(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   9478869,     219574]*)
(*NotebookOutlinePosition[   9582071,     222801]*)
(*  CellTagsIndexPosition[   9566610,     222312]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["2. Fourier Series and Transforms", "Title",
  CellTags->"c:1"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["2.1 Fourier Representation of Periodic Functions", "Subtitle",
  CellTags->{"Sec. 2.1", "i:14", "c:2"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["2.1.1 Introduction", "Subsubtitle",
  CellTags->"c:3"],

Cell[TextData[{
  "A  function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\)\(\ \)\)\)]],
  "is ",
  StyleBox["periodic with period ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`T\)],
    FontSlant->"Italic"],
  " when, for any value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", "
}], "Text",
  CellTags->"i:1"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = f(t + T)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.1)"],

Cell[TextData[{
  "An example of a periodic function is shown in Fig. ",
  ButtonBox["2.1",
    ButtonData:>"Fig. 2.1",
    ButtonStyle->"Hyperlink"],
  ". We have already encountered simple examples of periodic functions: the \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ t\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ t\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`tan\ t\)]],
  " are periodic with periods ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ",",
  " and \[Pi] respectively. "
}], "Text"],

Cell[TextData[{
  "\tFunctions that have period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " are also periodic over longer time intervals ",
  Cell[BoxData[
      \(TraditionalForm\`2  T, \ 3  T, \ 4  T, \  ... \)]],
  " . This follows directly from Eq. ",
  ButtonBox["(2.1.1)",
    ButtonData:>"(2.1.1)",
    ButtonStyle->"Hyperlink"],
  ": "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`f(
        t) = \(f(
          t + T) = \(f(
            t + 2  T) = \(f(
              t + 3  T) = \ \(\(...\)\(\ \)\(.\)\)\)\)\)\)]]], \
"NumberedEquation",
  CellTags->"(2.1.2)"],

Cell[TextData[{
  "For example, ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ t\)]],
  " has period ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ", but also has period ",
  Cell[BoxData[
      \(TraditionalForm\`4  \[Pi], \ 6  \[Pi],  ... \)]],
  ". We can define the ",
  StyleBox["fundamental period",
    FontSlant->"Italic"],
  " of a periodic function as the smallest period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " for which Eq. ",
  ButtonBox["(2.1.1)",
    ButtonData:>"(2.1.1)",
    ButtonStyle->"Hyperlink"],
  " holds. So the fundamental period of ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ t\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]\)]],
  ", and that of ",
  Cell[BoxData[
      \(TraditionalForm\`tan\ t\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]\)]],
  ". When we speak of the period of a function, we usually mean ",
  "its",
  " fundamental period. We will also have occasion to discuss the ",
  StyleBox["fundamental frequency ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\  = \ 2\ \[Pi]/T\)]],
  " of the function."
}], "Text",
  CellTags->"i:97"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0 0.515028 [
[.02381 -0.0125 -6 -9 ]
[.02381 -0.0125 6 0 ]
[.2619 -0.0125 -6 -9 ]
[.2619 -0.0125 6 0 ]
[.7381 -0.0125 -3 -9 ]
[.7381 -0.0125 3 0 ]
[.97619 -0.0125 -3 -9 ]
[.97619 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .10301 -18 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -18 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .30902 -18 -4.5 ]
[.4875 .30902 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.5 .64303 -14 0 ]
[.5 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-1)] .2619 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(1)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(2)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .10301 m
.50625 .10301 L
s
[(0.2)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(0.4)] .4875 .20601 1 0 Mshowa
.5 .30902 m
.50625 .30902 L
s
[(0.6)] .4875 .30902 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.8)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.125 Mabswid
.5 .02575 m
.50375 .02575 L
s
.5 .0515 m
.50375 .0515 L
s
.5 .07725 m
.50375 .07725 L
s
.5 .12876 m
.50375 .12876 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .18026 m
.50375 .18026 L
s
.5 .23176 m
.50375 .23176 L
s
.5 .25751 m
.50375 .25751 L
s
.5 .28327 m
.50375 .28327 L
s
.5 .33477 m
.50375 .33477 L
s
.5 .36052 m
.50375 .36052 L
s
.5 .38627 m
.50375 .38627 L
s
.5 .43777 m
.50375 .43777 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .48928 m
.50375 .48928 L
s
.5 .54078 m
.50375 .54078 L
s
.5 .56653 m
.50375 .56653 L
s
.5 .59228 m
.50375 .59228 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .51503 m
.03347 .52463 L
.044 .53316 L
.0539 .53934 L
.06341 .54361 L
.0683 .54516 L
.07102 .54584 L
.07354 .54635 L
.07609 .54674 L
.07744 .5469 L
.07886 .54704 L
.07946 .54708 L
.0801 .54712 L
.08065 .54715 L
.08126 .54718 L
.08163 .54719 L
.08197 .5472 L
.08229 .54721 L
.08246 .54721 L
.08264 .54721 L
.08281 .54722 L
.08298 .54722 L
.0833 .54722 L
.08359 .54722 L
.0839 .54721 L
.0842 .54721 L
.08437 .54721 L
.08453 .5472 L
.08514 .54719 L
.08569 .54717 L
.08627 .54714 L
.08747 .54706 L
.08881 .54695 L
.09117 .54666 L
.09339 .5463 L
.09844 .54515 L
.10306 .54368 L
.11297 .53924 L
.1225 .53328 L
.13264 .52513 L
.1424 .51552 L
.15277 .50341 L
.16277 .48989 L
.17238 .47517 L
.18261 .45767 L
.19246 .43902 L
.20194 .41942 L
.21202 .39676 L
.22173 .37321 L
.23205 .3463 L
Mistroke
.24199 .31854 L
.25155 .29015 L
.26172 .25811 L
.2619 .25751 L
Mfstroke
.2619 .51503 m
.27156 .52463 L
.2821 .53316 L
.29199 .53934 L
.3015 .54361 L
.3064 .54516 L
.30912 .54584 L
.31163 .54635 L
.31419 .54674 L
.31553 .5469 L
.31696 .54704 L
.31755 .54708 L
.31819 .54712 L
.31875 .54715 L
.31935 .54718 L
.31972 .54719 L
.32006 .5472 L
.32039 .54721 L
.32055 .54721 L
.32073 .54721 L
.32091 .54722 L
.32107 .54722 L
.32139 .54722 L
.32168 .54722 L
.32199 .54721 L
.3223 .54721 L
.32247 .54721 L
.32263 .5472 L
.32323 .54719 L
.32378 .54717 L
.32436 .54714 L
.32557 .54706 L
.3269 .54695 L
.32927 .54666 L
.33149 .5463 L
.33653 .54515 L
.34116 .54368 L
.35106 .53924 L
.36059 .53328 L
.37073 .52513 L
.38049 .51552 L
.39087 .50341 L
.40086 .48989 L
.41048 .47517 L
.42071 .45767 L
.43056 .43902 L
.44003 .41942 L
.45012 .39676 L
.45982 .37321 L
.47014 .3463 L
Mistroke
.48008 .31854 L
.48964 .29015 L
.49982 .25811 L
.5 .25751 L
Mfstroke
.5 .51503 m
.50966 .52463 L
.52019 .53316 L
.53009 .53934 L
.5396 .54361 L
.54449 .54516 L
.54721 .54584 L
.54973 .54635 L
.55228 .54674 L
.55363 .5469 L
.55505 .54704 L
.55565 .54708 L
.55629 .54712 L
.55684 .54715 L
.55745 .54718 L
.55782 .54719 L
.55816 .5472 L
.55848 .54721 L
.55865 .54721 L
.55883 .54721 L
.559 .54722 L
.55917 .54722 L
.55949 .54722 L
.55978 .54722 L
.56009 .54721 L
.56039 .54721 L
.56057 .54721 L
.56072 .5472 L
.56133 .54719 L
.56188 .54717 L
.56246 .54714 L
.56366 .54706 L
.565 .54695 L
.56736 .54666 L
.56958 .5463 L
.57463 .54515 L
.57925 .54368 L
.58916 .53924 L
.59869 .53328 L
.60883 .52513 L
.61859 .51552 L
.62896 .50341 L
.63896 .48989 L
.64857 .47517 L
.6588 .45767 L
.66865 .43902 L
.67813 .41942 L
.68821 .39676 L
.69792 .37321 L
.70824 .3463 L
Mistroke
.71818 .31854 L
.72774 .29015 L
.73791 .25811 L
.7381 .25751 L
Mfstroke
.7381 .51503 m
.74775 .52463 L
.75829 .53316 L
.76818 .53934 L
.77769 .54361 L
.78259 .54516 L
.78531 .54584 L
.78782 .54635 L
.79038 .54674 L
.79172 .5469 L
.79315 .54704 L
.79374 .54708 L
.79439 .54712 L
.79494 .54715 L
.79554 .54718 L
.79591 .54719 L
.79625 .5472 L
.79658 .54721 L
.79674 .54721 L
.79692 .54721 L
.7971 .54722 L
.79726 .54722 L
.79758 .54722 L
.79788 .54722 L
.79818 .54721 L
.79849 .54721 L
.79866 .54721 L
.79882 .5472 L
.79942 .54719 L
.79997 .54717 L
.80055 .54714 L
.80176 .54706 L
.80309 .54695 L
.80546 .54666 L
.80768 .5463 L
.81272 .54515 L
.81735 .54368 L
.82725 .53924 L
.83678 .53328 L
.84692 .52513 L
.85668 .51552 L
.86706 .50341 L
.87705 .48989 L
.88667 .47517 L
.8969 .45767 L
.90675 .43902 L
.91622 .41942 L
.92631 .39676 L
.93601 .37321 L
.94633 .3463 L
Mistroke
.95627 .31854 L
.96583 .29015 L
.97601 .25811 L
.97619 .25751 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo000^Ool8001[Ool7003FOol7001ZOol80019Ool0
02moo`03001oogoo00=oo`03001oogoo06aoo`03001oogoo0=Yoo`03001oogoo06aoo`03001oogoo
00=oo`03001oogoo04Moo`00<7oo00<007ooOol0LGoo00<007ooOol0fWoo00<007ooOol0KGoo00<0
07ooOol0C7oo000aOol00`00Oomoo`1`Ool00`00Oomoo`3JOol00`00Oomoo`1^Ool00`00Oomoo`1;
Ool0029oo`T000Moo`03001oogoo05moo`T000Moo`03001oogoo0=Yoo`03001oogoo06moo`03001o
ogoo04Yoo`008Woo2@0027oo00<007ooOol0GWoo2@001goo00<007ooOol0fWoo00<007ooOol0L7oo
00<007ooOol0BGoo000dOol00`00Oomoo`1]Ool00`00Oomoo`3JOol00`00Oomoo`1aOol00`00Oomo
o`18Ool003Eoo`03001oogoo06aoo`03001oogoo0=Yoo`03001oogoo079oo`03001oogoo04Moo`00
=Goo00<007ooOol0K7oo00<007ooOol0fWoo00<007ooOol0LWoo00<007ooOol0Agoo000_Ool00`00
Oomoo`03Ool00`00Oomoo`1/Ool00`00Oomoo`3JOol00`00Oomoo`1/Ool00`00Oomoo`03Ool00`00
Oomoo`17Ool002moo`8000=oo`03001oogoo06Yoo`@00=Uoo`@006ioo`8000=oo`03001oogoo04Qo
o`00<Goo0`00Kgoo0P00fgoo0P00L7oo0`00Bgoo003oOoooOom2Ool00?mooomood9oo`00ogooogoo
@Woo003oOoooOolDOol5000YOol00?mooomooa=oo`03001oogoo00=oo`8002Moo`00ogooogoo4goo
00<007ooOol0;7oo003oOoooOolCOol00`00Oomoo`0/Ool00?mooomooa=oo`03001oogoo02aoo`00
8Gooo`00g`004Woo00<007ooOol0;7oo000/Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomo
o`0COol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomo
o`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomo
o`0DOol00`00Oomoo`0COol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol00`00Oomo
o`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0/Ool002aoo`03
001oogoo06moo`03001oogoo06ioo`03001oogoo06moo`03001oogoo06moo`03001oogoo01Uoo`P0
02Uoo`00;7oo00<007ooOol0Kgoo00<007ooOol0KWoo00<007ooOol0Kgoo00<007ooOol0Kgoo00<0
07ooOol06goo00<007ooOol0;7oo003oOol@Ool00`00Oomoo`3oOol00`00Oomoo`0/Ool00?mooa1o
o`03001oogoo0?moo`03001oogoo02aoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00
Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003o
Ool@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo0`00ogoo;goo
003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007oo
Ool0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo
47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?mo
obmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03
001oogoo0?moobmoo`00ogoo47oo0`00ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1o
o`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_
Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00
Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003o
Ool@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo0`00ogoo;goo
003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007oo
Ool0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo
47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?mo
obmoo`00jGoo100027oo0`001goo200027oo00<007ooOol0ogoo;goo003XOol00`00Oomoo`02Ool0
0`00Oomoo`05Ool30008Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`3oOol_Ool00>Qo
o`03001oogoo009oo`03001oogoo00Eoo`<000Uoo`03001oogoo00]oo`03001oogoo0?moobmoo`00
igoo00<007ooOol017oo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol0ogoo;goo003WOol0
0`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`09Ool4003oOol^Ool00>Moo`03001oogoo00Ao
o`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo0?moobmoo`00igoo00<007ooOol017oo00<0
07ooOol057oo00<007ooOol01goo00<007ooOol0ogoo;goo003WOol00`00Oomoo`04Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`3oOol_Ool00>Moo`03001oogoo00Aoo`03001oogoo01Eo
o`03001oogoo00Ioo`03001oogoo0?moobmoo`00j7oo00<007ooOol00Woo00<007ooOol047oo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol0ogoo;goo003XOol00`00Oomoo`02Ool00`00Oomo
o`0@Ool20003Ool00`00Oomoo`07Ool00`00Oomoo`3oOol_Ool00>Uoo`@001Eoo`<000Yoo`03001o
ogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mo
oa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool3003oOol_Ool0
0?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomo
o`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@
Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo
;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<0
07ooOol0ogoo;goo003oOol@Ool3003oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo
00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmo
o`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001o
ogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mo
oa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3o
Ool_Ool00?mooa1oo`<00?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomo
o`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@
Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo
;goo003YOol40008Ool3000;Ool50007Ool00`00Oomoo`3oOol_Ool00>Qoo`03001oogoo009oo`03
001oogoo00Eoo`<000eoo`03001oogoo00Moo`03001oogoo0?moobmoo`00j7oo00<007ooOol00Woo
00<007ooOol01Goo0`003Goo00<007ooOol01goo00<007ooOol0ogoo;goo003WOol00`00Oomoo`04
Ool00`00Oomoo`0>Ool90007Ool00`00Oomoo`3oOol_Ool00>Moo`03001oogoo00Aoo`03001oogoo
00moo`03001oogoo009oo`03001oogoo00Moo`@00?moobioo`00igoo00<007ooOol017oo00<007oo
Ool03goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogoo;goo003WOol00`00Oomoo`04
Ool00`00Oomoo`0@Ool01@00Oomoogoo00002Goo00<007ooOol0ogoo;goo003WOol00`00Oomoo`04
Ool00`00Oomoo`0AOol01000Oomoo`002Goo00<007ooOol0ogoo;goo003WOol00`00Oomoo`04Ool0
0`00Oomoo`0AOol01000Oomoo`002Goo00<007ooOol0ogoo;goo003XOol00`00Oomoo`02Ool00`00
Oomoo`0COol00`00Ool00009Ool00`00Oomoo`3oOol_Ool00>Qoo`03001oogoo009oo`03001oogoo
01Aoo`8000Uoo`03001oogoo0?moobmoo`00jGoo10005goo0P002Goo00<007ooOol0ogoo;goo003o
Ool@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0
ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`<00?moobmoo`00ogoo47oo00<007oo
Ool0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo
47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?mo
obmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03
001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool0
09ioo`03001oogoo06ioo`<006moo`03001oogoo06moo`03001oogoo04Yoo`00WWoo00<007ooOol0
KWoo00<007ooOol0Kgoo00<007ooOol0Kgoo00<007ooOol0BWoo002NOol00`00Oomoo`1^Ool00`00
Oomoo`1_Ool00`00Oomoo`1_Ool00`00Oomoo`1:Ool009eoo`03001oogoo06ioo`80071oo`03001o
ogoo06moo`03001oogoo04]oo`00WGoo00<007ooOol0KWoo0P00L7oo00<007ooOol0Kgoo00<007oo
Ool0Bgoo002MOol00`00Oomoo`1^Ool2001`Ool00`00Oomoo`1_Ool00`00Oomoo`1;Ool009aoo`03
001oogoo06ioo`03001oo`0006moo`03001oogoo06moo`03001oogoo04aoo`00W7oo00<007ooOol0
KWoo00<007oo0000Kgoo00<007ooOol0Kgoo00<007ooOol0C7oo002LOol00`00Oomoo`1^Ool00`00
Ool0001_Ool00`00Oomoo`1_Ool00`00Oomoo`1<Ool009]oo`03001oogoo06ioo`04001oogoo001^
Ool00`00Oomoo`1_Ool00`00Oomoo`1=Ool009]oo`03001oogoo06ioo`04001oogoo001^Ool00`00
Oomoo`1_Ool00`00Oomoo`1=Ool009]oo`03001oogoo06ioo`04001oogoo001^Ool00`00Oomoo`1_
Ool00`00Oomoo`1=Ool009Yoo`03001oogoo06ioo`05001oogooOol0001]Ool00`00Oomoo`1_Ool0
0`00Oomoo`1>Ool009Yoo`03001oogoo06ioo`04001oogooOol3001[Ool00`00Oomoo`1_Ool00`00
Oomoo`1>Ool009Yoo`03001oogoo06ioo`05001oogooOol0001]Ool00`00Oomoo`1_Ool00`00Oomo
o`1>Ool009Uoo`03001oogoo06ioo`03001oogoo009oo`03001oogoo06Yoo`03001oogoo06moo`03
001oogoo04moo`00VGoo00<007ooOol0KWoo00<007ooOol00Woo00<007ooOol0JWoo00<007ooOol0
Kgoo00<007ooOol0Cgoo002IOol00`00Oomoo`1^Ool00`00Oomoo`02Ool00`00Oomoo`1ZOol00`00
Oomoo`1_Ool00`00Oomoo`1?Ool009Qoo`03001oogoo06moo`03001oogoo009oo`03001oogoo06Uo
o`03001oogoo06moo`03001oogoo051oo`00V7oo00<007ooOol0KWoo00<007ooOol00goo00<007oo
Ool0JGoo00<007ooOol0Kgoo00<007ooOol0D7oo002HOol00`00Oomoo`1^Ool00`00Oomoo`03Ool0
0`00Oomoo`1YOol00`00Oomoo`1_Ool00`00Oomoo`1@Ool009Moo`03001oogoo04moo`@000Qoo`<0
00Uoo`@000Aoo`03001oogoo00=oo`03001oogoo06Qoo`03001oogoo06moo`03001oogoo055oo`00
Ugoo00<007ooOol0CWoo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol00Woo00@0
07ooOol000Ioo`03001oogoo06Qoo`03001oogoo06moo`03001oogoo055oo`00Ugoo00<007ooOol0
CWoo00<007ooOol00Woo00<007ooOol01Goo0`001goo00<007ooOol017oo00<007oo00001Woo00<0
07ooOol0J7oo00<007ooOol0Kgoo00<007ooOol0DGoo002FOol00`00Oomoo`1>Ool00`00Oomoo`04
Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Ool00006Ool00`00Oomoo`1WOol00`00Oomoo`1_
Ool00`00Oomoo`1BOol009Ioo`03001oogoo04ioo`03001oogoo00Aoo`03001oogoo00ioo`03001o
ogoo00Aoo`03001oo`0000Ioo`@006Ioo`03001oogoo06moo`03001oogoo059oo`00UWoo00<007oo
Ool0CWoo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo0P001goo00<007ooOol0Igoo
00<007ooOol0Kgoo00<007ooOol0DWoo002EOol00`00Oomoo`1?Ool00`00Oomoo`04Ool00`00Oomo
o`0>Ool20004Ool00`00Ool00007Ool00`00Oomoo`1VOol00`00Oomoo`1_Ool00`00Oomoo`1COol0
09Eoo`03001oogoo04moo`03001oogoo00Aoo`03001oogoo00ioo`03001oo`0000<0009oo`03001o
ogoo00Eoo`03001oogoo06Ioo`03001oogoo06moo`03001oogoo05=oo`00UGoo00<007ooOol0Cgoo
00<007ooOol017oo00<007ooOol03goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0IWoo
00<007ooOol0Kgoo00<007ooOol0Dgoo002DOol00`00Oomoo`1AOol00`00Oomoo`02Ool00`00Oomo
o`0@Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1UOol00`00Oomoo`1_Ool00`00Oomo
o`1DOol009Aoo`03001oogoo055oo`03001oogoo009oo`03001oogoo015oo`8000=oo`03001oogoo
00Ioo`03001oogoo06Eoo`03001oogoo06moo`03001oogoo05Aoo`00Tgoo00<007ooOol0Dgoo1000
5Woo100027oo00<007ooOol0IGoo00<007ooOol0KWoo00<007ooOol0EGoo002COol00`00Oomoo`1_
Ool00`00Oomoo`07Ool00`00Oomoo`1TOol00`00Oomoo`1_Ool00`00Oomoo`1EOol009=oo`03001o
ogoo06moo`03001oogoo00Moo`03001oogoo06Aoo`03001oogoo06moo`03001oogoo05Eoo`00TWoo
00<007ooOol0Kgoo00<007ooOol027oo00<007ooOol0I7oo00<007ooOol0KWoo00<007ooOol0EWoo
002BOol00`00Oomoo`1_Ool00`00Oomoo`08Ool00`00Oomoo`1SOol00`00Oomoo`1_Ool00`00Oomo
o`1FOol0095oo`03001oogoo06moo`03001oogoo00Uoo`<006=oo`03001oogoo06ioo`03001oogoo
05Moo`00TGoo00<007ooOol0Kgoo00<007ooOol02Goo00<007ooOol0Hgoo00<007ooOol0KWoo00<0
07ooOol0Egoo002AOol00`00Oomoo`1_Ool00`00Oomoo`09Ool00`00Oomoo`1ROol00`00Oomoo`1_
Ool00`00Oomoo`1GOol0091oo`03001oogoo06moo`03001oogoo00Yoo`03001oogoo069oo`03001o
ogoo06ioo`03001oogoo05Qoo`00T7oo00<007ooOol0Kgoo00<007ooOol02Woo00<007ooOol0HWoo
00<007ooOol0KWoo00<007ooOol0F7oo002@Ool00`00Oomoo`1_Ool00`00Oomoo`0:Ool00`00Oomo
o`1QOol00`00Oomoo`1_Ool00`00Oomoo`1HOol008moo`03001oogoo06moo`03001oogoo00]oo`03
001oogoo065oo`03001oogoo06ioo`03001oogoo05Uoo`00Sgoo00<007ooOol0Kgoo00<007ooOol0
2goo00<007ooOol0HGoo00<007ooOol0KWoo00<007ooOol0FGoo002?Ool00`00Oomoo`1^Ool00`00
Oomoo`0<Ool00`00Oomoo`1POol00`00Oomoo`1^Ool00`00Oomoo`1JOol008ioo`03001oogoo06mo
o`03001oogoo00aoo`03001oogoo061oo`03001oogoo06ioo`03001oogoo05Yoo`00SWoo00<007oo
Ool0Kgoo00<007ooOol037oo00<007ooOol0H7oo00<007ooOol0KWoo00<007ooOol0FWoo002>Ool0
0`00Oomoo`1^Ool00`00Oomoo`0=Ool00`00Oomoo`1OOol00`00Oomoo`1^Ool00`00Oomoo`1KOol0
08eoo`03001oogoo06moo`03001oogoo00eoo`03001oogoo05moo`03001oogoo06ioo`03001oogoo
05]oo`00SGoo00<007ooOol0KWoo00<007ooOol03Woo0`00GWoo00<007ooOol0KWoo00<007ooOol0
G7oo002=Ool00`00Oomoo`1^Ool00`00Oomoo`0>Ool00`00Oomoo`1NOol00`00Oomoo`1^Ool00`00
Oomoo`1LOol008aoo`03001oogoo06moo`03001oogoo00ioo`03001oogoo05ioo`03001oogoo06io
o`03001oogoo05aoo`00S7oo00<007ooOol0KWoo00<007ooOol03goo00<007ooOol0GGoo00<007oo
Ool0KWoo00<007ooOol0GGoo002<Ool00`00Oomoo`1^Ool00`00Oomoo`0?Ool00`00Oomoo`1MOol0
0`00Oomoo`1^Ool00`00Oomoo`1MOol008]oo`03001oogoo06moo`03001oogoo00moo`03001oogoo
05eoo`03001oogoo06ioo`03001oogoo05eoo`00Rgoo00<007ooOol0KWoo00<007ooOol047oo00<0
07ooOol0G7oo00<007ooOol0KWoo00<007ooOol0GWoo002;Ool00`00Oomoo`1^Ool00`00Oomoo`0@
Ool00`00Oomoo`1LOol00`00Oomoo`1^Ool00`00Oomoo`1NOol008Yoo`03001oogoo06ioo`03001o
ogoo015oo`03001oogoo05]oo`03001oogoo06ioo`03001oogoo05moo`00RWoo00<007ooOol0KWoo
00<007ooOol04Goo00<007ooOol0Fgoo00<007ooOol0KWoo00<007ooOol0Ggoo0029Ool00`00Oomo
o`1_Ool00`00Oomoo`0AOol00`00Oomoo`1JOol00`00Oomoo`1_Ool00`00Oomoo`1OOol008Uoo`03
001oogoo06ioo`03001oogoo019oo`03001oogoo05Yoo`03001oogoo06ioo`03001oogoo061oo`00
R7oo00<007ooOol0Kgoo00<007ooOol04Woo0`00FGoo00<007ooOol0Kgoo00<007ooOol0H7oo0028
Ool00`00Oomoo`1_Ool00`00Oomoo`0BOol00`00Oomoo`1IOol00`00Oomoo`1_Ool00`00Oomoo`1P
Ool008Qoo`03001oogoo06ioo`03001oogoo01=oo`03001oogoo05Uoo`03001oogoo06ioo`03001o
ogoo065oo`00Qgoo00<007ooOol0Kgoo00<007ooOol04goo00<007ooOol0F7oo00<007ooOol0Kgoo
00<007ooOol0HGoo0027Ool00`00Oomoo`1_Ool00`00Oomoo`0COol00`00Oomoo`1HOol00`00Oomo
o`1_Ool00`00Oomoo`1QOol008Ioo`03001oogoo06moo`03001oogoo01Aoo`03001oogoo05Moo`03
001oogoo06moo`03001oogoo069oo`00QWoo00<007ooOol0Kgoo00<007ooOol057oo00<007ooOol0
Egoo00<007ooOol0Kgoo00<007ooOol0HWoo0025Ool00`00Oomoo`1_Ool00`00Oomoo`0EOol00`00
Oomoo`1FOol00`00Oomoo`1_Ool00`00Oomoo`1SOol008Eoo`03001oogoo065oo`@000Qoo`<000Uo
o`@000Yoo`03001oogoo05Ioo`03001oogoo06moo`03001oogoo06=oo`00Q7oo00<007ooOol0HGoo
00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool0EGoo00<007ooOol0Kgoo00<007ooOol0I7oo0024Ool00`00Oomoo`1QOol00`00Oomoo`02Ool0
0`00Oomoo`05Ool30007Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`1EOol00`00Oomo
o`1_Ool00`00Oomoo`1TOol008=oo`03001oogoo065oo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo05Aoo`03001oogoo06moo`03
001oogoo06Eoo`00Pgoo00<007ooOol0HGoo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
1goo00<007ooOol017oo00<007ooOol01Woo1000Dgoo00<007ooOol0Kgoo00<007ooOol0IGoo0023
Ool00`00Oomoo`1QOol00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`1DOol00`00Oomoo`1_Ool00`00Oomoo`1UOol0089oo`03001o
ogoo069oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Uoo`H000Uoo`03001oogoo05=o
o`03001oogoo06moo`03001oogoo06Ioo`00PWoo00<007ooOol0HWoo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0Dgoo00<007oo
Ool0Kgoo00<007ooOol0IWoo0021Ool00`00Oomoo`1SOol00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`1BOol00`00Oomoo`1_Ool0
0`00Oomoo`1WOol0085oo`03001oogoo06Aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo
00Uoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo059oo`03001oogoo06moo`03001oogoo
06Moo`00P7oo00<007ooOol0IGoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02goo00<0
07ooOol00Woo00<007ooOol01goo00<007ooOol0DGoo00<007ooOol0Kgoo00<007ooOol0J7oo0020
Ool00`00Oomoo`1VOol40005Ool00`00Oomoo`0<Ool4000:Ool00`00Oomoo`1AOol00`00Oomoo`1_
Ool00`00Oomoo`1XOol007moo`03001oogoo06moo`03001oogoo01]oo`03001oogoo051oo`03001o
ogoo06moo`03001oogoo06Uoo`00Ogoo00<007ooOol0KWoo00<007ooOol077oo00<007ooOol0D7oo
00<007ooOol0KWoo00<007ooOol0JWoo001oOol00`00Oomoo`1^Ool00`00Oomoo`0LOol00`00Oomo
o`1@Ool00`00Oomoo`1^Ool00`00Oomoo`1ZOol007ioo`03001oogoo06ioo`03001oogoo01eoo`03
001oogoo04moo`03001oogoo06ioo`03001oogoo06]oo`00OWoo00<007ooOol0KWoo00<007ooOol0
7Goo00<007ooOol0Cgoo00<007ooOol0KWoo00<007ooOol0Jgoo001mOol00`00Oomoo`1^Ool00`00
Oomoo`0NOol3001>Ool00`00Oomoo`1^Ool00`00Oomoo`1/Ool007eoo`03001oogoo06ioo`03001o
ogoo01ioo`03001oogoo04ioo`03001oogoo06ioo`03001oogoo06aoo`00O7oo00<007ooOol0KWoo
00<007ooOol07goo00<007ooOol0CGoo00<007ooOol0KWoo00<007ooOol0KGoo001lOol00`00Oomo
o`1^Ool00`00Oomoo`0OOol00`00Oomoo`1=Ool00`00Oomoo`1^Ool00`00Oomoo`1]Ool007]oo`03
001oogoo06ioo`03001oogoo021oo`03001oogoo04aoo`03001oogoo06ioo`03001oogoo06ioo`00
NWoo00<007ooOol0Kgoo00<007ooOol087oo00<007ooOol0Bgoo00<007ooOol0Kgoo00<007ooOol0
KWoo001jOol00`00Oomoo`1_Ool00`00Oomoo`0POol00`00Oomoo`1;Ool00`00Oomoo`1_Ool00`00
Oomoo`1^Ool007Uoo`03001oogoo06moo`03001oogoo025oo`03001oogoo04Yoo`03001oogoo06mo
o`03001oogoo06moo`00NGoo00<007ooOol0Kgoo00<007ooOol08Goo00<007ooOol0BWoo00<007oo
Ool0Kgoo00<007ooOol0Kgoo001hOol00`00Oomoo`1_Ool00`00Oomoo`0ROol00`00Oomoo`19Ool0
0`00Oomoo`1_Ool00`00Oomoo`1`Ool007Qoo`03001oogoo06moo`03001oogoo029oo`03001oogoo
04Uoo`03001oogoo06moo`03001oogoo071oo`00Mgoo00<007ooOol0Kgoo00<007ooOol08goo00<0
07ooOol0B7oo00<007ooOol0Kgoo00<007ooOol0LGoo001fOol00`00Oomoo`1_Ool00`00Oomoo`0T
Ool30017Ool00`00Oomoo`1_Ool00`00Oomoo`1bOol007Ioo`03001oogoo06moo`03001oogoo02Ao
o`03001oogoo04Moo`03001oogoo06moo`03001oogoo079oo`00MGoo00<007ooOol0Kgoo00<007oo
Ool09Goo00<007ooOol0AWoo00<007ooOol0Kgoo00<007ooOol0Lgoo001eOol00`00Oomoo`1_Ool0
0`00Oomoo`0UOol00`00Oomoo`16Ool00`00Oomoo`1_Ool00`00Oomoo`1cOol007Aoo`03001oogoo
06moo`03001oogoo02Ioo`03001oogoo04Eoo`03001oogoo06moo`03001oogoo07Aoo`00Lgoo00<0
07ooOol0Kgoo00<007ooOol09goo00<007ooOol0A7oo00<007ooOol0Kgoo00<007ooOol0MGoo001c
Ool00`00Oomoo`1_Ool00`00Oomoo`0WOol00`00Oomoo`14Ool00`00Oomoo`1_Ool00`00Oomoo`1e
Ool0079oo`03001oogoo06moo`03001oogoo02Qoo`03001oogoo04=oo`03001oogoo06moo`03001o
ogoo07Ioo`00LGoo00<007ooOol0Kgoo00<007ooOol0:Goo00<007ooOol0@goo00<007ooOol0KWoo
00<007ooOol0Mgoo001`Ool00`00Oomoo`1_Ool00`00Oomoo`0ZOol00`00Oomoo`12Ool00`00Oomo
o`1^Ool00`00Oomoo`1hOol0071oo`03001oogoo06moo`03001oogoo02Yoo`03001oogoo045oo`03
001oogoo06moo`03001oogoo07Qoo`00Kgoo00<007ooOol0Kgoo00<007ooOol0:goo00<007ooOol0
@Goo00<007ooOol0KWoo00<007ooOol0NGoo001^Ool00`00Oomoo`1_Ool00`00Oomoo`0/Ool30010
Ool00`00Oomoo`1^Ool00`00Oomoo`1jOol006ioo`03001oogoo06moo`03001oogoo02aoo`03001o
ogoo041oo`03001oogoo06ioo`03001oogoo07Yoo`00KGoo00<007ooOol0Kgoo00<007ooOol0;Goo
00<007ooOol0?goo00<007ooOol0KWoo00<007ooOol0Ngoo001]Ool00`00Oomoo`1^Ool00`00Oomo
o`0^Ool00`00Oomoo`0nOol00`00Oomoo`1_Ool00`00Oomoo`1kOol006aoo`03001oogoo06ioo`03
001oogoo02moo`03001oogoo03eoo`03001oogoo06moo`03001oogoo07aoo`00Jgoo00<007ooOol0
Kgoo00<007ooOol0;goo00<007ooOol0?Goo00<007ooOol0KWoo00<007ooOol0OGoo001[Ool00`00
Oomoo`1^Ool00`00Oomoo`0`Ool00`00Oomoo`0lOol00`00Oomoo`1_Ool00`00Oomoo`1mOol006Yo
o`03001oogoo06ioo`03001oogoo035oo`03001oogoo03]oo`03001oogoo06moo`03001oogoo07io
o`00JWoo00<007ooOol0KWoo00<007ooOol08Woo1`0027oo00<007ooOol0>goo00<007ooOol0Kgoo
00<007ooOol0OWoo001YOol00`00Oomoo`1^Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomo
o`0jOol00`00Oomoo`1_Ool00`00Oomoo`1oOol006Qoo`03001oogoo06ioo`03001oogoo02Moo`03
001oogoo00Uoo`03001oogoo03Uoo`03001oogoo06moo`03001oogoo081oo`00Igoo00<007ooOol0
KWoo00<007ooOol0:7oo00<007ooOol02Goo00<007ooOol0>7oo00<007ooOol0Kgoo00<007ooOol0
PGoo000/Ool00`00Oomoo`0gOol00`00Oomoo`0eOol00`00Oomoo`0fOol00`00Oomoo`0YOol00`00
Oomoo`09Ool4000fOol00`00Oomoo`0eOol00`00Oomoo`0gOol00`00Oomoo`22Ool002eoo`03001o
ogoo03Aoo`8003Qoo`03001oogoo03Eoo`03001oogoo02Yoo`03001oogoo00Uoo`8003Ioo`8003Uo
o`03001oogoo03Aoo`8008Eoo`00;Woo00<007ooOol0<Woo00<007ooOol0>Goo00<007ooOol0<goo
00<007ooOol0:goo00<007ooOol02Goo00<007oo0000=7oo00<007ooOol0>Woo00<007ooOol0<Woo
00<007ooOol0QGoo000_Ool00`00Oomoo`0`Ool00`00Oomoo`0kOol00`00Oomoo`0aOol00`00Oomo
o`0/Ool00`00Oomoo`09Ool01000Oomoo`00<Woo00<007ooOol0?7oo00<007ooOol0<7oo00<007oo
Ool0QWoo000`Ool00`00Oomoo`0^Ool00`00Oomoo`0mOol00`00Oomoo`0_Ool00`00Oomoo`0]Ool0
0`00Oomoo`09Ool01@00Oomoogoo0000<7oo00<007ooOol0?Woo00<007ooOol0;Woo00<007ooOol0
Qgoo000aOol2000/Ool20011Ool2000]Ool2000`Ool00`00Oomoo`09Ool00`00Oomoo`02Ool2000/
Ool20012Ool2000/Ool2002:Ool003=oo`03001oogoo02Qoo`03001oogoo04=oo`03001oogoo02Uo
o`03001oogoo02eoo`@000]oo`03001oogoo00Aoo`03001oogoo02Qoo`03001oogoo04Aoo`03001o
ogoo02Qoo`03001oogoo08Yoo`00=7oo00<007ooOol09Woo00<007ooOol0AGoo00<007ooOol09goo
00<007ooOol0<7oo0P002goo00<007ooOol01Goo00<007ooOol09Woo00<007ooOol0AWoo00<007oo
Ool09Woo00<007ooOol0Rgoo000eOol00`00Oomoo`0TOol00`00Oomoo`17Ool00`00Oomoo`0UOol0
0`00Oomoo`0nOol00`00Oomoo`06Ool00`00Oomoo`0TOol00`00Oomoo`18Ool00`00Oomoo`0TOol0
0`00Oomoo`2<Ool003Ioo`80029oo`8004]oo`8002=oo`80045oo`03001oogoo00Moo`80029oo`80
04aoo`80029oo`8008moo`00>7oo00<007ooOol07Woo00<007ooOol0CGoo0P007goo0P00@goo00<0
07ooOol02Goo0P007goo00<007ooOol0CWoo00<007ooOol07Woo00<007ooOol0Sgoo000iOol00`00
Oomoo`0LOol00`00Oomoo`1@Ool00`00Oomoo`0KOol00`00Oomoo`13Ool00`00Oomoo`0;Ool00`00
Oomoo`0KOol00`00Oomoo`1@Ool00`00Oomoo`0LOol00`00Oomoo`2@Ool003Yoo`8001Yoo`8005Ao
o`8001Uoo`8004Ioo`03001oogoo00aoo`8001Uoo`8005Aoo`8001Yoo`8009=oo`00?7oo0`0057oo
0`00F7oo0`0057oo0P00B7oo0`003Woo0P0057oo0`00F7oo0`0057oo0`00UGoo000oOol2000@Ool2
001NOol2000@Ool2001:Ool00`00Oomoo`0@Ool3000?Ool2001NOol2000@Ool2002HOol0045oo`@0
00Qoo`@0069oo`@000Qoo`@004aoo`03001oogoo01=oo`<000Uoo`<0069oo`@000Qoo`@009Yoo`00
AGoo2000JWoo2000D7oo00<007ooOol05Woo2@00JGoo2000WWoo003oOol@Ool00`00Oomoo`3oOol_
Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00
Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003o
Ool@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo0`00ogoo;goo
003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007oo
Ool0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo
47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?mo
obmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03
001oogoo0?moobmoo`00ogoo47oo0`00ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1o
o`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_
Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00
Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003o
Ool@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0
ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2
Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogoo3Goo
00<007ooOol03Woo00<007ooOol0ogoo8Goo003oOol<Ool00`00Oomoo`0@Ool00`00Oomoo`3oOolP
Ool00?moo`aoo`03001oogoo011oo`03001oogoo0?moob1oo`00ogoo2goo00<007ooOol04Woo00<0
07ooOol0ogoo7goo003iOol7000:Ool00`00Oomoo`06Ool50007Ool00`00Oomoo`3oOolOOol00?]o
o`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00=oo`8000Ioo`03001oogoo0?mooaioo`00
ngoo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0ogoo7Woo003kOol0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3oOolNOol00?]oo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?mooaioo`00ngoo00<007ooOol0
2goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0ogoo7Woo003kOol00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3oOolNOol00?]oo`03001oogoo00]oo`03001o
ogoo00Aoo`P000Qoo`03001oogoo0?mooaioo`00nGoo1`002Woo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol0ogoo7goo003kOol00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`3oOolOOol00?]oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Uoo`03001o
ogoo0?moob1oo`00ngoo0P003Woo00<007ooOol047oo00<007ooOol0ogoo87oo003lOol5000;Ool0
0`00Oomoo`0>Ool00`00Oomoo`3oOolQOol00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool0
0?mooomood9oo`00ogooogoo@Woo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-2, 0, 0, 0}}],

Cell[TextData[{
  "Fig. 2.1 A periodic function with period ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  "."
}], "Caption",
  CellTags->"Fig. 2.1"],

Cell[TextData[{
  "\tWhy should we care about periodic functions? They play an important role \
in our quest to determine the particular solution to an ODE due to arbitrary \
forcing. In Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:45"},
    ButtonStyle->"Hyperlink"],
  ", we found the response of an oscillator to a simple periodic sine or \
cosine forcing.  However, this response will clearly be more complicated for \
periodic forcing of the type shown in Fig. ",
  ButtonBox["2.1",
    ButtonData:>"Fig. 2.1",
    ButtonStyle->"Hyperlink"],
  ". We  can determine this response by first writing the periodic forcing \
function as a sum of simple sine and cosine functions. This superposition is \
called a ",
  StyleBox["Fourier series",
    FontSlant->"Italic"],
  ", after the French mathematician ",
  ButtonBox["Jean Fourier",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ", who first showed how such a series can be constructed. Once we have this \
series for the forcing function, we can use the superposition principle to \
write the response of the oscillator as a sum of the individual responses to \
the individual cosine and sine terms in the series."
}], "Text",
  CellTags->"i:2"],

Cell["\<\
\t Later, we will find that Fourier series representation of \
periodic functions (and generalizations to the representation of nonperiodic \
functions) are also very useful in a number of other applications, such as \
the solution to certain common partial differential equations.\
\>", "Text"],

Cell[TextData[{
  "\tIn order to expand a  given periodic  function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " as a sum of sines and cosine functions, we must choose sines and cosines \
with the same periodicity as ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " itself. Since ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " has period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", we will therefore choose the functions ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ 2  \[Pi]\ t/T, \ sin\ 4  \[Pi]\ t/T, \ 
      sin\ 6  \[Pi]\ t/T ... \)]],
  "  and   ",
  Cell[BoxData[
      \(TraditionalForm\`1, \ cos\ 2  \[Pi]\ t/T, \ cos\ 4  \[Pi]\ t/T, \ 
      cos\ 6  \[Pi]\ t/T,  ... \)]],
  ". These functions have fundamental periods ",
  Cell[BoxData[
      \(TraditionalForm\`T/n\)]],
  " for integers ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3,  ... \)]],
  ", and therefore by Eq. ",
  ButtonBox["(2.1.2)",
    ButtonData:>"(2.1.2)",
    ButtonStyle->"Hyperlink"],
  " are also periodic with period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". Note that the constant function ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ", with undefined period, is included. A few of these functions are shown \
in Cells ",
  ButtonBox["2.1",
    ButtonData:>"Cell 2.1",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["2.2",
    ButtonData:>"Cell 2.2",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(T = 1; \ 
    Plot[{Sin[2  Pi\ t/T], Sin[4  Pi\ t/T], Sin[6  Pi\ t/T]}, {t, 0, T}, 
      PlotStyle \[Rule] {Red, Blue, Purple}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.1"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309016 0.294303 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .30902 m
.06244 .38322 L
.10458 .45852 L
.14415 .51889 L
.18221 .56357 L
.20178 .58047 L
.21267 .58793 L
.22272 .59354 L
.23293 .59796 L
.23832 .59976 L
.24402 .60127 L
.24641 .60178 L
.24897 .60225 L
.25119 .60258 L
.25361 .60288 L
.25507 .60302 L
.25643 .60313 L
.25773 .60321 L
.2584 .60324 L
.25912 .60327 L
.25983 .60329 L
.26048 .60331 L
.26176 .60332 L
.26293 .60331 L
.26416 .60329 L
.26538 .60324 L
.26607 .60321 L
.26671 .60317 L
.26912 .60299 L
.27131 .60275 L
.27364 .60244 L
.27847 .60156 L
.2838 .60025 L
.29326 .59705 L
.30213 .59301 L
.32232 .58025 L
.34082 .56432 L
.38045 .51781 L
.41855 .45965 L
.45912 .38744 L
.49816 .31259 L
.53966 .23289 L
.57964 .1614 L
.61811 .10221 L
.63759 .07707 L
.65902 .05386 L
.67938 .03652 L
.69843 .02473 L
.70884 .02018 L
.71396 .01844 L
Mistroke
.71872 .01712 L
.72301 .01617 L
.72758 .01542 L
.7302 .01511 L
.73148 .01499 L
.73266 .0149 L
.73371 .01484 L
.73487 .01478 L
.73603 .01474 L
.73725 .01472 L
.73856 .01472 L
.73977 .01473 L
.7404 .01475 L
.7411 .01477 L
.74251 .01484 L
.74375 .01492 L
.74508 .01503 L
.74748 .01528 L
.74985 .0156 L
.75235 .01601 L
.7568 .01695 L
.76198 .01836 L
.7668 .01998 L
.77773 .02472 L
.78828 .0307 L
.79823 .03757 L
.81683 .05353 L
.85534 .09846 L
.89632 .16101 L
.93577 .23146 L
.97371 .3042 L
.97619 .30902 L
Mfstroke
0 0 1 r
.02381 .30902 m
.06244 .45263 L
.08255 .51497 L
.0932 .54236 L
.10458 .56657 L
.11009 .57624 L
.11531 .58409 L
.12038 .59047 L
.12507 .59525 L
.12951 .59877 L
.13178 .60018 L
.13422 .60141 L
.13549 .60193 L
.13666 .60234 L
.13784 .60268 L
.13895 .60293 L
.14022 .60314 L
.1409 .60322 L
.14161 .60328 L
.1423 .60331 L
.14295 .60332 L
.14415 .60328 L
.14531 .60316 L
.14656 .60297 L
.14773 .60271 L
.14881 .60241 L
.15143 .60144 L
.15392 .60019 L
.15886 .59679 L
.16423 .59169 L
.17383 .57909 L
.1827 .56357 L
.20137 .51989 L
.22197 .45702 L
.26217 .30798 L
.30086 .16432 L
.32051 .10346 L
.3309 .0766 L
.342 .05274 L
.35275 .03485 L
.35784 .0283 L
.36253 .02337 L
.36724 .01952 L
.36972 .01794 L
.37235 .01661 L
.37463 .01574 L
.37573 .01541 L
.37677 .01516 L
.37799 .01494 L
.37911 .0148 L
Mistroke
.38031 .01472 L
.38162 .01473 L
.38227 .01476 L
.38296 .01482 L
.38419 .01498 L
.38551 .01524 L
.38695 .01564 L
.38955 .0166 L
.39197 .01782 L
.39649 .02088 L
.40134 .02529 L
.40698 .0319 L
.41232 .03956 L
.42232 .05748 L
.44227 .1059 L
.4607 .16316 L
.50002 .3091 L
.53782 .44987 L
.55884 .51523 L
.56803 .53913 L
.57808 .56136 L
.58722 .57774 L
.59696 .59091 L
.60236 .59621 L
.60726 .59976 L
.60962 .60104 L
.61086 .6016 L
.61218 .60211 L
.61333 .60248 L
.61459 .60281 L
.61574 .60304 L
.61682 .60319 L
.61808 .60329 L
.61871 .60332 L
.61941 .60332 L
.62065 .60325 L
.62181 .60312 L
.62248 .60302 L
.62318 .60288 L
.62443 .60258 L
.62578 .60216 L
.62725 .6016 L
.62973 .6004 L
.63238 .59878 L
.63715 .59497 L
.64214 .58976 L
.64686 .58372 L
.6557 .56958 L
.67568 .52489 L
.69413 .47033 L
Mistroke
.7335 .32685 L
.77136 .18397 L
.79241 .1157 L
.81166 .06613 L
.82118 .04724 L
.8262 .0389 L
.83155 .03133 L
.8367 .02536 L
.84136 .02107 L
.84361 .01939 L
.84604 .01786 L
.84835 .01669 L
.85045 .01586 L
.85159 .0155 L
.85283 .01519 L
.85414 .01494 L
.85538 .01479 L
.85653 .01472 L
.85776 .01472 L
.85881 .01479 L
.85997 .01492 L
.86063 .01502 L
.86132 .01516 L
.86256 .01547 L
.86535 .01644 L
.86777 .0176 L
.87041 .01921 L
.87569 .02348 L
.88133 .02957 L
.89148 .0444 L
.90173 .06419 L
.91284 .09067 L
.933 .15021 L
.97393 .30026 L
.97619 .30902 L
Mfstroke
.628 .126 .941 r
.02381 .30902 m
.04262 .41606 L
.06244 .51276 L
.07286 .5519 L
.08255 .57915 L
.08813 .59036 L
.09076 .59448 L
.0932 .5976 L
.096 .60036 L
.09748 .60145 L
.09824 .60191 L
.09905 .60234 L
.09976 .60265 L
.10041 .60288 L
.10168 .60319 L
.10239 .60328 L
.10317 .60332 L
.1039 .60329 L
.10458 .60321 L
.10587 .6029 L
.10651 .60268 L
.10722 .60237 L
.10848 .6017 L
.10966 .6009 L
.11231 .59853 L
.11515 .59509 L
.12035 .58647 L
.1251 .57604 L
.13466 .54801 L
.14371 .51358 L
.18204 .31193 L
.20142 .20156 L
.21172 .14833 L
.22282 .09846 L
.23339 .06036 L
.23801 .04701 L
.24307 .03492 L
.24787 .02599 L
.25234 .01998 L
.25481 .01761 L
.25705 .01607 L
.25829 .01546 L
.259 .0152 L
.25964 .01501 L
.26083 .01478 L
.26209 .01472 L
.2633 .01483 L
.26462 .01514 L
.26586 .01562 L
.26702 .01622 L
Mistroke
.2692 .01778 L
.27152 .02003 L
.27427 .02348 L
.27684 .02749 L
.28166 .03693 L
.29046 .06049 L
.29997 .09438 L
.31995 .1885 L
.34103 .30762 L
.36093 .42068 L
.37905 .50916 L
.3891 .54783 L
.3986 .57578 L
.40382 .58716 L
.40863 .59506 L
.41115 .59815 L
.41392 .60072 L
.41532 .60169 L
.41605 .60211 L
.41682 .60248 L
.41749 .60275 L
.41823 .60299 L
.41953 .60325 L
.42017 .60331 L
.42086 .60332 L
.42208 .6032 L
.42339 .60288 L
.42414 .60261 L
.42483 .6023 L
.42724 .6008 L
.4286 .59967 L
.42983 .59846 L
.43463 .5921 L
.43918 .58372 L
.44922 .55747 L
.46014 .51783 L
.47989 .42306 L
.50089 .30381 L
.52056 .19252 L
.53861 .10537 L
.54802 .06955 L
.55794 .04079 L
.56309 .02985 L
.56789 .02227 L
.57065 .01909 L
.57315 .01694 L
.57454 .01605 L
.57527 .01568 L
.57605 .01535 L
.57672 .01512 L
Mistroke
.57747 .01492 L
.57878 .01473 L
.58007 .01474 L
.58127 .01492 L
.58259 .01531 L
.58332 .01561 L
.58399 .01594 L
.58653 .01767 L
.58893 .01997 L
.59339 .02597 L
.59821 .03494 L
.6035 .04765 L
.60909 .06418 L
.61909 .10109 L
.65708 .29942 L
.67824 .41987 L
.69753 .51344 L
.70711 .54968 L
.71216 .56538 L
.71752 .57926 L
.7222 .58887 L
.72468 .59301 L
.72736 .5967 L
.72981 .59937 L
.73088 .60032 L
.73205 .60122 L
.73309 .60188 L
.7342 .60244 L
.73537 .60289 L
.73645 .60316 L
.73769 .60331 L
.73839 .60331 L
.73905 .60327 L
.73974 .60316 L
.74037 .60302 L
.7411 .6028 L
.74179 .60253 L
.74301 .60193 L
.74414 .60121 L
.74671 .59905 L
.74953 .59581 L
.75209 .5921 L
.75782 .58118 L
.76281 .5688 L
.7682 .55259 L
.77797 .51632 L
.81905 .29977 L
.83953 .18454 L
.84952 .13458 L
.85861 .09497 L
Mistroke
.86742 .06317 L
.87699 .03711 L
.88224 .02689 L
.88455 .02336 L
.88709 .02016 L
.88949 .01781 L
.89173 .01621 L
.89297 .01557 L
.8941 .01514 L
.89541 .01483 L
.89665 .01472 L
.89789 .01478 L
.89859 .01489 L
.89924 .01505 L
.90042 .01546 L
.90168 .01607 L
.90385 .01755 L
.90623 .0198 L
.90878 .02291 L
.91151 .02706 L
.91645 .03663 L
.92606 .06263 L
.93483 .09413 L
.95391 .18339 L
.97467 .30013 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003oooooooooo`3oooooodCooooo
000Rooooo`03o`000?oooooooooo0?ooooooA?ooool001Sooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooooooo0?ooooooA?ooool001[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooodCooooo000?ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?ooooooA?ooool001[ooooo00?o0000ooooooooool01Oooool3o`0004[ooooo
1OnP8?0Rooooo`Ko003o?Oooool4oj0Pl2gooooo3?oo000Oooooo`Ko003o1oooool5oj0Pl27ooooo
000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B_ooool01OnP8?3ooooooooo
ooooooooX23`023ooooo0ol00?l4ooooo`?o003o>_ooool00onP8?3oooooooooo`02ooooo`03oj0P
l?oooooooooo02Oooooo0ooo000<ooooo`?oo`006Oooool3o`00o`Gooooo0_l00?l6ooooo`03oj0P
l?oooooooooo00;ooooo00?oX23`ooooooooool07_ooool001[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`19ooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool07?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo03Kooooo00?oX23`ooooooooool01?oo
ool00onP8?3oooooooooo`0Sooooo`?oo`004_ooool3ool001Gooooo0_l00?l9ooooo`03o`00oooo
oooooooo00;ooooo00?oX23`ooooooooool00oooool00onP8?3oooooooooo`0Nooooo`006_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo00?oX23`ooooooooool01Oooool0
0onP8?3oooooooooo`0Jooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool0=Oooool0
0onP8?3oooooooooo`04ooooo`03oj0Pl?oooooooooo023ooooo0ooo000Hooooo`?oo`004Oooool0
0ol00?ooooooooooo`0:ooooo`04o`00oooooooooooooj0Pl0Oooooo00?oX23`ooooooooool07Ooo
ool001Sooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`17ooooo`03oj0Pl?oooooo
oooo00Oooooo00?oX23`ooooooooool06?ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo03Cooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`0Nooooo`03ool00?oooooo
oooo01cooooo00?oo`00ooooooooool03Oooool00ol00?ooooooooooo`0<ooooo`03o`00oonP8?3o
oooo00Sooooo00?oX23`ooooooooool07?ooool002;ooooo00?o0000ooooooooool0Aoooool00onP
8?3oooooooooo`07ooooo`03oj0Pl?oooooooooo01Sooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0booooo`03oj0Pl?oooooooooo00Oooooo00?oX23`ooooooooool07?ooool2ool0
023ooooo0_oo000<ooooo`03o`00oooooooooooo00kooooo00?oX23`ooooooooool01oooool00onP
8?3oooooooooo`0Looooo`008_ooool00ol0003oooooooooo`16ooooo`03oj0Pl?oooooooooo00Wo
oooo00?oX23`ooooooooool05_ooool00ol00?ooooooooooo`0>ooooo`03o`00oooooooooooo037o
oooo00?oX23`ooooooooool02?ooool00onP8?3oooooooooo`0Jooooo`03ool00?oooooooooo02;o
oooo00?oo`00ooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03oj0Pl?l00?oooooo00Wo
oooo00?oX23`ooooooooool06oooool002;ooooo00?o0000ooooooooool0A_ooool00onP8?3ooooo
ooooo`09ooooo`03oj0Pl?oooooooooo01Gooooo00?o003oooooooooool04?ooool00ol00?oooooo
ooooo`0_ooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool05oooool2ool002Kooooo
0_oo0008ooooo`03o`00oooooooooooo00kooooo00?oX23`ooooool00?l02_ooool00onP8?3ooooo
ooooo`0Jooooo`008_ooool00ol0003oooooooooo`16ooooo`03oj0Pl?oooooooooo00Wooooo00?o
X23`ooooooooool05Oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooooooo02kooooo00?o
X23`ooooooooool02_ooool00onP8?3oooooooooo`0Fooooo`03ool00?oooooooooo02Sooooo00?o
o`00ooooooooool01Oooool00ol00?ooooooooooo`0>ooooo`04oj0Pl?ooooooooooo`00o`Wooooo
00?oX23`ooooooooool06_ooool002;ooooo00?o0000ooooooooool0AOooool00onP8?3ooooooooo
o`0;ooooo`03oj0Pl?oooooooooo01?ooooo00?o003oooooooooool04_ooool00ol00?oooooooooo
o`0]ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool05?ooool00ooo003ooooooooo
o`0Zooooo`03ool00?oooooooooo00Cooooo00?o003oooooooooool03Oooool01OnP8?3ooooooooo
oooooooo003o00[ooooo00?oX23`ooooooooool06Oooool002;ooooo0_l00016ooooo`03oj0Pl?oo
oooooooo00_ooooo00?oX23`ooooooooool04oooool00ol00?ooooooooooo`0Cooooo`03o`00oooo
oooooooo02cooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`0Cooooo`03ool00?oo
oooooooo02cooooo00?oo`00ooooooooool00_ooool00ol00?ooooooooooo`0>ooooo`03oj0Pl?oo
oooooooo00;ooooo00?o003oooooooooool01oooool00onP8?3oooooooooo`0Iooooo`008_ooool0
0ol0003oooooooooo`14ooooo`03oj0Pl?oooooooooo00cooooo00?oX23`ooooooooool04_ooool0
0ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo02_ooooo00?oX23`ooooooooool03_ooool0
0onP8?3oooooooooo`0Aooooo`03ool00?oooooooooo02kooooo00Coo`00oooooooooooo003o4?oo
ool00onP8?3oooooooooo`03ooooo`03o`00oooooooooooo00Oooooo00?oX23`ooooooooool06Ooo
ool002;ooooo00?o0000ooooooooool0A?ooool00onP8?3oooooooooo`0=ooooo`03oj0Pl?oooooo
oooo017ooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Zooooo`03oj0Pl?oooooo
oooo00kooooo00?oX23`ooooooooool04?ooool00ooo003oooooooooo`0`ooooo`03ool00?oooooo
003o013ooooo00?oX23`ooooooooool01?ooool00ol00?ooooooooooo`07ooooo`03oj0Pl?oooooo
oooo01Sooooo000Rooooo`03o`000?oooooooooo04?ooooo00?oX23`ooooooooool03_ooool00onP
8?3oooooooooo`0@ooooo`03o`00oooooooooooo01Kooooo00?o003oooooooooool0:_ooool00onP
8?3oooooooooo`0>ooooo`03oj0Pl?oooooooooo00oooooo00?oo`00ooooooooool0<_ooool00ol0
0?ooooooooooo`0?ooooo`03oj0Pl?oooooooooo00Gooooo00?o003oooooooooool01_ooool00onP
8?3oooooooooo`0Hooooo`008_ooool00ol0003oooooooooo`13ooooo`03oj0Pl?oooooooooo00ko
oooo00?oX23`ooooooooool04?ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo02So
oooo00?oX23`ooooooooool04?ooool00onP8?3oooooooooo`0>ooooo`03ool00?oooooooooo03;o
oooo00?o003oooooooooool03_ooool00onP8?3oooooooooo`06ooooo`03o`00oooooooooooo00Ko
oooo00?oX23`ooooooooool06?ooool002;ooooo00?o0000ooooooooool0@_ooool00onP8?3ooooo
ooooo`0@ooooo`03oj0Pl?oooooooooo00kooooo00?o003oooooooooool06?ooool00ol00?oooooo
ooooo`0Xooooo`03oj0Pl?oooooooooo013ooooo00?oX23`ooooooooool03Oooool00ooo003ooooo
ooooo`0booooo`03o`00ooooooooo`0000oooooo00?oX23`ooooooooool01oooool00ol00?oooooo
ooooo`06ooooo`03oj0Pl?oooooooooo01Oooooo000Rooooo`03o`000?oooooooooo04;ooooo00?o
X23`ooooooooool04?ooool00onP8?3oooooooooo`0>ooooo`03o`00oooooooooooo01Wooooo00?o
003oooooooooool09oooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo00cooooo00?o
o`00ooooooooool0<oooool01?l00?oooooooooooooo000=ooooo`03oj0Pl?oooooooooo00Wooooo
00?o003oooooooooool01Oooool00onP8?3oooooooooo`0Gooooo`008_ooool00ol0003ooooooooo
o`12ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool03?ooool00ol00?oooooooooo
o`0Jooooo`03o`00oooooooooooo02Kooooo00?oX23`ooooooooool04Oooool00onP8?3ooooooooo
o`0;ooooo`03ool00?oooooooooo03?ooooo00?o003oooooooooool00_ooool00ooo003ooooooooo
o`0:ooooo`03oj0Pl?oooooooooo00Wooooo00?o003oooooooooool01Oooool00onP8?3ooooooooo
o`0Gooooo`008_ooool00ol0003oooooooooo`11ooooo`03oj0Pl?oooooooooo01;ooooo00?oX23`
ooooooooool02oooool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02Gooooo00?oX23`
ooooooooool04Oooool00onP8?3oooooooooo`0:ooooo`03ool00?oooooooooo03Cooooo00?o003o
ooooooooool00oooool00ooo003oooooooooo`09ooooo`03oj0Pl?oooooooooo00[ooooo00?o003o
ooooooooool01?ooool00onP8?3oooooooooo`0Gooooo`008_ooool2o`0004;ooooo00?oX23`oooo
ooooool04_ooool00onP8?3oooooooooo`0;ooooo`03o`00oooooooooooo01cooooo00?o003ooooo
ooooool09Oooool00onP8?3oooooooooo`0Booooo`03oj0Pl?oooooooooo00Sooooo00?oo`00oooo
ooooool0=?ooool00ol00?ooooooooooo`04ooooo`03ool00?oooooooooo00Sooooo00?oX23`oooo
ooooool02oooool00ol00?ooooooooooo`05ooooo`03oj0Pl?oooooooooo01Kooooo000Rooooo`03
o`000?oooooooooo047ooooo00?oX23`ooooooooool04oooool00onP8?3oooooooooo`09ooooo`03
o`00oooooooooooo01gooooo00?o003oooooooooool09Oooool00onP8?3oooooooooo`0Booooo`03
oj0Pl?oooooooooo00Oooooo00?oo`00ooooooooool0=Oooool00ol00?ooooooooooo`05ooooo`03
ool00?oooooooooo00Oooooo00?oX23`ooooooooool02oooool00ol00?ooooooooooo`05ooooo`03
oj0Pl?oooooooooo01Kooooo000Rooooo`03o`000?oooooooooo047ooooo00?oX23`ooooooooool0
4oooool00onP8?3oooooooooo`09ooooo`03o`00oooooooooooo01kooooo00?o003oooooooooool0
8oooool00onP8?3oooooooooo`0Cooooo`03oj0Pl?oooooooooo00Kooooo00?oo`00ooooooooool0
=Oooool00ol00?ooooooooooo`07ooooo`03ool00?oooooooooo00Kooooo00?oX23`ooooooooool0
3?ooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oooooooooo01Kooooo000Rooooo`03o`000?oo
oooooooo043ooooo00?oX23`ooooooooool05?ooool00onP8?3oooooooooo`08ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool08oooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oo
oooooooo00Gooooo00?oo`00ooooooooool0=Oooool00ol00?ooooooooooo`08ooooo`03ool00?oo
oooooooo00Cooooo00?oX23`ooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03oj0Pl?oo
oooooooo01Gooooo000Rooooo`03o`000?oooooooooo043ooooo00?oX23`ooooooooool05Oooool0
0onP8?3oooooooooo`07ooooo`03o`00oooooooooooo023ooooo00?o003oooooooooool08_ooool0
0onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo00Cooooo00?oo`00ooooooooool0=_ooool0
0ol00?ooooooooooo`09ooooo`03ool00?oooooooooo00?ooooo00?oX23`ooooooooool03Oooool0
0ol00?ooooooooooo`05ooooo`03oj0Pl?oooooooooo01Gooooo000Rooooo`03o`000?oooooooooo
043ooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`06ooooo`03o`00oooooooooooo
027ooooo00?o003oooooooooool08_ooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo
00?ooooo00?oo`00ooooooooool0=_ooool00ol00?ooooooooooo`0:ooooo`03ool00?oooooooooo
00?ooooo00?oX23`ooooooooool03_ooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oooooooooo
01Gooooo000Rooooo`03o`000?oooooooooo043ooooo00?oX23`ooooooooool05Oooool00onP8?3o
ooooooooo`06ooooo`03o`00oooooooooooo02;ooooo00?o003oooooooooool08?ooool00onP8?3o
ooooooooo`0Fooooo`05oj0Pl?oooooooooooooooooo0000>Oooool00ol00?ooooooooooo`0;oooo
o`03ool00?oooooooooo00;ooooo00?oX23`ooooooooool03_ooool00ol00?ooooooooooo`05oooo
o`03oj0Pl?oooooooooo01Cooooo000Rooooo`03o`000?oooooooooo043ooooo00?oX23`oooooooo
ool05_ooool00onP8?3oooooooooo`05ooooo`03o`00oooooooooooo02;ooooo00?o003ooooooooo
ool08?ooool00onP8?3oooooooooo`0Fooooo`04oj0Pl?ooooooooooool003Wooooo00?o003ooooo
ooooool03Oooool01?oo003ooooooooooonP8?0Aooooo`03o`00oooooooooooo00Gooooo00?oX23`
ooooooooool05?ooool002;ooooo00?o0000ooooooooool0?oooool00onP8?3oooooooooo`0Goooo
o`03oj0Pl?oooooooooo00Cooooo00?o003oooooooooool08oooool00ol00?ooooooooooo`0Poooo
o`03oj0Pl?oooooooooo01Kooooo00?oX23`oooooooo0000>_ooool00ol00?ooooooooooo`0>oooo
o`03ool00?ooooooX23`01;ooooo00?o003oooooooooool01?ooool00onP8?3oooooooooo`0Doooo
o`008_ooool00ol0003oooooooooo`0oooooo`03oj0Pl?oooooooooo01Oooooo00?oX23`oooooooo
ool01?ooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo01oooooo00?oX23`oooooooo
ool05oooool00onP8?3oooooooooo`0hooooo`03o`00oooooooooooo013ooooo00?oo`00oj0Pl?oo
ool04Oooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oooooooooo01Cooooo000Rooooo`;o0000
@?ooool00onP8?3oooooooooo`0Gooooo`03oj0Pl?oooooooooo00?ooooo00?o003oooooooooool0
9Oooool00ol00?ooooooooooo`0Nooooo`03oj0Pl?oooooooooo01Oooooo00?oo`00oj0Pl?ooool0
>Oooool00ol00?ooooooooooo`0@ooooo`03ool00?nP8?3ooooo017ooooo00?o003oooooooooool0
1Oooool00onP8?3oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0oooooo`03oj0Pl?oo
oooooooo01Sooooo00?oX23`ooooooooool00_ooool00ol00?ooooooooooo`0Vooooo`03o`00oooo
oooooooo01gooooo00?oX23`ooooooooool05oooool00ooo003oX23`ooooo`0iooooo`03o`00oooo
oooooooo013ooooo00?oX23`ool00?ooool04_ooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oo
oooooooo01?ooooo000Rooooo`03o`000?oooooooooo03kooooo00?oX23`ooooooooool06Oooool0
0onP8?3oooooooooo`02ooooo`03o`00oooooooooooo02Kooooo00?o003oooooooooool07Oooool0
0onP8?3oooooooooo`0Fooooo`03ool00?ooooooX23`03Wooooo00?o003oooooooooool04Oooool0
0onP8?3oooooool0000Booooo`03o`00oooooooooooo00Cooooo00?oX23`ooooooooool04oooool0
02;ooooo00?o0000ooooooooool0?_ooool00onP8?3oooooooooo`0Iooooo`05oj0Pl?oooooooooo
ooooool00?l0:Oooool00ol00?ooooooooooo`0Mooooo`03oj0Pl?oooooooooo01Gooooo00Coo`00
ooooooooooooX23`>Oooool00ol00?ooooooooooo`0Aooooo`03oj0Pl?ooooooo`0001;ooooo00?o
003oooooooooool01?ooool00onP8?3oooooooooo`0Cooooo`008_ooool00ol0003oooooooooo`0n
ooooo`03oj0Pl?oooooooooo01Wooooo00GoX23`ooooooooooooooooo`00o`0Zooooo`03o`00oooo
oooooooo01_ooooo00?oX23`ooooooooool05_ooool01Ooo003oooooooooooooooooX23`03Oooooo
00?o003oooooooooool04_ooool01?nP8?3ooooooooooooo000Booooo`03o`00oooooooooooo00?o
oooo00?oX23`ooooooooool04oooool002;ooooo00?o0000ooooooooool0?_ooool00onP8?3ooooo
ooooo`0Iooooo`05oj0Pl?ooooooooooooooool00?l0:_ooool00ol00?ooooooooooo`0Kooooo`03
oj0Pl?oooooooooo01Gooooo00?oo`00ooooooooool00_ooool00onP8?3oooooooooo`0eooooo`03
o`00oooooooooooo017ooooo00?oX23`ooooooooool00_ooool00ooo003oooooooooo`0?ooooo`03
o`00oooooooooooo00Cooooo00?oX23`ooooooooool04_ooool002;ooooo00?o0000ooooooooool0
?Oooool00onP8?3oooooooooo`0Kooooo`03oj0Pl?oooooo003o02_ooooo00?o003oooooooooool0
6oooool00onP8?3oooooooooo`0Eooooo`03ool00?oooooooooo00;ooooo00?oX23`ooooooooool0
=Oooool00ol00?ooooooooooo`0Aooooo`03oj0Pl?oooooooooo00;ooooo00?oo`00ooooooooool0
3oooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oooooooooo01;ooooo000Rooooo`03o`000?oo
oooooooo03gooooo00?oX23`ooooooooool06oooool00onP8?3oooooo`00o`0/ooooo`03o`00oooo
oooooooo01[ooooo00?oX23`ooooooooool05?ooool00ooo003oooooooooo`03ooooo`03oj0Pl?oo
oooooooo03Cooooo00?o003oooooooooool04_ooool00onP8?3oooooooooo`03ooooo`03ool00?oo
oooooooo00oooooo00?o003oooooooooool00oooool00onP8?3oooooooooo`0Booooo`008_ooool0
0ol0003oooooooooo`0mooooo`03oj0Pl?oooooooooo01_ooooo00?oX23`ooooool00?l0;?ooool0
0ol00?ooooooooooo`0Jooooo`03oj0Pl?oooooooooo01?ooooo00?oo`00ooooooooool01?ooool0
0onP8?3oooooooooo`0dooooo`03o`00oooooooooooo01;ooooo00?oX23`ooooooooool01?ooool0
0ooo003oooooooooo`0>ooooo`03o`00oooooooooooo00?ooooo00?oX23`ooooooooool04_ooool0
02;ooooo00?o0000ooooooooool0?Oooool00onP8?3oooooooooo`0Kooooo`03oj0Pl?oooooo003o
02cooooo00?o003oooooooooool06Oooool00onP8?3oooooooooo`0Dooooo`03ool00?oooooooooo
00Gooooo00?oX23`ooooooooool0<oooool00ol00?ooooooooooo`0Booooo`03oj0Pl?oooooooooo
00Cooooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03oj0Pl?oooooooooo
01;ooooo000Rooooo`;o0000?Oooool00onP8?3oooooooooo`0Looooo`03oj0Pl?l00?oooooo02go
oooo00?o003oooooooooool06?ooool00onP8?3oooooooooo`0Cooooo`03ool00?oooooooooo00Ko
oooo00?oX23`ooooooooool0<_ooool00ol00?ooooooooooo`0Booooo`03oj0Pl?oooooooooo00Ko
oooo00?oo`00ooooooooool03_ooool00ol00?ooooooooooo`03ooooo`03oj0Pl?oooooooooo017o
oooo000Rooooo`03o`000?oooooooooo03cooooo00?oX23`ooooooooool07Oooool00onP8?3ooooo
ooooo`0/ooooo`03o`00oooooooooooo01Sooooo00?oX23`ooooooooool04oooool00ooo003ooooo
ooooo`06ooooo`03oj0Pl?oooooooooo03;ooooo00?o003oooooooooool04_ooool00onP8?3ooooo
ooooo`07ooooo`03ool00?oooooooooo00gooooo00?o003oooooooooool00oooool00onP8?3ooooo
ooooo`0Aooooo`008_ooool00ol0003oooooooooo`0looooo`03oj0Pl?oooooooooo01gooooo00?o
X23`ooooooooool0;?ooool00ol00?ooooooooooo`0Hooooo`03oj0Pl?oooooooooo01;ooooo00?o
o`00ooooooooool01oooool00onP8?3oooooooooo`0booooo`03o`00oooooooooooo01;ooooo00?o
X23`ooooooooool01oooool00ooo003oooooooooo`0=ooooo`03o`00oooooooooooo00?ooooo00?o
X23`ooooooooool04Oooool002;ooooo00?o0000ooooooooool0??ooool00onP8?3oooooooooo`0L
ooooo`03o`00oonP8?3ooooo02kooooo00?o003oooooooooool05oooool00onP8?3oooooooooo`0A
ooooo`03ool00?oooooooooo00Sooooo00?oX23`ooooooooool0<Oooool00ol00?ooooooooooo`0C
ooooo`03oj0Pl?oooooooooo00Sooooo00?oo`00ooooooooool03Oooool00ol00?ooooooooooo`02
ooooo`03oj0Pl?oooooooooo017ooooo000Rooooo`03o`000?oooooooooo03_ooooo00?oX23`oooo
ooooool07Oooool00ol00?ooX23`ooooo`0^ooooo`03o`00oooooooooooo01Kooooo00?oX23`oooo
ooooool04_ooool00ooo003oooooooooo`08ooooo`03oj0Pl?oooooooooo037ooooo00?o003ooooo
ooooool04oooool00onP8?3oooooooooo`09ooooo`03ool00?oooooooooo00cooooo00?o003ooooo
ooooool00_ooool00onP8?3oooooooooo`0Aooooo`008_ooool00ol0003oooooooooo`0kooooo`03
oj0Pl?oooooooooo01gooooo00?o003ooj0Pl?ooool0;_ooool00ol00?ooooooooooo`0Fooooo`03
oj0Pl?oooooooooo017ooooo00?oo`00ooooooooool02_ooool00onP8?3oooooooooo`0`ooooo`03
o`00oooooooooooo01;ooooo00?oX23`ooooooooool02_ooool00ooo003oooooooooo`0<ooooo`03
o`00oooooooooooo00?ooooo00?oX23`ooooooooool04?ooool002;ooooo00?o0000ooooooooool0
>oooool00onP8?3oooooooooo`0Mooooo`03o`00oonP8?3ooooo02oooooo00?o003oooooooooool0
5Oooool00onP8?3oooooooooo`0Aooooo`03ool00?oooooooooo00[ooooo00?oX23`ooooooooool0
;oooool00ol00?ooooooooooo`0Cooooo`03oj0Pl?oooooooooo00_ooooo00?oo`00ooooooooool0
3?ooool00ol00?ooooooooooo`02ooooo`03oj0Pl?oooooooooo013ooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo03_ooooo00?oX23`ooooooooool07?ooool01?l00?oooooooooooonP8?0_oooo
o`03o`00oooooooooooo01Gooooo00?oX23`ooooooooool04?ooool00ooo003oooooooooo`0;oooo
o`03oj0Pl?oooooooooo02oooooo00?o003oooooooooool04oooool00onP8?3oooooooooo`0<oooo
o`03ool00?oooooooooo00_ooooo00?o003oooooooooool00_ooool00onP8?3oooooooooo`0@oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0>oooool00onP8?3oooooooooo`0Looooo`04o`00oooooooooooo
oj0Pl2oooooo00?o003oooooooooool05Oooool00onP8?3oooooooooo`0?ooooo`03ool00?oooooo
oooo00cooooo00?oX23`ooooooooool0;oooool00ol00?ooooooooooo`0Cooooo`03oj0Pl?oooooo
oooo00cooooo00?oo`00ooooooooool02oooool00ol00?ooooooooooo`02ooooo`03oj0Pl?oooooo
oooo013ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0>_ooool00onP8?3oooooooooo`0Mooooo`04o`00oooooooo
oooooj0Pl33ooooo00?o003oooooooooool04oooool00onP8?3oooooooooo`0@ooooo`03ool00?oo
oooooooo00cooooo00?oX23`ooooooooool0;oooool00ol00?ooooooooooo`0Cooooo`03oj0Pl?oo
oooooooo00gooooo00?oo`00ooooooooool02oooool01Ol00?ooooooooooooooooooX23`01;ooooo
0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`?o0000
>_ooool00onP8?3oooooooooo`0Looooo`05o`00oooooooooooooooooonP8?00<?ooool00ol00?oo
ooooooooo`0Cooooo`03oj0Pl?oooooooooo00oooooo00?oo`00ooooooooool03_ooool00onP8?3o
ooooooooo`0]ooooo`03o`00oooooooooooo01?ooooo00?oX23`ooooooooool03oooool00ooo003o
ooooooooo`0:ooooo`03o`00oooooooooooo00;ooooo00?oX23`ooooooooool03oooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0
003oooooooooo`0jooooo`03oj0Pl?oooooooooo01cooooo00Go003ooooooooooooooooooj0Pl00`
ooooo`03o`00oooooooooooo01?ooooo00?oX23`ooooooooool03oooool00ooo003oooooooooo`0>
ooooo`03oj0Pl?oooooooooo02gooooo00?o003oooooooooool04oooool00onP8?3oooooooooo`0?
ooooo`03ool00?oooooooooo00[ooooo00?o003oooooooooool00_ooool00onP8?3oooooooooo`0?
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0jooooo`03oj0Pl?oooooooooo01cooooo00?o003oooooooooool00_ooool0
0onP8?3oooooooooo`0]ooooo`03o`00oooooooooooo01?ooooo00?oX23`ooooooooool03_ooool0
0ooo003oooooooooo`0?ooooo`03oj0Pl?oooooooooo02gooooo00?o003oooooooooool04oooool0
0onP8?3oooooooooo`0@ooooo`03ool00?oooooooooo00[ooooo00Go003ooooooooooooooooooj0P
l00Aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0jooooo`03oj0Pl?oooooooooo01cooooo00?o003oooooooooool00_oo
ool00onP8?3oooooooooo`0^ooooo`03o`00oooooooooooo01;ooooo00?oX23`ooooooooool03Ooo
ool00ooo003oooooooooo`0@ooooo`03oj0Pl?oooooooooo02cooooo00?o003oooooooooool05?oo
ool00onP8?3oooooooooo`0@ooooo`03ool00?oooooooooo00[ooooo00Go003ooooooooooooooooo
oj0Pl00Aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006ooooo`03o`00
0?oooooooooo03[ooooo00?oX23`ooooooooool06oooool00ol00?ooooooooooo`03ooooo`03oj0P
l?oooooooooo02kooooo00?o003oooooooooool04Oooool00onP8?3oooooooooo`0>ooooo`03ool0
0?oooooooooo013ooooo00?oX23`ooooooooool0;?ooool00ol00?ooooooooooo`0Dooooo`03oj0P
l?oooooooooo017ooooo00?oo`00ooooooooool02Oooool01Ol00?ooooooooooooooooooX23`017o
oooo000Rooooo`03o`000?oooooooooo03Wooooo00?oX23`ooooooooool07?ooool00ol00?oooooo
ooooo`03ooooo`03oj0Pl?oooooooooo02kooooo00?o003oooooooooool04Oooool00onP8?3ooooo
ooooo`0=ooooo`03ool00?oooooooooo017ooooo00?oX23`ooooooooool0;?ooool00ol00?oooooo
ooooo`0Cooooo`03oj0Pl?oooooooooo01?ooooo00?oo`00ooooooooool02?ooool00ol00?oooooo
ooooo`02ooooo`03oj0Pl?oooooooooo00kooooo000Rooooo`03o`000?oooooooooo03Wooooo00?o
X23`ooooooooool07?ooool00ol00?ooooooooooo`03ooooo`03oj0Pl?oooooooooo02kooooo00?o
003oooooooooool04Oooool00onP8?3oooooooooo`0=ooooo`03ool00?oooooooooo01;ooooo00?o
X23`ooooooooool0:_ooool00ol00?ooooooooooo`0Dooooo`03oj0Pl?oooooooooo01?ooooo00?o
o`00ooooooooool02Oooool01Ol00?ooooooooooooooooooX23`013ooooo000Rooooo`03o`000?oo
oooooooo03Wooooo00?oX23`ooooooooool06oooool00ol00?ooooooooooo`05ooooo`03oj0Pl?oo
oooooooo02kooooo00?o003oooooooooool04?ooool00onP8?3oooooooooo`0<ooooo`03ool00?oo
oooooooo01?ooooo00?oX23`ooooooooool0:_ooool00ol00?ooooooooooo`0Dooooo`03oj0Pl?oo
oooooooo01Cooooo00?oo`00ooooooooool02?ooool01Ol00?ooooooooooooooooooX23`013ooooo
000Rooooo`03o`000?oooooooooo03Wooooo00?oX23`ooooooooool06oooool00ol00?oooooooooo
o`05ooooo`03oj0Pl?oooooooooo02kooooo00?o003oooooooooool04?ooool00onP8?3ooooooooo
o`0;ooooo`03ool00?oooooooooo01Cooooo00?oX23`ooooooooool0:_ooool00ol00?oooooooooo
o`0Dooooo`03oj0Pl?oooooooooo01Cooooo00?oo`00ooooooooool02?ooool01Ol00?oooooooooo
ooooooooX23`013ooooo000Rooooo`03o`000?oooooooooo03Wooooo00?oX23`ooooooooool06ooo
ool00ol00?ooooooooooo`05ooooo`03oj0Pl?oooooooooo02kooooo00?o003oooooooooool03ooo
ool00onP8?3oooooooooo`0<ooooo`03ool00?oooooooooo01Cooooo00?oX23`ooooooooool0:_oo
ool00ol00?ooooooooooo`0Dooooo`03oj0Pl?oooooooooo01Gooooo00?oo`00ooooooooool02?oo
ool01?l00?oooooooooooonP8?0@ooooo`008_ooool2o`0003[ooooo00?oX23`ooooooooool06ooo
ool00ol00?ooooooooooo`05ooooo`03oj0Pl?oooooooooo02oooooo00?o003oooooooooool03_oo
ool00onP8?3oooooooooo`0;ooooo`03ool00?oooooooooo01Gooooo00?oX23`ooooooooool0:Ooo
ool00ol00?ooooooooooo`0Eooooo`03oj0Pl?oooooooooo01Gooooo00?oo`00ooooooooool02?oo
ool01?l00?oooooooooooonP8?0@ooooo`008_ooool00ol0003oooooooooo`0hooooo`03oj0Pl?oo
oooooooo01_ooooo00?o003oooooooooool01_ooool00onP8?3oooooooooo`0_ooooo`03o`00oooo
oooooooo00kooooo00?oX23`ooooooooool02oooool00ooo003oooooooooo`0Fooooo`03oj0Pl?oo
oooooooo02Sooooo00?o003oooooooooool05?ooool00onP8?3oooooooooo`0Gooooo`03ool00?oo
oooooooo00Oooooo00Go003ooooooooooooooooooj0Pl00?ooooo`008_ooool00ol0003ooooooooo
o`0hooooo`03oj0Pl?oooooooooo01_ooooo00?o003oooooooooool01_ooool00onP8?3ooooooooo
o`0_ooooo`03o`00oooooooooooo00kooooo00?oX23`ooooooooool02_ooool00ooo003ooooooooo
o`0Gooooo`03oj0Pl?oooooooooo02Sooooo00?o003oooooooooool05?ooool00onP8?3ooooooooo
o`0Hooooo`03ool00?oooooooooo00Kooooo00Go003ooooooooooooooooooj0Pl00?ooooo`008_oo
ool00ol0003oooooooooo`0hooooo`03oj0Pl?oooooooooo01_ooooo00?o003oooooooooool01ooo
ool00onP8?3oooooooooo`0^ooooo`03o`00oooooooooooo00kooooo00?oX23`ooooooooool02Ooo
ool00ooo003oooooooooo`0Hooooo`03oj0Pl?oooooooooo02Sooooo00?o003oooooooooool05?oo
ool00onP8?3oooooooooo`0Hooooo`03ool00?oooooooooo00Oooooo00Co003oooooooooooooX23`
3oooool002;ooooo00?o0000ooooooooool0>?ooool00onP8?3oooooooooo`0Kooooo`03o`00oooo
oooooooo00Oooooo00?oX23`ooooooooool0;oooool00ol00?ooooooooooo`0<ooooo`03oj0Pl?oo
oooooooo00[ooooo00?oo`00ooooooooool06?ooool00onP8?3oooooooooo`0Wooooo`03o`00oooo
oooooooo01Gooooo00?oX23`ooooooooool06Oooool00ooo003oooooooooo`06ooooo`04o`00oooo
oooooooooj0Pl0oooooo000Rooooo`03o`000?oooooooooo03Sooooo00?oX23`ooooooooool06_oo
ool00ol00?ooooooooooo`08ooooo`03oj0Pl?oooooooooo02oooooo00?o003oooooooooool03?oo
ool00onP8?3oooooooooo`09ooooo`03ool00?oooooooooo01Wooooo00?oX23`ooooooooool09ooo
ool00ol00?ooooooooooo`0Eooooo`03oj0Pl?oooooooooo01Wooooo00?oo`00ooooooooool01_oo
ool01?l00?oooooooooooonP8?0?ooooo`008_ooool00ol0003oooooooooo`0hooooo`03oj0Pl?oo
oooooooo01[ooooo00?o003oooooooooool02?ooool00onP8?3oooooooooo`0_ooooo`03o`00oooo
oooooooo00cooooo00?oX23`ooooooooool02Oooool00ooo003oooooooooo`0Iooooo`03oj0Pl?oo
oooooooo02Oooooo00?o003oooooooooool05?ooool00onP8?3oooooooooo`0Kooooo`03ool00?oo
oooooooo00Gooooo00Go003ooooooooooooooooooj0Pl00>ooooo`008_ooool00ol0003ooooooooo
o`0gooooo`03oj0Pl?oooooooooo01_ooooo00?o003oooooooooool02?ooool00onP8?3ooooooooo
o`0_ooooo`03o`00oooooooooooo00cooooo00?oX23`ooooooooool02?ooool00ooo003ooooooooo
o`0Kooooo`03oj0Pl?oooooooooo02Kooooo00?o003oooooooooool05?ooool00onP8?3ooooooooo
o`0Kooooo`03ool00?oooooooooo00Kooooo00Co003oooooooooooooX23`3_ooool002;ooooo00?o
0000ooooooooool0=oooool00onP8?3oooooooooo`0Jooooo`03o`00oooooooooooo00[ooooo00?o
X23`ooooooooool0;oooool00ol00?ooooooooooo`0;ooooo`03oj0Pl?oooooooooo00Oooooo00?o
o`00ooooooooool07?ooool00onP8?3oooooooooo`0Uooooo`03o`00oooooooooooo01Gooooo00?o
X23`ooooooooool07?ooool00ooo003oooooooooo`05ooooo`04o`00oooooooooooooj0Pl0kooooo
000Rooooo`;o0000>?ooool00onP8?3oooooooooo`0Jooooo`03o`00oooooooooooo00[ooooo00?o
X23`ooooooooool0;oooool00ol00?ooooooooooo`0:ooooo`03oj0Pl?oooooooooo00Sooooo00?o
o`00ooooooooool07?ooool00onP8?3oooooooooo`0Uooooo`03o`00oooooooooooo01Gooooo00?o
X23`ooooooooool07?ooool00ooo003oooooooooo`05ooooo`04o`00oooooooooooooj0Pl0kooooo
000Rooooo`03o`000?oooooooooo03Oooooo00?oX23`ooooooooool06_ooool00ol00?oooooooooo
o`0:ooooo`03oj0Pl?oooooooooo02oooooo00?o003oooooooooool02_ooool00onP8?3ooooooooo
o`07ooooo`03ool00?oooooooooo01gooooo00?oX23`ooooooooool09Oooool00ol00?oooooooooo
o`0Eooooo`03oj0Pl?oooooooooo01gooooo00?oo`00ooooooooool01Oooool00ol00?oooooooj0P
l00>ooooo`008_ooool00ol0003oooooooooo`0gooooo`03oj0Pl?oooooooooo01[ooooo00?o003o
ooooooooool02_ooool00onP8?3oooooooooo`0_ooooo`03o`00oooooooooooo00[ooooo00?oX23`
ooooooooool01oooool00ooo003oooooooooo`0Mooooo`03oj0Pl?oooooooooo02Gooooo00?o003o
ooooooooool05Oooool00onP8?3oooooooooo`0Nooooo`03ool00?oooooooooo00Cooooo00?o003o
oooooonP8?003_ooool002;ooooo00?o0000ooooooooool0=_ooool00onP8?3oooooooooo`0Joooo
o`03o`00oooooooooooo00_ooooo00?oX23`ooooooooool0<?ooool00ol00?ooooooooooo`09oooo
o`03oj0Pl?oooooooooo00Kooooo00?oo`00ooooooooool07oooool00onP8?3oooooooooo`0Soooo
o`03o`00oooooooooooo01Gooooo00?oX23`ooooooooool07oooool00ooo003oooooooooo`04oooo
o`04o`00oooooooooooooj0Pl0gooooo000Rooooo`03o`000?oooooooooo03Kooooo00?oX23`oooo
ooooool06_ooool00ol00?ooooooooooo`0;ooooo`03oj0Pl?oooooooooo033ooooo00?o003ooooo
ooooool02Oooool00onP8?3oooooooooo`05ooooo`03ool00?oooooooooo023ooooo00?oX23`oooo
ooooool08oooool00ol00?ooooooooooo`0Eooooo`03oj0Pl?oooooooooo023ooooo00?oo`00oooo
ooooool00oooool01?l00?oooooooooooonP8?0=ooooo`008_ooool00ol0003oooooooooo`0foooo
o`03oj0Pl?oooooooooo01[ooooo00?o003oooooooooool03?ooool00onP8?3oooooooooo`0_oooo
o`03o`00oooooooooooo00Sooooo00?oX23`ooooooooool01_ooool00ooo003oooooooooo`0Poooo
o`03oj0Pl?oooooooooo02?ooooo00?o003oooooooooool05Oooool00onP8?3oooooooooo`0Poooo
o`03ool00?oooooooooo00Cooooo00?o003ooooooonP8?003Oooool002;ooooo00?o0000oooooooo
ool0=_ooool00onP8?3oooooooooo`0Iooooo`03o`00oooooooooooo00gooooo00?oX23`oooooooo
ool0<?ooool00ol00?ooooooooooo`07ooooo`03oj0Pl?oooooooooo00Gooooo00?oo`00oooooooo
ool08Oooool00onP8?3oooooooooo`0Sooooo`03o`00oooooooooooo01Gooooo00?oX23`oooooooo
ool08Oooool00ooo003oooooooooo`03ooooo`03o`00ooooooooX23`00gooooo000Rooooo`03o`00
0?oooooooooo03Kooooo00?oX23`ooooooooool06Oooool00ol00?ooooooooooo`0=ooooo`03oj0P
l?oooooooooo033ooooo00?o003oooooooooool01oooool00onP8?3oooooooooo`05ooooo`03ool0
0?oooooooooo027ooooo00?oX23`ooooooooool08_ooool00ol00?ooooooooooo`0Fooooo`03oj0P
l?oooooooooo027ooooo00?oo`00ooooooooool00oooool00ol00?oooooooj0Pl00=ooooo`008_oo
ool00ol0003oooooooooo`0eooooo`03oj0Pl?oooooooooo01[ooooo00?o003oooooooooool03Ooo
ool00onP8?3oooooooooo`0`ooooo`03o`00oooooooooooo00Oooooo00?oX23`ooooooooool01?oo
ool00ooo003oooooooooo`0Rooooo`03oj0Pl?oooooooooo02;ooooo00?o003oooooooooool05Ooo
ool00onP8?3oooooooooo`0Sooooo`03ool00?oooooooooo00?ooooo00?o003ooooooonP8?003?oo
ool002;ooooo00?o0000ooooooooool0=Oooool00onP8?3oooooooooo`0Jooooo`03o`00oooooooo
oooo00gooooo00?oX23`ooooooooool0<?ooool00ol00?ooooooooooo`07ooooo`03oj0Pl?oooooo
oooo00Cooooo00?oo`00ooooooooool08oooool00onP8?3oooooooooo`0Qooooo`03o`00oooooooo
oooo01Gooooo00?oX23`ooooooooool08oooool00ooo003oooooooooo`03ooooo`03o`00oooooooo
X23`00cooooo000Rooooo`;o0000=_ooool00onP8?3oooooooooo`0Iooooo`03o`00oooooooooooo
00oooooo00?oX23`ooooooooool0<?ooool00ol00?ooooooooooo`05ooooo`03oj0Pl?oooooooooo
00Cooooo00?oo`00ooooooooool09?ooool00onP8?3oooooooooo`0Qooooo`03o`00oooooooooooo
01Gooooo00?oX23`ooooooooool09?ooool00ooo003oooooooooo`02ooooo`03o`00ooooooooX23`
00cooooo000Rooooo`03o`000?oooooooooo03Gooooo00?oX23`ooooooooool06Oooool00ol00?oo
ooooooooo`0?ooooo`03oj0Pl?oooooooooo033ooooo00?o003oooooooooool01Oooool00onP8?3o
ooooooooo`04ooooo`03ool00?oooooooooo02Cooooo00?oX23`ooooooooool08?ooool00ol00?oo
ooooooooo`0Fooooo`03oj0Pl?oooooooooo02Gooooo00Ooo`00ooooooooooooooooo`00oooooooo
X23`00cooooo000Rooooo`03o`000?oooooooooo03Gooooo00?oX23`ooooooooool06Oooool00ol0
0?ooooooooooo`0?ooooo`03oj0Pl?oooooooooo033ooooo00?o003oooooooooool01Oooool00onP
8?3oooooooooo`03ooooo`03ool00?oooooooooo02Gooooo00?oX23`ooooooooool08?ooool00ol0
0?ooooooooooo`0Fooooo`03oj0Pl?oooooooooo02Gooooo00?oo`00ooooooooool00_ooool00ol0
0?ooX23`ooooo`0;ooooo`008_ooool00ol0003oooooooooo`0dooooo`03oj0Pl?oooooooooo01[o
oooo00?o003oooooooooool03oooool00onP8?3oooooooooo`0`ooooo`03o`00oooooooooooo00Go
oooo00?oX23`ooooooooool00oooool00ooo003oooooooooo`0Uooooo`03oj0Pl?oooooooooo023o
oooo00?o003oooooooooool05_ooool00onP8?3oooooooooo`0Vooooo`06ool00?oooooooooooooo
ool00?ooX23`3?ooool002;ooooo00?o0000ooooooooool0=?ooool00onP8?3oooooooooo`0Ioooo
o`03o`00oooooooooooo013ooooo00?oX23`ooooooooool0<Oooool00ol00?ooooooooooo`04oooo
o`03oj0Pl?oooooooooo00;ooooo00?oo`00ooooooooool09oooool00onP8?3oooooooooo`0Ooooo
o`03o`00oooooooooooo01Gooooo00?oX23`ooooooooool09oooool01ooo003ooooooooooooooooo
003ooooooonP8?002oooool002;ooooo00?o0000ooooooooool0=?ooool00onP8?3oooooooooo`0I
ooooo`03o`00oooooooooooo013ooooo00?oX23`ooooooooool0<Oooool00ol00?ooooooooooo`04
ooooo`03oj0Pl?oooooooooo00;ooooo00?oo`00ooooooooool09oooool00onP8?3oooooooooo`0N
ooooo`03o`00oooooooooooo01Kooooo00?oX23`ooooooooool0:?ooool01_oo003ooooooooooooo
oooo003ooj0Pl0_ooooo000Rooooo`03o`000?oooooooooo03Cooooo00?oX23`ooooooooool06Ooo
ool00ol00?ooooooooooo`0Aooooo`03oj0Pl?oooooooooo033ooooo00?o003oooooooooool00ooo
ool00onP8?3oooooooooo`02ooooo`03ool00?oooooooooo02Sooooo00?oX23`ooooooooool07_oo
ool00ol00?ooooooooooo`0Fooooo`03oj0Pl?oooooooooo02Sooooo00Koo`00oooooooooooooooo
o`00oonP8?0;ooooo`008_ooool00ol0003oooooooooo`0aooooo`05onk^k_lb<S;o0000oj0Pl?o^
k^h01Oooool2ob4Q8@Cooooo1Ol00009ooooo`03o`00oooooooooooo01;ooooo00?oX23`oooooooo
ool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool04?ooool00ol00?ooooooooooo`03ooooo`03oj0Pl?oooooooooo00;ooooo00?oo`00oooo
ooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`02?ooool00onP8?3oooooooooo`0Nooooo`06o`00ooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c003ooooo`03oj0Pl?oooooooooo
02Wooooo00Goo`00oooooooooooo003ooj0Pl004o`000003oa0@4?oooooooooo00Cooooo000Roooo
o`03o`000?oooooooooo037ooooo00GoMgMgoiRHV?ooooooX23`ogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Wooooo00?o003oooooooooool04_ooool00onP8?3ooooooooo
o`09ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0
4_ooool00ol00?ooooooooooo`02ooooo`05oj0Pl?oooooooooooooooooo00003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B402?ooool0
0onP8?3oooooooooo`0Nooooo`06o`00oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@03ooooo`03oj0Pl?oooooooooo02Wooooo00Goo`00oooooooo
oooo003ooj0Pl002ooooo`03o`000?oooooooooo00Kooooo000Rooooo`03o`000?oooooooooo037o
oooo00Go410@oooooonP8?3ooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00[ooooo00?o003ooooo
ooooool04_ooool00onP8?3oooooooooo`09ooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0001?ooooo00?o003oooooooooool00_ooool01OnP8?3oooooooooooooooooo`0000kooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000002?ooool00onP8?3o
ooooooooo`0Mooooo`03o`00oooooooo410@00?ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000?ooooo00?oX23`ooooooooool0:_ooool01?oo003ooooooooooonP8?02
ooooo`03o`000?oooooooooo00Kooooo000Rooooo`;o0000<_ooool01Ol0003ooooooj0Pl?oooooo
000000gooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol00?ooooooooooo`0Booooo`03oj0Pl?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0001Cooooo
00?o003oooooooooool00_ooool01OnP8?3oooooooooooooooooo`0000kooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B402Oooool00onP8?3oooooooooo`0L
ooooo`03o`00oooooooo000000?ooooo00?o0000ooooooooool02Oooool01Olb<S;oV9RHoooooonH
V9So<S8b00;ooooo00?oX23`ooooooooool0:oooool01ooo003oooooooooool00?ooX23`ooooool0
00002?ooool002;ooooo00?o0000ooooooooool0<Oooool01Ol0003ooooooj0Pl?oooooo000000ko
oooo00?oMgMgofIVI_ooool01oooool00ol00?ooooooooooo`0Cooooo`03oj0Pl?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001Cooooo00Go003o
oooooooooooooooooj0Pl003ooooo`03ool00?oooooooooo00gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`02Oooool00onP8?3oooooooooo`0Looooo`03
o`00oooooooo000000?ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<
00;ooooo00?oX23`ooooooooool0;?ooool01_oo003oooooo`00oonP8?3oooooo`0000Sooooo000R
ooooo`03o`000?oooooooooo037ooooo00Go410@oooooonP8?3ooooooa0@400?ooooo`03o`000?oo
oooooooo00Kooooo00?o003oooooooooool05?ooool00onP8?3oooooooooo`08ooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Eooooo`04o`00oooooooooooooj0Pl0?o
oooo00?oo`00ooooooooool03Oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7
Qoooool02oooool00onP8?3oooooooooo`0Looooo`03o`00oooooooo410@00?ooooo00?o410@oooo
ooooool02Oooool01Ol@413o^[Zjoooooonj^[[o410@00;ooooo00?oX23`ooooooooool0;?ooool0
1_oo003oooooo`00oonP8?3oooooo`0000Sooooo000Rooooo`03o`000?oooooooooo037ooooo00Go
MgMgoiRHV?nP8?3oV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41002?ooool00ol00?oo
ooooooooo`0Dooooo`03oj0Pl?oooooooooo00Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000001Gooooo00Co003oooooooooooooX23`0_ooool00ooo003oooooooooo`0>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00;ooooo`03oj0Pl?oo
oooooooo01_ooooo00So003oooooooooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj
^_oooooo^[Zjo`000002ooooo`03oj0Pl?oooooooooo02gooooo00Goo`00oooooonP8?3oooooo`00
0008ooooo`008_ooool00ol0003oooooooooo`0aooooo`05onk^k_nP8?3o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Sooooo00?o003oooooooooool05?ooool00onP8?3ooooo
ooooo`08ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`0Dooooo`04
o`00oooooooooooooj0Pl0;ooooo00?oo`00ooooooooool03_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00Coc<c<odA4A?l0003o410@2Oooool00onP8?3oooooooooo`0Kooooo`08o`00oooo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00_ooool0
0onP8?3oooooooooo`0^ooooo`04ool00?nP8?3oIVIVo`0000Sooooo000Rooooo`03o`000?oooooo
oooo03;ooooo00?oX23`ooooooooool06?ooool00ol00?ooooooooooo`0Eooooo`03oj0Pl?oooooo
oooo03;ooooo00Go003ooooooonP8?3oooooool0000`ooooo`03oj0Pl?oooooooooo01[ooooo00?o
003oooooooooool05_ooool00onP8?3oooooooooo`0_ooooo`03ool00?l00?ooX23`00Wooooo000R
ooooo`03o`000?oooooooooo03;ooooo00?oX23`ooooooooool06?ooool00ol00?ooooooooooo`0E
ooooo`03oj0Pl?oooooooooo03;ooooo00Go003ooj0Pl?ooooooooooool0000`ooooo`03oj0Pl?oo
oooooooo01[ooooo00?o003oooooooooool05_ooool00onP8?3oooooooooo`0`ooooo`03ool00?nP
8?3ooooo00Sooooo000Rooooo`03o`000?oooooooooo03;ooooo00?oX23`ooooooooool06?ooool0
0ol00?ooooooooooo`0Fooooo`03oj0Pl?oooooooooo037ooooo00Co003ooj0Pl?ooooooo`00<Ooo
ool00onP8?3oooooooooo`0Iooooo`03o`00oooooooooooo01Oooooo00?oX23`ooooooooool0<?oo
ool00ooo003oX23`ooooo`08ooooo`008_ooool00ol0003oooooooooo`0booooo`03oj0Pl?oooooo
oooo01Oooooo00?o003oooooooooool05oooool00onP8?3oooooooooo`0aooooo`04o`00oonP8?3o
ooooool0037ooooo00?oX23`ooooooooool06Oooool00ol00?ooooooooooo`0Gooooo`03oj0Pl?oo
oooooooo037ooooo00?oX23`ooooooooool01oooool002;ooooo00?o0000ooooooooool0<Oooool0
0onP8?3oooooooooo`0Hooooo`03o`00oooooooooooo01Oooooo00?oX23`ooooooooool0<_ooool0
0onP8?3oo`00ooooo`0aooooo`03oj0Pl?oooooooooo01Wooooo00?o003oooooooooool05oooool0
0onP8?3oooooooooo`0aooooo`03ool00?nP8?3ooooo00Oooooo000Jooooo`So000000?oX23`o`00
0?l00000<Ol000000onP8?3o0000o`00000Ho`000003o`00ool0003o000001Oo000000?oX23`o`00
0?l00000<_l000000onP8?3oo`00o`00000ao`000003oj0Pl?l0003o000001Wo000000?o003oo`00
0?l000005ol000000onP8?3o0000o`00000bo`000003oj0Pl?l0003o000000Ko0000000Rooooo`03
oj0Pl?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03
o`00oooooooooooo00gooooo00?o0000ooooooooool01oooool00onP8?3oooooooooo`03ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
oj0Pl?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00?oX23`ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03
o`00oooooooooooo00gooooo00?o0000ooooooooool01oooool00onP8?3oooooooooo`03ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo000Rooooo`03oj0Pl?oo003ooooo037ooooo00?oX23`ooooooooool0
2?ooool00ol0003oooooooooo`0<ooooo`03o`00oooooooooooo01Sooooo00?oX23`ooooooooool0
4_ooool00ol0003oooooooooo`0Looooo`03oj0Pl?l00?oooooo01kooooo00?o0000ooooooooool0
4_ooool00onP8?3oooooooooo`0Gooooo`03o`00oooooooooooo00gooooo00?o0000ooooooooool0
1oooool00onP8?3oooooooooo`0cooooo`03o`000?oooooooooo00Kooooo000Rooooo`03oj0Pl?l0
0?oooooo037ooooo00?oX23`ooooooooool05oooool00ol00?ooooooooooo`0Iooooo`03oj0Pl?oo
oooooooo033ooooo00?oX23`ooooool00?l0<oooool00onP8?3oooooooooo`0Gooooo`03o`00oooo
oooooooo01Oooooo00?oX23`ooooooooool0??ooool002;ooooo00?o0000oj0Pl?oo0000<Oooool0
0onP8?3oooooooooo`0Gooooo`03o`00oooooooooooo01Wooooo00?oX23`ooooooooool0<?ooool0
0onP8?3oooooo`00o`0cooooo`03oj0Pl?oooooooooo01Oooooo00?o003oooooooooool05oooool0
0onP8?3oooooooooo`0looooo`008_ooool00ol0003oX23`ool0000`ooooo`03oj0Pl?oooooooooo
01Sooooo00?o003oooooooooool06Oooool00onP8?3oooooooooo`0_ooooo`04ool00?nP8?3ooooo
o`00oc?ooooo00?oX23`ooooooooool05_ooool00ol00?ooooooooooo`0Hooooo`03oj0Pl?oooooo
oooo03cooooo000Rooooo`04o`000?nP8?3oooooool002oooooo00?oX23`ooooooooool05oooool0
0ol00?ooooooooooo`0Jooooo`03oj0Pl?oooooooooo02oooooo00Goo`00oj0Pl?ooooooooooo`00
o`0booooo`03oj0Pl?oooooooooo01Kooooo00?o003oooooooooool05oooool00onP8?3ooooooooo
o`0mooooo`008_ooool01?l0003oX23`o`00oooo000_ooooo`03oj0Pl?oooooooooo01Oooooo00?o
003oooooooooool06_ooool00onP8?3oooooooooo`0^ooooo`03ool00?ooooooX23`00;ooooo00?o
003oooooooooool0<Oooool00onP8?3oooooooooo`0Eooooo`03o`00oooooooooooo01Oooooo00?o
X23`ooooooooool0?Oooool002;ooooo00Go0000oj0Pl?l00?ooooooool0000^ooooo`03oj0Pl?oo
oooooooo01Oooooo00?o003oooooooooool06oooool00onP8?3oooooooooo`0]ooooo`03ool00?nP
8?3ooooo00;ooooo00?o003oooooooooool0<Oooool00onP8?3oooooooooo`0Eooooo`03o`00oooo
oooooooo01Oooooo00?oX23`ooooooooool0?Oooool002;ooooo00Go0000oj0Pl?l00?ooooooool0
000^ooooo`03oj0Pl?oooooooooo01Oooooo00?o003oooooooooool06oooool00onP8?3ooooooooo
o`0/ooooo`03ool00?ooooooX23`00?ooooo00?o003oooooooooool0<Oooool00onP8?3ooooooooo
o`0Dooooo`03o`00oooooooooooo01Sooooo00?oX23`ooooooooool0?Oooool002;ooooo0_l00000
1?nP8?3o003ooooooooo000/ooooo`03oj0Pl?oooooooooo01Oooooo00?o003oooooooooool07?oo
ool00onP8?3oooooooooo`0/ooooo`03ool00?ooooooX23`00Cooooo00?o003oooooooooool0<?oo
ool00onP8?3oooooooooo`0Dooooo`03o`00oooooooooooo01Sooooo00?oX23`ooooooooool0?Ooo
ool002;ooooo00Ko0000oooooonP8?3o003ooooooooo000/ooooo`03oj0Pl?oooooooooo01Oooooo
00?o003oooooooooool07?ooool00onP8?3oooooooooo`0[ooooo`04ool00?oooooooooooj0Pl0Co
oooo00?o003oooooooooool0<?ooool00onP8?3oooooooooo`0Dooooo`03o`00oooooooooooo01So
oooo00?oX23`ooooooooool0?Oooool002;ooooo00Co0000oooooonP8?3o003o0_ooool00ooo003o
ooooooooo`0Yooooo`03oj0Pl?oooooooooo01Oooooo00?o003oooooooooool07?ooool00onP8?3o
ooooooooo`0[ooooo`04ool00?oooooooooooj0Pl0Cooooo00?o003oooooooooool0<Oooool00onP
8?3oooooooooo`0Booooo`03o`00oooooooooooo01Sooooo00?oX23`ooooooooool0?_ooool002;o
oooo00Co0000oooooonP8?3o003o0oooool00ooo003oooooooooo`0Xooooo`03oj0Pl?oooooooooo
01Kooooo00?o003oooooooooool07Oooool00onP8?3oooooooooo`0Zooooo`04ool00?oooooooooo
oj0Pl0Gooooo00?o003oooooooooool0<Oooool00onP8?3oooooooooo`0Booooo`03o`00oooooooo
oooo01Sooooo00?oX23`ooooooooool0?_ooool002;ooooo00Go0000oooooonP8?3oooooo`00o`02
ooooo`03ool00?oooooooooo02Sooooo00?oX23`ooooooooool05_ooool00ol00?ooooooooooo`0N
ooooo`03oj0Pl?oooooooooo02Sooooo00Goo`00oooooooooooooooooj0Pl006ooooo`03o`00oooo
oooooooo033ooooo00?oX23`ooooooooool04_ooool00ol00?ooooooooooo`0Hooooo`03oj0Pl?oo
oooooooo03kooooo000Rooooo`05o`000?ooooooX23`ooooool00?l00oooool00ooo003ooooooooo
o`0Wooooo`03oj0Pl?oooooooooo01Kooooo00?o003oooooooooool07_ooool00onP8?3ooooooooo
o`0Xooooo`05ool00?oooooooooooooooonP8?001_ooool00ol00?ooooooooooo`0`ooooo`03oj0P
l?oooooooooo01;ooooo00?o003oooooooooool06?ooool00onP8?3oooooooooo`0nooooo`008_oo
ool01Ol0003ooooooooooonP8?3o003o00?ooooo00?oo`00ooooooooool09_ooool00onP8?3ooooo
ooooo`0Gooooo`03o`00oooooooooooo01kooooo00?oX23`ooooooooool09oooool00ooo003ooooo
ooooo`02ooooo`03oj0Pl?oooooooooo00Cooooo00?o003oooooooooool0<?ooool00onP8?3ooooo
ooooo`0Aooooo`03o`00oooooooooooo01Wooooo00?oX23`ooooooooool0?_ooool002;ooooo00Go
0000ooooooooooooX23`o`00o`04ooooo`03ool00?oooooooooo02Gooooo00?oX23`ooooooooool0
5_ooool00ol00?ooooooooooo`0Oooooo`03oj0Pl?oooooooooo02Oooooo00?oo`00ooooooooool0
0_ooool00onP8?3oooooooooo`05ooooo`03o`00oooooooooooo02oooooo00?oX23`ooooooooool0
4Oooool00ol00?ooooooooooo`0Hooooo`03oj0Pl?oooooooooo03oooooo000Rooooo`06o`000?oo
oooooooooj0Pl?oooooo003o0oooool00ooo003oooooooooo`0Uooooo`03oj0Pl?oooooooooo01Ko
oooo00?o003oooooooooool07oooool00onP8?3oooooooooo`0Vooooo`03ool00?oooooooooo00?o
oooo00?oX23`ooooooooool01Oooool00ol00?ooooooooooo`0`ooooo`03oj0Pl?oooooooooo013o
oooo00?o003oooooooooool06?ooool00onP8?3oooooooooo`0oooooo`008_ooool2o`000004oooo
oonP8?3oooooo`00o`Cooooo00?oo`00ooooooooool09?ooool00onP8?3oooooooooo`0Fooooo`03
o`00oooooooooooo023ooooo00?oX23`ooooooooool09Oooool00ooo003oooooooooo`02ooooo`03
oj0Pl?oooooooooo00Kooooo00?o003oooooooooool0<?ooool00onP8?3oooooooooo`0@ooooo`03
o`00oooooooooooo01Sooooo00?oX23`ooooooooool0?oooool002;ooooo00Ko0000oooooooooooo
X23`ooooool00?l4ooooo`03ool00?oooooooooo02Cooooo00?oX23`ooooooooool05_ooool00ol0
0?ooooooooooo`0Pooooo`03oj0Pl?oooooooooo02Cooooo00?oo`00ooooooooool00oooool00onP
8?3oooooooooo`06ooooo`03o`00oooooooooooo033ooooo00?oX23`ooooooooool03oooool00ol0
0?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo03oooooo000Rooooo`07o`000?oooooooooooooo
oonP8?3oooooo`00o`04ooooo`03ool00?oooooooooo02?ooooo00?oX23`ooooooooool05Oooool0
0ol00?ooooooooooo`0Qooooo`03oj0Pl?oooooooooo02Cooooo00?oo`00ooooooooool00oooool0
0onP8?3oooooooooo`07ooooo`03o`00oooooooooooo02oooooo00?oX23`ooooooooool03oooool0
0ol00?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo03oooooo000Rooooo`07o`000?oooooooooo
oooooonP8?3oooooo`00o`04ooooo`03ool00?oooooooooo02;ooooo00?oX23`ooooooooool05_oo
ool00ol00?ooooooooooo`0Qooooo`03oj0Pl?oooooooooo02?ooooo00?oo`00ooooooooool01?oo
ool00onP8?3oooooooooo`07ooooo`03o`00oooooooooooo02oooooo00?oX23`ooooooooool03ooo
ool00ol00?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo03oooooo000Rooooo`07o`000?oooooo
oooooooooonP8?3oooooo`00o`05ooooo`03ool00?oooooooooo027ooooo00?oX23`ooooooooool0
5_ooool00ol00?ooooooooooo`0Qooooo`03oj0Pl?oooooooooo02?ooooo00?oo`00ooooooooool0
1?ooool00onP8?3oooooooooo`07ooooo`03o`00oooooooooooo02oooooo00?oX23`ooooooooool0
3_ooool00ol00?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo043ooooo000Rooooo`07o`000?oo
oooooooooooooonP8?3oooooo`00o`05ooooo`03ool00?oooooooooo027ooooo00?oX23`oooooooo
ool05_ooool00ol00?ooooooooooo`0Rooooo`03oj0Pl?oooooooooo027ooooo00?oo`00oooooooo
ool01Oooool00onP8?3oooooooooo`08ooooo`03o`00oooooooooooo02oooooo00?oX23`oooooooo
ool03Oooool00ol00?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo043ooooo000Rooooo`05o`00
0?oooooooooooooooonP8?000_ooool00ol00?ooooooooooo`03ooooo`03ool00?oooooooooo023o
oooo00?oX23`ooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03oj0Pl?oooooooooo027o
oooo00?oo`00ooooooooool01?ooool00onP8?3oooooooooo`09ooooo`03o`00oooooooooooo02oo
oooo00?oX23`ooooooooool03Oooool00ol00?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo043o
oooo000Rooooo`05o`000?oooooooooooooooonP8?000_ooool00ol00?ooooooooooo`03ooooo`03
ool00?oooooooooo023ooooo00?oX23`ooooooooool05Oooool00ol00?ooooooooooo`0Sooooo`03
oj0Pl?oooooooooo023ooooo00?oo`00ooooooooool01Oooool00onP8?3oooooooooo`09ooooo`03
o`00oooooooooooo02oooooo00?oX23`ooooooooool03Oooool00ol00?ooooooooooo`0Iooooo`03
oj0Pl?oooooooooo043ooooo000Rooooo`03o`000?oooooooooo00;ooooo00?oX23`ooooool00?l0
1_ooool00ooo003oooooooooo`0Nooooo`03oj0Pl?oooooooooo01Kooooo00?o003oooooooooool0
8oooool00onP8?3oooooooooo`0Pooooo`03ool00?oooooooooo00Gooooo00?oX23`ooooooooool0
2Oooool00ol00?ooooooooooo`0_ooooo`03oj0Pl?oooooooooo00cooooo00?o003oooooooooool0
6_ooool00onP8?3oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`02ooooo`03oj0Pl?oo
oooo003o00Kooooo00?oo`00ooooooooool07_ooool00onP8?3oooooooooo`0Fooooo`03o`00oooo
oooooooo02?ooooo00?oX23`ooooooooool07oooool00ooo003oooooooooo`06ooooo`03oj0Pl?oo
oooooooo00[ooooo00?o003oooooooooool0;_ooool00onP8?3oooooooooo`0<ooooo`03o`00oooo
oooooooo01Wooooo00?oX23`ooooooooool0@Oooool002;ooooo0_l00003ooooo`04oj0Pl?oooooo
ooooo`00o`Kooooo00?oo`00ooooooooool07Oooool00onP8?3oooooooooo`0Eooooo`03o`00oooo
oooooooo02Cooooo00?oX23`ooooooooool07oooool00ooo003oooooooooo`06ooooo`03oj0Pl?oo
oooooooo00[ooooo00?o003oooooooooool0;oooool00onP8?3oooooooooo`0;ooooo`03o`00oooo
oooooooo01Wooooo00?oX23`ooooooooool0@Oooool002;ooooo00?o0000ooooooooool00_ooool0
1?nP8?3oooooooooool00?l7ooooo`03ool00?oooooooooo01cooooo00?oX23`ooooooooool05Ooo
ool00ol00?ooooooooooo`0Uooooo`03oj0Pl?oooooooooo01gooooo00?oo`00ooooooooool01_oo
ool00onP8?3oooooooooo`0;ooooo`03o`00oooooooooooo02oooooo00?oX23`ooooooooool02_oo
ool00ol00?ooooooooooo`0Jooooo`03oj0Pl?oooooooooo047ooooo000Rooooo`03o`000?oooooo
oooo00;ooooo00CoX23`oooooooooooo003o1oooool00ooo003oooooooooo`0Looooo`03oj0Pl?oo
oooooooo01Gooooo00?o003oooooooooool09Oooool00onP8?3oooooooooo`0Looooo`03ool00?oo
oooooooo00Oooooo00?oX23`ooooooooool02oooool00ol00?ooooooooooo`0_ooooo`03oj0Pl?oo
oooooooo00[ooooo00?o003oooooooooool06_ooool00onP8?3oooooooooo`11ooooo`008_ooool0
0ol0003oooooooooo`02ooooo`05oj0Pl?ooooooooooooooool00?l01oooool00ooo003ooooooooo
o`0Kooooo`03oj0Pl?oooooooooo01Gooooo00?o003oooooooooool09Oooool00onP8?3ooooooooo
o`0Looooo`03ool00?oooooooooo00Oooooo00?oX23`ooooooooool03?ooool00ol00?oooooooooo
o`0^ooooo`03oj0Pl?oooooooooo00[ooooo00?o003oooooooooool06_ooool00onP8?3ooooooooo
o`11ooooo`008_ooool00ol0003oooooooooo`03ooooo`04oj0Pl?ooooooooooo`00o`Oooooo00?o
o`00ooooooooool06_ooool00onP8?3oooooooooo`0Eooooo`03o`00oooooooooooo02Kooooo00?o
X23`ooooooooool06oooool00ooo003oooooooooo`08ooooo`03oj0Pl?oooooooooo00cooooo00?o
003oooooooooool0;_ooool00onP8?3oooooooooo`0:ooooo`03o`00oooooooooooo01[ooooo00?o
X23`ooooooooool0@Oooool002;ooooo00?o0000ooooooooool00oooool01?nP8?3oooooooooool0
0?l8ooooo`03ool00?oooooooooo01Wooooo00?oX23`ooooooooool05Oooool00ol00?oooooooooo
o`0Vooooo`03oj0Pl?oooooooooo01_ooooo00?oo`00ooooooooool02?ooool00onP8?3ooooooooo
o`0<ooooo`03o`00oooooooooooo02kooooo00?oX23`ooooooooool02Oooool00ol00?oooooooooo
o`0Jooooo`03oj0Pl?oooooooooo04;ooooo000Rooooo`03o`000?oooooooooo00?ooooo00CoX23`
oooooooooooo003o2?ooool00ooo003oooooooooo`0Iooooo`03oj0Pl?oooooooooo01Gooooo00?o
003oooooooooool09oooool00onP8?3oooooooooo`0Iooooo`03ool00?oooooooooo00Wooooo00?o
X23`ooooooooool03Oooool00ol00?ooooooooooo`0^ooooo`03oj0Pl?oooooooooo00Sooooo00?o
003oooooooooool06_ooool00onP8?3oooooooooo`12ooooo`008_ooool00ol0003oooooooooo`03
ooooo`05oj0Pl?ooooooooooooooool00?l02?ooool00ooo003oooooooooo`0Hooooo`03oj0Pl?oo
oooooooo01Gooooo00?o003oooooooooool09oooool00onP8?3oooooooooo`0Hooooo`03ool00?oo
oooooooo00Wooooo00?oX23`ooooooooool03_ooool00ol00?ooooooooooo`0^ooooo`03oj0Pl?oo
oooooooo00Sooooo00?o003oooooooooool06_ooool00onP8?3oooooooooo`12ooooo`008_ooool0
0ol0003oooooooooo`03ooooo`05oj0Pl?ooooooooooooooool00?l02?ooool00ooo003ooooooooo
o`0Hooooo`03oj0Pl?oooooooooo01Cooooo00?o003oooooooooool0:?ooool00onP8?3ooooooooo
o`0Hooooo`03ool00?oooooooooo00Wooooo00?oX23`ooooooooool03_ooool00ol00?oooooooooo
o`0^ooooo`03oj0Pl?oooooooooo00Sooooo00?o003oooooooooool06_ooool00onP8?3ooooooooo
o`12ooooo`008_ooool00ol0003oooooooooo`04ooooo`04oj0Pl?ooooooooooo`00o`Wooooo00?o
o`00ooooooooool05_ooool00onP8?3oooooooooo`0Eooooo`03o`00oooooooooooo02Sooooo00?o
X23`ooooooooool05oooool00ooo003oooooooooo`0:ooooo`03oj0Pl?oooooooooo00kooooo00?o
003oooooooooool0;_ooool00onP8?3oooooooooo`07ooooo`03o`00oooooooooooo01_ooooo00?o
X23`ooooooooool0@_ooool002;ooooo0_l00005ooooo`04oj0Pl?ooooooooooo`00o`[ooooo00?o
o`00ooooooooool05Oooool00onP8?3oooooooooo`0Eooooo`03o`00oooooooooooo02Sooooo00?o
X23`ooooooooool05oooool00ooo003oooooooooo`0:ooooo`03oj0Pl?oooooooooo00oooooo00?o
003oooooooooool0;Oooool00onP8?3oooooooooo`07ooooo`03o`00oooooooooooo01_ooooo00?o
X23`ooooooooool0@_ooool002;ooooo00?o0000ooooooooool01?ooool01OnP8?3ooooooooooooo
oooo003o00Wooooo00?oo`00ooooooooool05Oooool00onP8?3oooooooooo`0Dooooo`03o`00oooo
oooooooo02[ooooo00?oX23`ooooooooool05Oooool00ooo003oooooooooo`0;ooooo`03oj0Pl?oo
oooooooo00oooooo00?o003oooooooooool0;_ooool00onP8?3oooooooooo`06ooooo`03o`00oooo
oooooooo01[ooooo00?oX23`ooooooooool0@oooool002;ooooo00?o0000ooooooooool01?ooool0
1OnP8?3ooooooooooooooooo003o00[ooooo00?oo`00ooooooooool05?ooool00onP8?3ooooooooo
o`0Dooooo`03o`00oooooooooooo02[ooooo00?oX23`ooooooooool05Oooool00ooo003ooooooooo
o`0;ooooo`03oj0Pl?oooooooooo00oooooo00?o003oooooooooool0;_ooool00onP8?3ooooooooo
o`05ooooo`03o`00oooooooooooo01_ooooo00?oX23`ooooooooool0@oooool002;ooooo00?o0000
ooooooooool01?ooool01OnP8?3ooooooooooooooooo003o00[ooooo00?oo`00ooooooooool05?oo
ool00onP8?3oooooooooo`0Dooooo`03o`00oooooooooooo02[ooooo00?oX23`ooooooooool05?oo
ool00ooo003oooooooooo`0;ooooo`03oj0Pl?oooooooooo013ooooo00?o003oooooooooool0;_oo
ool00onP8?3oooooooooo`05ooooo`03o`00oooooooooooo01_ooooo00?oX23`ooooooooool0@ooo
ool002;ooooo00?o0000ooooooooool01Oooool01OnP8?3ooooooooooooooooo003o00[ooooo00?o
o`00ooooooooool04oooool00onP8?3oooooooooo`0Dooooo`03o`00oooooooooooo02[ooooo00?o
X23`ooooooooool04oooool00ooo003oooooooooo`0<ooooo`03oj0Pl?oooooooooo017ooooo00?o
003oooooooooool0;Oooool00onP8?3oooooooooo`05ooooo`03o`00oooooooooooo01_ooooo00?o
X23`ooooooooool0@oooool002;ooooo00?o0000ooooooooool01Oooool01OnP8?3ooooooooooooo
oooo003o00[ooooo00?oo`00ooooooooool04_ooool00onP8?3oooooooooo`0Dooooo`03o`00oooo
oooooooo02_ooooo00?oX23`ooooooooool04oooool00ooo003oooooooooo`0<ooooo`03oj0Pl?oo
oooooooo017ooooo00?o003oooooooooool0;Oooool00onP8?3oooooooooo`05ooooo`03o`00oooo
oooooooo01_ooooo00?oX23`ooooooooool0@oooool002;ooooo00?o0000ooooooooool01Oooool0
1OnP8?3ooooooooooooooooo003o00_ooooo00?oo`00ooooooooool04Oooool00onP8?3ooooooooo
o`0Dooooo`03o`00oooooooooooo02cooooo00?oX23`ooooooooool04Oooool00ooo003ooooooooo
o`0=ooooo`03oj0Pl?oooooooooo017ooooo00?o003oooooooooool0;_ooool00onP8?3ooooooooo
o`03ooooo`03o`00oooooooooooo01_ooooo00?oX23`ooooooooool0A?ooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool01Oooool01OnP8?3ooooooooooooooooo003o00_ooooo00?oo`00oooooooo
ool04Oooool00onP8?3oooooooooo`0Dooooo`03o`00oooooooooooo02cooooo00?oX23`oooooooo
ool04Oooool00ooo003oooooooooo`0=ooooo`03oj0Pl?oooooooooo01;ooooo00?o003ooooooooo
ool0;Oooool00onP8?3oooooooooo`03ooooo`03o`00oooooooooooo01_ooooo00?oX23`oooooooo
ool0A?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00Gooooo00?oX23`ooooooooool00_ooool00ol00?oo
ooooooooo`09ooooo`03ool00?oooooooooo013ooooo00?oX23`ooooooooool05?ooool00ol00?oo
ooooooooo`0/ooooo`03oj0Pl?oooooooooo013ooooo00?oo`00ooooooooool03Oooool00onP8?3o
ooooooooo`0Cooooo`03o`00oooooooooooo02gooooo00?oX23`ooooooooool00oooool00ol00?oo
ooooooooo`0Kooooo`03oj0Pl?oooooooooo04Cooooo0007ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00GoX23`oooooooo
ooooooooo`00o`0<ooooo`03ool00?oooooooooo00oooooo00?oX23`ooooooooool04oooool00ol0
0?ooooooooooo`0]ooooo`03oj0Pl?oooooooooo00oooooo00?oo`00ooooooooool03_ooool00onP
8?3oooooooooo`0Cooooo`03o`00oooooooooooo02gooooo00?oX23`ooooooooool00oooool00ol0
0?ooooooooooo`0Kooooo`03oj0Pl?oooooooooo04Cooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`04ooooo`?o00001_ooool01OnP8?3ooooooooooooooooo
003o00cooooo00?oo`00ooooooooool03_ooool00onP8?3oooooooooo`0Dooooo`03o`00oooooooo
oooo02gooooo00?oX23`ooooooooool03oooool00ooo003oooooooooo`0>ooooo`03oj0Pl?oooooo
oooo01Cooooo00?o003oooooooooool0;Oooool01OnP8?3ooooooooooooooooo003o01kooooo00?o
X23`ooooooooool0A?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`05oj0Pl?ooooooooooooooool0
0?l03Oooool00ooo003oooooooooo`0=ooooo`03oj0Pl?oooooooooo01Cooooo00?o003ooooooooo
ool0;_ooool00onP8?3oooooooooo`0=ooooo`03ool00?oooooooooo00oooooo00?oX23`oooooooo
ool05?ooool00ol00?ooooooooooo`0]ooooo`05oj0Pl?ooooooooooooooool00?l07_ooool00onP
8?3oooooooooo`14ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03oj0Pl?oooooooooo00;ooooo00?o003ooooo
ooooool02_ooool00ooo003oooooooooo`0=ooooo`03oj0Pl?oooooooooo01?ooooo00?o003ooooo
ooooool0;oooool00onP8?3oooooooooo`0=ooooo`03ool00?oooooooooo00oooooo00?oX23`oooo
ooooool05?ooool00ol00?ooooooooooo`0]ooooo`05oj0Pl?ooooooooooooooool00?l07Oooool0
0onP8?3oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`05oj0Pl?ooooooooooooooool00?l03Ooo
ool00ooo003oooooooooo`0<ooooo`03oj0Pl?oooooooooo01?ooooo00?o003oooooooooool0;ooo
ool00onP8?3oooooooooo`0<ooooo`03ool00?oooooooooo00oooooo00?oX23`ooooooooool05_oo
ool00ol00?ooooooooooo`0/ooooo`04oj0Pl?ooooooooooo`00oakooooo00?oX23`ooooooooool0
AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003ooooo
ooooo`07ooooo`05oj0Pl?ooooooooooooooool00?l03_ooool00ooo003oooooooooo`0;ooooo`03
oj0Pl?oooooooooo01?ooooo00?o003oooooooooool0;oooool00onP8?3oooooooooo`0;ooooo`03
ool00?oooooooooo013ooooo00?oX23`ooooooooool05_ooool00ol00?ooooooooooo`0]ooooo`03
oj0Pl?oooooo003o01kooooo00?oX23`ooooooooool0AOooool002;ooooo00?o0000ooooooooool0
1oooool00onP8?3oooooooooo`02ooooo`03o`00oooooooooooo00_ooooo00?oo`00ooooooooool0
2oooool00onP8?3oooooooooo`0Booooo`03o`00oooooooooooo033ooooo00?oX23`ooooooooool0
2oooool00ooo003oooooooooo`0@ooooo`03oj0Pl?oooooooooo01Kooooo00?o003oooooooooool0
;Oooool00onP8?3oooooo`00o`0Nooooo`03oj0Pl?oooooooooo04Gooooo000Rooooo`03o`000?oo
oooooooo00Oooooo00?oX23`ooooooooool00_ooool00ol00?ooooooooooo`0<ooooo`03ool00?oo
oooooooo00Wooooo00?oX23`ooooooooool04oooool00ol00?ooooooooooo`0aooooo`03oj0Pl?oo
oooooooo00Wooooo00?oo`00ooooooooool04Oooool00onP8?3oooooooooo`0Gooooo`03o`00oooo
oooooooo02cooooo00?oX23`ooooool00?l07_ooool00onP8?3oooooooooo`15ooooo`008_ooool0
0ol0003oooooooooo`07ooooo`03oj0Pl?oooooooooo00;ooooo00?o003oooooooooool03Oooool0
0ooo003oooooooooo`08ooooo`03oj0Pl?oooooooooo01?ooooo00?o003oooooooooool0<Oooool0
0onP8?3oooooooooo`08ooooo`03ool00?oooooooooo01;ooooo00?oX23`ooooooooool05oooool0
0ol00?ooooooooooo`0/ooooo`03oj0Pl?l00?oooooo01gooooo00?oX23`ooooooooool0A_ooool0
02;ooooo00?o0000ooooooooool02?ooool00onP8?3oooooooooo`02ooooo`03o`00oooooooooooo
00cooooo00?oo`00ooooooooool02?ooool00onP8?3oooooooooo`0Booooo`03o`00oooooooooooo
03;ooooo00?oX23`ooooooooool02?ooool00ooo003oooooooooo`0Aooooo`03oj0Pl?oooooooooo
01Sooooo00?o003oooooooooool0;?ooool00onP8?3o003oooooo`0Mooooo`03oj0Pl?oooooooooo
04Kooooo000Rooooo`03o`000?oooooooooo00Sooooo00?oX23`ooooooooool00_ooool00ol00?oo
ooooooooo`0=ooooo`03ool00?oooooooooo00Oooooo00?oX23`ooooooooool04_ooool00ol00?oo
ooooooooo`0booooo`03oj0Pl?oooooooooo00Oooooo00?oo`00ooooooooool04_ooool00onP8?3o
ooooooooo`0Iooooo`03o`00oooooooooooo02cooooo00?oX23`ooooooooool07?ooool00onP8?3o
ooooooooo`16ooooo`008_ooool2o`0000Wooooo00?oX23`ooooooooool00_ooool00ol00?oooooo
ooooo`0>ooooo`03ool00?oooooooooo00Kooooo00?oX23`ooooooooool04_ooool00ol00?oooooo
ooooo`0booooo`03oj0Pl?oooooooooo00Kooooo00?oo`00ooooooooool04oooool00onP8?3ooooo
ooooo`0Iooooo`03o`00oooooooooooo02_ooooo00?o003ooj0Pl?ooool07Oooool00onP8?3ooooo
ooooo`16ooooo`008_ooool00ol0003oooooooooo`08ooooo`03oj0Pl?oooooooooo00;ooooo00?o
003oooooooooool03_ooool00ooo003oooooooooo`06ooooo`03oj0Pl?oooooooooo017ooooo00?o
003oooooooooool0=?ooool00onP8?3oooooooooo`04ooooo`03ool00?oooooooooo01Cooooo00?o
X23`ooooooooool06Oooool00ol00?ooooooooooo`0[ooooo`03o`00oonP8?3ooooo01gooooo00?o
X23`ooooooooool0A_ooool002;ooooo00?o0000ooooooooool02?ooool00onP8?3oooooooooo`03
ooooo`03o`00oooooooooooo00kooooo00?oo`00ooooooooool01?ooool00onP8?3oooooooooo`0B
ooooo`03o`00oooooooooooo03Cooooo00?oX23`ooooooooool01?ooool00ooo003oooooooooo`0D
ooooo`03oj0Pl?oooooooooo01[ooooo00?o003oooooooooool0:_ooool00ol00?ooX23`ooooo`0M
ooooo`03oj0Pl?oooooooooo04Kooooo000Rooooo`03o`000?oooooooooo00Wooooo00?oX23`oooo
ooooool00_ooool00ol00?ooooooooooo`0>ooooo`03ool00?oooooooooo00Cooooo00?oX23`oooo
ooooool04_ooool00ol00?ooooooooooo`0dooooo`03oj0Pl?oooooooooo00?ooooo00?oo`00oooo
ooooool05?ooool00onP8?3oooooooooo`0Kooooo`03o`00oooooooooooo02Wooooo00Co003ooooo
ooooooooX23`7?ooool00onP8?3oooooooooo`17ooooo`008_ooool00ol0003oooooooooo`09oooo
o`03oj0Pl?oooooooooo00;ooooo00?o003oooooooooool03oooool00ooo003oooooooooo`03oooo
o`03oj0Pl?oooooooooo017ooooo00?o003oooooooooool0=Oooool00onP8?3oooooooooo`02oooo
o`03ool00?oooooooooo01Gooooo00?oX23`ooooooooool06oooool00ol00?ooooooooooo`0Yoooo
o`04o`00oooooooooooooj0Pl1cooooo00?oX23`ooooooooool0Aoooool002;ooooo00?o0000oooo
ooooool02Oooool00onP8?3oooooooooo`03ooooo`03o`00oooooooooooo00oooooo00?oo`00oooo
ooooool00_ooool00onP8?3oooooooooo`0Aooooo`03o`00oooooooooooo03Gooooo00?oX23`oooo
ooooool00_ooool00ooo003oooooooooo`0Eooooo`03oj0Pl?oooooooooo01cooooo00?o003ooooo
ooooool0:?ooool01?l00?oooooooooooonP8?0Looooo`03oj0Pl?oooooooooo04Oooooo000Roooo
o`03o`000?oooooooooo00Wooooo00?oX23`ooooooooool00oooool00ol00?ooooooooooo`0?oooo
o`03ool00?oooooooooo00;ooooo00?oX23`ooooooooool04Oooool00ol00?ooooooooooo`0foooo
o`04oj0Pl?ooooooooooool001Sooooo00?oX23`ooooooooool07?ooool00ol00?ooooooooooo`0W
ooooo`05o`00oooooooooooooooooonP8?007?ooool00onP8?3oooooooooo`17ooooo`008_ooool0
0ol0003oooooooooo`09ooooo`03oj0Pl?oooooooooo00?ooooo00?o003oooooooooool04?ooool0
1?oo003ooooooooooonP8?0Cooooo`03o`00oooooooooooo03Oooooo00?oX23`oooooooo00006Ooo
ool00onP8?3oooooooooo`0Looooo`03o`00oooooooooooo02Oooooo00Go003ooooooooooooooooo
oj0Pl00Looooo`03oj0Pl?oooooooooo04Oooooo000Rooooo`03o`000?oooooooooo00[ooooo00?o
X23`ooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03ool00?ooooooX23`01?ooooo00?o
003oooooooooool0=oooool00onP8?3oooooool0000Hooooo`03oj0Pl?oooooooooo01kooooo00?o
003oooooooooool09_ooool00ol00?ooooooooooo`02ooooo`03oj0Pl?oooooooooo01Sooooo00?o
X23`ooooooooool0B?ooool002;ooooo0_l0000;ooooo`03oj0Pl?oooooooooo00?ooooo00?o003o
ooooooooool04?ooool00ooo003ooooooj0Pl00Cooooo`03o`00oooooooooooo03Oooooo00?oX23`
ool00?ooool06?ooool00onP8?3oooooooooo`0Nooooo`03o`00oooooooooooo02Gooooo00?o003o
ooooooooool00oooool00onP8?3oooooooooo`0Hooooo`03oj0Pl?oooooooooo04Sooooo000Roooo
o`03o`000?oooooooooo00[ooooo00?oX23`ooooooooool00oooool00ol00?ooooooooooo`0Aoooo
o`03ool00?nP8?3ooooo017ooooo00?o003oooooooooool0>?ooool00ooo003oX23`ooooo`0Hoooo
o`03oj0Pl?oooooooooo01kooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`03oooo
o`03oj0Pl?oooooooooo01Sooooo00?oX23`ooooooooool0B?ooool002;ooooo00?o0000oooooooo
ool02_ooool00onP8?3oooooooooo`04ooooo`03o`00oooooooooooo017ooooo00?oX23`oooooooo
ool04?ooool00ol00?ooooooooooo`0hooooo`03ool00?nP8?3ooooo01Sooooo00?oX23`oooooooo
ool07oooool00ol00?ooooooooooo`0Tooooo`03o`00oooooooooooo00?ooooo00?oX23`oooooooo
ool06?ooool00onP8?3oooooooooo`18ooooo`008_ooool00ol0003oooooooooo`0;ooooo`03oj0P
l?oooooooooo00?ooooo00?o003oooooooooool04?ooool00onP8?3oo`00ooooo`0Aooooo`03o`00
oooooooooooo03Oooooo00?oo`00oooooonP8?006Oooool00onP8?3oooooooooo`0Oooooo`03o`00
oooooooooooo02?ooooo00?o003oooooooooool01Oooool00onP8?3oooooooooo`0Fooooo`03oj0P
l?oooooooooo04Wooooo000Rooooo`03o`000?oooooooooo00_ooooo00?oX23`ooooooooool01?oo
ool00ol00?ooooooooooo`0?ooooo`03oj0Pl?ooooooo`00013ooooo00?o003oooooooooool0=ooo
ool01?oo003ooooooooooonP8?0Hooooo`03oj0Pl?oooooooooo023ooooo00?o003oooooooooool0
8oooool00ol00?ooooooooooo`05ooooo`03oj0Pl?oooooooooo01Kooooo00?oX23`ooooooooool0
BOooool002;ooooo00?o0000ooooooooool02oooool00onP8?3oooooooooo`04ooooo`03o`00oooo
oooooooo00oooooo00CoX23`ooooooooooooo`003oooool00ol00?ooooooooooo`0fooooo`03ool0
0?oooooooooo00;ooooo00?oX23`ooooooooool05Oooool00onP8?3oooooooooo`0Qooooo`03o`00
oooooooooooo02;ooooo00?o003oooooooooool01Oooool00onP8?3oooooooooo`0Fooooo`03oj0P
l?oooooooooo04Wooooo000Rooooo`03o`000?oooooooooo00_ooooo00?oX23`ooooooooool01?oo
ool00ol00?ooooooooooo`0>ooooo`03oj0Pl?oooooooooo00;ooooo00?oo`00ooooooooool03?oo
ool00ol00?ooooooooooo`0eooooo`03ool00?oooooooooo00?ooooo00?oX23`ooooooooool05Ooo
ool00onP8?3oooooooooo`0Qooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool01_oo
ool00onP8?3oooooooooo`0Eooooo`03oj0Pl?oooooooooo04[ooooo000Rooooo`03o`000?oooooo
oooo00cooooo00?oX23`ooooooooool01?ooool00ol00?ooooooooooo`0=ooooo`03oj0Pl?oooooo
oooo00?ooooo00?oo`00ooooooooool02_ooool00ol00?ooooooooooo`0fooooo`03ool00?oooooo
oooo00?ooooo00?oX23`ooooooooool05?ooool00onP8?3oooooooooo`0Rooooo`03o`00oooooooo
oooo027ooooo00?o003oooooooooool01oooool00onP8?3oooooooooo`0Dooooo`03oj0Pl?oooooo
oooo04[ooooo000Rooooo`03o`000?oooooooooo00cooooo00?oX23`ooooooooool01?ooool00ol0
0?ooooooooooo`0=ooooo`03oj0Pl?oooooooooo00?ooooo00?oo`00ooooooooool02_ooool00ol0
0?ooooooooooo`0eooooo`03ool00?oooooooooo00Cooooo00?oX23`ooooooooool05?ooool00onP
8?3oooooooooo`0Sooooo`03o`00oooooooooooo01oooooo00?o003oooooooooool02?ooool00onP
8?3oooooooooo`0Dooooo`03oj0Pl?oooooooooo04[ooooo000Rooooo`03o`000?oooooooooo00co
oooo00?oX23`ooooooooool01Oooool00ol00?ooooooooooo`0<ooooo`03oj0Pl?oooooooooo00Co
oooo00?oo`00ooooooooool02?ooool00ol00?ooooooooooo`0eooooo`03ool00?oooooooooo00Go
oooo00?oX23`ooooooooool05?ooool00onP8?3oooooooooo`0Sooooo`03o`00oooooooooooo01oo
oooo00?o003oooooooooool02?ooool00onP8?3oooooooooo`0Cooooo`03oj0Pl?oooooooooo04_o
oooo000Rooooo`;o00003Oooool00onP8?3oooooooooo`05ooooo`03o`00oooooooooooo00_ooooo
00?oX23`ooooooooool01_ooool00ooo003oooooooooo`07ooooo`03o`00oooooooooooo03Cooooo
00?oo`00ooooooooool01oooool00onP8?3oooooooooo`0Booooo`03oj0Pl?oooooooooo02Gooooo
00?o003oooooooooool07Oooool00ol00?ooooooooooo`09ooooo`03oj0Pl?oooooooooo01?ooooo
00?oX23`ooooooooool0Boooool002;ooooo00?o0000ooooooooool03?ooool00onP8?3ooooooooo
o`06ooooo`03o`00oooooooooooo00[ooooo00?oX23`ooooooooool01oooool00ooo003ooooooooo
o`06ooooo`03o`00oooooooooooo03?ooooo00?oo`00ooooooooool02?ooool00onP8?3ooooooooo
o`0Booooo`03oj0Pl?oooooooooo02Gooooo00?o003oooooooooool07Oooool00ol00?oooooooooo
o`0:ooooo`03oj0Pl?oooooooooo01;ooooo00?oX23`ooooooooool0Boooool002;ooooo00?o0000
ooooooooool03Oooool00onP8?3oooooooooo`05ooooo`03o`00oooooooooooo00[ooooo00?oX23`
ooooooooool02?ooool00ooo003oooooooooo`04ooooo`03o`00oooooooooooo03?ooooo00?oo`00
ooooooooool02Oooool00onP8?3oooooooooo`0Booooo`03oj0Pl?oooooooooo02Gooooo00?o003o
ooooooooool07?ooool00ol00?ooooooooooo`0;ooooo`03oj0Pl?oooooooooo017ooooo00?oX23`
ooooooooool0C?ooool002;ooooo00?o0000ooooooooool03Oooool00onP8?3oooooooooo`06oooo
o`03o`00oooooooooooo00Sooooo00?oX23`ooooooooool02Oooool00ooo003oooooooooo`04oooo
o`03o`00oooooooooooo03?ooooo00?oo`00ooooooooool02Oooool00onP8?3oooooooooo`0Aoooo
o`03oj0Pl?oooooooooo02Oooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0;oooo
o`03oj0Pl?oooooooooo017ooooo00?oX23`ooooooooool0C?ooool002;ooooo00?o0000oooooooo
ool03Oooool00onP8?3oooooooooo`06ooooo`03o`00oooooooooooo00Sooooo00?oX23`oooooooo
ool02_ooool00ooo003oooooooooo`02ooooo`03o`00oooooooooooo03?ooooo00?oo`00oooooooo
ool02oooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo02Oooooo00?o003ooooooooo
ool06oooool00ol00?ooooooooooo`0<ooooo`03oj0Pl?oooooooooo013ooooo00?oX23`oooooooo
ool0C?ooool002;ooooo00?o0000ooooooooool03_ooool00onP8?3oooooooooo`05ooooo`03o`00
oooooooooooo00Sooooo00?oX23`ooooooooool02oooool01Ooo003ooooooooooooooooo003o03Co
oooo00?oo`00ooooooooool03?ooool00onP8?3oooooooooo`0@ooooo`03oj0Pl?oooooooooo02Oo
oooo00?o003oooooooooool06_ooool00ol00?ooooooooooo`0=ooooo`03oj0Pl?oooooooooo013o
oooo00?oX23`ooooooooool0C?ooool002;ooooo00?o0000ooooooooool03_ooool00onP8?3ooooo
ooooo`06ooooo`03o`00oooooooooooo00Kooooo00?oX23`ooooooooool03Oooool01?oo003ooooo
ooooool00?lcooooo`03ool00?oooooooooo00gooooo00?oX23`ooooooooool03oooool00onP8?3o
ooooooooo`0Yooooo`03o`00oooooooooooo01Wooooo00?o003oooooooooool03Oooool00onP8?3o
ooooooooo`0?ooooo`03oj0Pl?oooooooooo04gooooo000Rooooo`03o`000?oooooooooo00kooooo
00?oX23`ooooooooool01_ooool00ol00?ooooooooooo`06ooooo`03oj0Pl?oooooooooo00kooooo
00?oo`00o`00ooooool0<Oooool2ool0017ooooo00?oX23`ooooooooool03_ooool00onP8?3ooooo
ooooo`0Yooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool03oooool00onP8?3ooooo
ooooo`0>ooooo`03oj0Pl?oooooooooo04gooooo000Rooooo`03o`000?oooooooooo00oooooo00?o
X23`ooooooooool01_ooool00ol00?ooooooooooo`04ooooo`03oj0Pl?oooooooooo013ooooo00?o
003oool00?ooool0;oooool00ooo003oooooooooo`0Aooooo`03oj0Pl?oooooooooo00kooooo00?o
X23`ooooooooool0:_ooool00ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo00oooooo00?o
X23`ooooooooool03_ooool00onP8?3oooooooooo`1=ooooo`008_ooool00ol0003oooooooooo`0?
ooooo`03oj0Pl?oooooooooo00Kooooo00?o003oooooooooool01?ooool00onP8?3oooooooooo`0?
ooooo`03o`00oooooooooooo00;oo`00;Oooool00ooo003oooooooooo`0Booooo`03oj0Pl?oooooo
oooo00gooooo00?oX23`ooooooooool0;?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooo
oooo017ooooo00?oX23`ooooooooool03Oooool00onP8?3oooooooooo`1=ooooo`008_ooool2o`00
013ooooo00?oX23`ooooooooool01oooool00ol00?ooooooooooo`03ooooo`03oj0Pl?oooooooooo
00kooooo00?o003oooooooooool00oooool00ooo003oooooooooo`0Yooooo`03ool00?oooooooooo
01Cooooo00?oX23`ooooooooool03?ooool00onP8?3oooooooooo`0/ooooo`03o`00oooooooooooo
01Gooooo00?o003oooooooooool04Oooool00onP8?3oooooooooo`0<ooooo`03oj0Pl?oooooooooo
04kooooo000Rooooo`03o`000?oooooooooo013ooooo00?oX23`ooooooooool01_ooool00ol00?oo
ooooooooo`02ooooo`03oj0Pl?oooooooooo00oooooo00?o003oooooooooool01?ooool00ooo003o
ooooooooo`0Wooooo`03ool00?oooooooooo01Gooooo00?oX23`ooooooooool03?ooool00onP8?3o
ooooooooo`0]ooooo`03o`00oooooooooooo01?ooooo00?o003oooooooooool04_ooool00onP8?3o
ooooooooo`0<ooooo`03oj0Pl?oooooooooo04kooooo000Rooooo`03o`000?oooooooooo013ooooo
00?oX23`ooooooooool01oooool01Ol00?ooooooooooooooooooX23`013ooooo00?o003ooooooooo
ool01_ooool2ool002Gooooo0_oo000Hooooo`03oj0Pl?oooooooooo00_ooooo00?oX23`oooooooo
ool0;_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Cooooo00?oX23`oooooooo
ool02_ooool00onP8?3oooooooooo`1?ooooo`008_ooool00ol0003oooooooooo`0@ooooo`03oj0P
l?oooooooooo00Sooooo00?o003ooooooonP8?004?ooool00ol00?ooooooooooo`09ooooo`03ool0
0?oooooooooo023ooooo0_oo000Kooooo`03oj0Pl?oooooooooo00[ooooo00?oX23`ooooooooool0
;oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Gooooo00?oX23`ooooooooool0
2_ooool00onP8?3oooooooooo`1?ooooo`008_ooool00ol0003oooooooooo`0Aooooo`03oj0Pl?oo
oooooooo00Sooooo00?o003ooj0Pl?ooool03_ooool00ol00?ooooooooooo`0;ooooo`03ool00?oo
oooooooo01kooooo00?oo`00ooooooooool07?ooool00onP8?3oooooooooo`09ooooo`03oj0Pl?oo
oooooooo033ooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`0Gooooo`03oj0Pl?oo
oooooooo00Sooooo00?oX23`ooooooooool0D?ooool002;ooooo00?o0000ooooooooool04_ooool0
0onP8?3oooooooooo`08ooooo`03oj0Pl?oooooooooo00cooooo00?o003oooooooooool03Oooool3
ool001_ooooo0_oo000Oooooo`03oj0Pl?oooooooooo00Sooooo00?oX23`ooooooooool0<Oooool0
0ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo01Sooooo00?oX23`ooooooooool02?ooool0
0onP8?3oooooooooo`1@ooooo`008_ooool00ol0003oooooooooo`0Booooo`03oj0Pl?oooooooooo
00Oooooo00?oX23`o`00ooooool03?ooool00ol00?ooooooooooo`0Aooooo`;oo`005oooool2ool0
02;ooooo00?oX23`ooooooooool01_ooool00onP8?3oooooooooo`0cooooo`;o003o3Oooool00ol0
0?ooooooooooo`0Iooooo`03oj0Pl?oooooooooo00Kooooo00?oX23`ooooooooool0DOooool001So
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?oX23`oooooooo
ool01Oooool00onP8?3oooooooooo`02o`00o`_ooooo00?o003oooooooooool04oooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo02?ooooo00?oX23`ooooooooool01Oooool00onP8?3o
ooooooooo`0eooooo`03o`00oooooooooooo00Sooooo0_l00?lLooooo`03oj0Pl?oooooooooo00Go
oooo00?oX23`ooooooooool0D_ooool001[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Dooooo`03oj0Pl?oooooooooo00?ooooo00?oX23`ooooooooool00oooool00ol00?oooooo
ooooo`06ooooo`;o003o5oooool2ool0017ooooo0_oo000Wooooo`03oj0Pl?oooooooooo00?ooooo
00?oX23`ooooooooool0=oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo01gooooo
0_nP8?04ooooo`03oj0Pl?oooooooooo05?ooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05Oooool2oj0Pl003oooooonP8?3oX23`00Oooooo0_l00?l3ooooo`?o003o6ooo
ool5ool000Oooooo1Ooo000Yooooo`;oX23`0_ooool2oj0Pl3_ooooo0ol00?l3ooooo`;o003o8Ooo
ool2oj0Pl0;ooooo00?oX23`ooooooooool0E?ooool001[ooooo00?o0000ooooooooool01Oooool3
o`0001Kooooo0onP8?0:ooooo`Co003o8_ooool7ool0033ooooo0onP8?0nooooo`Co003o9?ooool3
oj0Pl5Oooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom4oooo
o`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooA?ooool001[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooodCooooo000Hooooo`03oeEEEOmV
IVKo000000Oooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003oooooooooo`3o
ooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.107792, -1.13025, \
0.00394428, 0.0127639}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = 1; \ 
    Plot[{1, Cos[2  Pi\ t/T], Cos[4  Pi\ t/T]}, {t, 0, T}, 
      PlotStyle \[Rule] {Red, Blue, Purple}];\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.2"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.309017 0.294302 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(0.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(0.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(0.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(0.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.02381 .60332 m
.06244 .60332 L
.10458 .60332 L
.14415 .60332 L
.18221 .60332 L
.22272 .60332 L
.26171 .60332 L
.30316 .60332 L
.34309 .60332 L
.3815 .60332 L
.42237 .60332 L
.46172 .60332 L
.49955 .60332 L
.53984 .60332 L
.57861 .60332 L
.61984 .60332 L
.65954 .60332 L
.69774 .60332 L
.73838 .60332 L
.77751 .60332 L
.81909 .60332 L
.85916 .60332 L
.89771 .60332 L
.93871 .60332 L
.97619 .60332 L
s
0 0 1 r
.02381 .60332 m
.02499 .60331 L
.02605 .60329 L
.02729 .60324 L
.02846 .60318 L
.03053 .60303 L
.03279 .6028 L
.03527 .60248 L
.0379 .60205 L
.04262 .60106 L
.04749 .59974 L
.05205 .59822 L
.06244 .59381 L
.07305 .58793 L
.08274 .58135 L
.10458 .56251 L
.14429 .51515 L
.18248 .45627 L
.22313 .38349 L
.26226 .30833 L
.30384 .22863 L
.34391 .15746 L
.38246 .09886 L
.402 .07411 L
.42346 .05145 L
.44388 .03466 L
.45301 .02874 L
.46295 .02346 L
.46838 .0211 L
.4734 .01924 L
.4781 .01778 L
.4833 .0165 L
.48553 .01605 L
.48794 .01565 L
.49002 .01535 L
.4923 .0151 L
.49473 .01489 L
.49605 .01481 L
.49728 .01476 L
.49844 .01473 L
.49949 .01472 L
.50071 .01472 L
.50186 .01474 L
.50301 .01477 L
.50425 .01483 L
.50542 .0149 L
.50648 .01498 L
.5091 .01524 L
.51158 .01557 L
.5165 .01646 L
Mistroke
.52187 .01777 L
.53144 .02102 L
.54032 .02507 L
.56088 .03814 L
.5795 .05428 L
.61962 .1017 L
.65822 .16102 L
.69928 .23447 L
.73882 .31042 L
.77684 .38344 L
.81732 .45593 L
.85628 .51593 L
.87613 .54149 L
.89769 .56473 L
.91843 .58221 L
.92832 .58876 L
.93759 .59383 L
.94643 .59767 L
.95595 .6007 L
.9611 .60186 L
.96369 .60232 L
.96652 .60272 L
.96894 .60298 L
.9703 .6031 L
.97153 .60318 L
.97268 .60324 L
.97393 .60329 L
.97511 .60331 L
.97619 .60332 L
Mfstroke
.628 .126 .941 r
.02381 .60332 m
.02499 .60328 L
.02605 .60319 L
.02729 .60301 L
.02846 .60277 L
.03053 .60216 L
.03279 .60126 L
.03527 .59996 L
.0379 .59825 L
.04262 .5943 L
.05205 .58312 L
.06244 .5659 L
.0842 .51473 L
.10458 .45142 L
.14335 .3071 L
.18458 .15507 L
.20517 .0934 L
.21519 .06887 L
.22428 .05023 L
.2338 .03472 L
.24277 .02404 L
.2477 .01987 L
.25224 .01711 L
.25461 .01608 L
.25597 .01562 L
.25722 .01528 L
.25853 .01501 L
.25925 .0149 L
.25994 .01481 L
.26115 .01473 L
.26184 .01472 L
.26248 .01472 L
.26365 .01479 L
.26489 .01494 L
.26595 .01513 L
.26711 .01541 L
.2697 .01627 L
.2721 .01738 L
.27647 .02014 L
.28114 .02415 L
.28669 .03032 L
.29194 .03752 L
.30174 .05445 L
.32176 .10182 L
.34021 .15832 L
.37961 .30382 L
.4175 .4455 L
.43858 .51185 L
.45784 .55895 L
.46737 .57646 L
Mistroke
.4724 .58402 L
.47776 .59073 L
.48291 .59586 L
.48757 .59937 L
.48982 .60067 L
.49225 .60178 L
.49337 .60219 L
.49455 .60256 L
.49565 .60283 L
.49666 .60303 L
.49789 .6032 L
.49854 .60326 L
.49922 .6033 L
.50037 .60332 L
.50164 .60325 L
.50276 .60312 L
.50398 .60291 L
.50512 .60265 L
.50617 .60234 L
.50854 .60145 L
.51113 .60015 L
.51634 .5965 L
.52094 .59215 L
.52585 .58636 L
.53469 .57303 L
.54496 .55304 L
.55607 .52637 L
.57624 .46655 L
.61721 .31615 L
.65666 .16887 L
.6765 .10667 L
.6946 .06186 L
.70461 .04298 L
.71409 .02936 L
.71929 .02373 L
.7241 .01972 L
.72661 .01809 L
.72938 .01666 L
.73077 .01609 L
.73228 .01558 L
.73369 .01521 L
.735 .01496 L
.73627 .0148 L
.73747 .01472 L
.73855 .01472 L
.73973 .01478 L
.741 .01493 L
.74165 .01504 L
.74236 .01518 L
.74362 .0155 L
Mistroke
.74478 .01586 L
.74705 .01677 L
.74949 .01803 L
.7539 .02109 L
.75897 .02581 L
.76451 .03241 L
.77459 .04818 L
.79428 .09194 L
.81525 .15451 L
.85686 .3079 L
.89694 .45656 L
.91533 .51343 L
.92577 .54056 L
.93551 .56194 L
.94506 .57884 L
.94997 .58588 L
.9553 .59221 L
.95822 .59508 L
.96091 .59736 L
.96344 .59916 L
.96623 .60078 L
.96872 .60189 L
.97106 .60264 L
.97235 .60294 L
.97353 .60314 L
.97483 .60327 L
.97548 .60331 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`008P3oool00`000000oooo0?ooo`3o0?oood@0oooo
000R0?ooo`030000003oool0oooo0?l0ooooA03oool001P0oooo100000000`0A4A40oooo0?ooo`03
0?ooo`030000003oool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`3o0?oood@0oooo000?0?ooo`H000001@3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0?l0ooooA03oool001X0oooo00<000000?ooo`3oool01@3oool3000004T0oooo
1P2P8?170?ooo``0003oAP3oool60:0Pl5D0oooo000J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool0B03oool20:0Pl0D0oooo0P2P8?110?ooo`D0003o2`3oool30000od80oooo00<0
X23`0?ooo`3oool00`3oool30:0Pl5<0oooo000J0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0A`3oool00`2P8?00oooo0?ooo`070?ooo`030:0Pl03oool0oooo03`0oooo0P000?lC
0?ooo`@0003o?03oool20:0Pl0T0oooo00<0X23`0?ooo`3oool0D03oool001X0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`160?ooo`030:0Pl03oool0oooo00T0oooo00<0X23`0?oo
o`3oool0>@3oool20000oaT0oooo0P000?li0?ooo`030:0Pl03oool0oooo00T0oooo00<0X23`0?oo
o`3oool0D03oool001P0oooo0P1EEED00`000000oooo0?ooo`050?ooo`030000003oool0oooo04H0
oooo00<0X23`0?ooo`3oool02P3oool00`2P8?00oooo0?ooo`0f0?ooo`80003o7@3oool00`000?l0
oooo0?ooo`0e0?ooo`030:0Pl03oool0oooo00/0oooo00<0X23`0?ooo`3oool0C`3oool00280oooo
00<000000?ooo`3oool0A@3oool00`2P8?00oooo0?ooo`0<0?ooo`030:0Pl03oool0oooo03<0oooo
0P000?lP0?ooo`030000o`3oool0oooo03<0oooo00<0X23`0?ooo`3oool03@3oool00`2P8?00oooo
0?ooo`1>0?ooo`008P3oool00`000000oooo0?ooo`140?ooo`030:0Pl03oool0oooo00h0oooo00<0
X23`0?ooo`3oool0<@3oool00`000?l0oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0380oooo00<0
X23`0?ooo`3oool03P3oool00`2P8?00oooo0?ooo`1=0?ooo`008P3oool00`000000oooo0?ooo`13
0?ooo`030:0Pl03oool0oooo0100oooo00<0X23`0?ooo`3oool0;P3oool20000obD0oooo00<0003o
0?ooo`3oool0<03oool00`2P8?00oooo0?ooo`0?0?ooo`030:0Pl03oool0oooo04d0oooo000R0?oo
o`030000003oool0oooo04<0oooo00<0X23`0?ooo`3oool0403oool00`2P8?00oooo0?ooo`0]0?oo
o`030000o`3oool0oooo02H0oooo0P000?l_0?ooo`030:0Pl03oool0oooo0140oooo00<0X23`0?oo
o`3oool0C03oool00280oooo00<000000?ooo`3oool0@P3oool00`2P8?00oooo0?ooo`0B0?ooo`03
0:0Pl03oool0oooo02/0oooo00<0003o0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0[0?ooo`03
0:0Pl03oool0oooo01<0oooo00<0X23`0?ooo`3oool0B`3oool00280oooo0P0000120?ooo`030:0P
l03oool0oooo01<0oooo00<0X23`0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0[0?ooo`80003o
:`3oool00`2P8?00oooo0?ooo`0C0?ooo`030:0Pl03oool0oooo04/0oooo000R0?ooo`030000003o
ool0oooo0400oooo00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo0?ooo`0X0?ooo`030000o`3o
ool0oooo02h0oooo00<0003o0?ooo`3oool09`3oool00`2P8?00oooo0?ooo`0E0?ooo`030:0Pl03o
ool0oooo04X0oooo000R0?ooo`030000003oool0oooo03l0oooo00<0X23`0?ooo`3oool05P3oool0
0`2P8?00oooo0?ooo`0W0?ooo`030000o`3oool0oooo0300oooo00<0003o0?ooo`3oool09P3oool0
0`2P8?00oooo0?ooo`0E0?ooo`030:0Pl03oool0oooo04X0oooo000R0?ooo`030000003oool0oooo
03l0oooo00<0X23`0?ooo`3oool05`3oool00`2P8?00oooo0?ooo`0V0?ooo`030000o`3oool0oooo
0340oooo00<0003o0?ooo`3oool0903oool00`2P8?00oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo
04T0oooo000R0?ooo`030000003oool0oooo03h0oooo00<0X23`0?ooo`3oool0603oool00`2P8?00
oooo0?ooo`0U0?ooo`030000o`3oool0oooo0380oooo00<0003o0?ooo`3oool0903oool00`2P8?00
oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo04T0oooo000R0?ooo`030000003oool0oooo03h0oooo
00<0X23`0?ooo`3oool06@3oool00`2P8?00oooo0?ooo`0S0?ooo`030000o`3oool0oooo03@0oooo
00<0003o0?ooo`3oool08`3oool00`2P8?00oooo0?ooo`0H0?ooo`030:0Pl03oool0oooo04P0oooo
000R0?ooo`030000003oool0oooo03d0oooo00<0X23`0?ooo`3oool06P3oool00`2P8?00oooo0?oo
o`0R0?ooo`030000o`3oool0oooo03H0oooo00<0003o0?ooo`3oool08@3oool00`2P8?00oooo0?oo
o`0I0?ooo`030:0Pl03oool0oooo04P0oooo000R0?ooo`030000003oool0oooo03d0oooo00<0X23`
0?ooo`3oool06`3oool00`2P8?00oooo0?ooo`0P0?ooo`030000o`3oool0oooo03P0oooo00<0003o
0?ooo`3oool0803oool00`2P8?00oooo0?ooo`0J0?ooo`030:0Pl03oool0oooo04L0oooo000R0?oo
o`030000003oool0oooo03`0oooo00<0X23`0?ooo`3oool0703oool00`2P8?00oooo0?ooo`0O0?oo
o`030000o`3oool0oooo03X0oooo00<0003o0?ooo`3oool07P3oool00`2P8?00oooo0?ooo`0K0?oo
o`030:0Pl03oool0oooo04L0oooo000R0?ooo`800000?@3oool00`2P8?00oooo0?ooo`0L0?ooo`03
0:0Pl03oool0oooo01h0oooo00<0003o0?ooo`3oool0>`3oool00`000?l0oooo0?ooo`0N0?ooo`03
0:0Pl03oool0oooo01`0oooo00<0X23`0?ooo`3oool0AP3oool00280oooo00<000000?ooo`3oool0
>`3oool00`2P8?00oooo0?ooo`0N0?ooo`030:0Pl03oool0oooo01`0oooo00<0003o0?ooo`3oool0
?@3oool00`000?l0oooo0?ooo`0M0?ooo`030:0Pl03oool0oooo01`0oooo00<0X23`0?ooo`3oool0
AP3oool00280oooo00<000000?ooo`3oool0>`3oool00`2P8?00oooo0?ooo`0N0?ooo`030:0Pl03o
ool0oooo01`0oooo00<0003o0?ooo`3oool0?P3oool00`000?l0oooo0?ooo`0K0?ooo`030:0Pl03o
ool0oooo01d0oooo00<0X23`0?ooo`3oool0AP3oool00280oooo00<000000?ooo`3oool0>`3oool0
0`2P8?00oooo0?ooo`0O0?ooo`030:0Pl03oool0oooo01X0oooo00<0003o0?ooo`3oool0@03oool0
0`000?l0oooo0?ooo`0J0?ooo`030:0Pl03oool0oooo01h0oooo00<0X23`0?ooo`3oool0A@3oool0
0280oooo00<000000?ooo`3oool0>P3oool00`2P8?00oooo0?ooo`0P0?ooo`030:0Pl03oool0oooo
01T0oooo00<0003o0?ooo`3oool0@P3oool00`000?l0oooo0?ooo`0H0?ooo`030:0Pl03oool0oooo
01l0oooo00<0X23`0?ooo`3oool0A@3oool00280oooo00<000000?ooo`3oool0>P3oool00`2P8?00
oooo0?ooo`0Q0?ooo`030:0Pl03oool0oooo01L0oooo00<0003o0?ooo`3oool0A03oool00`000?l0
oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo0200oooo00<0X23`0?ooo`3oool0A03oool00280oooo
00<000000?ooo`3oool0>P3oool00`2P8?00oooo0?ooo`0Q0?ooo`030:0Pl03oool0oooo01H0oooo
00<0003o0?ooo`3oool0A@3oool00`000?l0oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo0200oooo
00<0X23`0?ooo`3oool0A03oool00280oooo00<000000?ooo`3oool0>@3oool00`2P8?00oooo0?oo
o`0R0?ooo`030:0Pl03oool0oooo01D0oooo00<0003o0?ooo`3oool0A`3oool00`000?l0oooo0?oo
o`0E0?ooo`030:0Pl03oool0oooo0280oooo00<0X23`0?ooo`3oool0@`3oool00280oooo00<00000
0?ooo`3oool0>@3oool00`2P8?00oooo0?ooo`0S0?ooo`030:0Pl03oool0oooo01<0oooo00<0003o
0?ooo`3oool0B@3oool00`000?l0oooo0?ooo`0D0?ooo`030:0Pl03oool0oooo0280oooo00<0X23`
0?ooo`3oool0@`3oool00280oooo00<000000?ooo`3oool0>03oool00`2P8?00oooo0?ooo`0T0?oo
o`030:0Pl03oool0oooo0180oooo00<0003o0?ooo`3oool0B`3oool00`000?l0oooo0?ooo`0B0?oo
o`030:0Pl03oool0oooo02@0oooo00<0X23`0?ooo`3oool0@P3oool00280oooo0P00000i0?ooo`03
0:0Pl03oool0oooo02D0oooo00<0X23`0?ooo`3oool04@3oool00`000?l0oooo0?ooo`1<0?ooo`03
0000o`3oool0oooo0140oooo00<0X23`0?ooo`3oool0903oool00`2P8?00oooo0?ooo`120?ooo`00
8P3oool00`000000oooo0?ooo`0h0?ooo`030:0Pl03oool0oooo02D0oooo00<0X23`0?ooo`3oool0
403oool00`000?l0oooo0?ooo`1=0?ooo`030000o`3oool0oooo0140oooo00<0X23`0?ooo`3oool0
903oool00`2P8?00oooo0?ooo`120?ooo`008P3oool00`000000oooo0?ooo`0g0?ooo`030:0Pl03o
ool0oooo02H0oooo00<0X23`0?ooo`3oool03`3oool00`000?l0oooo0?ooo`1?0?ooo`030000o`3o
ool0oooo00l0oooo00<0X23`0?ooo`3oool09P3oool00`2P8?00oooo0?ooo`110?ooo`008P3oool0
0`000000oooo0?ooo`0g0?ooo`030:0Pl03oool0oooo02L0oooo00<0X23`0?ooo`3oool03P3oool0
0`000?l0oooo0?ooo`1@0?ooo`030000o`3oool0oooo00h0oooo00<0X23`0?ooo`3oool09P3oool0
0`2P8?00oooo0?ooo`110?ooo`008P3oool00`000000oooo0?ooo`0g0?ooo`030:0Pl03oool0oooo
02L0oooo00<0X23`0?ooo`3oool03@3oool00`000?l0oooo0?ooo`1A0?ooo`030000o`3oool0oooo
00d0oooo00<0X23`0?ooo`3oool09`3oool00`2P8?00oooo0?ooo`110?ooo`008P3oool00`000000
oooo0?ooo`0f0?ooo`030:0Pl03oool0oooo02P0oooo00<0X23`0?ooo`3oool0303oool00`000?l0
oooo0?ooo`1C0?ooo`030000o`3oool0oooo00`0oooo00<0X23`0?ooo`3oool0:03oool00`2P8?00
oooo0?ooo`100?ooo`008P3oool00`000000oooo0?ooo`0f0?ooo`030:0Pl03oool0oooo02T0oooo
00<0X23`0?ooo`3oool02`3oool00`000?l0oooo0?ooo`1D0?ooo`030000o`3oool0oooo00/0oooo
00<0X23`0?ooo`3oool0:03oool00`2P8?00oooo0?ooo`100?ooo`008P3oool00`000000oooo0?oo
o`0f0?ooo`030:0Pl03oool0oooo02T0oooo00<0X23`0?ooo`3oool02P3oool00`000?l0oooo0?oo
o`1E0?ooo`030000o`3oool0oooo00X0oooo00<0X23`0?ooo`3oool0:@3oool00`2P8?00oooo0?oo
o`100?ooo`008P3oool00`000000oooo0?ooo`0e0?ooo`030:0Pl03oool0oooo02X0oooo00<0X23`
0?ooo`3oool02@3oool00`000?l0oooo0?ooo`1G0?ooo`030000o`3oool0oooo00T0oooo00<0X23`
0?ooo`3oool0:P3oool00`2P8?00oooo0?ooo`0o0?ooo`008P3oool00`000000oooo0?ooo`0e0?oo
o`030:0Pl03oool0oooo02/0oooo00<0X23`0?ooo`3oool01`3oool00`000?l0oooo0?ooo`1I0?oo
o`030000o`3oool0oooo00P0oooo00<0X23`0?ooo`3oool0:P3oool00`2P8?00oooo0?ooo`0o0?oo
o`008P3oool2000003H0oooo00<0X23`0?ooo`3oool0:`3oool00`2P8?00oooo0?ooo`070?ooo`03
0000o`3oool0oooo05T0oooo00<0003o0?ooo`3oool01`3oool00`2P8?00oooo0?ooo`0[0?ooo`03
0:0Pl03oool0oooo03l0oooo000R0?ooo`030000003oool0oooo03@0oooo00<0X23`0?ooo`3oool0
;03oool00`2P8?00oooo0?ooo`060?ooo`030000o`3oool0oooo05/0oooo00<0003o0?ooo`3oool0
1P3oool00`2P8?00oooo0?ooo`0/0?ooo`030:0Pl03oool0oooo03h0oooo000R0?ooo`030000003o
ool0oooo03@0oooo00<0X23`0?ooo`3oool0;@3oool00`2P8?00oooo0?ooo`040?ooo`030000o`3o
ool0oooo05`0oooo00<0003o0?ooo`3oool01P3oool00`2P8?00oooo0?ooo`0/0?ooo`030:0Pl03o
ool0oooo03h0oooo000R0?ooo`030000003oool0oooo03@0oooo00<0X23`0?ooo`3oool0;@3oool0
0`2P8?00oooo0?ooo`040?ooo`030000o`3oool0oooo05d0oooo00<0003o0?ooo`3oool0103oool0
0`2P8?00oooo0?ooo`0]0?ooo`030:0Pl03oool0oooo03h0oooo000R0?ooo`030000003oool0oooo
03<0oooo00<0X23`0?ooo`3oool0;P3oool00`2P8?00oooo0?ooo`030?ooo`030000o`3oool0oooo
05l0oooo00<0003o0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`0^0?ooo`030:0Pl03oool0oooo
03d0oooo000R0?ooo`030000003oool0oooo03<0oooo00<0X23`0?ooo`3oool0;`3oool01@2P8?00
oooo0?ooo`3oool0003o0680oooo00<0003o0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`0^0?oo
o`030:0Pl03oool0oooo03d0oooo000R0?ooo`030000003oool0oooo03<0oooo00<0X23`0?ooo`3o
ool0;`3oool01@2P8?00oooo0?ooo`3oool0003o06<0oooo00D0003o0?ooo`3oool0oooo0:0Pl00a
0?ooo`030:0Pl03oool0oooo03d0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2
028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo0380oooo00<0
X23`0?ooo`3oool0<03oool0102P8?00oooo0?ooo`000?mU0?ooo`040000o`3oool0oooo0:0Pl380
oooo00<0X23`0?ooo`3oool0?03oool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`80
8R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0380oooo00<0X23`0?ooo`3o
ool0<@3oool00`2P8?00003o0?ooo`1U0?ooo`040000o`3oool0oooo0:0Pl380oooo00<0X23`0?oo
o`3oool0?03oool000D000000P3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0b0?ooo`030:0Pl03oool0oooo0340oooo00<0X23`0000
o`3oool0IP3oool00`000?l0X23`0?ooo`0b0?ooo`030:0Pl03oool0oooo03`0oooo00070?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`040?ooo`<00000<P3oool00`2P
8?00oooo0?ooo`0a0?ooo`030:0Pl03oool0oooo06L0oooo00<0X23`0?ooo`3oool0<P3oool00`2P
8?00oooo0?ooo`0k0?ooo`001`3oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R
8P000000<c<c0<c<c0050?ooo`030000003oool0oooo0340oooo00<0X23`0?ooo`3oool0<P3oool0
0`2P8?00oooo0?ooo`1W0?ooo`030:0Pl03oool0oooo0380oooo00<0X23`0?ooo`3oool0>`3oool0
00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0<@3oool00`2P8?00oooo0?ooo`0a0?ooo`030000o`3oool0X23`06L0oooo00<0X23`
0?ooo`000?l0<`3oool00`2P8?00oooo0?ooo`0k0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0a0?ooo`030:0Pl03oool0
oooo0340oooo00<0003o0?ooo`2P8?00I`3oool00`2P8?00oooo0000o`0d0?ooo`030:0Pl03oool0
oooo03X0oooo00070?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000H0oooo00<00000
0?ooo`3oool0<03oool00`2P8?00oooo0?ooo`0a0?ooo`040000o`3oool0oooo0:0Pl6L0oooo00@0
X23`0?ooo`3oool0003o<`3oool00`2P8?00oooo0?ooo`0j0?ooo`008P3oool00`000000oooo0?oo
o`0`0?ooo`030:0Pl03oool0oooo0300oooo00D0003o0?ooo`3oool0oooo0:0Pl01V0?ooo`050:0P
l03oool0oooo0?ooo`000?l0<`3oool00`2P8?00oooo0?ooo`0j0?ooo`008P3oool00`000000oooo
0?ooo`0`0?ooo`030:0Pl03oool0oooo0300oooo00<0003o0?ooo`3oool00P3oool00`2P8?00oooo
0?ooo`1S0?ooo`030:0Pl03oool0oooo0080oooo00<0003o0?ooo`3oool0<03oool00`2P8?00oooo
0?ooo`0j0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`030:0Pl03oool0oooo02l0oooo00<0
003o0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`1S0?ooo`030:0Pl03oool0oooo00<0oooo00<0
003o0?ooo`3oool0<03oool00`2P8?00oooo0?ooo`0i0?ooo`008P3oool00`000000oooo0?ooo`0_
0?ooo`030:0Pl03oool0oooo0300oooo00<0003o0?ooo`3oool00`3oool00`2P8?00oooo0?ooo`1S
0?ooo`030:0Pl03oool0oooo00<0oooo00<0003o0?ooo`3oool0<03oool00`2P8?00oooo0?ooo`0i
0?ooo`008P3oool00`000000oooo0?ooo`0_0?ooo`030:0Pl03oool0oooo02l0oooo00<0003o0?oo
o`3oool01@3oool00`2P8?00oooo0?ooo`1Q0?ooo`030:0Pl03oool0oooo00D0oooo00<0003o0?oo
o`3oool0;`3oool00`2P8?00oooo0?ooo`0i0?ooo`008P3oool200000300oooo00<0X23`0?ooo`3o
ool0;`3oool00`000?l0oooo0?ooo`050?ooo`030:0Pl03oool0oooo0640oooo00<0X23`0?ooo`3o
ool01@3oool00`000?l0oooo0?ooo`0_0?ooo`030:0Pl03oool0oooo03T0oooo000R0?ooo`030000
003oool0oooo02h0oooo00<0X23`0?ooo`3oool0;`3oool00`000?l0oooo0?ooo`060?ooo`030:0P
l03oool0oooo0640oooo00<0X23`0?ooo`3oool01P3oool00`000?l0oooo0?ooo`0_0?ooo`030:0P
l03oool0oooo03P0oooo000R0?ooo`030000003oool0oooo02h0oooo00<0X23`0?ooo`3oool0;`3o
ool00`000?l0oooo0?ooo`060?ooo`030:0Pl03oool0oooo0600oooo00<0X23`0?ooo`3oool01`3o
ool00`000?l0oooo0?ooo`0_0?ooo`030:0Pl03oool0oooo03P0oooo000R0?ooo`030000003oool0
oooo02h0oooo00<0X23`0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`080?ooo`030:0Pl03oool0
oooo05l0oooo00<0X23`0?ooo`3oool0203oool00`000?l0oooo0?ooo`0^0?ooo`030:0Pl03oool0
oooo03P0oooo000R0?ooo`030000003oool0oooo02h0oooo00<0X23`0?ooo`3oool0;P3oool00`00
0?l0oooo0?ooo`080?ooo`030:0Pl03oool0oooo05l0oooo00<0X23`0?ooo`3oool0203oool00`00
0?l0oooo0?ooo`0_0?ooo`030:0Pl03oool0oooo03L0oooo000R0?ooo`030000003oool0oooo02d0
oooo00<0X23`0?ooo`3oool0;P3oool00`000?l0oooo0?ooo`090?ooo`030:0Pl03oool0oooo05l0
oooo00<0X23`0?ooo`3oool02@3oool00`000?l0oooo0?ooo`0^0?ooo`030:0Pl03oool0oooo03L0
oooo000R0?ooo`030000003oool0oooo02d0oooo00<0X23`0?ooo`3oool0;P3oool00`000?l0oooo
0?ooo`090?ooo`030:0Pl03oool0oooo05h0oooo00<0X23`0?ooo`3oool02P3oool00`000?l0oooo
0?ooo`0^0?ooo`030:0Pl03oool0oooo03L0oooo000R0?ooo`030000003oool0oooo02d0oooo00<0
X23`0?ooo`3oool0;@3oool00`000?l0oooo0?ooo`0;0?ooo`030:0Pl03oool0oooo05d0oooo00<0
X23`0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0]0?ooo`030:0Pl03oool0oooo03L0oooo000R
0?ooo`030000003oool0oooo02d0oooo00<0X23`0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0<
0?ooo`030:0Pl03oool0oooo05d0oooo00<0X23`0?ooo`3oool02`3oool00`000?l0oooo0?ooo`0^
0?ooo`030:0Pl03oool0oooo03H0oooo000R0?ooo`800000;@3oool00`2P8?00oooo0?ooo`0]0?oo
o`030000o`3oool0oooo00`0oooo00<0X23`0?ooo`3oool0G@3oool00`2P8?00oooo0?ooo`0<0?oo
o`030000o`3oool0oooo02d0oooo00<0X23`0?ooo`3oool0=P3oool00280oooo00<000000?ooo`3o
ool0;03oool00`2P8?00oooo0?ooo`0/0?ooo`030000o`3oool0oooo00h0oooo00<0X23`0?ooo`3o
ool0F`3oool00`2P8?00oooo0?ooo`0>0?ooo`030000o`3oool0oooo02`0oooo00<0X23`0?ooo`3o
ool0=P3oool00280oooo00<000000?ooo`3oool0;03oool00`2P8?00oooo0?ooo`0/0?ooo`030000
o`3oool0oooo00h0oooo00<0X23`0?ooo`3oool0F`3oool00`2P8?00oooo0?ooo`0>0?ooo`030000
o`3oool0oooo02`0oooo00<0X23`0?ooo`3oool0=P3oool00280oooo00<000000?ooo`3oool0:`3o
ool00`2P8?00oooo0?ooo`0/0?ooo`030000o`3oool0oooo00l0oooo00<0X23`0?ooo`3oool0F`3o
ool00`2P8?00oooo0?ooo`0?0?ooo`030000o`3oool0oooo02`0oooo00<0X23`0?ooo`3oool0=@3o
ool00280oooo00<000000?ooo`3oool0:`3oool00`2P8?00oooo0?ooo`0/0?ooo`030000o`3oool0
oooo00l0oooo00<0X23`0?ooo`3oool0F`3oool00`2P8?00oooo0?ooo`0?0?ooo`030000o`3oool0
oooo02`0oooo00<0X23`0?ooo`3oool0=@3oool00280oooo00<000000?ooo`3oool0:`3oool00`2P
8?00oooo0?ooo`0[0?ooo`030000o`3oool0oooo0140oooo00<0X23`0?ooo`3oool0F@3oool00`2P
8?00oooo0?ooo`0A0?ooo`030000o`3oool0oooo02/0oooo00<0X23`0?ooo`3oool0=@3oool00280
oooo00<000000?ooo`3oool0:`3oool00`2P8?00oooo0?ooo`0[0?ooo`030000o`3oool0oooo0140
oooo00<0X23`0?ooo`3oool0F@3oool00`2P8?00oooo0?ooo`0A0?ooo`030000o`3oool0oooo02`0
oooo00<0X23`0?ooo`3oool0=03oool00280oooo00<000000?ooo`3oool0:P3oool00`2P8?00oooo
0?ooo`0[0?ooo`030000o`3oool0oooo0180oooo00<0X23`0?ooo`3oool0F@3oool00`2P8?00oooo
0?ooo`0B0?ooo`030000o`3oool0oooo02/0oooo00<0X23`0?ooo`3oool0=03oool00280oooo00<0
00000?ooo`3oool0:P3oool00`2P8?00oooo0?ooo`0[0?ooo`030000o`3oool0oooo0180oooo00<0
X23`0?ooo`3oool0F03oool00`2P8?00oooo0?ooo`0C0?ooo`030000o`3oool0oooo02/0oooo00<0
X23`0?ooo`3oool0=03oool00280oooo00<000000?ooo`3oool0:P3oool00`2P8?00oooo0?ooo`0Z
0?ooo`030000o`3oool0oooo01@0oooo00<0X23`0?ooo`3oool0E`3oool00`2P8?00oooo0?ooo`0D
0?ooo`030000o`3oool0oooo02X0oooo00<0X23`0?ooo`3oool0=03oool00280oooo0P00000Z0?oo
o`030:0Pl03oool0oooo02/0oooo00<0003o0?ooo`3oool0503oool00`2P8?00oooo0?ooo`1G0?oo
o`030:0Pl03oool0oooo01D0oooo00<0003o0?ooo`3oool0:P3oool00`2P8?00oooo0?ooo`0c0?oo
o`008P3oool00`000000oooo0?ooo`0Y0?ooo`030:0Pl03oool0oooo02X0oooo00<0003o0?ooo`3o
ool05@3oool00`2P8?00oooo0?ooo`1G0?ooo`030:0Pl03oool0oooo01D0oooo00<0003o0?ooo`3o
ool0:P3oool00`2P8?00oooo0?ooo`0c0?ooo`008P3oool00`000000oooo0?ooo`0Y0?ooo`030:0P
l03oool0oooo02X0oooo00<0003o0?ooo`3oool05P3oool00`2P8?00oooo0?ooo`1E0?ooo`030:0P
l03oool0oooo01L0oooo00<0003o0?ooo`3oool0:@3oool00`2P8?00oooo0?ooo`0c0?ooo`008P3o
ool00`000000oooo0?ooo`0Y0?ooo`030:0Pl03oool0oooo02T0oooo00<0003o0?ooo`3oool05`3o
ool00`2P8?00oooo0?ooo`1E0?ooo`030:0Pl03oool0oooo01L0oooo00<0003o0?ooo`3oool0:@3o
ool00`2P8?00oooo0?ooo`0c0?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`030:0Pl03oool0
oooo02X0oooo00<0003o0?ooo`3oool05`3oool00`2P8?00oooo0?ooo`1E0?ooo`030:0Pl03oool0
oooo01P0oooo00<0003o0?ooo`3oool0:@3oool00`2P8?00oooo0?ooo`0b0?ooo`008P3oool00`00
0000oooo0?ooo`0X0?ooo`030:0Pl03oool0oooo02T0oooo00<0003o0?ooo`3oool0603oool00`2P
8?00oooo0?ooo`1E0?ooo`030:0Pl03oool0oooo01P0oooo00<0003o0?ooo`3oool0:@3oool00`2P
8?00oooo0?ooo`0b0?ooo`008P3oool00`000000oooo0?ooo`0X0?ooo`030:0Pl03oool0oooo02T0
oooo00<0003o0?ooo`3oool06@3oool00`2P8?00oooo0?ooo`1C0?ooo`030:0Pl03oool0oooo01X0
oooo00<0003o0?ooo`3oool0:03oool00`2P8?00oooo0?ooo`0b0?ooo`008P3oool00`000000oooo
0?ooo`0W0?ooo`030:0Pl03oool0oooo00L0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`80
8R8R103oool5000000d0oooo00<0003o0?ooo`3oool06P3oool01@2P8?00<c<c0000000c<c<0k^k^
00D0oooo0P0R8R860?ooo`80000000<04A4A0?ooo`3oool0:@3oool01@3^k^h0<c<c0000000c<c<0
k^k^00D0oooo0P0R8R840?ooo`070>k^kP0c<c<00000014A4@3<c<`0oooo0:0Pl00L0?ooo`030000
o`3oool0oooo00T0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R103oool01@3<c<`0
8R8R0000000R8R80c<c<00/0oooo00<0X23`0?ooo`3oool09P3oool400000003014A4@3oool0oooo
00@0oooo000R0?ooo`030000003oool0oooo02L0oooo00<0X23`0?ooo`3oool01`3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0303oool0
0`000?l0oooo0?ooo`0K0?ooo`050:0Pl02IVIT0oooo09VIV@1gMgL01@3oool2028R8PL0oooo00<0
00000?ooo`3oool0:P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R840?ooo`0705EE
E@1gMgL0oooo09VIV@0R8R80oooo0:0Pl00M0?ooo`030000o`3oool0oooo00P0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`050?ooo`808R8R103oool01@0R8R80VIVI0?ooo`2IVIT08R8R00/0oooo00<0
X23`0?ooo`3oool0:03oool00`000000oooo0?ooo`060?ooo`008P3oool00`000000oooo0?ooo`0W
0?ooo`030:0Pl03oool0oooo00L0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`0309VIV@0R
8R80k^k^00d0oooo00<0003o0?ooo`3oool06`3oool01@2P8?00oooo0?ooo`3oool04A4A00/0oooo
1@00000[0?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01`000000oooo0?ooo`3oool00000
0?ooo`2P8?007P3oool00`000?l0oooo0?ooo`070?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3o
ool01@000000oooo0?ooo`3oool0000000/0oooo00<0X23`0?ooo`3oool0:03oool00`000000oooo
0?ooo`060?ooo`008P3oool2000002P0oooo00<0X23`0?ooo`3oool01`3oool01@000000oooo0?oo
o`3oool0000000d0oooo00<0VIVI028R8P3^k^h02`3oool00`000?l0oooo0?ooo`0L0?ooo`050000
002P8?00oooo0?ooo`0000002`3oool01014A4@0gMgM0?ooo`00000/0?ooo`050000003oool0oooo
0?ooo`0000002`3oool01P000000VIVI0?ooo`2IVIT08R8R0:0Pl1l0oooo00<0003o0?ooo`3oool0
1`3oool01@000000oooo0?ooo`3oool0000000/0oooo00D0<c<c09VIV@3oool0VIVI03<c<`0;0?oo
o`030:0Pl03oool0oooo02P0oooo00<000000?ooo`3oool01P3oool00280oooo00<000000?ooo`3o
ool09P3oool00`2P8?00oooo0?ooo`080?ooo`050000003oool0oooo0?ooo`0000003P3oool00`1g
MgL0IVIV0?ooo`0:0?ooo`030000o`3oool0oooo01`0oooo00D000000:0Pl03oool0oooo0000000;
0?ooo`040=gMg@1EEED0oooo000002`0oooo00D000000?ooo`3oool0oooo0000000;0?ooo`060000
001EEED00000014A4@3<c<`0X23`803oool00`000?l0oooo0?ooo`060?ooo`050000003oool0oooo
0?ooo`0000002`3oool01@3<c<`00000000000000000c<c<00`0oooo00<0X23`0?ooo`3oool09`3o
ool00`000000oooo0?ooo`060?ooo`008P3oool00`000000oooo0?ooo`0V0?ooo`030:0Pl03oool0
oooo00P0oooo00D04A4A0?ooo`3oool0oooo014A4@0?0?ooo`030000003oool0oooo00P0oooo00<0
003o0?ooo`3oool07@3oool01@0A4A40X23`0?ooo`3oool04A4A00`0oooo00<0MgMg0<c<c0000000
;03oool01@0A4A40oooo0?ooo`3oool04A4A00/0oooo00<0EEEE08R8R03oool00P3oool00`2P8?00
oooo0?ooo`0N0?ooo`030000o`3oool0oooo00H0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?oo
o`05014A4@2k^k/0oooo0;^k^`0A4A40303oool00`2P8?00oooo0?ooo`0W0?ooo`030000003oool0
oooo00H0oooo000R0?ooo`030000003oool0oooo02H0oooo00<0X23`0?ooo`3oool0203oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00D000000;^k^`3oool0VIVI014A4@0:0?ooo`030000o`3o
ool0oooo01d0oooo00D0MgMg09VIV@2P8?00VIVI07MgM`0<0?ooo`030>k^kP14A4@0000002`0oooo
00D0MgMg09VIV@3oool0VIVI07MgM`0;0?ooo`030=gMg@0A4A40VIVI0080oooo00<0X23`0?ooo`3o
ool07`3oool00`000?l0oooo0?ooo`050?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02`3oool01@00
0000^k^k0?ooo`2k^k/0000000`0oooo00<0X23`0?ooo`3oool09`3oool00`000000oooo0?ooo`06
0?ooo`008P3oool00`000000oooo0?ooo`0V0?ooo`030:0Pl03oool0oooo00P0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0;0?ooo`0509VIV@0A4A400000028R8P3<c<`02@3oool00`000?l0oooo0?oo
o`0N0?ooo`050>k^kP0c<c<0X23`03<c<`3^k^h03@3oool00`1gMgL000000?ooo`0[0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h0303oool0103<c<`0A4A40000002P8?0R0?ooo`030000o`3oool0oooo
00D0oooo00D0k^k^03<c<`000000<c<c0>k^kP0;0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0303o
ool00`2P8?00oooo0?ooo`0U0?ooo`80EEEE00<000000?ooo`3oool01P3oool00280oooo00<00000
0?ooo`3oool09@3oool00`2P8?00oooo0?ooo`0W0?ooo`030000o`3oool0oooo0200oooo00<0X23`
0?ooo`3oool0C`3oool00`2P8?00oooo0?ooo`0Q0?ooo`030000o`3oool0oooo02H0oooo00<0X23`
0?ooo`3oool0;`3oool00280oooo00<000000?ooo`3oool09@3oool00`2P8?00oooo0?ooo`0V0?oo
o`030000o`3oool0oooo0240oooo00<0X23`0?ooo`3oool0C`3oool00`2P8?00oooo0?ooo`0Q0?oo
o`030000o`3oool0oooo02H0oooo00<0X23`0?ooo`3oool0;`3oool00280oooo00<000000?ooo`3o
ool09@3oool00`2P8?00oooo0?ooo`0V0?ooo`030000o`3oool0oooo0280oooo00<0X23`0?ooo`3o
ool0C@3oool00`2P8?00oooo0?ooo`0S0?ooo`030000o`3oool0oooo02D0oooo00<0X23`0?ooo`3o
ool0;`3oool00280oooo00<000000?ooo`3oool0903oool00`2P8?00oooo0?ooo`0V0?ooo`030000
o`3oool0oooo02<0oooo00<0X23`0?ooo`3oool0C@3oool00`2P8?00oooo0?ooo`0T0?ooo`030000
o`3oool0oooo02D0oooo00<0X23`0?ooo`3oool0;P3oool00280oooo00<000000?ooo`3oool0903o
ool00`2P8?00oooo0?ooo`0V0?ooo`030000o`3oool0oooo02<0oooo00<0X23`0?ooo`3oool0C@3o
ool00`2P8?00oooo0?ooo`0T0?ooo`030000o`3oool0oooo02D0oooo00<0X23`0?ooo`3oool0;P3o
ool001X0oooo;`0000000`2P8?0000000000000U000000030000o`000000000002@0000000<0X23`
000000000000C@0000000`2P8?0000000000000U000000030000o`000000000002@0000000<0X23`
000000000000;P0000000280oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo00D0oooo00<0X23`0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<0003o0?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00D0oooo00<0X23`0?ooo`3oool0103oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00@0oooo00<0X23`0?ooo`3oool01P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00`0oooo00<000000000o`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00D0oooo00<0X23`0?ooo`3oool01@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00280oooo00<000000?ooo`3o
ool08`3oool00`2P8?00oooo0?ooo`0F0?ooo`030000003oool0oooo00`0oooo00<0003o0?ooo`3o
ool09P3oool00`2P8?00oooo0?ooo`040?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3o
ool0103oool00`2P8?00oooo0?ooo`0W0?ooo`030000o`3oool0oooo00/0oooo00<000000?ooo`3o
ool05P3oool00`2P8?00oooo0?ooo`0T0?ooo`030000003oool0oooo00H0oooo000R0?ooo`030000
003oool0oooo02<0oooo00<0X23`0?ooo`3oool09@3oool00`000?l0oooo0?ooo`0V0?ooo`030:0P
l03oool0oooo04/0oooo00<0X23`0?ooo`3oool09`3oool00`000?l0oooo0?ooo`0T0?ooo`030:0P
l03oool0oooo02d0oooo000R0?ooo`030000003oool0oooo02<0oooo00<0X23`0?ooo`3oool0903o
ool00`000?l0oooo0?ooo`0X0?ooo`030:0Pl03oool0oooo04X0oooo00<0X23`0?ooo`3oool0:03o
ool00`000?l0oooo0?ooo`0S0?ooo`030:0Pl03oool0oooo02d0oooo000R0?ooo`030000003oool0
oooo02<0oooo00<0X23`0?ooo`3oool0903oool00`000?l0oooo0?ooo`0X0?ooo`030:0Pl03oool0
oooo04T0oooo00<0X23`0?ooo`3oool0:@3oool00`000?l0oooo0?ooo`0S0?ooo`030:0Pl03oool0
oooo02d0oooo000R0?ooo`030000003oool0oooo0280oooo00<0X23`0?ooo`3oool0903oool00`00
0?l0oooo0?ooo`0Y0?ooo`030:0Pl03oool0oooo04T0oooo00<0X23`0?ooo`3oool0:P3oool00`00
0?l0oooo0?ooo`0S0?ooo`030:0Pl03oool0oooo02`0oooo000R0?ooo`030000003oool0oooo0280
oooo00<0X23`0?ooo`3oool0903oool00`000?l0oooo0?ooo`0Y0?ooo`030:0Pl03oool0oooo04T0
oooo00<0X23`0?ooo`3oool0:P3oool00`000?l0oooo0?ooo`0S0?ooo`030:0Pl03oool0oooo02`0
oooo000R0?ooo`030000003oool0oooo0280oooo00<0X23`0?ooo`3oool08`3oool00`000?l0oooo
0?ooo`0[0?ooo`030:0Pl03oool0oooo04L0oooo00<0X23`0?ooo`3oool0;03oool00`000?l0oooo
0?ooo`0R0?ooo`030:0Pl03oool0oooo02`0oooo000R0?ooo`030000003oool0oooo0280oooo00<0
X23`0?ooo`3oool08`3oool00`000?l0oooo0?ooo`0[0?ooo`030:0Pl03oool0oooo04L0oooo00<0
X23`0?ooo`3oool0;03oool00`000?l0oooo0?ooo`0R0?ooo`030:0Pl03oool0oooo02`0oooo000R
0?ooo`8000008P3oool00`2P8?00oooo0?ooo`0S0?ooo`030000o`3oool0oooo02`0oooo00<0X23`
0?ooo`3oool0A`3oool00`2P8?00oooo0?ooo`0]0?ooo`030000o`3oool0oooo0280oooo00<0X23`
0?ooo`3oool0:`3oool00280oooo00<000000?ooo`3oool08@3oool00`2P8?00oooo0?ooo`0S0?oo
o`030000o`3oool0oooo02`0oooo00<0X23`0?ooo`3oool0A`3oool00`2P8?00oooo0?ooo`0]0?oo
o`030000o`3oool0oooo0280oooo00<0X23`0?ooo`3oool0:`3oool00280oooo00<000000?ooo`3o
ool08@3oool00`2P8?00oooo0?ooo`0R0?ooo`030000o`3oool0oooo02h0oooo00<0X23`0?ooo`3o
ool0A@3oool00`2P8?00oooo0?ooo`0_0?ooo`030000o`3oool0oooo0240oooo00<0X23`0?ooo`3o
ool0:`3oool00280oooo00<000000?ooo`3oool08@3oool00`2P8?00oooo0?ooo`0Q0?ooo`030000
o`3oool0oooo02l0oooo00<0X23`0?ooo`3oool0A@3oool00`2P8?00oooo0?ooo`0_0?ooo`030000
o`3oool0oooo0280oooo00<0X23`0?ooo`3oool0:P3oool00280oooo00<000000?ooo`3oool0803o
ool00`2P8?00oooo0?ooo`0R0?ooo`030000o`3oool0oooo02l0oooo00<0X23`0?ooo`3oool0A@3o
ool00`2P8?00oooo0?ooo`0_0?ooo`030000o`3oool0oooo0280oooo00<0X23`0?ooo`3oool0:P3o
ool00280oooo00<000000?ooo`3oool0803oool00`2P8?00oooo0?ooo`0Q0?ooo`030000o`3oool0
oooo0340oooo00<0X23`0?ooo`3oool0@`3oool00`2P8?00oooo0?ooo`0a0?ooo`030000o`3oool0
oooo0240oooo00<0X23`0?ooo`3oool0:P3oool00280oooo00<000000?ooo`3oool0803oool00`2P
8?00oooo0?ooo`0Q0?ooo`030000o`3oool0oooo0340oooo00<0X23`0?ooo`3oool0@`3oool00`2P
8?00oooo0?ooo`0a0?ooo`030000o`3oool0oooo0240oooo00<0X23`0?ooo`3oool0:P3oool00280
oooo00<000000?ooo`3oool0803oool00`2P8?00oooo0?ooo`0P0?ooo`030000o`3oool0oooo0380
oooo00<0X23`0?ooo`3oool0@`3oool00`2P8?00oooo0?ooo`0b0?ooo`030000o`3oool0oooo0240
oooo00<0X23`0?ooo`3oool0:@3oool00280oooo00<000000?ooo`3oool07`3oool00`2P8?00oooo
0?ooo`0Q0?ooo`030000o`3oool0oooo0380oooo00<0X23`0?ooo`3oool0@`3oool00`2P8?00oooo
0?ooo`0b0?ooo`030000o`3oool0oooo0240oooo00<0X23`0?ooo`3oool0:@3oool00280oooo0P00
000P0?ooo`030:0Pl03oool0oooo0200oooo00<0003o0?ooo`3oool0=03oool00`2P8?00oooo0?oo
o`110?ooo`030:0Pl03oool0oooo03@0oooo00<0003o0?ooo`3oool0803oool00`2P8?00oooo0?oo
o`0Y0?ooo`008P3oool00`000000oooo0?ooo`0O0?ooo`030:0Pl03oool0oooo0200oooo00<0003o
0?ooo`3oool0=03oool00`2P8?00oooo0?ooo`110?ooo`030:0Pl03oool0oooo03@0oooo00<0003o
0?ooo`3oool0803oool00`2P8?00oooo0?ooo`0Y0?ooo`008P3oool00`000000oooo0?ooo`0O0?oo
o`030:0Pl03oool0oooo01l0oooo00<0003o0?ooo`3oool0=@3oool00`2P8?00oooo0?ooo`110?oo
o`030:0Pl03oool0oooo03D0oooo00<0003o0?ooo`3oool0803oool00`2P8?00oooo0?ooo`0X0?oo
o`008P3oool00`000000oooo0?ooo`0N0?ooo`030:0Pl03oool0oooo0200oooo00<0003o0?ooo`3o
ool0=P3oool00`2P8?00oooo0?ooo`100?ooo`030:0Pl03oool0oooo03D0oooo00<0003o0?ooo`3o
ool0803oool00`2P8?00oooo0?ooo`0X0?ooo`008P3oool00`000000oooo0?ooo`0N0?ooo`030:0P
l03oool0oooo01l0oooo00<0003o0?ooo`3oool0=`3oool00`2P8?00oooo0?ooo`0o0?ooo`030:0P
l03oool0oooo03L0oooo00<0003o0?ooo`3oool07`3oool00`2P8?00oooo0?ooo`0X0?ooo`008P3o
ool00`000000oooo0?ooo`0N0?ooo`030:0Pl03oool0oooo01l0oooo00<0003o0?ooo`3oool0=`3o
ool00`2P8?00oooo0?ooo`0o0?ooo`030:0Pl03oool0oooo03L0oooo00<0003o0?ooo`3oool07`3o
ool00`2P8?00oooo0?ooo`0X0?ooo`008P3oool00`000000oooo0?ooo`0N0?ooo`030:0Pl03oool0
oooo01h0oooo00<0003o0?ooo`3oool0>03oool00`2P8?00oooo0?ooo`0o0?ooo`030:0Pl03oool0
oooo03P0oooo00<0003o0?ooo`3oool07`3oool00`2P8?00oooo0?ooo`0W0?ooo`008P3oool00`00
0000oooo0?ooo`0M0?ooo`030:0Pl03oool0oooo01l0oooo00<0003o0?ooo`3oool0>@3oool00`2P
8?00oooo0?ooo`0m0?ooo`030:0Pl03oool0oooo03T0oooo00<0003o0?ooo`3oool07`3oool00`2P
8?00oooo0?ooo`0W0?ooo`008P3oool00`000000oooo0?ooo`0M0?ooo`030:0Pl03oool0oooo01h0
oooo00<0003o0?ooo`3oool0>P3oool00`2P8?00oooo0?ooo`0m0?ooo`030:0Pl03oool0oooo03X0
oooo00<0003o0?ooo`3oool07P3oool00`2P8?00oooo0?ooo`0W0?ooo`008P3oool00`000000oooo
0?ooo`0M0?ooo`030:0Pl03oool0oooo01h0oooo00<0003o0?ooo`3oool0>P3oool00`2P8?00oooo
0?ooo`0m0?ooo`030:0Pl03oool0oooo03X0oooo00<0003o0?ooo`3oool07P3oool00`2P8?00oooo
0?ooo`0W0?ooo`008P3oool2000001h0oooo00<0X23`0?ooo`3oool07@3oool00`000?l0oooo0?oo
o`0k0?ooo`030:0Pl03oool0oooo03d0oooo00<0X23`0?ooo`3oool0>`3oool00`000?l0oooo0?oo
o`0N0?ooo`030:0Pl03oool0oooo02H0oooo000R0?ooo`030000003oool0oooo01`0oooo00<0X23`
0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0m0?ooo`030:0Pl03oool0oooo03/0oooo00<0X23`
0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0M0?ooo`030:0Pl03oool0oooo02H0oooo000R0?oo
o`030000003oool0oooo01`0oooo00<0X23`0?ooo`3oool07@3oool00`000?l0oooo0?ooo`0m0?oo
o`030:0Pl03oool0oooo03/0oooo00<0X23`0?ooo`3oool0?@3oool00`000?l0oooo0?ooo`0M0?oo
o`030:0Pl03oool0oooo02H0oooo000R0?ooo`030000003oool0oooo01`0oooo00<0X23`0?ooo`3o
ool0703oool00`000?l0oooo0?ooo`0n0?ooo`030:0Pl03oool0oooo03/0oooo00<0X23`0?ooo`3o
ool0?P3oool00`000?l0oooo0?ooo`0L0?ooo`030:0Pl03oool0oooo02H0oooo000R0?ooo`030000
003oool0oooo01`0oooo00<0X23`0?ooo`3oool0703oool00`000?l0oooo0?ooo`0o0?ooo`030:0P
l03oool0oooo03T0oooo00<0X23`0?ooo`3oool0?`3oool00`000?l0oooo0?ooo`0M0?ooo`030:0P
l03oool0oooo02D0oooo000R0?ooo`030000003oool0oooo01/0oooo00<0X23`0?ooo`3oool0703o
ool00`000?l0oooo0?ooo`100?ooo`030:0Pl03oool0oooo03T0oooo00<0X23`0?ooo`3oool0@03o
ool00`000?l0oooo0?ooo`0L0?ooo`030:0Pl03oool0oooo02D0oooo000R0?ooo`030000003oool0
oooo01/0oooo00<0X23`0?ooo`3oool06`3oool00`000?l0oooo0?ooo`110?ooo`030:0Pl03oool0
oooo03T0oooo00<0X23`0?ooo`3oool0@@3oool00`000?l0oooo0?ooo`0K0?ooo`030:0Pl03oool0
oooo02D0oooo000R0?ooo`030000003oool0oooo01/0oooo00<0X23`0?ooo`3oool06`3oool00`00
0?l0oooo0?ooo`110?ooo`030:0Pl03oool0oooo03T0oooo00<0X23`0?ooo`3oool0@@3oool00`00
0?l0oooo0?ooo`0K0?ooo`030:0Pl03oool0oooo02D0oooo000R0?ooo`030000003oool0oooo01/0
oooo00<0X23`0?ooo`3oool06P3oool00`000?l0oooo0?ooo`130?ooo`030:0Pl03oool0oooo03L0
oooo00<0X23`0?ooo`3oool0@`3oool00`000?l0oooo0?ooo`0K0?ooo`030:0Pl03oool0oooo02@0
oooo000R0?ooo`030000003oool0oooo01X0oooo00<0X23`0?ooo`3oool06`3oool00`000?l0oooo
0?ooo`130?ooo`030:0Pl03oool0oooo03L0oooo00<0X23`0?ooo`3oool0@`3oool00`000?l0oooo
0?ooo`0K0?ooo`030:0Pl03oool0oooo02@0oooo000R0?ooo`8000006`3oool00`2P8?00oooo0?oo
o`0J0?ooo`030000o`3oool0oooo04@0oooo00<0X23`0?ooo`3oool0=`3oool00`2P8?00oooo0?oo
o`140?ooo`030000o`3oool0oooo01X0oooo00<0X23`0?ooo`3oool0903oool00280oooo00<00000
0?ooo`3oool06P3oool00`2P8?00oooo0?ooo`0J0?ooo`030000o`3oool0oooo04@0oooo00<0X23`
0?ooo`3oool0=P3oool00`2P8?00oooo0?ooo`150?ooo`030000o`3oool0oooo01/0oooo00<0X23`
0?ooo`3oool08`3oool00280oooo00<000000?ooo`3oool06P3oool00`2P8?00oooo0?ooo`0I0?oo
o`030000o`3oool0oooo04H0oooo00<0X23`0?ooo`3oool0=@3oool00`2P8?00oooo0?ooo`160?oo
o`030000o`3oool0oooo01X0oooo00<0X23`0?ooo`3oool08`3oool00280oooo00<000000?ooo`3o
ool06@3oool00`2P8?00oooo0?ooo`0I0?ooo`030000o`3oool0oooo04L0oooo00<0X23`0?ooo`3o
ool0=@3oool00`2P8?00oooo0?ooo`170?ooo`030000o`3oool0oooo01T0oooo00<0X23`0?ooo`3o
ool08`3oool00280oooo00<000000?ooo`3oool06@3oool00`2P8?00oooo0?ooo`0I0?ooo`030000
o`3oool0oooo04L0oooo00<0X23`0?ooo`3oool0=@3oool00`2P8?00oooo0?ooo`170?ooo`030000
o`3oool0oooo01T0oooo00<0X23`0?ooo`3oool08`3oool00280oooo00<000000?ooo`3oool06@3o
ool00`2P8?00oooo0?ooo`0H0?ooo`030000o`3oool0oooo04T0oooo00<0X23`0?ooo`3oool0<`3o
ool00`2P8?00oooo0?ooo`190?ooo`030000o`3oool0oooo01T0oooo00<0X23`0?ooo`3oool08P3o
ool00280oooo00<000000?ooo`3oool06@3oool00`2P8?00oooo0?ooo`0H0?ooo`030000o`3oool0
oooo04T0oooo00<0X23`0?ooo`3oool0<`3oool00`2P8?00oooo0?ooo`190?ooo`030000o`3oool0
oooo01T0oooo00<0X23`0?ooo`3oool08P3oool000L0oooo00D0k^k^03<c<`000000<c<c0>k^kP05
0?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0603o
ool00`2P8?00oooo0?ooo`0H0?ooo`030000o`3oool0oooo04X0oooo00<0X23`0?ooo`3oool0<`3o
ool00`2P8?00oooo0?ooo`1:0?ooo`030000o`3oool0oooo01P0oooo00<0X23`0?ooo`3oool08P3o
ool000L0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?oo
o`040?ooo`030000003oool0oooo01P0oooo00<0X23`0?ooo`3oool05`3oool00`000?l0oooo0?oo
o`1;0?ooo`030:0Pl03oool0oooo03<0oooo00<0X23`0?ooo`3oool0B`3oool00`000?l0oooo0?oo
o`0G0?ooo`030:0Pl03oool0oooo0280oooo00070?ooo`05014A4@3oool0oooo0?ooo`0A4A40403o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01P0oooo00<0X23`0?ooo`3oool05`3o
ool00`000?l0oooo0?ooo`1<0?ooo`030:0Pl03oool0oooo0340oooo00<0X23`0?ooo`3oool0C03o
ool00`000?l0oooo0?ooo`0H0?ooo`030:0Pl03oool0oooo0240oooo00070?ooo`050000003oool0
oooo0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`040?ooo`<000005`3oool00`2P8?00oooo0?oo
o`0G0?ooo`030000o`3oool0oooo04d0oooo00<0X23`0?ooo`3oool0<@3oool00`2P8?00oooo0?oo
o`1=0?ooo`030000o`3oool0oooo01L0oooo00<0X23`0?ooo`3oool08@3oool000L0oooo00D00000
0?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo
0?ooo`0G0?ooo`030:0Pl03oool0oooo01L0oooo00<0003o0?ooo`3oool0C@3oool00`2P8?00oooo
0?ooo`0a0?ooo`030:0Pl03oool0oooo04d0oooo00<0003o0?ooo`3oool05`3oool00`2P8?00oooo
0?ooo`0Q0?ooo`001`3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo01H0oooo00<0003o0?ooo`3oool0
C`3oool00`2P8?00oooo0?ooo`0_0?ooo`030:0Pl03oool0oooo04l0oooo00<0003o0?ooo`3oool0
5P3oool00`2P8?00oooo0?ooo`0Q0?ooo`001`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030:0Pl03oool0oooo01H0oooo
00<0003o0?ooo`3oool0D03oool00`2P8?00oooo0?ooo`0_0?ooo`030:0Pl03oool0oooo0500oooo
00<0003o0?ooo`3oool05P3oool00`2P8?00oooo0?ooo`0P0?ooo`001`3oool01@3^k^h0<c<c0000
000c<c<0k^k^00`0oooo100000060?ooo`030000003oool0oooo01H0oooo00<0X23`0?ooo`3oool0
5P3oool00`000?l0oooo0?ooo`1@0?ooo`030:0Pl03oool0oooo02l0oooo00<0X23`0?ooo`3oool0
D03oool00`000?l0oooo0?ooo`0F0?ooo`030:0Pl03oool0oooo0200oooo000R0?ooo`030000003o
ool0oooo01H0oooo00<0X23`0?ooo`3oool05@3oool00`000?l0oooo0?ooo`1B0?ooo`030:0Pl03o
ool0oooo02h0oooo00<0X23`0?ooo`3oool0D@3oool00`000?l0oooo0?ooo`0E0?ooo`030:0Pl03o
ool0oooo0200oooo000R0?ooo`030000003oool0oooo01D0oooo00<0X23`0?ooo`3oool05P3oool0
0`000?l0oooo0?ooo`1B0?ooo`030:0Pl03oool0oooo02d0oooo00<0X23`0?ooo`3oool0D`3oool0
0`000?l0oooo0?ooo`0E0?ooo`030:0Pl03oool0oooo01l0oooo000R0?ooo`030000003oool0oooo
01D0oooo00<0X23`0?ooo`3oool05@3oool00`000?l0oooo0?ooo`1C0?ooo`030:0Pl03oool0oooo
02d0oooo00<0X23`0?ooo`3oool0D`3oool00`000?l0oooo0?ooo`0E0?ooo`030:0Pl03oool0oooo
01l0oooo000R0?ooo`030000003oool0oooo01D0oooo00<0X23`0?ooo`3oool0503oool00`000?l0
oooo0?ooo`1E0?ooo`030:0Pl03oool0oooo02`0oooo00<0X23`0?ooo`3oool0E03oool00`000?l0
oooo0?ooo`0D0?ooo`030:0Pl03oool0oooo01l0oooo000R0?ooo`030000003oool0oooo01@0oooo
00<0X23`0?ooo`3oool05@3oool00`000?l0oooo0?ooo`1E0?ooo`030:0Pl03oool0oooo02/0oooo
00<0X23`0?ooo`3oool0EP3oool00`000?l0oooo0?ooo`0D0?ooo`030:0Pl03oool0oooo01h0oooo
000R0?ooo`8000005@3oool00`2P8?00oooo0?ooo`0D0?ooo`030000o`3oool0oooo05H0oooo00<0
X23`0?ooo`3oool0:`3oool00`2P8?00oooo0?ooo`1F0?ooo`030000o`3oool0oooo01@0oooo00<0
X23`0?ooo`3oool07P3oool00280oooo00<000000?ooo`3oool0503oool00`2P8?00oooo0?ooo`0C
0?ooo`030000o`3oool0oooo05P0oooo00<0X23`0?ooo`3oool0:P3oool00`2P8?00oooo0?ooo`1G
0?ooo`030000o`3oool0oooo01<0oooo00<0X23`0?ooo`3oool07P3oool00280oooo00<000000?oo
o`3oool04`3oool00`2P8?00oooo0?ooo`0D0?ooo`030000o`3oool0oooo05P0oooo00<0X23`0?oo
o`3oool0:@3oool00`2P8?00oooo0?ooo`1H0?ooo`030000o`3oool0oooo01@0oooo00<0X23`0?oo
o`3oool07@3oool00280oooo00<000000?ooo`3oool04`3oool00`2P8?00oooo0?ooo`0C0?ooo`03
0000o`3oool0oooo05T0oooo00<0X23`0?ooo`3oool0:@3oool00`2P8?00oooo0?ooo`1I0?ooo`03
0000o`3oool0oooo01<0oooo00<0X23`0?ooo`3oool07@3oool00280oooo00<000000?ooo`3oool0
4`3oool00`2P8?00oooo0?ooo`0B0?ooo`030000o`3oool0oooo05/0oooo00<0X23`0?ooo`3oool0
:03oool00`2P8?00oooo0?ooo`1J0?ooo`030000o`3oool0oooo0180oooo00<0X23`0?ooo`3oool0
7@3oool00280oooo00<000000?ooo`3oool04P3oool00`2P8?00oooo0?ooo`0C0?ooo`030000o`3o
ool0oooo05/0oooo00<0X23`0?ooo`3oool0:03oool00`2P8?00oooo0?ooo`1J0?ooo`030000o`3o
ool0oooo01<0oooo00<0X23`0?ooo`3oool0703oool00280oooo00<000000?ooo`3oool04P3oool0
0`2P8?00oooo0?ooo`0B0?ooo`030000o`3oool0oooo05`0oooo00<0X23`0?ooo`3oool09`3oool0
0`2P8?00oooo0?ooo`1L0?ooo`030000o`3oool0oooo0180oooo00<0X23`0?ooo`3oool0703oool0
0280oooo00<000000?ooo`3oool04P3oool00`2P8?00oooo0?ooo`0B0?ooo`030000o`3oool0oooo
05d0oooo00<0X23`0?ooo`3oool09P3oool00`2P8?00oooo0?ooo`1M0?ooo`030000o`3oool0oooo
0140oooo00<0X23`0?ooo`3oool0703oool00280oooo00<000000?ooo`3oool04@3oool00`2P8?00
oooo0?ooo`0B0?ooo`030000o`3oool0oooo05h0oooo00<0X23`0?ooo`3oool09P3oool00`2P8?00
oooo0?ooo`1M0?ooo`030000o`3oool0oooo0180oooo00<0X23`0?ooo`3oool06`3oool00280oooo
0P00000B0?ooo`030:0Pl03oool0oooo0140oooo00<0003o0?ooo`3oool0G`3oool00`2P8?00oooo
0?ooo`0U0?ooo`030:0Pl03oool0oooo05l0oooo00<0003o0?ooo`3oool04@3oool00`2P8?00oooo
0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0A0?ooo`030:0Pl03oool0oooo0140oooo00<0
003o0?ooo`3oool0H03oool00`2P8?00oooo0?ooo`0T0?ooo`030:0Pl03oool0oooo0600oooo00<0
003o0?ooo`3oool0403oool00`2P8?00oooo0?ooo`0K0?ooo`008P3oool00`000000oooo0?ooo`0@
0?ooo`030:0Pl03oool0oooo0140oooo00<0003o0?ooo`3oool0H@3oool00`2P8?00oooo0?ooo`0T
0?ooo`030:0Pl03oool0oooo0600oooo00<0003o0?ooo`3oool04@3oool00`2P8?00oooo0?ooo`0J
0?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`030:0Pl03oool0oooo0100oooo00<0003o0?oo
o`3oool0HP3oool00`2P8?00oooo0?ooo`0S0?ooo`030:0Pl03oool0oooo0680oooo00<0003o0?oo
o`3oool0403oool00`2P8?00oooo0?ooo`0J0?ooo`008P3oool00`000000oooo0?ooo`0@0?ooo`03
0:0Pl03oool0oooo00l0oooo00<0003o0?ooo`3oool0I03oool00`2P8?00oooo0?ooo`0R0?ooo`03
0:0Pl03oool0oooo06<0oooo00<0003o0?ooo`3oool0403oool00`2P8?00oooo0?ooo`0I0?ooo`00
8P3oool00`000000oooo0?ooo`0?0?ooo`030:0Pl03oool0oooo00l0oooo00<0003o0?ooo`3oool0
I@3oool00`2P8?00oooo0?ooo`0R0?ooo`030:0Pl03oool0oooo06@0oooo00<0003o0?ooo`3oool0
3`3oool00`2P8?00oooo0?ooo`0I0?ooo`008P3oool00`000000oooo0?ooo`0?0?ooo`030:0Pl03o
ool0oooo00l0oooo00<0003o0?ooo`3oool0I@3oool00`2P8?00oooo0?ooo`0Q0?ooo`030:0Pl03o
ool0oooo06D0oooo00<0003o0?ooo`3oool03`3oool00`2P8?00oooo0?ooo`0I0?ooo`008P3oool0
0`000000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo00l0oooo00<0003o0?ooo`3oool0I`3oool0
0`2P8?00oooo0?ooo`0P0?ooo`030:0Pl03oool0oooo06H0oooo00<0003o0?ooo`3oool03`3oool0
0`2P8?00oooo0?ooo`0H0?ooo`008P3oool00`000000oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo
00h0oooo00<0003o0?ooo`3oool0J03oool00`2P8?00oooo0?ooo`0O0?ooo`030:0Pl03oool0oooo
06P0oooo00<0003o0?ooo`3oool03P3oool00`2P8?00oooo0?ooo`0H0?ooo`008P3oool00`000000
oooo0?ooo`0=0?ooo`030:0Pl03oool0oooo00h0oooo00<0003o0?ooo`3oool0JP3oool00`2P8?00
oooo0?ooo`0N0?ooo`030:0Pl03oool0oooo06T0oooo00<0003o0?ooo`3oool03P3oool00`2P8?00
oooo0?ooo`0G0?ooo`008P3oool2000000h0oooo00<0X23`0?ooo`3oool03@3oool00`000?l0oooo
0?ooo`1[0?ooo`030:0Pl03oool0oooo01h0oooo00<0X23`0?ooo`3oool0J@3oool00`000?l0oooo
0?ooo`0>0?ooo`030:0Pl03oool0oooo01L0oooo000R0?ooo`030000003oool0oooo00d0oooo00<0
X23`0?ooo`3oool0303oool00`000?l0oooo0?ooo`1/0?ooo`030:0Pl03oool0oooo01d0oooo00<0
X23`0?ooo`3oool0J`3oool00`000?l0oooo0?ooo`0>0?ooo`030:0Pl03oool0oooo01H0oooo000R
0?ooo`030000003oool0oooo00`0oooo00<0X23`0?ooo`3oool03@3oool00`000?l0oooo0?ooo`1]
0?ooo`030:0Pl03oool0oooo01`0oooo00<0X23`0?ooo`3oool0K03oool00`000?l0oooo0?ooo`0=
0?ooo`030:0Pl03oool0oooo01H0oooo000R0?ooo`030000003oool0oooo00`0oooo00<0X23`0?oo
o`3oool0303oool00`000?l0oooo0?ooo`1^0?ooo`030:0Pl03oool0oooo01/0oooo00<0X23`0?oo
o`3oool0KP3oool00`000?l0oooo0?ooo`0=0?ooo`030:0Pl03oool0oooo01D0oooo000R0?ooo`03
0000003oool0oooo00/0oooo00<0X23`0?ooo`3oool0303oool00`000?l0oooo0?ooo`1_0?ooo`03
0:0Pl03oool0oooo01/0oooo00<0X23`0?ooo`3oool0K`3oool00`000?l0oooo0?ooo`0<0?ooo`03
0:0Pl03oool0oooo01D0oooo000R0?ooo`030000003oool0oooo00/0oooo00<0X23`0?ooo`3oool0
2`3oool00`000?l0oooo0?ooo`1a0?ooo`030:0Pl03oool0oooo01T0oooo00<0X23`0?ooo`3oool0
L@3oool00`000?l0oooo0?ooo`0;0?ooo`030:0Pl03oool0oooo01D0oooo000R0?ooo`030000003o
ool0oooo00/0oooo00<0X23`0?ooo`3oool02@3oool20000og@0oooo00<0X23`0?ooo`3oool06@3o
ool00`2P8?00oooo0?ooo`1b0?ooo`030000o`3oool0oooo00/0oooo00<0X23`0?ooo`3oool0503o
ool00280oooo00<000000?ooo`3oool02P3oool00`2P8?00oooo0?ooo`090?ooo`030000o`3oool0
oooo07D0oooo00<0X23`0?ooo`3oool05`3oool00`2P8?00oooo0?ooo`1d0?ooo`80003o2`3oool0
0`2P8?00oooo0?ooo`0D0?ooo`008P3oool00`000000oooo0?ooo`0:0?ooo`030:0Pl03oool0oooo
00P0oooo00<0003o0?ooo`3oool0MP3oool00`2P8?00oooo0?ooo`0G0?ooo`030:0Pl03oool0oooo
07H0oooo00<0003o0?ooo`3oool02@3oool00`2P8?00oooo0?ooo`0C0?ooo`008P3oool00`000000
oooo0?ooo`090?ooo`030:0Pl03oool0oooo00L0oooo0P000?mj0?ooo`030:0Pl03oool0oooo01H0
oooo00<0X23`0?ooo`3oool0M`3oool00`000?l0oooo0?ooo`080?ooo`030:0Pl03oool0oooo01<0
oooo000R0?ooo`8000002@3oool00`2P8?00oooo0?ooo`070?ooo`030000o`3oool0oooo07X0oooo
00<0X23`0?ooo`3oool05@3oool00`2P8?00oooo0?ooo`1i0?ooo`030000o`3oool0oooo00P0oooo
00<0X23`0?ooo`3oool04P3oool00280oooo00<000000?ooo`3oool0203oool00`2P8?00oooo0?oo
o`060?ooo`030000o`3oool0oooo07`0oooo00<0X23`0?ooo`3oool0503oool00`2P8?00oooo0?oo
o`1j0?ooo`030000o`3oool0oooo00L0oooo00<0X23`0?ooo`3oool04P3oool00280oooo00<00000
0?ooo`3oool01`3oool00`2P8?00oooo0?ooo`060?ooo`030000o`3oool0oooo07h0oooo00<0X23`
0?ooo`3oool04P3oool00`2P8?00oooo0?ooo`1l0?ooo`030000o`3oool0oooo00L0oooo00<0X23`
0?ooo`3oool04@3oool00280oooo00<000000?ooo`3oool01P3oool00`2P8?00oooo0?ooo`060?oo
o`030000o`3oool0oooo0800oooo00<0X23`0?ooo`3oool0403oool00`2P8?00oooo0?ooo`1n0?oo
o`80003o203oool00`2P8?00oooo0?ooo`0@0?ooo`008P3oool00`000000oooo0?ooo`060?ooo`03
0:0Pl03oool0oooo00D0oooo00<0003o0?ooo`3oool0P@3oool00`2P8?00oooo0?ooo`0?0?ooo`03
0:0Pl03oool0oooo0840oooo0P000?l70?ooo`030:0Pl03oool0oooo00l0oooo000R0?ooo`030000
003oool0oooo00D0oooo00<0X23`0?ooo`3oool0103oool20000ohD0oooo00<0X23`0?ooo`3oool0
3@3oool00`2P8?00oooo0?ooo`240?ooo`80003o1P3oool00`2P8?00oooo0?ooo`0>0?ooo`008P3o
ool00`000000oooo0?ooo`040?ooo`030:0Pl03oool0oooo00@0oooo00<0003o0?ooo`3oool0QP3o
ool00`2P8?00oooo0?ooo`0;0?ooo`030:0Pl03oool0oooo08L0oooo00<0003o0?ooo`3oool0103o
ool00`2P8?00oooo0?ooo`0=0?ooo`00603oool400000003014A4@3oool0oooo00<0oooo00<00000
0?ooo`3oool00P3oool20:0Pl0@0oooo0`000?n:0?ooo`80X23`2`3oool00`2P8?00oooo0?ooo`28
0?ooo`<0003o103oool00`2P8?00oooo0?ooo`0<0?ooo`006P3oool00`000000oooo0?ooo`050?oo
o`050000003oool0oooo0?ooo`2P8?00103oool20000ohl0oooo00<0X23`0?ooo`3oool01P3oool2
0:0Pl8h0oooo0`000?l00`3oool0X23`0:0Pl00=0?ooo`006P3oool00`000000oooo0?ooo`050?oo
o`040000003oool0X23`0:0Pl0D0003oTP3oool20:0Pl0<0oooo0`2P8?2C0?ooo`<0003o0P2P8?0;
0?ooo`006P3oool00`000000oooo0?ooo`050?ooo`80X23`0P000?nH0?l000D0X23`V03o00020000
o`<0X23`203oool001X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?oood@0
oooo000J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooom40?ooo`006P3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA03oool001P0oooo0P1EEED0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0ooooA03oool00280oooo00<000000?oo
o`3oool0o`3ooom40?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "One can see that both ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ 2  \[Pi]\ n\ t/T\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ 2\ \[Pi]\ n\ t/T\)]],
  " become more and more rapidly varying as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases. The more rapidly varying functions will be useful in helping \
describe rapid variation in ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tA general linear combination of these sines and cosines constitute a ",
  StyleBox[ButtonBox["Fourier series",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fourier.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ", and has the form "
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["a",
                FontSize->12], "o"],
            FontSize->11], 
          StyleBox["+",
            FontSize->11], 
          RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity]\), 
            RowBox[{
              StyleBox["(",
                
                FontSize->14], \(\(a\_n\) cos\ 2\ \[Pi]\ n\ t/T + \(b\_n\) 
                  sin\ 2  \[Pi]\ n\ t/T\), 
              StyleBox[")",
                FontSize->14]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where the constants ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  "  are called ",
  StyleBox[" Fourier coefficients",
    FontSlant->"Italic"],
  ". The functions ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ 2\ \[Pi]\ n\ t/T\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ 2  \[Pi]\ n\ t/T\)]],
  " are often referred to as ",
  StyleBox["Fourier modes.",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\tIt is easy to see that the above Fourier series has the correct period \
",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". If we evaluate the series at time ",
  Cell[BoxData[
      \(TraditionalForm\`t + T\)]],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th cosine term is ",
  Cell[BoxData[
      \(TraditionalForm\`cos[
          2\ \[Pi]\ n\ \((t + T)\)/T] = \(cos(
            2  \[Pi]\ n\ t/T\  + \ 2\ \[Pi]\ n) = 
          cos\ 2  \[Pi]\ n\ \(\(t/T\)\(\ \)\)\)\)]],
  ", where in the last step we have used the fact that cosine functions have \
period 2\[Pi]. Thus, the cosine series at time ",
  Cell[BoxData[
      \(TraditionalForm\`t + T\)]],
  " returns to the form it had at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  A similar argument shows that the sine series evaluated at time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(+\)\(T\)\(\ \)\)\)]],
  "also returns to its  form at time ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(.\)\)\)]],
  " Therefore, according to Eq. ",
  ButtonBox["(2.1.1)",
    ButtonData:>"(2.1.1)",
    ButtonStyle->"Hyperlink"],
  " the series is periodic with period  ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["\t ",
    FontSlant->"Italic"],
  "The fact that Fourier coefficients can be found that allow this series to \
equal a given periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is a consequence of the following theorem: "
}], "Text"],

Cell[TextData[{
  StyleBox["Theorem 2.1",
    FontWeight->"Bold"],
  "\t\n\tIf a periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is continuous, and its derivative is nowhere infinite and is ",
  StyleBox["sectionally",
    FontSlant->"Italic"],
  " continuous, then it is possible to construct a Fourier series that equals \
",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(.\)\)\)]]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\t A sectionally continuous periodic function is one that is continuous in \
finite-size sections, with either no discontinuities at all or at most a \
finite number of discontinuities in one period of the function. Figure ",
  ButtonBox["2.1",
    ButtonData:>"Fig. 2.1",
    ButtonStyle->"Hyperlink"],
  " is an example of a sectionally continuous periodic function.  We will see \
later in this section what happens to the Fourier representation of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " when ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " violates the restrictions placed on it by Theorem 2.1 . For now, we  \
assume that the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " satisfies the requirements of the theorem, in which case Fourier \
coefficients can be found such that"
}], "Text",
  CellTags->"i:4"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(t)\), " ", "=", 
          RowBox[{
            StyleBox[
              SubscriptBox[
                StyleBox["a",
                  FontSize->12], "o"],
              FontSize->11], 
            StyleBox["+",
              FontSize->11], 
            RowBox[{\(\[Sum]\+\(n = 1\)\%\[Infinity]\), 
              RowBox[{
                StyleBox["(",
                  
                  FontSize->14], \(\(a\_n\) cos\ 2\ \[Pi]\ n\ t/T + \(b\_n\) 
                    sin\ 2  \[Pi]\ n\ t/T\), " ", 
                StyleBox[")",
                  FontSize->14]}], " "}]}]}], TraditionalForm]]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.3)"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.2 Fourier Coefficients and Orthogonality Relations", "Subsubtitle",
  CellTags->"c:4"],

Cell[TextData[{
  "\tWe are now ready to find the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  "  that enter into the Fourier series representation of a given  periodic \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ".  These coefficients can be found by using an important property of the \
sine and cosine functions that appear in Eq. ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  ": the property of ",
  StyleBox["orthogonality",
    FontSlant->"Italic"],
  ". Two real functions ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " are said to be ",
  StyleBox["orthogonal on the interval  ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "if they satisfy "
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( g(t)\) \(h(
              t)\) \[DifferentialD]t = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.4)"],

Cell[TextData[{
  "The sine and cosine Fourier modes in Eq. ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  " have this property of orthogonality on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([t\_o, \ t\_o + T]\)\)]],
  " for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " choice of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(t\_o\),
          FontSize->10], TraditionalForm]]],
  ". That is, for integers ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "  the Fourier modes satisfy"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(sin(
              2  \[Pi]\ n\ t/T)\)\ \(sin(
              2\ \[Pi]\ m\ t/
                  T)\) \[DifferentialD]t = \(\[Integral]\_\(t\_o\)\%\(t\_o + \
T\)\(cos(2  \[Pi]\ n\ t/T)\)\ \(cos(2\ \[Pi]\ m\ t/T)\) \[DifferentialD]t = 
          0\), \ \ \ \ m \[NotEqual] n\)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(sin(
              2  \[Pi]\ n\ t/T)\)\ \(cos(
              2\ \[Pi]\ m\ t/T)\) \[DifferentialD]t = 0. \)]]
}], "NumberedEquation",
  CellTags->"(2.1.5)"],

Cell[TextData[{
  "In the first equations, the restriction ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] n\)]],
  " was applied, because a real function cannot be orthogonal with itself: \
for any real function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " that is nonzero on a finite range within ",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\(\( g\^2\)(
            t)\) \[DifferentialD]t\)]],
  " must be greater than zero. This follows simply because ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^2\)(t) \[GreaterEqual] \ 0\)]],
  ", so there is a finite positive area under the  ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^2\)(t)\)]],
  " curve. For this reason, when  ",
  Cell[BoxData[
      \(TraditionalForm\`m = n\)]],
  "  in Eq. ",
  ButtonBox["(2.1.5)",
    ButtonData:>"(2.1.5)",
    ButtonStyle->"Hyperlink"],
  ",",
  " the first and last integrals return a positive result:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(\(sin\^2\)(
              2  \[Pi]\ n\ t/
                  T)\)\ \[DifferentialD]t = \(\[Integral]\_\(t\_o\)\%\(t\_o + \
T\)\(\(cos\^2\)(2  \[Pi]\ n\ t/T)\)\ \[DifferentialD]t = T/2\), \ \ \ n > 
        0\)]],
  ","
}], "NumberedEquation",
  CellTags->"(2.1.6)"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(\(cos\^2\)(
              2  \[Pi]\ 0\ t/T)\)\ \[DifferentialD]t = T\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.7)"],

Cell[TextData[{
  "The last equation follows because ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ 0 = 1\)]],
  ". The analogous equation for the sine functions, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(\(sin\^2\)(
              2  \[Pi]\ 0\ t/T)\)\ \[DifferentialD]t = 0\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  " is not required, since ",
  Cell[BoxData[
      FormBox[Cell["sin 0 =0"], TraditionalForm]]],
  " is a trivial function that plays no role in our Fourier series.  \
Equations ",
  ButtonBox["(2.1.5)",
    ButtonData:>"(2.1.5)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.6)",
    ButtonData:>"(2.1.6)",
    ButtonStyle->"Hyperlink"],
  " can be proven using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(g\  = \ {Sin, Cos};\)\), "\n", 
    \(Table[
      Table[FullSimplify[
          Integrate[\(g[\([i]\)]\)[2\ Pi\ n\ t/T]\ \(g[\([j]\)]\)[
                2\ Pi\ m\ t/T], {t, t0, t0 + T}], 
          n\  \[NotEqual] \ m\  && \ n \[Element] Integers && 
            m \[Element] Integers], {j, i, 2}], {i, 1, 2}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.3"],

Cell[BoxData[
    \({{0, 0}, {0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We have added an optional argument to ",
  StyleBox["FullSimplify",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a list of logical statements that can be applied to help simplify the \
integral. For instance, one of these statements, ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Element] Integers\)]],
  ", simplifies expressions like ",
  Cell[BoxData[
      \(TraditionalForm\`Sin(n\ \[Pi])\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      FullSimplify[
        Integrate[\(g[\([i]\)]\)[2\ Pi\ n\ t/T]\ ^2, {t, t0, t0 + T}], 
        n \[Element] Integers], {i, 1, 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.4"],

Cell[BoxData[
    \({T\/2, T\/2}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that in the last two integrals, we did not specify that ",
  Cell[BoxData[
      \(TraditionalForm\`n > 0\)]],
  ", yet ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " gave us results assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`n\  \[NotEqual] \ 0\)]],
  ". This is a case where ",
  Cell[BoxData[
      \(TraditionalForm\`Mathematica\)]],
  " has not been sufficiently careful. We also need to be careful: as we can \
see in Eqs. ",
  ButtonBox["(2.1.5)",
    ButtonData:>"(2.1.5)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(2.1.7)",
    ButtonData:>"(2.1.7)",
    ButtonStyle->"Hyperlink"],
  ","
}], "Text"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " Fourier cosine mode is a special case that must be dealt with separately \
from the other modes."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\tThese orthogonality relations can be used to extract the Fourier \
coefficients from  Eq. ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  ". For a given periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", we can determine the coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`a\_m\)]],
  " by multiplying both sides of  Eq. ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ 2\ \[Pi]\ m\ t/T\)]],
  " and integrating over one period, from ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o + T\)]],
  " for some choice of  ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(f(
            t)\)\ cos\ \(\(2\ \[Pi]\ m\ t\)\/T\) \[DifferentialD]t = \[Sum]\+\
\(n = 0\)\%\[Infinity] a\_n\ \(\[Integral]\_\(t\_o\)\%\(t\_o + T\)cos \(\( 
                      2\ \[Pi]\ n\ t\)\/T\) 
                cos \(\( 
                      2\ \[Pi]\ m\ t\)\/T\) \[DifferentialD]t\) + \[Sum]\+\(n \
= 1\)\%\[Infinity] b\_n\ \(\[Integral]\_\(t\_o\)\%\(t\_o + T\)sin \( 2\ \[Pi]\
\ n\ t\)\/T\ cos \(\( 
                      2\ \[Pi]\ m\ t\)\/T\) \
\(\(\[DifferentialD]t\)\(.\)\)\)\)]]], "NumberedEquation",
  CellTags->"(2.1.8)"],

Cell[TextData[{
  " The orthogonality of the sine and cosine Fourier modes, as shown by Eq. \
",
  ButtonBox["(2.1.5)",
    ButtonData:>"(2.1.5)",
    ButtonStyle->"Hyperlink"],
  ", implies that every term in the sum involving ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " vanishes.  In the first sum, only the ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  " term provides a nonzero integral, equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T/2\)\(\ \)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] \ 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`m = 0\)]],
  " according to Eq. ",
  ButtonBox["(2.1.6)",
    ButtonData:>"(2.1.6)",
    ButtonStyle->"Hyperlink"],
  ". Dividing through by these constants, we arrive at "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`a\_o = \(1\/T\) \(\[Integral]\_\(t\_o\)\%\(t\_o + \
T\)\(f(t)\) \[DifferentialD]t\)\)]],
  ",\n\n",
  Cell[BoxData[
      \(TraditionalForm\`a\_m = \(\(\(2\)\(\ \)\)\/T\) \
\(\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(f(
                t)\)\ \(cos(\(2\ \[Pi]\ m\ t\)\/T)\) \[DifferentialD]t\), \ \ \
\ m > 0. \)]]
}], "NumberedEquation",
  CellTags->"(2.1.9)"],

Cell[TextData[{
  "Similarly, the  ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  StyleBox["'s",
    FontSlant->"Italic"],
  " are determined by multiplying both sides of  Eq. ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`sin\ 2\ \[Pi]\ m\ t/T\)]],
  " and integrating from ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o + T\)]],
  " for some choice of  ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ". Now orthogonality  causes all terms involving the ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  StyleBox["'s",
    FontSlant->"Italic"],
  " to vanish, and only the term proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`b\_m\)]],
  " survives. The result is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`b\_m = \(\(\(2\)\(\ \)\)\/T\) \
\(\[Integral]\_\(t\_o\)\%\(t\_o + T\)\(f(
              t)\)\ sin \(\( 
                  2\ \[Pi]\ m\ t\)\/T\) \[DifferentialD]t\), \ \ \ m > 
      0. \)]]], "NumberedEquation",
  CellTags->"(2.1.10)"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.3 Triangle Wave", "Subsubtitle",
  CellTags->"c:5"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["(2.1.9)",
    ButtonData:>"(2.1.9)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(2.1.10)",
    ButtonData:>"(2.1.10)",
    ButtonStyle->"Hyperlink"],
  " provide us with everything we need to determine a Fourier series for a \
given periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". Let's use these equations to construct Fourier series representations \
for some example functions. Our first example will be a triangle wave of \
period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". This function can be created from the following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands, and is shown in Cell ",
  ButtonBox["2.5",
    ButtonData:>"Cell 2.5",
    ButtonStyle->"Hyperlink"],
  " for the case of ",
  Cell[BoxData[
      \(TraditionalForm\`T = 1\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[t_]\  := \ 2  t/T\  /; \ 0 \[LessEqual] \ t < T/2;\)\), "\n", 
    \(\(f[t_]\  := \ 
        2\  - \ 2  t/T\  /; \ T/2\  \[LessEqual] \ t\  < T;\)\), "\n", 
    \(T = 1; \ Plot[f[t], {t, 0, T}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.5"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.589159 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .13255 -18 -4.5 ]
[.01131 .13255 0 4.5 ]
[.01131 .25038 -18 -4.5 ]
[.01131 .25038 0 4.5 ]
[.01131 .36821 -18 -4.5 ]
[.01131 .36821 0 4.5 ]
[.01131 .48604 -18 -4.5 ]
[.01131 .48604 0 4.5 ]
[.01131 .60387 -6 -4.5 ]
[.01131 .60387 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(0.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(0.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(0.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(0.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13255 m
.03006 .13255 L
s
[(0.2)] .01131 .13255 1 0 Mshowa
.02381 .25038 m
.03006 .25038 L
s
[(0.4)] .01131 .25038 1 0 Mshowa
.02381 .36821 m
.03006 .36821 L
s
[(0.6)] .01131 .36821 1 0 Mshowa
.02381 .48604 m
.03006 .48604 L
s
[(0.8)] .01131 .48604 1 0 Mshowa
.02381 .60387 m
.03006 .60387 L
s
[(1)] .01131 .60387 1 0 Mshowa
.125 Mabswid
.02381 .04417 m
.02756 .04417 L
s
.02381 .07363 m
.02756 .07363 L
s
.02381 .10309 m
.02756 .10309 L
s
.02381 .162 m
.02756 .162 L
s
.02381 .19146 m
.02756 .19146 L
s
.02381 .22092 m
.02756 .22092 L
s
.02381 .27984 m
.02756 .27984 L
s
.02381 .30929 m
.02756 .30929 L
s
.02381 .33875 m
.02756 .33875 L
s
.02381 .39767 m
.02756 .39767 L
s
.02381 .42713 m
.02756 .42713 L
s
.02381 .45658 m
.02756 .45658 L
s
.02381 .5155 m
.02756 .5155 L
s
.02381 .54496 m
.02756 .54496 L
s
.02381 .57442 m
.02756 .57442 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .06252 L
.10458 .11465 L
.14415 .16361 L
.18221 .21069 L
.22272 .26081 L
.26171 .30905 L
.30316 .36033 L
.34309 .40973 L
.3815 .45726 L
.42237 .50782 L
.46172 .55651 L
.48147 .58095 L
.49012 .59165 L
.49468 .5973 L
.49719 .6004 L
.49842 .60192 L
.49955 .60332 L
.50085 .60282 L
.50154 .60197 L
.50226 .60108 L
.50471 .59804 L
.5095 .59212 L
.51896 .58041 L
.53984 .55458 L
.57781 .5076 L
.61824 .45759 L
.65714 .40945 L
.6985 .35828 L
.73835 .30898 L
.77668 .26156 L
.81746 .2111 L
.85673 .16252 L
.89448 .11581 L
.93468 .06607 L
.97337 .01821 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00Hgoo0P001goo0`0017oo1P00>7oo0P001goo0`001goo0`00>7oo0P001goo0`00
1Goo1000>7oo0P001goo0`001Goo1000@Goo1@002Goo001ROol01000Oomoo`001Woo0`001Goo00D0
07ooOomoo`0003Moo`04001oogoo0006Ool30008Ool00`00Oomoo`0fOol01000Oomoo`001Woo0`00
17oo00<007ooOol00Woo00<007ooOol0=7oo00@007ooOol000Ioo`<000Aoo`03001oogoo009oo`03
001oogoo041oo`03001oogoo00Uoo`00HGoo00<007ooOol00Woo00<007ooOol00goo0`001Woo00<0
07ooOol0=goo00<007ooOol00Woo00<007ooOol00goo0`0017oo1P00=Woo00<007ooOol00Woo00<0
07ooOol00goo0`0017oo00<007ooOol00Woo00<007ooOol0<goo00<007ooOol00Woo00<007ooOol0
0goo0`0017oo00<007ooOol00Woo00<007ooOol0@7oo00<007ooOol02Goo001QOol00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`0fOol00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo
0000=goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0<goo00<007oo
Ool00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0@7oo00<007ooOol02Goo001QOol0
0`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`0eOol00`00Oomoo`02Ool00`00Oomoo`0;Ool0
1000Oomoo`00=goo00<007ooOol00Woo00<007ooOol02Woo0P000goo00<007ooOol0<goo00<007oo
Ool00Woo00<007ooOol02goo1000@goo00<007ooOol02Goo001QOol00`00Oomoo`02Ool00`00Oomo
o`0?Ool00`00Oomoo`0dOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Ool0000gOol00`00Oomo
o`02Ool00`00Oomoo`0:Ool00`00Ool00002000fOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`02Ool00`00Oomoo`10Ool00`00Oomoo`09Ool0065oo`03001oogoo009oo`03001oogoo00mo
o`03001oogoo03Aoo`03001oogoo009oo`03001oogoo00aoo`03001oo`0003Moo`03001oogoo009o
o`03001oogoo00]oo`03001oogoo03Moo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009o
o`03001oogoo041oo`03001oogoo00Uoo`00HWoo00@007ooOol000eoo`03001oogoo009oo`03001o
ogoo03Eoo`04001oogoo000@Ool2000hOol01000Oomoo`003Woo0P00>Goo00@007ooOol000eoo`03
001oogoo009oo`03001oogoo03ioo`<000]oo`00Hgoo0P003goo1000>Goo0P004Woo00<007ooOol0
=goo0P004Goo0`00=goo0P003goo1000@Woo0P002goo000POol00`00Oomoo`3oOon>Ool0021oo`03
001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03
001oogoo0?moohioo`0087oo00<007ooOol0ogooSWoo000FOooo002J0001Ool0021oo`03001oogoo
011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo
011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo
015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03001oogoo
015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`8000Yoo`00
87oo0P004Goo00<007ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<0
07ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<0
07ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007ooOol047oo00<0
07ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol047oo00<007ooOol03goo00<0
07oo00002Woo000POol00`00Ool0001;Ool00`00Oomoo`1:Ool00`00Oomoo`1;Ool00`00Oomoo`1;
Ool00`00Oomoo`19Ool00`00Ool0000:Ool0021oo`04001oogoo003oOomoOol00`00Oomoo`0;Ool0
021oo`05001oogooOol0003oOommOol00`00Oomoo`0<Ool0021oo`05001oogooOol0003oOomlOol0
0`00Oomoo`0=Ool0021oo`03001oogoo009oo`03001oogoo0?moogQoo`03001oogoo00ioo`0087oo
00<007ooOol00goo00<007ooOol0ogooMgoo00<007ooOol03Woo000POol00`00Oomoo`04Ool00`00
Oomoo`3oOomeOol00`00Oomoo`0?Ool0021oo`03001oogoo00Eoo`03001oogoo0?moog=oo`03001o
ogoo011oo`0087oo00<007ooOol01Goo00<007ooOol0ogooLWoo00<007ooOol04Goo000POol20007
Ool00`00Oomoo`3oOom`Ool00`00Oomoo`0BOol0021oo`03001oogoo00Moo`03001oogoo0?moofmo
o`03001oogoo019oo`0087oo00<007ooOol027oo00<007ooOol0ogooKGoo00<007ooOol04goo000P
Ool00`00Oomoo`09Ool00`00Oomoo`3oOom[Ool00`00Oomoo`0DOol0021oo`03001oogoo00Uoo`03
001oogoo0?moofYoo`03001oogoo01Eoo`0087oo00<007ooOol02Woo00<007ooOol0ogooJGoo00<0
07ooOol05Goo000POol00`00Oomoo`0;Ool00`00Oomoo`3oOomWOol00`00Oomoo`0FOol0021oo`03
001oogoo00aoo`03001oogoo0?moofEoo`03001oogoo01Moo`0087oo00<007ooOol03Goo00<007oo
Ool0ogooHgoo00<007ooOol067oo000POol00`00Oomoo`0=Ool00`00Oomoo`3oOomROol00`00Oomo
o`0IOol0021oo`03001oogoo00ioo`03001oogoo0?moof5oo`03001oogoo01Uoo`0087oo00<007oo
Ool03goo00<007ooOol0ogooGgoo00<007ooOol06Woo000POol2000AOol00`00Oomoo`3oOomMOol0
0`00Oomoo`0KOol0021oo`03001oogoo015oo`03001oogoo0?mooe]oo`03001oogoo01aoo`0087oo
00<007ooOol04Goo00<007ooOol0ogooFWoo00<007ooOol07Goo000POol00`00Oomoo`0BOol00`00
Oomoo`3oOomHOol00`00Oomoo`0NOol0021oo`03001oogoo01=oo`03001oogoo0?mooeIoo`03001o
ogoo01moo`0087oo00<007ooOol057oo00<007ooOol0ogooEGoo00<007ooOol07goo000POol00`00
Oomoo`0EOol00`00Oomoo`3oOomCOol00`00Oomoo`0POol0021oo`03001oogoo01Ioo`03001oogoo
0?mooe5oo`03001oogoo025oo`0087oo00<007ooOol05Woo00<007ooOol0ogooD7oo00<007ooOol0
8Woo000POol00`00Oomoo`0GOol00`00Oomoo`3oOom>Ool00`00Oomoo`0SOol0021oo`03001oogoo
01Qoo`03001oogoo0?moodaoo`03001oogoo02Aoo`0087oo00<007ooOol06Goo00<007ooOol0ogoo
Bgoo00<007ooOol097oo000POol2000KOol00`00Oomoo`3oOom9Ool00`00Oomoo`0UOol0021oo`03
001oogoo01Yoo`03001oogoo0?moodQoo`03001oogoo02Ioo`0087oo00<007ooOol06goo00<007oo
Ool0ogooAWoo00<007ooOol09goo000POol00`00Oomoo`0LOol00`00Oomoo`3oOom4Ool00`00Oomo
o`0XOol0021oo`03001oogoo01eoo`03001oogoo0?mood9oo`03001oogoo02Uoo`0087oo00<007oo
Ool07Woo00<007ooOol0ogoo@7oo00<007ooOol0:Woo000POol00`00Oomoo`0NOol00`00Oomoo`3o
Oom0Ool00`00Oomoo`0ZOol0021oo`03001oogoo01moo`03001oogoo0?moocioo`03001oogoo02]o
o`0087oo00<007ooOol087oo00<007ooOol0ogoo?7oo00<007ooOol0;7oo000POol00`00Oomoo`0Q
Ool00`00Oomoo`3oOoljOol00`00Oomoo`0]Ool000=oo`8000Moo`<000Aoo`H000Moo`03001oogoo
029oo`03001oogoo0?moocUoo`03001oogoo02eoo`000Woo00@007ooOol000Ioo`<000Eoo`05001o
ogooOol00007Ool00`00Oomoo`0ROol00`00Oomoo`3oOolhOol00`00Oomoo`0^Ool00003Ool007oo
00=oo`03001oogoo00=oo`<000Ioo`03001oogoo00Qoo`<002=oo`03001oogoo0?moocIoo`03001o
ogoo02moo`0000=oo`00Ool00goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol097oo00<0
07ooOol0ogoo=7oo00<007ooOol0<7oo00000goo001oo`03Ool00`00Oomoo`0>Ool00`00Oomoo`06
Ool00`00Oomoo`0UOol00`00Oomoo`3oOolcOol00`00Oomoo`0`Ool00003Ool007oo00=oo`03001o
ogoo00moo`03001oogoo00Eoo`03001oogoo02Ioo`03001oogoo0?mooc5oo`03001oogoo035oo`00
00=oo`00Ool00goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol09Woo00<007ooOol0ogoo
<7oo00<007ooOol0<Woo0002Ool01000Oomoo`003Goo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol09goo00<007ooOol0ogoo;Woo00<007ooOol0<goo0003Ool2000?Ool40008Ool00`00Oomo
o`0XOol00`00Oomoo`3oOol]Ool00`00Oomoo`0cOol0021oo`03001oogoo02Uoo`03001oogoo0?mo
ob]oo`03001oogoo03Aoo`0087oo00<007ooOol0:Woo00<007ooOol0ogoo:Goo00<007ooOol0=Goo
000POol00`00Oomoo`0ZOol00`00Oomoo`3oOolXOol00`00Oomoo`0fOol0021oo`03001oogoo02]o
o`03001oogoo0?moobMoo`03001oogoo03Ioo`0087oo00<007ooOol0;7oo00<007ooOol0ogoo9Goo
00<007ooOol0=goo000POol2000^Ool00`00Oomoo`3oOolSOol00`00Oomoo`0hOol0021oo`03001o
ogoo02ioo`03001oogoo0?moob5oo`03001oogoo03Uoo`0087oo00<007ooOol0;Woo00<007ooOol0
ogoo8Goo00<007ooOol0>Goo000POol00`00Oomoo`0_Ool00`00Oomoo`3oOolOOol00`00Oomoo`0j
Ool0021oo`03001oogoo031oo`03001oogoo0?mooaeoo`03001oogoo03]oo`0087oo00<007ooOol0
<Goo00<007ooOol0ogoo6goo00<007ooOol0?7oo000POol00`00Oomoo`0bOol00`00Oomoo`3oOolI
Ool00`00Oomoo`0mOol0021oo`03001oogoo039oo`03001oogoo0?mooaQoo`03001oogoo03ioo`00
87oo00<007ooOol0<goo00<007ooOol0ogoo5goo00<007ooOol0?Woo000POol00`00Oomoo`0dOol0
0`00Oomoo`3oOolEOol00`00Oomoo`0oOol0021oo`03001oogoo03Eoo`03001oogoo0?mooa=oo`03
001oogoo041oo`0087oo00<007ooOol0=Woo00<007ooOol0ogoo4Goo00<007ooOol0@Goo000POol2
000gOol00`00Oomoo`3oOol@Ool00`00Oomoo`12Ool0021oo`03001oogoo03Moo`03001oogoo0?mo
o`ioo`03001oogoo04=oo`0087oo00<007ooOol0>7oo00<007ooOol0ogoo37oo00<007ooOol0A7oo
000POol00`00Oomoo`0iOol00`00Oomoo`3oOol;Ool00`00Oomoo`14Ool0021oo`03001oogoo03Uo
o`03001oogoo0?moo`Yoo`03001oogoo04Eoo`0087oo00<007ooOol0>Woo00<007ooOol0ogoo27oo
00<007ooOol0AWoo000POol00`00Oomoo`0kOol00`00Oomoo`3oOol6Ool00`00Oomoo`17Ool0021o
o`03001oogoo03aoo`03001oogoo0?moo`Aoo`03001oogoo04Qoo`0087oo00<007ooOol0?Goo00<0
07ooOol0ogoo0Woo00<007ooOol0BGoo000POol00`00Oomoo`0mOol00`00Oomoo`3oOol2Ool00`00
Oomoo`19Ool0021oo`03001oogoo03ioo`03001oogoo0?moo`03001oogoo04Yoo`0087oo00<007oo
Ool0?goo00<007ooOol0oGoo00<007ooOol0Bgoo000POol20011Ool00`00Oomoo`3kOol00`00Oomo
o`1<Ool0021oo`03001oogoo045oo`03001oogoo0?Uoo`03001oogoo04eoo`0087oo00<007ooOol0
@Goo00<007ooOol0nGoo00<007ooOol0CGoo000POol00`00Oomoo`12Ool00`00Oomoo`3gOol00`00
Oomoo`1>Ool0021oo`03001oogoo04=oo`03001oogoo0?Eoo`03001oogoo04moo`0087oo00<007oo
Ool0A7oo00<007ooOol0lgoo00<007ooOol0D7oo000POol00`00Oomoo`15Ool00`00Oomoo`3aOol0
0`00Oomoo`1AOol0021oo`03001oogoo04Ioo`03001oogoo0>moo`03001oogoo059oo`0087oo00<0
07ooOol0AWoo00<007ooOol0kgoo00<007ooOol0DWoo000POol00`00Oomoo`17Ool00`00Oomoo`3]
Ool00`00Oomoo`1COol000=oo`8000Moo`<000Moo`<000Moo`03001oogoo04Qoo`03001oogoo0>]o
o`03001oogoo05Aoo`000Woo00@007ooOol000Ioo`<000Qoo`03001oogoo00Ioo`03001oogoo04Uo
o`03001oogoo0>Uoo`03001oogoo05Eoo`0000=oo`00Ool00goo00<007ooOol00goo0`0017oo1P00
1goo0`00BWoo00<007ooOol0igoo00<007ooOol0EWoo00000goo001oo`03Ool00`00Oomoo`0:Ool0
1@00Oomoogoo000027oo00<007ooOol0BWoo00<007ooOol0igoo00<007ooOol0EWoo00000goo001o
o`03Ool00`00Oomoo`0;Ool01000Oomoo`0027oo00<007ooOol0Bgoo00<007ooOol0iGoo00<007oo
Ool0Egoo00000goo001oo`03Ool00`00Oomoo`0<Ool00`00Ool00008Ool00`00Oomoo`1<Ool00`00
Oomoo`3SOol00`00Oomoo`1HOol00003Ool007oo00=oo`03001oogoo00aoo`03001oo`0000Qoo`03
001oogoo04eoo`03001oogoo0>5oo`03001oogoo05Uoo`000Woo00@007ooOol0011oo`8000Qoo`03
001oogoo04ioo`03001oogoo0=moo`03001oogoo05Yoo`000goo0P004Woo00<007ooOol01Woo00<0
07ooOol0CWoo00<007ooOol0ggoo00<007ooOol0FWoo000POol00`00Oomoo`1?Ool00`00Oomoo`3M
Ool00`00Oomoo`1KOol0021oo`03001oogoo051oo`03001oogoo0=]oo`03001oogoo05aoo`0087oo
00<007ooOol0DGoo00<007ooOol0fGoo00<007ooOol0GGoo000POol00`00Oomoo`1BOol00`00Oomo
o`3GOol00`00Oomoo`1NOol0021oo`03001oogoo05=oo`03001oogoo0=Eoo`03001oogoo05moo`00
87oo0P00E7oo00<007ooOol0eGoo00<007ooOol0Ggoo000POol00`00Oomoo`1DOol00`00Oomoo`3C
Ool00`00Oomoo`1POol0021oo`03001oogoo05Eoo`03001oogoo0=5oo`03001oogoo065oo`0087oo
00<007ooOol0EWoo00<007ooOol0cgoo00<007ooOol0HWoo000POol00`00Oomoo`1GOol00`00Oomo
o`3=Ool00`00Oomoo`1SOol0021oo`03001oogoo05Qoo`03001oogoo0<]oo`03001oogoo06Aoo`00
87oo00<007ooOol0FGoo00<007ooOol0bGoo00<007ooOol0IGoo000POol00`00Oomoo`1IOol00`00
Oomoo`39Ool00`00Oomoo`1UOol0021oo`03001oogoo05Yoo`03001oogoo0<Moo`03001oogoo06Io
o`0087oo00<007ooOol0Fgoo00<007ooOol0aGoo00<007ooOol0Igoo000POol00`00Oomoo`1LOol0
0`00Oomoo`33Ool00`00Oomoo`1XOol0021oo`03001oogoo05eoo`03001oogoo0<5oo`03001oogoo
06Uoo`0087oo0P00Ggoo00<007ooOol0_goo00<007ooOol0JWoo000POol00`00Oomoo`1NOol00`00
Oomoo`2oOol00`00Oomoo`1ZOol0021oo`03001oogoo05moo`03001oogoo0;eoo`03001oogoo06]o
o`0087oo00<007ooOol0H7oo00<007ooOol0^goo00<007ooOol0K7oo000POol00`00Oomoo`1QOol0
0`00Oomoo`2iOol00`00Oomoo`1]Ool0021oo`03001oogoo069oo`03001oogoo0;Moo`03001oogoo
06ioo`0087oo00<007ooOol0HWoo00<007ooOol0]goo00<007ooOol0KWoo000POol00`00Oomoo`1S
Ool00`00Oomoo`2eOol00`00Oomoo`1_Ool0021oo`03001oogoo06Aoo`03001oogoo0;=oo`03001o
ogoo071oo`0087oo00<007ooOol0IGoo00<007ooOol0/Goo00<007ooOol0LGoo000POol00`00Oomo
o`1VOol00`00Oomoo`2_Ool00`00Oomoo`1bOol0021oo`03001oogoo06Moo`03001oogoo0:ioo`03
001oogoo079oo`0087oo00<007ooOol0Igoo00<007ooOol0[Goo00<007ooOol0Lgoo000POol2001Y
Ool00`00Oomoo`2[Ool00`00Oomoo`1dOol0021oo`03001oogoo06Uoo`03001oogoo0:Uoo`03001o
ogoo07Eoo`0087oo00<007ooOol0JWoo00<007ooOol0Ygoo00<007ooOol0MWoo000POol00`00Oomo
o`1[Ool00`00Oomoo`2VOol00`00Oomoo`1fOol0021oo`03001oogoo06]oo`03001oogoo0:Eoo`03
001oogoo07Moo`0087oo00<007ooOol0K7oo00<007ooOol0Xgoo00<007ooOol0N7oo000POol00`00
Oomoo`1]Ool00`00Oomoo`2QOol00`00Oomoo`1iOol0021oo`03001oogoo06ioo`03001oogoo09mo
o`03001oogoo07Yoo`0087oo00<007ooOol0Kgoo00<007ooOol0WWoo00<007ooOol0NWoo0003Ool2
0007Ool30005Ool40008Ool00`00Oomoo`1_Ool00`00Oomoo`2MOol00`00Oomoo`1kOol0009oo`04
001oogoo0006Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool00`00Oomo
o`2KOol00`00Oomoo`1lOol00003Ool007oo00=oo`03001oogoo00=oo`<000Aoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo075oo`03001oogoo09Uoo`03001oogoo07eoo`0000=oo`00Ool0
0goo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol01Goo0`00LWoo00<007ooOol0Ugoo00<0
07ooOol0OWoo00000goo001oo`03Ool00`00Oomoo`0:Ool20003Ool00`00Oomoo`05Ool00`00Oomo
o`1cOol00`00Oomoo`2FOol00`00Oomoo`1nOol00003Ool007oo00=oo`03001oogoo00Yoo`03001o
o`00008000Qoo`03001oogoo07=oo`03001oogoo09Eoo`03001oogoo07moo`0000=oo`00Ool00goo
00<007ooOol02goo00<007ooOol02Goo00<007ooOol0M7oo00<007ooOol0Tgoo00<007ooOol0P7oo
0002Ool01000Oomoo`003Woo0P002Woo00<007ooOol0MGoo00<007ooOol0TGoo00<007ooOol0PGoo
0003Ool2000AOol30007Ool00`00Oomoo`1fOol00`00Oomoo`2?Ool00`00Oomoo`22Ool0021oo`03
001oogoo07Moo`03001oogoo08eoo`03001oogoo08=oo`0087oo00<007ooOol0Mgoo00<007ooOol0
SGoo00<007ooOol0Pgoo000POol00`00Oomoo`1hOol00`00Oomoo`2;Ool00`00Oomoo`24Ool0021o
o`03001oogoo07Uoo`03001oogoo08Uoo`03001oogoo08Eoo`0087oo00<007ooOol0NWoo00<007oo
Ool0Qgoo00<007ooOol0QWoo000POol00`00Oomoo`1kOol00`00Oomoo`25Ool00`00Oomoo`27Ool0
021oo`8007aoo`03001oogoo08Eoo`03001oogoo08Moo`0087oo00<007ooOol0O7oo00<007ooOol0
Pgoo00<007ooOol0R7oo000POol00`00Oomoo`1mOol00`00Oomoo`21Ool00`00Oomoo`29Ool0021o
o`03001oogoo07ioo`03001oogoo07moo`03001oogoo08Yoo`0087oo00<007ooOol0Ogoo00<007oo
Ool0OGoo00<007ooOol0Rgoo000POol00`00Oomoo`1oOol00`00Oomoo`1mOol00`00Oomoo`2;Ool0
021oo`03001oogoo081oo`03001oogoo07]oo`03001oogoo08aoo`0087oo00<007ooOol0PGoo00<0
07ooOol0NGoo00<007ooOol0SGoo000POol00`00Oomoo`22Ool00`00Oomoo`1gOol00`00Oomoo`2>
Ool0021oo`03001oogoo08=oo`03001oogoo07Eoo`03001oogoo08moo`0087oo00<007ooOol0Pgoo
00<007ooOol0MGoo00<007ooOol0Sgoo000POol00`00Oomoo`24Ool00`00Oomoo`1cOol00`00Oomo
o`2@Ool0021oo`8008Ioo`03001oogoo075oo`03001oogoo095oo`0087oo00<007ooOol0QWoo00<0
07ooOol0Kgoo00<007ooOol0TWoo000POol00`00Oomoo`27Ool00`00Oomoo`1]Ool00`00Oomoo`2C
Ool0021oo`03001oogoo08Moo`03001oogoo06eoo`03001oogoo09=oo`0087oo00<007ooOol0R7oo
00<007ooOol0Jgoo00<007ooOol0U7oo000POol00`00Oomoo`29Ool00`00Oomoo`1YOol00`00Oomo
o`2EOol0021oo`03001oogoo08Yoo`03001oogoo06Moo`03001oogoo09Ioo`0087oo00<007ooOol0
Rgoo00<007ooOol0IGoo00<007ooOol0Ugoo000POol00`00Oomoo`2;Ool00`00Oomoo`1UOol00`00
Oomoo`2GOol0021oo`03001oogoo08aoo`03001oogoo06=oo`03001oogoo09Qoo`0087oo00<007oo
Ool0SGoo00<007ooOol0HGoo00<007ooOol0VGoo000POol00`00Oomoo`2>Ool00`00Oomoo`1OOol0
0`00Oomoo`2JOol0021oo`80091oo`03001oogoo05eoo`03001oogoo09]oo`0087oo00<007ooOol0
Sgoo00<007ooOol0GGoo00<007ooOol0Vgoo000POol00`00Oomoo`2@Ool00`00Oomoo`1KOol00`00
Oomoo`2LOol0021oo`03001oogoo095oo`03001oogoo05Uoo`03001oogoo09eoo`0087oo00<007oo
Ool0TWoo00<007ooOol0Egoo00<007ooOol0WWoo000POol00`00Oomoo`2COol00`00Oomoo`1EOol0
0`00Oomoo`2OOol0021oo`03001oogoo09=oo`03001oogoo05Eoo`03001oogoo09moo`0087oo00<0
07ooOol0U7oo00<007ooOol0Dgoo00<007ooOol0X7oo000POol00`00Oomoo`2EOol00`00Oomoo`1A
Ool00`00Oomoo`2QOol000=oo`8000Moo`<000Eoo`@000Qoo`03001oogoo09Ioo`03001oogoo04mo
o`03001oogoo0:9oo`000Woo00@007ooOol000Ioo`<000Aoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo09Moo`03001oogoo04eoo`03001oogoo0:=oo`0000=oo`00Ool00goo00<007ooOol0
0goo0`0017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0V7oo00<007ooOol0C7oo00<0
07ooOol0Xgoo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3
002HOol00`00Oomoo`1;Ool00`00Oomoo`2TOol00003Ool007oo00=oo`03001oogoo00]oo`@000Qo
o`03001oogoo09Uoo`03001oogoo04Uoo`03001oogoo0:Eoo`0000=oo`00Ool00goo00<007ooOol0
2Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0VWoo00<007ooOol0Agoo00<007ooOol0
YWoo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`2KOol00`00Oomoo`15Ool00`00Oomoo`2WOol0009oo`04001oogoo000=Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`2LOol00`00Oomoo`14Ool00`00Oomoo`2WOol000=oo`8000moo`@0
00Qoo`03001oogoo09aoo`03001oogoo04=oo`03001oogoo0:Qoo`0087oo00<007ooOol0WGoo00<0
07ooOol0@Goo00<007ooOol0ZGoo000POol00`00Oomoo`2NOol00`00Oomoo`0oOol00`00Oomoo`2Z
Ool0021oo`03001oogoo09moo`03001oogoo03eoo`03001oogoo0:]oo`0087oo00<007ooOol0X7oo
00<007ooOol0?7oo00<007ooOol0Zgoo000POol00`00Oomoo`2POol00`00Oomoo`0kOol00`00Oomo
o`2/Ool0021oo`03001oogoo0:5oo`03001oogoo03Uoo`03001oogoo0:eoo`0087oo0P00Xgoo00<0
07ooOol0=goo00<007ooOol0[Woo000POol00`00Oomoo`2SOol00`00Oomoo`0eOol00`00Oomoo`2_
Ool0021oo`03001oogoo0:Aoo`03001oogoo03Aoo`03001oogoo0:moo`0087oo00<007ooOol0YGoo
00<007ooOol0<Woo00<007ooOol0/7oo000POol00`00Oomoo`2UOol00`00Oomoo`0aOol00`00Oomo
o`2aOol0021oo`03001oogoo0:Ioo`03001oogoo02moo`03001oogoo0;9oo`0087oo00<007ooOol0
Ygoo00<007ooOol0;Goo00<007ooOol0/goo000POol00`00Oomoo`2XOol00`00Oomoo`0/Ool00`00
Oomoo`2cOol0021oo`03001oogoo0:Uoo`03001oogoo02Yoo`03001oogoo0;Aoo`0087oo00<007oo
Ool0ZWoo00<007ooOol0:7oo00<007ooOol0]Goo000POol00`00Oomoo`2[Ool00`00Oomoo`0VOol0
0`00Oomoo`2fOol0021oo`03001oogoo0:]oo`03001oogoo02Eoo`03001oogoo0;Moo`0087oo0P00
[Goo00<007ooOol097oo00<007ooOol0]goo000POol00`00Oomoo`2]Ool00`00Oomoo`0ROol00`00
Oomoo`2hOol0021oo`03001oogoo0:ioo`03001oogoo021oo`03001oogoo0;Uoo`0087oo00<007oo
Ool0[goo00<007ooOol07Woo00<007ooOol0^Woo000POol00`00Oomoo`2`Ool00`00Oomoo`0LOol0
0`00Oomoo`2kOol0021oo`03001oogoo0;1oo`03001oogoo01aoo`03001oogoo0;]oo`0087oo00<0
07ooOol0/Goo00<007ooOol06Woo00<007ooOol0_7oo000POol00`00Oomoo`2bOol00`00Oomoo`0H
Ool00`00Oomoo`2mOol0021oo`03001oogoo0;=oo`03001oogoo01Ioo`03001oogoo0;ioo`0087oo
00<007ooOol0]7oo00<007ooOol057oo00<007ooOol0_goo000POol00`00Oomoo`2dOol00`00Oomo
o`0DOol00`00Oomoo`2oOol0021oo`03001oogoo0;Eoo`03001oogoo019oo`03001oogoo0<1oo`00
87oo0P00]goo00<007ooOol047oo00<007ooOol0`Goo000POol00`00Oomoo`2gOol00`00Oomoo`0>
Ool00`00Oomoo`32Ool0021oo`03001oogoo0;Qoo`03001oogoo00aoo`03001oogoo0<=oo`0087oo
00<007ooOol0^7oo00<007ooOol037oo00<007ooOol0`goo000POol00`00Oomoo`2iOol00`00Oomo
o`0:Ool00`00Oomoo`34Ool0021oo`03001oogoo0;Yoo`03001oogoo00Qoo`03001oogoo0<Eoo`00
87oo00<007ooOol0^Woo00<007ooOol01goo00<007ooOol0aWoo000POol00`00Oomoo`2kOol00`00
Oomoo`05Ool00`00Oomoo`37Ool0021oo`03001oogoo0;aoo`03001oogoo00=oo`03001oogoo0<Qo
o`0057oo1@001goo00<007ooOol0_Goo00D007ooOomoo`000<]oo`005Woo00<007ooOol01goo00<0
07ooOol0_Woo00@007ooOol00<]oo`005Woo00<007ooOol01goo00<007ooOol0_goo0P00c7oo000F
Ool00`00Oomoo`07Ool3002oOol00`00Oomoo`3;Ool001Ioo`03001oogoo00Moo`03001oogoo0?mo
ohioo`005Woo00<007ooOol01goo00<007ooOol0ogooSWoo000FOol00`00Oomoo`07Ool00`00Oomo
o`3oOon>Ool001Aoo`<000Uoo`03001oogoo0?moohioo`005Goo0P002Goo00<007ooOol0ogooSWoo
000POol00`00Oomoo`3oOon>Ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "This is only one period of the wave. To create a periodic function, we \
need to define ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " for the rest of the real line. This can be done using Eq. ",
  ButtonBox["(2.1.1)",
    ButtonData:>"(2.1.1)",
    ButtonStyle->"Hyperlink"],
  ", the definition of a periodic function, as a recursion relation for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(f[t_]\  := \ f[t - T]\  /; \ t > T\ ;\)\), "\n", 
    \(f[t_]\  := \ f[t + T]\  /; \ t < 0\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.6"],

Cell[TextData[{
  "Now we can plot the wave over several periods, as shown in Cell ",
  ButtonBox["2.7",
    ButtonData:>"Cell 2.7",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f[t], {t, \(-3\) T, 3  T}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.0147151 0.588703 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.34127 .00222 -6 -9 ]
[.34127 .00222 6 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -3 -9 ]
[.81746 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.4875 .13246 -18 -4.5 ]
[.4875 .13246 0 4.5 ]
[.4875 .2502 -18 -4.5 ]
[.4875 .2502 0 4.5 ]
[.4875 .36794 -18 -4.5 ]
[.4875 .36794 0 4.5 ]
[.4875 .48568 -18 -4.5 ]
[.4875 .48568 0 4.5 ]
[.4875 .60342 -6 -4.5 ]
[.4875 .60342 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-3)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-2)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(-1)] .34127 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(1)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.5 .13246 m
.50625 .13246 L
s
[(0.2)] .4875 .13246 1 0 Mshowa
.5 .2502 m
.50625 .2502 L
s
[(0.4)] .4875 .2502 1 0 Mshowa
.5 .36794 m
.50625 .36794 L
s
[(0.6)] .4875 .36794 1 0 Mshowa
.5 .48568 m
.50625 .48568 L
s
[(0.8)] .4875 .48568 1 0 Mshowa
.5 .60342 m
.50625 .60342 L
s
[(1)] .4875 .60342 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07359 m
.50375 .07359 L
s
.5 .10302 m
.50375 .10302 L
s
.5 .16189 m
.50375 .16189 L
s
.5 .19133 m
.50375 .19133 L
s
.5 .22076 m
.50375 .22076 L
s
.5 .27963 m
.50375 .27963 L
s
.5 .30907 m
.50375 .30907 L
s
.5 .3385 m
.50375 .3385 L
s
.5 .39737 m
.50375 .39737 L
s
.5 .42681 m
.50375 .42681 L
s
.5 .45624 m
.50375 .45624 L
s
.5 .51511 m
.50375 .51511 L
s
.5 .54455 m
.50375 .54455 L
s
.5 .57398 m
.50375 .57398 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .3013 L
.08255 .45046 L
.0932 .5294 L
.096 .55021 L
.09905 .57281 L
.10044 .58316 L
.10192 .59414 L
.10319 .60332 L
.10391 .59799 L
.10458 .59299 L
.11531 .51343 L
.12507 .44103 L
.14415 .29946 L
.16269 .16196 L
.17248 .08931 L
.17786 .04943 L
.17914 .03992 L
.1805 .02987 L
.18165 .02129 L
.18292 .01756 L
.18361 .02268 L
.18435 .02816 L
.18568 .03804 L
.18867 .0602 L
.19388 .09886 L
.20406 .17433 L
.22415 .32335 L
.24396 .4703 L
.24939 .51056 L
.25515 .55333 L
.25752 .57091 L
.26008 .58985 L
.26079 .59513 L
.26154 .60069 L
.26218 .60139 L
.26288 .5962 L
.26551 .57668 L
.30535 .28112 L
.31629 .20004 L
.32661 .12349 L
.33587 .05476 L
.33841 .03593 L
.3398 .02563 L
.3411 .016 L
.3422 .02164 L
.34339 .03045 L
.34592 .04917 L
.38496 .3388 L
.40471 .48529 L
Mistroke
.41012 .52542 L
.41588 .56815 L
.41723 .57813 L
.41868 .58892 L
.41935 .59388 L
.42005 .59911 L
.42132 .59837 L
.42253 .58936 L
.42366 .58095 L
.42624 .56186 L
.466 .26693 L
.48467 .12841 L
.48979 .09046 L
.49522 .0502 L
.49745 .03365 L
.49862 .02496 L
.49985 .01583 L
.50051 .01848 L
.50123 .02381 L
.50249 .03316 L
.50496 .0515 L
.52624 .20935 L
.54637 .35869 L
.56602 .50444 L
.57168 .5464 L
.57446 .567 L
.57701 .58596 L
.57822 .59489 L
.57934 .60323 L
.58051 .59491 L
.5818 .58535 L
.58699 .54689 L
.62586 .25852 L
.63602 .18318 L
.64708 .10116 L
.65214 .06361 L
.65491 .04303 L
.65627 .03295 L
.65752 .02369 L
.6586 .01571 L
.65973 .02213 L
.66211 .03982 L
.66719 .07747 L
.70527 .3599 L
.72485 .50519 L
.73049 .54702 L
.73326 .56758 L
.73582 .58655 L
.73702 .59545 L
.73814 .60306 L
Mistroke
.73932 .59437 L
.7406 .5848 L
.7458 .5463 L
.78459 .25856 L
.7947 .18353 L
.80574 .10168 L
.81078 .06425 L
.81355 .04371 L
.81491 .03363 L
.81616 .02436 L
.81735 .01557 L
.8186 .02315 L
.82123 .0427 L
.82583 .07681 L
.86382 .35862 L
.88335 .50344 L
.88897 .54514 L
.89174 .56566 L
.89429 .58463 L
.89549 .5935 L
.89661 .60182 L
.89778 .59633 L
.89907 .58676 L
.90427 .54822 L
.94297 .2611 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`004P3oool01@2IVIT04A4A0000000c<c<0c<c<0340oooo1@00000b0?oo
o`@0000000<04A4A0?ooo`3oool0H@3oool400000003014A4@3oool0oooo02h0oooo1@00000a0?oo
o`0509VIV@0A4A40000003<c<`3<c<`04@3oool00180oooo00D04A4A0;^k^`3oool0MgMg03<c<`0a
0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0=03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0300oooo00D0VIVI028R8P3^k^h0oooo04A4A00a0?ooo`05014A4@2k^k/0oooo07MgM`0c
<c<04@3oool000X0oooo1P0000060?ooo`030000003oool0oooo02L0oooo1P0000030?ooo`0309VI
V@0R8R80k^k^02X0oooo1P0000050?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool0
<@3oool00`2IVIT08R8R0>k^kP0f0?ooo`030000003oool0oooo00l0oooo000E0?ooo`030:ZZZP0A
4A40oooo0380oooo00<0VIVI028R8P3^k^h0=03oool00`000000oooo0?ooo`1U0?ooo`030000003o
ool0oooo0380oooo00<0VIVI028R8P3^k^h0=03oool00`2ZZZX04A4A0?ooo`0@0?ooo`00503oool0
0`0A4A4000000;^k^`0d0?ooo`0307MgM`1VIVH0oooo03<0oooo00<000000?ooo`3oool0I@3oool0
0`000000oooo0?ooo`0c0?ooo`0307MgM`1VIVH0oooo0380oooo00<04A4A0000002k^k/04@3oool0
01D0oooo00<0^k^k028R8P3oool0=03oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo
06D0oooo00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`0b0?ooo`030;^k^`0R8R80oooo
0100oooo000B0?ooo`05014A4@2IVIT0oooo0;^k^`000000<@3oool01@000000^k^k0?ooo`2IVIT0
4A4A03@0oooo00<000000?ooo`3oool0I@3oool00`000000oooo0?ooo`0`0?ooo`050000002k^k/0
oooo09VIV@0A4A40<@3oool01@0A4A40VIVI0?ooo`2k^k/000000140oooo000B0?ooo`050:ZZZP0A
4A400000014A4@2ZZZX0<@3oool01@2IVIT04A4A0000000R8R80c<c<0380oooo0P1EEED00`000000
oooo0?ooo`1S0?ooo`80EEEE00<000000?ooo`3oool0<03oool01@2IVIT04A4A0000000R8R80c<c<
0340oooo00D0ZZZZ014A4@0000004A4A0:ZZZP0A0?ooo`00o`3ooomY0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`002@3ooooo000005H000002P3oool00140oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool00140oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0403oool00140oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0c
0?ooo`030000003oool0oooo03<0oooo00<000000?ooo`3oool0403oool00140oooo00<000000?oo
o`3oool0<P3oool00`000000oooo0000000d0?ooo`800000=03oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0@0?oo
o`004P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0000003@0oooo0P00000c0?ooo`<0
0000<`3oool2000003@0oooo0P00000d0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000
003oool0oooo0340oooo00<000000?ooo`000000<`3oool00`000000oooo0000000c0?ooo`<00000
<`3oool00`000000oooo0000000c0?ooo`800000=03oool00`000000oooo0?ooo`0A0?ooo`004P3o
ool00`000000oooo0?ooo`0a0?ooo`030000003oool0000003<0oooo00<000000?ooo`000000<`3o
ool3000003<0oooo00<000000?ooo`000000<`3oool00`000000oooo0000000c0?ooo`030000003o
ool0oooo0140oooo000B0?ooo`030000003oool0oooo0340oooo00<000000?ooo`000000<`3oool0
0`000000oooo0000000c0?ooo`<00000<`3oool00`000000oooo0000000c0?ooo`030000003oool0
000003<0oooo00<000000?ooo`3oool04@3oool00180oooo00<000000?ooo`3oool0<@3oool00`00
0000oooo0000000c0?ooo`040000003oool0oooo00000380oooo0`00000c0?ooo`030000003oool0
000003<0oooo00<000000?ooo`000000<`3oool00`000000oooo0?ooo`0A0?ooo`004P3oool00`00
0000oooo0?ooo`0`0?ooo`040000003oool0oooo000003<0oooo00@000000?ooo`3oool00000<@3o
ool00`000000oooo0000000200000380oooo00<000000?ooo`000000<`3oool00`000000oooo0000
000c0?ooo`030000003oool0oooo0140oooo000B0?ooo`030000003oool0oooo0300oooo00@00000
0?ooo`3oool00000<P3oool01@000000oooo0?ooo`3oool000000340oooo00D000000?ooo`000000
oooo0000000b0?ooo`030000003oool0000003<0oooo00<000000?ooo`000000<`3oool00`000000
oooo0?ooo`0A0?ooo`004`3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`00
0000<@3oool01@000000oooo0?ooo`3oool000000340oooo00D000000?ooo`000000oooo0000000b
0?ooo`040000003oool0oooo00000380oooo00<000000?ooo`000000<P3oool00`000000oooo0?oo
o`0B0?ooo`004`3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`000000<@3o
ool01@000000oooo0?ooo`3oool000000340oooo00D000000?ooo`000000oooo0000000a0?ooo`05
0000003oool0oooo0?ooo`000000<P3oool010000000oooo0?ooo`00000a0?ooo`030000003oool0
oooo0180oooo000C0?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo0000000a
0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@000000oooo0000003oool000000340oooo
00D000000?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`00
0000oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?oo
o`000000<@3oool01@000000oooo0?ooo`3oool000000340oooo00D000000?ooo`000000oooo0000
000a0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@000000oooo0?ooo`3oool000000340
oooo00<000000?ooo`3oool04P3oool001<0oooo00<000000?ooo`3oool0;`3oool01@000000oooo
0?ooo`3oool000000340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`05
0000003oool000000?ooo`000000<@3oool01@000000oooo0?ooo`3oool000000340oooo00D00000
0?ooo`3oool0oooo0000000a0?ooo`030000003oool0oooo0180oooo000C0?ooo`030000003oool0
oooo02l0oooo00D000000?ooo`3oool0oooo0000000a0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0;P3oool00`000000oooo000000020?ooo`030000003oool0oooo02h0oooo00D0
00000?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000<@3oool00`000000
oooo0?ooo`0B0?ooo`004`3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`00
0000<03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02h0oooo00<000000?ooo`00
00000P3oool00`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@00
0000oooo0?ooo`3oool000000340oooo00<000000?ooo`3oool04P3oool001<0oooo00<000000?oo
o`3oool0;P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0180oooo000D0?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020000
00030?ooo`000000oooo02h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0^0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0C0?oo
o`00503oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool04`3oool001@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo01<0oooo000D0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0;03oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0;@3oool00`000000oooo0?ooo`0C0?ooo`00503oool00`000000oooo0?ooo`0]0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0]0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02d0oooo00<000000?ooo`3oool04`3oool001@0oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0/0?ooo`040000003oool0oooo000000<0oooo00<000000?oo
o`3oool0;03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo01<0oooo000D0?ooo`03
0000003oool0oooo02d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0;03oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo02`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0/0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0C0?oo
o`005@3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02`0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0503oool001D0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0/0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0:`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0:`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0:`3oool010000000oooo0?ooo`3oool200000080oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo01@0oooo000E0?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool00000
00<0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
01@0oooo000E0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0:P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?oo
o`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0:P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0:@3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo000E0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo01@0oooo000F0?ooo`03
0000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0:P3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
01D0oooo000F0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo01D0oooo000F0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R840?ooo`D0
000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo
0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo01<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`80
8R8R103oool01`2IVIT08R8R0>k^kP3oool0A4A40?ooo`000000103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0E
0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0180oooo00D04A4A0?oo
o`3oool0oooo014A4@0<0?ooo`0309VIV@0R8R80k^k^0080oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0E0?ooo`005P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
0180oooo00D000000?ooo`3oool0oooo0000000=0?ooo`0509VIV@0R8R80k^k^0?ooo`000000103o
ool3000000<0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`030000003o
ool0oooo01D0oooo000F0?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool04P3oool0
1@000000oooo0?ooo`3oool0000000h0oooo00@0MgMg06IVIP3oool00000103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:03oool00`000000oooo
0?ooo`0E0?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00D0
4A4A0?ooo`3oool0oooo014A4@0?0?ooo`8000001@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`005`3o
ool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00D0MgMg09VIV@3oool0VIVI
07MgM`0;0?ooo`060000002k^k/0oooo09VIV@0A4A4000001@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?oo
o`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0180oooo00D0k^k^03<c<`00
0000<c<c0>k^kP0;0?ooo`0609VIV@0A4A400000028R8P3<c<`000001@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`0F0?ooo`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02L0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0F0?oo
o`005`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool09`3oool00`000000oooo0?ooo`0F0?ooo`005`3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo02H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0F0?ooo`00603o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09P3o
ool00`000000oooo0?ooo`0F0?ooo`00603oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo02D0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
01L0oooo000H0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool00`000000
oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01L0oooo
000H0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?oo
o`0U0?ooo`030000003oool0oooo01L0oooo000H0?ooo`030000003oool0oooo02@0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0903oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo000H0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?oo
o`030000003oool0oooo01L0oooo000I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01L0oooo000I0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0U0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000
003oool0oooo01P0oooo000I0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01P0oooo000I0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`8000001P3oool0
0`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool0
01T0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool0603oool001T0oooo00<000000?ooo`3oool08`3oool00`000000
oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0R0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08P3oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0603oool001T0oooo
00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo
00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0603oool001X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0603oool001X0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo02<0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<00000
0?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3o
ool06@3oool001X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0Q0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0240oooo00<000000?ooo`3oool06@3oool001X0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0403o
ool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool06@3o
ool001X0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo0240oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0O0?ooo`030000003oool0
oooo00L0oooo0P0000070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`0I0?ooo`006P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0I0?ooo`006`3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0803oool00`000000
oooo0?ooo`0I0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?oo
o`0J0?ooo`006`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01l0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0J0?oo
o`006`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool07`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00D0k^k^03<c<`00
0000<c<c0>k^kP050?ooo`808R8R103oool01@000000oooo0000000000004A4A00H0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8P@0oooo00@000000?ooo`3oool000001`3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3o
ool00`000000oooo0?ooo`0J0?ooo`00703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00d0oooo00D04A4A0?ooo`3oool0oooo014A4@0;0?ooo`D000001P3oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000oooo0?oo
o`0J0?ooo`00703oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00d0oooo00D00000
0?ooo`3oool0oooo0000000;0?ooo`040000003MgMd0oooo000000L0oooo0`0000080?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0K0?ooo`00703o
ool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00d0oooo00D000000?ooo`3oool0oooo
0000000;0?ooo`040000001EEED0oooo000000L0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool06`3oool001`0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`05014A4@3oool0oooo0?ooo`0A
4A402`3oool010000000MgMg0<c<c00000070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo000L0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool03@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00X0oooo00D000000?ooo`3^k^h0A4A4000000070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<00000
0?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo000L0?oo
o`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01@0oooo00<000000?ooo`3oool0303oool01@3^k^h0<c<c0000000c<c<0
k^k^00X0oooo00D000000?ooo`3oool0MgMg000000070?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01/0oooo000L
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01/0oooo000L0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01/0oooo000M0?ooo`03
0000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0M0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01`0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo01`0oooo000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01`0oooo000M0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01`0oooo000M0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0:0?ooo`8000002P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01/0oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0J0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0703oool001d0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool0703oool001d0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo
0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0703oool001h0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01H0oooo00<0
00000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool07@3oool001h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool07@3oool001h0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool07@3oool001h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool07@3oool001h0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
7@3oool001h0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0H0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool07@3oool001h0oooo00<000000?ooo`3oool06@3oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0603oool0
0`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00/0oooo0P00000<0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo01P0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0M0?ooo`007P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo
0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<0
00000?ooo`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0I
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0G
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0N
0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool06@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0N0?ooo`007`3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0J0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?ooo`00
7`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
6P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0O0?ooo`00803oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0K0?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo01X0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0O0?ooo`00803oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0303oool2
000000d0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0
oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01l0oooo000P0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01l0
oooo000P0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01l0oooo000P0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool06`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01/0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0703oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01l0oooo000P
0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo0200oooo000Q0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01d0oooo00<000000?oo
o`3oool04`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0703oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0200oooo000Q0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool01@3^k^h0<c<c0000000c<c<0k^k^
00D0oooo00<08R8R0000003oool00`3oool01@3^k^h0<c<c0000000A4A40c<c<00H0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0803oool00240oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`080?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool00`0R8R8000000?ooo`030?ooo`0505EEE@1gMgL0
oooo09VIV@0R8R801P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01<0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<0
00000?ooo`3oool04`3oool00`000000oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`0C
0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M
0?ooo`030000003oool0oooo00P0oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`030000003o
ool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo
00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0200oooo
000Q0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0203oool01@000000oooo0?oo
o`3oool0000000H0oooo00<000000?ooo`3oool00P3oool01@000000VIVI0?ooo`2IVIT08R8R00H0
oooo0`00000=0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0P0?ooo`008@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01d0oooo
00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00P0oooo
00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00D0000005EEE@00
00004A4A0<c<c0060?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`0M0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo0200oooo000Q0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool01`3oool01@0A4A40oooo0?ooo`3oool04A4A00D0oooo00<000000?oo
o`3oool00`3oool00`1EEED0R8R80?ooo`080?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo000R0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00D0oooo00<000000?ooo`3oool00`3oool00`3MgMd04A4A09VIV@080?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0240oooo000R0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool01`3oool01@3^k^h0
<c<c0000000c<c<0k^k^00D0oooo00<000000?ooo`3oool0103oool0103<c<`0A4A40000000A4A46
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0N
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0A
0?ooo`030000003oool0oooo0240oooo000R0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<000000?oo
o`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo000R0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo0240oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0240oooo000R0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo01l0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo0240oooo000R0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0O0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0280oooo000R0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`800000403oool00`00
0000oooo0?ooo`0@0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool002<0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool08P3oool002<0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool002<0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool08P3oool002<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool002<0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool08P3oool002<0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0240oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool08`3oool002<0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0
8P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
8`3oool002@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0280oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0R0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool08`3oool002@0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`0R0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool0
02@0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
0100oooo0P00000A0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool08P3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`00
0000oooo0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0280
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0S0?ooo`00903oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0S0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo
0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0S0?ooo`00903oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`00903oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0T
0?ooo`009@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?oo
o`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo02<0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0T0?ooo`00
9@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo02@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0A0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0T0?ooo`009@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0T0?ooo`009@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
02D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool04@3oool200000180oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo000U0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0
oooo000V0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo
0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool09@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02D0oooo000V
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0:
0?ooo`030000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02D0oooo000V0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02D0oooo000V0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
9`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0
0P3oool01`3^k^h0<c<c0000000c<c<0k^k^0?ooo`0000000`3oool2028R8P@0oooo00D0c<c<028R
8P0000008R8R0<c<c0060?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool0
0`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool0
0`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo000V0?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02P0oooo00<000000?ooo`3oool00P3oool01`1gMgL0VIVI0?ooo`2IVIT0MgMg0?ooo`0000000`3o
ool2028R8P@0oooo00D08R8R09VIV@3oool0VIVI028R8P060?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02H0oooo
000W0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool00P3oool01`0A4A40oooo0?oo
o`3oool04A4A0?ooo`0000002@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool09P3oool002L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0X0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`020?ooo`04
0000003oool0oooo0?ooo`8000002P3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c00H0oooo0`00000B
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0V
0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool0oooo0P00000:0?ooo`050<c<c000000000000000003<c<`01P3oool00`000000oooo0?oo
o`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0V0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo00H04A4A
0?ooo`3oool0oooo014A4@00000:0?ooo`05014A4@2k^k/0oooo0;^k^`0A4A401P3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool09`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo0080oooo
00H0MgMg09VIV@3oool0VIVI07MgM`00000:0?ooo`050000002k^k/0oooo0;^k^`0000001P3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0V0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo
0080oooo00H0k^k^03<c<`000000<c<c0>k^kP00000:0?ooo`050:ZZZP0A4A400000014A4@2ZZZX0
1P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0W0?ooo`009`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Y0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`00:03oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool04`3oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0:@3oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo
00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0W0?ooo`00:03oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0503oool2000001D0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02L0oooo000X
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02P0oooo000X0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo000Y0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0[0?ooo`030000003o
ool0oooo00D0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`040?ooo`030000003o
ool0oooo02P0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool0103oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0:`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo02P0oooo000Y0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01D0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0[0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02P0oooo000Y0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;@3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo000Z0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02T0oooo
000Z0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0E0?ooo`8000005P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02d0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0^
0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0]0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0:@3oool002X0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0^0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool002X0oooo00D00000
0?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool002X0oooo00D0
00000?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05P3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`000000:`3oool002X0oooo00D000000?ooo`3o
ool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@000000oooo0?ooo`3o
ool0000001P0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool000000340oooo
00D000000?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?ooo`000000:`3oool002/0
oooo00@000000?ooo`3oool00000<@3oool01@000000oooo0?ooo`3oool000000340oooo00D00000
0?ooo`3oool0oooo0000000H0?ooo`030000003oool0oooo01H0oooo00D000000?ooo`3oool0oooo
0000000a0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@000000oooo0?ooo`3oool00000
02/0oooo000[0?ooo`040000003oool0oooo00000380oooo00@000000?ooo`3oool00000<@3oool0
1@000000oooo0?ooo`3oool0000001P0oooo00<000000?ooo`3oool05P3oool01@000000oooo0?oo
o`3oool000000340oooo00D000000?ooo`3oool0oooo0000000a0?ooo`050000003oool0oooo0?oo
o`000000:`3oool002/0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0000000b0?oo
o`050000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`000000<@3oool01@000000oooo0?ooo`3oool000000340oooo00@000000?ooo`3oool0
0000;03oool002/0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0000000b0?ooo`05
0000003oool0oooo0?ooo`000000603oool00`000000oooo0?ooo`0F0?ooo`050000003oool0oooo
0?ooo`000000<@3oool01@000000oooo0?ooo`3oool000000340oooo00@000000?ooo`3oool00000
;03oool002/0oooo00@000000?ooo`3oool00000<P3oool00`000000oooo0000000c0?ooo`030000
003oool0000001T0oooo0P00000G0?ooo`050000003oool0oooo0?ooo`000000<@3oool01@000000
oooo0?ooo`3oool000000340oooo00@000000?ooo`3oool00000;03oool002/0oooo00@000000?oo
o`3oool00000<P3oool00`000000oooo0000000c0?ooo`030000003oool0000001T0oooo00<00000
0?ooo`3oool05`3oool010000000oooo0?ooo`00000a0?ooo`040000003oool0oooo000003<0oooo
00<000000?ooo`000000;03oool002/0oooo00<000000?ooo`000000<`3oool00`000000oooo0000
000c0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0000
000c0?ooo`030000003oool0000003<0oooo00<000000?ooo`000000;03oool002/0oooo00<00000
0?ooo`000000<`3oool00`000000oooo0000000c0?ooo`030000003oool0000001T0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0000000c0?ooo`030000003oool0000003<0oooo00<00000
0?ooo`000000;03oool002/0oooo00<000000?ooo`000000<`3oool00`000000oooo0000000c0?oo
o`030000003oool0000001T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0000000c0?oo
o`030000003oool0000003<0oooo00<000000?ooo`000000;03oool002/0oooo00<000000?ooo`00
0000<`3oool2000003@0oooo00<000000?ooo`0000006@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0000003<0oooo00<000000?ooo`000000<`3oool00`000000oooo0000000/0?ooo`00
;03oool2000003<0oooo0P00000d0?ooo`030000003oool0000001T0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo0380oooo0P00000]0?ooo`00;03o
ool2000003@0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`0>0?ooo`@0000000<0
4A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo03<0oooo00<0
00000?ooo`3oool0<P3oool2000002d0oooo000/0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0<`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`0c0?ooo`030000003oool0oooo03<0oooo00<00000
0?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3oool0<`3oool00`000000oooo0?ooo`160?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0c0?oo
o`030000003oool0oooo03<0oooo00<000000?ooo`3oool0:`3oool002`0oooo00<000000?ooo`3o
ool0O03oool00`000000oooo0?ooo`050?ooo`<00000603oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo0640oooo002[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0
/P3oool00:/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00Z`3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo0;80oooo002Y0?ooo`80EEEE00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-3, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "\tThis function is continuous, and its derivative is sectionally \
continuous and not singular, so according to Theorem 2.1 the Fourier series \
representation of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox["f",
            "TraditionalForm"]}], TraditionalForm]]],
  " should work. To test this conclusion, we first need to determine the \
Fourier coefficients. The ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  StyleBox["'s",
    FontSlant->"Italic"],
  " are evaluated according to Eq. ",
  ButtonBox["(2.1.9)",
    ButtonData:>"(2.1.9)",
    ButtonStyle->"Hyperlink"],
  ". We will perform this integral in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " analytically, by choosing ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o = 0\)]],
  " and breaking the integral over ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " into two pieces: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Clear[
      T]; \(\(a[
        n_]\)\(\ \)\(=\)\(\ \)\(FullSimplify[\((2/T)\) 
            Integrate[
              Cos[2\ Pi\ n\ t/T]\ 2\ t/T, {t, 0, T/2}]\  + \ \((2/T)\) 
            Integrate[Cos[2\ Pi\ n\ t/T] \((2 - 2  t/T)\), {t, T/2, T}], 
        n \[Element] Integers]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.8"],

Cell[BoxData[
    \(\(-\(\(2\ \((\(-1\))\)\^n\ \((\(-1\) + \((\(-1\))\)\^n)\)\)\/\(n\^2\ \
\[Pi]\^2\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(a[
        0]\)\(\ \)\(=\)\(\ \)\(Simplify[\((1/T)\) 
            Integrate[2\ t/T, {t, 0, T/2}]\  + \ \((1/T)\) 
            Integrate[\((2 - 2  t/T)\), {t, T/2, T}]]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.9"],

Cell[BoxData[
    \(1\/2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A list of ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  "-values can now be constructed:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[a[n], {n, 0, 10}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.10"],

Cell[BoxData[
    \({1\/2, \(-\(4\/\[Pi]\^2\)\), 0, \(-\(4\/\(9\ \[Pi]\^2\)\)\), 
      0, \(-\(4\/\(25\ \[Pi]\^2\)\)\), 0, \(-\(4\/\(49\ \[Pi]\^2\)\)\), 
      0, \(-\(4\/\(81\ \[Pi]\^2\)\)\), 0}\)], "Output"]
}, Open  ]],

Cell["\<\
For future reference, we reproduce these results for our triangle \
wave below:\
\>", "Text",
  CellTags->"i:7"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`a\_n = \(-\(4\/\(n\^2\ \[Pi]\^2\)\)\), \ \ n\ odd, \
\[IndentingNewLine]a\_o\  = \ 1/2. \)]]], "NumberedEquation",
  CellTags->"(2.1.11)"],

Cell[TextData[{
  "Similarly, we can work out the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(b\_n\), 
            StyleBox["'",
              FontSlant->"Italic"]}], 
          StyleBox["s",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " by replacing the cosine functions in the above integrals with sine \
functions. However, we can save ourselves some work  by noticing that ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is an ",
  StyleBox["even function of t:",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(\(-t\)) = f(t)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.12)"],

Cell[TextData[{
  "Since sine functions are odd in ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\(-\[Omega]\)\ t) = \(\(-sin\)\(\ \)\(\[Omega]\)\
\(\ \)\(t\)\(\ \)\)\)]],
  ",",
  " the Fourier sum involving the sines is also an odd function of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", and therefore cannot enter into the representation of the even function \
",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". This can be proven rigorously if we choose ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o = \(-T\)/2\)]],
  " in Eq. ",
  ButtonBox["(2.1.10)",
    ButtonData:>"(2.1.10)",
    ButtonStyle->"Hyperlink"],
  ". The integrand is an odd function multiplied by an even function, and is \
therefore odd. Integrating this odd function from",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(-T\)/2\)\)\)]],
  " to",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(T/2\)\)\)]],
  " must yield zero, so therefore ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "For an even function",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f(t)\)\)\)]],
  ", the Fourier representation involves only Fourier cosine modes; for an \
odd function it involves only Fourier sine modes."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:13"],

Cell[TextData[{
  "\tThus, our triangle wave can be represented by a Fourier cosine series. \
We can construct this series in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " provided that we keep only a finite number of terms; otherwise the \
evaluation of the series takes an infinitely long time. Let's keep only ",
  StyleBox["M",
    FontSlant->"Italic"],
  " terms in the series, and call the resulting function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_approx\)(t, M)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(f\_approx[t_, M_]\  := \ 
      Sum[a[n]\ Cos[2  Pi\ n\ t/T], {n, 0, M}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.11"],

Cell[TextData[{
  "For a given period ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\)\(\ \)\)\)]],
  "we can plot this function for increasing ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  "values and watch how the series converges  to the triangle wave: see Cell \
",
  ButtonBox["2.12",
    ButtonData:>"Cell 2.12",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = 1; \ 
    Table[Plot[f\_approx[t, M], {t, 0, 2}, PlotRange \[Rule] {\(- .2\), 1.2}, 
        PlotLabel \[Rule] "\<M = \>" <> ToString[M]], {M, 1, 11, 
        2}];\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.12"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0882906 0.441453 [
[.2619 .07579 -9 -9 ]
[.2619 .07579 9 0 ]
[.5 .07579 -3 -9 ]
[.5 .07579 3 0 ]
[.7381 .07579 -9 -9 ]
[.7381 .07579 9 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .17658 -18 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -18 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08829 m
.2619 .09454 L
s
[(0.5)] .2619 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(1)] .5 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1.5)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.02381 0 m
.03006 0 L
s
[(-0.2)] .01131 0 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(0.2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(0.4)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(0.6)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(0.8)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(1)] .01131 .52974 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .1301 m
.02499 .13012 L
.02605 .13018 L
.02729 .13029 L
.02846 .13044 L
.03053 .13081 L
.03279 .13136 L
.03527 .13214 L
.0379 .13319 L
.04262 .13558 L
.05205 .14238 L
.06244 .15285 L
.0842 .18396 L
.10458 .22245 L
.14335 .31018 L
.18458 .4026 L
.20517 .44009 L
.21519 .45501 L
.22428 .46634 L
.2338 .47577 L
.24277 .48226 L
.2477 .4848 L
.25224 .48648 L
.25461 .4871 L
.25597 .48738 L
.25722 .48759 L
.25853 .48775 L
.25925 .48782 L
.25994 .48787 L
.26115 .48792 L
.26184 .48793 L
.26248 .48793 L
.26365 .48788 L
.26489 .48779 L
.26595 .48768 L
.26711 .48751 L
.2697 .48699 L
.2721 .48631 L
.27647 .48464 L
.28114 .4822 L
.28669 .47845 L
.29194 .47407 L
.30174 .46378 L
.32176 .43498 L
.34021 .40063 L
.37961 .31218 L
.4175 .22604 L
.43858 .18571 L
.45784 .15708 L
.46737 .14643 L
Mistroke
.4724 .14184 L
.47776 .13775 L
.48291 .13463 L
.48757 .1325 L
.48982 .13171 L
.49225 .13104 L
.49337 .13079 L
.49455 .13056 L
.49565 .1304 L
.49666 .13028 L
.49789 .13017 L
.49854 .13014 L
.49922 .13011 L
.50037 .13011 L
.50164 .13014 L
.50276 .13022 L
.50398 .13035 L
.50512 .13051 L
.50617 .1307 L
.50854 .13124 L
.51113 .13203 L
.51634 .13425 L
.52094 .13689 L
.52585 .14041 L
.53469 .14852 L
.54496 .16067 L
.55607 .17688 L
.57624 .21325 L
.61721 .30468 L
.65666 .39422 L
.6765 .43203 L
.6946 .45927 L
.70461 .47075 L
.71409 .47903 L
.71929 .48245 L
.7241 .48489 L
.72661 .48588 L
.72938 .48675 L
.73077 .4871 L
.73228 .4874 L
.73369 .48763 L
.735 .48778 L
.73627 .48788 L
.73747 .48793 L
.73855 .48793 L
.73973 .48789 L
.741 .4878 L
.74165 .48773 L
.74236 .48765 L
.74362 .48746 L
Mistroke
.74478 .48723 L
.74705 .48668 L
.74949 .48591 L
.7539 .48406 L
.75897 .48119 L
.76451 .47718 L
.77459 .46759 L
.79428 .44098 L
.81525 .40295 L
.85686 .3097 L
.89694 .21932 L
.91533 .18475 L
.92577 .16825 L
.93551 .15526 L
.94506 .14498 L
.94997 .14071 L
.9553 .13686 L
.95822 .13511 L
.96091 .13373 L
.96344 .13263 L
.96623 .13165 L
.96872 .13097 L
.97106 .13051 L
.97235 .13033 L
.97353 .13021 L
.97483 .13013 L
.97548 .13011 L
.97619 .1301 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`003goo0`001Woo0P0017oo1@00ogooAWoo000>Ool01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol00?moodIoo`001Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo0?moodIo
o`003Woo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<00?mooceoo`003Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00
Oomoo`3oOolmOol000moo`<000eoo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00
Oomoo`0nOol30006Ool20005Ool40010Ool5000oOol50004Ool20005Ool4000oOol5000>Ool002Uo
o`03001oogoo03eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0oOol00`00Oomoo`11Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`0mOol01000Oomoo`003Woo000YOol00`00Oomoo`0mOol0
1@00Oomoogoo000047oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
?Woo00<007ooOol03Woo000YOol00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0?goo
00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0?goo00<007ooOol03Goo000YOol00`00Oomo
o`0mOol01@00Oomoogoo000037oo1000@Woo00<007ooOol0@Goo00<007ooOol02goo1000@goo00<0
07ooOol037oo000YOol00`00Oomoo`0mOol01@00Oomoogoo000037oo00<007ooOol0@goo00<007oo
Ool0@Goo00<007ooOol02goo00<007ooOol0A7oo00<007ooOol037oo000YOol2000nOol01@00Oomo
ogoo000037oo00<007ooOol0@goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0@7oo00D0
07ooOomoo`0000ioo`00:Goo00<007ooOol0?Woo0`003Goo1000@7oo0`00@Goo0`003Goo1000@7oo
0`003goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`008Gooo`00@00027oo
000YOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool002Uoo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03
001oogoo04Uoo`03001oogoo00eoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolm
Ool002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol2003oOolnOol002Uo
o`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uo
o`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol3002BOol5002BOol4000?Ool0
02Uoo`H008eoo`8000Eoo`@008aoo`<0019oo`00:Goo00<007ooOol00goo0P00RGoo0P002goo00<0
07ooOol0Qgoo0P005Goo000YOol00`00Oomoo`05Ool00`00Oomoo`24Ool2000>Ool00`00Oomoo`25
Ool00`00Oomoo`0EOol002Uoo`03001oogoo00Ioo`03001oogoo089oo`03001oogoo00moo`03001o
ogoo08=oo`03001oogoo01Ioo`00:Goo00<007ooOol01goo00<007ooOol0P7oo00<007ooOol04Goo
00<007ooOol0PGoo00<007ooOol05goo000YOol00`00Oomoo`08Ool00`00Oomoo`1oOol00`00Oomo
o`0BOol00`00Oomoo`1oOol00`00Oomoo`0HOol002Uoo`03001oogoo00Uoo`03001oogoo07eoo`03
001oogoo01Aoo`03001oogoo07eoo`03001oogoo01Uoo`00:Goo0P002Woo00<007ooOol0O7oo00<0
07ooOol05Woo00<007ooOol0Ngoo00<007ooOol06Woo000YOol00`00Oomoo`0:Ool00`00Oomoo`1j
Ool00`00Oomoo`0HOol00`00Oomoo`1jOol00`00Oomoo`0JOol002Uoo`03001oogoo00]oo`03001o
ogoo07Uoo`03001oogoo01Uoo`03001oogoo07Qoo`03001oogoo01]oo`00:Goo00<007ooOol02goo
00<007ooOol0N7oo00<007ooOol06Woo00<007ooOol0Mgoo00<007ooOol077oo000?Ool30006Ool2
0004Ool50006Ool00`00Oomoo`0<Ool00`00Oomoo`1fOol00`00Oomoo`0LOol00`00Oomoo`1eOol0
0`00Oomoo`0MOol000ioo`05001oogooOol00005Ool20005Ool01000Oomoo`001Woo00<007ooOol0
3Goo00<007ooOol0MGoo00<007ooOol07Goo00<007ooOol0M7oo00<007ooOol07Goo000>Ool01@00
Oomoogoo00003Goo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol0Lgoo00<007ooOol07Woo
00<007ooOol0Lgoo00<007ooOol07Woo000>Ool01@00Oomoogoo00003Woo00<007ooOol01Goo0`00
3Woo00<007ooOol0LWoo00<007ooOol087oo00<007ooOol0LGoo00<007ooOol07goo000>Ool01@00
Oomoogoo00003goo00<007ooOol017oo00<007ooOol03goo00<007ooOol0LGoo00<007ooOol087oo
00<007ooOol0LGoo00<007ooOol07goo000>Ool01@00Oomoogoo00003goo00<007ooOol017oo00<0
07ooOol047oo00<007ooOol0Kgoo00<007ooOol08Woo00<007ooOol0Kgoo00<007ooOol087oo000>
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo011oo`03001oogoo06ioo`03
001oogoo02=oo`03001oogoo06ioo`03001oogoo025oo`003goo0`003Goo0`001goo00<007ooOol0
4Goo00<007ooOol0KGoo00<007ooOol097oo00<007ooOol0KGoo00<007ooOol08Goo000YOol00`00
Oomoo`0AOol00`00Oomoo`1/Ool00`00Oomoo`0UOol00`00Oomoo`1/Ool00`00Oomoo`0ROol002Uo
o`03001oogoo019oo`03001oogoo06]oo`03001oogoo02Ioo`03001oogoo06]oo`03001oogoo029o
o`00:Goo0P004goo00<007ooOol0JWoo00<007ooOol09goo00<007ooOol0JWoo00<007ooOol08goo
000YOol00`00Oomoo`0COol00`00Oomoo`1YOol00`00Oomoo`0XOol00`00Oomoo`1YOol00`00Oomo
o`0SOol002Uoo`03001oogoo01=oo`03001oogoo06Qoo`03001oogoo02Uoo`03001oogoo06Qoo`03
001oogoo02Aoo`00:Goo00<007ooOol04goo00<007ooOol0Igoo00<007ooOol0:goo00<007ooOol0
Igoo00<007ooOol097oo000YOol00`00Oomoo`0DOol00`00Oomoo`1VOol00`00Oomoo`0[Ool00`00
Oomoo`1WOol00`00Oomoo`0TOol002Uoo`03001oogoo01Aoo`03001oogoo06Eoo`03001oogoo02eo
o`03001oogoo06Eoo`03001oogoo02Eoo`00:Goo00<007ooOol05Goo00<007ooOol0I7oo00<007oo
Ool0;Goo00<007ooOol0IGoo00<007ooOol09Goo000YOol2000FOol00`00Oomoo`1SOol00`00Oomo
o`0_Ool00`00Oomoo`1SOol00`00Oomoo`0VOol002Uoo`03001oogoo01Ioo`03001oogoo069oo`03
001oogoo02moo`03001oogoo06=oo`03001oogoo02Ioo`00:Goo00<007ooOol05Woo00<007ooOol0
HGoo00<007ooOol0<Goo00<007ooOol0HGoo00<007ooOol09goo000YOol00`00Oomoo`0GOol00`00
Oomoo`1POol00`00Oomoo`0aOol00`00Oomoo`1QOol00`00Oomoo`0WOol002Uoo`03001oogoo01Mo
o`03001oogoo05moo`03001oogoo03=oo`03001oogoo05moo`03001oogoo02Qoo`00:Goo00<007oo
Ool067oo00<007ooOol0GWoo00<007ooOol0<goo00<007ooOol0Ggoo00<007ooOol0:7oo000YOol0
0`00Oomoo`0HOol00`00Oomoo`1MOol00`00Oomoo`0eOol00`00Oomoo`1MOol00`00Oomoo`0YOol0
02Uoo`8001Yoo`03001oogoo05aoo`03001oogoo03Eoo`03001oogoo05eoo`03001oogoo02Uoo`00
:Goo00<007ooOol06Goo00<007ooOol0G7oo00<007ooOol0=Woo00<007ooOol0G7oo00<007ooOol0
:Goo000YOol00`00Oomoo`0IOol00`00Oomoo`1KOol00`00Oomoo`0gOol00`00Oomoo`1KOol00`00
Oomoo`0ZOol002Uoo`03001oogoo01Yoo`03001oogoo05Yoo`03001oogoo03Qoo`03001oogoo05Yo
o`03001oogoo02Yoo`00:Goo00<007ooOol06Woo00<007ooOol0FGoo00<007ooOol0>Goo00<007oo
Ool0FGoo00<007ooOol0:goo000?Ool30006Ool20006Ool30006Ool00`00Oomoo`0KOol00`00Oomo
o`1HOol00`00Oomoo`0jOol00`00Oomoo`1HOol00`00Oomoo`0[Ool000ioo`05001oogooOol00005
Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0KOol00`00Oomoo`1GOol00`00Oomoo`0kOol00`00
Oomoo`1GOol00`00Oomoo`0/Ool000ioo`05001oogooOol0000;Ool50006Ool3000LOol00`00Oomo
o`1FOol00`00Oomoo`0kOol00`00Oomoo`1GOol00`00Oomoo`0/Ool000ioo`05001oogooOol0000;
Ool01000Oomoo`001goo00<007ooOol077oo00<007ooOol0EGoo00<007ooOol0?Goo00<007ooOol0
EGoo00<007ooOol0;Goo000>Ool01@00Oomoogoo000037oo00<007oo00001goo00<007ooOol07Goo
00<007ooOol0E7oo00<007ooOol0?Goo00<007ooOol0EGoo00<007ooOol0;Goo000>Ool01@00Oomo
ogoo000037oo00<007oo00001goo00<007ooOol07Goo00<007ooOol0E7oo00<007ooOol0?Woo00<0
07ooOol0Dgoo00<007ooOol0;Woo000>Ool01@00Oomoogoo00003Goo0P001goo00<007ooOol07Woo
00<007ooOol0DWoo00<007ooOol0?goo00<007ooOol0Dgoo00<007ooOol0;Woo000?Ool3000?Ool0
0`00Oomoo`05Ool00`00Oomoo`0NOol00`00Oomoo`1BOol00`00Oomoo`10Ool00`00Oomoo`1AOol0
0`00Oomoo`0_Ool002Uoo`03001oogoo01moo`03001oogoo051oo`03001oogoo045oo`03001oogoo
055oo`03001oogoo02moo`00:Goo0P0087oo00<007ooOol0D7oo00<007ooOol0@Woo00<007ooOol0
Cgoo00<007ooOol0<7oo000YOol00`00Oomoo`0POol00`00Oomoo`1>Ool00`00Oomoo`13Ool00`00
Oomoo`1?Ool00`00Oomoo`0`Ool002Uoo`03001oogoo021oo`03001oogoo04ioo`03001oogoo04Ao
o`03001oogoo04ioo`03001oogoo031oo`00:Goo00<007ooOol087oo00<007ooOol0CGoo00<007oo
Ool0AGoo00<007ooOol0CGoo00<007ooOol0<Goo000YOol00`00Oomoo`0QOol00`00Oomoo`1<Ool0
0`00Oomoo`16Ool00`00Oomoo`1<Ool00`00Oomoo`0aOol002Uoo`03001oogoo025oo`03001oogoo
04aoo`03001oogoo04Ioo`03001oogoo04]oo`03001oogoo039oo`00:Goo00<007ooOol08Woo00<0
07ooOol0BWoo00<007ooOol0B7oo00<007ooOol0BWoo00<007ooOol0<Woo000YOol2000SOol00`00
Oomoo`1:Ool00`00Oomoo`18Ool00`00Oomoo`19Ool00`00Oomoo`0cOol002Uoo`03001oogoo02=o
o`03001oogoo04Qoo`03001oogoo04Yoo`03001oogoo04Qoo`03001oogoo03=oo`00:Goo00<007oo
Ool08goo00<007ooOol0B7oo00<007ooOol0BWoo00<007ooOol0Agoo00<007ooOol0=7oo000YOol0
0`00Oomoo`0TOol00`00Oomoo`16Ool00`00Oomoo`1<Ool00`00Oomoo`16Ool00`00Oomoo`0dOol0
02Uoo`03001oogoo02Aoo`03001oogoo04Ioo`03001oogoo04aoo`03001oogoo04Eoo`03001oogoo
03Eoo`00:Goo00<007ooOol09Goo00<007ooOol0A7oo00<007ooOol0CGoo00<007ooOol0AGoo00<0
07ooOol0=Goo000YOol00`00Oomoo`0UOol00`00Oomoo`14Ool00`00Oomoo`1>Ool00`00Oomoo`14
Ool00`00Oomoo`0eOol002Uoo`8002Ioo`03001oogoo04=oo`03001oogoo04moo`03001oogoo04=o
o`03001oogoo03Ioo`00:Goo00<007ooOol09Woo00<007ooOol0@Woo00<007ooOol0D7oo00<007oo
Ool0@Woo00<007ooOol0=Woo000YOol00`00Oomoo`0VOol00`00Oomoo`12Ool00`00Oomoo`1@Ool0
0`00Oomoo`11Ool00`00Oomoo`0gOol002Uoo`03001oogoo02Moo`03001oogoo041oo`03001oogoo
059oo`03001oogoo041oo`03001oogoo03Moo`00:Goo00<007ooOol09goo00<007ooOol0@7oo00<0
07ooOol0DWoo00<007ooOol0?goo00<007ooOol0>7oo000?Ool30006Ool20005Ool30007Ool00`00
Oomoo`0XOol00`00Oomoo`0nOol00`00Oomoo`1COol00`00Oomoo`0oOol00`00Oomoo`0hOol000io
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo00001Woo00<007ooOol0:7oo00<007ooOol0
?Woo00<007ooOol0E7oo00<007ooOol0?Woo00<007ooOol0>7oo000>Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Ioo`<002Uoo`03001oogoo03aoo`03001oogoo05Eoo`03001oogoo03eoo`03
001oogoo03Uoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0YOol0
0`00Oomoo`0lOol00`00Oomoo`1FOol00`00Oomoo`0lOol00`00Oomoo`0iOol000ioo`05001oogoo
Ool0000;Ool40007Ool00`00Oomoo`0ZOol00`00Oomoo`0jOol00`00Oomoo`1GOol00`00Oomoo`0k
Ool00`00Oomoo`0jOol000ioo`05001oogooOol0000;Ool00`00Oomoo`08Ool00`00Oomoo`0ZOol0
0`00Oomoo`0jOol00`00Oomoo`1HOol00`00Oomoo`0jOol00`00Oomoo`0jOol000ioo`05001oogoo
Ool0000<Ool00`00Oomoo`07Ool00`00Oomoo`0ZOol00`00Oomoo`0iOol00`00Oomoo`1IOol00`00
Oomoo`0iOol00`00Oomoo`0kOol000moo`<000ioo`<000Ioo`03001oogoo02]oo`03001oogoo03Qo
o`03001oogoo05Uoo`03001oogoo03Uoo`03001oogoo03]oo`00:Goo00<007ooOol0:goo00<007oo
Ool0=goo00<007ooOol0Fgoo00<007ooOol0>7oo00<007ooOol0>goo000YOol2000]Ool00`00Oomo
o`0fOol00`00Oomoo`1KOol00`00Oomoo`0gOol00`00Oomoo`0lOol002Uoo`03001oogoo02aoo`03
001oogoo03Eoo`03001oogoo05eoo`03001oogoo03Ioo`03001oogoo03aoo`00:Goo00<007ooOol0
;Goo00<007ooOol0=7oo00<007ooOol0GGoo00<007ooOol0=Goo00<007ooOol0?Goo000YOol00`00
Oomoo`0]Ool00`00Oomoo`0dOol00`00Oomoo`1NOol00`00Oomoo`0dOol00`00Oomoo`0mOol002Uo
o`03001oogoo02ioo`03001oogoo039oo`03001oogoo05moo`03001oogoo03=oo`03001oogoo03io
o`00:Goo00<007ooOol0;Woo00<007ooOol0<Woo00<007ooOol0Ggoo00<007ooOol0<goo00<007oo
Ool0?Woo000YOol00`00Oomoo`0^Ool00`00Oomoo`0aOol00`00Oomoo`1QOol00`00Oomoo`0bOol0
0`00Oomoo`0nOol002Uoo`80031oo`03001oogoo031oo`03001oogoo065oo`03001oogoo035oo`03
001oogoo03moo`00:Goo00<007ooOol0;goo00<007ooOol0;goo00<007ooOol0Hgoo00<007ooOol0
<7oo00<007ooOol0?goo000YOol00`00Oomoo`0`Ool00`00Oomoo`0^Ool00`00Oomoo`1SOol00`00
Oomoo`0_Ool00`00Oomoo`10Ool002Uoo`03001oogoo031oo`03001oogoo02eoo`03001oogoo06Eo
o`03001oogoo02ioo`03001oogoo041oo`00:Goo00<007ooOol0<Goo00<007ooOol0;7oo00<007oo
Ool0IGoo00<007ooOol0;Goo00<007ooOol0@Goo000YOol00`00Oomoo`0aOol00`00Oomoo`0[Ool0
0`00Oomoo`1WOol00`00Oomoo`0/Ool00`00Oomoo`11Ool002Uoo`03001oogoo039oo`03001oogoo
02Yoo`03001oogoo06Moo`03001oogoo02]oo`03001oogoo049oo`00:Goo0P00<goo00<007ooOol0
:Goo00<007ooOol0JGoo00<007ooOol0:Goo00<007ooOol0@goo000YOol00`00Oomoo`0cOol00`00
Oomoo`0WOol00`00Oomoo`1ZOol00`00Oomoo`0YOol00`00Oomoo`13Ool002Uoo`03001oogoo03=o
o`03001oogoo02Moo`03001oogoo06]oo`03001oogoo02Moo`03001oogoo04Aoo`00:Goo00<007oo
Ool0=7oo00<007ooOol09Goo00<007ooOol0K7oo00<007ooOol09goo00<007ooOol0A7oo000YOol0
0`00Oomoo`0dOol00`00Oomoo`0UOol00`00Oomoo`1]Ool00`00Oomoo`0UOol00`00Oomoo`15Ool0
00moo`<000Ioo`8000Eoo`<000Moo`03001oogoo03Eoo`03001oogoo02=oo`03001oogoo06ioo`03
001oogoo02Aoo`03001oogoo04Ioo`003Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol0
0006Ool00`00Oomoo`0eOol00`00Oomoo`0SOol00`00Oomoo`1_Ool00`00Oomoo`0SOol00`00Oomo
o`16Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo0`00=Woo00<007ooOol08Goo
00<007ooOol0LGoo00<007ooOol08Goo00<007ooOol0Agoo000>Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0000Ioo`03001oogoo03Ioo`03001oogoo021oo`03001oogoo079oo`03001oogoo025o
o`03001oogoo04Moo`003Woo00D007ooOomoo`0000aoo`<000Moo`03001oogoo03Moo`03001oogoo
01moo`03001oogoo07=oo`03001oogoo01moo`03001oogoo04Qoo`003Woo00D007ooOomoo`0000]o
o`05001oogooOol00006Ool00`00Oomoo`0hOol00`00Oomoo`0MOol00`00Oomoo`1eOol00`00Oomo
o`0MOol00`00Oomoo`19Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo00<007oo
Ool0>Goo00<007ooOol06goo00<007ooOol0MWoo00<007ooOol07Goo00<007ooOol0BGoo000?Ool3
000=Ool30007Ool00`00Oomoo`0jOol00`00Oomoo`0JOol00`00Oomoo`1gOol00`00Oomoo`0KOol0
0`00Oomoo`1:Ool002Uoo`03001oogoo03Yoo`03001oogoo01Uoo`03001oogoo07Uoo`03001oogoo
01Uoo`03001oogoo04]oo`00:Goo0P00?7oo00<007ooOol05goo00<007ooOol0NWoo00<007ooOol0
6Goo00<007ooOol0Bgoo000YOol00`00Oomoo`0lOol00`00Oomoo`0FOol00`00Oomoo`1kOol00`00
Oomoo`0GOol00`00Oomoo`1<Ool002Uoo`03001oogoo03eoo`03001oogoo01Aoo`03001oogoo07eo
o`03001oogoo01Aoo`8004moo`00:Goo00<007ooOol0?Woo00<007ooOol04Woo00<007ooOol0Ogoo
0P004goo00<007ooOol0Cgoo000YOol00`00Oomoo`0oOol2000@Ool20024Ool00`00Oomoo`0?Ool0
0`00Oomoo`1@Ool002Uoo`03001oogoo045oo`03001oogoo00aoo`03001oogoo08Eoo`8000ioo`03
001oogoo055oo`00:Goo00<007ooOol0@Woo0P002Woo0P00RWoo0P002Woo0P00E7oo000YOol20015
Ool00`00Oomoo`06Ool00`00Oomoo`2<Ool00`00Oomoo`05Ool2001FOol002Uoo`03001oogoo04Eo
o`P0091oo`L005Qoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03
001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`80
0?moocioo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo
0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000OOol50005Ool00`00Oomoo`3oOolmOol0025oo`03
001oogoo00Eoo`03001oogoo0?mooceoo`008Goo00<007ooOol01Goo0`00ogoo?Goo000QOol00`00
Oomoo`05Ool00`00Oomoo`3oOolmOol0025oo`03001oogoo00Eoo`03001oogoo0?mooceoo`008Goo
00<007ooOol01Goo00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05Ool00`00Oomoo`3oOolmOol0
01moo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol2003oOolnOol0
02Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol0
02Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol0
02Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03
001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03
001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo
0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo
0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo
0?mooceoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo002]Ool30002Ool3000HOol5002FOol00:ioo`03001oogoo009oo`03001oogoo00Moo`H000ao
o`03001oogoo09Ioo`00[Woo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0UWoo002^Ool0
1P00Ool00000Ool000Uoo`H000aoo`03001oogoo09Ioo`00[Woo00H007oo000007oo000KOol00`00
Oomoo`2FOol00:ioo`80009oo`8001]oo`03001oogoo09Ioo`00[Woo0P000Woo0P006goo00<007oo
Ool0UWoo002]Ool20004Ool2000HOol3002HOol00?moofUoo`00ogooJGoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0882906 0.441453 [
[.2619 .07579 -9 -9 ]
[.2619 .07579 9 0 ]
[.5 .07579 -3 -9 ]
[.5 .07579 3 0 ]
[.7381 .07579 -9 -9 ]
[.7381 .07579 9 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .17658 -18 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -18 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08829 m
.2619 .09454 L
s
[(0.5)] .2619 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(1)] .5 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1.5)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.02381 0 m
.03006 0 L
s
[(-0.2)] .01131 0 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(0.2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(0.4)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(0.6)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(0.8)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(1)] .01131 .52974 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .11022 m
.02499 .11027 L
.02605 .11038 L
.02729 .1106 L
.02846 .1109 L
.03053 .11163 L
.03279 .11272 L
.03527 .11427 L
.0379 .11632 L
.04262 .12096 L
.05205 .13369 L
.06244 .15203 L
.10458 .2423 L
.14487 .31218 L
.18364 .38085 L
.20335 .42363 L
.21376 .4465 L
.22486 .46906 L
.23566 .4874 L
.24076 .49433 L
.24546 .49955 L
.25018 .50357 L
.25267 .50517 L
.25394 .50584 L
.2553 .50646 L
.25649 .5069 L
.25759 .50723 L
.25868 .50749 L
.25972 .50766 L
.26093 .50778 L
.26204 .50781 L
.26327 .50775 L
.26457 .50759 L
.26571 .50736 L
.26695 .50702 L
.26946 .50604 L
.27178 .50479 L
.27394 .50334 L
.27883 .49907 L
.28404 .49307 L
.29362 .47866 L
.30232 .46251 L
.3423 .37649 L
.38077 .3093 L
.42169 .23727 L
.44205 .19307 L
.46109 .15256 L
.47046 .13575 L
.47936 .12309 L
.48426 .1178 L
Mistroke
.48685 .11554 L
.48961 .11356 L
.49216 .11213 L
.49447 .11117 L
.49559 .11083 L
.4968 .11054 L
.49793 .11036 L
.49898 .11026 L
.50025 .11023 L
.50145 .11029 L
.50252 .11042 L
.50369 .11065 L
.50497 .11099 L
.50632 .11146 L
.50874 .11259 L
.51098 .11394 L
.51307 .11548 L
.51784 .11991 L
.5278 .133 L
.53852 .1518 L
.57971 .24015 L
.61939 .30955 L
.65755 .37619 L
.67884 .42207 L
.69816 .46347 L
.70783 .48109 L
.71291 .48893 L
.71829 .49593 L
.72299 .50082 L
.72549 .50292 L
.72816 .50476 L
.73062 .50608 L
.73287 .50696 L
.73395 .50727 L
.73512 .50754 L
.73623 .5077 L
.73726 .50779 L
.73843 .50781 L
.73967 .50773 L
.74073 .50759 L
.74188 .50736 L
.74313 .50702 L
.74447 .50655 L
.74687 .50543 L
.7493 .50393 L
.7516 .5022 L
.7559 .49816 L
.76578 .48522 L
.77649 .46646 L
.81738 .37876 L
Mistroke
.85675 .30963 L
.89461 .24394 L
.91566 .1988 L
.93491 .15724 L
.94443 .13946 L
.94945 .13138 L
.95481 .12401 L
.95995 .11829 L
.96461 .11436 L
.96686 .11292 L
.96929 .1117 L
.97041 .11126 L
.97159 .11088 L
.9726 .11062 L
.97371 .11042 L
.97491 .11028 L
.97619 .11022 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`003goo0`001Woo0P0017oo1@00ogooAWoo000>Ool01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol00?moodIoo`001Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo0?moodIo
o`003Woo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<00?mooceoo`003Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00
Oomoo`3oOolmOol000moo`<000eoo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00
Oomoo`0nOol30006Ool20005Ool40010Ool5000oOol50004Ool20005Ool4000oOol5000>Ool002Uo
o`03001oogoo03eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0oOol00`00Oomoo`11Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`0mOol01000Oomoo`003Woo000YOol00`00Oomoo`0mOol0
1@00Oomoogoo000047oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
?Woo00<007ooOol03Woo000YOol00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0?goo
00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0?goo00<007ooOol03Goo000YOol00`00Oomo
o`0mOol01@00Oomoogoo000037oo1000@Woo00<007ooOol0@Goo00<007ooOol02goo1000@goo00<0
07ooOol037oo000YOol00`00Oomoo`0mOol01@00Oomoogoo000037oo00<007ooOol0@goo00<007oo
Ool0@Goo00<007ooOol02goo00<007ooOol0A7oo00<007ooOol037oo000YOol2000nOol01@00Oomo
ogoo000037oo00<007ooOol0@goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0@7oo00D0
07ooOomoo`0000ioo`00:Goo00<007ooOol0?Woo0`003Goo1000@7oo0`00@Goo0`003Goo1000@7oo
0`003goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`008Gooo`00@00027oo
000YOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool002Uoo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03
001oogoo04Uoo`03001oogoo00eoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolm
Ool002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol3002BOol5002COol3
000?Ool002Uoo`04001oo`00002@Ool00`00Oomoo`03Ool2002?Ool2000BOol002Uoo`04001oogoo
Ool2002<Ool20007Ool2002=Ool00`00Oomoo`0BOol002Uoo`03001oogoo00=oo`03001oogoo08Uo
o`03001oogoo00Qoo`03001oogoo08Uoo`03001oogoo01=oo`00:Goo00<007ooOol00goo00<007oo
Ool0R7oo00<007ooOol02Goo00<007ooOol0R7oo00<007ooOol057oo000YOol00`00Oomoo`04Ool0
0`00Oomoo`27Ool00`00Oomoo`0:Ool00`00Oomoo`27Ool00`00Oomoo`0DOol002Uoo`03001oogoo
00Eoo`03001oogoo08Eoo`03001oogoo00aoo`03001oogoo08Eoo`03001oogoo01Eoo`00:Goo0P00
1goo00<007ooOol0Pgoo00<007ooOol03Woo00<007ooOol0Pgoo00<007ooOol05Woo000YOol00`00
Oomoo`06Ool00`00Oomoo`22Ool00`00Oomoo`0?Ool00`00Oomoo`23Ool00`00Oomoo`0FOol002Uo
o`03001oogoo00Moo`03001oogoo085oo`03001oogoo011oo`03001oogoo085oo`03001oogoo01Mo
o`00:Goo00<007ooOol01goo00<007ooOol0P7oo00<007ooOol04Goo00<007ooOol0PGoo00<007oo
Ool05goo000YOol00`00Oomoo`08Ool00`00Oomoo`1nOol00`00Oomoo`0COol00`00Oomoo`1oOol0
0`00Oomoo`0HOol002Uoo`03001oogoo00Qoo`03001oogoo07ioo`03001oogoo01=oo`03001oogoo
07moo`03001oogoo01Qoo`00:Goo00<007ooOol02Goo00<007ooOol0O7oo00<007ooOol05Goo00<0
07ooOol0OGoo00<007ooOol06Goo000YOol2000:Ool00`00Oomoo`1lOol00`00Oomoo`0EOol00`00
Oomoo`1mOol00`00Oomoo`0IOol002Uoo`03001oogoo00Yoo`03001oogoo07Yoo`03001oogoo01Mo
o`03001oogoo07]oo`03001oogoo01Yoo`00:Goo00<007ooOol02Woo00<007ooOol0NWoo00<007oo
Ool05goo00<007ooOol0Ngoo00<007ooOol06Woo000YOol00`00Oomoo`0;Ool00`00Oomoo`1hOol0
0`00Oomoo`0IOol00`00Oomoo`1iOol00`00Oomoo`0KOol000moo`<000Ioo`8000Aoo`D000Ioo`03
001oogoo00]oo`03001oogoo07Qoo`03001oogoo01Uoo`03001oogoo07Uoo`03001oogoo01]oo`00
3Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0006Ool00`00Oomoo`0;Ool00`00Oomoo`1g
Ool00`00Oomoo`0KOol00`00Oomoo`1gOol00`00Oomoo`0LOol000ioo`05001oogooOol0000=Ool0
0`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`1fOol00`00Oomoo`0KOol00`00Oomoo`1gOol0
0`00Oomoo`0LOol000ioo`05001oogooOol0000>Ool00`00Oomoo`05Ool3000<Ool00`00Oomoo`1f
Ool00`00Oomoo`0LOol00`00Oomoo`1eOol00`00Oomoo`0MOol000ioo`05001oogooOol0000?Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`1dOol00`00Oomoo`0MOol00`00Oomoo`1eOol0
0`00Oomoo`0MOol000ioo`05001oogooOol0000?Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00
Oomoo`1dOol00`00Oomoo`0NOol00`00Oomoo`1dOol00`00Oomoo`0MOol000ioo`05001oogooOol0
000;Ool01@00Oomoogoo00001Woo00<007ooOol03Woo00<007ooOol0LWoo00<007ooOol07goo00<0
07ooOol0Lgoo00<007ooOol07Woo000?Ool3000=Ool30007Ool00`00Oomoo`0>Ool00`00Oomoo`1b
Ool00`00Oomoo`0POol00`00Oomoo`1bOol00`00Oomoo`0NOol002Uoo`03001oogoo00moo`03001o
ogoo071oo`03001oogoo025oo`03001oogoo075oo`03001oogoo01moo`00:Goo00<007ooOol03goo
00<007ooOol0L7oo00<007ooOol08Woo00<007ooOol0L7oo00<007ooOol07goo000YOol2000AOol0
0`00Oomoo`1^Ool00`00Oomoo`0SOol00`00Oomoo`1_Ool00`00Oomoo`0POol002Uoo`03001oogoo
011oo`03001oogoo06ioo`03001oogoo02Aoo`03001oogoo06ioo`03001oogoo021oo`00:Goo00<0
07ooOol047oo00<007ooOol0KGoo00<007ooOol09Goo00<007ooOol0KGoo00<007ooOol08Goo000Y
Ool00`00Oomoo`0AOol00`00Oomoo`1/Ool00`00Oomoo`0VOol00`00Oomoo`1/Ool00`00Oomoo`0Q
Ool002Uoo`03001oogoo015oo`03001oogoo06]oo`03001oogoo02Moo`03001oogoo06]oo`03001o
ogoo029oo`00:Goo00<007ooOol04Woo00<007ooOol0JWoo00<007ooOol0:7oo00<007ooOol0JWoo
00<007ooOol08Woo000YOol00`00Oomoo`0BOol00`00Oomoo`1YOol00`00Oomoo`0YOol00`00Oomo
o`1YOol00`00Oomoo`0SOol002Uoo`8001Aoo`03001oogoo06Qoo`03001oogoo02Yoo`03001oogoo
06Qoo`03001oogoo02=oo`00:Goo00<007ooOol04goo00<007ooOol0Igoo00<007ooOol0:goo00<0
07ooOol0Igoo00<007ooOol097oo000YOol00`00Oomoo`0DOol00`00Oomoo`1VOol00`00Oomoo`0/
Ool00`00Oomoo`1VOol00`00Oomoo`0TOol002Uoo`03001oogoo01Aoo`03001oogoo06Eoo`03001o
ogoo02eoo`03001oogoo06Eoo`03001oogoo02Eoo`00:Goo00<007ooOol057oo00<007ooOol0IGoo
00<007ooOol0;Woo00<007ooOol0I7oo00<007ooOol09Goo000YOol00`00Oomoo`0EOol00`00Oomo
o`1SOol00`00Oomoo`0_Ool00`00Oomoo`1SOol00`00Oomoo`0VOol002Uoo`03001oogoo01Eoo`03
001oogoo06=oo`03001oogoo031oo`03001oogoo069oo`03001oogoo02Ioo`00:Goo0P005goo00<0
07ooOol0HGoo00<007ooOol0<Goo00<007ooOol0HGoo00<007ooOol09goo000YOol00`00Oomoo`0F
Ool00`00Oomoo`1QOol00`00Oomoo`0bOol00`00Oomoo`1POol00`00Oomoo`0WOol002Uoo`03001o
ogoo01Moo`03001oogoo05moo`03001oogoo03=oo`03001oogoo05moo`03001oogoo02Qoo`00:Goo
00<007ooOol05goo00<007ooOol0GWoo00<007ooOol0=Goo00<007ooOol0GWoo00<007ooOol0:7oo
000YOol00`00Oomoo`0HOol00`00Oomoo`1MOol00`00Oomoo`0eOol00`00Oomoo`1MOol00`00Oomo
o`0YOol000moo`<000Ioo`8000Ioo`<000Ioo`03001oogoo01Uoo`03001oogoo05]oo`03001oogoo
03Moo`03001oogoo05]oo`03001oogoo02Yoo`003Woo00D007ooOomoo`0000Eoo`8000Moo`03001o
ogoo00Eoo`03001oogoo01Uoo`03001oogoo05]oo`03001oogoo03Qoo`03001oogoo05Yoo`03001o
ogoo02Yoo`003Woo00D007ooOomoo`0000]oo`D000Ioo`<001Yoo`03001oogoo05Uoo`03001oogoo
03Uoo`03001oogoo05Uoo`03001oogoo02]oo`003Woo00D007ooOomoo`0000]oo`04001oogoo0007
Ool00`00Oomoo`0JOol00`00Oomoo`1IOol00`00Oomoo`0jOol00`00Oomoo`1HOol00`00Oomoo`0[
Ool000ioo`05001oogooOol0000<Ool00`00Ool00007Ool00`00Oomoo`0KOol00`00Oomoo`1GOol0
0`00Oomoo`0kOol00`00Oomoo`1GOol00`00Oomoo`0/Ool000ioo`05001oogooOol0000<Ool00`00
Ool00007Ool00`00Oomoo`0LOol00`00Oomoo`1EOol00`00Oomoo`0mOol00`00Oomoo`1FOol00`00
Oomoo`0/Ool000ioo`05001oogooOol0000=Ool20007Ool00`00Oomoo`0LOol00`00Oomoo`1EOol0
0`00Oomoo`0mOol00`00Oomoo`1EOol00`00Oomoo`0]Ool000moo`<000moo`03001oogoo00Eoo`03
001oogoo01eoo`03001oogoo05=oo`03001oogoo03moo`03001oogoo05=oo`03001oogoo02ioo`00
:Goo00<007ooOol07Goo00<007ooOol0Dgoo00<007ooOol0?goo00<007ooOol0Dgoo00<007ooOol0
;Woo000YOol2000OOol00`00Oomoo`1AOol00`00Oomoo`11Ool00`00Oomoo`1AOol00`00Oomoo`0_
Ool002Uoo`03001oogoo01moo`03001oogoo051oo`03001oogoo045oo`03001oogoo055oo`03001o
ogoo02moo`00:Goo00<007ooOol07goo00<007ooOol0Cgoo00<007ooOol0@goo00<007ooOol0Cgoo
00<007ooOol0<7oo000YOol00`00Oomoo`0POol00`00Oomoo`1>Ool00`00Oomoo`14Ool00`00Oomo
o`1>Ool00`00Oomoo`0`Ool002Uoo`03001oogoo021oo`03001oogoo04eoo`03001oogoo04Eoo`03
001oogoo04eoo`03001oogoo035oo`00:Goo00<007ooOol08Goo00<007ooOol0Bgoo00<007ooOol0
Agoo00<007ooOol0Bgoo00<007ooOol0<Woo000YOol00`00Oomoo`0ROol00`00Oomoo`1:Ool00`00
Oomoo`17Ool00`00Oomoo`1;Ool00`00Oomoo`0bOol002Uoo`8002=oo`03001oogoo04Uoo`03001o
ogoo04Uoo`03001oogoo04Uoo`03001oogoo03=oo`00:Goo00<007ooOol08goo00<007ooOol0B7oo
00<007ooOol0BGoo00<007ooOol0BGoo00<007ooOol0<goo000YOol00`00Oomoo`0SOol00`00Oomo
o`17Ool00`00Oomoo`1;Ool00`00Oomoo`17Ool00`00Oomoo`0dOol002Uoo`03001oogoo02Aoo`03
001oogoo04Ioo`03001oogoo04]oo`03001oogoo04Moo`03001oogoo03Aoo`00:Goo00<007ooOol0
97oo00<007ooOol0AGoo00<007ooOol0CGoo00<007ooOol0AGoo00<007ooOol0=Goo000YOol00`00
Oomoo`0UOol00`00Oomoo`14Ool00`00Oomoo`1=Ool00`00Oomoo`14Ool00`00Oomoo`0fOol002Uo
o`03001oogoo02Eoo`03001oogoo04=oo`03001oogoo04moo`03001oogoo04=oo`03001oogoo03Io
o`00:Goo0P009goo00<007ooOol0@Goo00<007ooOol0DGoo00<007ooOol0@Goo00<007ooOol0=goo
000YOol00`00Oomoo`0WOol00`00Oomoo`10Ool00`00Oomoo`1AOol00`00Oomoo`11Ool00`00Oomo
o`0gOol002Uoo`03001oogoo02Moo`03001oogoo03moo`03001oogoo05=oo`03001oogoo03moo`03
001oogoo03Qoo`00:Goo00<007ooOol0:7oo00<007ooOol0?Woo00<007ooOol0Dgoo00<007ooOol0
?Woo00<007ooOol0>Goo000YOol00`00Oomoo`0XOol00`00Oomoo`0mOol00`00Oomoo`1EOol00`00
Oomoo`0mOol00`00Oomoo`0iOol000moo`<000Ioo`8000Eoo`<000Moo`03001oogoo02Uoo`03001o
ogoo03aoo`03001oogoo05Eoo`03001oogoo03aoo`03001oogoo03Yoo`003Woo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol00006Ool00`00Oomoo`0YOol00`00Oomoo`0kOol00`00Oomoo`1G
Ool00`00Oomoo`0kOol00`00Oomoo`0jOol000ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
1Woo0`00:Woo00<007ooOol0>Woo00<007ooOol0Egoo00<007ooOol0>Woo00<007ooOol0>goo000>
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo02Yoo`03001oogoo03Uoo`03
001oogoo05Uoo`03001oogoo03Qoo`03001oogoo03aoo`003Woo00D007ooOomoo`0000]oo`@000Mo
o`03001oogoo02]oo`03001oogoo03Qoo`03001oogoo05Uoo`03001oogoo03Qoo`03001oogoo03ao
o`003Woo00D007ooOomoo`0000]oo`03001oogoo00Qoo`03001oogoo02]oo`03001oogoo03Moo`03
001oogoo05]oo`03001oogoo03Ioo`03001oogoo03eoo`003Woo00D007ooOomoo`0000aoo`03001o
ogoo00Moo`03001oogoo02aoo`03001oogoo03Eoo`03001oogoo05eoo`03001oogoo03Eoo`03001o
ogoo03eoo`003goo0`003Woo0`001Woo00<007ooOol0;Goo00<007ooOol0=7oo00<007ooOol0GGoo
00<007ooOol0=7oo00<007ooOol0?Woo000YOol00`00Oomoo`0]Ool00`00Oomoo`0cOol00`00Oomo
o`1OOol00`00Oomoo`0bOol00`00Oomoo`0oOol002Uoo`8002moo`03001oogoo039oo`03001oogoo
05moo`03001oogoo039oo`03001oogoo03moo`00:Goo00<007ooOol0;Woo00<007ooOol0<Goo00<0
07ooOol0HGoo00<007ooOol0<7oo00<007ooOol0@7oo000YOol00`00Oomoo`0_Ool00`00Oomoo`0`
Ool00`00Oomoo`1QOol00`00Oomoo`0`Ool00`00Oomoo`10Ool002Uoo`03001oogoo02moo`03001o
ogoo02moo`03001oogoo06=oo`03001oogoo02ioo`03001oogoo045oo`00:Goo00<007ooOol0<7oo
00<007ooOol0;Woo00<007ooOol0Hgoo00<007ooOol0;Woo00<007ooOol0@Goo000YOol00`00Oomo
o`0`Ool00`00Oomoo`0]Ool00`00Oomoo`1UOol00`00Oomoo`0/Ool00`00Oomoo`12Ool002Uoo`03
001oogoo035oo`03001oogoo02aoo`03001oogoo06Eoo`03001oogoo02aoo`03001oogoo049oo`00
:Goo0P00<Woo00<007ooOol0:goo00<007ooOol0Igoo00<007ooOol0:Woo00<007ooOol0@goo000Y
Ool00`00Oomoo`0bOol00`00Oomoo`0ZOol00`00Oomoo`1WOol00`00Oomoo`0ZOol00`00Oomoo`13
Ool002Uoo`03001oogoo039oo`03001oogoo02Uoo`03001oogoo06Uoo`03001oogoo02Uoo`03001o
ogoo04=oo`00:Goo00<007ooOol0<goo00<007ooOol0:7oo00<007ooOol0JGoo00<007ooOol0:7oo
00<007ooOol0A7oo000YOol00`00Oomoo`0cOol00`00Oomoo`0WOol00`00Oomoo`1[Ool00`00Oomo
o`0WOol00`00Oomoo`14Ool002Uoo`03001oogoo03Aoo`03001oogoo02Ioo`03001oogoo06]oo`03
001oogoo02Ioo`03001oogoo04Eoo`00:Goo00<007ooOol0=7oo00<007ooOol09Goo00<007ooOol0
KGoo00<007ooOol09Goo00<007ooOol0AGoo000YOol2000fOol00`00Oomoo`0TOol00`00Oomoo`1]
Ool00`00Oomoo`0TOol00`00Oomoo`16Ool002Uoo`03001oogoo03Eoo`03001oogoo02=oo`03001o
ogoo06moo`03001oogoo02=oo`03001oogoo04Ioo`00:Goo00<007ooOol0=Woo00<007ooOol08Woo
00<007ooOol0Kgoo00<007ooOol08Woo00<007ooOol0Agoo000YOol00`00Oomoo`0fOol00`00Oomo
o`0ROol00`00Oomoo`1`Ool00`00Oomoo`0QOol00`00Oomoo`17Ool002Uoo`03001oogoo03Moo`03
001oogoo021oo`03001oogoo075oo`03001oogoo021oo`03001oogoo04Qoo`003goo0`001Woo0P00
1Goo0`001goo00<007ooOol0=goo00<007ooOol087oo00<007ooOol0LWoo00<007ooOol07goo00<0
07ooOol0B7oo000>Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`0000Ioo`03001oogoo
03Qoo`03001oogoo01ioo`03001oogoo07=oo`03001oogoo01ioo`03001oogoo04Uoo`003Woo00D0
07ooOomoo`0000]oo`05001oogooOol00006Ool3000hOol00`00Oomoo`0NOol00`00Oomoo`1dOol0
0`00Oomoo`0MOol00`00Oomoo`19Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo
00<007ooOol0>7oo00<007ooOol07Goo00<007ooOol0MGoo00<007ooOol077oo00<007ooOol0BWoo
000>Ool01@00Oomoogoo000037oo0`001goo00<007ooOol0>Goo00<007ooOol077oo00<007ooOol0
MGoo00<007ooOol077oo00<007ooOol0BWoo000>Ool01@00Oomoogoo00002goo00D007ooOomoo`00
00Ioo`03001oogoo03Uoo`03001oogoo01]oo`03001oogoo07Moo`03001oogoo01]oo`03001oogoo
04Yoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0jOol00`00Oomo
o`0JOol00`00Oomoo`1gOol00`00Oomoo`0JOol00`00Oomoo`1;Ool000moo`<000eoo`<000Moo`03
001oogoo03Yoo`03001oogoo01Uoo`03001oogoo07Uoo`03001oogoo01Uoo`03001oogoo04]oo`00
:Goo00<007ooOol0>goo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol0
C7oo000YOol2000mOol00`00Oomoo`0FOol00`00Oomoo`1kOol00`00Oomoo`0GOol00`00Oomoo`1<
Ool002Uoo`03001oogoo03aoo`03001oogoo01Ioo`03001oogoo07]oo`03001oogoo01Ioo`03001o
ogoo04eoo`00:Goo00<007ooOol0?Goo00<007ooOol057oo00<007ooOol0OGoo00<007ooOol05Goo
00<007ooOol0CGoo000YOol00`00Oomoo`0mOol00`00Oomoo`0COol00`00Oomoo`1nOol00`00Oomo
o`0DOol00`00Oomoo`1>Ool002Uoo`03001oogoo03ioo`03001oogoo019oo`03001oogoo07moo`03
001oogoo01=oo`03001oogoo04ioo`00:Goo00<007ooOol0?Woo00<007ooOol04Goo00<007ooOol0
P7oo00<007ooOol04Woo00<007ooOol0Cgoo000YOol00`00Oomoo`0oOol00`00Oomoo`0@Ool00`00
Oomoo`21Ool00`00Oomoo`0AOol00`00Oomoo`1?Ool002Uoo`80041oo`03001oogoo00moo`03001o
ogoo08=oo`03001oogoo00moo`03001oogoo051oo`00:Goo00<007ooOol0@7oo00<007ooOol03Goo
00<007ooOol0QGoo00<007ooOol03Woo00<007ooOol0D7oo000YOol00`00Oomoo`11Ool00`00Oomo
o`0<Ool00`00Oomoo`25Ool00`00Oomoo`0=Ool00`00Oomoo`1AOol002Uoo`03001oogoo049oo`03
001oogoo00Yoo`03001oogoo08Moo`03001oogoo00]oo`03001oogoo059oo`00:Goo00<007ooOol0
@Woo00<007ooOol02Woo00<007ooOol0R7oo00<007ooOol02Goo00<007ooOol0Dgoo000YOol00`00
Oomoo`13Ool20008Ool2002<Ool00`00Oomoo`07Ool00`00Oomoo`1DOol002Uoo`03001oogoo04Eo
o`03001oogoo00Aoo`03001oogoo08eoo`8000Ioo`03001oogoo05Eoo`00:Goo0P00AWoo1`00TWoo
1P00F7oo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol001moo`D000Eoo`03001oogoo0?mooceoo`008Goo00<0
07ooOol01Goo00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05Ool3003oOolmOol0025oo`03001o
ogoo00Eoo`03001oogoo0?mooceoo`008Goo00<007ooOol01Goo00<007ooOol0ogoo?Goo000QOol0
0`00Oomoo`05Ool00`00Oomoo`3oOolmOol0025oo`03001oogoo00Eoo`03001oogoo0?mooceoo`00
7goo0`001goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00
:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00
:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00
:Goo0P00ogoo?Woo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<0
07ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<0
07ooOol0ogoo?Goo000YOol2003oOolnOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00:eoo`<0009oo`<001Qoo`<009Qoo`00[Woo00<007ooOol00Woo00<007ooOol01goo1P002Goo
00D007ooOomoo`0009Moo`00[Woo00<007ooOol00Woo00<007ooOol06Woo00<007ooOol0UGoo002^
Ool01P00Ool00000Ool000Uoo`H000eoo`03001oogoo09Eoo`00[Woo00H007oo000007oo000JOol2
002HOol00:ioo`80009oo`8001aoo`03001oogoo09Eoo`00[Woo0P000Woo0P0067oo00D007ooOomo
o`0009Moo`00[Goo0P0017oo0P0067oo0`00V7oo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0882906 0.441453 [
[.2619 .07579 -9 -9 ]
[.2619 .07579 9 0 ]
[.5 .07579 -3 -9 ]
[.5 .07579 3 0 ]
[.7381 .07579 -9 -9 ]
[.7381 .07579 9 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .17658 -18 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -18 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08829 m
.2619 .09454 L
s
[(0.5)] .2619 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(1)] .5 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1.5)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.02381 0 m
.03006 0 L
s
[(-0.2)] .01131 0 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(0.2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(0.4)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(0.6)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(0.8)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(1)] .01131 .52974 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10307 m
.06244 .15796 L
.10458 .23816 L
.14415 .31167 L
.18221 .38163 L
.22272 .45885 L
.23179 .47846 L
.24141 .49668 L
.24644 .50423 L
.2491 .50752 L
.25197 .51043 L
.25459 .51249 L
.257 .51385 L
.25815 .51431 L
.25941 .51468 L
.2606 .51489 L
.26171 .51497 L
.26241 .51496 L
.26305 .51491 L
.26375 .51481 L
.26449 .51465 L
.26575 .51428 L
.26712 .5137 L
.26965 .51219 L
.27202 .51027 L
.27733 .50429 L
.28302 .49564 L
.30316 .45431 L
.34452 .37686 L
.38436 .30205 L
.42269 .2325 L
.44208 .19857 L
.46347 .15333 L
.47322 .13283 L
.47834 .12334 L
.48373 .1149 L
.48846 .10915 L
.49115 .10668 L
.49243 .10572 L
.49365 .10494 L
.49475 .10435 L
.49595 .10383 L
.49704 .10348 L
.49804 .10325 L
.49913 .1031 L
.50032 .10307 L
.50157 .10318 L
.50274 .10342 L
.50399 .10381 L
.50532 .10438 L
Mistroke
.50772 .10582 L
.51057 .10819 L
.51315 .11091 L
.52303 .12575 L
.54156 .16441 L
.58168 .23965 L
.62029 .31155 L
.66134 .38645 L
.6818 .42264 L
.70088 .46319 L
.71032 .48322 L
.71924 .49932 L
.72418 .50621 L
.72678 .50911 L
.72953 .51158 L
.73185 .51316 L
.73317 .51384 L
.7344 .51433 L
.73554 .51466 L
.73657 .51486 L
.73771 .51496 L
.7389 .51494 L
.74014 .51477 L
.74084 .51461 L
.74149 .51443 L
.74267 .51399 L
.74392 .51339 L
.74609 .51201 L
.74847 .51002 L
.75375 .50397 L
.75869 .49651 L
.77707 .45933 L
.81594 .38466 L
.85727 .30876 L
.89708 .23544 L
.93538 .16275 L
.94469 .14248 L
.95474 .12298 L
.96049 .11411 L
.96301 .11095 L
.96577 .10805 L
.96838 .10589 L
.97081 .10441 L
.97216 .10382 L
.97338 .10343 L
.97406 .10328 L
.9748 .10316 L
.97549 .10309 L
.97613 .10307 L
.97619 .10307 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`003goo0`001Woo0P0017oo1@00ogooAWoo000>Ool01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol00?moodIoo`001Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo0?moodIo
o`003Woo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<00?mooceoo`003Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00
Oomoo`3oOolmOol000moo`<000eoo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00
Oomoo`0nOol30006Ool20005Ool40010Ool5000oOol50004Ool20005Ool4000oOol5000>Ool002Uo
o`03001oogoo03eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0oOol00`00Oomoo`11Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`0mOol01000Oomoo`003Woo000YOol00`00Oomoo`0mOol0
1@00Oomoogoo000047oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
?Woo00<007ooOol03Woo000YOol00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0?goo
00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0?goo00<007ooOol03Goo000YOol00`00Oomo
o`0mOol01@00Oomoogoo000037oo1000@Woo00<007ooOol0@Goo00<007ooOol02goo1000@goo00<0
07ooOol037oo000YOol00`00Oomoo`0mOol01@00Oomoogoo000037oo00<007ooOol0@goo00<007oo
Ool0@Goo00<007ooOol02goo00<007ooOol0A7oo00<007ooOol037oo000YOol2000nOol01@00Oomo
ogoo000037oo00<007ooOol0@goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0@7oo00D0
07ooOomoo`0000ioo`00:Goo00<007ooOol0?Woo0`003Goo1000@7oo0`00@Goo0`003Goo1000@7oo
0`003goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`008Gooo`00@00027oo
000YOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool002Uoo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03
001oogoo04Uoo`03001oogoo00eoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOol]
Ool00`00Oomoo`0=Ool002Uoo`03001oogoo099oo`H0095oo`@000moo`00:Goo00<007ooOol0TGoo
00<007ooOol017oo00<007ooOol0SGoo00<007ooOol04Goo000YOol2002AOol20006Ool00`00Oomo
o`2=Ool00`00Oomoo`0AOol002Uoo`03001oo`0008moo`03001oogoo00Ioo`03001oogoo08aoo`03
001oogoo019oo`00:Goo00<007oo0000Sgoo00<007ooOol01goo00<007ooOol0Rgoo00<007ooOol0
4Woo000YOol01000Oomoo`00SGoo00<007ooOol02Goo00<007ooOol0RGoo00<007ooOol04goo000Y
Ool01@00Oomoogoo0000Rgoo00<007ooOol02goo00<007ooOol0Qgoo00<007ooOol057oo000YOol0
0`00Oomoo`02Ool00`00Oomoo`28Ool00`00Oomoo`0<Ool00`00Oomoo`26Ool00`00Oomoo`0DOol0
02Uoo`03001oogoo009oo`03001oogoo08Moo`03001oogoo00eoo`03001oogoo08Eoo`03001oogoo
01Eoo`00:Goo0P0017oo00<007ooOol0QWoo00<007ooOol03Woo00<007ooOol0Q7oo00<007ooOol0
5Goo000YOol00`00Oomoo`04Ool00`00Oomoo`25Ool00`00Oomoo`0>Ool00`00Oomoo`23Ool00`00
Oomoo`0FOol002Uoo`03001oogoo00Aoo`03001oogoo08Aoo`03001oogoo00moo`03001oogoo08=o
o`03001oogoo01Ioo`00:Goo00<007ooOol01Goo00<007ooOol0Pgoo00<007ooOol047oo00<007oo
Ool0PGoo00<007ooOol05goo000YOol00`00Oomoo`06Ool00`00Oomoo`21Ool00`00Oomoo`0AOol0
0`00Oomoo`21Ool00`00Oomoo`0GOol002Uoo`03001oogoo00Moo`03001oogoo081oo`03001oogoo
019oo`03001oogoo07moo`03001oogoo01Qoo`00:Goo00<007ooOol01goo00<007ooOol0P7oo00<0
07ooOol04Woo00<007ooOol0Ogoo00<007ooOol067oo000YOol20009Ool00`00Oomoo`1nOol00`00
Oomoo`0DOol00`00Oomoo`1mOol00`00Oomoo`0IOol002Uoo`03001oogoo00Uoo`03001oogoo07eo
o`03001oogoo01Aoo`03001oogoo07eoo`03001oogoo01Uoo`00:Goo00<007ooOol02Goo00<007oo
Ool0O7oo00<007ooOol05Goo00<007ooOol0OGoo00<007ooOol06Goo000YOol00`00Oomoo`0:Ool0
0`00Oomoo`1kOol00`00Oomoo`0FOol00`00Oomoo`1kOol00`00Oomoo`0JOol000moo`<000Ioo`80
00Aoo`D000Ioo`03001oogoo00Yoo`03001oogoo07Yoo`03001oogoo01Moo`03001oogoo07]oo`03
001oogoo01Yoo`003Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo0006Ool00`00Oomoo`0;
Ool00`00Oomoo`1iOol00`00Oomoo`0HOol00`00Oomoo`1iOol00`00Oomoo`0KOol000ioo`05001o
ogooOol0000=Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`1hOol00`00Oomoo`0IOol0
0`00Oomoo`1iOol00`00Oomoo`0KOol000ioo`05001oogooOol0000>Ool00`00Oomoo`05Ool3000<
Ool00`00Oomoo`1gOol00`00Oomoo`0JOol00`00Oomoo`1gOol00`00Oomoo`0LOol000ioo`05001o
ogooOol0000?Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`1fOol00`00Oomoo`0KOol0
0`00Oomoo`1gOol00`00Oomoo`0LOol000ioo`05001oogooOol0000?Ool00`00Oomoo`04Ool00`00
Oomoo`0=Ool00`00Oomoo`1eOol00`00Oomoo`0LOol00`00Oomoo`1eOol00`00Oomoo`0MOol000io
o`05001oogooOol0000;Ool01@00Oomoogoo00001Woo00<007ooOol03Goo00<007ooOol0M7oo00<0
07ooOol07Woo00<007ooOol0M7oo00<007ooOol07Goo000?Ool3000=Ool30007Ool00`00Oomoo`0>
Ool00`00Oomoo`1cOol00`00Oomoo`0NOol00`00Oomoo`1cOol00`00Oomoo`0NOol002Uoo`03001o
ogoo00ioo`03001oogoo079oo`03001oogoo021oo`03001oogoo079oo`03001oogoo01ioo`00:Goo
00<007ooOol03goo00<007ooOol0LGoo00<007ooOol087oo00<007ooOol0LGoo00<007ooOol07goo
000YOol2000@Ool00`00Oomoo`1`Ool00`00Oomoo`0ROol00`00Oomoo`1`Ool00`00Oomoo`0OOol0
02Uoo`03001oogoo011oo`03001oogoo06moo`03001oogoo029oo`03001oogoo06moo`03001oogoo
021oo`00:Goo00<007ooOol047oo00<007ooOol0KWoo00<007ooOol097oo00<007ooOol0KGoo00<0
07ooOol08Goo000YOol00`00Oomoo`0AOol00`00Oomoo`1]Ool00`00Oomoo`0TOol00`00Oomoo`1]
Ool00`00Oomoo`0QOol002Uoo`03001oogoo015oo`03001oogoo06aoo`03001oogoo02Ioo`03001o
ogoo06]oo`03001oogoo029oo`00:Goo00<007ooOol04Woo00<007ooOol0Jgoo00<007ooOol09Woo
00<007ooOol0Jgoo00<007ooOol08Woo000YOol00`00Oomoo`0BOol00`00Oomoo`1ZOol00`00Oomo
o`0XOol00`00Oomoo`1YOol00`00Oomoo`0SOol002Uoo`8001Aoo`03001oogoo06Qoo`03001oogoo
02Uoo`03001oogoo06Uoo`03001oogoo02=oo`00:Goo00<007ooOol04goo00<007ooOol0J7oo00<0
07ooOol0:Woo00<007ooOol0Igoo00<007ooOol097oo000YOol00`00Oomoo`0DOol00`00Oomoo`1V
Ool00`00Oomoo`0/Ool00`00Oomoo`1VOol00`00Oomoo`0TOol002Uoo`03001oogoo01Aoo`03001o
ogoo06Ioo`03001oogoo02aoo`03001oogoo06Eoo`03001oogoo02Eoo`00:Goo00<007ooOol05Goo
00<007ooOol0I7oo00<007ooOol0;Woo00<007ooOol0I7oo00<007ooOol09Goo000YOol00`00Oomo
o`0EOol00`00Oomoo`1TOol00`00Oomoo`0^Ool00`00Oomoo`1SOol00`00Oomoo`0VOol002Uoo`03
001oogoo01Ioo`03001oogoo069oo`03001oogoo031oo`03001oogoo069oo`03001oogoo02Ioo`00
:Goo0P005goo00<007ooOol0HWoo00<007ooOol0<7oo00<007ooOol0HGoo00<007ooOol09goo000Y
Ool00`00Oomoo`0GOol00`00Oomoo`1POol00`00Oomoo`0bOol00`00Oomoo`1POol00`00Oomoo`0W
Ool002Uoo`03001oogoo01Moo`03001oogoo05moo`03001oogoo03=oo`03001oogoo05moo`03001o
ogoo02Qoo`00:Goo00<007ooOol067oo00<007ooOol0GWoo00<007ooOol0=7oo00<007ooOol0GGoo
00<007ooOol0:Goo000YOol00`00Oomoo`0IOol00`00Oomoo`1LOol00`00Oomoo`0eOol00`00Oomo
o`1MOol00`00Oomoo`0YOol000moo`<000Ioo`8000Ioo`<000Ioo`03001oogoo01Uoo`03001oogoo
05aoo`03001oogoo03Ioo`03001oogoo05]oo`03001oogoo02Yoo`003Woo00D007ooOomoo`0000Eo
o`8000Moo`03001oogoo00Eoo`03001oogoo01Yoo`03001oogoo05Yoo`03001oogoo03Moo`03001o
ogoo05]oo`03001oogoo02Yoo`003Woo00D007ooOomoo`0000]oo`D000Ioo`<001Yoo`03001oogoo
05Uoo`03001oogoo03Uoo`03001oogoo05Uoo`03001oogoo02]oo`003Woo00D007ooOomoo`0000]o
o`04001oogoo0007Ool00`00Oomoo`0KOol00`00Oomoo`1HOol00`00Oomoo`0iOol00`00Oomoo`1I
Ool00`00Oomoo`0[Ool000ioo`05001oogooOol0000<Ool00`00Ool00007Ool00`00Oomoo`0KOol0
0`00Oomoo`1GOol00`00Oomoo`0kOol00`00Oomoo`1GOol00`00Oomoo`0/Ool000ioo`05001oogoo
Ool0000<Ool00`00Ool00007Ool00`00Oomoo`0LOol00`00Oomoo`1FOol00`00Oomoo`0kOol00`00
Oomoo`1FOol00`00Oomoo`0]Ool000ioo`05001oogooOol0000=Ool20007Ool00`00Oomoo`0MOol0
0`00Oomoo`1DOol00`00Oomoo`0mOol00`00Oomoo`1EOol00`00Oomoo`0]Ool000moo`<000moo`03
001oogoo00Eoo`03001oogoo01eoo`03001oogoo05=oo`03001oogoo03moo`03001oogoo05=oo`03
001oogoo02ioo`00:Goo00<007ooOol07Woo00<007ooOol0DWoo00<007ooOol0?goo00<007ooOol0
Dgoo00<007ooOol0;Woo000YOol2000OOol00`00Oomoo`1AOol00`00Oomoo`11Ool00`00Oomoo`1A
Ool00`00Oomoo`0_Ool002Uoo`03001oogoo01moo`03001oogoo051oo`03001oogoo045oo`03001o
ogoo055oo`03001oogoo02moo`00:Goo00<007ooOol07goo00<007ooOol0Cgoo00<007ooOol0@goo
00<007ooOol0Cgoo00<007ooOol0<7oo000YOol00`00Oomoo`0POol00`00Oomoo`1=Ool00`00Oomo
o`14Ool00`00Oomoo`1?Ool00`00Oomoo`0`Ool002Uoo`03001oogoo021oo`03001oogoo04eoo`03
001oogoo04Eoo`03001oogoo04eoo`03001oogoo035oo`00:Goo00<007ooOol08Goo00<007ooOol0
Bgoo00<007ooOol0AWoo00<007ooOol0C7oo00<007ooOol0<Woo000YOol00`00Oomoo`0ROol00`00
Oomoo`1:Ool00`00Oomoo`17Ool00`00Oomoo`1;Ool00`00Oomoo`0bOol002Uoo`8002=oo`03001o
ogoo04Uoo`03001oogoo04Qoo`03001oogoo04Yoo`03001oogoo03=oo`00:Goo00<007ooOol08goo
00<007ooOol0B7oo00<007ooOol0BGoo00<007ooOol0BGoo00<007ooOol0<goo000YOol00`00Oomo
o`0SOol00`00Oomoo`17Ool00`00Oomoo`1:Ool00`00Oomoo`18Ool00`00Oomoo`0dOol002Uoo`03
001oogoo02Aoo`03001oogoo04Ioo`03001oogoo04]oo`03001oogoo04Moo`03001oogoo03Aoo`00
:Goo00<007ooOol097oo00<007ooOol0AGoo00<007ooOol0C7oo00<007ooOol0AWoo00<007ooOol0
=Goo000YOol00`00Oomoo`0UOol00`00Oomoo`14Ool00`00Oomoo`1=Ool00`00Oomoo`15Ool00`00
Oomoo`0eOol002Uoo`03001oogoo02Eoo`03001oogoo04=oo`03001oogoo04moo`03001oogoo04=o
o`03001oogoo03Ioo`00:Goo0P009goo00<007ooOol0@Woo00<007ooOol0Cgoo00<007ooOol0@Woo
00<007ooOol0=goo000YOol00`00Oomoo`0WOol00`00Oomoo`10Ool00`00Oomoo`1AOol00`00Oomo
o`11Ool00`00Oomoo`0gOol002Uoo`03001oogoo02Moo`03001oogoo041oo`03001oogoo055oo`03
001oogoo041oo`03001oogoo03Qoo`00:Goo00<007ooOol0:7oo00<007ooOol0?Woo00<007ooOol0
Dgoo00<007ooOol0?goo00<007ooOol0>7oo000YOol00`00Oomoo`0XOol00`00Oomoo`0nOol00`00
Oomoo`1DOol00`00Oomoo`0mOol00`00Oomoo`0iOol000moo`<000Ioo`8000Eoo`<000Moo`03001o
ogoo02Uoo`03001oogoo03aoo`03001oogoo05Eoo`03001oogoo03eoo`03001oogoo03Uoo`003Woo
00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00006Ool00`00Oomoo`0YOol00`00Oomoo`0l
Ool00`00Oomoo`1FOol00`00Oomoo`0kOol00`00Oomoo`0jOol000ioo`05001oogooOol0000;Ool0
1@00Oomoogoo00001Woo0`00:Woo00<007ooOol0>Woo00<007ooOol0Egoo00<007ooOol0>goo00<0
07ooOol0>Woo000>Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo02Yoo`03
001oogoo03Yoo`03001oogoo05Qoo`03001oogoo03Uoo`03001oogoo03]oo`003Woo00D007ooOomo
o`0000]oo`@000Moo`03001oogoo02]oo`03001oogoo03Qoo`03001oogoo05Uoo`03001oogoo03Uo
o`03001oogoo03]oo`003Woo00D007ooOomoo`0000]oo`03001oogoo00Qoo`03001oogoo02]oo`03
001oogoo03Qoo`03001oogoo05Yoo`03001oogoo03Moo`03001oogoo03aoo`003Woo00D007ooOomo
o`0000aoo`03001oogoo00Moo`03001oogoo02aoo`03001oogoo03Ioo`03001oogoo05aoo`03001o
ogoo03Ioo`03001oogoo03aoo`003goo0`003Woo0`001Woo00<007ooOol0;Goo00<007ooOol0=Goo
00<007ooOol0G7oo00<007ooOol0=Goo00<007ooOol0?Goo000YOol00`00Oomoo`0]Ool00`00Oomo
o`0dOol00`00Oomoo`1NOol00`00Oomoo`0cOol00`00Oomoo`0nOol002Uoo`8002moo`03001oogoo
03=oo`03001oogoo05ioo`03001oogoo03=oo`03001oogoo03ioo`00:Goo00<007ooOol0;Woo00<0
07ooOol0<Woo00<007ooOol0H7oo00<007ooOol0<Goo00<007ooOol0?goo000YOol00`00Oomoo`0_
Ool00`00Oomoo`0aOol00`00Oomoo`1QOol00`00Oomoo`0`Ool00`00Oomoo`0oOol002Uoo`03001o
ogoo02moo`03001oogoo031oo`03001oogoo069oo`03001oogoo02moo`03001oogoo041oo`00:Goo
00<007ooOol0<7oo00<007ooOol0;goo00<007ooOol0Hgoo00<007ooOol0;Woo00<007ooOol0@7oo
000YOol00`00Oomoo`0`Ool00`00Oomoo`0^Ool00`00Oomoo`1TOol00`00Oomoo`0]Ool00`00Oomo
o`11Ool002Uoo`03001oogoo035oo`03001oogoo02eoo`03001oogoo06Eoo`03001oogoo02aoo`03
001oogoo045oo`00:Goo0P00<Woo00<007ooOol0;7oo00<007ooOol0IWoo00<007ooOol0:goo00<0
07ooOol0@Woo000YOol00`00Oomoo`0bOol00`00Oomoo`0ZOol00`00Oomoo`1XOol00`00Oomoo`0Z
Ool00`00Oomoo`12Ool002Uoo`03001oogoo039oo`03001oogoo02Yoo`03001oogoo06Qoo`03001o
ogoo02Uoo`03001oogoo04=oo`00:Goo00<007ooOol0<goo00<007ooOol0:7oo00<007ooOol0JWoo
00<007ooOol09goo00<007ooOol0A7oo000YOol00`00Oomoo`0cOol00`00Oomoo`0XOol00`00Oomo
o`1[Ool00`00Oomoo`0VOol00`00Oomoo`14Ool002Uoo`03001oogoo03Aoo`03001oogoo02Ioo`03
001oogoo06aoo`03001oogoo02Eoo`03001oogoo04Eoo`00:Goo00<007ooOol0=7oo00<007ooOol0
9Woo00<007ooOol0KGoo00<007ooOol097oo00<007ooOol0AGoo000YOol2000fOol00`00Oomoo`0T
Ool00`00Oomoo`1^Ool00`00Oomoo`0SOol00`00Oomoo`16Ool002Uoo`03001oogoo03Ioo`03001o
ogoo02=oo`03001oogoo06moo`03001oogoo029oo`03001oogoo04Ioo`00:Goo00<007ooOol0=Woo
00<007ooOol08Woo00<007ooOol0L7oo00<007ooOol08Goo00<007ooOol0Agoo000YOol00`00Oomo
o`0gOol00`00Oomoo`0QOol00`00Oomoo`1aOol00`00Oomoo`0POol00`00Oomoo`17Ool002Uoo`03
001oogoo03Moo`03001oogoo021oo`03001oogoo079oo`03001oogoo01moo`03001oogoo04Qoo`00
3goo0`001Woo0P001Goo0`001goo00<007ooOol0>7oo00<007ooOol07goo00<007ooOol0Lgoo00<0
07ooOol07Woo00<007ooOol0B7oo000>Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomoo`00
00Ioo`03001oogoo03Qoo`03001oogoo01ioo`03001oogoo07Aoo`03001oogoo01eoo`03001oogoo
04Uoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool3000iOol00`00Oomoo`0LOol0
0`00Oomoo`1fOol00`00Oomoo`0LOol00`00Oomoo`19Ool000ioo`05001oogooOol0000;Ool01@00
Oomoogoo00001Woo00<007ooOol0>Goo00<007ooOol077oo00<007ooOol0MWoo00<007ooOol06goo
00<007ooOol0BWoo000>Ool01@00Oomoogoo000037oo0`001goo00<007ooOol0>Woo00<007ooOol0
6Woo00<007ooOol0Mgoo00<007ooOol06Woo00<007ooOol0Bgoo000>Ool01@00Oomoogoo00002goo
00D007ooOomoo`0000Ioo`03001oogoo03Yoo`03001oogoo01Yoo`03001oogoo07Qoo`03001oogoo
01Uoo`03001oogoo04]oo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomo
o`0kOol00`00Oomoo`0HOol00`00Oomoo`1iOol00`00Oomoo`0HOol00`00Oomoo`1<Ool000moo`<0
00eoo`<000Moo`03001oogoo03]oo`03001oogoo01Qoo`03001oogoo07Yoo`03001oogoo01Moo`03
001oogoo04aoo`00:Goo00<007ooOol0?7oo00<007ooOol05Woo00<007ooOol0Ngoo00<007ooOol0
5Woo00<007ooOol0CGoo000YOol2000mOol00`00Oomoo`0FOol00`00Oomoo`1lOol00`00Oomoo`0E
Ool00`00Oomoo`1=Ool002Uoo`03001oogoo03eoo`03001oogoo01Aoo`03001oogoo07eoo`03001o
ogoo01Aoo`03001oogoo04ioo`00:Goo00<007ooOol0?Goo00<007ooOol057oo00<007ooOol0OWoo
00<007ooOol04goo00<007ooOol0CWoo000YOol00`00Oomoo`0nOol00`00Oomoo`0BOol00`00Oomo
o`1oOol00`00Oomoo`0COol00`00Oomoo`1>Ool002Uoo`03001oogoo03ioo`03001oogoo019oo`03
001oogoo081oo`03001oogoo015oo`03001oogoo04moo`00:Goo00<007ooOol0?goo00<007ooOol0
47oo00<007ooOol0PGoo00<007ooOol04Goo00<007ooOol0Cgoo000YOol00`00Oomoo`0oOol00`00
Oomoo`0@Ool00`00Oomoo`21Ool00`00Oomoo`0@Ool00`00Oomoo`1@Ool002Uoo`80045oo`03001o
ogoo00ioo`03001oogoo08=oo`03001oogoo00moo`03001oogoo051oo`00:Goo00<007ooOol0@7oo
00<007ooOol03Woo00<007ooOol0Pgoo00<007ooOol03Woo00<007ooOol0DGoo000YOol00`00Oomo
o`11Ool00`00Oomoo`0<Ool00`00Oomoo`25Ool00`00Oomoo`0=Ool00`00Oomoo`1AOol002Uoo`03
001oogoo045oo`03001oogoo00aoo`03001oogoo08Ioo`03001oogoo00aoo`03001oogoo055oo`00
:Goo00<007ooOol0@Woo00<007ooOol02Woo00<007ooOol0Qgoo00<007ooOol02goo00<007ooOol0
DWoo000YOol00`00Oomoo`12Ool00`00Oomoo`09Ool00`00Oomoo`29Ool00`00Oomoo`09Ool00`00
Oomoo`1COol002Uoo`03001oogoo04=oo`03001oogoo00Moo`03001oogoo08]oo`03001oogoo00Mo
o`03001oogoo05Aoo`00:Goo0P00AGoo00<007ooOol01Woo00<007ooOol0S7oo00<007ooOol01Goo
00<007ooOol0EGoo000YOol00`00Oomoo`15Ool00`00Oomoo`04Ool00`00Oomoo`2=Ool00`00Oomo
o`04Ool00`00Oomoo`1FOol002Uoo`03001oogoo04Ioo`80009oo`80095oo`80009oo`<005Qoo`00
:Goo00<007ooOol0B7oo0P00UGoo0`00FWoo000YOol00`00Oomoo`3oOolmOol001moo`D000Eoo`03
001oogoo0?mooceoo`008Goo00<007ooOol01Goo00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05
Ool3003oOolmOol0025oo`03001oogoo00Eoo`03001oogoo0?mooceoo`008Goo00<007ooOol01Goo
00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05Ool00`00Oomoo`3oOolmOol0025oo`03001oogoo
00Eoo`03001oogoo0?mooceoo`007goo0`001goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3o
OolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol0
02Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol0
02Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00Oomoo`3oOolmOol002Uoo`03
001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03
001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol2003oOolnOol002Uoo`03001oogoo
0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo
0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo
0?mooceoo`00:Goo00<007ooOol0ogoo?Goo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol0
0?moofUoo`00ogooJGoo003oOomYOol00:eoo`<0009oo`<001Qoo`@009Moo`00[Woo00<007ooOol0
0Woo00<007ooOol01goo1P003Woo00<007ooOol0U7oo002^Ool00`00Oomoo`02Ool00`00Oomoo`0K
Ool00`00Oomoo`2DOol00:ioo`06001oo`00001oo`002Goo1P003Woo00<007ooOol0U7oo002^Ool0
1P00Ool00000Ool001Uoo`@009Moo`00[Woo0P000Woo0P006Goo00<007ooOol0V7oo002^Ool20002
Ool2000IOol00`00Oomoo`2HOol00:eoo`8000Aoo`8001Qoo`@009Moo`00ogooJGoo003oOomYOol0
0?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0882906 0.441453 [
[.2619 .07579 -9 -9 ]
[.2619 .07579 9 0 ]
[.5 .07579 -3 -9 ]
[.5 .07579 3 0 ]
[.7381 .07579 -9 -9 ]
[.7381 .07579 9 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .17658 -18 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -18 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08829 m
.2619 .09454 L
s
[(0.5)] .2619 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(1)] .5 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1.5)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.02381 0 m
.03006 0 L
s
[(-0.2)] .01131 0 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(0.2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(0.4)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(0.6)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(0.8)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(1)] .01131 .52974 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09942 m
.06244 .16129 L
.10458 .23676 L
.14415 .31123 L
.18221 .38336 L
.22272 .45561 L
.24141 .49552 L
.24654 .50491 L
.24934 .50924 L
.25197 .51265 L
.25439 .51516 L
.2566 .51688 L
.25786 .51761 L
.25906 .51812 L
.26033 .51846 L
.26104 .51857 L
.26171 .51862 L
.26241 .5186 L
.26305 .51854 L
.26375 .51841 L
.26449 .5182 L
.26575 .5177 L
.26712 .51694 L
.26965 .51494 L
.27202 .51244 L
.27733 .50482 L
.28302 .49428 L
.30316 .45144 L
.34452 .37767 L
.38436 .30318 L
.42269 .23011 L
.46347 .15688 L
.47322 .1357 L
.47834 .12487 L
.48373 .11466 L
.48846 .10738 L
.49115 .10418 L
.49243 .10292 L
.49365 .1019 L
.49475 .10112 L
.49595 .10043 L
.49704 .09996 L
.49804 .09965 L
.49913 .09946 L
.50032 .09942 L
.50157 .09957 L
.50274 .09988 L
.50395 .10038 L
.50507 .10101 L
.50762 .10297 L
Mistroke
.50986 .1053 L
.51225 .10835 L
.52094 .1234 L
.54049 .16507 L
.58212 .23941 L
.62224 .31449 L
.66085 .38804 L
.7019 .46186 L
.71178 .48335 L
.71722 .49476 L
.72236 .5043 L
.72715 .51142 L
.72985 .51447 L
.73114 .51565 L
.73235 .51658 L
.73344 .51728 L
.73445 .51779 L
.73556 .51822 L
.73676 .51851 L
.73785 .51861 L
.73904 .51856 L
.74029 .51832 L
.74144 .51792 L
.74268 .51732 L
.74383 .51659 L
.74641 .51441 L
.74868 .51187 L
.75109 .50863 L
.75984 .493 L
.77947 .45121 L
.8174 .38411 L
.8578 .3079 L
.89667 .23433 L
.938 .16036 L
.97619 .09942 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`003goo0`001Woo0P0017oo1@00ogooAWoo000>Ool01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol00?moodIoo`001Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo0?moodIo
o`003Woo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<00?mooceoo`003Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00
Oomoo`3oOolmOol000moo`<000eoo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00
Oomoo`0nOol30006Ool20005Ool40010Ool5000oOol50004Ool20005Ool4000oOol5000>Ool002Uo
o`03001oogoo03eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0oOol00`00Oomoo`11Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`0mOol01000Oomoo`003Woo000YOol00`00Oomoo`0mOol0
1@00Oomoogoo000047oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
?Woo00<007ooOol03Woo000YOol00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0?goo
00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0?goo00<007ooOol03Goo000YOol00`00Oomo
o`0mOol01@00Oomoogoo000037oo1000@Woo00<007ooOol0@Goo00<007ooOol02goo1000@goo00<0
07ooOol037oo000YOol00`00Oomoo`0mOol01@00Oomoogoo000037oo00<007ooOol0@goo00<007oo
Ool0@Goo00<007ooOol02goo00<007ooOol0A7oo00<007ooOol037oo000YOol2000nOol01@00Oomo
ogoo000037oo00<007ooOol0@goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0@7oo00D0
07ooOomoo`0000ioo`00:Goo00<007ooOol0?Woo0`003Goo1000@7oo0`00@Goo0`003Goo1000@7oo
0`003goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`008Gooo`00@00027oo
000YOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool002Uoo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03
001oogoo04Uoo`03001oogoo00eoo`00:Goo00<007ooOol0U7oo0P00UWoo00<007ooOol03Goo000Y
Ool00`00Oomoo`2BOol200000goo0000002EOol00`00Oomoo`0=Ool002Uoo`80099oo`8000Aoo`03
001oogoo095oo`03001oogoo00ioo`00:Goo00<007oo0000TGoo00<007ooOol017oo00<007ooOol0
Sgoo00<007ooOol03goo000YOol3002@Ool00`00Oomoo`05Ool00`00Oomoo`2?Ool00`00Oomoo`0?
Ool002Uoo`04001oogoo002>Ool00`00Oomoo`07Ool00`00Oomoo`2=Ool00`00Oomoo`0@Ool002Uo
o`04001oogoo002>Ool00`00Oomoo`08Ool00`00Oomoo`2<Ool00`00Oomoo`0@Ool002Uoo`05001o
ogooOol0002<Ool00`00Oomoo`09Ool00`00Oomoo`2;Ool00`00Oomoo`0AOol002Uoo`03001oogoo
009oo`03001oogoo08Uoo`03001oogoo00Yoo`03001oogoo08Uoo`03001oogoo019oo`00:Goo00<0
07ooOol00Woo00<007ooOol0R7oo00<007ooOol02goo00<007ooOol0RGoo00<007ooOol04Woo000Y
Ool00`00Oomoo`03Ool00`00Oomoo`27Ool00`00Oomoo`0<Ool00`00Oomoo`27Ool00`00Oomoo`0C
Ool002Uoo`8000Aoo`03001oogoo08Ioo`03001oogoo00eoo`03001oogoo08Moo`03001oogoo01=o
o`00:Goo00<007ooOol017oo00<007ooOol0QGoo00<007ooOol03Woo00<007ooOol0QGoo00<007oo
Ool057oo000YOol00`00Oomoo`05Ool00`00Oomoo`24Ool00`00Oomoo`0>Ool00`00Oomoo`24Ool0
0`00Oomoo`0EOol002Uoo`03001oogoo00Eoo`03001oogoo08=oo`03001oogoo011oo`03001oogoo
08=oo`03001oogoo01Eoo`00:Goo00<007ooOol01Woo00<007ooOol0PWoo00<007ooOol047oo00<0
07ooOol0PWoo00<007ooOol05Woo000YOol00`00Oomoo`06Ool00`00Oomoo`21Ool00`00Oomoo`0A
Ool00`00Oomoo`22Ool00`00Oomoo`0FOol002Uoo`03001oogoo00Moo`03001oogoo081oo`03001o
ogoo019oo`03001oogoo081oo`03001oogoo01Moo`00:Goo0P002Goo00<007ooOol0Ogoo00<007oo
Ool04Woo00<007ooOol0Ogoo00<007ooOol067oo000YOol00`00Oomoo`08Ool00`00Oomoo`1nOol0
0`00Oomoo`0DOol00`00Oomoo`1nOol00`00Oomoo`0HOol002Uoo`03001oogoo00Uoo`03001oogoo
07eoo`03001oogoo01Aoo`03001oogoo07eoo`03001oogoo01Uoo`00:Goo00<007ooOol02Goo00<0
07ooOol0O7oo00<007ooOol05Woo00<007ooOol0O7oo00<007ooOol06Goo000?Ool30006Ool20004
Ool50006Ool00`00Oomoo`0:Ool00`00Oomoo`1kOol00`00Oomoo`0FOol00`00Oomoo`1kOol00`00
Oomoo`0JOol000ioo`05001oogooOol00005Ool20005Ool01000Oomoo`001Woo00<007ooOol02Woo
00<007ooOol0NWoo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol06goo000>Ool01@00Oomo
ogoo00003Goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0N7oo00<007ooOol06Goo00<0
07ooOol0NGoo00<007ooOol06goo000>Ool01@00Oomoogoo00003Woo00<007ooOol01Goo0`002goo
00<007ooOol0N7oo00<007ooOol06Woo00<007ooOol0Mgoo00<007ooOol077oo000>Ool01@00Oomo
ogoo00003goo00<007ooOol017oo00<007ooOol037oo00<007ooOol0MWoo00<007ooOol06goo00<0
07ooOol0Mgoo00<007ooOol077oo000>Ool01@00Oomoogoo00003goo00<007ooOol017oo00<007oo
Ool03Goo00<007ooOol0MGoo00<007ooOol077oo00<007ooOol0MGoo00<007ooOol07Goo000>Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo00eoo`03001oogoo07Aoo`03001o
ogoo01ioo`03001oogoo07=oo`03001oogoo01ioo`003goo0`003Goo0`001goo00<007ooOol03Woo
00<007ooOol0Lgoo00<007ooOol07Woo00<007ooOol0Lgoo00<007ooOol07Woo000YOol00`00Oomo
o`0>Ool00`00Oomoo`1bOol00`00Oomoo`0POol00`00Oomoo`1aOol00`00Oomoo`0OOol002Uoo`03
001oogoo00moo`03001oogoo071oo`03001oogoo025oo`03001oogoo075oo`03001oogoo01moo`00
:Goo0P0047oo00<007ooOol0L7oo00<007ooOol08Woo00<007ooOol0Kgoo00<007ooOol087oo000Y
Ool00`00Oomoo`0@Ool00`00Oomoo`1^Ool00`00Oomoo`0SOol00`00Oomoo`1^Ool00`00Oomoo`0Q
Ool002Uoo`03001oogoo011oo`03001oogoo06ioo`03001oogoo02Aoo`03001oogoo06eoo`03001o
ogoo025oo`00:Goo00<007ooOol04Goo00<007ooOol0K7oo00<007ooOol09Goo00<007ooOol0K7oo
00<007ooOol08Woo000YOol00`00Oomoo`0AOol00`00Oomoo`1/Ool00`00Oomoo`0VOol00`00Oomo
o`1[Ool00`00Oomoo`0ROol002Uoo`03001oogoo019oo`03001oogoo06Yoo`03001oogoo02Moo`03
001oogoo06Yoo`03001oogoo02=oo`00:Goo00<007ooOol04Woo00<007ooOol0JWoo00<007ooOol0
:7oo00<007ooOol0J7oo00<007ooOol097oo000YOol2000DOol00`00Oomoo`1XOol00`00Oomoo`0Y
Ool00`00Oomoo`1XOol00`00Oomoo`0TOol002Uoo`03001oogoo01Aoo`03001oogoo06Ioo`03001o
ogoo02]oo`03001oogoo06Ioo`03001oogoo02Eoo`00:Goo00<007ooOol057oo00<007ooOol0IWoo
00<007ooOol0;7oo00<007ooOol0IGoo00<007ooOol09Goo000YOol00`00Oomoo`0EOol00`00Oomo
o`1TOol00`00Oomoo`0]Ool00`00Oomoo`1TOol00`00Oomoo`0VOol002Uoo`03001oogoo01Eoo`03
001oogoo06Aoo`03001oogoo02ioo`03001oogoo069oo`03001oogoo02Moo`00:Goo00<007ooOol0
5Woo00<007ooOol0HWoo00<007ooOol0;goo00<007ooOol0HWoo00<007ooOol09goo000YOol00`00
Oomoo`0FOol00`00Oomoo`1ROol00`00Oomoo`0`Ool00`00Oomoo`1POol00`00Oomoo`0XOol002Uo
o`8001Qoo`03001oogoo061oo`03001oogoo035oo`03001oogoo061oo`03001oogoo02Qoo`00:Goo
00<007ooOol05goo00<007ooOol0Ggoo00<007ooOol0<goo00<007ooOol0GWoo00<007ooOol0:Goo
000YOol00`00Oomoo`0HOol00`00Oomoo`1NOol00`00Oomoo`0cOol00`00Oomoo`1NOol00`00Oomo
o`0YOol002Uoo`03001oogoo01Qoo`03001oogoo05eoo`03001oogoo03Eoo`03001oogoo05aoo`03
001oogoo02Yoo`00:Goo00<007ooOol06Goo00<007ooOol0G7oo00<007ooOol0=Goo00<007ooOol0
G7oo00<007ooOol0:Woo000?Ool30006Ool20006Ool30006Ool00`00Oomoo`0JOol00`00Oomoo`1J
Ool00`00Oomoo`0gOol00`00Oomoo`1JOol00`00Oomoo`0[Ool000ioo`05001oogooOol00005Ool2
0007Ool00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`1JOol00`00Oomoo`0hOol00`00Oomo
o`1IOol00`00Oomoo`0[Ool000ioo`05001oogooOol0000;Ool50006Ool3000KOol00`00Oomoo`1H
Ool00`00Oomoo`0iOol00`00Oomoo`1HOol00`00Oomoo`0/Ool000ioo`05001oogooOol0000;Ool0
1000Oomoo`001goo00<007ooOol06goo00<007ooOol0Egoo00<007ooOol0>goo00<007ooOol0Egoo
00<007ooOol0;7oo000>Ool01@00Oomoogoo000037oo00<007oo00001goo00<007ooOol077oo00<0
07ooOol0EWoo00<007ooOol0>goo00<007ooOol0EWoo00<007ooOol0;Goo000>Ool01@00Oomoogoo
000037oo00<007oo00001goo00<007ooOol077oo00<007ooOol0EGoo00<007ooOol0?Goo00<007oo
Ool0EGoo00<007ooOol0;Goo000>Ool01@00Oomoogoo00003Goo0P001goo00<007ooOol07Goo00<0
07ooOol0E7oo00<007ooOol0?Goo00<007ooOol0E7oo00<007ooOol0;Woo000?Ool3000?Ool00`00
Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`1COol00`00Oomoo`0oOol00`00Oomoo`1COol00`00
Oomoo`0^Ool002Uoo`03001oogoo01ioo`03001oogoo059oo`03001oogoo03moo`03001oogoo059o
o`03001oogoo02moo`00:Goo0P007goo00<007ooOol0DGoo00<007ooOol0@Goo00<007ooOol0DGoo
00<007ooOol0;goo000YOol00`00Oomoo`0OOol00`00Oomoo`1@Ool00`00Oomoo`11Ool00`00Oomo
o`1@Ool00`00Oomoo`0`Ool002Uoo`03001oogoo01moo`03001oogoo04moo`03001oogoo04=oo`03
001oogoo04moo`03001oogoo031oo`00:Goo00<007ooOol087oo00<007ooOol0CGoo00<007ooOol0
A7oo00<007ooOol0CWoo00<007ooOol0<Goo000YOol00`00Oomoo`0QOol00`00Oomoo`1<Ool00`00
Oomoo`15Ool00`00Oomoo`1=Ool00`00Oomoo`0aOol002Uoo`03001oogoo025oo`03001oogoo04]o
o`03001oogoo04Moo`03001oogoo04]oo`03001oogoo039oo`00:Goo00<007ooOol08Woo00<007oo
Ool0BWoo00<007ooOol0Agoo00<007ooOol0Bgoo00<007ooOol0<Woo000YOol2000SOol00`00Oomo
o`19Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`0cOol002Uoo`03001oogoo02=oo`03
001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03001oogoo03=oo`00:Goo00<007ooOol0
8goo00<007ooOol0Agoo00<007ooOol0Bgoo00<007ooOol0Agoo00<007ooOol0=7oo000YOol00`00
Oomoo`0TOol00`00Oomoo`16Ool00`00Oomoo`1;Ool00`00Oomoo`17Ool00`00Oomoo`0dOol002Uo
o`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo04eoo`03001oogoo04Eoo`03001oogoo03Eo
o`00:Goo00<007ooOol09Goo00<007ooOol0A7oo00<007ooOol0CGoo00<007ooOol0AGoo00<007oo
Ool0=Goo000YOol00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`1?Ool00`00Oomoo`13Ool0
0`00Oomoo`0fOol002Uoo`8002Moo`03001oogoo049oo`03001oogoo04moo`03001oogoo049oo`03
001oogoo03Moo`00:Goo00<007ooOol09Woo00<007ooOol0@Goo00<007ooOol0DGoo00<007ooOol0
@Goo00<007ooOol0=goo000YOol00`00Oomoo`0WOol00`00Oomoo`10Ool00`00Oomoo`1AOol00`00
Oomoo`10Ool00`00Oomoo`0hOol002Uoo`03001oogoo02Moo`03001oogoo03moo`03001oogoo05=o
o`03001oogoo03moo`03001oogoo03Qoo`00:Goo00<007ooOol0:7oo00<007ooOol0?Woo00<007oo
Ool0Dgoo00<007ooOol0?Woo00<007ooOol0>Goo000?Ool30006Ool20005Ool30007Ool00`00Oomo
o`0XOol00`00Oomoo`0mOol00`00Oomoo`1EOol00`00Oomoo`0mOol00`00Oomoo`0iOol000ioo`05
001oogooOol00005Ool20004Ool01@00Oomoogoo00001Woo00<007ooOol0:Goo00<007ooOol0?7oo
00<007ooOol0EGoo00<007ooOol0?7oo00<007ooOol0>Woo000>Ool01@00Oomoogoo00002goo00D0
07ooOomoo`0000Ioo`<002Yoo`03001oogoo03Yoo`03001oogoo05Moo`03001oogoo03]oo`03001o
ogoo03Yoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0ZOol00`00
Oomoo`0jOol00`00Oomoo`1HOol00`00Oomoo`0iOol00`00Oomoo`0kOol000ioo`05001oogooOol0
000;Ool40007Ool00`00Oomoo`0[Ool00`00Oomoo`0hOol00`00Oomoo`1IOol00`00Oomoo`0iOol0
0`00Oomoo`0kOol000ioo`05001oogooOol0000;Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool00`00
Oomoo`0hOol00`00Oomoo`1JOol00`00Oomoo`0gOol00`00Oomoo`0lOol000ioo`05001oogooOol0
000<Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomoo`0fOol00`00Oomoo`1KOol00`00Oomo
o`0gOol00`00Oomoo`0lOol000moo`<000ioo`<000Ioo`03001oogoo02aoo`03001oogoo03Ioo`03
001oogoo05aoo`03001oogoo03Eoo`03001oogoo03eoo`00:Goo00<007ooOol0;Goo00<007ooOol0
=7oo00<007ooOol0GGoo00<007ooOol0=7oo00<007ooOol0?Woo000YOol2000^Ool00`00Oomoo`0d
Ool00`00Oomoo`1NOol00`00Oomoo`0cOol00`00Oomoo`0nOol002Uoo`03001oogoo02ioo`03001o
ogoo039oo`03001oogoo05moo`03001oogoo039oo`03001oogoo03moo`00:Goo00<007ooOol0;Woo
00<007ooOol0<Woo00<007ooOol0H7oo00<007ooOol0<Goo00<007ooOol0?goo000YOol00`00Oomo
o`0_Ool00`00Oomoo`0`Ool00`00Oomoo`1QOol00`00Oomoo`0`Ool00`00Oomoo`10Ool002Uoo`03
001oogoo02moo`03001oogoo031oo`03001oogoo069oo`03001oogoo02moo`03001oogoo041oo`00
:Goo00<007ooOol0<7oo00<007ooOol0;Woo00<007ooOol0Hgoo00<007ooOol0;Woo00<007ooOol0
@Goo000YOol00`00Oomoo`0`Ool00`00Oomoo`0]Ool00`00Oomoo`1UOol00`00Oomoo`0]Ool00`00
Oomoo`11Ool002Uoo`80039oo`03001oogoo02aoo`03001oogoo06Eoo`03001oogoo02aoo`03001o
ogoo049oo`00:Goo00<007ooOol0<Woo00<007ooOol0:Woo00<007ooOol0Igoo00<007ooOol0:Woo
00<007ooOol0@goo000YOol00`00Oomoo`0bOol00`00Oomoo`0ZOol00`00Oomoo`1WOol00`00Oomo
o`0ZOol00`00Oomoo`13Ool002Uoo`03001oogoo03=oo`03001oogoo02Qoo`03001oogoo06Uoo`03
001oogoo02Qoo`03001oogoo04Aoo`00:Goo00<007ooOol0<goo00<007ooOol0:7oo00<007ooOol0
JWoo00<007ooOol09goo00<007ooOol0A7oo000YOol00`00Oomoo`0dOol00`00Oomoo`0VOol00`00
Oomoo`1[Ool00`00Oomoo`0VOol00`00Oomoo`15Ool002Uoo`03001oogoo03Aoo`03001oogoo02Eo
o`03001oogoo06eoo`03001oogoo02Eoo`03001oogoo04Eoo`00:Goo0P00=Woo00<007ooOol097oo
00<007ooOol0KGoo00<007ooOol097oo00<007ooOol0AWoo000YOol00`00Oomoo`0fOol00`00Oomo
o`0ROol00`00Oomoo`1_Ool00`00Oomoo`0ROol00`00Oomoo`17Ool002Uoo`03001oogoo03Ioo`03
001oogoo029oo`03001oogoo06moo`03001oogoo029oo`03001oogoo04Moo`00:Goo00<007ooOol0
=goo00<007ooOol087oo00<007ooOol0LGoo00<007ooOol087oo00<007ooOol0B7oo000YOol00`00
Oomoo`0gOol00`00Oomoo`0POol00`00Oomoo`1aOol00`00Oomoo`0POol00`00Oomoo`18Ool000mo
o`<000Ioo`8000Eoo`<000Moo`03001oogoo03Qoo`03001oogoo01ioo`03001oogoo07=oo`03001o
ogoo01ioo`03001oogoo04Uoo`003Woo00D007ooOomoo`0000Eoo`8000Aoo`05001oogooOol00006
Ool00`00Oomoo`0hOol00`00Oomoo`0NOol00`00Oomoo`1cOol00`00Oomoo`0NOol00`00Oomoo`19
Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo0`00>Goo00<007ooOol077oo00<0
07ooOol0MGoo00<007ooOol077oo00<007ooOol0BWoo000>Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Ioo`03001oogoo03Uoo`03001oogoo01]oo`03001oogoo07Ioo`03001oogoo01]oo`03
001oogoo04]oo`003Woo00D007ooOomoo`0000aoo`<000Moo`03001oogoo03Yoo`03001oogoo01Yo
o`03001oogoo07Moo`03001oogoo01Yoo`03001oogoo04]oo`003Woo00D007ooOomoo`0000]oo`05
001oogooOol00006Ool00`00Oomoo`0kOol00`00Oomoo`0HOol00`00Oomoo`1iOol00`00Oomoo`0H
Ool00`00Oomoo`1<Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo00<007ooOol0
>goo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol067oo00<007ooOol0C7oo000?Ool3000=
Ool30007Ool00`00Oomoo`0lOol00`00Oomoo`0FOol00`00Oomoo`1kOol00`00Oomoo`0FOol00`00
Oomoo`1=Ool002Uoo`03001oogoo03aoo`03001oogoo01Ioo`03001oogoo07]oo`03001oogoo01Io
o`03001oogoo04eoo`00:Goo0P00?Woo00<007ooOol057oo00<007ooOol0OGoo00<007ooOol057oo
00<007ooOol0CWoo000YOol00`00Oomoo`0mOol00`00Oomoo`0DOol00`00Oomoo`1mOol00`00Oomo
o`0DOol00`00Oomoo`1>Ool002Uoo`03001oogoo03ioo`03001oogoo019oo`03001oogoo07moo`03
001oogoo01=oo`03001oogoo04ioo`00:Goo00<007ooOol0?Woo00<007ooOol04Woo00<007ooOol0
Ogoo00<007ooOol04Woo00<007ooOol0Cgoo000YOol00`00Oomoo`0oOol00`00Oomoo`0@Ool00`00
Oomoo`21Ool00`00Oomoo`0AOol00`00Oomoo`1?Ool002Uoo`03001oogoo03moo`03001oogoo011o
o`03001oogoo089oo`03001oogoo00moo`03001oogoo051oo`00:Goo00<007ooOol0?goo00<007oo
Ool03goo00<007ooOol0Pgoo00<007ooOol03goo00<007ooOol0D7oo000YOol20011Ool00`00Oomo
o`0>Ool00`00Oomoo`24Ool00`00Oomoo`0=Ool00`00Oomoo`1AOol002Uoo`03001oogoo041oo`03
001oogoo00eoo`03001oogoo08Eoo`03001oogoo00eoo`03001oogoo055oo`00:Goo00<007ooOol0
@Goo00<007ooOol037oo00<007ooOol0QWoo00<007ooOol037oo00<007ooOol0DGoo000YOol00`00
Oomoo`11Ool00`00Oomoo`0;Ool00`00Oomoo`27Ool00`00Oomoo`0;Ool00`00Oomoo`1BOol002Uo
o`03001oogoo049oo`03001oogoo00Yoo`03001oogoo08Moo`03001oogoo00]oo`03001oogoo059o
o`00:Goo00<007ooOol0@Woo00<007ooOol02Goo00<007ooOol0RGoo00<007ooOol02Goo00<007oo
Ool0Dgoo000YOol00`00Oomoo`13Ool00`00Oomoo`07Ool00`00Oomoo`2;Ool00`00Oomoo`07Ool0
0`00Oomoo`1DOol002Uoo`8004Eoo`03001oogoo00Ioo`03001oogoo08]oo`03001oogoo00Moo`03
001oogoo05Aoo`00:Goo00<007ooOol0A7oo00<007ooOol01Goo00<007ooOol0SGoo00<007ooOol0
1Goo00<007ooOol0EGoo000YOol00`00Oomoo`15Ool00`00Oomoo`04Ool00`00Oomoo`2>Ool00`00
Oomoo`03Ool00`00Oomoo`1FOol002Uoo`03001oogoo04Ioo`80009oo`80095oo`<00004Ool00000
001HOol002Uoo`03001oogoo04Moo`@009Aoo`<005Yoo`007goo1@001Goo00<007ooOol0ogoo?Goo
000QOol00`00Oomoo`05Ool00`00Oomoo`3oOolmOol0025oo`03001oogoo00Eoo`<00?mooceoo`00
8Goo00<007ooOol01Goo00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05Ool00`00Oomoo`3oOolm
Ool0025oo`03001oogoo00Eoo`03001oogoo0?mooceoo`008Goo00<007ooOol01Goo00<007ooOol0
ogoo?Goo000OOol30007Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00
ogoo?Woo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol2003oOolnOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo
000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo
000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000YOol0
0`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol0
0`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000YOol0
0`00Oomoo`3oOolmOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00?moofUoo`00[Goo0`000Woo0`006Goo00<007ooOol0Ugoo002^Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool6000;Ool00`00Oomoo`2GOol00:ioo`03001oogoo009oo`03001oogoo01Uoo`03001o
ogoo09Ioo`00[Woo00H007oo000007oo0009Ool6000<Ool00`00Oomoo`2FOol00:ioo`06001oo`00
001oo`006goo00<007ooOol0UWoo002^Ool20002Ool2000LOol00`00Oomoo`2EOol00:ioo`80009o
o`8001Qoo`05001oogooOol0002GOol00:eoo`8000Aoo`8001Moo`D009Moo`00ogooJGoo003oOomY
Ool00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0882906 0.441453 [
[.2619 .07579 -9 -9 ]
[.2619 .07579 9 0 ]
[.5 .07579 -3 -9 ]
[.5 .07579 3 0 ]
[.7381 .07579 -9 -9 ]
[.7381 .07579 9 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .17658 -18 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -18 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08829 m
.2619 .09454 L
s
[(0.5)] .2619 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(1)] .5 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1.5)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.02381 0 m
.03006 0 L
s
[(-0.2)] .01131 0 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(0.2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(0.4)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(0.6)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(0.8)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(1)] .01131 .52974 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09721 m
.06244 .16156 L
.10458 .23894 L
.14415 .31157 L
.18221 .38115 L
.22272 .45548 L
.24141 .49384 L
.24654 .50436 L
.24934 .50941 L
.25197 .51349 L
.25439 .51654 L
.2566 .51867 L
.25786 .51957 L
.25906 .5202 L
.26033 .52063 L
.26104 .52077 L
.26171 .52082 L
.26241 .52081 L
.26305 .52073 L
.26375 .52056 L
.26449 .52031 L
.26575 .51969 L
.26712 .51874 L
.26965 .51628 L
.27202 .51323 L
.27733 .50425 L
.28302 .49251 L
.30316 .45185 L
.34452 .37562 L
.38436 .30231 L
.42269 .23225 L
.46347 .15769 L
.47322 .13791 L
.48373 .11544 L
.48856 .10679 L
.49119 .10303 L
.49365 .10029 L
.49473 .09934 L
.49575 .0986 L
.49692 .09794 L
.49799 .09752 L
.49917 .09726 L
.50027 .09721 L
.50147 .09737 L
.50274 .09779 L
.50394 .09841 L
.50508 .09919 L
.50722 .10116 L
.50952 .10397 L
.51203 .10773 L
Mistroke
.52072 .12468 L
.54049 .16486 L
.58119 .23973 L
.62037 .31162 L
.662 .38818 L
.70212 .46138 L
.72054 .50002 L
.72558 .5095 L
.72836 .51377 L
.73099 .51698 L
.73217 .51814 L
.73343 .51915 L
.73409 .51958 L
.73481 .51999 L
.73608 .52051 L
.73724 .52077 L
.73848 .52082 L
.73965 .52064 L
.74073 .52029 L
.74189 .51971 L
.74314 .51887 L
.74538 .5168 L
.74805 .51347 L
.75046 .50974 L
.7607 .48924 L
.78178 .44769 L
.82182 .37355 L
.86033 .30274 L
.9013 .22747 L
.94076 .15562 L
.97619 .09721 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`003goo0`001Woo0P0017oo1@00ogooAWoo000>Ool01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol00?moodIoo`001Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo0?moodIo
o`003Woo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<00?mooceoo`003Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00
Oomoo`3oOolmOol000moo`<000eoo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00
Oomoo`0nOol30006Ool20005Ool40010Ool5000oOol50004Ool20005Ool4000oOol5000>Ool002Uo
o`03001oogoo03eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0oOol00`00Oomoo`11Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`0mOol01000Oomoo`003Woo000YOol00`00Oomoo`0mOol0
1@00Oomoogoo000047oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
?Woo00<007ooOol03Woo000YOol00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0?goo
00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0?goo00<007ooOol03Goo000YOol00`00Oomo
o`0mOol01@00Oomoogoo000037oo1000@Woo00<007ooOol0@Goo00<007ooOol02goo1000@goo00<0
07ooOol037oo000YOol00`00Oomoo`0mOol01@00Oomoogoo000037oo00<007ooOol0@goo00<007oo
Ool0@Goo00<007ooOol02goo00<007ooOol0A7oo00<007ooOol037oo000YOol2000nOol01@00Oomo
ogoo000037oo00<007ooOol0@goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0@7oo00D0
07ooOomoo`0000ioo`00:Goo00<007ooOol0?Woo0`003Goo1000@7oo0`00@Goo0`003Goo1000@7oo
0`003goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`008Gooo`00@00027oo
000YOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool002Uoo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03
001oogoo04Uoo`03001oogoo00eoo`00:Goo00<007ooOol0Tgoo1000UGoo00<007ooOol03Goo000Y
Ool00`00Oomoo`2BOol00`00Oomoo`02Ool00`00Oomoo`2BOol00`00Oomoo`0=Ool002Uoo`80099o
o`03001oogoo00=oo`03001oogoo095oo`03001oogoo00ioo`00:Goo00<007oo0000TGoo00<007oo
Ool017oo00<007ooOol0Sgoo00<007ooOol03goo000YOol3002AOol00`00Oomoo`04Ool00`00Oomo
o`2?Ool00`00Oomoo`0?Ool002Uoo`04001oogoo002?Ool00`00Oomoo`06Ool00`00Oomoo`2=Ool0
0`00Oomoo`0@Ool002Uoo`04001oogoo002>Ool00`00Oomoo`08Ool00`00Oomoo`2<Ool00`00Oomo
o`0@Ool002Uoo`05001oogooOol0002=Ool00`00Oomoo`08Ool00`00Oomoo`2;Ool00`00Oomoo`0A
Ool002Uoo`03001oogoo009oo`03001oogoo08Uoo`03001oogoo00Yoo`03001oogoo08Uoo`03001o
ogoo019oo`00:Goo00<007ooOol00Woo00<007ooOol0RGoo00<007ooOol02Woo00<007ooOol0RGoo
00<007ooOol04Woo000YOol00`00Oomoo`03Ool00`00Oomoo`27Ool00`00Oomoo`0<Ool00`00Oomo
o`27Ool00`00Oomoo`0COol002Uoo`8000Aoo`03001oogoo08Moo`03001oogoo00aoo`03001oogoo
08Moo`03001oogoo01=oo`00:Goo00<007ooOol017oo00<007ooOol0QWoo00<007ooOol03Goo00<0
07ooOol0QGoo00<007ooOol057oo000YOol00`00Oomoo`05Ool00`00Oomoo`24Ool00`00Oomoo`0>
Ool00`00Oomoo`24Ool00`00Oomoo`0EOol002Uoo`03001oogoo00Eoo`03001oogoo08Aoo`03001o
ogoo00moo`03001oogoo08=oo`03001oogoo01Eoo`00:Goo00<007ooOol01Woo00<007ooOol0PWoo
00<007ooOol047oo00<007ooOol0PWoo00<007ooOol05Woo000YOol00`00Oomoo`06Ool00`00Oomo
o`22Ool00`00Oomoo`0@Ool00`00Oomoo`22Ool00`00Oomoo`0FOol002Uoo`03001oogoo00Moo`03
001oogoo081oo`03001oogoo019oo`03001oogoo081oo`03001oogoo01Moo`00:Goo0P002Goo00<0
07ooOol0Ogoo00<007ooOol04Woo00<007ooOol0Ogoo00<007ooOol067oo000YOol00`00Oomoo`08
Ool00`00Oomoo`1nOol00`00Oomoo`0DOol00`00Oomoo`1nOol00`00Oomoo`0HOol002Uoo`03001o
ogoo00Uoo`03001oogoo07eoo`03001oogoo01Aoo`03001oogoo07eoo`03001oogoo01Uoo`00:Goo
00<007ooOol02Goo00<007ooOol0O7oo00<007ooOol05Woo00<007ooOol0O7oo00<007ooOol06Goo
000?Ool30006Ool20004Ool50006Ool00`00Oomoo`0:Ool00`00Oomoo`1kOol00`00Oomoo`0FOol0
0`00Oomoo`1kOol00`00Oomoo`0JOol000ioo`05001oogooOol00005Ool20005Ool01000Oomoo`00
1Woo00<007ooOol02Woo00<007ooOol0NWoo00<007ooOol067oo00<007ooOol0NGoo00<007ooOol0
6goo000>Ool01@00Oomoogoo00003Goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0NGoo
00<007ooOol067oo00<007ooOol0NGoo00<007ooOol06goo000>Ool01@00Oomoogoo00003Woo00<0
07ooOol01Goo0`002goo00<007ooOol0N7oo00<007ooOol06Woo00<007ooOol0Mgoo00<007ooOol0
77oo000>Ool01@00Oomoogoo00003goo00<007ooOol017oo00<007ooOol037oo00<007ooOol0MWoo
00<007ooOol06goo00<007ooOol0Mgoo00<007ooOol077oo000>Ool01@00Oomoogoo00003goo00<0
07ooOol017oo00<007ooOol037oo00<007ooOol0MWoo00<007ooOol077oo00<007ooOol0MGoo00<0
07ooOol07Goo000>Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo00eoo`03
001oogoo07Aoo`03001oogoo01ioo`03001oogoo07Aoo`03001oogoo01eoo`003goo0`003Goo0`00
1goo00<007ooOol03Goo00<007ooOol0M7oo00<007ooOol07Woo00<007ooOol0Lgoo00<007ooOol0
7Woo000YOol00`00Oomoo`0>Ool00`00Oomoo`1bOol00`00Oomoo`0POol00`00Oomoo`1aOol00`00
Oomoo`0OOol002Uoo`03001oogoo00ioo`03001oogoo079oo`03001oogoo021oo`03001oogoo075o
o`03001oogoo01moo`00:Goo0P0047oo00<007ooOol0L7oo00<007ooOol08Woo00<007ooOol0Kgoo
00<007ooOol087oo000YOol00`00Oomoo`0@Ool00`00Oomoo`1_Ool00`00Oomoo`0ROol00`00Oomo
o`1_Ool00`00Oomoo`0POol002Uoo`03001oogoo011oo`03001oogoo06ioo`03001oogoo02Aoo`03
001oogoo06eoo`03001oogoo025oo`00:Goo00<007ooOol04Goo00<007ooOol0KGoo00<007ooOol0
97oo00<007ooOol0KGoo00<007ooOol08Goo000YOol00`00Oomoo`0AOol00`00Oomoo`1/Ool00`00
Oomoo`0VOol00`00Oomoo`1[Ool00`00Oomoo`0ROol002Uoo`03001oogoo019oo`03001oogoo06]o
o`03001oogoo02Ioo`03001oogoo06]oo`03001oogoo029oo`00:Goo00<007ooOol04Woo00<007oo
Ool0JWoo00<007ooOol0:7oo00<007ooOol0JGoo00<007ooOol08goo000YOol2000DOol00`00Oomo
o`1XOol00`00Oomoo`0YOol00`00Oomoo`1XOol00`00Oomoo`0TOol002Uoo`03001oogoo01=oo`03
001oogoo06Qoo`03001oogoo02Yoo`03001oogoo06Moo`03001oogoo02Aoo`00:Goo00<007ooOol0
57oo00<007ooOol0IWoo00<007ooOol0;7oo00<007ooOol0IGoo00<007ooOol09Goo000YOol00`00
Oomoo`0DOol00`00Oomoo`1VOol00`00Oomoo`0/Ool00`00Oomoo`1UOol00`00Oomoo`0UOol002Uo
o`03001oogoo01Eoo`03001oogoo06Aoo`03001oogoo02ioo`03001oogoo06=oo`03001oogoo02Io
o`00:Goo00<007ooOol05Goo00<007ooOol0I7oo00<007ooOol0;Woo00<007ooOol0Hgoo00<007oo
Ool09Woo000YOol00`00Oomoo`0FOol00`00Oomoo`1ROol00`00Oomoo`0`Ool00`00Oomoo`1QOol0
0`00Oomoo`0WOol002Uoo`8001Moo`03001oogoo069oo`03001oogoo031oo`03001oogoo065oo`03
001oogoo02Moo`00:Goo00<007ooOol05goo00<007ooOol0H7oo00<007ooOol0<Woo00<007ooOol0
Ggoo00<007ooOol0:7oo000YOol00`00Oomoo`0GOol00`00Oomoo`1OOol00`00Oomoo`0cOol00`00
Oomoo`1NOol00`00Oomoo`0YOol002Uoo`03001oogoo01Qoo`03001oogoo05ioo`03001oogoo03Ao
o`03001oogoo05eoo`03001oogoo02Uoo`00:Goo00<007ooOol06Goo00<007ooOol0G7oo00<007oo
Ool0=Woo00<007ooOol0Fgoo00<007ooOol0:Woo000?Ool30006Ool20006Ool30006Ool00`00Oomo
o`0IOol00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomoo`1KOol00`00Oomoo`0ZOol000ioo`05
001oogooOol00005Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`1JOol00`00
Oomoo`0hOol00`00Oomoo`1IOol00`00Oomoo`0[Ool000ioo`05001oogooOol0000;Ool50006Ool3
000JOol00`00Oomoo`1IOol00`00Oomoo`0iOol00`00Oomoo`1IOol00`00Oomoo`0[Ool000ioo`05
001oogooOol0000;Ool01000Oomoo`001goo00<007ooOol06goo00<007ooOol0F7oo00<007ooOol0
>Woo00<007ooOol0Egoo00<007ooOol0;7oo000>Ool01@00Oomoogoo000037oo00<007oo00001goo
00<007ooOol06goo00<007ooOol0Egoo00<007ooOol0>goo00<007ooOol0Egoo00<007ooOol0;7oo
000>Ool01@00Oomoogoo000037oo00<007oo00001goo00<007ooOol077oo00<007ooOol0EWoo00<0
07ooOol0?7oo00<007ooOol0EGoo00<007ooOol0;Goo000>Ool01@00Oomoogoo00003Goo0P001goo
00<007ooOol07Goo00<007ooOol0E7oo00<007ooOol0?Woo00<007ooOol0E7oo00<007ooOol0;Goo
000?Ool3000?Ool00`00Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`1COol00`00Oomoo`0oOol0
0`00Oomoo`1COol00`00Oomoo`0^Ool002Uoo`03001oogoo01ioo`03001oogoo059oo`03001oogoo
041oo`03001oogoo059oo`03001oogoo02ioo`00:Goo0P007goo00<007ooOol0DGoo00<007ooOol0
@Goo00<007ooOol0DGoo00<007ooOol0;goo000YOol00`00Oomoo`0OOol00`00Oomoo`1@Ool00`00
Oomoo`12Ool00`00Oomoo`1?Ool00`00Oomoo`0`Ool002Uoo`03001oogoo01moo`03001oogoo04mo
o`03001oogoo04=oo`03001oogoo04moo`03001oogoo031oo`00:Goo00<007ooOol087oo00<007oo
Ool0CGoo00<007ooOol0AGoo00<007ooOol0CGoo00<007ooOol0<Goo000YOol00`00Oomoo`0POol0
0`00Oomoo`1=Ool00`00Oomoo`15Ool00`00Oomoo`1=Ool00`00Oomoo`0aOol002Uoo`03001oogoo
025oo`03001oogoo04]oo`03001oogoo04Moo`03001oogoo04]oo`03001oogoo039oo`00:Goo00<0
07ooOol08Woo00<007ooOol0BWoo00<007ooOol0B7oo00<007ooOol0BWoo00<007ooOol0<Woo000Y
Ool2000SOol00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`0cOol002Uo
o`03001oogoo02=oo`03001oogoo04Qoo`03001oogoo04Yoo`03001oogoo04Qoo`03001oogoo03=o
o`00:Goo00<007ooOol08goo00<007ooOol0Agoo00<007ooOol0Bgoo00<007ooOol0Agoo00<007oo
Ool0=7oo000YOol00`00Oomoo`0TOol00`00Oomoo`16Ool00`00Oomoo`1<Ool00`00Oomoo`16Ool0
0`00Oomoo`0dOol002Uoo`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo04eoo`03001oogoo
04Eoo`03001oogoo03Eoo`00:Goo00<007ooOol09Goo00<007ooOol0A7oo00<007ooOol0CWoo00<0
07ooOol0A7oo00<007ooOol0=Goo000YOol00`00Oomoo`0UOol00`00Oomoo`13Ool00`00Oomoo`1?
Ool00`00Oomoo`13Ool00`00Oomoo`0fOol002Uoo`8002Moo`03001oogoo049oo`03001oogoo051o
o`03001oogoo049oo`03001oogoo03Ioo`00:Goo00<007ooOol09goo00<007ooOol0@7oo00<007oo
Ool0DWoo00<007ooOol0@7oo00<007ooOol0=goo000YOol00`00Oomoo`0WOol00`00Oomoo`10Ool0
0`00Oomoo`1BOol00`00Oomoo`10Ool00`00Oomoo`0gOol002Uoo`03001oogoo02Qoo`03001oogoo
03ioo`03001oogoo05Aoo`03001oogoo03ioo`03001oogoo03Qoo`00:Goo00<007ooOol0:7oo00<0
07ooOol0?Goo00<007ooOol0EGoo00<007ooOol0?Goo00<007ooOol0>Goo000?Ool30006Ool20005
Ool30007Ool00`00Oomoo`0YOol00`00Oomoo`0lOol00`00Oomoo`1FOol00`00Oomoo`0lOol00`00
Oomoo`0iOol000ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00001Woo00<007ooOol0
:Goo00<007ooOol0>goo00<007ooOol0Egoo00<007ooOol0>goo00<007ooOol0>Woo000>Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Ioo`<002Yoo`03001oogoo03Yoo`03001oogoo05Qoo`03
001oogoo03Yoo`03001oogoo03Yoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool0
0`00Oomoo`0ZOol00`00Oomoo`0iOol00`00Oomoo`1IOol00`00Oomoo`0iOol00`00Oomoo`0kOol0
00ioo`05001oogooOol0000;Ool40007Ool00`00Oomoo`0[Ool00`00Oomoo`0hOol00`00Oomoo`1J
Ool00`00Oomoo`0hOol00`00Oomoo`0kOol000ioo`05001oogooOol0000;Ool00`00Oomoo`08Ool0
0`00Oomoo`0[Ool00`00Oomoo`0gOol00`00Oomoo`1KOol00`00Oomoo`0gOol00`00Oomoo`0lOol0
00ioo`05001oogooOol0000<Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomoo`0fOol00`00
Oomoo`1LOol00`00Oomoo`0fOol00`00Oomoo`0lOol000moo`<000ioo`<000Ioo`03001oogoo02eo
o`03001oogoo03Aoo`03001oogoo05eoo`03001oogoo03Eoo`03001oogoo03eoo`00:Goo00<007oo
Ool0;Goo00<007ooOol0=7oo00<007ooOol0GWoo00<007ooOol0=7oo00<007ooOol0?Goo000YOol2
000_Ool00`00Oomoo`0bOol00`00Oomoo`1POol00`00Oomoo`0bOol00`00Oomoo`0nOol002Uoo`03
001oogoo02ioo`03001oogoo039oo`03001oogoo061oo`03001oogoo039oo`03001oogoo03ioo`00
:Goo00<007ooOol0;goo00<007ooOol0<7oo00<007ooOol0HWoo00<007ooOol0<7oo00<007ooOol0
?goo000YOol00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`1ROol00`00Oomoo`0`Ool00`00
Oomoo`0oOol002Uoo`03001oogoo031oo`03001oogoo02ioo`03001oogoo06Aoo`03001oogoo02io
o`03001oogoo041oo`00:Goo00<007ooOol0<7oo00<007ooOol0;Woo00<007ooOol0I7oo00<007oo
Ool0;Goo00<007ooOol0@Goo000YOol00`00Oomoo`0aOol00`00Oomoo`0/Ool00`00Oomoo`1VOol0
0`00Oomoo`0/Ool00`00Oomoo`11Ool002Uoo`80039oo`03001oogoo02aoo`03001oogoo06Ioo`03
001oogoo02]oo`03001oogoo049oo`00:Goo00<007ooOol0<Woo00<007ooOol0:Woo00<007ooOol0
J7oo00<007ooOol0:Woo00<007ooOol0@Woo000YOol00`00Oomoo`0cOol00`00Oomoo`0YOol00`00
Oomoo`1XOol00`00Oomoo`0YOol00`00Oomoo`13Ool002Uoo`03001oogoo03=oo`03001oogoo02Qo
o`03001oogoo06Yoo`03001oogoo02Qoo`03001oogoo04=oo`00:Goo00<007ooOol0=7oo00<007oo
Ool09goo00<007ooOol0Jgoo00<007ooOol09Woo00<007ooOol0A7oo000YOol00`00Oomoo`0dOol0
0`00Oomoo`0VOol00`00Oomoo`1/Ool00`00Oomoo`0UOol00`00Oomoo`15Ool002Uoo`03001oogoo
03Eoo`03001oogoo02Aoo`03001oogoo06ioo`03001oogoo02Aoo`03001oogoo04Eoo`00:Goo0P00
=Woo00<007ooOol097oo00<007ooOol0KWoo00<007ooOol08goo00<007ooOol0AWoo000YOol00`00
Oomoo`0fOol00`00Oomoo`0ROol00`00Oomoo`1`Ool00`00Oomoo`0ROol00`00Oomoo`16Ool002Uo
o`03001oogoo03Ioo`03001oogoo029oo`03001oogoo071oo`03001oogoo025oo`03001oogoo04Mo
o`00:Goo00<007ooOol0=goo00<007ooOol087oo00<007ooOol0LWoo00<007ooOol087oo00<007oo
Ool0Agoo000YOol00`00Oomoo`0gOol00`00Oomoo`0POol00`00Oomoo`1bOol00`00Oomoo`0OOol0
0`00Oomoo`18Ool000moo`<000Ioo`8000Eoo`<000Moo`03001oogoo03Qoo`03001oogoo01ioo`03
001oogoo07Aoo`03001oogoo01ioo`03001oogoo04Qoo`003Woo00D007ooOomoo`0000Eoo`8000Ao
o`05001oogooOol00006Ool00`00Oomoo`0hOol00`00Oomoo`0NOol00`00Oomoo`1dOol00`00Oomo
o`0MOol00`00Oomoo`19Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo0`00>Goo
00<007ooOol077oo00<007ooOol0MWoo00<007ooOol06goo00<007ooOol0BWoo000>Ool01@00Oomo
ogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo03Yoo`03001oogoo01]oo`03001oogoo07Io
o`03001oogoo01]oo`03001oogoo04Yoo`003Woo00D007ooOomoo`0000aoo`<000Moo`03001oogoo
03Yoo`03001oogoo01Yoo`03001oogoo07Qoo`03001oogoo01Uoo`03001oogoo04]oo`003Woo00D0
07ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0kOol00`00Oomoo`0IOol00`00Oomo
o`1iOol00`00Oomoo`0HOol00`00Oomoo`1;Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo
00001Woo00<007ooOol0>goo00<007ooOol067oo00<007ooOol0NWoo00<007ooOol05goo00<007oo
Ool0C7oo000?Ool3000=Ool30007Ool00`00Oomoo`0lOol00`00Oomoo`0GOol00`00Oomoo`1kOol0
0`00Oomoo`0FOol00`00Oomoo`1<Ool002Uoo`03001oogoo03aoo`03001oogoo01Ioo`03001oogoo
07aoo`03001oogoo01Eoo`03001oogoo04eoo`00:Goo0P00?Woo00<007ooOol05Goo00<007ooOol0
OGoo00<007ooOol057oo00<007ooOol0CGoo000YOol00`00Oomoo`0mOol00`00Oomoo`0DOol00`00
Oomoo`1nOol00`00Oomoo`0COol00`00Oomoo`1>Ool002Uoo`03001oogoo03ioo`03001oogoo01=o
o`03001oogoo07moo`03001oogoo019oo`03001oogoo04ioo`00:Goo00<007ooOol0?Woo00<007oo
Ool04Woo00<007ooOol0P7oo00<007ooOol04Goo00<007ooOol0Cgoo000YOol00`00Oomoo`0oOol0
0`00Oomoo`0@Ool00`00Oomoo`21Ool00`00Oomoo`0AOol00`00Oomoo`1?Ool002Uoo`03001oogoo
03moo`03001oogoo011oo`03001oogoo089oo`03001oogoo00moo`03001oogoo051oo`00:Goo00<0
07ooOol0@7oo00<007ooOol03Woo00<007ooOol0Pgoo00<007ooOol03goo00<007ooOol0D7oo000Y
Ool20011Ool00`00Oomoo`0>Ool00`00Oomoo`24Ool00`00Oomoo`0=Ool00`00Oomoo`1AOol002Uo
o`03001oogoo045oo`03001oogoo00aoo`03001oogoo08Eoo`03001oogoo00eoo`03001oogoo055o
o`00:Goo00<007ooOol0@Goo00<007ooOol037oo00<007ooOol0QWoo00<007ooOol02goo00<007oo
Ool0DWoo000YOol00`00Oomoo`12Ool00`00Oomoo`0:Ool00`00Oomoo`27Ool00`00Oomoo`0;Ool0
0`00Oomoo`1BOol002Uoo`03001oogoo049oo`03001oogoo00Yoo`03001oogoo08Moo`03001oogoo
00Yoo`03001oogoo05=oo`00:Goo00<007ooOol0@goo00<007ooOol027oo00<007ooOol0RGoo00<0
07ooOol02Goo00<007ooOol0Dgoo000YOol00`00Oomoo`14Ool00`00Oomoo`06Ool00`00Oomoo`2:
Ool00`00Oomoo`08Ool00`00Oomoo`1DOol002Uoo`8004Eoo`03001oogoo00Ioo`03001oogoo08]o
o`03001oogoo00Moo`03001oogoo05Aoo`00:Goo00<007ooOol0A7oo00<007ooOol01Goo00<007oo
Ool0SGoo00<007ooOol01Goo00<007ooOol0EGoo000YOol00`00Oomoo`15Ool00`00Oomoo`04Ool0
0`00Oomoo`2>Ool00`00Oomoo`03Ool00`00Oomoo`1FOol002Uoo`03001oogoo04Ioo`03001oogoo
009oo`03001oogoo091oo`05001oogooOol0001IOol002Uoo`03001oogoo04Moo`04001oo`00002C
Ool200000goo0000001IOol001moo`D000Eoo`03001oogoo04Qoo`8009Ioo`8005Yoo`008Goo00<0
07ooOol01Goo00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05Ool3003oOolmOol0025oo`03001o
ogoo00Eoo`03001oogoo0?mooceoo`008Goo00<007ooOol01Goo00<007ooOol0ogoo?Goo000QOol0
0`00Oomoo`05Ool00`00Oomoo`3oOolmOol0025oo`03001oogoo00Eoo`03001oogoo0?mooceoo`00
7goo0`001goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00
:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00
:Goo00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00
:Goo0P00ogoo?Woo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<0
07ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<0
07ooOol0ogoo?Goo000YOol2003oOolnOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomY
Ool00:eoo`<0009oo`<001Moo`<009Uoo`00[Woo00<007ooOol00Woo00<007ooOol01goo1P0037oo
00<007ooOol0UWoo002^Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`2EOol00:ioo`06
001oo`00001oo`002Goo1P002Woo1000Ugoo002^Ool01P00Ool00000Ool001Qoo`05001oogooOol0
002GOol00:ioo`80009oo`8001Qoo`05001oogooOol0002GOol00:ioo`80009oo`8001Qoo`05001o
ogooOol0002GOol00:eoo`8000Aoo`8001Qoo`<009Qoo`00ogooJGoo003oOomYOol00?moofUoo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0882906 0.441453 [
[.2619 .07579 -9 -9 ]
[.2619 .07579 9 0 ]
[.5 .07579 -3 -9 ]
[.5 .07579 3 0 ]
[.7381 .07579 -9 -9 ]
[.7381 .07579 9 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.01131 0 -24 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .17658 -18 -4.5 ]
[.01131 .17658 0 4.5 ]
[.01131 .26487 -18 -4.5 ]
[.01131 .26487 0 4.5 ]
[.01131 .35316 -18 -4.5 ]
[.01131 .35316 0 4.5 ]
[.01131 .44145 -18 -4.5 ]
[.01131 .44145 0 4.5 ]
[.01131 .52974 -6 -4.5 ]
[.01131 .52974 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .08829 m
.2619 .09454 L
s
[(0.5)] .2619 .07579 0 1 Mshowa
.5 .08829 m
.5 .09454 L
s
[(1)] .5 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1.5)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.02381 0 m
.03006 0 L
s
[(-0.2)] .01131 0 1 0 Mshowa
.02381 .17658 m
.03006 .17658 L
s
[(0.2)] .01131 .17658 1 0 Mshowa
.02381 .26487 m
.03006 .26487 L
s
[(0.4)] .01131 .26487 1 0 Mshowa
.02381 .35316 m
.03006 .35316 L
s
[(0.6)] .01131 .35316 1 0 Mshowa
.02381 .44145 m
.03006 .44145 L
s
[(0.8)] .01131 .44145 1 0 Mshowa
.02381 .52974 m
.03006 .52974 L
s
[(1)] .01131 .52974 1 0 Mshowa
.125 Mabswid
.02381 .02207 m
.02756 .02207 L
s
.02381 .04415 m
.02756 .04415 L
s
.02381 .06622 m
.02756 .06622 L
s
.02381 .11036 m
.02756 .11036 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .15451 m
.02756 .15451 L
s
.02381 .19865 m
.02756 .19865 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .2428 m
.02756 .2428 L
s
.02381 .28694 m
.02756 .28694 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33109 m
.02756 .33109 L
s
.02381 .37523 m
.02756 .37523 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .41938 m
.02756 .41938 L
s
.02381 .46353 m
.02756 .46353 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50767 m
.02756 .50767 L
s
.02381 .55182 m
.02756 .55182 L
s
.02381 .57389 m
.02756 .57389 L
s
.02381 .59596 m
.02756 .59596 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .09573 m
.06244 .16041 L
.10458 .23795 L
.14415 .31129 L
.18221 .38195 L
.22272 .45671 L
.24141 .49239 L
.2465 .50338 L
.25127 .51251 L
.25386 .51652 L
.25624 .51937 L
.25759 .52059 L
.25887 .52145 L
.25958 .5218 L
.26023 .52204 L
.26095 .52222 L
.26171 .5223 L
.26246 .52228 L
.26315 .52216 L
.2639 .52193 L
.2647 .52158 L
.2654 .52118 L
.26605 .52072 L
.26752 .51942 L
.27006 .51636 L
.27279 .51209 L
.28302 .49103 L
.30316 .45327 L
.34452 .37686 L
.38436 .30301 L
.42269 .23192 L
.46347 .15687 L
.47322 .13899 L
.48373 .11649 L
.48856 .10692 L
.49119 .1026 L
.49365 .0994 L
.49575 .0974 L
.49692 .09661 L
.49799 .09611 L
.49916 .09579 L
.50043 .09575 L
.50163 .09598 L
.50274 .09643 L
.50388 .09712 L
.50491 .09795 L
.50725 .10047 L
.50942 .10353 L
.51147 .10698 L
.52108 .12693 L
Mistroke
.54049 .1635 L
.57874 .23441 L
.61943 .30969 L
.65861 .38233 L
.70025 .45895 L
.71042 .47726 L
.72116 .50013 L
.72558 .50914 L
.72802 .51345 L
.73032 .51689 L
.73163 .51851 L
.73304 .51996 L
.73433 .52099 L
.73552 .52169 L
.73664 .52211 L
.73787 .5223 L
.73916 .5222 L
.74037 .52182 L
.74154 .52121 L
.74263 .52041 L
.7451 .51787 L
.7475 .51452 L
.75007 .51014 L
.75896 .49157 L
.77897 .45389 L
.82052 .37719 L
.86056 .30301 L
.89907 .23158 L
.94004 .15623 L
.97619 .09573 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.627485,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`003goo0`001Woo0P0017oo1@00ogooAWoo000>Ool01@00Oomoogoo00001Goo0P00
1Goo00@007ooOol00?moodIoo`001Woo1P000Woo00D007ooOomoo`0000eoo`03001oogoo0?moodIo
o`003Woo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<00?mooceoo`003Woo00D007ooOomoo`00
00moo`03001oogoo00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000moo`03001oogoo
00Aoo`03001oogoo0?mooceoo`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00
Oomoo`3oOolmOol000moo`<000eoo`<000Moo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo?Goo000Y
Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo0P00ogoo?Woo000YOol00`00
Oomoo`0nOol30006Ool20005Ool40010Ool5000oOol50004Ool20005Ool4000oOol5000>Ool002Uo
o`03001oogoo03eoo`05001oogooOol00005Ool20009Ool00`00Oomoo`0oOol00`00Oomoo`11Ool0
0`00Oomoo`04Ool20009Ool00`00Oomoo`0mOol01000Oomoo`003Woo000YOol00`00Oomoo`0mOol0
1@00Oomoogoo000047oo00<007ooOol0?goo00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0
?Woo00<007ooOol03Woo000YOol00`00Oomoo`0mOol01@00Oomoogoo000047oo00<007ooOol0?goo
00<007ooOol0@Goo00<007ooOol03goo00<007ooOol0?goo00<007ooOol03Goo000YOol00`00Oomo
o`0mOol01@00Oomoogoo000037oo1000@Woo00<007ooOol0@Goo00<007ooOol02goo1000@goo00<0
07ooOol037oo000YOol00`00Oomoo`0mOol01@00Oomoogoo000037oo00<007ooOol0@goo00<007oo
Ool0@Goo00<007ooOol02goo00<007ooOol0A7oo00<007ooOol037oo000YOol2000nOol01@00Oomo
ogoo000037oo00<007ooOol0@goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0@7oo00D0
07ooOomoo`0000ioo`00:Goo00<007ooOol0?Woo0`003Goo1000@7oo0`00@Goo0`003Goo1000@7oo
0`003goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0
ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`008Gooo`00@00027oo
000YOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomo
o`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0=Ool00`00Oomo
o`0<Ool00`00Oomoo`0=Ool002Uoo`03001oogoo04Qoo`03001oogoo04Uoo`8004Yoo`03001oogoo
04Uoo`03001oogoo00eoo`00:Goo00<007ooOol0TWoo0P0000=oo`000000UGoo00<007ooOol03Goo
000YOol2002BOol00`00Oomoo`03Ool00`00Oomoo`2AOol00`00Oomoo`0>Ool002Uoo`80099oo`03
001oogoo00=oo`03001oogoo091oo`03001oogoo00moo`00:Goo00<007oo0000TGoo00<007ooOol0
17oo00<007ooOol0Sgoo00<007ooOol03goo000YOol200000goo001oo`2?Ool00`00Oomoo`04Ool0
0`00Oomoo`2>Ool00`00Oomoo`0@Ool002Uoo`04001oogoo002?Ool00`00Oomoo`06Ool00`00Oomo
o`2=Ool00`00Oomoo`0@Ool002Uoo`05001oogooOol0002=Ool00`00Oomoo`07Ool00`00Oomoo`2<
Ool00`00Oomoo`0AOol002Uoo`05001oogooOol0002=Ool00`00Oomoo`08Ool00`00Oomoo`2:Ool0
0`00Oomoo`0BOol002Uoo`03001oogoo009oo`03001oogoo08Uoo`03001oogoo00Uoo`03001oogoo
08Yoo`03001oogoo019oo`00:Goo00<007ooOol00Woo00<007ooOol0RGoo00<007ooOol02Woo00<0
07ooOol0R7oo00<007ooOol04goo000YOol00`00Oomoo`03Ool00`00Oomoo`27Ool00`00Oomoo`0;
Ool00`00Oomoo`27Ool00`00Oomoo`0DOol002Uoo`8000Eoo`03001oogoo08Ioo`03001oogoo00ao
o`03001oogoo08Ioo`03001oogoo01Aoo`00:Goo00<007ooOol017oo00<007ooOol0QWoo00<007oo
Ool037oo00<007ooOol0QGoo00<007ooOol05Goo000YOol00`00Oomoo`05Ool00`00Oomoo`24Ool0
0`00Oomoo`0>Ool00`00Oomoo`23Ool00`00Oomoo`0FOol002Uoo`03001oogoo00Eoo`03001oogoo
08Aoo`03001oogoo00ioo`03001oogoo08=oo`03001oogoo01Ioo`00:Goo00<007ooOol01Woo00<0
07ooOol0PWoo00<007ooOol047oo00<007ooOol0PGoo00<007ooOol05goo000YOol00`00Oomoo`06
Ool00`00Oomoo`22Ool00`00Oomoo`0@Ool00`00Oomoo`21Ool00`00Oomoo`0GOol002Uoo`03001o
ogoo00Moo`03001oogoo081oo`03001oogoo019oo`03001oogoo07moo`03001oogoo01Qoo`00:Goo
0P002Goo00<007ooOol0Ogoo00<007ooOol04Woo00<007ooOol0OWoo00<007ooOol06Goo000YOol0
0`00Oomoo`08Ool00`00Oomoo`1nOol00`00Oomoo`0DOol00`00Oomoo`1mOol00`00Oomoo`0IOol0
02Uoo`03001oogoo00Uoo`03001oogoo07eoo`03001oogoo01Aoo`03001oogoo07aoo`03001oogoo
01Yoo`00:Goo00<007ooOol02Goo00<007ooOol0O7oo00<007ooOol05Woo00<007ooOol0Ngoo00<0
07ooOol06Woo000?Ool30006Ool20004Ool50006Ool00`00Oomoo`0:Ool00`00Oomoo`1kOol00`00
Oomoo`0FOol00`00Oomoo`1jOol00`00Oomoo`0KOol000ioo`05001oogooOol00005Ool20005Ool0
1000Oomoo`001Woo00<007ooOol02Woo00<007ooOol0NWoo00<007ooOol067oo00<007ooOol0NGoo
00<007ooOol06goo000>Ool01@00Oomoogoo00003Goo00<007ooOol01Woo00<007ooOol02goo00<0
07ooOol0NGoo00<007ooOol067oo00<007ooOol0N7oo00<007ooOol077oo000>Ool01@00Oomoogoo
00003Woo00<007ooOol01Goo0`002goo00<007ooOol0N7oo00<007ooOol06Woo00<007ooOol0MWoo
00<007ooOol07Goo000>Ool01@00Oomoogoo00003goo00<007ooOol017oo00<007ooOol037oo00<0
07ooOol0MWoo00<007ooOol06goo00<007ooOol0MWoo00<007ooOol07Goo000>Ool01@00Oomoogoo
00003goo00<007ooOol017oo00<007ooOol037oo00<007ooOol0MWoo00<007ooOol077oo00<007oo
Ool0M7oo00<007ooOol07Woo000>Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001o
ogoo00eoo`03001oogoo07Aoo`03001oogoo01ioo`03001oogoo07=oo`03001oogoo01ioo`003goo
0`003Goo0`001goo00<007ooOol03Goo00<007ooOol0M7oo00<007ooOol07Woo00<007ooOol0LWoo
00<007ooOol07goo000YOol00`00Oomoo`0>Ool00`00Oomoo`1bOol00`00Oomoo`0POol00`00Oomo
o`1aOol00`00Oomoo`0OOol002Uoo`03001oogoo00ioo`03001oogoo079oo`03001oogoo021oo`03
001oogoo071oo`03001oogoo021oo`00:Goo0P0047oo00<007ooOol0L7oo00<007ooOol08Woo00<0
07ooOol0Kgoo00<007ooOol087oo000YOol00`00Oomoo`0@Ool00`00Oomoo`1_Ool00`00Oomoo`0R
Ool00`00Oomoo`1^Ool00`00Oomoo`0QOol002Uoo`03001oogoo011oo`03001oogoo06ioo`03001o
ogoo02Aoo`03001oogoo06eoo`03001oogoo025oo`00:Goo00<007ooOol04Goo00<007ooOol0KGoo
00<007ooOol097oo00<007ooOol0K7oo00<007ooOol08Woo000YOol00`00Oomoo`0AOol00`00Oomo
o`1/Ool00`00Oomoo`0VOol00`00Oomoo`1[Ool00`00Oomoo`0ROol002Uoo`03001oogoo019oo`03
001oogoo06]oo`03001oogoo02Ioo`03001oogoo06Yoo`03001oogoo02=oo`00:Goo00<007ooOol0
4Woo00<007ooOol0JWoo00<007ooOol0:7oo00<007ooOol0J7oo00<007ooOol097oo000YOol2000D
Ool00`00Oomoo`1XOol00`00Oomoo`0ZOol00`00Oomoo`1WOol00`00Oomoo`0TOol002Uoo`03001o
ogoo01=oo`03001oogoo06Qoo`03001oogoo02Yoo`03001oogoo06Ioo`03001oogoo02Eoo`00:Goo
00<007ooOol057oo00<007ooOol0IWoo00<007ooOol0;7oo00<007ooOol0IGoo00<007ooOol09Goo
000YOol00`00Oomoo`0DOol00`00Oomoo`1VOol00`00Oomoo`0/Ool00`00Oomoo`1TOol00`00Oomo
o`0VOol002Uoo`03001oogoo01Eoo`03001oogoo06Aoo`03001oogoo02ioo`03001oogoo06=oo`03
001oogoo02Ioo`00:Goo00<007ooOol05Goo00<007ooOol0I7oo00<007ooOol0;Woo00<007ooOol0
HWoo00<007ooOol09goo000YOol00`00Oomoo`0FOol00`00Oomoo`1ROol00`00Oomoo`0`Ool00`00
Oomoo`1QOol00`00Oomoo`0WOol002Uoo`8001Moo`03001oogoo069oo`03001oogoo031oo`03001o
ogoo061oo`03001oogoo02Qoo`00:Goo00<007ooOol05goo00<007ooOol0H7oo00<007ooOol0<Woo
00<007ooOol0Ggoo00<007ooOol0:7oo000YOol00`00Oomoo`0GOol00`00Oomoo`1OOol00`00Oomo
o`0cOol00`00Oomoo`1NOol00`00Oomoo`0YOol002Uoo`03001oogoo01Qoo`03001oogoo05ioo`03
001oogoo03Aoo`03001oogoo05eoo`03001oogoo02Uoo`00:Goo00<007ooOol06Goo00<007ooOol0
G7oo00<007ooOol0=Woo00<007ooOol0Fgoo00<007ooOol0:Woo000?Ool30006Ool20006Ool30006
Ool00`00Oomoo`0IOol00`00Oomoo`1LOol00`00Oomoo`0fOol00`00Oomoo`1KOol00`00Oomoo`0Z
Ool000ioo`05001oogooOol00005Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomo
o`1JOol00`00Oomoo`0hOol00`00Oomoo`1IOol00`00Oomoo`0[Ool000ioo`05001oogooOol0000;
Ool50006Ool3000JOol00`00Oomoo`1IOol00`00Oomoo`0iOol00`00Oomoo`1IOol00`00Oomoo`0[
Ool000ioo`05001oogooOol0000;Ool01000Oomoo`001goo00<007ooOol06goo00<007ooOol0F7oo
00<007ooOol0>Woo00<007ooOol0Egoo00<007ooOol0;7oo000>Ool01@00Oomoogoo000037oo00<0
07oo00001goo00<007ooOol06goo00<007ooOol0Egoo00<007ooOol0>goo00<007ooOol0EWoo00<0
07ooOol0;Goo000>Ool01@00Oomoogoo000037oo00<007oo00001goo00<007ooOol077oo00<007oo
Ool0EWoo00<007ooOol0?7oo00<007ooOol0EGoo00<007ooOol0;Goo000>Ool01@00Oomoogoo0000
3Goo0P001goo00<007ooOol07Goo00<007ooOol0E7oo00<007ooOol0?Goo00<007ooOol0E7oo00<0
07ooOol0;Woo000?Ool3000?Ool00`00Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`1COol00`00
Oomoo`0oOol00`00Oomoo`1COol00`00Oomoo`0^Ool002Uoo`03001oogoo01ioo`03001oogoo059o
o`03001oogoo03moo`03001oogoo059oo`03001oogoo02moo`00:Goo0P007goo00<007ooOol0DGoo
00<007ooOol0@Goo00<007ooOol0DGoo00<007ooOol0;goo000YOol00`00Oomoo`0OOol00`00Oomo
o`1@Ool00`00Oomoo`11Ool00`00Oomoo`1@Ool00`00Oomoo`0`Ool002Uoo`03001oogoo01moo`03
001oogoo04moo`03001oogoo04=oo`03001oogoo04moo`03001oogoo031oo`00:Goo00<007ooOol0
87oo00<007ooOol0CGoo00<007ooOol0AGoo00<007ooOol0CGoo00<007ooOol0<Goo000YOol00`00
Oomoo`0POol00`00Oomoo`1=Ool00`00Oomoo`15Ool00`00Oomoo`1=Ool00`00Oomoo`0aOol002Uo
o`03001oogoo025oo`03001oogoo04]oo`03001oogoo04Moo`03001oogoo04]oo`03001oogoo039o
o`00:Goo00<007ooOol08Woo00<007ooOol0BWoo00<007ooOol0Agoo00<007ooOol0Bgoo00<007oo
Ool0<Woo000YOol2000SOol00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomoo`19Ool00`00Oomo
o`0cOol002Uoo`03001oogoo02=oo`03001oogoo04Qoo`03001oogoo04Uoo`03001oogoo04Uoo`03
001oogoo03=oo`00:Goo00<007ooOol08goo00<007ooOol0Agoo00<007ooOol0Bgoo00<007ooOol0
Agoo00<007ooOol0=7oo000YOol00`00Oomoo`0TOol00`00Oomoo`16Ool00`00Oomoo`1;Ool00`00
Oomoo`17Ool00`00Oomoo`0dOol002Uoo`03001oogoo02Aoo`03001oogoo04Eoo`03001oogoo04eo
o`03001oogoo04Eoo`03001oogoo03Eoo`00:Goo00<007ooOol09Goo00<007ooOol0A7oo00<007oo
Ool0CWoo00<007ooOol0@goo00<007ooOol0=Woo000YOol00`00Oomoo`0UOol00`00Oomoo`13Ool0
0`00Oomoo`1?Ool00`00Oomoo`13Ool00`00Oomoo`0fOol002Uoo`8002Moo`03001oogoo049oo`03
001oogoo051oo`03001oogoo045oo`03001oogoo03Moo`00:Goo00<007ooOol09goo00<007ooOol0
@7oo00<007ooOol0DGoo00<007ooOol0@Goo00<007ooOol0=goo000YOol00`00Oomoo`0WOol00`00
Oomoo`10Ool00`00Oomoo`1BOol00`00Oomoo`0oOol00`00Oomoo`0hOol002Uoo`03001oogoo02Qo
o`03001oogoo03ioo`03001oogoo05=oo`03001oogoo03moo`03001oogoo03Qoo`00:Goo00<007oo
Ool0:7oo00<007ooOol0?Woo00<007ooOol0E7oo00<007ooOol0?Goo00<007ooOol0>Goo000?Ool3
0006Ool20005Ool30007Ool00`00Oomoo`0YOol00`00Oomoo`0lOol00`00Oomoo`1FOol00`00Oomo
o`0lOol00`00Oomoo`0iOol000ioo`05001oogooOol00005Ool20004Ool01@00Oomoogoo00001Woo
00<007ooOol0:Goo00<007ooOol0?7oo00<007ooOol0EWoo00<007ooOol0>goo00<007ooOol0>Woo
000>Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`<002Yoo`03001oogoo03Yoo`03001o
ogoo05Qoo`03001oogoo03Yoo`03001oogoo03Yoo`003Woo00D007ooOomoo`0000]oo`05001oogoo
Ool00006Ool00`00Oomoo`0ZOol00`00Oomoo`0jOol00`00Oomoo`1HOol00`00Oomoo`0iOol00`00
Oomoo`0kOol000ioo`05001oogooOol0000;Ool40007Ool00`00Oomoo`0[Ool00`00Oomoo`0hOol0
0`00Oomoo`1JOol00`00Oomoo`0hOol00`00Oomoo`0kOol000ioo`05001oogooOol0000;Ool00`00
Oomoo`08Ool00`00Oomoo`0[Ool00`00Oomoo`0hOol00`00Oomoo`1JOol00`00Oomoo`0gOol00`00
Oomoo`0lOol000ioo`05001oogooOol0000<Ool00`00Oomoo`07Ool00`00Oomoo`0/Ool00`00Oomo
o`0fOol00`00Oomoo`1LOol00`00Oomoo`0eOol00`00Oomoo`0mOol000moo`<000ioo`<000Ioo`03
001oogoo02eoo`03001oogoo03Eoo`03001oogoo05aoo`03001oogoo03Eoo`03001oogoo03eoo`00
:Goo00<007ooOol0;Goo00<007ooOol0=7oo00<007ooOol0GWoo00<007ooOol0<goo00<007ooOol0
?Woo000YOol2000_Ool00`00Oomoo`0cOol00`00Oomoo`1OOol00`00Oomoo`0bOol00`00Oomoo`0n
Ool002Uoo`03001oogoo02ioo`03001oogoo039oo`03001oogoo061oo`03001oogoo035oo`03001o
ogoo03moo`00:Goo00<007ooOol0;goo00<007ooOol0<Goo00<007ooOol0HGoo00<007ooOol0<7oo
00<007ooOol0?goo000YOol00`00Oomoo`0_Ool00`00Oomoo`0`Ool00`00Oomoo`1ROol00`00Oomo
o`0_Ool00`00Oomoo`10Ool002Uoo`03001oogoo031oo`03001oogoo02moo`03001oogoo06=oo`03
001oogoo02ioo`03001oogoo041oo`00:Goo00<007ooOol0<7oo00<007ooOol0;Woo00<007ooOol0
I7oo00<007ooOol0;Goo00<007ooOol0@Goo000YOol00`00Oomoo`0aOol00`00Oomoo`0]Ool00`00
Oomoo`1UOol00`00Oomoo`0/Ool00`00Oomoo`11Ool002Uoo`80039oo`03001oogoo02aoo`03001o
ogoo06Ioo`03001oogoo02]oo`03001oogoo049oo`00:Goo00<007ooOol0<Woo00<007ooOol0:Woo
00<007ooOol0J7oo00<007ooOol0:Goo00<007ooOol0@goo000YOol00`00Oomoo`0cOol00`00Oomo
o`0YOol00`00Oomoo`1XOol00`00Oomoo`0YOol00`00Oomoo`13Ool002Uoo`03001oogoo03=oo`03
001oogoo02Qoo`03001oogoo06Yoo`03001oogoo02Moo`03001oogoo04Aoo`00:Goo00<007ooOol0
=7oo00<007ooOol09goo00<007ooOol0JWoo00<007ooOol09goo00<007ooOol0A7oo000YOol00`00
Oomoo`0dOol00`00Oomoo`0VOol00`00Oomoo`1/Ool00`00Oomoo`0UOol00`00Oomoo`15Ool002Uo
o`03001oogoo03Eoo`03001oogoo02Eoo`03001oogoo06aoo`03001oogoo02Eoo`03001oogoo04Eo
o`00:Goo0P00=Woo00<007ooOol097oo00<007ooOol0KWoo00<007ooOol08goo00<007ooOol0AWoo
000YOol00`00Oomoo`0fOol00`00Oomoo`0SOol00`00Oomoo`1_Ool00`00Oomoo`0ROol00`00Oomo
o`16Ool002Uoo`03001oogoo03Ioo`03001oogoo029oo`03001oogoo071oo`03001oogoo025oo`03
001oogoo04Moo`00:Goo00<007ooOol0=goo00<007ooOol08Goo00<007ooOol0LGoo00<007ooOol0
87oo00<007ooOol0Agoo000YOol00`00Oomoo`0gOol00`00Oomoo`0POol00`00Oomoo`1bOol00`00
Oomoo`0OOol00`00Oomoo`18Ool000moo`<000Ioo`8000Eoo`<000Moo`03001oogoo03Qoo`03001o
ogoo01moo`03001oogoo07=oo`03001oogoo01ioo`03001oogoo04Qoo`003Woo00D007ooOomoo`00
00Eoo`8000Aoo`05001oogooOol00006Ool00`00Oomoo`0hOol00`00Oomoo`0NOol00`00Oomoo`1d
Ool00`00Oomoo`0MOol00`00Oomoo`19Ool000ioo`05001oogooOol0000;Ool01@00Oomoogoo0000
1Woo0`00>Goo00<007ooOol077oo00<007ooOol0MWoo00<007ooOol06goo00<007ooOol0BWoo000>
Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo03Yoo`03001oogoo01]oo`03
001oogoo07Ioo`03001oogoo01]oo`03001oogoo04Yoo`003Woo00D007ooOomoo`0000aoo`<000Mo
o`03001oogoo03Yoo`03001oogoo01Yoo`03001oogoo07Qoo`03001oogoo01Uoo`03001oogoo04]o
o`003Woo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`0kOol00`00Oomoo`0I
Ool00`00Oomoo`1hOol00`00Oomoo`0IOol00`00Oomoo`1;Ool000ioo`05001oogooOol0000;Ool0
1@00Oomoogoo00001Woo00<007ooOol0>goo00<007ooOol067oo00<007ooOol0NWoo00<007ooOol0
5goo00<007ooOol0C7oo000?Ool3000=Ool30007Ool00`00Oomoo`0lOol00`00Oomoo`0GOol00`00
Oomoo`1jOol00`00Oomoo`0GOol00`00Oomoo`1<Ool002Uoo`03001oogoo03aoo`03001oogoo01Io
o`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo04eoo`00:Goo0P00?Woo00<007ooOol05Goo
00<007ooOol0O7oo00<007ooOol05Goo00<007ooOol0CGoo000YOol00`00Oomoo`0mOol00`00Oomo
o`0DOol00`00Oomoo`1nOol00`00Oomoo`0COol00`00Oomoo`1>Ool002Uoo`03001oogoo03ioo`03
001oogoo019oo`03001oogoo07moo`03001oogoo01=oo`03001oogoo04ioo`00:Goo00<007ooOol0
?Woo00<007ooOol04Woo00<007ooOol0P7oo00<007ooOol04Goo00<007ooOol0Cgoo000YOol00`00
Oomoo`0oOol00`00Oomoo`0@Ool00`00Oomoo`21Ool00`00Oomoo`0AOol00`00Oomoo`1?Ool002Uo
o`03001oogoo03moo`03001oogoo011oo`03001oogoo089oo`03001oogoo00moo`03001oogoo051o
o`00:Goo00<007ooOol0@7oo00<007ooOol03Woo00<007ooOol0Pgoo00<007ooOol03goo00<007oo
Ool0D7oo000YOol20011Ool00`00Oomoo`0=Ool00`00Oomoo`25Ool00`00Oomoo`0=Ool00`00Oomo
o`1AOol002Uoo`03001oogoo045oo`03001oogoo00aoo`03001oogoo08Eoo`03001oogoo00eoo`03
001oogoo055oo`00:Goo00<007ooOol0@Goo00<007ooOol02goo00<007ooOol0Qgoo00<007ooOol0
2goo00<007ooOol0DWoo000YOol00`00Oomoo`12Ool00`00Oomoo`0:Ool00`00Oomoo`28Ool00`00
Oomoo`0:Ool00`00Oomoo`1BOol002Uoo`03001oogoo049oo`03001oogoo00Uoo`03001oogoo08Uo
o`03001oogoo00Uoo`03001oogoo05=oo`00:Goo00<007ooOol0@goo00<007ooOol027oo00<007oo
Ool0RWoo00<007ooOol027oo00<007ooOol0Dgoo000YOol00`00Oomoo`13Ool00`00Oomoo`07Ool0
0`00Oomoo`2;Ool00`00Oomoo`07Ool00`00Oomoo`1DOol002Uoo`8004Aoo`03001oogoo00Moo`03
001oogoo08aoo`03001oogoo00Ioo`03001oogoo05Aoo`00:Goo00<007ooOol0A7oo00<007ooOol0
1Woo00<007ooOol0S7oo00<007ooOol01Goo00<007ooOol0EGoo000YOol00`00Oomoo`15Ool00`00
Oomoo`04Ool00`00Oomoo`2>Ool00`00Oomoo`04Ool00`00Oomoo`1EOol002Uoo`03001oogoo04Io
o`03001oogoo009oo`03001oogoo091oo`03001oogoo009oo`03001oogoo05Ioo`00:Goo00<007oo
Ool0Agoo00@007ooOol009=oo`03001oogoo008005Uoo`007goo1@001Goo00<007ooOol0Agoo1000
U7oo0`00FWoo000QOol00`00Oomoo`05Ool00`00Oomoo`3oOolmOol0025oo`03001oogoo00Eoo`<0
0?mooceoo`008Goo00<007ooOol01Goo00<007ooOol0ogoo?Goo000QOol00`00Oomoo`05Ool00`00
Oomoo`3oOolmOol0025oo`03001oogoo00Eoo`03001oogoo0?mooceoo`008Goo00<007ooOol01Goo
00<007ooOol0ogoo?Goo000OOol30007Ool00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceo
o`00:Goo0P00ogoo?Woo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo
00<007ooOol0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo
00<007ooOol0ogoo?Goo000YOol2003oOolnOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007oo
Ool0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007oo
Ool0ogoo?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`800?moocioo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol002Uoo`03001oogoo0?mooceoo`00:Goo00<007ooOol0ogoo
?Goo000YOol00`00Oomoo`3oOolmOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogoo
JGoo003oOomYOol00?moofUoo`00ZWoo0`000Woo0`0067oo1@000goo1@00TGoo002[Ool00`00Oomo
o`02Ool00`00Oomoo`07Ool6000<Ool00`00Oomoo`05Ool00`00Oomoo`2AOol00:]oo`03001oogoo
009oo`03001oogoo01Uoo`03001oogoo00Eoo`03001oogoo095oo`00Zgoo00H007oo000007oo0009
Ool6000<Ool00`00Oomoo`05Ool00`00Oomoo`2AOol00:]oo`06001oo`00001oo`006goo00<007oo
Ool01Goo00<007ooOol0TGoo002[Ool20002Ool2000KOol00`00Oomoo`05Ool00`00Oomoo`2AOol0
0:]oo`80009oo`8001]oo`03001oogoo00Eoo`03001oogoo095oo`00ZWoo0P0017oo0P0067oo0`00
1Goo0`00Tgoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "One can see that as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases",
  ",",
  " the series approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is converging quite nicely. This is to be expected: according to Eq. ",
  ButtonBox["(2.1.11)",
    ButtonData:>"(2.1.11)",
    ButtonStyle->"Hyperlink"],
  ", the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " fall off with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " like ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\^2\)]],
  ", so coefficients with large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " make a negligible contribution to the series. "
}], "Text"],

Cell[TextData[{
  "\tAlthough the series converges, convergence is more rapid in some places \
than others. The error in the series is greatest near the sharp points in the \
triangle wave. This should come as no surprise, since a sharp point \
introduces rapid variation that is difficult  to reproduce by smoothly \
varying cosine Fourier modes. Functions with rapid variation must be \
described by rapidly varying cosine and sine functions, which means that ",
  Cell[BoxData[
      \(TraditionalForm\`n >> 1\)]],
  " terms must be kept in the Fourier series.  "
}], "Text"],

Cell[TextData[StyleBox["Functions that vary smoothly can be well- described \
by a finite Fourier series keeping a relatively small number of terms. \
Functions with more rapid variation need more terms in the series.",
  FontSlant->"Plain"]], "Text",
  CellFrame->True,
  FontSlant->"Italic",
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "Perhaps it is now starting to become clear as to why the restrictions on \
",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " are necessary in Theorem 2.1. If ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " has a discontinuity or its derivative is singular, it cannot be \
represented properly by sine and cosine functions, because these functions do \
not have discontinuities or singularities",
  StyleBox[".",
    FontSlant->"Italic"],
  " "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.4 Square Wave", "Subsubtitle",
  CellTags->"c:6"],

Cell[TextData[{
  "\tOur next example is a good illustration of what happens when a function \
violates the restrictions of Theorem 2.1. Consider a ",
  StyleBox["square wave with period ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", defined by the following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[f];\)\), "\n", 
    \(\(f[t_]\  := \ 1\  /; \ 0 \[LessEqual] \ t < T/2;\)\), "\n", 
    \(f[t_]\  := \ \(-1\)\  /; \ \(-T\)/2\  \[LessEqual] \ \ t\  < \ 
          0\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.13"],

Cell[TextData[{
  "The definition of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is extended over the entire real line using the same recursive technique \
as for the triangle wave, as shown in Cell ",
  ButtonBox["2.14",
    ButtonData:>"Cell 2.14",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[t_]\  := \ f[t + T]\  /; \ t < \(-T\)/2;\)\), "\n", 
    \(\(f[t_]\  := \ f[t - T]\  /; \ t > T/2;\)\), "\n", 
    \(T = 1; \ Plot[f[t], {t, \(-3\), 3}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.14"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309017 0.294302 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .01472 -12 -4.5 ]
[.4875 .01472 0 4.5 ]
[.4875 .16187 -24 -4.5 ]
[.4875 .16187 0 4.5 ]
[.4875 .45617 -18 -4.5 ]
[.4875 .45617 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .01472 m
.50625 .01472 L
s
[(-1)] .4875 .01472 1 0 Mshowa
.5 .16187 m
.50625 .16187 L
s
[(-0.5)] .4875 .16187 1 0 Mshowa
.5 .45617 m
.50625 .45617 L
s
[(0.5)] .4875 .45617 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .25016 m
.50375 .25016 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .36788 m
.50375 .36788 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04262 .60332 L
.06244 .60332 L
.08255 .60332 L
.08806 .60332 L
.09396 .60332 L
.09682 .60332 L
.09952 .60332 L
.1007 .60332 L
.10195 .60332 L
.1026 .60332 L
.10332 .01472 L
.10458 .01472 L
.12562 .01472 L
.14487 .01472 L
.15437 .01472 L
.16474 .01472 L
.16949 .01472 L
.17454 .01472 L
.177 .01472 L
.17931 .01472 L
.18032 .01472 L
.18139 .01472 L
.18256 .60332 L
.18364 .60332 L
.22161 .60332 L
.24112 .60332 L
.24674 .60332 L
.25206 .60332 L
.25684 .60332 L
.25815 .60332 L
.25954 .60332 L
.26072 .60332 L
.26204 .01472 L
.26325 .01472 L
.26438 .01472 L
.26695 .01472 L
.27213 .01472 L
.28138 .01472 L
.30224 .01472 L
.31276 .01472 L
.3227 .01472 L
.33161 .01472 L
.33406 .01472 L
.33665 .01472 L
.33885 .01472 L
.34011 .01472 L
.34128 .60332 L
.34254 .60332 L
.34387 .60332 L
Mistroke
.34626 .60332 L
.35169 .60332 L
.36157 .60332 L
.38011 .60332 L
.39042 .60332 L
.40156 .60332 L
.40668 .60332 L
.41208 .60332 L
.41669 .60332 L
.41795 .60332 L
.4193 .60332 L
.42058 .60332 L
.42174 .01472 L
.42293 .01472 L
.42404 .01472 L
.42656 .01472 L
.43168 .01472 L
.44087 .01472 L
.46164 .01472 L
.4715 .01472 L
.48186 .01472 L
.49071 .01472 L
.49314 .01472 L
.49572 .01472 L
.49698 .01472 L
.49816 .01472 L
.49923 .01472 L
.50038 .60332 L
.50162 .60332 L
.50275 .60332 L
.50529 .60332 L
.50987 .60332 L
.52029 .60332 L
.54135 .60332 L
.56041 .60332 L
.56563 .60332 L
.57119 .60332 L
.57593 .60332 L
.57723 .60332 L
.57791 .60332 L
.57863 .60332 L
.57926 .60332 L
.57995 .01472 L
.58116 .01472 L
.60239 .01472 L
.62169 .01472 L
.63131 .01472 L
.64175 .01472 L
.64654 .01472 L
.65161 .01472 L
Mistroke
.65594 .01472 L
.65712 .01472 L
.6584 .01472 L
.6596 .60332 L
.6607 .60332 L
.68131 .60332 L
.70043 .60332 L
.71893 .60332 L
.72426 .60332 L
.72927 .60332 L
.73378 .60332 L
.73501 .60332 L
.73631 .60332 L
.73743 .60332 L
.73865 .01472 L
.73995 .01472 L
.74116 .01472 L
.74389 .01472 L
.74886 .01472 L
.75817 .01472 L
.77909 .01472 L
.79777 .01472 L
.80289 .01472 L
.8084 .01472 L
.81094 .01472 L
.81361 .01472 L
.81589 .01472 L
.81718 .01472 L
.81838 .60332 L
.81966 .60332 L
.82101 .60332 L
.82343 .60332 L
.82891 .60332 L
.83885 .60332 L
.85744 .60332 L
.87725 .60332 L
.88591 .60332 L
.89049 .60332 L
.89299 .60332 L
.89535 .60332 L
.89666 .60332 L
.89739 .01472 L
.89807 .01472 L
.90053 .01472 L
.90534 .01472 L
.91481 .01472 L
.93571 .01472 L
.97527 .01472 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oegoo00<007ooOol0
eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003;Ool5
0007Ool00`00Oomoo`3FOol00<eoo`03001oogoo00Moo`03001oogoo0=Ioo`00;Goo8P008Woo8P00
8Woo9P007Woo8`008Goo8`008Goo8`0037oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`09Ool70005Ool00`00Oomoo`07Ool00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/
Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01Eoo`03001oogoo00Moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo
00<007ooOol07Woo00<007ooOol087oo00<007ooOol05Goo00<007ooOol01goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo
000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0EOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03
001oogoo01ioo`03001oogoo021oo`03001oogoo01=oo`<000Uoo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol057oo0P00
2Goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00
Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0O
Ool3000OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool0
02eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00
;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00
Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`<001moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo
000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool0
02eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`<001mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02ao
o`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo
000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07goo0`007goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03
001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01io
o`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02ao
o`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`02Ool20007Ool30005Ool40008Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01io
o`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`05001oogooOol00002Ool00`00Oomo
o`04Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo
01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`04001oogoo0004Ool00`00Oomo
o`03Ool30009Ool00`00Oomoo`05Ool4000NOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03
001oogoo01ioo`03001oogoo01Yoo`L0009oo`03001oogoo009oo`03001oogoo00moo`03001oogoo
00Eoo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol087oo00@007ooOol000Aoo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0
87oo00@007ooOol000Aoo`03001oogoo00Yoo`D000Qoo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol0
7Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00@007ooOol000Aoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<0
07ooOol07Woo00<007ooOol087oo00D007ooOomoo`00009oo`03001oogoo00]oo`03001oogoo00Yo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007oo
Ool087oo00<007ooOol00Woo0P003Woo1@0027oo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool0
02eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol3000OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo
000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool0
02eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01moo`<001moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01io
o`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02ao
o`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo
000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01moo`<001moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0N
Ool00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/
Ool002eoo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03
001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo01io
o`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo02ao
o`003Goo100077oo00<007ooOol07Woo00<007oo00001@006goo00<007ooOol07Woo00<007ooOol0
1@006goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07Goo1@007goo00<007ooOol077oo
1P007goo00<007ooOol07Goo10002goo000<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomo
o`0NOol01000Oomoo`000goo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol00Woo00<007oo
Ool06goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07Goo00D007oo001oo`0001moo`03001oogoo01aoo`03001oogoo009oo`03001oogoo00Qoo`00
4Goo00<007ooOol06Goo00<007ooOol07Woo00D007ooOomoo`0001ioo`03001oogoo01ioo`03001o
ogoo009oo`03001oogoo01]oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01ioo`80025oo`03001oogoo025oo`03001oogoo00Qoo`000goo1`001goo
00<007ooOol06Goo00<007ooOol05goo200017oo00<007ooOol06goo00<007ooOol05goo200017oo
00<007ooOol06goo00<007ooOol07goo0`007goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol08Goo00<007ooOol027oo000>Ool3000LOol00`00Oomo
o`0NOol00`00Oomoo`03Ool00`00Oomoo`0JOol00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomo
o`0KOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol2000POol00`00Oomoo`0NOol3000;Ool0015oo`03001oogoo01Uoo`03001oogoo01ioo`03
001oogoo00Aoo`03001oogoo01Uoo`03001oogoo01ioo`03001oogoo009oo`03001oogoo01]oo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oo`0001moo`03001oogoo025oo`03001oogoo00Qoo`004Goo00<007ooOol06Goo00<007ooOol0
7Woo00<007ooOol017oo00<007ooOol06Goo00<007ooOol07Woo00<007ooOol00Woo00<007ooOol0
6goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007oo00007goo00<007ooOol08Goo00<007ooOol027oo000<Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol00`00Oomoo`0NOol00`00Ool00004Ool00`00Oomoo`0IOol00`00Oomoo`0NOol00`00
Oomoo`03000MOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0MOol3000QOol00`00Oomo
o`0LOol01P00Oomoo`00Ool001moo`03001oogoo01aoo`03001oogoo009oo`03001oogoo00Qoo`00
3Goo100077oo00<007ooOol07Woo00<007ooOol0100077oo00<007ooOol07Woo00@007ooOomoo`80
01eoo`03001oogoo01moo`03001oogoo01moo`03001oogoo01ioo`80025oo`03001oogoo01eoo`@0
021oo`03001oogoo01eoo`@000]oo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol0
7Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00
Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eo
o`03001oogoo01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007oo
Ool087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol0;7oo000]Ool00`00Oomoo`0NOol00`00Oomoo`0POol0
0`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0/Ool002eoo`03001oogoo
01ioo`03001oogoo021oo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
02aoo`00;Goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07Woo00<007ooOol087oo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol0;7oo00000goo0000003o002/0002Ool000]oo`03001oogoo00Yoo`03
001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00]oo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Yoo`03
001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Aoo`03
001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00]oo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Yoo`8000aoo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo
00Yoo`002goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo0P0087oo00<007ooOol07goo00<007ooOol02Woo000]Ool00`00Oomoo`0OOol00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eo
o`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01io
o`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo
01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo
02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<0
07ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo
00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo
00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol3000OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol0
0`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]
Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0N
Ool00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomo
o`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomo
o`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03
001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol0
87oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00
Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eo
o`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01io
o`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo
01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`<001moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00
;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol0
7Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01io
o`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007oo
Ool07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007oo
Ool0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol0
0`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]
Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0N
Ool00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo
00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomo
o`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomo
o`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03
001oogoo01moo`<001moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo
01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0N
Ool00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001o
ogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001o
ogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo
00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03
001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00
;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol0
7Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01io
o`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007oo
Ool07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007oo
Ool0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol0
0`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<0
07ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo0`007goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00
Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00
Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021o
o`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007oo
Ool087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol0
0`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool0
02eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo
01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0N
Ool00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001o
ogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001o
ogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo
00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomo
o`0POol00`00Oomoo`0OOol00`00Oomoo`02Ool20007Ool30005Ool40008Ool00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool0
02eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`05001oogoo
Ool00002Ool00`00Oomoo`04Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/
Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`04001o
ogoo0004Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`05Ool00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001o
ogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`04001oogoo0004Ool00`00
Oomoo`0?Ool00`00Oomoo`05Ool4000NOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0P
Ool00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001o
ogoo021oo`03001oogoo01moo`04001oogoo0004Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`04001oogoo0004Ool00`00Oomoo`0:Ool50008Ool00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eo
o`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`04001oogoo0004
Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`05001oogooOol00002Ool00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol0
0`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo
021oo`03001oogoo01moo`03001oogoo009oo`8000ioo`D000Qoo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<0
07ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0P
Ool00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001o
ogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo
00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo
000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomo
o`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol0
7Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo0`007goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0O
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/
Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001o
ogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomo
o`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03
001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03
001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00
Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01mo
o`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02ao
o`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007oo
Ool07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo
01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<0
07ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0O
Ool00`00Oomoo`0OOol3000OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool0
0`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol0
0`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0O
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/
Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001o
ogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo
00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomo
o`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03
001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03
001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
87oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00
Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01mo
o`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`<001moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo
00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo
00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol0
7goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol0
7goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0
;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00
Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00
Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021o
o`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01mo
o`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007oo
Ool07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool0
0`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol0
0`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo
021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<0
07ooOol087oo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0O
Ool00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/
Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001o
ogoo01moo`<001moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01io
o`03001oogoo02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007oo
Ool07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007oo
Ool087oo00<007ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol0
0`00Oomoo`0POol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol0
0`00Oomoo`0OOol00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo
01moo`03001oogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo
01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo
02aoo`00;Goo00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<0
07ooOol07Woo00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0P
Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo
00<007ooOol07goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol07goo
00<007ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo
00<007ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomo
o`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomo
o`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001oogoo01ioo`03
001oogoo021oo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo01moo`03
001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001oogoo02aoo`00;Goo00<007ooOol0
7goo00<007ooOol07Woo00<007ooOol087oo00<007ooOol07goo00<007ooOol04goo1@001goo00<0
07ooOol07goo00<007ooOol07goo00<007ooOol07goo00<007ooOol087oo00<007ooOol07Woo00<0
07ooOol0;7oo000]Ool00`00Oomoo`0OOol00`00Oomoo`0NOol00`00Oomoo`0POol00`00Oomoo`0O
Ool00`00Oomoo`0EOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`0OOol00`00Oomoo`0O
Ool00`00Oomoo`0POol00`00Oomoo`0NOol00`00Oomoo`0/Ool002eoo`03001oogoo01moo`03001o
ogoo01ioo`03001oogoo021oo`03001oogoo01moo`03001oogoo01Eoo`03001oogoo00Moo`03001o
ogoo01moo`03001oogoo01moo`03001oogoo01moo`03001oogoo021oo`03001oogoo01ioo`03001o
ogoo02aoo`002goo8`008Goo8P008Woo8`005goo00<007ooOol01goo8`008Goo8`008Woo8P00;Woo
003=Ool00`00Oomoo`07Ool00`00Oomoo`3FOol00<eoo`03001oogoo00Moo`03001oogoo0=Ioo`00
cGoo00<007ooOol01goo00<007ooOol0eWoo003;Ool30009Ool00`00Oomoo`3FOol00<aoo`8000Uo
o`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-3, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Our square wave has been defined as an ",
  StyleBox["odd function",
    FontSlant->"Italic"],
  ", satisfying"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(\(-t\)) = \(-\(f(t)\)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(2.1.13)"],

Cell[TextData[{
  "and therefore ",
  "its",
  " Fourier representation will be as a sine series. The Fourier coefficients \
",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " follow from Eq. ",
  ButtonBox["(2.1.10)",
    ButtonData:>"(2.1.10)",
    ButtonStyle->"Hyperlink"],
  ", and can be determined using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as follows:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(b[n_]\  = \ 
      FullSimplify[
        2/T\ \((\(-Integrate[
                  Sin[2\ Pi\ n\ t/T], {t, \(-T\)/2, 
                    0}]\)\  + \[IndentingNewLine]Integrate[
                Sin[2\ Pi\ n\ t/T], {t, 0, T/2}])\), 
        n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.15"],

Cell[BoxData[
    \(\(2 - 2\ Cos[n\ \[Pi]]\)\/\(n\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell["Thus, this Fourier series has the simple form", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\_approx\)(t, \ M)\), "=", 
          RowBox[{
            StyleBox[\(\(\(4\)\(\ \)\)\/\[Pi]\),
              FontSize->14], 
            UnderoverscriptBox[
              StyleBox["\[CapitalSigma]",
                FontSize->19], \(\(n = 1\) \((n\ odd)\)\), "M"], 
            StyleBox[\(1\/n\),
              FontSize->14], \(sin(2\ \[Pi]\ n\ t/T)\), " "}]}], 
        TraditionalForm]]],
  " ."
}], "NumberedEquation",
  CellTags->{"(2.1.14)", "i:9"}],

Cell[TextData[{
  "The Fourier coefficients fall off rather slowly as ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " increases, like ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\)]],
  " .  The coefficients for the triangle wave fell off more rapidly, as ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\^2\)]],
  " [see Eq. ",
  ButtonBox["(2.1.11)]",
    ButtonData:>"(2.1.11)",
    ButtonStyle->"Hyperlink"],
  ". This makes some sense, since  the square wave isdiscontinuous and the \
triangle wave continuous,  so the high-",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " terms in the square wave series have more weight .  However, this is also \
a problem: because the high-",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " terms are so important, our finite approximation to the series will not \
converge the same way as for the triangle wave. Let's construct a finite \
series, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_approx\)(t, M)\)]],
  ", and view its convergence with a table of plots as we did previously for \
the triangle wave. This is done in Cell ",
  ButtonBox["2.16",
    ButtonData:>"Cell 2.16",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f\_approx[t_, M_]\  := \ 
        Sum[b[n]\ Sin[2  Pi\ n\ t/T], {n, 1, M}];\)\), "\n", 
    \(T = 1; 
    Table[Plot[f\_approx[t, M], {t, \(-1\), 1}, 
        PlotRange \[Rule] {\(-1.5\), 1.5}, 
        PlotLabel \[Rule] "\<M = \>" <> ToString[M]], {M, 4, 20, 
        4}];\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.16"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.03279 .37043 L
.04262 .43269 L
.053 .48756 L
.05753 .50691 L
.06244 .52438 L
.06526 .53266 L
.06786 .53917 L
.07051 .54469 L
.07298 .54885 L
.07559 .5522 L
.07697 .55357 L
.07846 .55472 L
.0792 .55518 L
.08001 .55558 L
.08078 .55589 L
.08149 .55609 L
.08219 .55623 L
.08283 .5563 L
.08356 .55631 L
.08426 .55626 L
.08544 .55604 L
.08673 .5556 L
.08738 .5553 L
.08808 .55493 L
.08934 .55412 L
.09179 .55207 L
.09402 .54971 L
.09944 .54232 L
.10458 .53371 L
.11335 .51742 L
.1228 .50089 L
.12821 .49329 L
.13058 .49057 L
.13317 .48809 L
.13563 .48625 L
.13792 .485 L
.13918 .4845 L
.14033 .48418 L
.14097 .48405 L
.14166 .48395 L
.14291 .48388 L
.14414 .48396 L
.14529 .48415 L
.14655 .48451 L
.14726 .48477 L
.14791 .48504 L
.15062 .48661 L
.1532 .48867 L
.15774 .49358 L
Mistroke
.16268 .50053 L
.17371 .51994 L
.18369 .53814 L
.18857 .54571 L
.19114 .54906 L
.19385 .552 L
.19622 .55401 L
.19757 .55489 L
.19883 .55553 L
.19998 .55595 L
.20104 .5562 L
.20225 .55632 L
.2034 .55625 L
.20461 .55599 L
.2053 .55575 L
.20594 .55547 L
.20724 .55473 L
.20863 .55367 L
.21115 .55101 L
.21346 .54772 L
.21879 .53695 L
.22147 .52983 L
.22439 .52073 L
.23469 .47819 L
.24404 .42709 L
.265 .28761 L
.27513 .21975 L
.28584 .15653 L
.29499 .11364 L
.30018 .0948 L
.30504 .08105 L
.30742 .07567 L
.31002 .07084 L
.31248 .06725 L
.31475 .06475 L
.31679 .06316 L
.31796 .06252 L
.31905 .06209 L
.3202 .06182 L
.32125 .06172 L
.3224 .06178 L
.32362 .06202 L
.32487 .06246 L
.326 .06301 L
.32855 .06477 L
.33091 .06699 L
.33314 .06954 L
.34355 .0859 L
.35237 .10234 L
.36185 .11861 L
Mistroke
.36728 .12591 L
.36986 .12866 L
.37225 .13074 L
.37464 .13234 L
.3759 .13299 L
.37655 .13327 L
.37724 .13352 L
.37853 .13388 L
.37973 .13408 L
.38091 .13415 L
.38199 .1341 L
.38314 .13393 L
.38437 .13362 L
.38553 .13319 L
.38659 .1327 L
.38919 .13109 L
.39164 .12904 L
.39653 .12357 L
.40184 .11583 L
.41184 .09802 L
.42288 .07809 L
.42779 .0708 L
.43037 .06766 L
.43308 .065 L
.43547 .06326 L
.43683 .06255 L
.43808 .06208 L
.43924 .06181 L
.4403 .06172 L
.44152 .06179 L
.44266 .06203 L
.44388 .06249 L
.44457 .06284 L
.44521 .06322 L
.44663 .06428 L
.44791 .0655 L
.45025 .06835 L
.45275 .07233 L
.45836 .08486 L
.46368 .1014 L
.4733 .14236 L
.48354 .19946 L
.50194 .32246 L
.52197 .45081 L
.52746 .47938 L
.53324 .50503 L
.53825 .52313 L
.541 .5314 L
.5436 .53811 L
.54609 .54351 L
Mistroke
.54879 .54826 L
.55124 .5516 L
.55241 .55287 L
.55351 .55387 L
.55462 .5547 L
.55564 .55531 L
.55678 .55582 L
.558 .55616 L
.55916 .55631 L
.56043 .55626 L
.56163 .55604 L
.56275 .55567 L
.56407 .55504 L
.56549 .55415 L
.56808 .55198 L
.57291 .5463 L
.58374 .52831 L
.59404 .50919 L
.60366 .49421 L
.60851 .48885 L
.61123 .48665 L
.6137 .48518 L
.61511 .48459 L
.61641 .4842 L
.61709 .48406 L
.61784 .48395 L
.61863 .48389 L
.61936 .48389 L
.62002 .48393 L
.62071 .48401 L
.62194 .48427 L
.62263 .48447 L
.62327 .4847 L
.62473 .48535 L
.62735 .48699 L
.62977 .48902 L
.63524 .49528 L
.64517 .51119 L
.65413 .52789 L
.66376 .54427 L
.66636 .54785 L
.66882 .55076 L
.67122 .55307 L
.67239 .55399 L
.67345 .5547 L
.67446 .55527 L
.67555 .55574 L
.6767 .5561 L
.67778 .55628 L
.67898 .55631 L
Mistroke
.68025 .55613 L
.68133 .55581 L
.68251 .55528 L
.6839 .5544 L
.68521 .55332 L
.68767 .55059 L
.69032 .54662 L
.69319 .54107 L
.69837 .52774 L
.70315 .51162 L
.7128 .4686 L
.72184 .41728 L
.74246 .27891 L
.76096 .16231 L
.76603 .13635 L
.77144 .11259 L
.77612 .09562 L
.78118 .08115 L
.784 .07488 L
.7866 .07022 L
.78908 .06674 L
.79035 .06533 L
.7917 .06409 L
.79293 .06319 L
.79406 .06256 L
.79518 .06211 L
.79625 .06184 L
.7975 .06172 L
.79865 .06178 L
.79991 .06205 L
.80055 .06226 L
.80125 .06254 L
.80258 .06323 L
.80398 .06418 L
.80649 .06636 L
.81214 .07333 L
.82236 .09072 L
.83189 .1084 L
.83712 .1172 L
.84207 .12421 L
.84668 .12925 L
.84928 .13136 L
.85052 .13216 L
.85168 .1328 L
.85274 .13327 L
.8537 .13361 L
.85478 .13389 L
.85593 .13408 L
.85703 .13415 L
.85823 .13409 L
Mistroke
.85937 .13392 L
.86043 .13366 L
.86171 .1332 L
.86307 .13255 L
.86551 .131 L
.86812 .12877 L
.871 .1257 L
.88096 .11094 L
.89051 .09336 L
.89956 .07728 L
.90445 .07018 L
.90703 .06715 L
.90977 .06459 L
.91207 .06302 L
.91338 .06239 L
.91461 .06199 L
.91573 .06177 L
.91676 .06172 L
.91789 .06181 L
.91908 .0621 L
.92039 .06264 L
.92158 .06334 L
.92296 .0644 L
.92426 .06566 L
.92657 .06853 L
.92907 .07257 L
.93476 .08543 L
.94 .10186 L
.9489 .13948 L
.95723 .18446 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
NP3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo0100oooo0P00001L0?ooo`800000
903oool2000002l0oooo001h0?ooo`80000000<0oooo0000000000008@3oool2000000030?ooo`00
000000000100oooo00<000000?ooo`3oool0FP3oool500000200oooo1P00000]0?ooo`00M`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0M0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:`3oool0
07L0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
02X0oooo001g0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool06`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0F03oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`0Y0?ooo`00MP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo05L0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0:@3oool007H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`1G0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02T0oooo001e0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo0P00001G
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0oooo02P0oooo001e0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?oo
o`3oool0EP3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`00M03oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00X0oooo00<000000?ooo`3oool0:03oool007@0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02L0oooo001c0?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0000000<0000000<04A4A0?ooo`3oool00`3oool00`000000oooo0?ooo`1E0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo02L0oooo001c0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool0
0`000000oooo0?ooo`0=0?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`1E0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo02L0oooo001c0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`060?ooo`H0000000<0oooo0000003oool00P3oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo05@0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09P3oool0
07<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00h0oooo00D000000?ooo`3oool0oooo000000070?ooo`<00000E03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0V
0?ooo`00LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool03P3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool0E03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0V0?ooo`00LP3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo05<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool09@3oool00780oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0100oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`1C0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02D0oooo001b0?ooo`030000003oool0oooo
0140oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0A0?ooo`040000001EEED0EEEE
000000L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0U0?ooo`00LP3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool09@3oool00740
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool01`3oool2000005@0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0903oool00740oooo
00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo02@0oooo
001a0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`0T0?ooo`00L@3oool00`000000oooo0?ooo`0G0?ooo`H000006@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool05`3oool6000001T0oooo00<00000
0?ooo`3oool0903oool00740oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool08`3oool00700oooo00<000000?ooo`3o
ool0>03oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`0S0?ooo`00L03oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo02<0oooo001`0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool01@3o
ool200000580oooo00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`0S0?ooo`00L03oool0
0`000000oooo0?ooo`0h0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0D@3oool0
0`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0280oooo001`0?ooo`030000003oool0oooo
03P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0oooo
03T0oooo00<000000?ooo`3oool08P3oool006l0oooo00<000000?ooo`3oool0>P3oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool0>@3oool00`000000
oooo0?ooo`0R0?ooo`00K`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0280oooo
001_0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`1@0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool08P3oool006l0oooo00<00000
0?ooo`3oool0>P3oool00`000000oooo0?ooo`040?ooo`800000D@3oool00`000000oooo0?ooo`0k
0?ooo`030000003oool0oooo0240oooo001^0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo03/0oooo00<000000?oo
o`3oool08@3oool006h0oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0500oooo00<000000?ooo`3oool0>`3oool00`000000oooo0?ooo`0Q0?ooo`00
KP3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
C`3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo0240oooo001^0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1?0?ooo`030000003o
ool0oooo03`0oooo00<000000?ooo`3oool08@3oool006h0oooo00<000000?ooo`3oool0?03oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool0?@3oool0
0`000000oooo0?ooo`0P0?ooo`00K@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
0200oooo001]0?ooo`030000003oool0oooo03d0oooo00<000000?ooo`3oool00`3oool200000500
oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`0P0?ooo`00K@3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0m0?ooo`030000003oool0oooo0200oooo001]0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03h0oooo00<0
00000?ooo`3oool0803oool006d0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0P
0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2
028R8PD0oooo00H0A4A4000000000000<c<c0=gMg@0000040?ooo`030000003oool0oooo04h0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0O0?ooo`00K03oool00`000000oooo0?oo
o`0Y0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`000000
103oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
7`3oool006`0oooo00<000000?ooo`3oool08@3oool600000080oooo00D04A4A0?ooo`3oool0oooo
014A4@0@0?ooo`800000103oool3000004h0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`0O0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`050000003oool0oooo0?ooo`000000
3`3oool00`1gMgL0<c<c000000040?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0O0?ooo`00K03oool00`000000oooo0?ooo`0Y0?ooo`050000003o
ool0oooo0?ooo`000000303oool01`0000008R8R0000000c<c<0c<c<0?ooo`0000000`3oool00`00
0000oooo0?ooo`1>0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool07`3oool006/0
oooo00<000000?ooo`3oool0:P3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000004l0oooo00<000000?ooo`3oool0@03oool0
0`000000oooo0?ooo`0O0?ooo`00J`3oool00`000000oooo0?ooo`0Z0?ooo`0507MgM`2IVIT0oooo
09VIV@1gMgL0303oool00`000000oooo0?ooo`030?ooo`050000003oool0oooo0?ooo`000000C`3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo01l0oooo001[0?ooo`030000003oool0
oooo02X0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000000P3oool01@000000oooo0?oo
o`3oool0000004l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?ooo`00J`3o
ool00`000000oooo0?ooo`110?ooo`050000003oool0oooo0?ooo`000000C`3oool00`000000oooo
0?ooo`110?ooo`030000003oool0oooo01h0oooo001[0?ooo`030000003oool0oooo0440oooo00@0
00000?ooo`3oool0oooo0P00001>0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0
7P3oool006/0oooo00<000000?ooo`3oool0@@3oool01@000000oooo0?ooo`3oool0000004l0oooo
00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`000000oooo0?oo
o`130?ooo`040000003oool0oooo000004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo
0?ooo`0N0?ooo`00JP3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000004h0oooo
00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`000000oooo0?oo
o`130?ooo`040000003oool0oooo000004h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`0M0?ooo`00JP3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000004h0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0M0?ooo`00JP3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00800000C@3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04<0oooo00@000000?ooo`3oool00000CP3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003oool0
oooo04@0oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`140?ooo`030000003oool0
oooo01d0oooo001Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`000000C@3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo001Y0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0
oooo001Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`000000C@3oool00`000000oooo
0?ooo`150?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`000000C@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01`0oooo000M
0?ooo`@0000000<04A4A0?ooo`3oool0?03oool01@3^k^h0<c<c0000000c<c<0k^k^00@0oooo00<0
0000028R8P0R8R801@3oool01@14A4@000000000000c<c<0gMgM03/0oooo00@000000?ooo`000000
0000?`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R800`3oool000000?ooo`020?oo
o`0504A4A0000000000003<c<`3MgMd0?`3oool400000003014A4@3oool0oooo01P0oooo000O0?oo
o`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`040?ooo`030000000R8R80
8R8R00P0oooo00<0MgMg03<c<`3oool0>P3oool00`000000oooo000000100?ooo`0507MgM`2IVIT0
oooo09VIV@1gMgL01@3oool2028R8P030?ooo`000000oooo00D0oooo00<0MgMg03<c<`3oool0?P3o
ool00`000000oooo0000000L0?ooo`00503oool6000000D0oooo00<000000?ooo`3oool0=P3oool6
00000080oooo00D04A4A0?ooo`3oool0oooo014A4@040?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0>P3oool200000400oooo00D04A4A0?ooo`3oool0oooo014A4@070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0000000L0?ooo`007`3o
ool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`090?ooo`0307MgM`0c<c<0oooo03/0oooo0P0000100?ooo`050000003oool0oooo0?ooo`00
00001`3oool00`000000oooo0?ooo`050?ooo`0307MgM`0c<c<0oooo03h0oooo00<000000?ooo`00
0000703oool001l0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool01P3oool01@0000008R8R0000000c<c<0c<c<03`0oooo0P0000100?oo
o`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`020?ooo`050000000R8R80
000003<c<`3<c<`0@03oool2000001`0oooo000O0?ooo`030000003oool0oooo03h0oooo00D04A4A
0?ooo`3oool0oooo014A4@030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?P3o
ool200000400oooo00D04A4A0?ooo`3oool0oooo014A4@070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool0@P3oool2000001`0oooo000O0?ooo`030000003oool0oooo03h0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`030?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
?P3oool200000400oooo00D0MgMg09VIV@3oool0VIVI07MgM`070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0@P3oool2000001`0oooo000M0?ooo`80EEEE00<000000?ooo`3oool0
?P3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00<000000?ooo`3oool01P3oool4000003d0
oooo0`00000o0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01`3oool00`000000oooo0?ooo`020?oo
o`@00000@03oool00`1EEED000000000000L0?ooo`00J03oool00`000000oooo0?ooo`180?ooo`03
0000003oool0oooo04X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00
J03oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B03oool00`000000oooo0?ooo`0K0?ooo`00J03oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0K0?ooo`00I`3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`0J0?ooo`00I`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0J0?ooo`00503ooooo00000400
00005@3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3o
ool2000004X0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0
oooo06L0oooo000L0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool20000
04T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`1:0?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo04X0oooo0P0000190?ooo`030000003oool0oooo06L0oooo
000L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0BP3oool2000004T0oooo00<0
00000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0000004P0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0000004P0oooo00<000000?oo
o`3oool0I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`03
0000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0
J03oool001d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0A@3oool0
0`000000oooo0?ooo`1;0?ooo`<00000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000A`3oool00`00
0000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0
oooo00@000000?ooo`3oool00000AP3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000AP3oool00`00
0000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0
oooo00@000000?ooo`3oool00000AP3oool00`000000oooo0?ooo`1X0?ooo`007P3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000A@3oool00`00
0000oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04/0
oooo00@000000?ooo`3oool00000A@3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000
oooo0?ooo`130?ooo`030000003oool0oooo04`0oooo0P0000000`3oool000000?ooo`140?ooo`03
0000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
C03oool010000000oooo0?ooo`0000150?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000
003oool0oooo04<0oooo00<000000?ooo`3oool0C03oool01@000000oooo0?ooo`3oool0000004@0
oooo00<000000?ooo`3oool0J@3oool001h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`1<0?ooo`050000003oool0oooo0?ooo`000000A03oool00`000000oooo0?ooo`1Y0?ooo`00
7`3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo04`0oooo00D000000?ooo`3oool0
oooo000000140?ooo`030000003oool0oooo06T0oooo000O0?ooo`030000003oool0oooo0480oooo
00<000000?ooo`3oool0C03oool01@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3o
ool0JP3oool001l0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`1<0?ooo`800000
0P3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo06X0oooo000O0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0C03oool01@000000oooo0?ooo`3oool0000004<0oooo
00<000000?ooo`3oool0JP3oool001l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`1=0?ooo`050000003oool0oooo0?ooo`000000@`3oool00`000000oooo0?ooo`1Z0?ooo`007`3o
ool00`000000oooo0?ooo`110?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo06X0oooo000O0?ooo`030000003oool0
oooo0440oooo00<000000?ooo`3oool0<P3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R
8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo0400oooo00<000000?ooo`3oool0JP3oool00200oooo00<000000?ooo`3oool0@03o
ool00`000000oooo0?ooo`0b0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo
00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0400oooo
00<000000?ooo`3oool0JP3oool00200oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0b0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`1[0?ooo`00803o
ool00`000000oooo0?ooo`100?ooo`030000003oool0oooo0380oooo00D000000?ooo`3oool0oooo
0000000?0?ooo`0307MgM`0c<c<0oooo00@0oooo0`0000020?ooo`030000003oool0oooo03l0oooo
00<000000?ooo`3oool0J`3oool00200oooo00<000000?ooo`3oool0@03oool00`000000oooo0?oo
o`0b0?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<00D0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo06/0
oooo000P0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0<`3oool01@0A4A40oooo
0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo03l0oooo00<000000?ooo`3oool0J`3oool00200oooo00<000000?ooo`3oool0
?`3oool00`000000oooo0?ooo`0c0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000
oooo0?ooo`070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0?P3oool00`000000
oooo0?ooo`1[0?ooo`00803oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03<0oooo
00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000001P3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo03h0oooo00<000000?ooo`3oool0J`3oool00240oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`1[0?ooo`008@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo04h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool0oooo06`0oooo000Q0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool0CP3oool2
000000@0oooo00<000000?ooo`3oool0?@3oool00`000000oooo0?ooo`1/0?ooo`008@3oool00`00
0000oooo0?ooo`0n0?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0m0?ooo`030000003oool0oooo06`0oooo000Q0?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03d0
oooo00<000000?ooo`3oool0K03oool00280oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`1?0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0?03oool00`000000oooo
0?ooo`1/0?ooo`008P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04l0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo06d0oooo000R
0?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3oool0K@3oool00280oooo00<000000?oo
o`3oool0?03oool00`000000oooo0?ooo`1?0?ooo`8000001@3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo06d0oooo000S0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3o
ool0D03oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03/0oooo00<000000?ooo`3o
ool0K@3oool002<0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1@0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0>P3oool00`000000oooo0?ooo`1]0?ooo`008`3o
ool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo06h0oooo000S0?ooo`030000003oool0
oooo03X0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo03T0oooo00<000000?ooo`3oool0KP3oool002<0oooo00<000000?ooo`3oool0>P3oool00`00
0000oooo0?ooo`1@0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0>@3oool00`00
0000oooo0?ooo`1^0?ooo`00903oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0540
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo06h0
oooo000T0?ooo`030000003oool0oooo03P0oooo00<000000?ooo`3oool0D@3oool2000000L0oooo
00<000000?ooo`3oool0>03oool00`000000oooo0?ooo`1^0?ooo`00903oool00`000000oooo0?oo
o`0h0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0g0?ooo`030000003oool0oooo06l0oooo000T0?ooo`030000003oool0oooo03P0oooo00<00000
0?ooo`3oool0D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03L0oooo00<00000
0?ooo`3oool0K`3oool002D0oooo00<000000?ooo`3oool0603oool4000001/0oooo00<000000?oo
o`3oool0D@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01P0oooo1@00000J0?oo
o`030000003oool0oooo06l0oooo000U0?ooo`030000003oool0oooo01H0oooo0P0000040?ooo`80
0000603oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0K`3oool002D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo06l0oooo000U0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0580oooo0P0000080?ooo`030000003o
ool0oooo01@0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0700oooo000U0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0C0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`1`0?ooo`009P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0L03oool002H0oooo00<000000?ooo`3oool04P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0D`3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0C0?ooo`030000003oool0oooo0700oooo000V0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo04T0oooo
100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
4@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0
L03oool002H0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0L@3oool002L0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0C03oool0
0`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0403oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0L@3oool0
02L0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`050?ooo`<000002@3oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`1a0?ooo`009`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0100
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1b0?ooo`00:03oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1=0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`1b0?ooo`00:03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`1b0?ooo`00:03oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1<
0?ooo`80EEEE00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo07<0oooo000Y0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`1c0?ooo`00:@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1G0?ooo`8000002`3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool02@3oool00`000000
oooo0?ooo`1d0?ooo`00:@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00P0oooo
00<000000?ooo`3oool0M03oool002T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0G0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0E`3oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo07D0oooo000Z0?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo05P0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`1e0?ooo`00:`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1H0?oo
o`030000003oool0oooo00d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool0M@3oool002/0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0F@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo07H0oooo000/0?ooo`800000
0P3oool200000200oooo0P0000020?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0200000200oooo0P0000030?ooo`030000003oool0oooo07L0oooo
000]0?ooo`@000008P3oool3000005d0oooo0P00000@0?ooo`<000008`3oool3000007X0oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool40000
0003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool0
0`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1g
MgL0<c<c0?ooo`040?ooo`030000003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo
0?ooo`0>0?ooo`0307MgM`0c<c<0oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo0?oo
o`0;0?ooo`050000000R8R80000003<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`2l0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0;`0oooo002I0?ooo`80EEEE00<000000?ooo`3oool02`3oool400000;/0oooo003o0?ooofT0
oooo003o0?ooofT0oooo003o0?ooofT0oooo002P0?ooo`80000000H04A4A0?ooo`3oool04A4A0000
000A4A4I0?ooo`80000000<04A4A0?ooo`3oool0XP3oool00:40oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`070?ooo`H00000303oool00`000000oooo0?ooo`2S0?ooo`00X@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo1@00002T0?ooo`00X@3oool01P00
0000oooo04A4A00c<c<0oooo000000T0oooo1P0000090?ooo`0404A4A03MgMd0oooo00000:D0oooo
002Q0?ooo`060000003MgMd0<c<c05EEE@3MgMd00000603oool0103MgMd0EEEE0?ooo`00002U0?oo
o`00X@3oool01P000000R8R80:ZZZP2k^k/0EEEE000001T0oooo00<0MgMg0<c<c0000000Y@3oool0
0:40oooo00H0000003<c<`3oool0oooo03<c<`00000I0?ooo`030>k^kP14A4@000000:D0oooo002P
0?ooo`03014A4@000000R8R80080oooo00<0R8R80000000A4A406@3oool00`1gMgL000000?ooo`2T
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.03279 .42734 L
.03793 .48226 L
.04262 .51927 L
.04517 .53364 L
.04758 .54344 L
.0489 .5473 L
.05012 .54994 L
.05076 .55099 L
.05146 .55187 L
.05219 .55252 L
.05288 .55287 L
.05412 .55291 L
.05529 .5523 L
.05634 .55126 L
.05749 .54964 L
.05873 .54738 L
.06006 .54445 L
.06244 .53817 L
.06791 .52127 L
.07079 .51254 L
.07382 .50448 L
.07649 .49891 L
.078 .49649 L
.07941 .49476 L
.0807 .49363 L
.08189 .493 L
.08254 .49281 L
.08325 .49273 L
.08454 .49291 L
.08578 .49348 L
.08694 .49434 L
.08822 .49562 L
.08959 .49736 L
.09495 .50678 L
.09994 .51708 L
.10237 .52177 L
.10458 .5255 L
.10696 .52876 L
.10805 .52993 L
.10921 .53094 L
.11044 .53174 L
.11158 .53221 L
.1128 .53243 L
.1135 .53242 L
.11415 .53233 L
.1148 .53215 L
.1155 .53187 L
.11679 .53112 L
.11804 .53011 L
Mistroke
.1192 .52895 L
.12462 .52124 L
.12985 .51214 L
.13259 .50763 L
.13549 .50359 L
.13672 .5022 L
.13803 .50095 L
.13879 .50036 L
.13948 .49991 L
.14018 .49953 L
.14082 .49925 L
.14203 .49894 L
.14334 .49889 L
.14449 .49912 L
.14572 .49962 L
.14699 .50041 L
.14815 .50137 L
.15077 .50428 L
.1555 .51151 L
.16065 .5205 L
.16338 .52486 L
.16628 .52869 L
.16755 .53 L
.16875 .531 L
.16982 .53168 L
.17099 .53218 L
.17209 .53241 L
.17326 .5324 L
.17426 .53217 L
.17536 .53169 L
.1766 .53087 L
.17774 .52986 L
.18029 .52676 L
.1849 .51882 L
.18966 .50903 L
.19414 .50043 L
.19639 .497 L
.19754 .49557 L
.19881 .49431 L
.20012 .49337 L
.20083 .49303 L
.2015 .49283 L
.20269 .49274 L
.20396 .49305 L
.20469 .49342 L
.20535 .49389 L
.20686 .49538 L
.2082 .49719 L
.20961 .4996 L
.21474 .51199 L
Mistroke
.21995 .52806 L
.22471 .54211 L
.22702 .54746 L
.22833 .54981 L
.22955 .55146 L
.23071 .55251 L
.23177 .55295 L
.23299 .55281 L
.23414 .55199 L
.23537 .55034 L
.23667 .54766 L
.23778 .54458 L
.239 .54034 L
.24172 .52753 L
.24426 .51131 L
.24889 .4716 L
.2531 .42528 L
.26257 .29981 L
.27183 .17957 L
.27651 .13137 L
.2792 .10922 L
.28167 .09288 L
.28435 .07952 L
.28576 .07432 L
.28724 .07014 L
.28853 .06755 L
.28973 .06598 L
.29105 .06515 L
.29179 .06506 L
.29246 .0652 L
.29374 .06603 L
.29492 .0674 L
.29622 .06949 L
.29759 .07228 L
.30243 .08552 L
.30728 .10073 L
.31188 .11346 L
.31442 .11883 L
.31585 .1212 L
.31718 .12293 L
.31841 .12411 L
.31953 .12484 L
.32081 .12526 L
.32202 .12526 L
.32309 .12496 L
.32426 .12431 L
.32548 .12329 L
.32662 .12206 L
.32865 .11925 L
.33083 .11554 L
Mistroke
.34034 .09649 L
.34292 .09216 L
.34433 .09018 L
.34565 .08861 L
.34687 .08744 L
.34798 .08662 L
.34922 .08598 L
.3499 .08576 L
.35055 .08564 L
.35125 .0856 L
.35188 .08564 L
.35261 .0858 L
.3533 .08603 L
.35453 .08667 L
.35522 .08715 L
.35585 .08767 L
.35866 .09071 L
.36164 .09503 L
.36663 .1036 L
.37136 .11141 L
.37397 .11489 L
.37534 .11636 L
.3768 .11761 L
.37803 .11839 L
.37873 .11871 L
.37939 .11894 L
.38054 .11914 L
.38178 .1191 L
.38301 .11878 L
.38416 .11823 L
.38542 .11737 L
.38676 .11617 L
.38951 .11289 L
.39201 .10915 L
.4014 .09327 L
.4036 .09026 L
.40593 .08778 L
.40714 .08683 L
.40779 .08643 L
.40848 .08609 L
.40969 .0857 L
.41083 .0856 L
.41197 .08575 L
.41322 .08622 L
.41439 .08694 L
.41548 .08784 L
.41754 .09013 L
.41973 .09333 L
.43004 .11359 L
.43286 .11864 L
Mistroke
.43441 .12093 L
.43584 .12269 L
.43707 .12387 L
.43839 .12476 L
.43914 .12508 L
.43985 .12526 L
.44048 .12531 L
.44118 .12524 L
.44243 .12481 L
.4436 .12403 L
.44488 .12274 L
.44626 .12088 L
.44908 .11562 L
.45166 .10929 L
.46136 .07989 L
.4638 .07346 L
.46611 .06874 L
.46738 .06687 L
.4681 .06609 L
.46877 .06555 L
.46994 .06507 L
.47118 .06527 L
.47226 .06607 L
.47343 .06764 L
.47453 .06981 L
.47553 .07241 L
.47798 .08135 L
.48031 .09332 L
.4828 .10997 L
.48546 .13193 L
.49022 .18132 L
.50102 .32314 L
.51037 .44348 L
.51293 .47074 L
.51563 .49561 L
.51796 .5136 L
.52046 .52905 L
.52167 .53514 L
.52282 .54003 L
.52394 .54401 L
.52497 .547 L
.52595 .54926 L
.52699 .55104 L
.52803 .55224 L
.52918 .5529 L
.53042 .55288 L
.53155 .55224 L
.53286 .55084 L
.53411 .54892 L
.53632 .54429 L
Mistroke
.53873 .5379 L
.5436 .52287 L
.54886 .50736 L
.55128 .50164 L
.5526 .49905 L
.55383 .49701 L
.55497 .49546 L
.55601 .49435 L
.55717 .49345 L
.55841 .49289 L
.55909 .49275 L
.55981 .49274 L
.56111 .49305 L
.56183 .4934 L
.56251 .49384 L
.56406 .49523 L
.5654 .49684 L
.56663 .4986 L
.56941 .50338 L
.57423 .51317 L
.57688 .51857 L
.57938 .52322 L
.58185 .52708 L
.58314 .52875 L
.58452 .5302 L
.58568 .53115 L
.58695 .53189 L
.5881 .5323 L
.58919 .53244 L
.59037 .53232 L
.59149 .53196 L
.59249 .53144 L
.59359 .53067 L
.59604 .52821 L
.59831 .52519 L
.60344 .5167 L
.60898 .50733 L
.61152 .50379 L
.61291 .5022 L
.61421 .50097 L
.61531 .50013 L
.6165 .49946 L
.61781 .49901 L
.61901 .49887 L
.62029 .49901 L
.62093 .4992 L
.62165 .49949 L
.6229 .50021 L
.62408 .50113 L
.62673 .50399 L
Mistroke
.62958 .50805 L
.63471 .51679 L
.63958 .52488 L
.64183 .52794 L
.64423 .53043 L
.64494 .53099 L
.64561 .53144 L
.64686 .53206 L
.64803 .53238 L
.6493 .53241 L
.65038 .53219 L
.65155 .53169 L
.65279 .53087 L
.65394 .52985 L
.65599 .52743 L
.6582 .52409 L
.66836 .504 L
.67115 .4991 L
.67267 .49687 L
.67411 .49516 L
.67532 .49404 L
.67663 .4932 L
.67734 .49292 L
.67809 .49276 L
.67872 .49273 L
.67942 .49282 L
.68007 .49302 L
.68078 .49336 L
.68206 .49433 L
.68331 .49569 L
.68446 .4973 L
.68707 .50218 L
.68984 .50896 L
.69491 .52415 L
.69954 .53839 L
.70185 .54446 L
.70307 .54717 L
.70437 .54957 L
.70562 .55133 L
.70675 .55241 L
.70789 .55293 L
.70896 .55289 L
.7102 .55212 L
.7115 .55044 L
.71261 .54825 L
.71383 .54502 L
.71515 .54053 L
.71655 .53452 L
.71909 .52051 L
.72145 .50385 L
Mistroke
.72401 .48186 L
.72867 .43261 L
.7374 .31863 L
.74232 .2512 L
.74761 .18431 L
.75228 .13519 L
.75483 .1135 L
.7572 .0969 L
.75969 .08328 L
.761 .07767 L
.76241 .07287 L
.7637 .06952 L
.76491 .06724 L
.76601 .0659 L
.76719 .06516 L
.76787 .06505 L
.76852 .06516 L
.76922 .06548 L
.76998 .06607 L
.77077 .06694 L
.77152 .06799 L
.77292 .07047 L
.77545 .07636 L
.77821 .08424 L
.7831 .09958 L
.78567 .1072 L
.78838 .11419 L
.79076 .1191 L
.79202 .12116 L
.79337 .12292 L
.79461 .12411 L
.79573 .12484 L
.79687 .12524 L
.79794 .12529 L
.79858 .12519 L
.79928 .12496 L
.80001 .12459 L
.80069 .12413 L
.80191 .12305 L
.80323 .12154 L
.80622 .11698 L
.80896 .11181 L
.81379 .10184 L
.81894 .09242 L
.82021 .09058 L
.82159 .08888 L
.82281 .08766 L
.8241 .08667 L
.82526 .08604 L
.82653 .08567 L
Mistroke
.82769 .08561 L
.82878 .08579 L
.82996 .08625 L
.83108 .08692 L
.83209 .08771 L
.83319 .08877 L
.83792 .09517 L
.84266 .10331 L
.84777 .11174 L
.84919 .1137 L
.85069 .1155 L
.85208 .11687 L
.85337 .11788 L
.85459 .11857 L
.85589 .11902 L
.85663 .11914 L
.85733 .11916 L
.85864 .11896 L
.85978 .11853 L
.86104 .11779 L
.86235 .11675 L
.86357 .11552 L
.86813 .10927 L
.8735 .10002 L
.87841 .09209 L
.8809 .08898 L
.8823 .08762 L
.8836 .08665 L
.88486 .08601 L
.88599 .08568 L
.8873 .08561 L
.88854 .08586 L
.88917 .08611 L
.88986 .08647 L
.89126 .08747 L
.89256 .08873 L
.89377 .09017 L
.89942 .09967 L
.90444 .11001 L
.90708 .11521 L
.90989 .11993 L
.91107 .12156 L
.91234 .12302 L
.91307 .12371 L
.91374 .12424 L
.91504 .12497 L
.91615 .12527 L
.91736 .12524 L
.91863 .1248 L
.91981 .12401 L
Mistroke
.92097 .12286 L
.92223 .12122 L
.92451 .11722 L
.92879 .10671 L
.93374 .09153 L
.93837 .07759 L
.94054 .0722 L
.9426 .06825 L
.94373 .06668 L
.94497 .06555 L
.94609 .06508 L
.94713 .06517 L
.94827 .0659 L
.94935 .0672 L
.95052 .06938 L
.95179 .07262 L
.95305 .0768 L
.95438 .08227 L
.95675 .09483 L
.95908 .11058 L
.96156 .13112 L
.96603 .17693 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo001`0?ooo`800000=`3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo0580oooo00<000000?ooo`3oool0=P3oool00`000000oooo0?ooo`0T0?ooo`00L03oool3
000003H0oooo0`0000070?ooo`030000003oool0oooo0540oooo0`00000f0?ooo`<000009@3oool0
06l0oooo00@000000?ooo`3oool00000=@3oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo0540oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0000000U0?ooo`00K`3o
ool01@000000oooo0?ooo`3oool0000003<0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo0540oooo00@000000?ooo`3oool00000=03oool01@000000oooo0?ooo`3oool0
000002@0oooo001_0?ooo`050000003oool0oooo0?ooo`000000<`3oool01@000000oooo0?ooo`3o
ool0000000L0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo0340oooo00D000000?ooo`3oool0oooo0000000T0?ooo`00KP3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0a0?ooo`050000003oool0oooo0?ooo`000000903oool006h0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103o
ool200000540oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0_0?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool08@3oool006h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0<0?ooo`<000003`3oool4000000h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0;0?ooo`<00000403oool3000000h0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00X0oooo0P0000020?ooo`030000003oool0oooo00`0oooo0P0000020?ooo`800000303oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0D03oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo0P0000020?ooo`030000003oool0oooo
00`0oooo0P0000020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0240
oooo001]0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo00D000001@3oool00`000000oooo0?ooo`1?0?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool08@3oool006d0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo000000050?ooo`030000003oool0oooo04l0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0203o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`0Q0?ooo`00K@3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00`3oool6000000D0oooo00<000000?ooo`0000001@3oool0
0`000000oooo0?ooo`1?0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool08@3oool0
06d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000040?ooo`<00000C`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0200oooo001]0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1>0?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0803oool006d0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo04h0oooo00<000000?ooo`3oool01`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`0P0?ooo`00K@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo0200oooo001]0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`0;0?ooo`80000000<0oooo0000000000003@3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00<0oooo0P1EEED010000000oooo0?ooo`0000040?ooo`030000003oool0
oooo04h0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00`0oooo0P0000000`3oool000000000000=0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`00K@3oool00`000000oooo0?ooo`080?oo
o`050000003oool0oooo0?ooo`0000003`3oool3000000l0oooo00D000000?ooo`3oool0oooo0000
000;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0CP3oool00`000000oooo0?oo
o`090?ooo`050000003oool0oooo0?ooo`0000003`3oool200000100oooo00@000000?ooo`3oool0
00002`3oool00`000000oooo0?ooo`0P0?ooo`00K03oool00`000000oooo0?ooo`0:0?ooo`@00000
8P3oool00`000000oooo0000000<0?ooo`030000003oool0oooo0080oooo0P00001?0?ooo`030000
003oool0oooo00T0oooo0P0000000`3oool000000?ooo`0Q0?ooo`@00000303oool00`000000oooo
0?ooo`0O0?ooo`00K03oool00`000000oooo0?ooo`0;0?ooo`800000903oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0280oooo0P00000=0?ooo`030000003oool0oooo01l0oooo001/
0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool07`3oool006`0oooo00<000000?oo
o`3oool0?`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04d0oooo00<000000?oo
o`3oool0@03oool00`000000oooo0?ooo`0O0?ooo`00K03oool00`000000oooo0?ooo`0o0?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0C@3oool00`000000oooo0?ooo`100?ooo`03
0000003oool0oooo01l0oooo001/0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0
7`3oool006`0oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo04d0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0O0?ooo`00K03oool0
0`000000oooo0?ooo`0o0?ooo`030000003oool0oooo0080oooo0P00001>0?ooo`030000003oool0
oooo0400oooo00<000000?ooo`3oool07`3oool006/0oooo00<000000?ooo`3oool0@@3oool01@00
0000oooo0?ooo`3oool0000004l0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0O
0?ooo`00J`3oool00`000000oooo0?ooo`110?ooo`050000003oool0oooo0?ooo`000000C`3oool0
0`000000oooo0?ooo`100?ooo`030000003oool0oooo01l0oooo001[0?ooo`030000003oool0oooo
0440oooo00D000000?ooo`3oool0oooo0000001?0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool07P3oool006/0oooo00<000000?ooo`3oool0@@3oool01@000000oooo0?ooo`3oool0
000004l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0N0?ooo`00J`3oool00`00
0000oooo0?ooo`110?ooo`050000003oool0oooo0?ooo`000000CP3oool00`000000oooo0?ooo`12
0?ooo`030000003oool0oooo01h0oooo001[0?ooo`030000003oool0oooo0440oooo00@000000?oo
o`3oool0oooo0P00001=0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool07P3oool0
06/0oooo00<000000?ooo`3oool0@@3oool01@000000oooo0?ooo`3oool0000004h0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`000000oooo0?ooo`130?oo
o`040000003oool0oooo000004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0N
0?ooo`00JP3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000004h0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`000000oooo0?ooo`130?oo
o`040000003oool0oooo000004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0N
0?ooo`00JP3oool00`000000oooo0?ooo`130?ooo`040000003oool0oooo000004h0oooo00<00000
0?ooo`3oool0@P3oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`000000oooo0?ooo`130?oo
o`040000003oool0oooo000004h0oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0N
0?ooo`00JP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo00800000C@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo01h0oooo001Z0?ooo`030000003oool0oooo04<0
oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo
01h0oooo001Z0?ooo`030000003oool0oooo04<0oooo00@000000?ooo`3oool00000CP3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo01h0oooo001Z0?ooo`030000003oool0oooo04<0
oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo
01d0oooo001Z0?ooo`030000003oool0oooo02/0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?oo
o`808R8R1@3oool01@14A4@000000000000c<c<0gMgM0080oooo00@000000?ooo`3oool00000CP3o
ool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo001Y0?ooo`030000003oool0
oooo02`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool01@1gMgL0<c<c0?oo
o`3oool000000080oooo00<000000?ooo`3oool0B`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo01d0oooo001Y0?ooo`030000003oool0oooo02@0oooo1P0000020?ooo`05014A4@3o
ool0oooo0?ooo`0A4A40403oool010000000oooo0?ooo`0000020?ooo`<00000B`3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo001Y0?ooo`030000003oool0oooo02`0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo0080oooo00<000000?ooo`00
0000C@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo001Y0?ooo`030000
003oool0oooo02`0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R80000003<c
<`3<c<`00`3oool00`000000oooo0000001=0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`3oool07@3oool006T0oooo00<000000?ooo`3oool0;03oool01@0A4A40oooo0?ooo`3oool04A4A
00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000001=0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`3oool07@3oool006T0oooo00<000000?ooo`3oool0;03oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000001=0?oo
o`030000003oool0oooo04@0oooo00<000000?ooo`3oool07@3oool006T0oooo00<000000?ooo`3o
ool0;03oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo100000040?ooo`030000003oool00000
04d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A03oool00`000000
oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`040000003oool00000000004`0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo
0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0000004`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L
0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004`0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`160?ooo`03
0000003oool0000004`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00
J03oool00`000000oooo0?ooo`160?ooo`040000003oool00000000004/0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`160?ooo`030000
003oool0000004`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03o
ool00`000000oooo0?ooo`160?ooo`030000003oool0000004`0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`800000C03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`030000003oool0oooo
04L0oooo0P00001<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0703oool006P0
oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0K0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`800000C03oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo01/0oooo000M0?ooo`@0000000<04A4A0?ooo`3oool0?03o
ool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo00@000000?ooo`0R8R808R8R1@3oool01@14A4@0
00000000000c<c<0gMgM03`0oooo0`00000o0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2
028R8P030000003oool0oooo0080oooo00D0A4A4000000000000<c<c0=gMg@0o0?ooo`@0000000<0
4A4A0?ooo`3oool0603oool001l0oooo00<000000?ooo`3oool0?P3oool01@1gMgL0VIVI0?ooo`2I
VIT0MgMg00<0oooo00@000000?ooo`0R8R808R8R203oool00`1gMgL0<c<c0?ooo`0k0?ooo`800000
@03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R800`000000oooo0?ooo`050?ooo`03
07MgM`0c<c<0oooo03l0oooo0P00000L0?ooo`00503oool6000000D0oooo00<000000?ooo`3oool0
=P3oool600000080oooo00D04A4A0?ooo`3oool0oooo014A4@030?ooo`030000003oool0oooo00X0
oooo00<000000?ooo`3oool0>P3oool200000400oooo00D04A4A0?ooo`3oool0oooo014A4@070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0?P3oool2000001`0oooo000O0?ooo`03
0000003oool0oooo03h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo
00T0oooo00<0MgMg03<c<`3oool0>`3oool200000400oooo00D000000?ooo`3oool0oooo00000007
0?ooo`030000003oool0oooo00D0oooo00<0MgMg03<c<`3oool0?`3oool2000001`0oooo000O0?oo
o`030000003oool0oooo03h0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0
oooo00H0oooo00D00000028R8P000000<c<c0<c<c00l0?ooo`800000@03oool01@000000oooo0?oo
o`3oool0000000L0oooo00<000000?ooo`3oool00P3oool01@0000008R8R0000000c<c<0c<c<0400
oooo0P00000L0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`05014A4@3oool0oooo0?ooo`0A
4A400P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03h0oooo0P0000100?ooo`05
014A4@3oool0oooo0?ooo`0A4A401`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0480oooo0P00000L0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL00P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo03h0oooo0P0000100?oo
o`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo0480oooo0P00000L0?ooo`007@3oool205EEE@030000003oool0oooo03h0oooo00D0k^k^03<c
<`000000<c<c0>k^kP020?ooo`030000003oool0oooo00L0oooo1000000m0?ooo`<00000?`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00H0oooo00<000000?ooo`3oool00`3oool400000400oooo00<0
EEEE000000000000703oool006L0oooo00<000000?ooo`3oool0B03oool2000004/0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0K0?ooo`00I`3oool00`000000oooo0?ooo`180?oo
o`800000B`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo001W0?ooo`03
0000003oool0oooo04P0oooo0P00001;0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool06P3oool006L0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool06P3oool006L0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool06P3o
ool001@0ooooo`000010000001D0oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo06H0oooo000K0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo06H0oooo000K0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0BP3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo06H0oooo000K0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0BP3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
06H0oooo000L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0BP3oool2000004X0
oooo00<000000?ooo`3oool0IP3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo
0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0IP3oool001`0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool0IP3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?oo
o`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04P0oooo00<000000?oo
o`3oool0I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`80
0000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000
003oool0oooo04X0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0I`3o
ool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3oool0
0`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo
04X0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0
oooo00<000000?ooo`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1;0?ooo`800000B@3oool00`000000oooo
0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04/0oooo0P00
00190?ooo`030000003oool0oooo06L0oooo000M0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0B`3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001d0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`1;0?ooo`800000B@3oool00`000000oooo0?ooo`1W0?oo
o`007@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo0P0000180?ooo`03
0000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
B`3oool2000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`1;0?ooo`800000B03oool00`000000oooo0?ooo`1X0?ooo`007@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000A`3oool0
0`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
04/0oooo0`0000170?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04D0
oooo00<000000?ooo`3oool0B`3oool00`000000oooo000000170?ooo`030000003oool0oooo06P0
oooo000M0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
000000170?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo000000170?ooo`030000003oool0oooo06P0oooo000M
0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0<03oool01@3^k^h0<c<c0000000c
<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo
000000170?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0<@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307Mg
M`0c<c<0oooo00@0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0340oooo00D04A4A0?ooo`3oool0oooo
014A4@0@0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000A`3oool00`000000oooo
0?ooo`1X0?ooo`007P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo0340oooo00D0
00000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00@0oooo0`0000170?ooo`030000
003oool0oooo06P0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0<@3o
ool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0050?ooo`03
0000003oool0000004H0oooo00<000000?ooo`3oool0J@3oool001h0oooo00<000000?ooo`3oool0
@`3oool00`000000oooo0?ooo`0a0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000
oooo0?ooo`070?ooo`030000003oool0000004H0oooo00<000000?ooo`3oool0J@3oool001h0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0a0?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL0303oool00`000000oooo0?ooo`070?ooo`030000003oool0000004H0oooo00<000000?ooo`3o
ool0J@3oool001h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0a0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h0303oool4000000H0oooo00<000000?ooo`000000AP3oool00`000000
oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo04`0oooo
00@000000?ooo`3oool00000A@3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo04`0oooo0P0000000`3oool000000?ooo`140?ooo`030000
003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0C03o
ool010000000oooo0?ooo`0000150?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0C03oool010000000oooo0?ooo`0000150?ooo`030000
003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0C03o
ool010000000oooo0?ooo`0000150?ooo`030000003oool0oooo06T0oooo000O0?ooo`030000003o
ool0oooo0480oooo00<000000?ooo`3oool0C03oool010000000oooo0?ooo`0000150?ooo`030000
003oool0oooo06T0oooo000O0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0C03o
ool010000000oooo0?ooo`0000140?ooo`030000003oool0oooo06X0oooo000O0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0C@3oool010000000oooo0?ooo`0000140?ooo`030000
003oool0oooo06X0oooo000O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0C@3o
ool2000000030?ooo`000000oooo04<0oooo00<000000?ooo`3oool0JP3oool001l0oooo00<00000
0?ooo`3oool0@@3oool00`000000oooo0?ooo`1=0?ooo`040000003oool0oooo000004@0oooo00<0
00000?ooo`3oool0JP3oool001l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1=
0?ooo`050000003oool0oooo0?ooo`000000@`3oool00`000000oooo0?ooo`1Z0?ooo`007`3oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo04d0oooo00D000000?ooo`3oool0oooo0000
00130?ooo`030000003oool0oooo06X0oooo000O0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool0C@3oool01@000000oooo0?ooo`3oool0000004<0oooo00<000000?ooo`3oool0JP3o
ool001l0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`1=0?ooo`050000003oool0
oooo0?ooo`000000@`3oool00`000000oooo0?ooo`1Z0?ooo`00803oool00`000000oooo0?ooo`10
0?ooo`030000003oool0oooo04d0oooo00D000000?ooo`3oool0oooo000000120?ooo`030000003o
ool0oooo06/0oooo000P0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0C@3oool2
00000080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1[0?ooo`00803oool00`00
0000oooo0?ooo`100?ooo`030000003oool0oooo04d0oooo00D000000?ooo`3oool0oooo00000012
0?ooo`030000003oool0oooo06/0oooo000P0?ooo`030000003oool0oooo0400oooo00<000000?oo
o`3oool0C@3oool01@000000oooo0?ooo`3oool000000480oooo00<000000?ooo`3oool0J`3oool0
0200oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`1=0?ooo`050000003oool0oooo
0?ooo`000000@P3oool00`000000oooo0?ooo`1[0?ooo`00803oool00`000000oooo0?ooo`100?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0o0?oo
o`030000003oool0oooo06/0oooo000P0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3o
ool0C@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0J`3oool00200oooo00<000000?ooo`3oool02P3oool3000002<0oooo1000000;0?ooo`030000
003oool0oooo04h0oooo0P0000030?ooo`030000003oool0oooo00X0oooo0`00000R0?ooo`@00000
303oool00`000000oooo0?ooo`1[0?ooo`00803oool00`000000oooo0?ooo`0:0?ooo`040000003o
ool0oooo00000240oooo0P0000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
CP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00D000000?ooo`3oool0
oooo0000000Q0?ooo`030000003oool0oooo008000002`3oool00`000000oooo0?ooo`1[0?ooo`00
803oool00`000000oooo0?ooo`090?ooo`050000003oool0oooo0?ooo`0000003`3oool4000000h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04h0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`8000000`3oool00`000000
oooo0?ooo`0<0?ooo`D000003@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0J`3oool00240oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00/0oooo00D000000?ooo`3oool0oooo0000000=0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1[0?ooo`00
8@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
2@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo04@0oooo100000000`0A4A40oooo
0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`0;0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`1[0?ooo`008@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo04H0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0J`3oool00240oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo06`0oooo000Q0?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`050?ooo`<000000`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo06`0oooo000Q0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`1/0?ooo`008@3oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo00P0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`050?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool0K03oool00240oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`170?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo06`0oooo000R0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool02P3oool01@000000oooo0?ooo`3oool0000000h0oooo00@0
00000?ooo`3oool000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04D0oooo
0P1EEED00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2`3oool010000000oooo0?ooo`3oool2000000/0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1]0?ooo`008P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00`0oooo
0`00000@0?ooo`<000003@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo04l0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo
1000000?0?ooo`@000003@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06d0oooo
000R0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo04l0oooo0P0000050?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0;`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo06d0oooo000R
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0340oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1]
0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`1@0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0K@3oool002<0oooo00D000000?ooo`3oool0oooo0000000c0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`050?ooo`050000003oool0oooo
0?ooo`000000<`3oool01@000000oooo0?ooo`3oool000000700oooo000S0?ooo`050000003oool0
oooo0?ooo`000000=03oool010000000oooo0?ooo`00001C0?ooo`030000003oool0oooo00D0oooo
00D000000?ooo`3oool0oooo0000000d0?ooo`040000003oool0oooo00000700oooo000T0?ooo`03
0000003oool0000003H0oooo0`00001C0?ooo`030000003oool0oooo00D0oooo1000000e0?ooo`03
0000003oool000000740oooo000T0?ooo`800000=`3oool2000005@0oooo00<000000?ooo`3oool0
1P3oool2000003L0oooo0P00001a0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?oo
o`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool400000003014A4@3oool0oooo
0080oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`2b
0?ooo`00V`3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?oo
o`030000003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`0>0?ooo`0307Mg
M`0c<c<0oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`050000000R
8R80000003<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?oo
o`2l0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo002I0?oo
o`80EEEE00<000000?ooo`3oool02`3oool400000;/0oooo003o0?ooofT0oooo003o0?ooofT0oooo
003o0?ooofT0oooo002P0?ooo`80000000H04A4A0?ooo`3oool04A4A0000000A4A4G0?ooo`050<c<
c00R8R800000028R8P3<c<`0Y03oool00:40oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`070?ooo`H000002@3oool01@0R8R80VIVI0?ooo`2IVIT08R8R0:@0oooo002Q0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool05P3oool01@000000oooo0?ooo`3oool000000:@0
oooo002Q0?ooo`060000003oool0A4A403<c<`3oool000002@3oool6000000T0oooo00D0<c<c09VI
V@3oool0VIVI03<c<`2T0?ooo`00X@3oool01P000000gMgM03<c<`1EEED0gMgM000001P0oooo00D0
c<c<00000000000000000<c<c02T0?ooo`00X@3oool01P000000R8R80:ZZZP2k^k/0EEEE000001P0
oooo00D04A4A0;^k^`3oool0^k^k014A4@2T0?ooo`00X@3oool01P000000<c<c0?ooo`3oool0<c<c
000001P0oooo00D000000;^k^`3oool0^k^k0000002T0?ooo`00X03oool00`0A4A40000008R8R002
0?ooo`0308R8R00000004A4A01L0oooo00D0ZZZZ014A4@0000004A4A0:ZZZP2T0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .40268 L
.03279 .47584 L
.03527 .50778 L
.03754 .52936 L
.03879 .53816 L
.03945 .5419 L
.04015 .54521 L
.04143 .54959 L
.04262 .55179 L
.04384 .55236 L
.04496 .55151 L
.04626 .54911 L
.04749 .54565 L
.04967 .53743 L
.05205 .52677 L
.05466 .51498 L
.05609 .50911 L
.05744 .50427 L
.0587 .5005 L
.05937 .49884 L
.06007 .49734 L
.0613 .49537 L
.06244 .49433 L
.06309 .49407 L
.06379 .49405 L
.06507 .49469 L
.06631 .49608 L
.06746 .49797 L
.07006 .50389 L
.07283 .51159 L
.07505 .51778 L
.07744 .5236 L
.07881 .52624 L
.08007 .52811 L
.08127 .52936 L
.08253 .53007 L
.08324 .53019 L
.08391 .53013 L
.08517 .52956 L
.08587 .52899 L
.08652 .52832 L
.08799 .52634 L
.09045 .52186 L
.09306 .51628 L
.09571 .51071 L
.09716 .50802 L
.09855 .50587 L
.09933 .50486 L
.10018 .50396 L
Mistroke
.10095 .50333 L
.10166 .50291 L
.1024 .50264 L
.10308 .50255 L
.10385 .50262 L
.10458 .50285 L
.10575 .50356 L
.107 .50475 L
.10818 .50621 L
.10925 .5078 L
.11437 .517 L
.11691 .52129 L
.11825 .52315 L
.11899 .52401 L
.11968 .5247 L
.12092 .52564 L
.12158 .52596 L
.12229 .52618 L
.12355 .52622 L
.1247 .52586 L
.12578 .5252 L
.12693 .52417 L
.129 .5216 L
.13371 .5138 L
.13627 .50961 L
.13752 .50785 L
.13868 .50648 L
.13973 .50549 L
.14084 .50473 L
.14196 .50428 L
.14318 .50419 L
.14448 .50453 L
.14569 .50525 L
.14701 .50645 L
.14841 .50814 L
.15337 .51618 L
.1555 .51976 L
.15779 .52304 L
.1591 .52448 L
.1603 .52546 L
.16146 .52604 L
.16267 .52626 L
.16398 .52603 L
.16517 .5254 L
.16582 .52489 L
.16654 .52421 L
.16784 .52267 L
.17265 .51458 L
.17541 .50954 L
.17692 .5071 L
Mistroke
.17833 .50519 L
.17953 .50393 L
.18083 .503 L
.18156 .5027 L
.18226 .50256 L
.18357 .50272 L
.18482 .50337 L
.18552 .50395 L
.18617 .50461 L
.18861 .50812 L
.19317 .51742 L
.19574 .52282 L
.19814 .52696 L
.19935 .5285 L
.20065 .52963 L
.20139 .53001 L
.20209 .53018 L
.2034 .52999 L
.20445 .52936 L
.20562 .52815 L
.20683 .52636 L
.20797 .52422 L
.21221 .51351 L
.21461 .5067 L
.21717 .5002 L
.21842 .49767 L
.21959 .49583 L
.22065 .49469 L
.22179 .49408 L
.22298 .49419 L
.22423 .49516 L
.22531 .49671 L
.22649 .49917 L
.22777 .50267 L
.22915 .50732 L
.23163 .5175 L
.23417 .52912 L
.23694 .54107 L
.23821 .5456 L
.23891 .54769 L
.23956 .54935 L
.24083 .55161 L
.24199 .55238 L
.24317 .55171 L
.24441 .54925 L
.24547 .5456 L
.24664 .53987 L
.24789 .53156 L
.24924 .52018 L
.25166 .49318 L
Mistroke
.25629 .42073 L
.26049 .33821 L
.26529 .23983 L
.26978 .15883 L
.27223 .12383 L
.27447 .09884 L
.27574 .08779 L
.27696 .07944 L
.27824 .07285 L
.27896 .07011 L
.27963 .06817 L
.28031 .0668 L
.28104 .06592 L
.28174 .06566 L
.28237 .06586 L
.28358 .06733 L
.28486 .07023 L
.28623 .0746 L
.28752 .07957 L
.29044 .09259 L
.29291 .10371 L
.29525 .1128 L
.29654 .11684 L
.29722 .11863 L
.29795 .12027 L
.29923 .12244 L
.30041 .12362 L
.30155 .124 L
.30279 .12362 L
.30409 .12237 L
.3053 .12053 L
.30746 .11591 L
.30978 .10973 L
.31227 .10265 L
.31497 .0957 L
.31621 .09307 L
.31752 .09081 L
.31864 .08936 L
.31987 .08831 L
.32112 .08786 L
.32226 .08797 L
.32357 .0887 L
.32482 .08995 L
.32597 .09152 L
.32703 .09328 L
.32945 .09805 L
.33398 .10768 L
.33597 .11118 L
.33702 .11268 L
.33815 .11396 L
Mistroke
.33943 .11495 L
.34063 .11542 L
.34133 .11549 L
.34199 .11541 L
.34324 .11489 L
.3439 .11442 L
.34461 .11379 L
.34588 .11235 L
.34874 .10791 L
.35121 .10335 L
.35388 .09854 L
.35511 .09659 L
.3564 .09482 L
.35751 .09358 L
.3587 .09259 L
.35985 .092 L
.3609 .09178 L
.36195 .09188 L
.36293 .09224 L
.36409 .093 L
.36515 .094 L
.36756 .09711 L
.37227 .10503 L
.37469 .1089 L
.37605 .11073 L
.37732 .1121 L
.37858 .1131 L
.37922 .11345 L
.37993 .11372 L
.3812 .11385 L
.3824 .11358 L
.38356 .11294 L
.38463 .11206 L
.3858 .11079 L
.38703 .10917 L
.39142 .10193 L
.39383 .0979 L
.39611 .09472 L
.39739 .09337 L
.39812 .09277 L
.39878 .09234 L
.39996 .09187 L
.40122 .0918 L
.40238 .09214 L
.40348 .09279 L
.40468 .09387 L
.40597 .09542 L
.41157 .10499 L
.41429 .10981 L
.41558 .11175 L
Mistroke
.41676 .11323 L
.41797 .1144 L
.41928 .1152 L
.42044 .11548 L
.42166 .11532 L
.42294 .11465 L
.42414 .11356 L
.42546 .11189 L
.42687 .10963 L
.43254 .09787 L
.43389 .09511 L
.43532 .0925 L
.43665 .0905 L
.4379 .08908 L
.43906 .08822 L
.4403 .08784 L
.44097 .08789 L
.44167 .08812 L
.44294 .08902 L
.44359 .08974 L
.44429 .09067 L
.44555 .0928 L
.44841 .09934 L
.45307 .11234 L
.4543 .11554 L
.45561 .11859 L
.45684 .12093 L
.458 .12259 L
.45863 .12325 L
.45932 .12374 L
.46053 .12399 L
.46124 .12377 L
.46198 .12323 L
.46269 .12243 L
.46333 .12145 L
.46454 .11896 L
.46586 .11538 L
.46824 .10685 L
.47365 .08272 L
.47496 .07727 L
.47637 .07224 L
.47717 .06988 L
.47791 .06813 L
.47865 .0668 L
.47935 .06599 L
.48062 .06577 L
.48126 .06632 L
.48196 .06748 L
.48321 .07104 L
.48438 .07624 L
Mistroke
.48576 .08478 L
.48702 .09494 L
.48985 .12609 L
.49221 .16031 L
.4948 .20493 L
.4995 .29865 L
.50481 .40567 L
.50741 .45165 L
.50981 .48741 L
.51199 .51344 L
.5143 .53363 L
.51549 .54112 L
.51661 .54633 L
.51784 .55012 L
.51916 .55212 L
.51983 .55238 L
.52055 .55212 L
.52185 .55039 L
.52257 .54881 L
.52324 .54699 L
.52478 .54176 L
.53012 .51819 L
.53246 .50843 L
.53493 .5004 L
.53622 .49741 L
.53696 .49612 L
.53764 .4952 L
.53884 .49423 L
.54012 .49408 L
.54135 .49477 L
.54205 .49549 L
.54271 .49638 L
.54402 .49869 L
.54544 .50185 L
.55035 .51535 L
.55177 .51918 L
.55332 .52292 L
.55469 .52569 L
.55544 .52696 L
.55615 .52797 L
.55684 .52879 L
.55759 .52946 L
.5589 .53012 L
.55954 .5302 L
.56023 .5301 L
.56145 .5295 L
.5627 .52833 L
.56385 .52684 L
.56642 .52231 L
.57106 .51241 L
Mistroke
.57365 .50752 L
.57511 .50536 L
.57581 .50453 L
.57647 .50387 L
.57765 .50301 L
.57896 .50257 L
.58023 .50266 L
.58094 .50293 L
.58159 .50332 L
.58287 .50441 L
.58408 .50583 L
.58634 .50928 L
.59141 .51852 L
.59354 .52194 L
.5947 .52347 L
.59579 .52463 L
.59697 .52555 L
.59826 .52613 L
.59936 .52625 L
.60054 .52601 L
.60121 .5257 L
.60192 .52524 L
.6032 .52409 L
.60472 .52226 L
.60609 .52025 L
.61136 .51133 L
.61381 .50772 L
.61519 .50615 L
.61646 .50508 L
.61757 .50447 L
.61879 .50418 L
.62006 .50431 L
.62125 .50483 L
.62252 .50578 L
.62386 .5072 L
.62628 .5106 L
.6291 .51537 L
.63174 .51984 L
.63401 .52308 L
.63529 .52448 L
.63646 .52543 L
.63773 .52607 L
.63846 .52623 L
.63913 .52625 L
.64035 .52595 L
.64166 .52518 L
.64291 .52401 L
.64407 .52261 L
.64668 .51854 L
.6514 .50988 L
Mistroke
.65362 .50636 L
.65471 .50497 L
.6557 .50395 L
.65674 .50316 L
.65786 .50266 L
.65908 .50256 L
.66023 .5029 L
.66137 .50365 L
.6626 .50489 L
.66376 .50644 L
.66482 .50815 L
.66989 .51856 L
.67247 .52386 L
.67373 .52605 L
.67488 .52771 L
.6761 .52905 L
.67739 .52993 L
.67807 .53015 L
.67881 .53019 L
.6795 .53003 L
.68014 .52971 L
.6812 .52884 L
.68234 .52743 L
.68342 .52567 L
.6844 .52373 L
.68909 .51154 L
.69165 .5044 L
.6929 .50125 L
.69406 .49872 L
.69509 .49685 L
.69622 .49529 L
.69736 .49433 L
.69856 .49403 L
.69975 .49453 L
.70103 .49596 L
.70224 .49816 L
.70334 .50087 L
.70595 .50966 L
.70843 .52023 L
.71287 .54003 L
.71395 .54407 L
.71511 .54772 L
.71638 .55065 L
.71758 .55214 L
.71889 .55216 L
.71955 .55145 L
.72028 .55008 L
.72156 .54604 L
.72274 .54034 L
.72395 .53251 L
Mistroke
.72505 .5236 L
.72752 .49737 L
.73019 .45969 L
.73308 .4097 L
.73832 .30445 L
.74289 .21252 L
.7478 .13194 L
.74925 .11377 L
.75062 .09922 L
.75196 .08763 L
.75319 .07917 L
.75436 .07314 L
.7556 .06875 L
.75685 .0663 L
.75756 .06573 L
.75823 .0657 L
.75945 .06681 L
.76015 .06805 L
.7608 .06956 L
.76211 .07349 L
.76351 .07875 L
.76835 .10046 L
.76977 .10649 L
.7713 .1123 L
.77265 .11659 L
.77339 .11856 L
.77408 .12014 L
.77537 .12237 L
.77605 .12317 L
.77678 .12373 L
.77809 .12398 L
.77928 .1234 L
.78057 .12199 L
.78178 .11999 L
.78405 .11491 L
.78913 .10079 L
.79127 .09544 L
.79244 .09299 L
.79353 .09109 L
.79471 .08949 L
.796 .08835 L
.7971 .08789 L
.79828 .08792 L
.79895 .08818 L
.79966 .08863 L
.80095 .08988 L
.80233 .09178 L
.80385 .09442 L
.80912 .10556 L
.81158 .11023 L
Mistroke
.81286 .11221 L
.81357 .11312 L
.81422 .11384 L
.81541 .11482 L
.81672 .1154 L
.81782 .11547 L
.81901 .11512 L
.82024 .1143 L
.82094 .11365 L
.8216 .11293 L
.82434 .10892 L
.82926 .09996 L
.83057 .09772 L
.832 .09558 L
.83327 .09403 L
.83396 .09334 L
.83461 .09279 L
.83543 .09227 L
.83617 .09196 L
.83687 .0918 L
.83762 .09179 L
.83831 .09192 L
.83905 .09221 L
.84036 .09307 L
.84162 .0943 L
.84277 .09571 L
.84534 .09965 L
.84998 .10754 L
.85258 .11112 L
.85329 .11189 L
.85404 .11257 L
.85469 .11305 L
.8554 .11345 L
.85665 .11383 L
.85783 .1138 L
.85855 .11359 L
.85924 .11327 L
.86052 .11234 L
.86545 .10567 L
.8701 .09778 L
.87135 .09594 L
.87267 .09429 L
.87336 .09358 L
.87412 .09291 L
.87481 .09244 L
.87545 .09211 L
.87668 .09179 L
.8778 .09187 L
.87909 .0924 L
.88031 .09332 L
Mistroke
.88136 .09442 L
.88253 .09592 L
.88488 .0997 L
.88911 .10748 L
.89149 .11135 L
.89274 .11299 L
.89405 .11431 L
.89521 .11508 L
.89647 .11547 L
.89762 .11539 L
.89869 .11493 L
.89997 .11393 L
.90061 .11324 L
.90132 .11235 L
.90374 .10839 L
.90921 .09687 L
.91168 .09223 L
.91307 .09021 L
.91434 .08886 L
.91552 .08809 L
.9168 .08784 L
.91801 .08819 L
.91914 .08903 L
.92031 .09042 L
.92157 .09247 L
.92386 .09745 L
.92814 .10922 L
.93057 .11574 L
.93189 .11878 L
.93313 .1211 L
.93419 .1226 L
.93532 .12363 L
.93658 .124 L
.93772 .12359 L
.93886 .12245 L
.93993 .1207 L
.94111 .11804 L
.94237 .11438 L
.9473 .09425 L
.94935 .08488 L
.95153 .0758 L
.95279 .07152 L
.95393 .0685 L
.95508 .06648 L
.95616 .06568 L
.95743 .06629 L
.9586 .06853 L
.95989 .07299 L
.96054 .07607 L
.96125 .08013 L
Mistroke
.96259 .08967 L
.96402 .10275 L
.96661 .1337 L
.97162 .21679 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo001]0?ooo`800000?@3oool2
000000D0oooo00<000000?ooo`3oool0C`3oool2000003d0oooo0P00000R0?ooo`00K@3oool00`00
0000oooo0000000l0?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0CP3oool00`00
0000oooo0000000m0?ooo`8000008P3oool006`0oooo00@000000?ooo`3oool00000>`3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0oooo04h0oooo00<000000?ooo`000000?03oool0
0`000000oooo0000000R0?ooo`00K03oool010000000oooo0?ooo`00000k0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0CP3oool00`000000oooo0000000l0?ooo`040000003o
ool0oooo00000240oooo001/0?ooo`040000003oool0oooo000003/0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`1>0?ooo`040000003oool0oooo000003/0oooo00@000000?oo
o`3oool000008@3oool006`0oooo00@000000?ooo`3oool00000>`3oool010000000oooo0?ooo`00
00040?ooo`800000C`3oool010000000oooo0?ooo`00000j0?ooo`050000003oool0oooo0?ooo`00
00008@3oool006`0oooo00@000000?ooo`3oool00000>`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo04d0oooo00D000000?ooo`3oool0oooo0000000j0?ooo`050000003oool0
oooo0?ooo`0000008@3oool006`0oooo00D000000?ooo`3oool0oooo000000080?ooo`<000008`3o
ool3000000T0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`1=0?ooo`050000
003oool0oooo0?ooo`0000002@3oool3000002<0oooo0P0000090?ooo`050000003oool0oooo0?oo
o`0000008@3oool006`0oooo00D000000?ooo`3oool0oooo000000070?ooo`8000000P3oool00`00
0000oooo0?ooo`070?ooo`<000002@3oool3000000T0oooo0P0000000`3oool00000000000070?oo
o`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000001?0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000090?ooo`<000002P3o
ool3000000T0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01l0oooo001[0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3o
ool01@000000oooo0?ooo`3oool0000000P0oooo0P0000000`3oool000000?ooo`080?ooo`040000
003oool0oooo000000P0oooo00D000000?ooo`3oool0oooo000000060?ooo`@0000000<04A4A0?oo
o`0000000`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool00000203o
ool2000000030?ooo`000000000000P0oooo00@000000?ooo`3oool000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01l0oooo001[0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo0P00
00030?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0103oool2000000<0oooo00D000000?ooo`3oool0
oooo0000001?0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0N0?oo
o`00J`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
00001@0000040?ooo`8000000`3oool01@000000oooo0?ooo`3oool0000004l0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo01h0oooo001[0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`3oool30000
04d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
01h0oooo001[0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000
oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0080oooo00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0
000004h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo01h0oooo001[0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo00000008
0?ooo`050000003oool0oooo0?ooo`000000203oool010000000oooo0000000000080?ooo`030000
003oool0oooo008000001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000<0oooo
00D000000?ooo`3oool0oooo0000001>0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`050?ooo`8000000P3oool00`000000oooo0?ooo`060?ooo`04
0000003oool0oooo000000T0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`00
0000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`000000203oool4000000T0oooo0`00000:
0?ooo`<00000203oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00001>0?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0
oooo000000090?ooo`<000002P3oool3000000T0oooo100000070?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0N0?ooo`00JP3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000002@3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00L0oooo00D000000?ooo`3oool0oooo0000000205EEE@030000003oool0oooo
0080oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`050?ooo`040000003oool0
oooo000000X0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`080?ooo`040000003o
ool0oooo000000L0oooo00<000000?ooo`3oool07P3oool006X0oooo00<000000?ooo`3oool01@3o
ool2000000030?ooo`000000oooo02h0oooo00@000000?ooo`00000000001`3oool010000000oooo
0?ooo`00001>0?ooo`030000003oool0oooo00D0oooo00@000000?ooo`3oool00000;`3oool00`00
0000oooo000000080?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo00H0
oooo0`00000`0?ooo`800000203oool00`000000oooo0?ooo`02000004d0oooo00<000000?ooo`3o
ool01P3oool200000300oooo0`0000080?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000
003oool0oooo04<0oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04<0oooo00@000000?ooo`3oool0
0000CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000
003oool0oooo04<0oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04<0oooo00@000000?ooo`3oool0
0000CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000
003oool0oooo04<0oooo00@000000?ooo`3oool00000CP3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04<0oooo00@000000?ooo`3oool0
0000CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000
003oool0oooo04@0oooo00@000000?ooo`0000000000C@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000
CP3oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003o
ool0oooo04@0oooo00<000000?ooo`000000CP3oool00`000000oooo0?ooo`130?ooo`030000003o
ool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000C@3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo
04@0oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
01d0oooo001Z0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000C@3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04@0oooo
00@000000?ooo`0000000000C03oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0
oooo001Z0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000C@3oool00`000000oooo
0?ooo`140?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`000000C@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo01d0oooo001Z
0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003oool0oooo04@0oooo00<000000?oo
o`000000C@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01`0oooo001Y0?ooo`03
0000003oool0oooo04D0oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`000000
C@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003o
ool0oooo04D0oooo00@000000?ooo`0000000000C03oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`000000C@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`000000C@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo01`0oooo001Y0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`000000C03oool00`00
0000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo02`0
oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0
gMgM00<0oooo00<000000?ooo`000000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0
oooo01`0oooo001Y0?ooo`030000003oool0oooo02`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`05
0?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`020?ooo`030000003oool0000004`0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`0T0?oo
o`H000000P3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00H000000?ooo`3oool0oooo0000
003oool3000004X0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J@3o
ool00`000000oooo0?ooo`0/0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c
0?ooo`020?ooo`030000003oool0000004`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo
0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`0/0?ooo`050000003oool0oooo0?ooo`000000
303oool01@0000008R8R0000000c<c<0c<c<00<0oooo00<000000?ooo`000000C03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo02`0oooo
00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`00
0000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000
003oool0oooo02`0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`000000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0
oooo001X0?ooo`030000003oool0oooo02d0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@0
0000103oool00`000000oooo0000001<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0703oool006P0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0000001<0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool0703oool006P0oooo00<000000?ooo`3oool0AP3o
ool010000000oooo00000000001;0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
703oool006P0oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`800000C03oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`030000003oool0oooo
04L0oooo0P00001<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0703oool006P0
oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`800000C03oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo01/0oooo001X0?ooo`030000003oool0oooo04L0oooo0`00
001;0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<00000
0?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K
0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`800000C03oool00`000000oooo0?ooo`170?oo
o`030000003oool0oooo01/0oooo001X0?ooo`030000003oool0oooo04L0oooo0P00001<0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0
A`3oool2000004`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00J03o
ool00`000000oooo0?ooo`170?ooo`800000B`3oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo01/0oooo001X0?ooo`030000003oool0oooo04L0oooo0P00001;0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool06`3oool001d0oooo100000000`0A4A40oooo0?ooo`0l0?oo
o`050>k^kP0c<c<0000003<c<`3^k^h00`3oool010000000oooo028R8P0R8R850?ooo`0504A4A000
0000000003<c<`3MgMd0?03oool3000003l0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`03
028R8P000000oooo00@0oooo00D0A4A4000000000000<c<c0=gMg@0o0?ooo`@0000000<04A4A0?oo
o`3oool0603oool001l0oooo00<000000?ooo`3oool0?P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00<0oooo00@000000?ooo`0R8R808R8R203oool00`1gMgL0<c<c0?ooo`0k0?ooo`800000@03oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo00<08R8R0000003oool01`3oool00`1gMgL0<c<c0?oo
o`0o0?ooo`800000703oool001@0oooo1P0000050?ooo`030000003oool0oooo03H0oooo1P000002
0?ooo`05014A4@3oool0oooo0?ooo`0A4A400`3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo03X0oooo0P0000100?ooo`05014A4@3oool0oooo0?ooo`0A4A401P3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo03h0oooo0P00000L0?ooo`007`3oool00`000000oooo0?oo
o`0n0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`0307Mg
M`0c<c<0oooo03`0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000H0
oooo00<000000?ooo`3oool01P3oool00`1gMgL0<c<c0?ooo`0o0?ooo`800000703oool001l0oooo
00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3o
ool01P3oool01@0000008R8R0000000c<c<0c<c<03d0oooo00<000000?ooo`3oool0?P3oool01@00
0000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool01@0000008R8R0000000c
<c<0c<c<0400oooo0P00000L0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`05014A4@3oool0
oooo0?ooo`0A4A400`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo03l0oooo00<0
00000?ooo`3oool0?P3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`120?ooo`800000703oool001l0oooo00<000000?ooo`3oool0?P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0o0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`060?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0@P3oool2000001`0oooo000M0?ooo`80EEEE
00<000000?ooo`3oool0?P3oool01@3^k^h0<c<c0000000c<c<0k^k^0080oooo00<000000?ooo`3o
ool01`3oool4000003h0oooo0P00000o0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01P3oool00`00
0000oooo0?ooo`030?ooo`@00000@03oool205EEE@030000003oool0oooo01X0oooo001W0?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo01X0oooo001W0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo001W0?ooo`030000003o
ool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo01X0oooo001W0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo001W0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
01X0oooo000D0?ooool00000@000000E0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1V0?ooo`006`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`1V0?ooo`006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1V0?ooo`006`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo04T0oooo0P00001:0?ooo`030000003oool0oooo06H0oooo
000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool2000004X0oooo00<0
00000?ooo`3oool0IP3oool001`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`19
0?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0oooo00<000000?ooo`3o
ool0I`3oool001`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`190?ooo`800000
B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0oooo00<000000?ooo`3oool0I`3oool0
01`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`190?ooo`800000B@3oool00`00
0000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0
oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04P0oooo
00<000000?ooo`3oool0B@3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3oool00`000000oooo0?oo
o`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04X0oooo0P000019
0?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00
703oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04X0oooo0P0000190?ooo`030000
003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0BP3o
ool2000004T0oooo00<000000?ooo`3oool0I`3oool001d0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`1:0?ooo`030000003oool0000004P0oooo00<000000?ooo`3oool0I`3oool0
01d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool00000
04P0oooo00<000000?ooo`3oool0I`3oool001d0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`<00000A`3oool00`000000oooo
0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo00<0
00000?ooo`000000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`16
0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1X
0?ooo`007@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo00<000000?oo
o`000000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo0300oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14
A4@000000000000c<c<0gMgM00D0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1X
0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo0300oooo00D0MgMg09VI
V@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0
000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0`0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`03
0?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0`0?ooo`050000003oool0oooo0?ooo`0000003`3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0oooo0300oooo00D000000?ooo`3oool0oooo0000000<
0?ooo`050000000R8R80000003<c<`3<c<`01@3oool00`000000oooo000000170?ooo`030000003o
ool0oooo06P0oooo000M0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0<03oool0
1@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000
00170?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool0<03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01`3o
ool00`000000oooo000000170?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0
oooo04D0oooo00<000000?ooo`3oool0<03oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo1000
00060?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<00000
0?ooo`3oool0A@3oool00`000000oooo0?ooo`1;0?ooo`030000003oool0000004L0oooo00<00000
0?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`1;0?oo
o`<00000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo04/0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1X0?ooo`00
7@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000
AP3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`140?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`000000AP3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool0
0`000000oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000AP3oool0
0`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`000000AP3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000AP3oool00`000000
oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo
0`0000160?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04@0oooo00<0
00000?ooo`3oool0B`3oool00`000000oooo000000160?ooo`030000003oool0oooo06T0oooo000N
0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0C03oool00`000000oooo00000016
0?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?oo
o`3oool0C03oool00`000000oooo000000160?ooo`030000003oool0oooo06T0oooo000N0?ooo`03
0000003oool0oooo04<0oooo00<000000?ooo`3oool0C03oool00`000000oooo000000160?ooo`03
0000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0
C03oool00`000000oooo000000160?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool0C03oool010000000oooo0?ooo`0000150?ooo`030000
003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0C03o
ool2000000030?ooo`000000oooo04@0oooo00<000000?ooo`3oool0J@3oool001h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`1<0?ooo`040000003oool0oooo000004D0oooo00<0
00000?ooo`3oool0J@3oool001h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1<
0?ooo`040000003oool0oooo000004@0oooo00<000000?ooo`3oool0JP3oool001h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`1<0?ooo`040000003oool0oooo000004@0oooo00<0
00000?ooo`3oool0JP3oool001h0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`1<
0?ooo`040000003oool0oooo000004@0oooo00<000000?ooo`3oool0JP3oool001h0oooo00<00000
0?ooo`3oool0@`3oool00`000000oooo0?ooo`1<0?ooo`040000003oool0oooo000004@0oooo00<0
00000?ooo`3oool0JP3oool001l0oooo00<000000?ooo`3oool01@3oool300000300oooo0P000008
0?ooo`030000003oool0oooo04`0oooo0P0000000`3oool000000?ooo`070?ooo`800000<03oool3
000000L0oooo00<000000?ooo`3oool0JP3oool001l0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0000000_0?ooo`80000000<0oooo0000003oool01P3oool00`000000oooo0?ooo`1<0?oo
o`040000003oool0oooo000000P0oooo0`00000_0?ooo`030000003oool0000000L0oooo00<00000
0?ooo`3oool0JP3oool001l0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000000_0?oo
o`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0C03oool010000000oooo0?ooo`00
00070?ooo`040000003oool0oooo000002h0oooo0P0000020?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool0JP3oool001l0oooo00<000000?ooo`3oool0103oool01@000000oooo0?oo
o`3oool0000000P0oooo1000000:0?ooo`8000002P3oool3000000T0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`1<0?ooo`050000003oool0oooo0?ooo`0000001P3oool01000
0000oooo0?ooo`0000090?ooo`<000002P3oool3000000X0oooo0`0000080?ooo`050000003oool0
oooo0?ooo`0000001P3oool00`000000oooo0?ooo`1Z0?ooo`007`3oool00`000000oooo0?ooo`04
0?ooo`050000003oool0oooo0?ooo`000000203oool00`000000oooo0?ooo`02000000P0oooo00@0
00000?ooo`0000000000203oool2000000030?ooo`000000oooo00L0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0480oooo100000000`0A4A40oooo
0?ooo`030?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool00000
00P0oooo0P0000020?ooo`030000003oool0oooo00H0oooo0P0000000`3oool000000?ooo`080?oo
o`040000003oool0oooo000000P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo06X0oooo000O0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0oooo00D000000?ooo`3oool0oooo0000
00070?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`150?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0
oooo00D000000?ooo`3oool0oooo000000070?ooo`050000003oool0oooo0?ooo`0000001`3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0JP3oool0
01l0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000H0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04D0oooo00<00000
0?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000070?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?ooo`00
7`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`050?ooo`<0000000<0oooo0000003oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo06X0oooo000P0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000050?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
JP3oool00200oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3o
ool00000203oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo0000
00050?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3oool0oooo000000080?ooo`040000
003oool0oooo000000T0oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1Z0?oo
o`00803oool01@000000oooo0?ooo`3oool0000000P0oooo00@000000?ooo`3oool000002@3oool3
000000T0oooo100000080?ooo`050000003oool0oooo0?ooo`0000001`3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool010000000oooo0?oo
o`0000090?ooo`@000002@3oool4000000P0oooo00@000000?ooo`3oool000001`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo06X0oooo000P0?ooo`050000003oool0oooo0?ooo`00
0000203oool3000002<0oooo0`0000080?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0@`3oool205EEE@030000003oool0oooo00D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000P0oooo00<000000?ooo`0000008`3oool3000000P0oooo00D000000?oo
o`3oool0oooo0000001]0?ooo`00803oool01@000000oooo0?ooo`3oool0000000T0oooo0P00000T
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000090?ooo`030000003o
ool0oooo02<0oooo00<000000?ooo`3oool01`3oool01@000000oooo0?ooo`3oool0000006d0oooo
000P0?ooo`050000003oool0oooo0?ooo`000000>@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo04d0oooo0P0000030?ooo`050000003oool0oooo0?ooo`000000>@3oool01@000000
oooo0?ooo`3oool0000006d0oooo000P0?ooo`050000003oool0oooo0?ooo`000000>P3oool01000
0000oooo0?ooo`00001@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000>`3o
ool010000000oooo0?ooo`00001]0?ooo`00803oool01@000000oooo0?ooo`3oool0000003X0oooo
00@000000?ooo`3oool00000D03oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
03/0oooo00@000000?ooo`3oool00000K@3oool00240oooo00<000000?ooo`000000?03oool00`00
0000oooo0000001@0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000>`3oool0
10000000oooo0?ooo`00001]0?ooo`008@3oool00`000000oooo0000000l0?ooo`030000003oool0
00000500oooo00<000000?ooo`3oool00P3oool00`000000oooo0000000l0?ooo`040000003oool0
oooo000006d0oooo000Q0?ooo`<00000?03oool300000500oooo00<000000?ooo`3oool00`3oool2
000003d0oooo0P00001^0?ooo`008P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo
04l0oooo00<000000?ooo`3oool00`3oool2000003d0oooo0P00001^0?ooo`00/`3oool200000;<0
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3o
ool400000003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0
1@3oool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`040?ooo`808R8R203o
ool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0;80oooo002K0?ooo`030000003oool0
oooo00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`00
0000oooo0?ooo`0>0?ooo`0307MgM`0c<c<0oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000
oooo0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2l0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo0;`0oooo002I0?ooo`80EEEE00<000000?ooo`3oool02`3oool400000;/0oooo003o
0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002M0?ooo`80000000H04A4A0?ooo`3oool0
4A4A0000000A4A4H0?ooo`@0000000<04A4A0?ooo`3oool01@00002O0?ooo`00WP3oool00`000000
oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1P00000<0?ooo`030000003oool0oooo0080
oooo00D0VIVI028R8P3^k^h0oooo04A4A02O0?ooo`00WP3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool00`3oool00`2IVIT08R8R0>k^kP2P0?ooo`00
WP3oool01P000000oooo04A4A00c<c<0oooo000000T0oooo1P00000<0?ooo`030000003oool0oooo
00@0oooo00<0VIVI028R8P3^k^h0W`3oool009h0oooo00H000000=gMg@0c<c<0EEEE0=gMg@00000K
0?ooo`030000003oool0oooo00D0oooo00<0MgMg06IVIP3oool0WP3oool009h0oooo00H0000008R8
R02ZZZX0^k^k05EEE@00000K0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0W@3o
ool009h0oooo00H0000003<c<`3oool0oooo03<c<`00000K0?ooo`030000003oool0oooo0080oooo
00D000000;^k^`3oool0VIVI014A4@2O0?ooo`00W@3oool00`0A4A40000008R8R0020?ooo`0308R8
R00000004A4A01P0oooo0P1EEED00`000000oooo0?ooo`020?ooo`0509VIV@0A4A400000028R8P3<
c<`0W`3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02846 .43102 L
.03068 .47847 L
.03279 .51313 L
.03398 .52788 L
.03527 .5398 L
.03645 .54704 L
.03754 .55086 L
.03871 .55217 L
.04 .55065 L
.04065 .54889 L
.04135 .54637 L
.04262 .5405 L
.04516 .52577 L
.04793 .50981 L
.04919 .50387 L
.04989 .50115 L
.05054 .49899 L
.05182 .49597 L
.05297 .49464 L
.05412 .49461 L
.05534 .49589 L
.05638 .49792 L
.05752 .50096 L
.06244 .51825 L
.0638 .5225 L
.06451 .52442 L
.06527 .52615 L
.06593 .52739 L
.06666 .52843 L
.06795 .52941 L
.06919 .52932 L
.06989 .52884 L
.07053 .52814 L
.07172 .52627 L
.07296 .52364 L
.07579 .51626 L
.07734 .51213 L
.0788 .50868 L
.08017 .50613 L
.08094 .50504 L
.08165 .5043 L
.08291 .50361 L
.08354 .50357 L
.08424 .50377 L
.0855 .50473 L
.08666 .50622 L
.08799 .50853 L
.08926 .51113 L
.09153 .51618 L
Mistroke
.09395 .52099 L
.09467 .52212 L
.09534 .52302 L
.09659 .52424 L
.09777 .52477 L
.09904 .52467 L
.09971 .52434 L
.10044 .52376 L
.10121 .52294 L
.10193 .522 L
.10458 .51743 L
.10702 .51271 L
.10835 .51037 L
.1096 .50854 L
.11031 .50771 L
.11095 .5071 L
.11167 .5066 L
.11244 .50629 L
.11372 .50628 L
.11436 .50651 L
.11506 .50695 L
.11636 .50821 L
.11754 .50978 L
.1202 .51426 L
.12268 .51861 L
.12377 .52025 L
.12497 .52172 L
.12613 .52272 L
.1272 .52324 L
.12834 .52333 L
.12956 .52289 L
.1302 .52245 L
.13089 .52182 L
.13216 .52032 L
.13453 .51661 L
.1368 .51271 L
.13804 .51075 L
.13921 .50918 L
.1402 .50812 L
.14127 .50732 L
.14245 .50689 L
.14354 .50695 L
.14481 .50755 L
.14602 .50862 L
.1471 .50994 L
.14827 .51166 L
.15073 .51582 L
.15207 .51809 L
.15333 .52001 L
.15451 .52149 L
Mistroke
.15558 .5225 L
.15678 .52318 L
.15807 .52333 L
.15914 .52299 L
.16031 .52214 L
.16142 .52094 L
.16244 .51953 L
.16492 .51534 L
.1676 .51066 L
.16883 .50886 L
.17013 .50739 L
.17124 .50657 L
.17246 .50621 L
.17319 .50627 L
.17386 .5065 L
.17463 .50699 L
.17536 .50766 L
.17665 .50927 L
.17806 .51155 L
.1805 .5162 L
.18178 .51866 L
.18313 .52101 L
.18434 .52274 L
.18498 .52348 L
.18567 .52409 L
.18687 .52473 L
.18799 .52476 L
.18921 .52417 L
.19037 .52303 L
.19141 .52156 L
.19254 .51958 L
.19749 .509 L
.19884 .50656 L
.19959 .50548 L
.20029 .50465 L
.20095 .50408 L
.20167 .50369 L
.20292 .50364 L
.20362 .50396 L
.20426 .50448 L
.20499 .50532 L
.20568 .50634 L
.20691 .50867 L
.20823 .51177 L
.21097 .5191 L
.21246 .52296 L
.21386 .526 L
.21507 .52799 L
.21636 .52924 L
.2171 .52949 L
Mistroke
.2178 .5294 L
.21911 .52836 L
.22031 .52642 L
.22142 .52385 L
.22393 .51594 L
.22632 .50722 L
.22859 .49982 L
.22984 .49683 L
.23055 .49563 L
.2312 .49488 L
.23236 .49449 L
.2336 .4955 L
.23477 .49787 L
.23604 .50194 L
.23724 .50709 L
.23834 .51276 L
.24265 .53811 L
.24384 .54415 L
.24512 .54908 L
.24633 .55173 L
.24743 .55201 L
.24872 .54928 L
.24945 .54612 L
.25012 .54208 L
.25136 .53176 L
.25268 .51653 L
.25527 .47382 L
.25771 .42017 L
.26327 .27131 L
.26573 .20678 L
.26836 .14763 L
.26964 .12409 L
.27084 .10543 L
.27194 .09165 L
.2731 .08037 L
.27433 .07206 L
.27547 .06758 L
.27669 .06587 L
.27739 .0662 L
.27804 .06725 L
.27874 .06911 L
.2794 .07147 L
.28065 .07719 L
.28345 .09346 L
.28567 .10639 L
.28689 .11243 L
.28804 .11708 L
.28911 .12035 L
.29027 .12262 L
.29133 .12351 L
Mistroke
.2923 .12338 L
.29346 .12211 L
.29454 .11997 L
.29572 .11676 L
.29699 .11258 L
.29935 .10399 L
.30069 .09928 L
.30195 .09538 L
.30319 .09226 L
.30388 .09089 L
.30452 .08991 L
.30515 .08918 L
.30585 .0887 L
.30657 .08853 L
.30725 .08869 L
.30849 .08972 L
.30961 .09141 L
.31091 .09407 L
.31214 .09708 L
.31473 .10406 L
.31614 .10764 L
.31746 .11049 L
.31821 .11181 L
.31889 .11281 L
.31965 .11365 L
.32046 .11423 L
.32114 .11445 L
.32187 .11442 L
.32257 .11414 L
.32322 .11366 L
.32821 .10501 L
.33083 .09931 L
.33226 .09668 L
.33296 .09563 L
.3336 .09482 L
.33477 .09374 L
.33602 .09324 L
.33668 .09325 L
.33739 .09347 L
.33868 .09441 L
.33986 .09581 L
.34111 .09774 L
.34335 .10192 L
.34556 .10614 L
.34677 .10818 L
.34793 .10978 L
.349 .11089 L
.35017 .11163 L
.35123 .11183 L
.35222 .11163 L
Mistroke
.35349 .11081 L
.3547 .10954 L
.35694 .10616 L
.35935 .10188 L
.36071 .09954 L
.36198 .09763 L
.36319 .09619 L
.36449 .09515 L
.3652 .09482 L
.36587 .09469 L
.36713 .09489 L
.36831 .0956 L
.3694 .09666 L
.3706 .0982 L
.37187 .10016 L
.37432 .10435 L
.37696 .10842 L
.37769 .10931 L
.37847 .11007 L
.37913 .11057 L
.37985 .11095 L
.38053 .11114 L
.38126 .11115 L
.38257 .1107 L
.40249 .10175 L
.4051 .1064 L
.40654 .10865 L
.40725 .10959 L
.40791 .11033 L
.40917 .11137 L
.40984 .11168 L
.41056 .11183 L
.41183 .11159 L
.41298 .11083 L
.41429 .1094 L
.4157 .10727 L
.41826 .10249 L
.42104 .09734 L
.4218 .09616 L
.42261 .09508 L
.42338 .09427 L
.42408 .09372 L
.42538 .09323 L
.42611 .09328 L
.42679 .09353 L
.42803 .09451 L
.42935 .09623 L
.43072 .09861 L
.432 .10125 L
.43492 .10768 L
Mistroke
.43621 .11022 L
.43743 .11221 L
.43852 .11351 L
.43972 .11432 L
.44101 .1144 L
.44174 .11406 L
.4424 .11351 L
.44368 .11185 L
.44488 .10961 L
.44936 .09814 L
.45054 .09512 L
.45181 .09231 L
.453 .09026 L
.4541 .08905 L
.45537 .08853 L
.45657 .08902 L
.45787 .09063 L
.45861 .09202 L
.45929 .09359 L
.4616 .1006 L
.46407 .10955 L
.46644 .11753 L
.46764 .12058 L
.46895 .1228 L
.47007 .12356 L
.47127 .12306 L
.4724 .12128 L
.47342 .11856 L
.47472 .11374 L
.47591 .10807 L
.47861 .09251 L
.47984 .08514 L
.48115 .07777 L
.48236 .07204 L
.48352 .06809 L
.48457 .06614 L
.48572 .06622 L
.48677 .0686 L
.48774 .07298 L
.48892 .08135 L
.48999 .09195 L
.49123 .1078 L
.49239 .12622 L
.49691 .22542 L
.50179 .35823 L
.50417 .41962 L
.50672 .47548 L
.50795 .49758 L
.50912 .5151 L
.51016 .5278 L
Mistroke
.51131 .53861 L
.51257 .54671 L
.51326 .54955 L
.51391 .55125 L
.51507 .55214 L
.51631 .55038 L
.51697 .54847 L
.5177 .54575 L
.51915 .53867 L
.52175 .5233 L
.52306 .51558 L
.52447 .50804 L
.52571 .50252 L
.52703 .49814 L
.52776 .49642 L
.52857 .49516 L
.5293 .49457 L
.52999 .49449 L
.53128 .49552 L
.53201 .49672 L
.53267 .49815 L
.53759 .51457 L
.53889 .51909 L
.54029 .52333 L
.54161 .52645 L
.54282 .5284 L
.54403 .52937 L
.54535 .52934 L
.54601 .5289 L
.54673 .52813 L
.54801 .52607 L
.54928 .52335 L
.55047 .52034 L
.55271 .51428 L
.55484 .50901 L
.55601 .50672 L
.5571 .50508 L
.55828 .50397 L
.55958 .50356 L
.56068 .5039 L
.56187 .50492 L
.56253 .50577 L
.56324 .50685 L
.56452 .5092 L
.56742 .51552 L
.56872 .51832 L
.57014 .52098 L
.57079 .52202 L
.57147 .52295 L
.5727 .52418 L
Mistroke
.57398 .52478 L
.57518 .52469 L
.57649 .52389 L
.57723 .52315 L
.5779 .52231 L
.58032 .51829 L
.58261 .51384 L
.58482 .50993 L
.58606 .5082 L
.5872 .50706 L
.58847 .50633 L
.58911 .50621 L
.58981 .50626 L
.59108 .50683 L
.59226 .50788 L
.5929 .50863 L
.5936 .50958 L
.59486 .51157 L
.59722 .51576 L
.59974 .51993 L
.60043 .52087 L
.60118 .52173 L
.60182 .52234 L
.60252 .52285 L
.60376 .52332 L
.60495 .52324 L
.6061 .52267 L
.60717 .52173 L
.60842 .52022 L
.60956 .51854 L
.6121 .51422 L
.61429 .51067 L
.61544 .50913 L
.61665 .50789 L
.61772 .50718 L
.61888 .50687 L
.61995 .50701 L
.62094 .50751 L
.62561 .51356 L
.6279 .5175 L
.62999 .52065 L
.63107 .52188 L
.6322 .5228 L
.63333 .52328 L
.63457 .52328 L
.63583 .52268 L
.63654 .52211 L
.63718 .52145 L
.63961 .51797 L
.64221 .51335 L
Mistroke
.64358 .51099 L
.64503 .50884 L
.6463 .50741 L
.64702 .50682 L
.6477 .50644 L
.64888 .5062 L
.65015 .50656 L
.6514 .50751 L
.65211 .50829 L
.65276 .50916 L
.65524 .51338 L
.65748 .51773 L
.65989 .52188 L
.66121 .52351 L
.66242 .52447 L
.66357 .52481 L
.66479 .52455 L
.66544 .52415 L
.66613 .52352 L
.66737 .52192 L
.66886 .51934 L
.6702 .51655 L
.67291 .51058 L
.67433 .50775 L
.67511 .50644 L
.67584 .50539 L
.67716 .50407 L
.67786 .50369 L
.67861 .50356 L
.6793 .5037 L
.67995 .50405 L
.68117 .5053 L
.68244 .50734 L
.68359 .50975 L
.68616 .51638 L
.68858 .52276 L
.68963 .52517 L
.6908 .52731 L
.69206 .52888 L
.69275 .52934 L
.6934 .5295 L
.6941 .52936 L
.69475 .52894 L
.6955 .52811 L
.69621 .52698 L
.69747 .52421 L
.69865 .52089 L
.7013 .51166 L
.70356 .50356 L
.70479 .49979 L
Mistroke
.70594 .49702 L
.70718 .49508 L
.70784 .49458 L
.70854 .49449 L
.7098 .49551 L
.71093 .4978 L
.7121 .50144 L
.71317 .50586 L
.71559 .51875 L
.7177 .53154 L
.71998 .54388 L
.72126 .54893 L
.72244 .55163 L
.72362 .55201 L
.72474 .54984 L
.72605 .54382 L
.72725 .53461 L
.72858 .52027 L
.72999 .50013 L
.73285 .44468 L
.73555 .37842 L
.74058 .24121 L
.74284 .18473 L
.74526 .13418 L
.74664 .11106 L
.74791 .09418 L
.74918 .0813 L
.75038 .07284 L
.75163 .06766 L
.75226 .06636 L
.75295 .06587 L
.75418 .06715 L
.75533 .07048 L
.75603 .0733 L
.75669 .07642 L
.75792 .08317 L
.76071 .09991 L
.76293 .11174 L
.76417 .11687 L
.76529 .12033 L
.76635 .12245 L
.76748 .1235 L
.76856 .12334 L
.76955 .12226 L
.77071 .12002 L
.77179 .11714 L
.77424 .10877 L
.77665 .10007 L
.77796 .09588 L
.7792 .09266 L
Mistroke
.78043 .0903 L
.78109 .08944 L
.7818 .08883 L
.78305 .08857 L
.7842 .08922 L
.78547 .09083 L
.78618 .09211 L
.78685 .0935 L
.78964 .1006 L
.7921 .1071 L
.79331 .10982 L
.79443 .11186 L
.79571 .11353 L
.79639 .11408 L
.7971 .1144 L
.79826 .11436 L
.79954 .11355 L
.80409 .1057 L
.80649 .10039 L
.80781 .09779 L
.80905 .09576 L
.81024 .09434 L
.81151 .09343 L
.81268 .09322 L
.81374 .09355 L
.81475 .0943 L
.81586 .09555 L
.81701 .09726 L
.81809 .09914 L
.82061 .10401 L
.82299 .10823 L
.82431 .11001 L
.82505 .11077 L
.82574 .1113 L
.82696 .1118 L
.82825 .11169 L
.82934 .11109 L
.83052 .10997 L
.83164 .10853 L
.83266 .10696 L
.83518 .10251 L
.83753 .09856 L
.83874 .09691 L
.83988 .09572 L
.8412 .09489 L
.84239 .09469 L
.84304 .09479 L
.84372 .09507 L
.84494 .09598 L
.84626 .09747 L
Mistroke
.84771 .09958 L
.85034 .10406 L
.85173 .10636 L
.8532 .10849 L
.85449 .10992 L
.85522 .1105 L
.85591 .11089 L
.85711 .11117 L
.85841 .11088 L
.85965 .11005 L
.86035 .10937 L
.861 .1086 L
.86372 .10444 L
.86627 .10008 L
.86739 .09835 L
.86859 .09677 L
.86979 .09559 L
.8709 .09492 L
.87196 .09468 L
.87308 .09489 L
.87426 .0956 L
.87537 .0967 L
.87658 .0983 L
.87789 .10037 L
.88056 .10514 L
.88198 .10752 L
.88275 .10868 L
.88348 .10964 L
.88418 .11042 L
.88493 .11108 L
.88624 .11175 L
.88689 .11183 L
.88758 .11174 L
.8888 .11112 L
.88999 .10999 L
.89127 .10827 L
.89356 .10422 L
.89605 .09941 L
.89746 .09696 L
.89815 .09592 L
.89879 .09509 L
.90002 .09389 L
.90067 .09349 L
.90135 .09326 L
.90265 .09338 L
.90339 .09378 L
.90407 .09436 L
.90531 .09588 L
.90644 .09773 L
.90896 .10295 L
Mistroke
.9117 .10889 L
.91313 .11148 L
.91392 .11262 L
.91466 .11346 L
.9153 .114 L
.91599 .11435 L
.91675 .11447 L
.91745 .11431 L
.91878 .11332 L
.92003 .11158 L
.9213 .10913 L
.92245 .10644 L
.92503 .09956 L
.9262 .09644 L
.92744 .09348 L
.92859 .09122 L
.92966 .08966 L
.9309 .08867 L
.93156 .08853 L
.93226 .0887 L
.93301 .08925 L
.93373 .09012 L
.93437 .09118 L
.93507 .09261 L
.93771 .10031 L
.94015 .10917 L
.94223 .11632 L
.94336 .1195 L
.94441 .12174 L
.94556 .12322 L
.94681 .1235 L
.94787 .12256 L
.949 .12031 L
.95008 .11702 L
.95124 .11228 L
.95335 .10122 L
.9573 .078 L
.95839 .07271 L
.95957 .06846 L
.96087 .06604 L
.96208 .06644 L
.96273 .06786 L
.96343 .07046 L
.96472 .07819 L
.96597 .08963 L
.96713 .10378 L
.96922 .13769 L
.97152 .18653 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo001/0?ooo`030000003oool0
oooo03l0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1=0?ooo`800000@@3oool0
0`000000oooo0?ooo`0O0?ooo`00K03oool200000400oooo0P0000030?ooo`030000003oool0oooo
04d0oooo0P0000100?ooo`030000003oool000000200oooo001[0?ooo`030000003oool0000003l0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`1=0?ooo`030000003oool0000003l0
oooo00<000000?ooo`000000803oool006/0oooo00<000000?ooo`000000?`3oool00`000000oooo
000000030?ooo`030000003oool0oooo04d0oooo00<000000?ooo`000000?`3oool00`000000oooo
0000000P0?ooo`00J`3oool00`000000oooo0000000o0?ooo`030000003oool0000000<0oooo00<0
00000?ooo`3oool0C03oool010000000oooo0?ooo`00000o0?ooo`030000003oool000000200oooo
001[0?ooo`030000003oool0000003l0oooo00<000000?ooo`0000000`3oool2000004d0oooo00@0
00000?ooo`3oool00000?`3oool00`000000oooo0000000P0?ooo`00J`3oool00`000000oooo0000
000o0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0C03oool010000000oooo0?oo
o`00000o0?ooo`030000003oool000000200oooo001Z0?ooo`050000003oool0oooo0?ooo`000000
1P3oool2000002d0oooo0P0000070?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool0C03oool010000000oooo0?ooo`0000060?ooo`800000;P3oool2000000H0oooo00@000000?oo
o`3oool00000803oool006X0oooo00D000000?ooo`3oool0oooo000000050?ooo`<00000203oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool0C03oool010000000oooo0?oo
o`0000060?ooo`030000003oool0000000L0oooo0P00000K0?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`00000000001@3oool010000000oooo0?ooo`00000P0?ooo`00JP3oool01@000000
oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000001P3oool3000000H0oooo0`00000@
0?ooo`@000001@3oool010000000oooo0?ooo`0000020?ooo`@0000000@04A4A0?ooo`3oool00000
0P3oool00`000000oooo0?ooo`1<0?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`0000060?ooo`@000001P3oool3000000L0oooo0P0000070?ooo`<000001P3oool01000
0000oooo0?ooo`0000050?ooo`040000003oool0oooo00000200oooo001Z0?ooo`050000003oool0
oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`80000000<0oooo0000003oool0
1@3oool010000000oooo00000000000?0?ooo`040000003oool0oooo000000D0oooo00@000000?oo
o`3oool00000103oool2000000<0oooo00@000000?ooo`3oool00000CP3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool000001P3oool010000000oooo0?ooo`0000050?oo
o`80000000<0oooo0000000000001@3oool010000000oooo0?ooo`0000050?ooo`80000000<0oooo
0000003oool0103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0M0?ooo`00JP3oool01@000000oooo0?ooo`3oool0000000D0oooo00@0
00000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3o
ool0oooo000000080?ooo`800000103oool01@000000oooo0?ooo`3oool000000080oooo1P000000
0`3oool000000?ooo`020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000CP3o
ool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`04
0000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0
oooo000000D0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000000@0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0M0?ooo`00JP3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
00<0oooo0P0000000`3oool000000?ooo`030?ooo`050000003oool0oooo0?ooo`000000103oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?oo
o`03000004`0oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`00
0000103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo00000004
0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool07@3oool006X0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000
003oool0oooo000000H0oooo00<000000?ooo`3oool00P0000040?ooo`040000003oool0oooo0000
00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool00000CP3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000D0
oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo000000D0oooo00@00000
0?ooo`3oool000001P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo00800000
103oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool07@3oool006X0oooo
00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000060?ooo`030000003oool0000000L0
oooo0`0000060?ooo`<000001P3oool4000000H0oooo00<000000?ooo`0000001P3oool010000000
oooo0?ooo`0000040?ooo`040000003oool0oooo000004h0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000050?ooo`80000000<0oooo0000003oool01@3oool3000000L0oooo0`00
00060?ooo`<000001`3oool00`000000oooo000000050?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`0M0?ooo`00JP3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000H0oooo0`00000S0?ooo`<000001P3oool010000000oooo0?ooo`0000040?ooo`04
0000003oool0oooo000004h0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000006
0?ooo`800000903oool2000000H0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo01d0oooo001Z0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000=@3oool0
10000000EEEE05EEE@0000040?ooo`040000003oool0oooo000004h0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000e0?ooo`030000003oool0000000D0oooo00<000000?ooo`3o
ool07@3oool006X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0000000f0?ooo`800000
1P3oool00`000000oooo0000001>0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000
=P3oool00`000000oooo000000050?ooo`030000003oool0oooo01d0oooo001Z0?ooo`030000003o
ool0oooo00<0oooo0P00000g0?ooo`8000001P3oool010000000oooo00000000001<0?ooo`030000
003oool0oooo00@0oooo0P00000f0?ooo`<000001@3oool00`000000oooo0?ooo`0M0?ooo`00JP3o
ool00`000000oooo0?ooo`140?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`0M0?ooo`00JP3oool00`000000oooo0?ooo`140?ooo`030000003oool0
000004d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00JP3oool00`00
0000oooo0?ooo`140?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`0M0?ooo`00JP3oool00`000000oooo0?ooo`140?ooo`030000003oool0000004d0
oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo
0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<0
00000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`15
0?ooo`040000003oool00000000004`0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?oo
o`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?oo
o`030000003oool0000004d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?oo
o`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0000004d0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`0M0?ooo`00J@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0000004`0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`040000003oool0
0000000004/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0000004`0oooo00<000000?ooo`3oool0AP3oool0
0`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool00000
04`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0000004`0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004`0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?oo
o`170?ooo`800000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X
0?ooo`030000003oool0oooo04L0oooo0P00001<0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0703oool006P0oooo00<000000?ooo`3oool0A`3oool3000004/0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`80
0000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`030000
003oool0oooo04L0oooo0P00001<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
703oool006P0oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?ooo`0]0?ooo`050>k^kP0c<c<0
000003<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@040?ooo`800000
C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`030000003o
ool0oooo02d0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c
0?ooo`030?ooo`800000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo
001X0?ooo`030000003oool0oooo02D0oooo1P0000020?ooo`05014A4@3oool0oooo0?ooo`0A4A40
403oool00`000000oooo0?ooo`020?ooo`@00000BP3oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01`0oooo001X0?ooo`030000003oool0oooo02d0oooo00D000000?ooo`3oool0oooo
0000000?0?ooo`0307MgM`0c<c<0oooo00<0oooo0P00001<0?ooo`030000003oool0oooo04H0oooo
00<000000?ooo`3oool0703oool006P0oooo00<000000?ooo`3oool0;@3oool01@000000oooo0?oo
o`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0040?ooo`800000C03oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`030000003oool0oooo02d0oooo
00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00H0oooo0P00001<0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0703oool006P0oooo00<000000?ooo`3oool0
;@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01P3oool2000004`0
oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo
0?ooo`0]0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000D0oooo0P00001<0?ooo`03
0000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0
A`3oool2000004`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00J03o
ool00`000000oooo0?ooo`170?ooo`<00000B`3oool00`000000oooo0?ooo`170?ooo`030000003o
ool0oooo01/0oooo001X0?ooo`030000003oool0oooo04L0oooo0P00001<0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0A`3oool20000
04`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00J03oool00`000000
oooo0?ooo`170?ooo`800000C03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01/0
oooo001X0?ooo`030000003oool0oooo04L0oooo0P00001<0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00J03oool00`000000oooo0?ooo`17
0?ooo`<00000B`3oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01/0oooo001X0?oo
o`030000003oool0oooo04L0oooo0P00001<0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool06`3oool006P0oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`0K0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`800000
C03oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo01/0oooo001X0?ooo`030000003o
ool0oooo04L0oooo0P00001<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3o
ool006P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0
oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0B03oool00`00
0000oooo0?ooo`1:0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool001d0
oooo100000000`0A4A40oooo0?ooo`0l0?ooo`050>k^kP0c<c<0000003<c<`3^k^h00`3oool01000
0000oooo028R8P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0?@3oool2000003l0oooo00D0
k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R00<000000?ooo`3oool00P3oool01@14A4@00000
0000000c<c<0gMgM03l0oooo100000000`0A4A40oooo0?ooo`0H0?ooo`007`3oool00`000000oooo
0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool010000000oooo028R8P0R8R880?oo
o`0307MgM`0c<c<0oooo03`0oooo00<000000?ooo`3oool0?P3oool01@1gMgL0VIVI0?ooo`2IVIT0
MgMg00D0oooo0P0R8R800`000000oooo0?ooo`050?ooo`0307MgM`0c<c<0oooo03l0oooo0P00000L
0?ooo`00503oool6000000D0oooo00<000000?ooo`3oool0=P3oool600000080oooo00D04A4A0?oo
o`3oool0oooo014A4@030?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0>`3oool0
0`000000oooo0?ooo`0n0?ooo`05014A4@3oool0oooo0?ooo`0A4A401`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03h0oooo0P00000L0?ooo`007`3oool00`000000oooo0?ooo`0n
0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`090?ooo`0307MgM`0c
<c<0oooo03`0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000L0oooo
00<000000?ooo`3oool01@3oool00`1gMgL0<c<c0?ooo`0o0?ooo`800000703oool001l0oooo00<0
00000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0
1P3oool01@0000008R8R0000000c<c<0c<c<03d0oooo00<000000?ooo`3oool0?P3oool01@000000
oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool00`3oool01@0000008R8R0000000c<c<0
c<c<0440oooo00<000000?ooo`3oool06P3oool001l0oooo00<000000?ooo`3oool0?P3oool01@0A
4A40oooo0?ooo`3oool04A4A00<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo03h0oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0J0?ooo`007`3oool0
0`000000oooo0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`130?ooo`030000
003oool0oooo01X0oooo000M0?ooo`80EEEE00<000000?ooo`3oool0?P3oool01@3^k^h0<c<c0000
000c<c<0k^k^00<0oooo00<000000?ooo`3oool01P3oool4000003h0oooo0P00000o0?ooo`050>k^
kP0c<c<0000003<c<`3^k^h01P3oool00`000000oooo0?ooo`030?ooo`@00000@03oool205EEE@03
0000003oool0oooo01X0oooo001X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo001X0?ooo`030000003o
ool0oooo04P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003o
ool0oooo01X0oooo001X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool0
0`000000oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo001X0?ooo`030000003oool0oooo
04P0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
01X0oooo001X0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo01X0oooo000D0?ooool00000@000000E0?ooo`006`3o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06P3o
ool001/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`00
0000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`00
0000oooo0?ooo`1V0?ooo`006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0
oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`1V0?ooo`006`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo
0?ooo`1V0?ooo`006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo0P00
001:0?ooo`030000003oool0oooo06H0oooo000K0?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0B@3oool2000004X0oooo00<000000?ooo`3oool0IP3oool001/0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`190?ooo`800000BP3oool00`000000oooo0?ooo`1V0?oo
o`006`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo0P00001:0?ooo`03
0000003oool0oooo06H0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B@3oool2000004X0oooo00<000000?ooo`3oool0IP3oool001`0oooo00<000000?ooo`3oool0B03o
ool00`000000oooo0?ooo`190?ooo`800000BP3oool00`000000oooo0?ooo`1V0?ooo`00703oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0
oooo06L0oooo000L0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool20000
04T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`190?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo
0?ooo`180?ooo`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo06L0oooo
000L0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0oooo00<0
00000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`19
0?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`180?oo
o`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`03
0000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0oooo00<000000?ooo`3o
ool0I`3oool001`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`190?ooo`800000
B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`180?ooo`030000003o
ool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0oooo00<000000?ooo`3oool0I`3oool0
01`0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`190?ooo`800000B@3oool00`00
0000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0
oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0oooo
00<000000?ooo`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<0
00000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3oool00`000000oooo0?oo
o`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04X0oooo0P000019
0?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0oooo00<000000?oo
o`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3o
ool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00
7@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02l0oooo00D0k^k^03<c<`000000
<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo0P0000190?oo
o`030000003oool0oooo06L0oooo000M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0;`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo
00@0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000M0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0;`3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?oo
o`3oool00`3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001d0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0_0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1g
MgL0<c<c0?ooo`040?ooo`<00000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo02l0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`050000000R8R80000003<c<`3<c<`01@3oool2000004P0oooo00<000000?ooo`3oool0J03oool0
01d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0_0?ooo`05014A4@3oool0oooo
0?ooo`0A4A40303oool00`000000oooo0?ooo`070?ooo`800000B03oool00`000000oooo0?ooo`1X
0?ooo`007@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo02l0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo00L0oooo0P0000180?ooo`030000003oool0
oooo06P0oooo000M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0;`3oool01@3^
k^h0<c<c0000000c<c<0k^k^00`0oooo100000060?ooo`800000B03oool00`000000oooo0?ooo`1X
0?ooo`007@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo0P0000180?oo
o`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3o
ool0BP3oool2000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0
AP3oool00`000000oooo0?ooo`1:0?ooo`800000B03oool00`000000oooo0?ooo`1X0?ooo`007@3o
ool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo0P0000180?ooo`030000003o
ool0oooo06P0oooo000M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0BP3oool2
000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0AP3oool00`00
0000oooo0?ooo`1:0?ooo`800000B03oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo0P0000180?ooo`030000003oool0oooo06P0
oooo000M0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0B`3oool00`000000oooo
000000170?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool0B`3oool3000004L0oooo00<000000?ooo`3oool0J03oool001h0oooo00<00000
0?ooo`3oool0A03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0000004L0oooo00<00000
0?ooo`3oool0J03oool001h0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1;0?oo
o`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001h0oooo00<000000?ooo`3o
ool0A03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0000004L0oooo00<000000?ooo`3o
ool0J03oool001h0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1;0?ooo`030000
003oool0000004L0oooo00<000000?ooo`3oool0J03oool001h0oooo00<000000?ooo`3oool0A03o
ool00`000000oooo0?ooo`1;0?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0J03o
ool001h0oooo00<000000?ooo`3oool0A03oool00`000000oooo0?ooo`1;0?ooo`030000003oool0
000004L0oooo00<000000?ooo`3oool0J03oool001h0oooo00<000000?ooo`3oool0A03oool00`00
0000oooo0?ooo`1;0?ooo`<00000AP3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000
oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000AP3oool00`000000
oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`000000AP3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?oo
o`140?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000AP3oool00`000000oooo0?oo
o`1Y0?ooo`007P3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo04/0oooo00@00000
0?ooo`3oool00000A@3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`000000oooo0?ooo`14
0?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000A@3oool00`000000oooo0?oo
o`1Y0?ooo`007P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo03D0oooo0P000006
0?ooo`030000003oool0oooo04/0oooo0P0000000`3oool000000?ooo`040?ooo`800000=`3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo
00<0oooo0`00000f0?ooo`<00000103oool00`000000oooo0?ooo`1<0?ooo`040000003oool0oooo
000000D0oooo0P00000g0?ooo`8000001@3oool00`000000oooo0?ooo`1Y0?ooo`007P3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0000003H0oooo00<000000?ooo`000000103oool00`00
0000oooo0?ooo`1<0?ooo`040000003oool0oooo000000D0oooo0P00000f0?ooo`040000003oool0
oooo000000@0oooo00<000000?ooo`3oool0J@3oool001h0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000070?ooo`800000903oool2000000L0oooo00<000000?ooo`000000103o
ool00`000000oooo0?ooo`1<0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool0
00001`3oool00`000000oooo0?ooo`0R0?ooo`8000001`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3o
ool0oooo000000050?ooo`<000001`3oool2000000P0oooo0P0000070?ooo`<000001P3oool00`00
0000oooo000000060?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0@P3oool4
00000003014A4@3oool0oooo00<0oooo00@000000?ooo`3oool00000103oool010000000oooo0?oo
o`0000060?ooo`030000003oool0000000L0oooo0P0000070?ooo`<000001`3oool2000000L0oooo
00<000000?ooo`0000001P3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo06T0
oooo000N0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000050?ooo`04
0000003oool0oooo000000D0oooo0P0000000`3oool000000?ooo`050?ooo`040000003oool00000
000000D0oooo0P0000000`3oool000000?ooo`050?ooo`040000003oool0oooo000000D0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo
0?ooo`0000001@3oool010000000oooo0?ooo`0000050?ooo`80000000<0oooo0000003oool01@3o
ool010000000oooo0000000000050?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3o
ool0oooo000000040?ooo`030000003oool0oooo06T0oooo000N0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`050000
003oool0oooo0?ooo`0000001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
0080oooo00D000000?ooo`3oool0oooo000000160?ooo`030000003oool0oooo00D0oooo00@00000
0?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000
oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0
oooo000000D0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo06T0oooo
000N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00P3oool0
1@000000oooo0?ooo`3oool0000004H0oooo00<000000?ooo`3oool01@3oool4000000<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000
103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0
oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0
000006/0oooo000N0?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3o
ool0000000@0oooo00D000000?ooo`3oool0oooo000000050?ooo`040000003oool0oooo000000D0
oooo0P0000020?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000001@3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo000000160?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`020?ooo`050000
003oool0oooo0?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000000D0oooo00@000000?oo
o`3oool000001@3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000
103oool01@000000oooo0?ooo`3oool0000000D0oooo00D000000?ooo`3oool0oooo0000001[0?oo
o`007`3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000H0oooo00<00000
0?ooo`0000001`3oool2000000L0oooo0`0000060?ooo`@000001@3oool010000000oooo0?ooo`00
00050?ooo`050000003oool0oooo0?ooo`000000AP3oool00`000000oooo0?ooo`050?ooo`040000
003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool010000000oooo0?ooo`0000050?oo
o`80000000<0oooo0000003oool01@3oool3000000H0oooo100000060?ooo`030000003oool00000
00H0oooo00@000000?ooo`3oool000001@3oool01@000000oooo0?ooo`3oool0000006/0oooo000O
0?ooo`040000003oool0oooo000000D0oooo0P0000000`3oool000000?ooo`060?ooo`8000006P3o
ool2000000L0oooo00<000000?ooo`0000001@3oool01@000000oooo0?ooo`3oool0000004H0oooo
00<000000?ooo`3oool01@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`0000001`3oool2000001/0oooo0P0000060?ooo`040000003oool0oooo0000
00D0oooo00D000000?ooo`3oool0oooo0000001[0?ooo`007`3oool010000000oooo0?ooo`000006
0?ooo`800000;@3oool3000000H0oooo00@000000?ooo`3oool00000A03oool205EEE@030000003o
ool0oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`800000
;@3oool2000000H0oooo00@000000?ooo`3oool00000K03oool001l0oooo00@000000?ooo`3oool0
0000?P3oool010000000oooo0?ooo`00001>0?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0?03oool010000000oooo0?ooo`00001/0?ooo`007`3oool00`000000oooo0000000o
0?ooo`040000003oool0oooo000004h0oooo0P0000020?ooo`030000003oool0000003h0oooo00@0
00000?ooo`3oool00000K03oool001l0oooo00<000000?ooo`000000?`3oool00`000000oooo0000
001?0?ooo`070000003oool0oooo0?ooo`000000oooo0000000n0?ooo`040000003oool0oooo0000
06`0oooo000O0?ooo`030000003oool0000003l0oooo00<000000?ooo`000000C`3oool01`000000
oooo0?ooo`3oool000000?ooo`000000?`3oool00`000000oooo0000001/0?ooo`007`3oool00`00
0000oooo0000000o0?ooo`030000003oool0000004l0oooo00L000000?ooo`3oool0oooo0000003o
ool0000003l0oooo00<000000?ooo`000000K03oool001l0oooo00<000000?ooo`000000?`3oool0
0`000000oooo0000001?0?ooo`040000003oool0oooo0?ooo`<00000?`3oool00`000000oooo0000
001/0?ooo`00803oool200000400oooo0P00001?0?ooo`040000003oool0oooo0?ooo`800000@03o
ool3000006`0oooo000P0?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2]0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`80
0000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00
002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`2b0?ooo`00
V`3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000
003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c<c<0
oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R800000
03<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2l0?oo
o`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo002I0?ooo`80EEEE
00<000000?ooo`3oool02`3oool400000;/0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo002M0?ooo`80000000H04A4A0?ooo`3oool04A4A0000000A4A4H0?ooo`@0000000P04A4A
0?ooo`3oool0k^k^03<c<`0000004A4A0<c<c9l0oooo002N0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool01`3oool6000000`0oooo00<000000?ooo`3oool00P3oool01@1EEED0MgMg
0?ooo`2IVIT08R8R09l0oooo002N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
6@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000W`3oool009h0oooo
00H000000?ooo`14A4@0<c<c0?ooo`0000090?ooo`H00000303oool00`000000oooo0?ooo`020?oo
o`050000002IVIT0oooo09VIV@0R8R80W`3oool009h0oooo00H000000=gMg@0c<c<0EEEE0=gMg@00
000K0?ooo`030000003oool0oooo0080oooo00D0000005EEE@0000004A4A0<c<c02O0?ooo`00WP3o
ool01P000000R8R80:ZZZP2k^k/0EEEE000001/0oooo00<000000?ooo`3oool00P3oool00`1EEED0
R8R80?ooo`2Q0?ooo`00WP3oool01P000000<c<c0?ooo`3oool0<c<c000001/0oooo00<000000?oo
o`3oool00P3oool00`3MgMd04A4A09VIV@2Q0?ooo`00W@3oool00`0A4A40000008R8R0020?ooo`03
08R8R00000004A4A01P0oooo0P1EEED00`000000oooo0?ooo`030?ooo`040<c<c014A4@00000014A
4Il0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02605 .38523 L
.02846 .45703 L
.02962 .48572 L
.03072 .50831 L
.03171 .52456 L
.03279 .53781 L
.03397 .54721 L
.03527 .55177 L
.03592 .55201 L
.03663 .55092 L
.0379 .54602 L
.03916 .53841 L
.04036 .52973 L
.04262 .5131 L
.04384 .50546 L
.045 .49992 L
.04564 .49766 L
.04633 .49593 L
.04753 .49467 L
.04869 .49548 L
.04991 .49821 L
.05095 .50174 L
.0521 .50647 L
.05468 .51798 L
.0561 .52334 L
.0568 .52544 L
.05745 .527 L
.0587 .52885 L
.05936 .52918 L
.06006 .52905 L
.06119 .52785 L
.06244 .5253 L
.06508 .51731 L
.06754 .50964 L
.06878 .5067 L
.06947 .50549 L
.0701 .50469 L
.07079 .50415 L
.07154 .504 L
.07225 .50426 L
.0729 .50482 L
.07361 .50574 L
.07426 .50688 L
.07576 .51021 L
.07878 .51807 L
.08012 .521 L
.08138 .52301 L
.08208 .52373 L
.08284 .52416 L
Mistroke
.08354 .52422 L
.08418 .52401 L
.08546 .52284 L
.08618 .52179 L
.08685 .52063 L
.08936 .51521 L
.09054 .51261 L
.09179 .51016 L
.09298 .50838 L
.09406 .50736 L
.09531 .50696 L
.0965 .50741 L
.09778 .5087 L
.09851 .50974 L
.09918 .51087 L
.102 .51642 L
.10323 .51871 L
.10388 .51976 L
.10458 .52072 L
.10575 .52187 L
.10685 .52234 L
.10809 .52213 L
.10923 .52128 L
.11046 .51975 L
.1118 .51755 L
.11423 .51308 L
.11542 .51112 L
.11652 .50964 L
.11768 .5086 L
.11894 .50816 L
.12004 .50839 L
.12104 .50908 L
.12219 .51037 L
.12328 .51199 L
.12577 .5163 L
.12713 .51853 L
.12841 .5202 L
.12949 .52116 L
.13066 .52163 L
.13196 .52142 L
.13315 .52057 L
.13445 .51903 L
.13565 .51719 L
.13838 .51255 L
.13976 .51057 L
.14105 .50922 L
.14177 .50876 L
.14254 .50851 L
.14325 .50852 L
.1439 .50873 L
Mistroke
.14515 .50965 L
.14633 .51106 L
.14856 .51462 L
.14982 .51679 L
.15116 .51889 L
.15243 .52044 L
.15358 .52133 L
.15465 .52165 L
.15581 .5214 L
.1569 .52061 L
.15791 .51948 L
.16021 .51584 L
.16264 .51166 L
.16392 .50987 L
.1651 .50874 L
.16574 .50836 L
.16645 .50817 L
.16773 .50842 L
.16892 .50935 L
.17019 .51096 L
.17248 .51491 L
.17495 .51929 L
.17562 .52027 L
.17633 .52113 L
.17761 .52212 L
.17833 .52235 L
.179 .52231 L
.17974 .52201 L
.18053 .52139 L
.18127 .52055 L
.18196 .51956 L
.18327 .51728 L
.1855 .51282 L
.18674 .51052 L
.1879 .50873 L
.18856 .50796 L
.18928 .50736 L
.19054 .50696 L
.19182 .50747 L
.193 .50872 L
.19579 .51394 L
.19841 .51973 L
.19955 .52183 L
.20076 .52341 L
.20139 .52392 L
.20208 .52421 L
.2033 .52396 L
.20447 .52284 L
.20553 .52112 L
.20676 .51847 L
Mistroke
.20793 .51553 L
.21002 .51005 L
.21117 .50744 L
.21224 .50555 L
.21337 .50432 L
.21461 .50404 L
.21567 .50474 L
.2168 .50644 L
.21744 .50778 L
.21813 .50951 L
.21939 .51324 L
.22176 .52098 L
.22299 .5246 L
.22431 .52749 L
.22499 .52849 L
.22574 .52909 L
.22706 .5288 L
.22831 .5269 L
.22901 .52517 L
.22965 .52322 L
.23207 .51347 L
.23437 .50329 L
.23567 .49862 L
.23687 .49573 L
.23792 .49469 L
.23907 .49539 L
.24028 .49832 L
.24142 .50308 L
.24633 .5369 L
.24753 .54448 L
.2488 .55013 L
.24954 .55177 L
.25021 .55201 L
.25151 .54849 L
.25224 .54396 L
.25291 .53801 L
.25365 .52946 L
.25443 .51805 L
.25574 .49346 L
.25718 .45899 L
.26239 .29229 L
.26488 .20949 L
.2662 .17065 L
.2676 .13504 L
.26894 .10745 L
.27016 .08857 L
.27139 .07552 L
.27254 .06845 L
.27368 .06599 L
.27487 .0675 L
Mistroke
.27589 .07149 L
.27701 .07795 L
.27948 .09605 L
.28183 .11195 L
.28314 .11829 L
.28387 .12079 L
.28456 .12236 L
.28577 .12337 L
.28705 .12212 L
.28771 .12065 L
.28842 .11854 L
.2897 .11366 L
.29264 .10064 L
.29396 .09547 L
.2952 .09181 L
.29649 .08949 L
.29717 .08895 L
.2979 .08888 L
.2992 .09004 L
.30042 .09245 L
.30152 .09543 L
.30272 .09919 L
.30508 .10682 L
.30638 .11028 L
.30762 .11262 L
.30876 .11381 L
.31001 .11394 L
.31115 .11305 L
.3122 .11145 L
.31458 .10596 L
.31715 .09931 L
.31787 .09773 L
.31862 .09629 L
.31927 .0953 L
.31997 .09449 L
.32063 .094 L
.32134 .0938 L
.32262 .09425 L
.32394 .09572 L
.32468 .09692 L
.32537 .09823 L
.32796 .10396 L
.32918 .10655 L
.33032 .1086 L
.33151 .11014 L
.33282 .111 L
.33349 .11106 L
.33422 .11085 L
.33491 .11038 L
.33555 .10974 L
Mistroke
.33676 .10804 L
.33805 .10571 L
.34079 .10029 L
.34216 .098 L
.34294 .09699 L
.34367 .0963 L
.34437 .09587 L
.34503 .09568 L
.34626 .09594 L
.34695 .09641 L
.34759 .09703 L
.34903 .09901 L
.35158 .10358 L
.35282 .10581 L
.35396 .10757 L
.3552 .10899 L
.35585 .10948 L
.35653 .10979 L
.35723 .10988 L
.35788 .10975 L
.3586 .10938 L
.35936 .10874 L
.3601 .1079 L
.36091 .10678 L
.36236 .10438 L
.36377 .10189 L
.36509 .0997 L
.36626 .0981 L
.36752 .09692 L
.36824 .09654 L
.36892 .09639 L
.37019 .09668 L
.37084 .09711 L
.37153 .09775 L
.37277 .09933 L
.37559 .104 L
.37685 .10606 L
.37751 .10702 L
.37821 .1079 L
.37949 .10906 L
.38067 .10953 L
.3818 .10938 L
.38286 .10873 L
.38402 .10751 L
.38526 .10574 L
.38784 .10138 L
.38925 .09916 L
.39057 .09755 L
.39169 .0967 L
.3929 .09638 L
Mistroke
.39359 .09651 L
.39424 .09682 L
.39547 .0979 L
.39825 .10209 L
.39977 .10479 L
.40121 .1071 L
.40187 .10798 L
.40256 .10875 L
.40331 .10939 L
.40401 .10975 L
.40522 .10983 L
.40591 .10957 L
.40655 .10912 L
.4078 .10777 L
.40898 .10599 L
.41119 .10196 L
.41235 .09988 L
.41358 .09795 L
.41422 .09714 L
.41493 .09643 L
.41617 .09574 L
.41684 .09568 L
.41753 .09587 L
.41878 .0968 L
.41948 .09763 L
.42012 .09858 L
.42159 .10119 L
.42424 .10645 L
.4255 .1086 L
.42669 .1101 L
.42785 .11093 L
.42913 .11098 L
.43038 .11015 L
.43108 .10932 L
.43173 .10836 L
.43434 .10306 L
.43572 .09994 L
.4372 .09697 L
.43791 .0958 L
.43858 .09492 L
.43984 .09393 L
.44101 .09389 L
.44229 .09485 L
.44351 .0967 L
.44481 .09944 L
.44712 .10543 L
.44826 .10834 L
.44934 .11075 L
.45058 .11282 L
.45171 .11386 L
Mistroke
.45277 .11398 L
.45376 .1133 L
.45484 .1117 L
.45599 .10915 L
.45846 .10162 L
.4598 .0972 L
.46106 .09352 L
.46213 .09103 L
.46328 .08934 L
.46455 .08888 L
.46571 .08987 L
.46691 .09233 L
.46802 .09576 L
.47053 .10625 L
.47167 .11138 L
.47289 .11642 L
.47404 .12022 L
.47509 .12251 L
.47629 .12336 L
.47743 .12221 L
.47866 .11871 L
.47936 .11573 L
.48 .11238 L
.48268 .09411 L
.48399 .08426 L
.4852 .07606 L
.48629 .07023 L
.48743 .06658 L
.48859 .06632 L
.48985 .07085 L
.4909 .07901 L
.49203 .09248 L
.49309 .10981 L
.49406 .12941 L
.49638 .18992 L
.4989 .27123 L
.50348 .42409 L
.50583 .48615 L
.50715 .51254 L
.50836 .53072 L
.50948 .54243 L
.5107 .54981 L
.51185 .55207 L
.51292 .55065 L
.51357 .5484 L
.51428 .54501 L
.51556 .53697 L
.51795 .51919 L
.51931 .50978 L
.52005 .50535 L
Mistroke
.52075 .50182 L
.52197 .49724 L
.52262 .49573 L
.52332 .49484 L
.524 .49469 L
.52472 .49526 L
.52602 .49798 L
.52674 .50028 L
.52742 .50282 L
.52897 .5095 L
.53033 .51564 L
.53176 .52148 L
.53298 .52541 L
.53367 .52707 L
.53432 .5282 L
.53554 .52918 L
.53665 .52876 L
.53793 .52688 L
.53914 .52397 L
.54183 .51546 L
.54314 .51131 L
.54435 .50807 L
.54549 .50576 L
.54658 .50442 L
.54772 .504 L
.54897 .50469 L
.55025 .50651 L
.55097 .50792 L
.55162 .5094 L
.55406 .51576 L
.5553 .51886 L
.55661 .52156 L
.5573 .52265 L
.55805 .52353 L
.55937 .52423 L
.56061 .52386 L
.56131 .52324 L
.56195 .52244 L
.56319 .52035 L
.56436 .51792 L
.56659 .51291 L
.56781 .51047 L
.56895 .50866 L
.56992 .5076 L
.57097 .50702 L
.57213 .5071 L
.5732 .50782 L
.57436 .50923 L
.57544 .51099 L
.57788 .51581 L
Mistroke
.57911 .51816 L
.58027 .52004 L
.58091 .52088 L
.5816 .5216 L
.58281 .52229 L
.58404 .52223 L
.58517 .52152 L
.58648 .52 L
.58771 .51805 L
.58993 .51397 L
.59115 .51184 L
.59229 .51015 L
.59353 .50885 L
.59418 .50842 L
.59489 .50818 L
.59614 .50835 L
.59729 .50913 L
.59855 .5106 L
.59993 .51274 L
.60272 .51759 L
.6034 .51865 L
.60414 .51966 L
.60479 .5204 L
.60548 .52102 L
.60678 .52162 L
.60799 .52149 L
.60865 .52113 L
.60937 .52054 L
.61067 .51899 L
.61362 .51414 L
.61492 .51201 L
.61561 .51101 L
.61634 .51009 L
.61704 .50938 L
.61768 .50891 L
.61892 .50849 L
.62012 .50875 L
.62142 .50973 L
.62265 .51123 L
.62377 .51296 L
.62619 .51709 L
.62738 .51892 L
.62848 .52029 L
.62974 .52131 L
.63041 .52158 L
.63111 .52164 L
.63226 .52126 L
.63352 .52018 L
.63469 .51865 L
.63577 .51693 L
Mistroke
.63821 .51267 L
.63932 .51092 L
.64035 .5096 L
.64143 .50863 L
.64261 .50817 L
.6439 .50842 L
.64463 .5089 L
.6453 .50955 L
.64654 .51119 L
.64785 .51339 L
.65014 .51762 L
.6514 .51969 L
.6526 .52121 L
.65326 .52179 L
.65398 .5222 L
.65523 .5223 L
.65651 .52159 L
.65769 .52025 L
.65842 .51914 L
.65911 .51794 L
.66039 .51544 L
.66179 .51264 L
.66328 .50993 L
.66454 .50819 L
.6657 .50723 L
.66685 .50697 L
.66795 .50743 L
.66923 .50877 L
.67041 .51069 L
.67307 .51642 L
.67432 .51917 L
.67566 .5217 L
.67693 .52339 L
.67809 .52416 L
.67938 .52402 L
.68062 .52289 L
.68131 .52186 L
.68195 .52068 L
.68341 .51737 L
.68582 .51103 L
.68701 .50819 L
.6881 .50607 L
.68909 .50472 L
.69014 .50404 L
.6912 .5042 L
.69235 .50537 L
.6936 .50771 L
.69473 .51067 L
.69729 .51885 L
.69842 .52244 L
Mistroke
.69965 .52576 L
.70082 .52801 L
.70189 .52907 L
.70307 .52895 L
.70431 .5273 L
.70537 .52471 L
.70652 .52079 L
.70893 .51039 L
.71026 .50452 L
.71151 .49972 L
.71269 .49644 L
.71396 .49474 L
.71512 .49519 L
.71619 .49743 L
.7172 .50114 L
.71831 .50686 L
.72055 .52221 L
.7218 .53169 L
.72318 .54125 L
.72447 .5482 L
.72567 .55169 L
.72641 .552 L
.72707 .55089 L
.72783 .5478 L
.72855 .54297 L
.72982 .52969 L
.73053 .51943 L
.73119 .50823 L
.7335 .45575 L
.73603 .37932 L
.74114 .20722 L
.74366 .138 L
.74508 .1084 L
.7464 .08803 L
.74754 .07584 L
.74881 .06817 L
.75013 .06599 L
.75137 .06847 L
.75251 .07375 L
.75371 .08142 L
.75585 .09738 L
.75697 .10536 L
.75816 .11273 L
.75946 .11882 L
.76068 .12223 L
.76136 .12315 L
.76209 .12335 L
.76339 .12183 L
.76411 .12007 L
.76479 .11794 L
Mistroke
.76632 .11183 L
.76911 .09947 L
.77032 .0949 L
.77096 .09293 L
.77165 .09122 L
.77293 .08924 L
.77411 .08889 L
.77522 .08981 L
.77645 .09206 L
.77773 .09547 L
.77911 .09985 L
.78041 .10416 L
.7816 .10778 L
.78283 .11085 L
.78399 .11288 L
.78522 .11394 L
.78591 .11402 L
.78655 .11377 L
.78761 .1127 L
.78878 .1107 L
.79115 .10496 L
.79375 .09838 L
.7945 .09685 L
.79521 .09565 L
.79585 .0948 L
.79655 .09417 L
.79782 .09381 L
.79853 .09406 L
.79917 .09456 L
.80043 .09617 L
.80161 .09833 L
.80417 .104 L
.80557 .10695 L
.80688 .10915 L
.808 .11042 L
.8092 .11104 L
.80988 .11104 L
.81053 .11079 L
.81174 .10975 L
.81306 .10786 L
.81446 .10528 L
.81699 .10027 L
.81829 .09809 L
.81898 .09718 L
.8197 .09643 L
.8205 .09589 L
.82124 .09568 L
.82194 .09574 L
.82269 .09608 L
.82401 .0973 L
Mistroke
.82523 .09902 L
.82798 .10398 L
.82923 .10618 L
.8304 .1079 L
.83163 .10919 L
.83227 .10961 L
.83297 .10985 L
.83417 .10971 L
.83547 .10882 L
.83671 .10735 L
.83785 .10559 L
.83999 .10184 L
.84112 .09996 L
.84231 .09828 L
.84299 .09752 L
.84374 .0969 L
.84505 .09639 L
.8457 .09643 L
.84639 .09669 L
.84763 .09766 L
.84893 .09928 L
.85016 .10121 L
.85245 .10513 L
.85376 .1071 L
.85448 .10799 L
.85515 .10866 L
.85633 .1094 L
.85763 .10949 L
.85832 .10923 L
.85905 .10874 L
.86034 .10735 L
.86174 .10529 L
.86326 .1027 L
.8645 .1006 L
.8658 .09866 L
.86649 .09784 L
.86724 .09712 L
.86856 .09644 L
.86981 .09652 L
.87051 .09687 L
.87115 .09738 L
.87239 .09881 L
.87356 .10059 L
.87573 .10438 L
.87692 .10637 L
.87804 .10795 L
.87924 .10919 L
.87988 .10961 L
.88057 .10984 L
.88179 .10971 L
Mistroke
.88291 .10898 L
.88413 .10757 L
.88543 .10554 L
.88778 .10123 L
.88922 .09876 L
.88993 .09774 L
.89058 .09695 L
.8918 .09596 L
.89312 .09569 L
.8944 .09628 L
.8956 .09755 L
.89692 .09959 L
.89834 .10229 L
.90102 .10751 L
.90179 .10875 L
.90252 .10971 L
.90317 .11037 L
.90387 .11085 L
.90451 .11105 L
.9052 .11102 L
.90593 .11069 L
.90661 .11012 L
.90782 .10852 L
.90912 .10613 L
.91145 .10097 L
.91268 .09831 L
.91399 .09597 L
.91472 .09497 L
.91553 .09421 L
.91627 .09385 L
.91696 .09383 L
.91766 .09412 L
.91831 .09467 L
.91902 .09556 L
.91976 .09681 L
.92228 .10267 L
.92369 .10642 L
.92503 .10968 L
.92629 .11213 L
.92701 .11312 L
.92767 .11372 L
.92883 .11401 L
.93006 .11317 L
.9307 .11228 L
.93139 .111 L
.93262 .10795 L
.93544 .099 L
.93668 .0951 L
.93734 .09329 L
.93804 .09162 L
Mistroke
.93931 .0895 L
.9405 .08884 L
.94175 .08967 L
.94293 .09189 L
.94398 .09496 L
.94512 .09923 L
.94861 .11456 L
.94961 .11832 L
.95056 .12108 L
.95141 .1227 L
.95234 .12337 L
.95337 .12263 L
.95447 .12005 L
.9554 .11641 L
.95643 .11101 L
.96024 .08381 L
.96131 .07657 L
.96231 .07097 L
.96322 .06752 L
.96421 .06597 L
.96528 .06748 L
.96642 .07333 L
.9675 .0833 L
.96848 .09627 L
.96947 .11335 L
.97038 .13244 L
.97245 .18629 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.28561,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo001[0?ooo`030000003oool0
oooo0440oooo00D000000?ooo`3oool0oooo0000001>0?ooo`800000@P3oool200000200oooo001[
0?ooo`030000003oool0oooo0440oooo0P0000020?ooo`030000003oool0oooo04`0oooo0P000012
0?ooo`800000803oool006/0oooo0P0000120?ooo`8000000P3oool00`000000oooo0?ooo`1<0?oo
o`800000@P3oool00`000000oooo0000000O0?ooo`00JP3oool00`000000oooo000000110?ooo`03
0000003oool000000080oooo00<000000?ooo`3oool0C03oool200000480oooo00<000000?ooo`00
00007`3oool006X0oooo00<000000?ooo`000000@@3oool00`000000oooo000000020?ooo`030000
003oool0oooo04`0oooo00<000000?ooo`000000@@3oool00`000000oooo0000000O0?ooo`00JP3o
ool00`000000oooo000000110?ooo`030000003oool000000080oooo0P00001=0?ooo`030000003o
ool000000440oooo00<000000?ooo`0000007`3oool006X0oooo00<000000?ooo`000000@@3oool0
0`000000oooo000000020?ooo`030000003oool0oooo04/0oooo00@000000?ooo`3oool00000@@3o
ool00`000000oooo0000000O0?ooo`00JP3oool010000000oooo0?ooo`0000040?ooo`800000<`3o
ool2000000D0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`1;0?ooo`040000003o
ool0oooo000000D0oooo0P00000c0?ooo`8000001@3oool00`000000oooo0000000O0?ooo`00JP3o
ool010000000oooo0?ooo`0000040?ooo`800000<`3oool2000000@0oooo00@000000?ooo`3oool0
00000P3oool00`000000oooo0?ooo`1;0?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`000000<P3oool00`000000oooo000000040?ooo`040000003oool0oooo000001l0oooo001Z0?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000103oool3000000D0oooo0P00
00060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103oool2000000D0oooo0`00
00050?ooo`030000003oool0000000@000000P3oool010000000oooo0?ooo`00001=0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`0000001@3oool3000000D0oooo0P0000060?ooo`03
0000003oool0oooo00@0oooo0P0000060?ooo`8000001@3oool2000000D0oooo00<000000?ooo`00
0000103oool010000000oooo0?ooo`00000O0?ooo`00JP3oool010000000oooo0?ooo`0000030?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`0000001@3oool3000000@0oooo0`000005
0?ooo`<00000103oool4000000@0oooo00<000000?ooo`000000103oool020000000oooo0?ooo`00
0000oooo0000003oool000000P3oool010000000oooo0?ooo`00001=0?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`@00000103oool3
000000@0oooo100000040?ooo`030000003oool0000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000001l0oooo001Y0?ooo`050000
003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`030000003oool00000
00@0oooo00@000000?ooo`3oool00000103oool00`000000oooo000000040?ooo`050000003oool0
oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`P000000P3oool01@000000oooo
0000003oool000000080oooo00@000000?ooo`3oool00000C@3oool010000000oooo0?ooo`000004
0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`000000103oool010000000oooo0?oo
o`0000030?ooo`80000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000030?ooo`05
0000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`0000040?ooo`040000003oool0
oooo000000<0oooo00@000000?ooo`3oool000007`3oool006T0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000000@0oooo00@0
00000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`80000000<0oooo0000003oool00P3oool00`000000oooo000000020000
04/0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`050000003oool0oooo0?ooo`0000000`3oool01@000000
oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000003
0?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo01d0oooo001Y0?ooo`030000
003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0000000D0oooo0`0000040?ooo`<000001@3oool3000000@0oooo00<000000?oo
o`0000001@3oool00`000000oooo000000040?ooo`80000000<0oooo0000003oool00P3oool00`00
0000oooo0000001=0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`02
0?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000103oool00`000000oooo
000000050?ooo`<00000103oool00`000000oooo000000050?ooo`030000003oool0000000@0oooo
00@000000?ooo`3oool00000103oool00`000000oooo000000030?ooo`030000003oool0oooo01d0
oooo001Y0?ooo`030000003oool0oooo0080oooo00<000000?ooo`000000103oool00`000000oooo
000000050?ooo`<000001@3oool2000000H0oooo00<000000?ooo`3oool0103oool2000000H0oooo
0P0000050?ooo`030000003oool0000000@0oooo0P0000000`3oool000000?ooo`020?ooo`030000
003oool0000004d0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080
oooo00<000000?ooo`0000001@3oool2000000H0oooo00<000000?ooo`3oool0103oool2000000H0
oooo0P0000050?ooo`8000001@3oool3000000D0oooo00<000000?ooo`0000000`3oool00`000000
oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`020?ooo`030000003oool0000000D0oooo
0P00000[0?ooo`8000001@3oool2000000030?ooo`000000oooo0080oooo00<000000?ooo`000000
C@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool3000002/0
oooo0P0000050?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool07@3oool006T0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0000000h0?ooo`0405EEE@0000000000000000@0
oooo00<000000?ooo`000000C@3oool01`000000oooo0?ooo`3oool000000?ooo`000000>P3oool0
0`000000oooo000000030?ooo`030000003oool0oooo01d0oooo001Y0?ooo`030000003oool0oooo
0080oooo0P00000k0?ooo`800000103oool00`000000oooo0000001=0?ooo`030000003oool0oooo
0080oooo0P00000j0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool07@3oool006T0
oooo00<000000?ooo`3oool00P3oool2000003/0oooo0P0000040?ooo`040000003oool000000000
04`0oooo00<000000?ooo`3oool00P3oool2000003/0oooo00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0M0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0
oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo
0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo
0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<0
00000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L
0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?oo
o`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00
J@3oool00`000000oooo0?ooo`150?ooo`040000003oool00000000004`0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000
003oool0000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3o
ool00`000000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A@3o
ool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`150?ooo`030000003oool0
000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`00
0000oooo0?ooo`150?ooo`030000003oool0000004d0oooo00<000000?ooo`3oool0A@3oool00`00
0000oooo0?ooo`0L0?ooo`00J@3oool00`000000oooo0?ooo`160?ooo`800000C@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo04H0oooo
0`00001<0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0703oool006T0oooo00<0
00000?ooo`3oool0AP3oool2000004d0oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?oo
o`0L0?ooo`00J@3oool00`000000oooo0?ooo`160?ooo`800000C@3oool00`000000oooo0?ooo`15
0?ooo`030000003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo04H0oooo0P00001=0?oo
o`030000003oool0oooo04D0oooo00<000000?ooo`3oool0703oool006T0oooo00<000000?ooo`3o
ool0AP3oool2000004`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00
J@3oool00`000000oooo0?ooo`160?ooo`800000C03oool00`000000oooo0?ooo`160?ooo`030000
003oool0oooo01`0oooo001Y0?ooo`030000003oool0oooo04H0oooo0P00001<0?ooo`030000003o
ool0oooo04H0oooo00<000000?ooo`3oool0703oool006T0oooo00<000000?ooo`3oool0AP3oool3
000004/0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J@3oool00`00
0000oooo0?ooo`160?ooo`800000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo
01`0oooo001X0?ooo`030000003oool0oooo04L0oooo0P00001<0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0703oool006P0oooo00<000000?ooo`3oool0A`3oool2000004`0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?ooo`00J03oool00`000000oooo0?oo
o`0]0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A4000000000000
<c<c0=gMg@040?ooo`800000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0
oooo001X0?ooo`030000003oool0oooo02d0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`80
8R8R203oool00`1gMgL0<c<c0?ooo`030?ooo`800000C03oool00`000000oooo0?ooo`160?ooo`03
0000003oool0oooo01`0oooo001X0?ooo`030000003oool0oooo02D0oooo1P0000020?ooo`05014A
4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`020?ooo`@00000BP3oool00`000000
oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`030000003oool0oooo02d0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00<0oooo0P00001<0?ooo`03
0000003oool0oooo04H0oooo00<000000?ooo`3oool0703oool006P0oooo00<000000?ooo`3oool0
;@3oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0040?oo
o`800000C03oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo01`0oooo001X0?ooo`03
0000003oool0oooo02d0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo
00H0oooo0P00001<0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0703oool006P0
oooo00<000000?ooo`3oool0;@3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?oo
o`3oool01P3oool2000004`0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`0L0?oo
o`00J03oool00`000000oooo0?ooo`0]0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool40000
00D0oooo0P00001<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0
oooo00<000000?ooo`3oool0A`3oool2000004`0oooo00<000000?ooo`3oool0A`3oool00`000000
oooo0?ooo`0K0?ooo`00J03oool00`000000oooo0?ooo`170?ooo`<00000B`3oool00`000000oooo
0?ooo`170?ooo`030000003oool0oooo01/0oooo001X0?ooo`030000003oool0oooo04L0oooo0P00
001<0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04L0oooo00<00000
0?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3o
ool06`3oool006P0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`1:0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool06`3oool006P0oooo00<000000?ooo`3oool0B03o
ool2000004/0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00J03oool0
0`000000oooo0?ooo`180?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0A`3oool0
0`000000oooo0?ooo`0K0?ooo`00I`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
04X0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0K0?ooo`00I`3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B03oool00`000000
oooo0?ooo`0K0?ooo`00I`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0B03oool00`000000oooo0?ooo`0K0?ooo`00I`3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B03oool00`000000oooo0?oo
o`0K0?ooo`00I`3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<00000
0?ooo`3oool0B03oool00`000000oooo0?ooo`0K0?ooo`007@3oool400000003014A4@3oool0oooo
03`0oooo00D0k^k^03<c<`000000<c<c0>k^kP020?ooo`030000003oool0oooo00808R8R1@3oool0
1@14A4@000000000000c<c<0gMgM03d0oooo0P00000o0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
1@3oool00`0R8R8000000?ooo`040?ooo`0504A4A0000000000003<c<`3MgMd0?`3oool400000003
014A4@3oool0oooo01P0oooo000O0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`020?ooo`030000003oool0oooo00808R8R203oool00`1gMgL0<c<c0?ooo`0l0?ooo`03
0000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`03028R8P000000oooo
00L0oooo00<0MgMg03<c<`3oool0?`3oool2000001`0oooo000D0?ooo`H000001@3oool00`000000
oooo0?ooo`0f0?ooo`H000000P3oool01@0A4A40oooo0?ooo`3oool04A4A0080oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03h0oooo00D04A4A0?oo
o`3oool0oooo014A4@060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?P3oool2
000001`0oooo000O0?ooo`030000003oool0oooo03h0oooo00D000000?ooo`3oool0oooo00000002
0?ooo`030000003oool0oooo00X0oooo00<0MgMg03<c<`3oool0?03oool00`000000oooo0?ooo`0n
0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000oooo0?ooo`060?ooo`0307MgM`0c
<c<0oooo03l0oooo0P00000L0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0
oooo0?ooo`0000000P3oool00`000000oooo0?ooo`070?ooo`050000000R8R80000003<c<`3<c<`0
?@3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`0000001P3oool00`000000
oooo0?ooo`030?ooo`050000000R8R80000003<c<`3<c<`0@@3oool00`000000oooo0?ooo`0J0?oo
o`007`3oool00`000000oooo0?ooo`0n0?ooo`05014A4@3oool0oooo0?ooo`0A4A400P3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool01@0A
4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`13
0?ooo`030000003oool0oooo01X0oooo000O0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`020?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0?`3oool0
0`000000oooo0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool06P3oool001d0oooo0P1EEED0
0`000000oooo0?ooo`0n0?ooo`050>k^kP0c<c<0000003<c<`3^k^h00P3oool00`000000oooo0?oo
o`070?ooo`@00000?P3oool2000003l0oooo00D0k^k^03<c<`000000<c<c0>k^kP060?ooo`030000
003oool0oooo00<0oooo100000100?ooo`80EEEE00<000000?ooo`3oool06P3oool006L0oooo00<0
00000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<0
00000?ooo`3oool06P3oool006L0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool06P3oool006L0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool06P3oool006L0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`03
0000003oool0oooo04T0oooo00<000000?ooo`3oool06P3oool006L0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
6P3oool001@0ooooo`000010000001D0oooo000K0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo06H0oooo000K0?ooo`030000
003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000
003oool0oooo06H0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3o
ool00`000000oooo0?ooo`190?ooo`030000003oool0oooo06H0oooo000K0?ooo`030000003oool0
oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0
oooo06H0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool20000
04X0oooo00<000000?ooo`3oool0IP3oool001/0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0IP3oool001/0oooo
00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo
00<000000?ooo`3oool0IP3oool001/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?oo
o`190?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0I`3oool001/0oooo00<00000
0?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04P0oooo00<00000
0?ooo`3oool0I`3oool001/0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?oo
o`030000003oool0oooo04P0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`190?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00
703oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo0P0000190?ooo`030000
003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3o
ool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0B03oool0
0`000000oooo0?ooo`190?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`00
0000oooo0?ooo`180?ooo`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo
06L0oooo000L0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0
oooo00<000000?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0B03oool00`000000oooo
0?ooo`190?ooo`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?oo
o`180?ooo`030000003oool0oooo04T0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L
0?ooo`030000003oool0oooo04P0oooo00<000000?ooo`3oool0B@3oool2000004T0oooo00<00000
0?ooo`3oool0I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?oo
o`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo04X0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000
003oool0oooo04L0oooo00<000000?ooo`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0
I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3o
ool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000003oool0
oooo04X0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo
04L0oooo00<000000?ooo`3oool0BP3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0
oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`1:0?ooo`800000B@3oool00`000000
oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo04X0oooo
0P0000190?ooo`030000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0oooo00<0
00000?ooo`3oool0;`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd01@3oool2000004T0oooo00<000000?ooo`3oool0I`3oool001`0oooo
00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0_0?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool2000004T0oooo00<000000?ooo`3o
ool0I`3oool001`0oooo00<000000?ooo`3oool0A`3oool00`000000oooo0?ooo`0_0?ooo`05014A
4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`030?ooo`800000B@3oool00`000000
oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`030000003oool0oooo02l0oooo
00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00@0oooo0`0000180?ooo`03
0000003oool0oooo06L0oooo000L0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
;`3oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0050?oo
o`800000B@3oool00`000000oooo0?ooo`1W0?ooo`00703oool00`000000oooo0?ooo`170?ooo`03
0000003oool0oooo02l0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo
00L0oooo0P0000190?ooo`030000003oool0oooo06L0oooo000M0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0;`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?oo
o`3oool01`3oool2000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`0_0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool40000
00H0oooo0P0000180?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04H0
oooo00<000000?ooo`3oool0BP3oool2000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`800000B03oool00`000000oooo
0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo0P00
00180?ooo`030000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04H0oooo00<00000
0?ooo`3oool0BP3oool2000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?oo
o`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`800000B03oool00`000000oooo0?ooo`1X0?oo
o`007@3oool00`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo0P0000180?ooo`03
0000003oool0oooo06P0oooo000M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0
BP3oool2000004P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0AP3o
ool00`000000oooo0?ooo`1:0?ooo`800000B03oool00`000000oooo0?ooo`1X0?ooo`007@3oool0
0`000000oooo0?ooo`160?ooo`030000003oool0oooo04X0oooo0P0000180?ooo`030000003oool0
oooo06P0oooo000M0?ooo`030000003oool0oooo04H0oooo00<000000?ooo`3oool0BP3oool20000
04P0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0AP3oool00`000000
oooo0?ooo`1:0?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo
00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0000004L0oooo
00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?oo
o`1:0?ooo`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<00000
0?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0000004L0oooo00<00000
0?ooo`3oool0J03oool001d0oooo00<000000?ooo`3oool0AP3oool00`000000oooo0?ooo`1:0?oo
o`030000003oool0000004L0oooo00<000000?ooo`3oool0J03oool001d0oooo00<000000?ooo`3o
ool0AP3oool00`000000oooo0?ooo`1:0?ooo`<00000A`3oool00`000000oooo0?ooo`1X0?ooo`00
7@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000
A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`030000003o
ool0oooo04/0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool0
0`000000oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000A`3oool0
0`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`150?ooo`030000003oool0oooo
04/0oooo00<000000?ooo`000000A`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000
oooo0?ooo`150?ooo`030000003oool0oooo04/0oooo00<000000?ooo`000000A`3oool00`000000
oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03X0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`1;0?ooo`<00000103oool2000003/0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1X0?ooo`007@3oool00`000000oooo0?oo
o`020?ooo`<00000>P3oool2000000@0oooo00<000000?ooo`3oool0B`3oool00`000000oooo0000
00040?ooo`800000>`3oool2000000@0oooo00<000000?ooo`3oool0J03oool001h0oooo00L00000
0?ooo`3oool0oooo0000003oool0000003X0oooo0P0000040?ooo`030000003oool0oooo04/0oooo
00<000000?ooo`000000103oool00`000000oooo0000000i0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool0J03oool001h0oooo00L000000?ooo`3oool0oooo0000003oool0000000D0
oooo0P00000/0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool00`00
0000oooo0?ooo`1;0?ooo`030000003oool0000000@0oooo00<000000?ooo`0000001@3oool20000
02/0oooo0P0000050?ooo`030000003oool0000000@0oooo00<000000?ooo`3oool0J03oool001h0
oooo00L000000?ooo`3oool0oooo0000003oool0000000D0oooo0P0000060?ooo`800000703oool2
000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo0440oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0000000<0oooo00@0
00000?ooo`3oool00000103oool00`000000oooo000000050?ooo`8000007@3oool00`000000oooo
0?ooo`040?ooo`<00000103oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo06P0
oooo000N0?ooo`070000003oool0oooo0?ooo`000000oooo000000040?ooo`040000003oool0oooo
000000@0oooo00<000000?ooo`0000001@3oool3000000@0oooo0`0000050?ooo`<00000103oool3
000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000030?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool01@3oool00`000000oooo000000030?ooo`040000003o
ool0oooo000000@0oooo00<000000?ooo`0000001@3oool00`000000oooo000000040?ooo`<00000
1@3oool3000000@0oooo0`0000050?ooo`030000003oool0000000@0oooo0P0000000`3oool00000
0?ooo`030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0J03oool001h0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`030000003oool0
000000D0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`0000040?ooo`040000003o
ool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool010000000oooo0?ooo`0000040?oo
o`030000003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`00
00030?ooo`80000000<0oooo0000003oool00`3oool010000000oooo0?ooo`0000040?ooo`030000
003oool0000000@0oooo00@000000?ooo`3oool00000103oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo06P0oooo000N0?ooo`040000003oool0oooo000000<0oooo00D000000?oo
o`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D000000?ooo`3oool0oooo
000000030?ooo`040000003oool0oooo000000<0oooo0P0000020?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00030?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`050?ooo`<000000`3oool01@000000oooo0?ooo`3oool000000080oooo00D000000?ooo`3o
ool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000000`3oool010000000oooo0?ooo`00
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool01@000000oooo0?ooo`3oool0000000<0
oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000006/0oooo000N0?ooo`040000003oool0
oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`000000103oool4000000@0oooo00<000000?ooo`0000001@3oool00`000000
oooo000000040?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3oool000000`3oool0
1@000000oooo0?ooo`3oool0000004D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0000
00030?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000
003oool0000000@0oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0000000D0oooo
00<000000?ooo`000000103oool010000000oooo0000000000040?ooo`030000003oool0000000@0
oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`00001[0?ooo`007P3oool01000
0000oooo0?ooo`0000040?ooo`030000003oool0000000@0oooo0`0000050?ooo`<000001@3oool2
000000H0oooo0P0000050?ooo`8000001@3oool3000000@0oooo00@000000?ooo`3oool00000103o
ool010000000oooo0?ooo`0000150?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
0`3oool01`000000oooo0?ooo`3oool000000?ooo`0000001@3oool00`000000oooo000000050?oo
o`8000001P3oool2000000D0oooo0P0000060?ooo`8000001@3oool00`000000oooo000000040?oo
o`040000003oool0oooo000000<0oooo00@000000?ooo`3oool00000J`3oool001h0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo000000050?ooo`800000903oool2000000D0oooo00<0
00000?ooo`000000103oool010000000oooo0?ooo`0000150?ooo`030000003oool0oooo00D0oooo
00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`020?ooo`8000001P3oool00`000000
oooo0?ooo`0S0?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`040000003oool0oooo0000
06/0oooo000N0?ooo`040000003oool0oooo000000@0oooo0P00000c0?ooo`<00000103oool01000
0000oooo0?ooo`0000130?ooo`80EEEE00<000000?ooo`3oool01@3oool010000000oooo0?ooo`00
00020?ooo`030000003oool0oooo0080oooo0P00000c0?ooo`8000001@3oool00`000000oooo0000
001[0?ooo`007P3oool010000000oooo0?ooo`0000100?ooo`040000003oool0oooo000004d0oooo
00H000000?ooo`3oool000000?ooo`0000110?ooo`030000003oool0000006/0oooo000N0?ooo`03
0000003oool000000440oooo00<000000?ooo`000000CP3oool2000000040?ooo`000000oooo0000
0440oooo00<000000?ooo`000000J`3oool001h0oooo00<000000?ooo`000000@@3oool00`000000
oooo0000001>0?ooo`060000003oool0oooo0000003oool00000@@3oool00`000000oooo0000001[
0?ooo`007P3oool00`000000oooo000000110?ooo`030000003oool0000004h0oooo00H000000?oo
o`3oool000000?ooo`0000110?ooo`030000003oool0000006/0oooo000O0?ooo`800000@P3oool2
000004h0oooo00H000000?ooo`3oool000000?ooo`0000110?ooo`030000003oool0000006/0oooo
000O0?ooo`800000@P3oool2000004h0oooo00<000000?ooo`3oool00P0000120?ooo`030000003o
ool0000006/0oooo000O0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool0C@3oool0
0`000000oooo0?ooo`02000004<0oooo00<000000?ooo`3oool0JP3oool00;<0oooo00D000000?oo
o`3oool0oooo0000002`0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`80
0000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3o
ool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00
002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`2b0?ooo`00
V`3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000
003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c<c<0
oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R800000
03<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2l0?oo
o`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo002I0?ooo`80EEEE
00<000000?ooo`3oool02`3oool400000;/0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo002M0?ooo`80000000H04A4A0?ooo`3oool04A4A0000000A4A4G0?ooo`D000000`3oool0
1@3^k^h0<c<c0000000c<c<0k^k^09l0oooo002N0?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool01`3oool6000000T0oooo00D0VIVI028R8P3^k^h0oooo04A4A0030?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL0W`3oool009h0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`0G0?ooo`0309VIV@0R8R80k^k^00@0oooo00D04A4A0?ooo`3oool0oooo014A4@2O0?ooo`00WP3o
ool01P000000oooo04A4A00c<c<0oooo000000T0oooo1P00000;0?ooo`0309VIV@0R8R80k^k^00<0
oooo00D000000?ooo`3oool0oooo0000002O0?ooo`00WP3oool01P000000gMgM03<c<`1EEED0gMgM
000001/0oooo00<0MgMg06IVIP3oool00P3oool01@000000oooo0?ooo`3oool0000009l0oooo002N
0?ooo`0600000028R8P0ZZZZ0;^k^`1EEED00000703oool01@000000oooo0?ooo`3oool04A4A00<0
oooo00<04A4A0?ooo`3oool0W@3oool009h0oooo00H0000003<c<`3oool0oooo03<c<`00000H0?oo
o`050000002k^k/0oooo09VIV@0A4A400`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg09l0oooo002M
0?ooo`03014A4@000000R8R80080oooo00<0R8R80000000A4A405`3oool01@2IVIT04A4A0000000R
8R80c<c<00<0oooo00D0k^k^03<c<`000000<c<c0>k^kP2O0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell["\<\
The series is clearly not converging as well as for the triangle \
wave. The discontinuity in the square wave is difficult to represent using a \
superposition of smoothly varying Fourier modes. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.5 Uniform and Nonuniform Convergence", "Subsubtitle",
  CellTags->"c:7"],

Cell[TextData[{
  "\tIt is useful to consider the difference between the series approximation \
and the exact square wave as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases. This difference is evaluated and plotted in Cell ",
  ButtonBox["2.17",
    ButtonData:>"Cell 2.17",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(errorplot[M_]\  := \ \((a\  = \ f\_approx[t, M]; \ 
          Plot[a - f[t], {t, \(-0.5\), 0.5}, PlotRange \[Rule] {\(-1\), 1}, 
            PlotPoints \[Rule] 100  M, 
            PlotLabel \[Rule] "\<Error, M = \>" <> 
                ToString[M]])\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Table[errorplot[M], {M, 10, 50, 10}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.17"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.309017 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.02474 .60599 L
.02575 .59287 L
.0267 .58059 L
.02761 .56882 L
.02859 .55635 L
.02952 .54443 L
.03052 .53187 L
.03148 .51988 L
.0324 .50846 L
.03338 .49646 L
.03433 .48506 L
.03524 .47426 L
.03621 .46294 L
.03714 .45224 L
.03813 .44108 L
.03908 .43056 L
.04 .42066 L
.04098 .41037 L
.04192 .40072 L
.04292 .39075 L
.04388 .38143 L
.0448 .37274 L
.04579 .36379 L
.04674 .35548 L
.04765 .34778 L
.04862 .3399 L
.04956 .33263 L
.05055 .32524 L
.05151 .31846 L
.05243 .31225 L
.05341 .30599 L
.05435 .3003 L
.05526 .29514 L
.05622 .28999 L
.05715 .28536 L
.05814 .28079 L
.05909 .27673 L
.06001 .27314 L
.06098 .26965 L
.06192 .26662 L
.06292 .26375 L
.06388 .26131 L
.0648 .25926 L
.06579 .2574 L
.06673 .25591 L
.06764 .25476 L
.06815 .25423 L
.06861 .25381 L
.0691 .25345 L
Mistroke
.06954 .25318 L
.07 .25296 L
.07026 .25287 L
.0705 .2528 L
.07074 .25274 L
.07087 .25272 L
.07099 .2527 L
.0711 .25269 L
.07116 .25268 L
.07121 .25268 L
.07127 .25268 L
.0713 .25268 L
.07133 .25268 L
.07136 .25268 L
.07138 .25267 L
.07141 .25267 L
.07144 .25267 L
.07147 .25267 L
.0715 .25268 L
.07153 .25268 L
.07156 .25268 L
.07161 .25268 L
.07167 .25268 L
.07173 .25269 L
.07179 .25269 L
.07191 .25271 L
.07212 .25274 L
.07235 .25279 L
.07258 .25285 L
.07283 .25294 L
.07333 .25316 L
.0738 .25343 L
.0743 .25377 L
.0753 .25463 L
.07625 .25568 L
.07717 .25687 L
.07815 .25833 L
.07909 .25991 L
.08 .26158 L
.08097 .26351 L
.08189 .2655 L
.08288 .26775 L
.08383 .27003 L
.08475 .27232 L
.08572 .27486 L
.08666 .27737 L
.08766 .28011 L
.08862 .28281 L
.08954 .28545 L
.09052 .28829 L
Mistroke
.09147 .29104 L
.09238 .29369 L
.09334 .29651 L
.09428 .29921 L
.09527 .30206 L
.09622 .30477 L
.09714 .30733 L
.09812 .31001 L
.09906 .31252 L
.10006 .31512 L
.10102 .31754 L
.10195 .31979 L
.10293 .32208 L
.10388 .32419 L
.10479 .32612 L
.10577 .32806 L
.1067 .32982 L
.10769 .33156 L
.10865 .3331 L
.10957 .33447 L
.11055 .33579 L
.1115 .33692 L
.1124 .33789 L
.11337 .33879 L
.1143 .33951 L
.11529 .34014 L
.11624 .34061 L
.11672 .34079 L
.11716 .34093 L
.11763 .34104 L
.11789 .34109 L
.11813 .34113 L
.11837 .34116 L
.11848 .34117 L
.11861 .34118 L
.11872 .34118 L
.11879 .34118 L
.11884 .34119 L
.1189 .34119 L
.11893 .34119 L
.11895 .34119 L
.11898 .34119 L
.119 .34119 L
.11903 .34119 L
.11906 .34119 L
.11909 .34119 L
.11912 .34119 L
.11914 .34119 L
.11917 .34119 L
.11923 .34119 L
Mistroke
.11929 .34118 L
.11941 .34118 L
.11954 .34117 L
.11977 .34115 L
.11999 .34113 L
.12044 .34105 L
.12093 .34093 L
.1214 .34079 L
.1219 .34061 L
.12289 .34014 L
.12384 .33957 L
.12476 .33892 L
.12574 .33811 L
.12668 .33722 L
.12767 .33617 L
.12864 .33506 L
.12956 .3339 L
.13055 .33259 L
.1315 .33124 L
.13241 .32988 L
.13338 .32837 L
.13431 .32686 L
.13531 .32519 L
.13626 .32355 L
.13718 .32193 L
.13816 .32017 L
.13911 .31846 L
.14001 .3168 L
.14098 .31502 L
.14191 .31331 L
.1429 .31149 L
.14385 .30975 L
.14476 .30809 L
.14574 .30635 L
.14667 .30471 L
.14767 .303 L
.14863 .3014 L
.14955 .29991 L
.15054 .29838 L
.15148 .29696 L
.15239 .29565 L
.15336 .29434 L
.15429 .29314 L
.15529 .29194 L
.15624 .29088 L
.15716 .28993 L
.15814 .28901 L
.15908 .28821 L
.16008 .28746 L
.16104 .28684 L
Mistroke
.16197 .28633 L
.16295 .28588 L
.1639 .28556 L
.16438 .28543 L
.16482 .28533 L
.16529 .28525 L
.16555 .28522 L
.16579 .28519 L
.16602 .28517 L
.16614 .28516 L
.16627 .28516 L
.16638 .28515 L
.16644 .28515 L
.1665 .28515 L
.16655 .28515 L
.16658 .28515 L
.1666 .28515 L
.16663 .28515 L
.16665 .28515 L
.16668 .28515 L
.16671 .28515 L
.16674 .28515 L
.16677 .28515 L
.1668 .28515 L
.16682 .28515 L
.16689 .28515 L
.16695 .28515 L
.16706 .28516 L
.16719 .28516 L
.16742 .28518 L
.16764 .2852 L
.16808 .28526 L
.16858 .28534 L
.16904 .28545 L
.16954 .28558 L
.17053 .28593 L
.17148 .28635 L
.1724 .28684 L
.17337 .28744 L
.17431 .2881 L
.1753 .28889 L
.17626 .28973 L
.17718 .2906 L
.17817 .29159 L
.17911 .29262 L
.18002 .29365 L
.18099 .29481 L
.18192 .29597 L
.18291 .29725 L
.18387 .29852 L
Mistroke
.18478 .29978 L
.18576 .30114 L
.1867 .30248 L
.1877 .30391 L
.18866 .30531 L
.18959 .30666 L
.19057 .3081 L
.19152 .30948 L
.19244 .31079 L
.19341 .31218 L
.19434 .31349 L
.19534 .31486 L
.19629 .31614 L
.19721 .31735 L
.19819 .31859 L
.19914 .31974 L
.20004 .3208 L
.20101 .32187 L
.20194 .32285 L
.20293 .32383 L
.20388 .3247 L
.2048 .32549 L
.20577 .32625 L
.20671 .32691 L
.20771 .32753 L
.20867 .32805 L
.20959 .32848 L
.21057 .32885 L
.21152 .32912 L
.212 .32923 L
.21243 .32931 L
.2129 .32938 L
.21316 .32941 L
.2134 .32943 L
.21363 .32945 L
.21376 .32945 L
.21388 .32946 L
.21399 .32946 L
.21405 .32946 L
.21411 .32946 L
.21416 .32947 L
.21418 .32947 L
.21421 .32947 L
.21424 .32947 L
.21426 .32947 L
.21429 .32947 L
.21432 .32947 L
.21435 .32947 L
.21438 .32947 L
.2144 .32947 L
Mistroke
.21443 .32947 L
.21449 .32946 L
.21455 .32946 L
.21467 .32946 L
.2148 .32945 L
.21503 .32944 L
.21524 .32943 L
.21573 .32937 L
.21618 .32931 L
.21714 .3291 L
.21807 .32883 L
.21905 .32846 L
.22 .32802 L
.22091 .32754 L
.22188 .32695 L
.22282 .32631 L
.22381 .32556 L
.22477 .32478 L
.22569 .32397 L
.22667 .32304 L
.22761 .3221 L
.22852 .32115 L
.22948 .32009 L
.23041 .31903 L
.2314 .31787 L
.23235 .31671 L
.23326 .31558 L
.23424 .31434 L
.23518 .31314 L
.23617 .31184 L
.23713 .31058 L
.23806 .30937 L
.23904 .30808 L
.23998 .30685 L
.24089 .30567 L
.24186 .30443 L
.24279 .30326 L
.24379 .30204 L
.24474 .30089 L
.24566 .29982 L
.24664 .29872 L
.24758 .2977 L
.24858 .29667 L
.24954 .29573 L
.25047 .29488 L
.25145 .29403 L
.2524 .29328 L
.25331 .29261 L
.25429 .29197 L
.25522 .29142 L
Mistroke
.25621 .2909 L
.25717 .29048 L
.25809 .29015 L
.25907 .28987 L
.25956 .28977 L
.26002 .28968 L
.26046 .28962 L
.26093 .28957 L
.26116 .28956 L
.26129 .28955 L
.26141 .28954 L
.26154 .28954 L
.26161 .28954 L
.26167 .28953 L
.26173 .28953 L
.26179 .28953 L
.26182 .28953 L
.26183 .28953 L
.26185 .28953 L
.26188 .28953 L
.2619 .28953 L
.26192 .28953 L
.26195 .28953 L
.26198 .28953 L
.262 .28953 L
.26203 .28953 L
.26209 .28953 L
.26215 .28953 L
.26226 .28954 L
.26237 .28954 L
.2625 .28955 L
.26261 .28955 L
.26287 .28957 L
.26312 .2896 L
.26336 .28962 L
.26381 .28969 L
.26473 .28987 L
.26571 .29015 L
.26666 .29049 L
.26757 .29089 L
.26853 .29138 L
.26947 .29193 L
.27046 .29258 L
.27141 .29328 L
.27233 .29401 L
.2733 .29484 L
.27424 .29571 L
.27524 .29668 L
.2762 .29767 L
.27713 .29867 L
Mistroke
.27812 .29978 L
.27906 .30088 L
.27998 .30198 L
.28095 .30317 L
.28188 .30434 L
.28288 .30561 L
.28383 .30685 L
.28475 .30806 L
.28573 .30934 L
.28668 .31058 L
.28758 .31177 L
.28855 .31303 L
.28948 .31422 L
.29047 .31548 L
.29142 .31666 L
.29233 .31777 L
.29331 .31893 L
.29425 .32 L
.29524 .32109 L
.2962 .3221 L
.29713 .32303 L
.29811 .32395 L
.29906 .32479 L
.29997 .32554 L
.30094 .32627 L
.30187 .32691 L
.30286 .32752 L
.30381 .32803 L
.30473 .32845 L
.30571 .32882 L
.30665 .3291 L
.30713 .32921 L
.30765 .32931 L
.30815 .32938 L
.30839 .32941 L
.30862 .32943 L
.30883 .32944 L
.30895 .32945 L
.30907 .32946 L
.30914 .32946 L
.3092 .32946 L
.30926 .32946 L
.30933 .32946 L
.30936 .32946 L
.30939 .32947 L
.30941 .32947 L
.30944 .32947 L
.30947 .32947 L
.30949 .32947 L
.30951 .32947 L
Mistroke
.30954 .32947 L
.30957 .32947 L
.3096 .32947 L
.30961 .32947 L
.30963 .32947 L
.30966 .32947 L
.30969 .32946 L
.30976 .32946 L
.30981 .32946 L
.30995 .32946 L
.31008 .32945 L
.31031 .32944 L
.31056 .32942 L
.31104 .32936 L
.31154 .32928 L
.31245 .32908 L
.31341 .32878 L
.31434 .32842 L
.31533 .32795 L
.31628 .32742 L
.3172 .32684 L
.31817 .32615 L
.31911 .32541 L
.3201 .32455 L
.32106 .32365 L
.32198 .32273 L
.32297 .32169 L
.32391 .32063 L
.32482 .31956 L
.32579 .31837 L
.32672 .31719 L
.32771 .31588 L
.32867 .3146 L
.32959 .31333 L
.33056 .31195 L
.3315 .31061 L
.3325 .30916 L
.33346 .30776 L
.33439 .30641 L
.33538 .30498 L
.33633 .3036 L
.33724 .30229 L
.33821 .30092 L
.33914 .29961 L
.34014 .29826 L
.3411 .29699 L
.34202 .29581 L
.343 .29459 L
.34394 .29347 L
.34485 .29245 L
Mistroke
.34581 .29142 L
.34674 .29048 L
.34773 .28956 L
.34869 .28874 L
.3496 .28803 L
.35058 .28735 L
.35151 .28678 L
.35251 .28626 L
.35347 .28585 L
.3544 .28554 L
.35487 .28542 L
.35538 .28531 L
.35562 .28527 L
.35587 .28524 L
.35611 .28521 L
.35633 .28518 L
.35657 .28517 L
.3567 .28516 L
.35677 .28516 L
.35684 .28515 L
.35691 .28515 L
.35697 .28515 L
.357 .28515 L
.35703 .28515 L
.35706 .28515 L
.35707 .28515 L
.35709 .28515 L
.35712 .28515 L
.35714 .28515 L
.35715 .28515 L
.35718 .28515 L
.35721 .28515 L
.35724 .28515 L
.35726 .28515 L
.35732 .28515 L
.35738 .28515 L
.35744 .28515 L
.35757 .28516 L
.35768 .28517 L
.35781 .28517 L
.35804 .28519 L
.35825 .28522 L
.35871 .28528 L
.35921 .28538 L
.3602 .28565 L
.36115 .286 L
.36206 .28644 L
.36303 .287 L
.36396 .28763 L
.36496 .28839 L
Mistroke
.36591 .28923 L
.36683 .29011 L
.36781 .29114 L
.36876 .29222 L
.36966 .29332 L
.37063 .29458 L
.37156 .29585 L
.37254 .29728 L
.3735 .29872 L
.37441 .30016 L
.37539 .30174 L
.37632 .30332 L
.37732 .30503 L
.37828 .30672 L
.3792 .30837 L
.38019 .31016 L
.38113 .31189 L
.38204 .31356 L
.38301 .31535 L
.38394 .31707 L
.38493 .31888 L
.38589 .32061 L
.38681 .32225 L
.38778 .32396 L
.38873 .32557 L
.38973 .32723 L
.39069 .32878 L
.39162 .33021 L
.3926 .33166 L
.39355 .33298 L
.39446 .33418 L
.39544 .33537 L
.39637 .33643 L
.39737 .33745 L
.39832 .33833 L
.39925 .33907 L
.40023 .33974 L
.40117 .34027 L
.40208 .34067 L
.40258 .34085 L
.40305 .34098 L
.4035 .34107 L
.40373 .34111 L
.40398 .34114 L
.4041 .34116 L
.40422 .34117 L
.40433 .34118 L
.40445 .34118 L
.40451 .34118 L
.40457 .34119 L
Mistroke
.4046 .34119 L
.40463 .34119 L
.40466 .34119 L
.40469 .34119 L
.40471 .34119 L
.40472 .34119 L
.40475 .34119 L
.40477 .34119 L
.40479 .34119 L
.4048 .34119 L
.40482 .34119 L
.40484 .34119 L
.40486 .34119 L
.40489 .34119 L
.40492 .34119 L
.40495 .34119 L
.40501 .34118 L
.40507 .34118 L
.4052 .34117 L
.40532 .34117 L
.40544 .34116 L
.40565 .34113 L
.40589 .3411 L
.40635 .341 L
.40686 .34087 L
.40785 .34049 L
.4088 .33998 L
.40972 .33936 L
.41069 .33856 L
.41163 .33766 L
.41263 .33655 L
.4136 .33535 L
.41452 .33406 L
.41551 .33255 L
.41646 .33098 L
.41737 .32934 L
.41834 .32749 L
.41927 .32558 L
.42027 .32345 L
.42123 .32129 L
.42215 .31911 L
.42313 .31671 L
.42407 .31431 L
.42498 .31193 L
.42594 .30933 L
.42687 .30677 L
.42786 .304 L
.42881 .30129 L
.42973 .29865 L
.4307 .29582 L
Mistroke
.43164 .29308 L
.43264 .29018 L
.4336 .28739 L
.43452 .28473 L
.43551 .28193 L
.43645 .27929 L
.43736 .2768 L
.43833 .27421 L
.43926 .27181 L
.44026 .26935 L
.44121 .26709 L
.44213 .26503 L
.44311 .26297 L
.44405 .26112 L
.44505 .25933 L
.44601 .25778 L
.44694 .25646 L
.44793 .25525 L
.44888 .25429 L
.44979 .25357 L
.4503 .25326 L
.45076 .25303 L
.45099 .25294 L
.45124 .25285 L
.45148 .25279 L
.4517 .25274 L
.45182 .25272 L
.45193 .2527 L
.45205 .25269 L
.45211 .25268 L
.45218 .25268 L
.45224 .25268 L
.45227 .25268 L
.4523 .25268 L
.45233 .25267 L
.45236 .25267 L
.45239 .25267 L
.45242 .25267 L
.45245 .25268 L
.45248 .25268 L
.45251 .25268 L
.45255 .25268 L
.45262 .25268 L
.45268 .25269 L
.4528 .2527 L
.45292 .25271 L
.45314 .25275 L
.45338 .25281 L
.45364 .2529 L
.4541 .25309 L
Mistroke
.4546 .25338 L
.45559 .25416 L
.45654 .2552 L
.45746 .25647 L
.45843 .25813 L
.45937 .26002 L
.46036 .26236 L
.46132 .26495 L
.46225 .26774 L
.46323 .27105 L
.46417 .27456 L
.46508 .27826 L
.46605 .28252 L
.46698 .28696 L
.46798 .29203 L
.46893 .29726 L
.46985 .30261 L
.47083 .30865 L
.47177 .3148 L
.47277 .32169 L
.47373 .32868 L
.47466 .33571 L
.47564 .34353 L
.47659 .35138 L
.4775 .35922 L
.47847 .36788 L
.47941 .3765 L
.4804 .38597 L
.48136 .39538 L
.48228 .40469 L
.48326 .41487 L
.48421 .42492 L
.48511 .4348 L
.48608 .44556 L
.48701 .45612 L
.488 .46756 L
.48895 .47878 L
.48987 .48973 L
.49084 .50155 L
.49178 .51309 L
.49278 .52548 L
.49374 .53755 L
.49467 .54927 L
.49565 .56182 L
.4966 .57398 L
.49751 .58572 L
.49848 .59827 L
.49941 .61037 L
.49965 .61354 L
.49978 .61521 L
Mistroke
.49985 .61612 L
.49992 .61698 L
.49995 .61738 L
.49998 .6178 L
.5 .61802 L
.50002 .00023 L
.50003 .00045 L
.50005 .00066 L
.50017 .0022 L
.5004 .00522 L
.50134 .01736 L
.50233 .03025 L
.50329 .04263 L
.50422 .05448 L
.5052 .06702 L
.50614 .079 L
.50705 .09043 L
.50802 .10248 L
.50895 .11395 L
.50994 .126 L
.51089 .13743 L
.51181 .14826 L
.51279 .1596 L
.51373 .17032 L
.51473 .18147 L
.51569 .19199 L
.51661 .20187 L
.5176 .21213 L
.51855 .22175 L
.51946 .23074 L
.52043 .24003 L
.52136 .2487 L
.52236 .25759 L
.52332 .26585 L
.52424 .2735 L
.52522 .28131 L
.52616 .28852 L
.52707 .29514 L
.52803 .30186 L
.52896 .30801 L
.52995 .31419 L
.5309 .31981 L
.53182 .32489 L
.53279 .32995 L
.53373 .33449 L
.53472 .33896 L
.53568 .34292 L
.53661 .3464 L
.53759 .34977 L
.53854 .35268 L
Mistroke
.53945 .35519 L
.54042 .35753 L
.54135 .35948 L
.54234 .36124 L
.5433 .36263 L
.54421 .36368 L
.54473 .36416 L
.54519 .36452 L
.54568 .36483 L
.54613 .36505 L
.5466 .36521 L
.54684 .36527 L
.54697 .3653 L
.5471 .36532 L
.54721 .36534 L
.54732 .36535 L
.54738 .36535 L
.54744 .36536 L
.54747 .36536 L
.5475 .36536 L
.54753 .36536 L
.54755 .36536 L
.54757 .36536 L
.5476 .36536 L
.54762 .36536 L
.54765 .36536 L
.54768 .36536 L
.5477 .36536 L
.54771 .36536 L
.54774 .36536 L
.5478 .36536 L
.54785 .36535 L
.54791 .36535 L
.54801 .36534 L
.54813 .36532 L
.54824 .36531 L
.54848 .36526 L
.54871 .3652 L
.54892 .36513 L
.5494 .36493 L
.54984 .3647 L
.55078 .36403 L
.55169 .3632 L
.55265 .3621 L
.55358 .36085 L
.55457 .35934 L
.55552 .3577 L
.55643 .35598 L
.55741 .354 L
.55834 .35196 L
Mistroke
.55934 .34965 L
.5603 .34732 L
.56122 .34498 L
.56221 .3424 L
.56315 .33984 L
.56406 .33732 L
.56503 .33459 L
.56596 .33192 L
.56695 .32905 L
.56791 .32627 L
.56882 .3236 L
.5698 .32076 L
.57074 .31803 L
.57174 .31517 L
.5727 .31245 L
.57363 .30988 L
.57461 .3072 L
.57556 .30468 L
.57648 .30233 L
.57745 .29991 L
.57838 .29767 L
.57938 .29538 L
.58033 .29328 L
.58125 .29136 L
.58223 .28944 L
.58318 .2877 L
.58408 .28614 L
.58505 .28461 L
.58598 .28326 L
.58697 .28196 L
.58792 .28085 L
.58884 .27991 L
.58981 .27904 L
.59075 .27834 L
.59175 .27775 L
.59225 .27751 L
.59271 .27732 L
.59319 .27716 L
.59363 .27703 L
.59408 .27694 L
.59432 .27691 L
.59446 .27689 L
.59458 .27688 L
.59471 .27687 L
.59482 .27686 L
.59495 .27685 L
.59502 .27685 L
.59505 .27685 L
.59509 .27685 L
.59512 .27685 L
Mistroke
.59515 .27685 L
.59516 .27685 L
.59518 .27685 L
.59521 .27684 L
.59524 .27684 L
.59527 .27684 L
.59529 .27685 L
.59532 .27685 L
.59535 .27685 L
.59538 .27685 L
.59544 .27685 L
.5955 .27685 L
.59557 .27685 L
.5957 .27686 L
.59581 .27687 L
.59608 .2769 L
.59631 .27693 L
.59656 .27697 L
.59707 .27709 L
.59756 .27723 L
.59848 .2776 L
.59947 .27811 L
.60042 .27872 L
.60133 .27942 L
.6023 .28027 L
.60323 .28119 L
.60423 .28227 L
.60518 .28341 L
.6061 .28459 L
.60708 .28593 L
.60803 .28729 L
.60893 .28867 L
.6099 .29019 L
.61083 .29172 L
.61181 .29338 L
.61277 .29504 L
.61368 .29666 L
.61466 .29841 L
.61559 .30012 L
.61659 .30195 L
.61755 .30372 L
.61847 .30542 L
.61946 .30722 L
.6204 .30895 L
.62131 .31058 L
.62228 .3123 L
.62321 .31392 L
.6242 .31561 L
.62516 .31718 L
.62608 .31865 L
Mistroke
.62705 .32015 L
.62799 .32154 L
.62899 .32295 L
.62996 .32423 L
.63088 .32539 L
.63187 .32654 L
.63282 .32757 L
.63373 .32848 L
.6347 .32936 L
.63564 .33011 L
.63663 .33082 L
.63759 .33141 L
.63851 .33188 L
.63949 .33228 L
.63998 .33244 L
.64044 .33257 L
.64088 .33268 L
.64135 .33276 L
.64158 .3328 L
.64183 .33283 L
.64206 .33285 L
.64228 .33287 L
.6424 .33287 L
.64246 .33288 L
.64253 .33288 L
.64259 .33288 L
.64265 .33288 L
.64268 .33288 L
.64271 .33288 L
.64274 .33288 L
.64277 .33288 L
.6428 .33288 L
.64282 .33288 L
.64284 .33288 L
.64286 .33288 L
.64289 .33288 L
.64292 .33288 L
.64294 .33288 L
.64297 .33288 L
.643 .33288 L
.64305 .33288 L
.6431 .33288 L
.64321 .33288 L
.64334 .33287 L
.64347 .33286 L
.6437 .33285 L
.64394 .33282 L
.64415 .3328 L
.6446 .33272 L
.6451 .33262 L
Mistroke
.64606 .33235 L
.647 .33199 L
.64799 .33153 L
.64894 .33099 L
.64986 .33039 L
.65083 .32967 L
.65177 .32891 L
.65277 .32801 L
.65374 .32708 L
.65466 .32612 L
.65565 .32503 L
.65659 .32393 L
.65751 .32282 L
.65848 .32159 L
.65941 .32037 L
.66041 .31904 L
.66136 .31772 L
.66228 .31642 L
.66326 .31502 L
.66421 .31366 L
.66511 .31234 L
.66608 .31093 L
.66701 .30958 L
.668 .30815 L
.66895 .30678 L
.66987 .30548 L
.67084 .30412 L
.67178 .30283 L
.67277 .3015 L
.67374 .30026 L
.67466 .29911 L
.67564 .29793 L
.67659 .29684 L
.6775 .29584 L
.67847 .29484 L
.6794 .29394 L
.68039 .29305 L
.68135 .29226 L
.68227 .29157 L
.68324 .2909 L
.68419 .29034 L
.68519 .28983 L
.68615 .28941 L
.68708 .28909 L
.68755 .28895 L
.68806 .28883 L
.68856 .28873 L
.68901 .28866 L
.68948 .28861 L
.68974 .28859 L
Mistroke
.68986 .28859 L
.68998 .28858 L
.6901 .28857 L
.69022 .28857 L
.69028 .28857 L
.69034 .28857 L
.69037 .28857 L
.6904 .28857 L
.69041 .28857 L
.69043 .28857 L
.69046 .28857 L
.69049 .28857 L
.69052 .28857 L
.69055 .28857 L
.69057 .28857 L
.69058 .28857 L
.69064 .28857 L
.6907 .28857 L
.6908 .28857 L
.69091 .28858 L
.69103 .28858 L
.69115 .28859 L
.69142 .28861 L
.69165 .28863 L
.6919 .28866 L
.69237 .28873 L
.69281 .28881 L
.69373 .28904 L
.69472 .28937 L
.69567 .28976 L
.69659 .29021 L
.69756 .29077 L
.6985 .29137 L
.69949 .29208 L
.70045 .29283 L
.70138 .29362 L
.70236 .29452 L
.70331 .29543 L
.70422 .29636 L
.70518 .2974 L
.70612 .29844 L
.70711 .29959 L
.70806 .30074 L
.70898 .30186 L
.70996 .30309 L
.7109 .30429 L
.7119 .30558 L
.71286 .30684 L
.71378 .30806 L
.71477 .30935 L
Mistroke
.71572 .3106 L
.71663 .31178 L
.7176 .31303 L
.71854 .31422 L
.71953 .31546 L
.72049 .31662 L
.72141 .31771 L
.72239 .31883 L
.72334 .31987 L
.72424 .32083 L
.72521 .3218 L
.72614 .32268 L
.72713 .32357 L
.72808 .32436 L
.729 .32506 L
.72997 .32574 L
.73091 .32633 L
.73191 .32688 L
.73287 .32734 L
.73379 .32771 L
.73478 .32803 L
.73527 .32816 L
.73572 .32826 L
.73619 .32835 L
.73663 .32841 L
.73687 .32844 L
.73712 .32846 L
.73735 .32848 L
.73757 .32849 L
.73769 .32849 L
.73775 .3285 L
.73782 .3285 L
.73788 .3285 L
.73791 .3285 L
.73795 .3285 L
.73798 .3285 L
.73801 .3285 L
.73803 .3285 L
.73806 .3285 L
.73809 .3285 L
.73812 .3285 L
.73815 .3285 L
.73817 .3285 L
.7382 .3285 L
.73822 .3285 L
.73828 .3285 L
.73833 .3285 L
.7384 .3285 L
.73851 .32849 L
.73864 .32849 L
Mistroke
.73876 .32848 L
.73898 .32847 L
.73922 .32845 L
.73948 .32842 L
.73996 .32835 L
.74047 .32826 L
.74138 .32804 L
.74235 .32773 L
.74329 .32736 L
.74428 .32689 L
.74524 .32636 L
.74616 .32578 L
.74714 .3251 L
.74808 .32438 L
.74899 .32363 L
.74995 .32278 L
.75088 .3219 L
.75187 .32091 L
.75282 .31991 L
.75374 .3189 L
.75471 .31779 L
.75565 .31668 L
.75664 .31547 L
.7576 .31428 L
.75853 .31311 L
.75951 .31184 L
.76046 .31061 L
.76137 .30942 L
.76234 .30815 L
.76327 .30693 L
.76426 .30563 L
.76521 .30439 L
.76613 .30322 L
.76711 .30199 L
.76805 .30083 L
.76905 .29963 L
.77001 .29851 L
.77094 .29747 L
.77193 .29641 L
.77288 .29544 L
.77379 .29455 L
.77476 .29366 L
.7757 .29287 L
.77669 .29208 L
.77765 .2914 L
.77857 .2908 L
.77955 .29024 L
.7805 .28977 L
.78141 .28939 L
.78237 .28907 L
Mistroke
.7833 .28883 L
.78378 .28873 L
.78429 .28866 L
.78452 .28863 L
.78477 .28861 L
.785 .28859 L
.78521 .28858 L
.78532 .28857 L
.78539 .28857 L
.78545 .28857 L
.7855 .28857 L
.78555 .28857 L
.78558 .28857 L
.78561 .28857 L
.78564 .28857 L
.78567 .28857 L
.7857 .28857 L
.78573 .28857 L
.78576 .28857 L
.78578 .28857 L
.7858 .28857 L
.78583 .28857 L
.78586 .28857 L
.78593 .28857 L
.78599 .28857 L
.78605 .28857 L
.78617 .28858 L
.7863 .28858 L
.78641 .28859 L
.78668 .28861 L
.78692 .28863 L
.78717 .28866 L
.78763 .28873 L
.78807 .28882 L
.78901 .28906 L
.79 .28939 L
.79095 .2898 L
.79187 .29026 L
.79284 .29084 L
.79379 .29147 L
.79478 .29221 L
.79575 .293 L
.79667 .29383 L
.79766 .29478 L
.79861 .29575 L
.79952 .29675 L
.80049 .29786 L
.80143 .29898 L
.80242 .30022 L
.80338 .30145 L
Mistroke
.8043 .30268 L
.80528 .30402 L
.80622 .30533 L
.80713 .30662 L
.80809 .308 L
.80902 .30935 L
.81001 .31079 L
.81096 .31218 L
.81188 .31351 L
.81285 .31492 L
.81379 .31626 L
.81479 .31766 L
.81575 .31899 L
.81667 .32024 L
.81766 .32152 L
.8186 .32272 L
.81952 .32383 L
.82048 .32496 L
.82142 .326 L
.82241 .32703 L
.82336 .32796 L
.82428 .32879 L
.82526 .3296 L
.8262 .3303 L
.8272 .33096 L
.82817 .33151 L
.82909 .33195 L
.83008 .33233 L
.83057 .33249 L
.83103 .33261 L
.8315 .33271 L
.83194 .33278 L
.83218 .33281 L
.83243 .33284 L
.83267 .33286 L
.83288 .33287 L
.83299 .33288 L
.83305 .33288 L
.83311 .33288 L
.83317 .33288 L
.8332 .33288 L
.83323 .33288 L
.83325 .33288 L
.83328 .33288 L
.83331 .33288 L
.83333 .33288 L
.83336 .33288 L
.83339 .33288 L
.83341 .33288 L
.83342 .33288 L
Mistroke
.83345 .33288 L
.83348 .33288 L
.83351 .33288 L
.83357 .33288 L
.83363 .33288 L
.83369 .33288 L
.83383 .33287 L
.83394 .33286 L
.83406 .33286 L
.83427 .33284 L
.83453 .33281 L
.83477 .33277 L
.83522 .33269 L
.83572 .33258 L
.83669 .33228 L
.83763 .3319 L
.83863 .33139 L
.83959 .3308 L
.84051 .33014 L
.84149 .32935 L
.84244 .3285 L
.84335 .32759 L
.84432 .32654 L
.84525 .32546 L
.84624 .32422 L
.84719 .32295 L
.84811 .32166 L
.84909 .32022 L
.85003 .31878 L
.85103 .31719 L
.85199 .3156 L
.85292 .31402 L
.85391 .31231 L
.85485 .31063 L
.85577 .30899 L
.85674 .30722 L
.85767 .3055 L
.85867 .30367 L
.85963 .3019 L
.86055 .30021 L
.86153 .29842 L
.86247 .29672 L
.86338 .29511 L
.86435 .29343 L
.86528 .29186 L
.86627 .29024 L
.86722 .28873 L
.86813 .28734 L
.86911 .28593 L
.87005 .28464 L
Mistroke
.87105 .28336 L
.87201 .28222 L
.87293 .28122 L
.87392 .28025 L
.87486 .27942 L
.87577 .27872 L
.87674 .2781 L
.87768 .27761 L
.87815 .27741 L
.87867 .27722 L
.87917 .27707 L
.87962 .27697 L
.87985 .27693 L
.8801 .2769 L
.88023 .27688 L
.88036 .27687 L
.88048 .27686 L
.88054 .27686 L
.8806 .27685 L
.88066 .27685 L
.88073 .27685 L
.88078 .27685 L
.88081 .27685 L
.88084 .27685 L
.88086 .27685 L
.88089 .27685 L
.88092 .27684 L
.88094 .27684 L
.88097 .27684 L
.881 .27685 L
.88103 .27685 L
.88106 .27685 L
.88109 .27685 L
.88112 .27685 L
.88118 .27685 L
.88124 .27685 L
.8813 .27685 L
.88142 .27686 L
.88155 .27687 L
.88178 .2769 L
.88202 .27693 L
.88247 .27701 L
.88298 .27715 L
.88346 .27731 L
.88438 .27771 L
.88536 .27829 L
.8863 .27898 L
.88721 .27977 L
.88817 .28075 L
.8891 .28182 L
Mistroke
.89009 .2831 L
.89104 .28447 L
.89196 .2859 L
.89293 .28756 L
.89387 .28928 L
.89487 .29122 L
.89583 .29322 L
.89675 .29524 L
.89774 .29749 L
.89868 .29976 L
.89959 .30202 L
.90056 .30451 L
.90149 .30698 L
.90248 .30967 L
.90344 .31232 L
.90436 .31491 L
.90534 .31771 L
.90628 .32043 L
.90728 .32334 L
.90824 .32615 L
.90917 .32885 L
.91015 .3317 L
.9111 .33442 L
.91202 .33701 L
.91299 .3397 L
.91393 .34224 L
.91492 .34486 L
.91588 .34729 L
.9168 .34954 L
.91778 .35181 L
.91873 .35388 L
.91963 .35574 L
.9206 .35758 L
.92153 .35919 L
.92252 .36073 L
.92347 .36202 L
.92439 .36308 L
.92537 .364 L
.92631 .36467 L
.92682 .36494 L
.92705 .36505 L
.9273 .36514 L
.92753 .36521 L
.92778 .36527 L
.9279 .3653 L
.92801 .36532 L
.92812 .36533 L
.92823 .36534 L
.92829 .36535 L
.92836 .36535 L
Mistroke
.92838 .36535 L
.92842 .36536 L
.92844 .36536 L
.92847 .36536 L
.9285 .36536 L
.92852 .36536 L
.92854 .36536 L
.92856 .36536 L
.92858 .36536 L
.92859 .36536 L
.92861 .36536 L
.92863 .36536 L
.92864 .36536 L
.92868 .36536 L
.92871 .36536 L
.92874 .36536 L
.9288 .36535 L
.92886 .36535 L
.92897 .36534 L
.92909 .36532 L
.92922 .3653 L
.92947 .36525 L
.92969 .36518 L
.9302 .36499 L
.93066 .36474 L
.93116 .3644 L
.93215 .36351 L
.9331 .36236 L
.93401 .36098 L
.93498 .35921 L
.93591 .35721 L
.93691 .35475 L
.93787 .35206 L
.93879 .34915 L
.93977 .34573 L
.94071 .3421 L
.94162 .33831 L
.94258 .33393 L
.94351 .32939 L
.9445 .3242 L
.94545 .31886 L
.94637 .31341 L
.94735 .30726 L
.94828 .30102 L
.94928 .29402 L
.95024 .28694 L
.95117 .27981 L
.95215 .2719 L
.9531 .26397 L
.95401 .25605 L
Mistroke
.95498 .24732 L
.95591 .23862 L
.9569 .22908 L
.95786 .2196 L
.95878 .21023 L
.95975 .19999 L
.9607 .18989 L
.9617 .1789 L
.96266 .16808 L
.96359 .15747 L
.96457 .14597 L
.96553 .13471 L
.96644 .12372 L
.96741 .11186 L
.96835 .1003 L
.96934 .08788 L
.9703 .07579 L
.97122 .06407 L
.97221 .05152 L
.97315 .03936 L
.97406 .02763 L
.97503 .0151 L
.97596 .00302 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00ZOooool4o`000003oa0@4?oooooooooo0;Sooooo
002[ooooo`03o`000?oooooooooo0;[ooooo002Pooooo`Ko00001Oooool00ol0003oooooooooo`2j
ooooo`00Zoooool00ol0003oooooooooo`05ooooo`?o0000UOooool00ol0003oooooooooo`0Joooo
o`00Zoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Cooooo00?o0000oooooooo
ool06oooool00:_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Dooooo`03o`00
0?oooooooooo01_ooooo002[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0U?oo
ool00ol0003oooooooooo`0Kooooo`00ZOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool06oooool00;?ooooo0_l0002Eooooo`03o`000?oooooooooo
01_ooooo002cooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool06oooool00;?ooooo
00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0Kooooo`00/oooool2o`0009Gooooo00?o
0000ooooooooool06oooool00;?ooooo0_l0002Eooooo`03o`000?oooooooooo01_ooooo002coooo
o`;o0000UOooool00ol0003oooooooooo`0Kooooo`00/oooool2o`0009Gooooo00?o0000oooooooo
ool06oooool00;?ooooo0_l0002Eooooo`03o`000?oooooooooo01_ooooo002cooooo`;o0000UOoo
ool00ol0003oooooooooo`0Kooooo`00/oooool2o`0009Gooooo00?o0000ooooooooool06oooool0
0;?ooooo0_l0002Dooooo`03o`000?oooooooooo01cooooo002cooooo`;o0000U?ooool00ol0003o
ooooooooo`0Looooo`00/oooool2o`0009Cooooo00?o0000ooooooooool07?ooool00;?ooooo0_l0
002Dooooo`03o`000?oooooooooo01cooooo002cooooo`;o0000U?ooool00ol0003oooooooooo`0L
ooooo`00/oooool00ol0003oooooo`00002Cooooo`03o`000?oooooooooo01cooooo002cooooo`03
o`000?oooooo000009?ooooo00?o0000ooooooooool07?ooool0093ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooo`00002Cooooo`03o`000?oooooooooo01cooooo002@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooo000009?ooooo00?o0000ooooooooool07?ooool008So
oooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08oooo
o`03o`000?oooooooooo00?ooooo0ol0002Cooooo`03o`000?oooooooooo01cooooo002@ooooo`05
o`000?ooooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooool00000Toooool00ol0003oooooooooo`0Looooo`00T?ooool01Ol0003o
oooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo00?o0000ooooool00000Toooool00ol0003oooooooooo`0Looooo`00T?ooool01Ol@
413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000009;ooooo00?o0000ooooooooool07Oooool0093ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooo000009;ooooo00?o0000ooooooooool07Oooool0093ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo0ol0002Booooo`03o`000?oo
oooooooo01gooooo002cooooo`03o`000?oooooo000009;ooooo00?o0000ooooooooool07Oooool0
0;?ooooo00Co0000oooooooooooo0000TOooool00ol0003oooooooooo`0Mooooo`00/oooool01?l0
003oooooooooool0002Aooooo`03o`000?oooooooooo01gooooo002cooooo`04o`000?oooooooooo
o`00097ooooo00?o0000ooooooooool07Oooool00;?ooooo0_l000000ooooooo0000ooooo`2@oooo
o`03o`000?oooooooooo01gooooo002cooooo`04o`000?ooooooooooo`00097ooooo00?o0000oooo
ooooool07Oooool00;?ooooo00Co0000oooooooooooo0000TOooool00ol0003oooooooooo`0Moooo
o`00/oooool01?l0003oooooooooool0002Aooooo`03o`000?oooooooooo01gooooo002cooooo`04
o`000?ooooooooooo`00093ooooo00?o0000ooooooooool07_ooool00;?ooooo0_l000000ooooooo
0000ooooo`2?ooooo`03o`000?oooooooooo01kooooo002cooooo`04o`000?ooooooooooo`00093o
oooo00?o0000ooooooooool07_ooool00;?ooooo00Co0000oooooooooooo0000T?ooool00ol0003o
ooooooooo`0Nooooo`00/oooool01?l0003oooooooooool0002@ooooo`03o`000?oooooooooo01ko
oooo002cooooo`04o`000?ooooooooooo`00093ooooo00?o0000ooooooooool07_ooool00;?ooooo
0_l000000ooooooo0000ooooo`2?ooooo`03o`000?oooooooooo01kooooo002cooooo`04o`000?oo
ooooooooo`00093ooooo00?o0000ooooooooool07_ooool009Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00Go0000oooooooo
ooooooooo`00002?ooooo`03o`000?oooooooooo01kooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool01Ol0003ooooooooooooooooo
000008oooooo00?o0000ooooooooool07_ooool0093ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000Sooo
ool00ol0003oooooooooo`0Nooooo`00V?ooool01Ol0003ooooooooooooooooo000000oooooo00?o
MgMgoc8b<_ooool01?ooool3o`000003ooooool0003ooooo08kooooo00?o0000ooooooooool07_oo
ool009Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool01Ol0003ooooooooooooooooo000008oooooo00?o0000ooooooooool07_ooool009Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00002?ooooo`03o`000?oooooooooo01kooooo002Hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000S_ooool0
0ol0003oooooooooo`0Oooooo`00V?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`05o`000?ooooooooooooooool00000S_ooool00ol0003oooooooooo`0Oooooo`00/oooool2
o`0000;ooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0Oooooo`00/oooool01Ol0
003ooooooooooooooooo000008kooooo00?o0000ooooooooool07oooool00;?ooooo00Go0000oooo
ooooooooooooo`00002>ooooo`03o`000?oooooooooo01oooooo002cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0Oooooo`00/oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool07oooool00;?ooooo
0_l00003ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool07oooool00;?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo01oooooo002c
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0O
ooooo`00/oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo08[ooooo00?o0000oooo
ooooool08?ooool00;?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo023ooooo002cooooo`;o00000oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo023ooooo002cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`0Pooooo`00/oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool08?ooool00;?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo023ooooo002cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Pooooo`00/oooool2o`0000Cooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`0Pooooo`00/oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool08?ooool0093ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0Pooooo`00T?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0Qooooo`00R?ooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo00?o0000oooooooo
ool08Oooool0093ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000?ooooo00?o0000ooooooooool0R?ooool00ol0003o
ooooooooo`0Qooooo`00T?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`27ooooo`03o`000?oooooooooo027ooooo002@ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo027ooooo002@ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool08Oooool0093ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00005ooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool08Oooool00;?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27
ooooo`03o`000?oooooooooo027ooooo000Zooooo`;o0000Moooool3o`0000gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo027ooooo000Yooooo`;o
000000?oooooo`000?ooool0M?ooool2o`000003ooooool0003ooooo00cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo027ooooo000Xooooo`;o0000
0_ooool2o`0007Cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0Qooooo`00:?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`;o00001Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02;ooooo
000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo02;ooooo000Xooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o
410@ooooooooool09Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
7?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Xooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol0000Wooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`0;ooooo`03o`000?oooooooooo02;ooooo000Wooooo`03o`000?oooooooooo00Go
oooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool09_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Wooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Wooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Rooooo`009oooool01?l0003oooooooooooooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`Go00007oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h0:?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0000=
ooooo`03o`000?oooooooooo02;ooooo000Wooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo0000:?oo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h06oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`03o`000?oooooooooo01;ooooo
1?l0000Aooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP0Wooooo`05
o`000?ooooooooooooooool000001Oooool4o`0000;ooooo00CoA4A4omgMgOoooooo00003_ooool0
0ol0003oooooooooo`0Rooooo`009_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool0000Xooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Jooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo
0_l00002ooooo`;o00004?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool09_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l00002ooooo`;o000000GoooooomgM
gOmEEEGoooooo`00000>ooooo`03o`000?oooooooooo02;ooooo000Vooooo`03o`000?oooooooooo
00Oooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co
000000;ooooo00?o0000ooooooooool08oooool01Ol@413ooooooooooooooooo410@00oooooo00Co
0000oooooooooooo00005oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`;o00001?ooool2o`0000oooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Gooooo00Go410@oooooooo
oooooooooa0@4003ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooMgMgolc<c?l0
000>ooooo`03o`000?oooooooooo02;ooooo000Vooooo`03o`000?oooooooooo00Oooooo00So0000
ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001Ol0000Sooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01?l0003o^[ZjoooooonHV9P6o`0001Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03oooool2o`0000Kooooo00?o0000ooooooooool03Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool00_ooool01Ol0003o^[ZjoooooonHV9So410@01Cooooo
00?o0000ooooooooool04?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooooooo
ool01Oooool01Ol0003oooooonk^k_m4A4Co000000gooooo00?o0000ooooooooool08oooool002Ko
oooo00?o0000ooooooooool02?ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`03ooooo`;o00006?ooool5o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`03oiRHV?l@413o000000;o00001?ooool2o`0001Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`Ko00000_ooool01OnHV9So410@o`000?lQ8B7oc<c<01;ooooo1Ol0000@ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ogMgMol000003Oooool00ol0003oooooooooo`0Sooooo`009_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Doooo
o`;o00000oooool3o`0001Gooooo0_l00006ooooo`;o00004_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Oooooo0_l00006ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01_ooool2o`0001Cooooo0_l00004ooooo`;o00005_ooool2o`0000Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool08oooool002Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo0_l0000Dooooo`;o00001_ooool00ol0003oooooooooo`0Booooo`;o
00002?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Aooooo`;o00001_ooool2o`0001Cooooo0_l00007ooooo`03
o`000?oooooooooo017ooooo0_l00009ooooo`;o00003oooool00ol0003oooooooooo`0Sooooo`00
9Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo0_l00009ooooo`;o0000
4_ooool2o`0000Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`;o0000
4Oooool2o`0000Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02?ooooo000Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo0_l0000:ooooo`03o`000?oo
oooooooo00oooooo0_l0000:ooooo`;o00003oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`;o00004Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo000Uooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03Oooool2o`0000cooooo00?o0000ooooooooool03Oooool2
o`0000cooooo00?o0000ooooooooool03Oooool2o`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`;o00003oooool00ol0003oooooooooo`0:ooooo`;o00003oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool0
01Coooooool00010o`0001Gooooo000Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo000Uooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000oooooo0_l0000<ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool2o`0000_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3_ooool2o`0000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool09?ooool002Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01ooo
ool2o`0001;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo0_l0000>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool2o`00017ooooo0_l00009ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?oo
ool2o`00013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`009?ooool0
0ol0003oooooooooo`0=ooooo`;o00002_ooool00ol0003oooooooooo`0@ooooo`;o00001oooool2
o`0001Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`;o00002?ooool2
o`0001?ooooo0_l00007ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09?ooool0
02Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01;ooooo0_l00005ooooo`;o00005Oooool2o`0000Gooooo0_l0000Dooooo`;o00002?ooool2o`00
00oooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0@ooooo`;o00001oooool00ol0003oooooooooo`0Cooooo`;o00001Oooool2o`00
01Cooooo0_l00007ooooo`;o00004_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02Gooooo000Tooooo`03o`000?oooooooooo00kooooo0_l00007ooooo`;o00005Oooool7o`0001So
oooo1_l0000Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Aooooo`;o00001?ooool2o`0001Oooooo1_l0000Gooooo`;o00001Oooool2o`0001?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Uooooo`009?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`0001_ooooo
0ol0000Iooooo`03o`000?oooooooooo00Cooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo
0_l00002ooooo`;o0000=oooool2o`000004ooooool0003o0000o`0001Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Uooooo`009?ooool00ol0003oooooooooo`0?ooooo`;o0000
1Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Dooooo`?o0000>_ooool3o`0001Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Uooooo`009?ooool00ol0003oooooooooo`0@ooooo`;o00000ooo
ool00ol0003oooooooooo`1Cooooo`;o00000oooool2o`0001;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0K?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo000Sooooo`03o`000?oooooo
oooo01;ooooo1Ol0001Fooooo`Go00004oooool00ol0003oooooooooo`05ooooo`;o00002Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Uooooo`008oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`008oooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Vooooo`008oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`008oooool00ol0003ooooooooo
o`26ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`;o0000LOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oooooo000S
ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool01?ooool2o`0000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09oooool002?ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00Co0000oooooooooooooooo0_l0001cooooo`04o`000?oooooo
ooooooooo`;o0000:Oooool002;ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000o`00001dooooo`;o00000_ooool0
0ol0003oooooooooo`0Xooooo`008_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool3o`0007Kooooo1?l0000Zooooo`008_ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0/_ooool002;ooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`04ooooo`;o0000/oooool002;ooooo00?o
0000ooooooooool0Qoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;;ooooo000R
ooooo`03o`000?oooooooooo06_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Cooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo0;;ooooo
000Rooooo`03o`000?oooooooooo06_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000oc8b<_ooool01?ooool00ol0003o
ooooooooo`2booooo`008_ooool00ol0003oooooooooo`1[ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0/_ooool002;ooooo00?o0000ooooooooool0Joooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo0000ooooo`04ooooo`?o0000/_ooool002;ooooo
00?o0000ooooooooool0Joooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;o000000Gooooo00?o0000ooooooooool0/_ooool002;o
oooo00?o0000ooooooooool0Joooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0/_ooool0
027ooooo00?o0000ooooooooool0K?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`2booooo`008Oooool00ol0003oooooooooo`1/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1Ol00005ooooo`03o`000?oooooooooo0;;o
oooo000Qooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool00oooool2o`000;?ooooo
000Qooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2booooo`008Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0/_ooool0027ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0;;ooooo000Qooooo`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2booooo`008Oooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo00;ooooo0_l0002cooooo`008Oooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0/_ooool0027ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;;ooooo000Pooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2booooo`008?ooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0/_ooool0023ooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`02ooooo`;o0000/oooool0023ooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;;ooooo000P
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2b
ooooo`008?ooool00ol0003oooooooooo`2<ooooo`05o`000?ooooooooooooooool00000]?ooool0
023ooooo00?o0000ooooooooool0S?ooool01?l0003oooooooooooooool2o`000;?ooooo000Poooo
o`03o`000?oooooooooo08cooooo00Go0000ooooooooooooooooo`00002dooooo`008?ooool00ol0
003oooooooooo`2<ooooo`05o`000?ooooooooooooooool00000]?ooool0023ooooo00?o0000oooo
ooooool0MOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`07odA4A?l0003o
0000oc8b<_oMgMgoooooo`000003ooooo`03o`000?oooooooooo0;;ooooo000Oooooo`03o`000?oo
oooooooo07Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool01?mgMgOo<S8b
ooooool00003ooooo`03o`000?oooooooooo0;;ooooo000Oooooo`03o`000?oooooooooo07Kooooo
00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooo000000?ooooo0ol0002booooo`00
7oooool00ol0003oooooooooo`1fooooo`05o`000?ooooooooooooooool000003oooool01?mgMgOo
<S8booooool00003ooooo`03o`000?oooooooooo0;;ooooo000Oooooo`03o`000?oooooooooo07Ko
oooo00Go0000ooooooooooooooooo`00000<ooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`00
0003ooooo`03o`000?oooooooooo0;;ooooo000Oooooo`03o`000?oooooooooo07Kooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`00002dooooo`007oooool00ol0003oooooooooo`1fooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000]?ooool001oooooo
00?o0000ooooooooool0M_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00002ooooo`04
o`000?ooooooooooooooo`;o0000/oooool001oooooo00?o0000ooooooooool0SOooool01Ol0003o
oooooooooooooooo00000;Cooooo000Oooooo`03o`000?oooooooooo08gooooo00Go0000oooooooo
ooooooooo`00002dooooo`007oooool00ol0003oooooooooo`2>ooooo`04o`000?ooooooooooo`00
0;Cooooo000Oooooo`03o`000?oooooooooo08kooooo00Co0000oooooooooooo0000]?ooool001ko
oooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`02o`000;?ooooo000Nooooo`03o`00
0?oooooooooo08oooooo00Co0000oooooooooooo0000]?ooool001kooooo00?o0000ooooooooool0
Soooool01?l0003oooooooooool0002dooooo`007_ooool00ol0003oooooooooo`2?ooooo`04o`00
0?ooooooooooo`000;Cooooo000Nooooo`03o`000?oooooooooo08oooooo00Co0000oooooooooooo
0000]?ooool001kooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`02o`000;?ooooo
000Nooooo`03o`000?oooooooooo08oooooo00Co0000oooooooooooo0000]?ooool001kooooo00?o
0000ooooooooool0Soooool01?l0003oooooooooool0002dooooo`007_ooool00ol0003ooooooooo
o`2?ooooo`04o`000?ooooooooooo`000;Cooooo000Nooooo`03o`000?oooooooooo093ooooo00?o
0000ooooool00000]?ooool001kooooo00?o0000ooooooooool0T?ooool01?l0003oooooo`000?l0
002cooooo`007_ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo00000;Cooooo000Noooo
o`03o`000?oooooooooo06oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool0
0ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd00oooool00ol0003oooooo`00
002dooooo`007_ooool00ol0003oooooooooo`1_ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`02ooooo`03o`000?oo
oooo00000;Cooooo000Nooooo`03o`000?oooooooooo06oooooo00Go410@oooooooooooooooooa0@
400=ooooo`03ojVYZOmEEEGooooo00Sooooo00Oo0000ooooooooooooooooo`000?oooooo00000;Co
oooo000Mooooo`03o`000?oooooooooo073ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooo`000002o`000;;o
oooo000Mooooo`03o`000?oooooooooo073ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c003ooooo`03o`000?oooooo0000
0;Cooooo000Mooooo`03o`000?oooooooooo073ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00002doooo
o`007Oooool00ol0003oooooooooo`1`ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00002d
ooooo`007Oooool00ol0003oooooooooo`1`ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5
o`0000Cooooo1?l00004ooooo`03o`000?oooooo00000;Cooooo000Mooooo`03o`000?oooooooooo
097ooooo00Co0000ooooool0003o0000/oooool001gooooo00?o0000ooooooooool0T_ooool2o`00
0;Cooooo000Mooooo`03o`000?oooooooooo09;ooooo0_l0002dooooo`007Oooool00ol0003ooooo
ooooo`2Booooo`;o0000]?ooool001gooooo00?o0000ooooooooool0T_ooool2o`000;Cooooo000M
ooooo`03o`000?oooooooooo09;ooooo0ol0002cooooo`007Oooool00ol0003oooooooooo`2Boooo
o`;o0000]?ooool001cooooo00?o0000ooooooooool0Toooool2o`000;Cooooo000Looooo`03o`00
0?oooooooooo09?ooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000]?oo
ool001cooooo00?o0000ooooooooool0Toooool3o`000;?ooooo000Looooo`03o`000?oooooooooo
09?ooooo0_l0002dooooo`007?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo0;;o
oooo000Looooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool0/_ooool001cooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`2booooo`007?ooool00ol0003oooooooooo`2D
ooooo`;o0000/oooool001cooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`2boooo
o`007?ooool00ol0003oooooooooo`2:ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`2booooo`007?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0/_ooool001_ooooo00?o0000ooooooooool0SOooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;;ooooo000Kooooo`03o`000?oooooooooo08gooooo00?o0000
ooooooooool01Oooool3o`000;;ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002[ooooo`03
o`000?oooooooooo0;[ooooo002[ooooo`03o`000?oooooooooo0;[ooooo002Yooooo`03oeEEEOmV
IVKo00000;cooooo003oooooofWooooo002Zooooo`03o`000?nj^[[ooooo0;_ooooo002Zooooo`;o
<S8b_?ooool008;ooooo1_l00002ooooo`03oa0@4?l0003o000000?o00000_ooool00ol@413o0000
o`000003o`0000?ooooo00Sok^k^oeEEEOl0003o0000oeEEEOo^k^kooooooa0@40Go00000_ooool0
0on7QhOo0000okZj^P0:ooooo`;o000000Ko410@oooooooooooo410@o`000?l@410Hooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kXGooooo0023ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00KoEEEE
ogMgMoooooooooooogMgMomEEED3ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@4100
2oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo1_l0000<ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`25ooooo`00Poooool01Ol0003ooooo
oooooooooooo410@00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100QOooool008?ooooo00?o0000ooooool@41001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001?ooooo00Ko0000oooooom4A4CoA4A4ooooool00009ooooo`Ko00003?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000QOooool008?ooooo0ol00006ooooo`03o`00
0?lb<S;ogMgM00Gooooo00?o0000oc8b<_oMgMd01?ooool01_mEEEGoMgMgooooooooooooMgMgoeEE
E@?ooooo00?o0000oc8b<_oMgMd04Oooool01_l0003ogMgMoc8b<_mEEEGogMgMo`0001_ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000008Gooooo0023ooooo`05o`000?oo
oooo410@ooooool@41000oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo0_l000001?nYZJWo
8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool2o`000004ojVYZOlQ
8B7o0000ob4Q8@oooooo00Ko0000ohN7QonYZJWo^[ZjoeEEEOl0000Kooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4025ooooo`00Poooool01Ol0003ooooooooooooooooo
0000033ooooo00Ko0000oc8b<_oooooooooooc8b<_l0000Kooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`25ooooo`00P_ooool6o`0002oooooo00?o410@o`000?n7QhL0
0_ooool00on7QhOo0000oa0@400Hooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP25ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.309017 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.02427 .606 L
.02478 .59289 L
.02525 .58061 L
.02571 .56884 L
.0262 .55639 L
.02667 .54447 L
.02716 .53192 L
.02764 .51993 L
.0281 .50853 L
.02859 .49654 L
.02907 .48515 L
.02952 .47436 L
.03 .46305 L
.03047 .45237 L
.03097 .44122 L
.03144 .43072 L
.0319 .42083 L
.03239 .41056 L
.03286 .40093 L
.03336 .39098 L
.03384 .38168 L
.0343 .37301 L
.03479 .36409 L
.03527 .35581 L
.03572 .34813 L
.03621 .34027 L
.03668 .33302 L
.03717 .32566 L
.03765 .3189 L
.03811 .31272 L
.0386 .30649 L
.03907 .30083 L
.03953 .29569 L
.04001 .29056 L
.04047 .28596 L
.04097 .28141 L
.04144 .27737 L
.0419 .2738 L
.04239 .27034 L
.04286 .26733 L
.04335 .26447 L
.04383 .26204 L
.0443 .26001 L
.04479 .25816 L
.04526 .25669 L
.04572 .25554 L
.04597 .25501 L
.0462 .2546 L
.04644 .25423 L
Mistroke
.04667 .25396 L
.04689 .25374 L
.04702 .25365 L
.04714 .25358 L
.04726 .25352 L
.04733 .2535 L
.04739 .25348 L
.04744 .25347 L
.0475 .25346 L
.04753 .25346 L
.04754 .25345 L
.04756 .25345 L
.04757 .25345 L
.04759 .25345 L
.0476 .25345 L
.04761 .25345 L
.04763 .25345 L
.04764 .25345 L
.04766 .25345 L
.04767 .25345 L
.04768 .25345 L
.0477 .25346 L
.04773 .25346 L
.04776 .25346 L
.04779 .25347 L
.04784 .25348 L
.0479 .25349 L
.04796 .25351 L
.04809 .25357 L
.0482 .25363 L
.04831 .25371 L
.04856 .25392 L
.04903 .25449 L
.04952 .25533 L
.05 .25634 L
.05046 .2575 L
.05095 .25893 L
.05142 .26047 L
.05187 .2621 L
.05236 .26398 L
.05282 .26593 L
.05331 .26813 L
.05379 .27036 L
.05425 .2726 L
.05473 .27507 L
.0552 .27752 L
.0557 .2802 L
.05618 .28284 L
.05664 .28541 L
.05713 .28817 L
Mistroke
.0576 .29085 L
.05806 .29344 L
.05854 .29619 L
.05901 .29882 L
.0595 .30159 L
.05998 .30422 L
.06044 .30672 L
.06093 .30932 L
.0614 .31176 L
.0619 .31428 L
.06238 .31663 L
.06284 .31881 L
.06333 .32103 L
.06381 .32308 L
.06426 .32494 L
.06475 .32683 L
.06522 .32852 L
.06571 .33021 L
.06619 .3317 L
.06665 .33303 L
.06714 .3343 L
.06761 .3354 L
.06807 .33634 L
.06855 .33721 L
.06901 .33791 L
.06951 .33852 L
.06998 .33898 L
.07044 .33929 L
.07068 .33941 L
.07081 .33946 L
.07093 .3395 L
.07105 .33953 L
.07112 .33954 L
.07119 .33955 L
.07125 .33956 L
.0713 .33956 L
.07134 .33956 L
.07136 .33957 L
.07138 .33957 L
.07139 .33957 L
.0714 .33957 L
.07141 .33957 L
.07141 .33957 L
.07143 .33957 L
.07144 .33957 L
.07146 .33957 L
.07147 .33957 L
.07148 .33957 L
.07149 .33957 L
.07152 .33956 L
Mistroke
.07155 .33956 L
.0716 .33956 L
.07166 .33955 L
.07172 .33954 L
.07179 .33953 L
.07191 .3395 L
.07214 .33943 L
.07236 .33933 L
.07283 .33903 L
.07332 .3386 L
.0738 .33807 L
.07426 .33745 L
.07475 .33669 L
.07522 .33586 L
.07572 .33488 L
.0762 .33383 L
.07666 .33275 L
.07715 .33152 L
.07763 .33027 L
.07808 .32899 L
.07857 .32758 L
.07903 .32617 L
.07953 .32462 L
.08001 .32309 L
.08047 .32158 L
.08096 .31995 L
.08143 .31836 L
.08188 .31682 L
.08236 .31518 L
.08283 .31359 L
.08332 .31191 L
.0838 .31031 L
.08426 .30878 L
.08474 .30718 L
.08521 .30566 L
.08571 .30409 L
.08619 .30262 L
.08665 .30125 L
.08714 .29985 L
.08761 .29855 L
.08807 .29736 L
.08855 .29615 L
.08902 .29506 L
.08951 .29397 L
.08999 .293 L
.09045 .29213 L
.09094 .2913 L
.09141 .29057 L
.09191 .28989 L
.09239 .28932 L
Mistroke
.09285 .28886 L
.09335 .28845 L
.09382 .28815 L
.09428 .28795 L
.09451 .28787 L
.09464 .28784 L
.09476 .28782 L
.09489 .2878 L
.09495 .28779 L
.09502 .28778 L
.09505 .28778 L
.09508 .28778 L
.09511 .28778 L
.09513 .28777 L
.09517 .28777 L
.09518 .28777 L
.09519 .28777 L
.0952 .28777 L
.09522 .28777 L
.09523 .28777 L
.09524 .28777 L
.09525 .28777 L
.09526 .28777 L
.09528 .28777 L
.09529 .28777 L
.0953 .28777 L
.09532 .28777 L
.09535 .28777 L
.09538 .28778 L
.09543 .28778 L
.09549 .28778 L
.0956 .2878 L
.09573 .28782 L
.09597 .28787 L
.09622 .28795 L
.09646 .28805 L
.09671 .28817 L
.09717 .28846 L
.09765 .28884 L
.09812 .28928 L
.09862 .28983 L
.0991 .29044 L
.09956 .29108 L
.10005 .29183 L
.10052 .29262 L
.10098 .29342 L
.10146 .29433 L
.10193 .29526 L
.10242 .29629 L
.1029 .29732 L
Mistroke
.10336 .29835 L
.10385 .29947 L
.10432 .30058 L
.10482 .30179 L
.1053 .30296 L
.10576 .30411 L
.10625 .30533 L
.10673 .30651 L
.10718 .30765 L
.10767 .30885 L
.10813 .30999 L
.10863 .3112 L
.10911 .31233 L
.10957 .3134 L
.11006 .31451 L
.11053 .31555 L
.11098 .31651 L
.11147 .3175 L
.11193 .3184 L
.11243 .31932 L
.1129 .32015 L
.11336 .32091 L
.11385 .32165 L
.11432 .32231 L
.11481 .32295 L
.11529 .32351 L
.11576 .32398 L
.11625 .32441 L
.11672 .32477 L
.11717 .32505 L
.11766 .32528 L
.11788 .32537 L
.11813 .32544 L
.11826 .32547 L
.11838 .3255 L
.1185 .32552 L
.11862 .32554 L
.11869 .32555 L
.11875 .32555 L
.11881 .32556 L
.11887 .32556 L
.1189 .32556 L
.11892 .32556 L
.11895 .32556 L
.11898 .32556 L
.11899 .32556 L
.11901 .32556 L
.11902 .32556 L
.11904 .32556 L
.11905 .32556 L
Mistroke
.11906 .32556 L
.11908 .32556 L
.11909 .32556 L
.1191 .32556 L
.11911 .32556 L
.11912 .32556 L
.11915 .32556 L
.11918 .32556 L
.11921 .32556 L
.11928 .32556 L
.11935 .32555 L
.11946 .32554 L
.11959 .32552 L
.11982 .32548 L
.12004 .32542 L
.12051 .32526 L
.12101 .32502 L
.12148 .32472 L
.12194 .32438 L
.12243 .32396 L
.1229 .32349 L
.12336 .323 L
.12384 .32242 L
.1243 .32182 L
.1248 .32113 L
.12527 .32042 L
.12573 .3197 L
.12622 .3189 L
.12668 .3181 L
.12718 .31721 L
.12766 .31633 L
.12812 .31546 L
.12861 .31452 L
.12909 .31359 L
.12954 .31269 L
.13003 .31173 L
.13049 .3108 L
.13099 .30981 L
.13146 .30886 L
.13192 .30795 L
.13241 .307 L
.13288 .30609 L
.13338 .30515 L
.13386 .30426 L
.13433 .30344 L
.13482 .30259 L
.13529 .3018 L
.13575 .30107 L
.13623 .30034 L
.1367 .29967 L
Mistroke
.1372 .299 L
.13768 .2984 L
.13814 .29787 L
.13863 .29736 L
.1391 .29691 L
.13955 .29653 L
.14004 .29617 L
.1405 .29588 L
.141 .29563 L
.14147 .29544 L
.14171 .29537 L
.14193 .29531 L
.14217 .29526 L
.14229 .29524 L
.14242 .29523 L
.14253 .29522 L
.14259 .29521 L
.14266 .29521 L
.14271 .29521 L
.14274 .29521 L
.14277 .29521 L
.1428 .29521 L
.14281 .29521 L
.14283 .29521 L
.14284 .29521 L
.14285 .29521 L
.14287 .29521 L
.14288 .29521 L
.14289 .29521 L
.14291 .29521 L
.14292 .29521 L
.14294 .29521 L
.14297 .29521 L
.143 .29521 L
.14306 .29521 L
.14312 .29521 L
.14324 .29522 L
.14334 .29523 L
.14357 .29527 L
.14382 .29532 L
.14405 .29538 L
.1443 .29546 L
.14479 .29565 L
.14527 .2959 L
.14573 .29618 L
.14622 .29653 L
.14669 .29692 L
.14719 .29737 L
.14767 .29786 L
.14813 .29837 L
Mistroke
.14862 .29895 L
.1491 .29954 L
.14955 .30015 L
.15004 .30082 L
.1505 .3015 L
.151 .30225 L
.15148 .303 L
.15194 .30373 L
.15243 .30453 L
.1529 .30531 L
.15335 .30608 L
.15384 .3069 L
.1543 .30769 L
.15479 .30853 L
.15527 .30934 L
.15573 .31012 L
.15621 .31093 L
.15668 .3117 L
.15718 .31251 L
.15766 .31327 L
.15812 .31398 L
.15861 .31471 L
.15909 .31538 L
.15954 .31601 L
.16003 .31664 L
.16049 .31722 L
.16099 .3178 L
.16146 .31831 L
.16192 .31877 L
.16241 .31922 L
.16288 .31961 L
.16338 .31998 L
.16386 .32029 L
.16433 .32054 L
.16482 .32075 L
.1653 .32092 L
.16553 .32098 L
.16575 .32103 L
.16599 .32107 L
.16612 .32108 L
.16624 .3211 L
.16635 .3211 L
.16641 .32111 L
.16648 .32111 L
.16653 .32111 L
.16656 .32111 L
.16658 .32111 L
.16659 .32111 L
.1666 .32111 L
.16662 .32111 L
Mistroke
.16663 .32111 L
.16664 .32111 L
.16666 .32111 L
.16667 .32111 L
.16669 .32111 L
.1667 .32111 L
.16671 .32111 L
.16673 .32111 L
.16675 .32111 L
.16678 .32111 L
.16681 .32111 L
.16687 .32111 L
.16692 .32111 L
.16704 .3211 L
.16717 .32109 L
.16741 .32106 L
.16762 .32102 L
.16809 .3209 L
.16858 .32073 L
.16906 .32052 L
.16951 .32027 L
.17 .31997 L
.17047 .31963 L
.17097 .31923 L
.17145 .31881 L
.17191 .31837 L
.1724 .31786 L
.17287 .31733 L
.17333 .3168 L
.17381 .31621 L
.17428 .31561 L
.17477 .31495 L
.17525 .3143 L
.17571 .31365 L
.17619 .31294 L
.17666 .31225 L
.17716 .3115 L
.17765 .31077 L
.17811 .31007 L
.1786 .30932 L
.17907 .3086 L
.17953 .30791 L
.18002 .30718 L
.18048 .3065 L
.18098 .30578 L
.18146 .3051 L
.18192 .30446 L
.18241 .30381 L
.18288 .3032 L
.18333 .30264 L
Mistroke
.18382 .30207 L
.18428 .30156 L
.18478 .30104 L
.18525 .30057 L
.18571 .30015 L
.1862 .29975 L
.18667 .2994 L
.18716 .29906 L
.18764 .29879 L
.18811 .29856 L
.1886 .29836 L
.18907 .29821 L
.18953 .29811 L
.18976 .29807 L
.18989 .29805 L
.19001 .29804 L
.19013 .29803 L
.1902 .29803 L
.19026 .29802 L
.1903 .29802 L
.19033 .29802 L
.19036 .29802 L
.19038 .29802 L
.19039 .29802 L
.19041 .29802 L
.19042 .29802 L
.19044 .29802 L
.19044 .29802 L
.19045 .29802 L
.19047 .29802 L
.19048 .29802 L
.19049 .29802 L
.19051 .29802 L
.19052 .29802 L
.19054 .29802 L
.19055 .29802 L
.19057 .29802 L
.19062 .29802 L
.19065 .29802 L
.19068 .29802 L
.19074 .29803 L
.19085 .29803 L
.19096 .29804 L
.1912 .29807 L
.19142 .2981 L
.1919 .29821 L
.19235 .29835 L
.19284 .29855 L
.1933 .29877 L
.1938 .29906 L
Mistroke
.19428 .29937 L
.19474 .2997 L
.19523 .3001 L
.1957 .30051 L
.19615 .30094 L
.19664 .30142 L
.1971 .30192 L
.19759 .30247 L
.19807 .30303 L
.19853 .30359 L
.19901 .3042 L
.19948 .30481 L
.19998 .30547 L
.20046 .30612 L
.20092 .30676 L
.20141 .30744 L
.20188 .3081 L
.20234 .30874 L
.20282 .30942 L
.20329 .31007 L
.20378 .31076 L
.20426 .31141 L
.20472 .31203 L
.20521 .31267 L
.20568 .31327 L
.20618 .31389 L
.20666 .31447 L
.20712 .315 L
.20762 .31554 L
.20809 .31603 L
.20855 .31648 L
.20903 .31692 L
.2095 .31732 L
.21 .31771 L
.21048 .31804 L
.21094 .31833 L
.21143 .3186 L
.2119 .31882 L
.21235 .31899 L
.21284 .31914 L
.2133 .31924 L
.21354 .31928 L
.21366 .31929 L
.2138 .31931 L
.21392 .31932 L
.21403 .31932 L
.21409 .31933 L
.21412 .31933 L
.21415 .31933 L
.21417 .31933 L
Mistroke
.2142 .31933 L
.21421 .31933 L
.21423 .31933 L
.21424 .31933 L
.21425 .31933 L
.21427 .31933 L
.21428 .31933 L
.2143 .31933 L
.21431 .31933 L
.21433 .31933 L
.21433 .31933 L
.21434 .31933 L
.21437 .31933 L
.2144 .31933 L
.21443 .31933 L
.21448 .31933 L
.21455 .31932 L
.21461 .31932 L
.21473 .31931 L
.21485 .3193 L
.21497 .31929 L
.21519 .31925 L
.21565 .31916 L
.21613 .31902 L
.2166 .31885 L
.21709 .31863 L
.21757 .31838 L
.21803 .3181 L
.21851 .31777 L
.21898 .31742 L
.21948 .31701 L
.21996 .31658 L
.22043 .31614 L
.22092 .31565 L
.22139 .31514 L
.22185 .31464 L
.22233 .31408 L
.2228 .31352 L
.2233 .31291 L
.22378 .31231 L
.22424 .31172 L
.22473 .31108 L
.2252 .31046 L
.22565 .30986 L
.22613 .30921 L
.2266 .30859 L
.22709 .30794 L
.22757 .30731 L
.22803 .30671 L
.22851 .30609 L
Mistroke
.22898 .3055 L
.22948 .30489 L
.22996 .30432 L
.23042 .30379 L
.23091 .30325 L
.23139 .30276 L
.23184 .3023 L
.23233 .30184 L
.23279 .30143 L
.23329 .30103 L
.23377 .30067 L
.23422 .30036 L
.23471 .30006 L
.23518 .29981 L
.23568 .29958 L
.23617 .29941 L
.23663 .29927 L
.23686 .29922 L
.23712 .29917 L
.23737 .29913 L
.2376 .29911 L
.23772 .2991 L
.23778 .29909 L
.23784 .29909 L
.23789 .29909 L
.23795 .29909 L
.23798 .29909 L
.238 .29908 L
.23803 .29908 L
.23805 .29908 L
.23806 .29908 L
.23808 .29908 L
.23809 .29908 L
.23811 .29908 L
.23812 .29908 L
.23814 .29908 L
.23814 .29908 L
.23815 .29908 L
.23818 .29908 L
.23821 .29908 L
.23824 .29909 L
.23829 .29909 L
.23836 .29909 L
.23842 .29909 L
.23854 .2991 L
.23866 .29911 L
.23878 .29912 L
.239 .29915 L
.23945 .29924 L
.23994 .29938 L
Mistroke
.2404 .29954 L
.24089 .29975 L
.24137 .3 L
.24183 .30026 L
.24231 .30058 L
.24278 .30092 L
.24328 .30132 L
.24376 .30173 L
.24422 .30215 L
.24471 .30263 L
.24518 .30311 L
.24564 .3036 L
.24612 .30414 L
.24659 .30468 L
.24708 .30527 L
.24756 .30585 L
.24802 .30643 L
.24851 .30705 L
.24898 .30765 L
.24948 .3083 L
.24996 .30892 L
.25042 .30953 L
.25091 .31016 L
.25139 .31077 L
.25184 .31135 L
.25233 .31196 L
.2528 .31254 L
.25329 .31313 L
.25377 .31369 L
.25423 .3142 L
.25472 .31473 L
.25519 .31522 L
.25565 .31566 L
.25613 .31611 L
.2566 .31651 L
.25709 .31691 L
.25757 .31726 L
.25802 .31757 L
.25851 .31786 L
.25898 .31811 L
.25948 .31833 L
.25996 .31851 L
.26042 .31864 L
.26066 .3187 L
.26091 .31874 L
.26116 .31878 L
.26139 .31881 L
.26151 .31882 L
.26157 .31882 L
.26163 .31882 L
Mistroke
.26169 .31882 L
.26174 .31883 L
.26176 .31883 L
.26179 .31883 L
.26181 .31883 L
.26182 .31883 L
.26184 .31883 L
.26185 .31883 L
.26187 .31883 L
.26188 .31883 L
.2619 .31883 L
.26191 .31883 L
.26192 .31883 L
.26194 .31883 L
.26195 .31883 L
.26195 .31883 L
.26197 .31883 L
.262 .31883 L
.26203 .31883 L
.26208 .31883 L
.26214 .31882 L
.2622 .31882 L
.26233 .31881 L
.26245 .3188 L
.26257 .31879 L
.2628 .31876 L
.26304 .31872 L
.26326 .31867 L
.26373 .31854 L
.26419 .31839 L
.26467 .31818 L
.26514 .31795 L
.26564 .31766 L
.26612 .31735 L
.26658 .31702 L
.26707 .31663 L
.26754 .31623 L
.26799 .31582 L
.26847 .31536 L
.26894 .31489 L
.26943 .31436 L
.26991 .31383 L
.27036 .31331 L
.27085 .31273 L
.27132 .31216 L
.27182 .31154 L
.2723 .31093 L
.27276 .31034 L
.27325 .30971 L
.27372 .30909 L
Mistroke
.27418 .3085 L
.27466 .30787 L
.27513 .30727 L
.27562 .30664 L
.2761 .30604 L
.27656 .30547 L
.27705 .30488 L
.27752 .30433 L
.27802 .30377 L
.2785 .30325 L
.27896 .30276 L
.27946 .30228 L
.27993 .30184 L
.28039 .30144 L
.28087 .30104 L
.28134 .30069 L
.28184 .30035 L
.28232 .30007 L
.28278 .29982 L
.28327 .2996 L
.28374 .29942 L
.28419 .29928 L
.28445 .29922 L
.28468 .29918 L
.2849 .29914 L
.28502 .29913 L
.28514 .29911 L
.28527 .2991 L
.28538 .29909 L
.28543 .29909 L
.28549 .29909 L
.28555 .29909 L
.2856 .29909 L
.28563 .29908 L
.28566 .29908 L
.28567 .29908 L
.28568 .29908 L
.28569 .29908 L
.2857 .29908 L
.28572 .29908 L
.28573 .29908 L
.28574 .29908 L
.28576 .29908 L
.28577 .29908 L
.2858 .29908 L
.28581 .29908 L
.28583 .29908 L
.28589 .29909 L
.28592 .29909 L
.28595 .29909 L
Mistroke
.28607 .2991 L
.28619 .2991 L
.2863 .29911 L
.28655 .29914 L
.28678 .29918 L
.28703 .29923 L
.28751 .29936 L
.28798 .29952 L
.28847 .29974 L
.28895 .29998 L
.28941 .30025 L
.28989 .30056 L
.29036 .30091 L
.29086 .3013 L
.29134 .30172 L
.29181 .30215 L
.2923 .30263 L
.29277 .30312 L
.29323 .30362 L
.29372 .30417 L
.29418 .30472 L
.29468 .30532 L
.29516 .30592 L
.29562 .3065 L
.29611 .30714 L
.29658 .30775 L
.29703 .30836 L
.29752 .309 L
.29798 .30962 L
.29847 .31028 L
.29895 .31091 L
.29941 .31151 L
.29989 .31213 L
.30036 .31273 L
.30086 .31335 L
.30134 .31392 L
.3018 .31446 L
.3023 .31501 L
.30277 .31552 L
.30322 .31598 L
.30371 .31645 L
.30417 .31688 L
.30467 .31729 L
.30515 .31766 L
.30561 .31799 L
.3061 .31829 L
.30657 .31855 L
.30707 .31879 L
.30755 .31898 L
.30801 .31912 L
Mistroke
.30825 .31918 L
.3085 .31924 L
.30875 .31927 L
.30898 .3193 L
.30911 .31931 L
.30917 .31932 L
.30922 .31932 L
.30928 .31932 L
.30933 .31933 L
.30939 .31933 L
.30942 .31933 L
.30945 .31933 L
.30946 .31933 L
.30948 .31933 L
.30949 .31933 L
.30951 .31933 L
.30952 .31933 L
.30952 .31933 L
.30953 .31933 L
.30954 .31933 L
.30956 .31933 L
.30956 .31933 L
.30957 .31933 L
.30959 .31933 L
.3096 .31933 L
.30963 .31933 L
.30966 .31933 L
.30969 .31933 L
.30975 .31932 L
.30981 .31932 L
.30991 .31932 L
.31003 .31931 L
.31015 .31929 L
.31037 .31926 L
.31061 .31922 L
.31086 .31917 L
.31132 .31904 L
.3118 .31886 L
.31227 .31865 L
.31277 .31839 L
.31325 .3181 L
.31371 .31778 L
.3142 .31741 L
.31467 .31701 L
.31513 .3166 L
.31561 .31614 L
.31608 .31566 L
.31657 .31512 L
.31705 .31458 L
.31751 .31403 L
Mistroke
.318 .31343 L
.31847 .31284 L
.31897 .31218 L
.31945 .31154 L
.31991 .31091 L
.32041 .31023 L
.32088 .30957 L
.32134 .30893 L
.32182 .30825 L
.32229 .30759 L
.32279 .3069 L
.32327 .30624 L
.32373 .30561 L
.32422 .30496 L
.32469 .30434 L
.32514 .30376 L
.32562 .30317 L
.32609 .30262 L
.32658 .30206 L
.32706 .30154 L
.32752 .30107 L
.32801 .30061 L
.32847 .30019 L
.32897 .29978 L
.32945 .29942 L
.32992 .29911 L
.33041 .29883 L
.33088 .29859 L
.33134 .2984 L
.33182 .29824 L
.33229 .29812 L
.33254 .29808 L
.33266 .29806 L
.33278 .29805 L
.33291 .29804 L
.33302 .29803 L
.33308 .29802 L
.33314 .29802 L
.33316 .29802 L
.33319 .29802 L
.33322 .29802 L
.33324 .29802 L
.33326 .29802 L
.33327 .29802 L
.33329 .29802 L
.3333 .29802 L
.33332 .29802 L
.33333 .29802 L
.33334 .29802 L
.33336 .29802 L
Mistroke
.33337 .29802 L
.33338 .29802 L
.33339 .29802 L
.33342 .29802 L
.33345 .29802 L
.33348 .29802 L
.33354 .29802 L
.33359 .29803 L
.3337 .29803 L
.33382 .29804 L
.33394 .29805 L
.33416 .29808 L
.3344 .29813 L
.33462 .29818 L
.33509 .29831 L
.33558 .2985 L
.33606 .29873 L
.33652 .29899 L
.33701 .2993 L
.33748 .29965 L
.33793 .30001 L
.33842 .30044 L
.33888 .30088 L
.33938 .30139 L
.33985 .30191 L
.34031 .30244 L
.3408 .30304 L
.34126 .30363 L
.34176 .30429 L
.34224 .30495 L
.3427 .3056 L
.3432 .30631 L
.34367 .307 L
.34412 .30768 L
.34461 .30841 L
.34507 .30911 L
.34557 .30987 L
.34605 .3106 L
.34651 .31129 L
.34699 .31202 L
.34747 .31272 L
.34796 .31345 L
.34845 .31413 L
.34891 .31478 L
.3494 .31544 L
.34988 .31606 L
.35033 .31662 L
.35082 .3172 L
.35129 .31772 L
.35178 .31825 L
Mistroke
.35226 .31872 L
.35272 .31913 L
.35321 .31954 L
.35369 .31989 L
.35414 .32018 L
.35462 .32045 L
.35509 .32067 L
.35558 .32086 L
.35583 .32093 L
.35606 .32099 L
.3563 .32104 L
.35652 .32107 L
.35664 .32109 L
.35676 .3211 L
.35682 .3211 L
.35688 .32111 L
.35694 .32111 L
.35699 .32111 L
.35702 .32111 L
.35705 .32111 L
.35706 .32111 L
.35708 .32111 L
.35709 .32111 L
.3571 .32111 L
.35712 .32111 L
.35713 .32111 L
.35714 .32111 L
.35716 .32111 L
.35717 .32111 L
.35719 .32111 L
.35721 .32111 L
.35722 .32111 L
.35725 .32111 L
.35728 .32111 L
.35734 .32111 L
.35739 .32111 L
.35744 .32111 L
.35756 .3211 L
.35767 .32109 L
.35792 .32105 L
.35816 .32101 L
.35838 .32095 L
.35886 .3208 L
.35932 .32061 L
.35981 .32037 L
.36028 .32008 L
.36077 .31973 L
.36126 .31934 L
.36172 .31893 L
.36221 .31845 L
Mistroke
.36269 .31795 L
.36314 .31743 L
.36363 .31684 L
.36409 .31624 L
.36459 .31557 L
.36507 .31489 L
.36553 .31421 L
.36602 .31347 L
.36649 .31273 L
.36695 .312 L
.36743 .31121 L
.36789 .31043 L
.36839 .3096 L
.36886 .30879 L
.36932 .30801 L
.36981 .30718 L
.37028 .30638 L
.37078 .30554 L
.37126 .30474 L
.37172 .30398 L
.37221 .30319 L
.37268 .30245 L
.37314 .30175 L
.37362 .30104 L
.37409 .30038 L
.37458 .29971 L
.37506 .2991 L
.37552 .29855 L
.37601 .298 L
.37648 .29751 L
.37698 .29704 L
.37746 .29663 L
.37793 .29629 L
.37842 .29597 L
.37889 .29571 L
.37935 .29551 L
.37961 .29542 L
.37984 .29536 L
.38008 .2953 L
.38031 .29526 L
.38042 .29524 L
.38054 .29523 L
.38065 .29522 L
.38072 .29521 L
.38075 .29521 L
.38078 .29521 L
.38082 .29521 L
.38084 .29521 L
.38088 .29521 L
.38089 .29521 L
Mistroke
.3809 .29521 L
.38091 .29521 L
.38092 .29521 L
.38094 .29521 L
.38095 .29521 L
.38097 .29521 L
.38098 .29521 L
.381 .29521 L
.38101 .29521 L
.38103 .29521 L
.38105 .29521 L
.38108 .29521 L
.38113 .29521 L
.38119 .29521 L
.38125 .29522 L
.38137 .29523 L
.38148 .29524 L
.38173 .29528 L
.38196 .29533 L
.38221 .2954 L
.3827 .29558 L
.38316 .2958 L
.38366 .2961 L
.38414 .29644 L
.3846 .29682 L
.38509 .29727 L
.38557 .29776 L
.38602 .29827 L
.38651 .29887 L
.38697 .29948 L
.38747 .30018 L
.38794 .30089 L
.3884 .30162 L
.38889 .30242 L
.38936 .30322 L
.38986 .30411 L
.39034 .30499 L
.39081 .30586 L
.3913 .3068 L
.39177 .30773 L
.39223 .30863 L
.39272 .3096 L
.39318 .31053 L
.39368 .31152 L
.39416 .31248 L
.39462 .31339 L
.39511 .31435 L
.39558 .31526 L
.39604 .31612 L
.39652 .31701 L
Mistroke
.39698 .31785 L
.39748 .31871 L
.39795 .3195 L
.39841 .32023 L
.3989 .32096 L
.39937 .32163 L
.39987 .32229 L
.40035 .32288 L
.40081 .32339 L
.4013 .32389 L
.40178 .3243 L
.40223 .32465 L
.40272 .32497 L
.40318 .32521 L
.40342 .3253 L
.40368 .32539 L
.40393 .32546 L
.40405 .32549 L
.40416 .32551 L
.40427 .32553 L
.40438 .32554 L
.4045 .32555 L
.40456 .32556 L
.4046 .32556 L
.40463 .32556 L
.40466 .32556 L
.40467 .32556 L
.40469 .32556 L
.4047 .32556 L
.40472 .32556 L
.40473 .32556 L
.40474 .32556 L
.40476 .32556 L
.40477 .32556 L
.40479 .32556 L
.4048 .32556 L
.40481 .32556 L
.40482 .32556 L
.40483 .32556 L
.40486 .32556 L
.40489 .32556 L
.40492 .32556 L
.40498 .32556 L
.40503 .32555 L
.40508 .32555 L
.4052 .32554 L
.40532 .32552 L
.40554 .32548 L
.4058 .32541 L
.40604 .32533 L
Mistroke
.4065 .32512 L
.40699 .32484 L
.40746 .3245 L
.40791 .32411 L
.40839 .32364 L
.40886 .32312 L
.40935 .3225 L
.40983 .32185 L
.41029 .32116 L
.41077 .32038 L
.41124 .31957 L
.41174 .31866 L
.41222 .31774 L
.41268 .31681 L
.41317 .31577 L
.41365 .31474 L
.4141 .31372 L
.41459 .3126 L
.41505 .3115 L
.41555 .3103 L
.41603 .30914 L
.41648 .308 L
.41697 .30679 L
.41744 .30562 L
.41794 .30437 L
.41843 .30318 L
.41889 .30204 L
.41938 .30085 L
.41986 .29972 L
.42031 .29866 L
.4208 .29757 L
.42127 .29654 L
.42176 .2955 L
.42224 .29454 L
.4227 .29366 L
.4232 .29277 L
.42367 .29198 L
.42412 .29127 L
.4246 .29058 L
.42507 .28998 L
.42556 .28941 L
.42604 .28894 L
.4265 .28856 L
.42699 .28824 L
.42746 .288 L
.42771 .28791 L
.42783 .28788 L
.42796 .28784 L
.42807 .28782 L
.4282 .2878 L
Mistroke
.42825 .28779 L
.42831 .28779 L
.42836 .28778 L
.42842 .28778 L
.42845 .28778 L
.42848 .28777 L
.4285 .28777 L
.42851 .28777 L
.42853 .28777 L
.42854 .28777 L
.42855 .28777 L
.42856 .28777 L
.42857 .28777 L
.42858 .28777 L
.42859 .28777 L
.4286 .28777 L
.4286 .28777 L
.42861 .28777 L
.42862 .28777 L
.42864 .28777 L
.42866 .28777 L
.42867 .28777 L
.4287 .28778 L
.42873 .28778 L
.42879 .28778 L
.42885 .28779 L
.42891 .28779 L
.42904 .28781 L
.42915 .28784 L
.4294 .2879 L
.42963 .28799 L
.42988 .2881 L
.43038 .28839 L
.43085 .28876 L
.43131 .2892 L
.43179 .28976 L
.43226 .29037 L
.43276 .29111 L
.43324 .29191 L
.4337 .29276 L
.43419 .29374 L
.43466 .29476 L
.43511 .29581 L
.43559 .29699 L
.43606 .29819 L
.43655 .29953 L
.43703 .30088 L
.43749 .30222 L
.43797 .3037 L
.43844 .30517 L
Mistroke
.43894 .30677 L
.43942 .30834 L
.43988 .30988 L
.44038 .31153 L
.44085 .31314 L
.4413 .3147 L
.44179 .31635 L
.44226 .31794 L
.44275 .31962 L
.44323 .32121 L
.44369 .32272 L
.44418 .3243 L
.44465 .32578 L
.44515 .3273 L
.44563 .32871 L
.44609 .33002 L
.44659 .33134 L
.44706 .33254 L
.44752 .33362 L
.44801 .33469 L
.44847 .33563 L
.44897 .33654 L
.44945 .3373 L
.44991 .33795 L
.4504 .33852 L
.45087 .33895 L
.45133 .33926 L
.45156 .33938 L
.45181 .33948 L
.45193 .33951 L
.452 .33953 L
.45207 .33954 L
.45213 .33955 L
.45219 .33956 L
.45222 .33956 L
.45225 .33956 L
.45228 .33956 L
.45231 .33956 L
.45232 .33957 L
.45234 .33957 L
.45235 .33957 L
.45236 .33957 L
.45238 .33957 L
.45239 .33957 L
.45239 .33957 L
.45241 .33957 L
.45242 .33957 L
.45244 .33957 L
.45245 .33956 L
.45248 .33956 L
Mistroke
.4525 .33956 L
.45253 .33956 L
.4526 .33955 L
.45266 .33954 L
.45278 .33952 L
.4529 .33949 L
.45304 .33945 L
.45328 .33934 L
.45352 .3392 L
.45377 .33902 L
.45423 .3386 L
.45471 .33803 L
.45518 .33734 L
.45567 .33648 L
.45615 .33551 L
.45661 .33445 L
.4571 .33319 L
.45757 .33186 L
.45807 .33031 L
.45855 .32869 L
.45901 .32701 L
.4595 .32511 L
.45998 .32318 L
.46043 .32122 L
.46092 .31903 L
.46139 .31684 L
.46189 .31442 L
.46236 .31201 L
.46283 .30962 L
.46332 .30702 L
.46379 .30446 L
.46424 .30196 L
.46472 .29926 L
.46519 .29663 L
.46568 .29383 L
.46616 .29112 L
.46662 .28852 L
.46711 .28577 L
.46758 .28315 L
.46807 .28041 L
.46855 .27782 L
.46902 .27538 L
.46951 .27287 L
.46998 .27054 L
.47044 .2684 L
.47092 .26622 L
.47139 .26425 L
.47189 .26229 L
.47236 .26056 L
.47282 .25904 L
Mistroke
.47331 .2576 L
.47378 .2564 L
.47424 .25542 L
.47472 .25459 L
.47518 .25399 L
.47542 .25377 L
.47554 .25368 L
.47568 .25359 L
.4758 .25353 L
.47591 .25349 L
.47597 .25348 L
.47603 .25347 L
.47605 .25346 L
.47608 .25346 L
.47611 .25346 L
.47612 .25345 L
.47613 .25345 L
.47615 .25345 L
.47616 .25345 L
.47617 .25345 L
.47618 .25345 L
.4762 .25345 L
.47621 .25345 L
.47622 .25345 L
.47624 .25345 L
.47625 .25345 L
.47628 .25346 L
.47631 .25346 L
.47637 .25347 L
.47643 .25348 L
.47649 .2535 L
.47662 .25355 L
.47674 .25362 L
.47685 .25369 L
.4771 .25391 L
.47732 .25417 L
.47757 .25453 L
.47805 .25544 L
.47851 .25659 L
.47901 .25812 L
.47948 .25989 L
.47994 .26189 L
.48043 .26433 L
.4809 .26699 L
.4814 .27016 L
.48188 .27356 L
.48234 .27714 L
.48283 .2813 L
.4833 .28564 L
.48376 .29012 L
Mistroke
.48424 .29524 L
.48471 .3005 L
.4852 .30644 L
.48568 .31252 L
.48614 .31867 L
.48663 .32557 L
.4871 .33253 L
.4876 .34028 L
.48808 .34808 L
.48855 .35589 L
.48904 .36452 L
.48951 .37313 L
.48997 .38169 L
.49046 .39109 L
.49093 .40041 L
.49142 .4106 L
.4919 .42068 L
.49236 .43061 L
.49285 .44142 L
.49333 .45205 L
.49378 .46247 L
.49426 .47376 L
.49473 .4848 L
.49522 .49672 L
.4957 .50837 L
.49616 .5197 L
.49665 .53189 L
.49711 .54374 L
.49761 .55643 L
.49809 .56875 L
.49856 .58066 L
.49905 .59338 L
.49952 .60566 L
.49976 .61184 L
.49987 .61454 L
.49992 .61597 L
.49995 .61675 L
.49998 .61748 L
.49999 .61785 L
.50001 .00022 L
.50002 .00044 L
.50003 .00066 L
.50004 .00107 L
.5001 .00257 L
.50021 .00553 L
.50046 .01204 L
.50092 .02389 L
.50141 .03648 L
.50188 .04854 L
.50237 .0613 L
Mistroke
.50285 .07351 L
.50332 .08516 L
.50381 .09745 L
.50428 .10915 L
.50473 .12027 L
.50522 .13195 L
.50568 .14303 L
.50618 .15462 L
.50666 .16558 L
.50712 .17592 L
.5076 .1867 L
.50807 .19685 L
.50857 .20737 L
.50906 .21723 L
.50952 .22647 L
.51001 .23601 L
.51049 .24491 L
.51094 .25319 L
.51143 .2617 L
.5119 .26959 L
.51239 .27765 L
.51287 .28508 L
.51333 .29192 L
.51382 .29886 L
.51429 .3052 L
.51475 .31099 L
.51523 .31683 L
.5157 .32211 L
.51619 .32737 L
.51667 .3321 L
.51712 .33633 L
.51761 .34048 L
.51808 .34415 L
.51858 .3477 L
.51906 .35079 L
.51952 .35344 L
.52001 .35594 L
.52049 .35802 L
.52094 .35975 L
.52143 .36128 L
.52189 .36247 L
.52213 .36297 L
.52239 .36344 L
.52262 .36378 L
.52287 .36408 L
.5231 .3643 L
.52323 .3644 L
.52336 .36447 L
.52347 .36452 L
.52353 .36454 L
Mistroke
.5236 .36456 L
.52365 .36457 L
.52368 .36457 L
.52371 .36458 L
.52374 .36458 L
.52375 .36458 L
.52377 .36458 L
.52378 .36458 L
.52379 .36458 L
.52381 .36458 L
.52382 .36458 L
.52383 .36458 L
.52384 .36458 L
.52385 .36458 L
.52387 .36458 L
.52388 .36458 L
.52391 .36458 L
.52394 .36457 L
.52401 .36456 L
.52406 .36455 L
.52417 .36451 L
.52429 .36446 L
.52452 .36431 L
.52474 .36412 L
.52521 .36355 L
.5257 .36272 L
.52618 .36171 L
.52664 .36055 L
.52713 .35913 L
.5276 .35759 L
.52806 .35596 L
.52854 .35407 L
.52901 .35213 L
.5295 .34993 L
.52997 .3477 L
.53043 .34546 L
.53092 .34298 L
.53139 .34052 L
.53189 .33784 L
.53237 .33521 L
.53283 .33264 L
.53332 .32987 L
.53379 .32718 L
.53425 .3246 L
.53473 .32185 L
.5352 .31921 L
.53569 .31644 L
.53617 .3138 L
.53663 .31131 L
.53712 .30871 L
Mistroke
.53759 .30626 L
.53809 .30374 L
.53857 .30139 L
.53903 .29921 L
.53953 .29698 L
.54 .29494 L
.54046 .29307 L
.54094 .29119 L
.54141 .28949 L
.54191 .28781 L
.54239 .28631 L
.54285 .28499 L
.54334 .28371 L
.54381 .28262 L
.54427 .28168 L
.54475 .28082 L
.54521 .28011 L
.54571 .2795 L
.54618 .27905 L
.54664 .27873 L
.54688 .27862 L
.54701 .27857 L
.54713 .27853 L
.54725 .2785 L
.54732 .27849 L
.54739 .27848 L
.54745 .27848 L
.54748 .27847 L
.5475 .27847 L
.54752 .27847 L
.54753 .27847 L
.54755 .27847 L
.54756 .27847 L
.54758 .27847 L
.54759 .27847 L
.5476 .27847 L
.54761 .27847 L
.54762 .27847 L
.54763 .27847 L
.54764 .27847 L
.54766 .27847 L
.54767 .27847 L
.54769 .27847 L
.54772 .27847 L
.54775 .27847 L
.5478 .27848 L
.54786 .27848 L
.54797 .2785 L
.5481 .27853 L
.54823 .27857 L
Mistroke
.54834 .27861 L
.54859 .27872 L
.54907 .27903 L
.54952 .27944 L
.55001 .27999 L
.55048 .28063 L
.55098 .28142 L
.55146 .28228 L
.55193 .2832 L
.55242 .28427 L
.55289 .28539 L
.55335 .28653 L
.55384 .28782 L
.5543 .28913 L
.5548 .29058 L
.55528 .29203 L
.55574 .29347 L
.55623 .29504 L
.5567 .29659 L
.55715 .2981 L
.55764 .29973 L
.5581 .30131 L
.5586 .303 L
.55907 .30462 L
.55953 .30618 L
.56002 .30782 L
.56049 .30939 L
.56098 .31102 L
.56146 .31257 L
.56193 .31402 L
.56242 .31553 L
.56289 .31693 L
.56335 .31823 L
.56383 .31955 L
.5643 .32077 L
.56479 .322 L
.56527 .32311 L
.56573 .32412 L
.56622 .32511 L
.56669 .32599 L
.56719 .32683 L
.56767 .32757 L
.56814 .32819 L
.56863 .32876 L
.5691 .32923 L
.56956 .3296 L
.57005 .3299 L
.57027 .33001 L
.57051 .3301 L
.57065 .33015 L
Mistroke
.57077 .33018 L
.5709 .33021 L
.57101 .33023 L
.57112 .33024 L
.57118 .33025 L
.57124 .33025 L
.5713 .33026 L
.57133 .33026 L
.57135 .33026 L
.57136 .33026 L
.57138 .33026 L
.57139 .33026 L
.57139 .33026 L
.57141 .33026 L
.57142 .33026 L
.57144 .33026 L
.57145 .33026 L
.57147 .33026 L
.57148 .33026 L
.57148 .33026 L
.57151 .33026 L
.57154 .33026 L
.57157 .33026 L
.5716 .33026 L
.57166 .33025 L
.57171 .33025 L
.57184 .33023 L
.57196 .33021 L
.57219 .33015 L
.57244 .33007 L
.57292 .32985 L
.57339 .32955 L
.57389 .32915 L
.57437 .32869 L
.57483 .32817 L
.57532 .32755 L
.5758 .32689 L
.57625 .32619 L
.57674 .32538 L
.5772 .32455 L
.5777 .32361 L
.57817 .32266 L
.57863 .3217 L
.57912 .32064 L
.57959 .31958 L
.58009 .31843 L
.58057 .31729 L
.58104 .31617 L
.58153 .31496 L
.582 .31379 L
Mistroke
.58246 .31265 L
.58295 .31144 L
.58341 .31028 L
.58391 .30905 L
.58439 .30788 L
.58485 .30677 L
.58534 .30561 L
.58581 .30451 L
.58627 .30348 L
.58675 .30242 L
.58722 .30144 L
.58771 .30043 L
.58819 .29951 L
.58864 .29866 L
.58913 .29781 L
.5896 .29705 L
.5901 .29629 L
.59058 .29562 L
.59104 .29504 L
.59153 .29447 L
.59201 .294 L
.59246 .2936 L
.59295 .29324 L
.59341 .29296 L
.59365 .29284 L
.59391 .29273 L
.59414 .29265 L
.59439 .29258 L
.59463 .29252 L
.59476 .2925 L
.59488 .29249 L
.59499 .29248 L
.59505 .29247 L
.59509 .29247 L
.59512 .29247 L
.59515 .29247 L
.59517 .29247 L
.59519 .29247 L
.5952 .29247 L
.59522 .29247 L
.59523 .29247 L
.59523 .29247 L
.59525 .29247 L
.59526 .29247 L
.59528 .29247 L
.59529 .29247 L
.5953 .29247 L
.59531 .29247 L
.59534 .29247 L
.59537 .29247 L
Mistroke
.5954 .29247 L
.59547 .29248 L
.59553 .29248 L
.59559 .29249 L
.59569 .2925 L
.59581 .29252 L
.59605 .29256 L
.5963 .29263 L
.59679 .29282 L
.59727 .29306 L
.59773 .29335 L
.59822 .29373 L
.59869 .29414 L
.59915 .2946 L
.59963 .29513 L
.60009 .2957 L
.60059 .29635 L
.60106 .29702 L
.60152 .29771 L
.60201 .29848 L
.60248 .29925 L
.60298 .30011 L
.60346 .30097 L
.60392 .30183 L
.60441 .30275 L
.60488 .30367 L
.60534 .30456 L
.60582 .30552 L
.60629 .30645 L
.60678 .30744 L
.60726 .30839 L
.60772 .30931 L
.60821 .31027 L
.60868 .31119 L
.60918 .31215 L
.60966 .31305 L
.61012 .3139 L
.61062 .31477 L
.61109 .31559 L
.61155 .31634 L
.61204 .31711 L
.6125 .31781 L
.613 .31851 L
.61348 .31915 L
.61394 .31972 L
.61443 .32027 L
.6149 .32076 L
.61536 .32118 L
.61584 .32158 L
.61631 .32192 L
Mistroke
.6168 .32221 L
.61728 .32245 L
.61774 .32262 L
.61797 .32269 L
.61822 .32275 L
.61835 .32277 L
.61848 .32279 L
.61861 .3228 L
.61872 .32281 L
.61878 .32282 L
.61884 .32282 L
.61887 .32282 L
.6189 .32282 L
.61892 .32283 L
.61895 .32283 L
.61898 .32283 L
.61899 .32283 L
.61901 .32283 L
.61902 .32283 L
.61904 .32283 L
.61905 .32283 L
.61907 .32283 L
.61908 .32283 L
.61909 .32283 L
.6191 .32283 L
.61913 .32283 L
.61914 .32283 L
.61916 .32283 L
.6192 .32283 L
.61925 .32282 L
.61931 .32282 L
.61943 .32281 L
.61956 .3228 L
.61969 .32278 L
.61994 .32273 L
.62018 .32267 L
.62064 .32252 L
.62113 .32231 L
.6216 .32206 L
.6221 .32173 L
.62258 .32137 L
.62304 .32097 L
.62354 .3205 L
.62401 .32001 L
.62447 .3195 L
.62495 .31891 L
.62542 .31832 L
.62592 .31765 L
.6264 .31697 L
.62686 .31629 L
Mistroke
.62735 .31554 L
.62782 .3148 L
.62827 .31407 L
.62875 .31328 L
.62922 .3125 L
.62971 .31167 L
.63019 .31086 L
.63065 .31008 L
.63113 .30925 L
.6316 .30845 L
.6321 .30761 L
.63258 .30681 L
.63304 .30605 L
.63354 .30526 L
.63401 .30452 L
.63447 .30383 L
.63495 .30312 L
.63542 .30246 L
.63591 .30179 L
.63639 .30117 L
.63685 .30062 L
.63734 .30006 L
.63781 .29956 L
.63831 .29908 L
.63879 .29865 L
.63926 .29828 L
.63975 .29794 L
.64022 .29765 L
.64068 .29742 L
.64117 .29722 L
.64163 .29708 L
.64189 .29702 L
.64213 .29697 L
.64225 .29696 L
.64237 .29694 L
.64248 .29693 L
.64259 .29693 L
.64266 .29692 L
.64269 .29692 L
.64272 .29692 L
.64274 .29692 L
.64277 .29692 L
.6428 .29692 L
.64281 .29692 L
.64283 .29692 L
.64284 .29692 L
.64285 .29692 L
.64286 .29692 L
.64287 .29692 L
.64288 .29692 L
Mistroke
.64289 .29692 L
.6429 .29692 L
.64292 .29692 L
.64295 .29692 L
.64298 .29692 L
.64301 .29692 L
.64308 .29692 L
.64314 .29693 L
.64319 .29693 L
.64331 .29694 L
.64342 .29695 L
.64353 .29697 L
.64377 .29701 L
.64399 .29705 L
.64446 .29719 L
.64495 .29738 L
.64543 .29761 L
.6459 .29787 L
.64639 .2982 L
.64686 .29856 L
.64732 .29894 L
.6478 .29938 L
.64827 .29984 L
.64876 .30036 L
.64924 .3009 L
.6497 .30145 L
.65019 .30206 L
.65066 .30267 L
.65116 .30335 L
.65164 .30402 L
.6521 .30468 L
.65259 .3054 L
.65307 .30611 L
.65353 .30679 L
.65401 .30753 L
.65448 .30824 L
.65498 .309 L
.65546 .30972 L
.65592 .31042 L
.65641 .31115 L
.65688 .31184 L
.65733 .31249 L
.65782 .31317 L
.65828 .3138 L
.65878 .31445 L
.65925 .31506 L
.65971 .31561 L
.6602 .31617 L
.66067 .31669 L
.66117 .3172 L
Mistroke
.66165 .31765 L
.66211 .31806 L
.6626 .31845 L
.66307 .31879 L
.66353 .31908 L
.66401 .31934 L
.66448 .31956 L
.66498 .31974 L
.66523 .31982 L
.66546 .31987 L
.66569 .31992 L
.66591 .31996 L
.66614 .31999 L
.66626 .32 L
.66632 .32 L
.66639 .32001 L
.66645 .32001 L
.6665 .32001 L
.66653 .32001 L
.66656 .32001 L
.66659 .32001 L
.66661 .32002 L
.66662 .32002 L
.66663 .32002 L
.66664 .32002 L
.66666 .32002 L
.66667 .32002 L
.66668 .32002 L
.66669 .32002 L
.6667 .32002 L
.66672 .32002 L
.66673 .32002 L
.66675 .32001 L
.66678 .32001 L
.66682 .32001 L
.66688 .32001 L
.66694 .32001 L
.66699 .32001 L
.66712 .32 L
.66724 .31998 L
.66737 .31997 L
.66763 .31993 L
.66787 .31988 L
.66833 .31975 L
.66882 .31958 L
.66929 .31936 L
.66974 .31912 L
.67023 .31883 L
.67069 .31851 L
.67119 .31813 L
Mistroke
.67166 .31773 L
.67212 .31731 L
.67261 .31684 L
.67308 .31635 L
.67357 .3158 L
.67405 .31525 L
.67452 .31469 L
.67501 .31408 L
.67548 .31347 L
.67594 .31288 L
.67642 .31222 L
.67689 .31159 L
.67738 .3109 L
.67786 .31023 L
.67832 .30959 L
.67881 .3089 L
.67928 .30824 L
.67978 .30755 L
.68026 .30689 L
.68072 .30626 L
.68122 .30561 L
.68169 .30499 L
.68215 .30442 L
.68264 .30382 L
.6831 .30328 L
.6836 .30272 L
.68408 .30221 L
.68454 .30174 L
.68503 .30128 L
.6855 .30087 L
.68596 .3005 L
.68644 .30015 L
.68691 .29984 L
.6874 .29955 L
.68788 .29931 L
.68834 .29912 L
.68882 .29895 L
.68929 .29883 L
.68955 .29878 L
.68967 .29876 L
.68979 .29875 L
.68991 .29873 L
.69003 .29872 L
.69015 .29871 L
.6902 .29871 L
.69026 .29871 L
.69032 .29871 L
.69035 .29871 L
.69038 .29871 L
.69039 .29871 L
Mistroke
.69041 .29871 L
.69042 .29871 L
.69044 .29871 L
.69045 .29871 L
.69046 .29871 L
.69047 .29871 L
.69048 .29871 L
.6905 .29871 L
.69051 .29871 L
.69053 .29871 L
.69054 .29871 L
.69056 .29871 L
.69059 .29871 L
.69062 .29871 L
.69067 .29871 L
.69072 .29871 L
.69085 .29872 L
.69097 .29873 L
.69119 .29875 L
.69143 .29879 L
.69165 .29883 L
.69212 .29895 L
.69262 .29911 L
.6931 .29932 L
.69356 .29955 L
.69405 .29983 L
.69453 .30014 L
.69499 .30047 L
.69547 .30086 L
.69594 .30126 L
.69644 .30172 L
.69691 .30219 L
.69737 .30267 L
.69786 .3032 L
.69834 .30374 L
.69879 .30427 L
.69927 .30485 L
.69974 .30543 L
.70023 .30606 L
.70071 .30668 L
.70117 .30728 L
.70165 .30793 L
.70212 .30855 L
.70262 .30922 L
.7031 .30986 L
.70357 .31047 L
.70406 .31111 L
.70453 .31172 L
.70499 .3123 L
.70547 .3129 L
Mistroke
.70594 .31346 L
.70643 .31404 L
.70691 .31457 L
.70737 .31506 L
.70786 .31556 L
.70833 .31602 L
.70878 .31643 L
.70926 .31684 L
.70973 .3172 L
.71022 .31755 L
.7107 .31785 L
.71115 .31811 L
.71164 .31835 L
.71211 .31854 L
.71261 .31871 L
.71286 .31877 L
.71309 .31883 L
.71332 .31887 L
.71355 .3189 L
.71377 .31893 L
.71389 .31894 L
.71396 .31894 L
.71402 .31894 L
.71408 .31895 L
.71414 .31895 L
.71418 .31895 L
.71419 .31895 L
.71421 .31895 L
.71422 .31895 L
.71424 .31895 L
.71425 .31895 L
.71426 .31895 L
.71426 .31895 L
.71427 .31895 L
.71428 .31895 L
.71429 .31895 L
.7143 .31895 L
.71431 .31895 L
.71432 .31895 L
.71434 .31895 L
.71435 .31895 L
.71437 .31895 L
.7144 .31895 L
.71443 .31895 L
.71446 .31895 L
.71451 .31895 L
.71458 .31894 L
.71464 .31894 L
.71475 .31893 L
.71487 .31892 L
Mistroke
.715 .31891 L
.71524 .31887 L
.71549 .31882 L
.71595 .31871 L
.71643 .31855 L
.7169 .31837 L
.71739 .31813 L
.71787 .31786 L
.71833 .31757 L
.71882 .31723 L
.71929 .31686 L
.71979 .31645 L
.72027 .31601 L
.72074 .31557 L
.72123 .31507 L
.7217 .31457 L
.72216 .31407 L
.72265 .31351 L
.72311 .31296 L
.72361 .31235 L
.72409 .31176 L
.72455 .31117 L
.72504 .31055 L
.72551 .30994 L
.72597 .30935 L
.72645 .30872 L
.72692 .30811 L
.72741 .30748 L
.72789 .30687 L
.72834 .30629 L
.72883 .30569 L
.7293 .30512 L
.7298 .30454 L
.73028 .30399 L
.73074 .30348 L
.73124 .30297 L
.73171 .3025 L
.73216 .30207 L
.73265 .30164 L
.73312 .30125 L
.73361 .30088 L
.73409 .30055 L
.73455 .30026 L
.73504 .29999 L
.73551 .29977 L
.73596 .29959 L
.73645 .29944 L
.73691 .29932 L
.73715 .29928 L
.73727 .29926 L
Mistroke
.7374 .29925 L
.73753 .29923 L
.73764 .29922 L
.73775 .29921 L
.73786 .29921 L
.73792 .29921 L
.73795 .29921 L
.73798 .29921 L
.73801 .29921 L
.73803 .29921 L
.73804 .29921 L
.73806 .29921 L
.73807 .29921 L
.73809 .2992 L
.73809 .2992 L
.7381 .2992 L
.73812 .29921 L
.73813 .29921 L
.73814 .29921 L
.73816 .29921 L
.73819 .29921 L
.73822 .29921 L
.73827 .29921 L
.73832 .29921 L
.73839 .29921 L
.73845 .29922 L
.73858 .29922 L
.7387 .29924 L
.73882 .29925 L
.73905 .29928 L
.73927 .29932 L
.73974 .29944 L
.74023 .29959 L
.74071 .29978 L
.74117 .3 L
.74165 .30027 L
.74212 .30056 L
.74262 .30091 L
.7431 .30127 L
.74356 .30166 L
.74405 .30209 L
.74453 .30254 L
.74498 .303 L
.74547 .30351 L
.74593 .30402 L
.74643 .30458 L
.74691 .30514 L
.74737 .3057 L
.74786 .3063 L
.74833 .3069 L
Mistroke
.74883 .30753 L
.74931 .30816 L
.74977 .30876 L
.75027 .3094 L
.75074 .31002 L
.7512 .31061 L
.75168 .31123 L
.75215 .31182 L
.75265 .31244 L
.75313 .31302 L
.75359 .31356 L
.75408 .31412 L
.75455 .31464 L
.75501 .31512 L
.75549 .3156 L
.75596 .31605 L
.75645 .31649 L
.75693 .31689 L
.75739 .31724 L
.75787 .31758 L
.75834 .31787 L
.75884 .31815 L
.75932 .31838 L
.75979 .31856 L
.76028 .31872 L
.76052 .31879 L
.76075 .31884 L
.76099 .31888 L
.76121 .31891 L
.76133 .31892 L
.76145 .31893 L
.76157 .31894 L
.76168 .31895 L
.76173 .31895 L
.76176 .31895 L
.76179 .31895 L
.76182 .31895 L
.76183 .31895 L
.76185 .31895 L
.76186 .31895 L
.76187 .31895 L
.76189 .31895 L
.7619 .31895 L
.76191 .31895 L
.76193 .31895 L
.76194 .31895 L
.76195 .31895 L
.76196 .31895 L
.76198 .31895 L
.76199 .31895 L
Mistroke
.76202 .31895 L
.76205 .31895 L
.76208 .31895 L
.76215 .31895 L
.76221 .31894 L
.76227 .31894 L
.76239 .31893 L
.76262 .31891 L
.76286 .31887 L
.76311 .31882 L
.76357 .31871 L
.76405 .31855 L
.76452 .31836 L
.76502 .31812 L
.7655 .31785 L
.76596 .31756 L
.76645 .31721 L
.76692 .31684 L
.76737 .31646 L
.76786 .31602 L
.76832 .31557 L
.76881 .31507 L
.76929 .31456 L
.76975 .31405 L
.77024 .31348 L
.77071 .31292 L
.7712 .3123 L
.77169 .31169 L
.77215 .31109 L
.77264 .31045 L
.77311 .30982 L
.77357 .30922 L
.77405 .30857 L
.77452 .30795 L
.77502 .30729 L
.77549 .30666 L
.77595 .30607 L
.77644 .30545 L
.77691 .30486 L
.77737 .30431 L
.77785 .30374 L
.77831 .30321 L
.77881 .30268 L
.77928 .30218 L
.77974 .30173 L
.78022 .30128 L
.78069 .30088 L
.78119 .30048 L
.78167 .30013 L
.78213 .29983 L
Mistroke
.78262 .29955 L
.7831 .29931 L
.78355 .29912 L
.78403 .29896 L
.7845 .29884 L
.78475 .29879 L
.78499 .29875 L
.78511 .29874 L
.78523 .29873 L
.78535 .29872 L
.78545 .29871 L
.78551 .29871 L
.78554 .29871 L
.78557 .29871 L
.7856 .29871 L
.78563 .29871 L
.78565 .29871 L
.78567 .29871 L
.78568 .29871 L
.7857 .29871 L
.78571 .29871 L
.78572 .29871 L
.78573 .29871 L
.78575 .29871 L
.78576 .29871 L
.78578 .29871 L
.7858 .29871 L
.78584 .29871 L
.78587 .29871 L
.78593 .29871 L
.78599 .29871 L
.78606 .29872 L
.78618 .29872 L
.7863 .29874 L
.7864 .29875 L
.78663 .29878 L
.78688 .29883 L
.78736 .29895 L
.78783 .29911 L
.78832 .29931 L
.7888 .29955 L
.78926 .29982 L
.78975 .30014 L
.79022 .30049 L
.79072 .3009 L
.7912 .30132 L
.79166 .30176 L
.79216 .30226 L
.79263 .30276 L
.79309 .30328 L
Mistroke
.79357 .30385 L
.79404 .30442 L
.79454 .30504 L
.79502 .30567 L
.79548 .30628 L
.79597 .30694 L
.79644 .30759 L
.7969 .30822 L
.79738 .3089 L
.79785 .30955 L
.79834 .31025 L
.79882 .31091 L
.79927 .31155 L
.79976 .31221 L
.80023 .31285 L
.80073 .3135 L
.80121 .31412 L
.80167 .31469 L
.80217 .31528 L
.80264 .31583 L
.8031 .31633 L
.80358 .31683 L
.80405 .31729 L
.80454 .31774 L
.80502 .31814 L
.80548 .3185 L
.80597 .31883 L
.80644 .31912 L
.8069 .31936 L
.80738 .31958 L
.80784 .31975 L
.80808 .31982 L
.80834 .31988 L
.80859 .31993 L
.80881 .31997 L
.80892 .31998 L
.80905 .31999 L
.80911 .32 L
.80918 .32 L
.80924 .32001 L
.8093 .32001 L
.80933 .32001 L
.80936 .32001 L
.80939 .32001 L
.80941 .32001 L
.80944 .32001 L
.80945 .32002 L
.80947 .32002 L
.80948 .32002 L
.8095 .32002 L
Mistroke
.80951 .32002 L
.80952 .32002 L
.80954 .32002 L
.80955 .32002 L
.80957 .32002 L
.80958 .32002 L
.8096 .32002 L
.80961 .32001 L
.80964 .32001 L
.80968 .32001 L
.80971 .32001 L
.80977 .32001 L
.80988 .32 L
.81001 .31999 L
.81023 .31997 L
.81047 .31993 L
.81072 .31988 L
.81118 .31975 L
.81166 .31958 L
.81213 .31936 L
.81263 .31909 L
.81311 .31879 L
.81357 .31846 L
.81407 .31807 L
.81454 .31766 L
.815 .31723 L
.81548 .31673 L
.81595 .31623 L
.81644 .31566 L
.81692 .31508 L
.81738 .3145 L
.81787 .31386 L
.81834 .31321 L
.81884 .31251 L
.81932 .31182 L
.81979 .31114 L
.82028 .31041 L
.82075 .30969 L
.82121 .309 L
.8217 .30826 L
.82217 .30755 L
.82266 .30679 L
.82314 .30607 L
.8236 .30539 L
.82409 .30467 L
.82457 .304 L
.82502 .30337 L
.8255 .30271 L
.82597 .3021 L
.82647 .30148 L
Mistroke
.82694 .30091 L
.8274 .30039 L
.82789 .29987 L
.82836 .29941 L
.82886 .29895 L
.82934 .29855 L
.8298 .2982 L
.83029 .29788 L
.83077 .2976 L
.83122 .29738 L
.83171 .2972 L
.83218 .29706 L
.83243 .29701 L
.83255 .29698 L
.83267 .29697 L
.83279 .29695 L
.83291 .29694 L
.83297 .29693 L
.83303 .29693 L
.83308 .29693 L
.83313 .29692 L
.83316 .29692 L
.83319 .29692 L
.83322 .29692 L
.83325 .29692 L
.83326 .29692 L
.83328 .29692 L
.83329 .29692 L
.8333 .29692 L
.83331 .29692 L
.83333 .29692 L
.83334 .29692 L
.83335 .29692 L
.83336 .29692 L
.83337 .29692 L
.83338 .29692 L
.83339 .29692 L
.83341 .29692 L
.83344 .29692 L
.83347 .29692 L
.8335 .29692 L
.83356 .29692 L
.83363 .29693 L
.83374 .29694 L
.83386 .29695 L
.83408 .29698 L
.83434 .29703 L
.83458 .29708 L
.83504 .29723 L
.83553 .29743 L
Mistroke
.836 .29767 L
.83646 .29795 L
.83694 .29829 L
.83741 .29866 L
.8379 .29909 L
.83838 .29956 L
.83883 .30004 L
.83932 .30059 L
.83979 .30116 L
.84029 .3018 L
.84077 .30245 L
.84123 .30311 L
.84173 .30383 L
.8422 .30455 L
.84265 .30526 L
.84314 .30604 L
.84361 .30681 L
.8441 .30763 L
.84458 .30844 L
.84504 .30922 L
.84553 .31005 L
.846 .31086 L
.84645 .31163 L
.84694 .31244 L
.8474 .31322 L
.84789 .31403 L
.84837 .3148 L
.84883 .31551 L
.84931 .31626 L
.84978 .31695 L
.85028 .31765 L
.85076 .3183 L
.85122 .31889 L
.85171 .31948 L
.85218 .32001 L
.85264 .32049 L
.85312 .32095 L
.85359 .32135 L
.85408 .32172 L
.85456 .32204 L
.85502 .32229 L
.85551 .32251 L
.85598 .32266 L
.85623 .32273 L
.85635 .32275 L
.85648 .32277 L
.85659 .32279 L
.85672 .32281 L
.85677 .32281 L
.85683 .32282 L
Mistroke
.85688 .32282 L
.85694 .32282 L
.85697 .32282 L
.857 .32283 L
.85703 .32283 L
.85706 .32283 L
.85708 .32283 L
.85709 .32283 L
.8571 .32283 L
.85711 .32283 L
.85712 .32283 L
.85713 .32283 L
.85714 .32283 L
.85715 .32283 L
.85716 .32283 L
.85716 .32283 L
.85718 .32283 L
.85719 .32283 L
.85721 .32283 L
.85722 .32283 L
.85725 .32283 L
.85728 .32283 L
.85731 .32282 L
.85737 .32282 L
.85744 .32282 L
.85756 .32281 L
.85767 .32279 L
.85792 .32275 L
.85816 .3227 L
.85841 .32263 L
.8589 .32245 L
.85937 .32222 L
.85983 .32195 L
.86032 .32161 L
.86079 .32123 L
.86128 .32077 L
.86176 .32027 L
.86222 .31975 L
.86271 .31915 L
.86319 .31852 L
.86364 .31788 L
.86412 .31716 L
.86459 .31643 L
.86508 .31561 L
.86556 .3148 L
.86602 .31398 L
.86651 .31309 L
.86698 .31221 L
.86748 .31126 L
.86796 .31032 L
Mistroke
.86842 .30941 L
.86891 .30843 L
.86938 .30748 L
.86984 .30657 L
.87033 .3056 L
.87079 .30468 L
.87129 .3037 L
.87177 .30278 L
.87223 .30191 L
.87272 .30101 L
.87319 .30016 L
.87364 .29938 L
.87412 .29857 L
.87459 .29783 L
.87508 .29708 L
.87556 .29641 L
.87601 .2958 L
.8765 .2952 L
.87697 .29467 L
.87747 .29417 L
.87795 .29374 L
.87841 .29339 L
.8789 .29307 L
.87937 .29283 L
.87983 .29265 L
.88006 .29258 L
.88031 .29253 L
.88043 .29251 L
.88057 .29249 L
.88063 .29249 L
.88069 .29248 L
.88075 .29248 L
.88081 .29247 L
.88084 .29247 L
.88087 .29247 L
.88088 .29247 L
.8809 .29247 L
.88091 .29247 L
.88093 .29247 L
.88094 .29247 L
.88096 .29247 L
.88097 .29247 L
.88099 .29247 L
.881 .29247 L
.88101 .29247 L
.88104 .29247 L
.88107 .29247 L
.8811 .29247 L
.88116 .29248 L
.88122 .29248 L
Mistroke
.88129 .29249 L
.88141 .2925 L
.88153 .29252 L
.88178 .29257 L
.88201 .29263 L
.88226 .29272 L
.88275 .29294 L
.88322 .29323 L
.88368 .29356 L
.88416 .29398 L
.88463 .29445 L
.88513 .29501 L
.8856 .29561 L
.88606 .29625 L
.88655 .29699 L
.88702 .29775 L
.88748 .29854 L
.88796 .29942 L
.88842 .30032 L
.88892 .30131 L
.88939 .30232 L
.88985 .30332 L
.89033 .30441 L
.8908 .3055 L
.8913 .30667 L
.89178 .30783 L
.89224 .30896 L
.89273 .31017 L
.8932 .31135 L
.89366 .31248 L
.89414 .31368 L
.89461 .31483 L
.8951 .31605 L
.89558 .3172 L
.89604 .31829 L
.89653 .31942 L
.897 .32048 L
.8975 .32157 L
.89798 .32258 L
.89844 .32351 L
.89893 .32445 L
.89941 .3253 L
.89986 .32606 L
.90035 .32682 L
.90081 .32748 L
.90131 .32812 L
.90179 .32866 L
.90225 .32911 L
.90274 .32951 L
.90321 .32982 L
Mistroke
.90366 .33004 L
.9039 .33012 L
.90402 .33016 L
.90415 .33019 L
.90426 .33021 L
.90439 .33024 L
.90446 .33024 L
.90452 .33025 L
.90458 .33026 L
.90461 .33026 L
.90464 .33026 L
.90467 .33026 L
.9047 .33026 L
.90471 .33026 L
.90473 .33026 L
.90474 .33026 L
.90476 .33026 L
.90477 .33026 L
.90477 .33026 L
.90479 .33026 L
.9048 .33026 L
.9048 .33026 L
.90482 .33026 L
.90484 .33026 L
.90485 .33026 L
.90488 .33026 L
.90494 .33026 L
.905 .33025 L
.9051 .33024 L
.90523 .33022 L
.90536 .33019 L
.9056 .33013 L
.90584 .33004 L
.90609 .32993 L
.90654 .32966 L
.90703 .32928 L
.90749 .32884 L
.90799 .32827 L
.90846 .32764 L
.90892 .32696 L
.90941 .32615 L
.90988 .32529 L
.91038 .32429 L
.91086 .32325 L
.91132 .32218 L
.91181 .32097 L
.91229 .31974 L
.91274 .31851 L
.91323 .31713 L
.9137 .31576 L
Mistroke
.91419 .31425 L
.91467 .31275 L
.91513 .31128 L
.91562 .30967 L
.91609 .3081 L
.91654 .30658 L
.91703 .30494 L
.91749 .30336 L
.91798 .30167 L
.91846 .30005 L
.91892 .29851 L
.9194 .29688 L
.91987 .29534 L
.92037 .29373 L
.92085 .29223 L
.92131 .29082 L
.9218 .28938 L
.92227 .28805 L
.92273 .28682 L
.92321 .28559 L
.92368 .28448 L
.92417 .28339 L
.92465 .28243 L
.92511 .28159 L
.9256 .28079 L
.92607 .28013 L
.92657 .27955 L
.92705 .2791 L
.92751 .27877 L
.92775 .27865 L
.92787 .2786 L
.928 .27856 L
.92813 .27852 L
.92824 .2785 L
.92829 .27849 L
.92835 .27848 L
.92841 .27847 L
.92846 .27847 L
.92849 .27847 L
.92852 .27847 L
.92853 .27847 L
.92855 .27847 L
.92855 .27847 L
.92856 .27847 L
.92858 .27847 L
.92859 .27847 L
.92861 .27847 L
.92862 .27847 L
.92863 .27847 L
.92866 .27847 L
Mistroke
.92868 .27847 L
.92871 .27847 L
.92875 .27848 L
.9288 .27848 L
.92887 .27849 L
.92893 .2785 L
.92905 .27853 L
.92916 .27856 L
.92941 .27866 L
.92966 .2788 L
.92988 .27895 L
.93036 .27937 L
.93083 .27991 L
.93132 .28062 L
.93179 .28143 L
.93225 .28234 L
.93274 .28344 L
.93321 .28462 L
.9337 .28602 L
.93418 .28749 L
.93464 .28902 L
.93513 .29077 L
.93561 .29257 L
.93606 .29441 L
.93654 .29646 L
.93701 .29854 L
.93751 .30084 L
.93798 .30315 L
.93844 .30544 L
.93893 .30796 L
.9394 .31044 L
.9399 .31313 L
.94038 .31578 L
.94084 .31836 L
.94133 .32114 L
.94181 .32382 L
.94226 .32642 L
.94275 .32917 L
.94322 .33181 L
.94371 .33459 L
.94419 .33722 L
.94465 .33971 L
.94514 .3423 L
.94561 .34472 L
.94606 .34696 L
.94655 .34926 L
.94701 .35137 L
.94751 .35348 L
.94798 .35538 L
.94844 .35707 L
Mistroke
.94893 .35871 L
.94939 .36013 L
.94989 .36144 L
.95037 .3625 L
.95083 .36333 L
.95107 .36367 L
.95132 .36399 L
.95157 .36423 L
.9518 .3644 L
.95192 .36447 L
.95204 .36452 L
.95215 .36455 L
.95221 .36457 L
.95224 .36457 L
.95226 .36458 L
.95228 .36458 L
.9523 .36458 L
.95231 .36458 L
.95233 .36458 L
.95234 .36458 L
.95235 .36458 L
.95236 .36458 L
.95237 .36458 L
.95238 .36458 L
.95239 .36458 L
.95241 .36458 L
.95242 .36458 L
.95243 .36458 L
.95245 .36458 L
.95248 .36458 L
.95251 .36457 L
.95256 .36456 L
.95262 .36455 L
.95273 .36451 L
.95286 .36446 L
.95297 .36439 L
.95322 .36419 L
.95345 .36394 L
.9537 .36359 L
.95419 .3627 L
.95467 .36155 L
.95512 .36017 L
.95561 .35841 L
.95608 .35641 L
.95657 .35396 L
.95705 .35128 L
.95751 .34839 L
.958 .34499 L
.95847 .34138 L
.95892 .3376 L
Mistroke
.9594 .33324 L
.95987 .32873 L
.96036 .32357 L
.96084 .31826 L
.96129 .31283 L
.96178 .30672 L
.96225 .3005 L
.96275 .29354 L
.96323 .28649 L
.96369 .27939 L
.96418 .27152 L
.96465 .26362 L
.96511 .25573 L
.96559 .24703 L
.96605 .23837 L
.96655 .22886 L
.96703 .21941 L
.96749 .21007 L
.96797 .19987 L
.96844 .1898 L
.96894 .17885 L
.96942 .16806 L
.96989 .15747 L
.97038 .146 L
.97085 .13477 L
.97131 .12381 L
.9718 .11198 L
.97226 .10044 L
.97276 .08805 L
.97324 .07599 L
.9737 .0643 L
.97419 .05177 L
.97466 .03964 L
.97511 .02793 L
.9756 .01542 L
.97606 .00336 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ZGoo1@00^Woo002[Ool00`00Oomoo`2jOol00:1oo`H000Eoo`03001oogoo0;Yo
o`00Zgoo00<007ooOol01Goo0`00UGoo00<007ooOol06Woo002[Ool00`00Oomoo`05Ool00`00Oomo
o`2EOol00`00Oomoo`0JOol00:]oo`03001oogoo00Eoo`03001oogoo09Eoo`03001oogoo01Yoo`00
Zgoo00<007ooOol01Goo00<007ooOol0UGoo00<007ooOol06Woo002YOol30007Ool00`00Oomoo`2D
Ool00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007oo
Ool06goo002cOol00`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03001oogoo
01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=o
o`03001oogoo09Aoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol0
0`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<0
07ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo
0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo
01]oo`00/goo0P00UGoo00<007ooOol06goo002AOol30006Ool20006Ool00`00Oomoo`04Ool40006
Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool0
0`00Oomoo`03Ool2002EOol00`00Oomoo`0KOol008Qoo`H0009oo`05001oogooOol0000>Ool00`00
Oomoo`07Ool00`00Oomoo`03Ool3002DOol00`00Oomoo`0KOol0091oo`05001oogooOol0000>Ool0
0`00Oomoo`07Ool00`00Oomoo`03Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0000>
Ool00`00Oomoo`03Ool40006Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0000;
Ool01@00Oomoogoo000017oo00<007ooOol01goo0P00UGoo00<007ooOol06goo002AOol3000<Ool5
0004Ool40006Ool2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00
U7oo00<007ooOol077oo002cOol2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01ao
o`00/goo0P00U7oo00<007ooOol077oo002cOol2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03
001oogoo01aoo`00/goo00<007oo0000Tgoo00<007ooOol077oo002cOol00`00Ool0002COol00`00
Oomoo`0LOol00;=oo`<009=oo`03001oogoo01aoo`00/goo00<007oo0000Tgoo00<007ooOol077oo
002cOol00`00Ool0002COol00`00Oomoo`0LOol00;=oo`03001oo`0009=oo`03001oogoo01aoo`00
/goo00<007oo0000Tgoo00<007ooOol077oo002cOol3002COol00`00Oomoo`0LOol00;=oo`03001o
o`0009=oo`03001oogoo01aoo`00VGoo0`001Woo0P001Goo10001Woo00<007oo0000Tgoo00<007oo
Ool077oo002HOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00goo00<007oo0000Tgoo00<0
07ooOol077oo002@Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00goo00<007oo0000Tgoo
00<007ooOol077oo002HOol01@00Oomoogoo000047oo00<007ooOol00goo0`00Tgoo00<007ooOol0
77oo002HOol01@00Oomoogoo000037oo10001Woo00<007oo0000Tgoo00<007ooOol077oo002HOol0
1@00Oomoogoo000037oo00<007ooOol01goo00<007oo0000Tgoo00<007ooOol077oo002HOol01@00
Oomoogoo000037oo00<007ooOol01goo00<007oo0000TWoo00<007ooOol07Goo002IOol3000=Ool4
0006Ool00`00Ool0002BOol00`00Oomoo`0MOol00;=oo`<0099oo`03001oogoo01eoo`00/goo00<0
07oo0000TWoo00<007ooOol07Goo002cOol00`00Ool0002BOol00`00Oomoo`0MOol00;=oo`03001o
o`00099oo`03001oogoo01eoo`00/goo00<007oo0000TWoo00<007ooOol07Goo002cOol3002BOol0
0`00Oomoo`0MOol00;=oo`03001oo`00099oo`03001oogoo01eoo`00/goo00@007ooOol0095oo`03
001oogoo01eoo`00/goo00@007ooOol0095oo`03001oogoo01eoo`00/goo00@007ooOol0095oo`03
001oogoo01eoo`00/goo0P0000=oo`00Ool0T7oo00<007ooOol07Goo002cOol01000Oomoo`00TGoo
00<007ooOol07Goo002cOol01000Oomoo`00TGoo00<007ooOol07Goo002cOol01000Oomoo`00TGoo
00<007ooOol07Goo002cOol01000Oomoo`00TGoo00<007ooOol07Goo002cOol200000goo001oo`2@
Ool00`00Oomoo`0MOol00;=oo`04001oogoo002AOol00`00Oomoo`0MOol0095oo`<000Ioo`8000Ao
o`D000Aoo`@000Ioo`04001oogoo002AOol00`00Oomoo`0MOol0091oo`05001oogooOol00005Ool2
0005Ool01000Oomoo`0027oo00<007ooOol00goo00@007ooOol0095oo`03001oogoo01eoo`00R7oo
1P000Woo00D007ooOomoo`0000eoo`03001oogoo00Qoo`03001oogoo00=oo`04001oogoo002AOol0
0`00Oomoo`0MOol0091oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`03Ool4002A
Ool00`00Oomoo`0MOol0091oo`05001oogooOol0000?Ool00`00Oomoo`02Ool40006Ool01000Oomo
o`00T7oo00<007ooOol07Woo002@Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1goo00@007ooOol0091oo`03001oogoo01ioo`00T7oo00D007ooOomoo`0000]oo`05001oogooOol0
0004Ool00`00Oomoo`07Ool01000Oomoo`00T7oo00<007ooOol07Woo002AOol3000=Ool30005Ool4
0006Ool200000goo001oo`2?Ool00`00Oomoo`0NOol00;=oo`04001oogoo002@Ool00`00Oomoo`0N
Ool002=oo`03001oogoo08Eoo`8000Ioo`04001oogoo002@Ool00`00Oomoo`0NOol0029oo`<008Io
o`8000Ioo`04001oogoo002@Ool00`00Oomoo`0NOol0029oo`03001oo`0008Eoo`<000Ioo`05001o
ogooOol0002?Ool00`00Oomoo`0NOol0029oo`03001oo`0008Eoo`04001oogoo0005Ool20002Ool0
0`00Oomoo`2=Ool00`00Oomoo`0NOol0029oo`04001oo`000024Ool01000Oomoo`001Goo00D007oo
Oomoo`0008moo`03001oogoo01ioo`008Goo00D007ooOomoo`0000ioo`<000Ioo`8000Ioo`<002Qo
o`<000Ioo`8000Aoo`D002Ioo`04001oogoo0005Ool01@00Oomoogoo0000;Woo0`001Woo0P0017oo
1@00:7oo0`001Woo0P001Woo0`004Goo00<007ooOol07Woo000QOol01@00Oomoogoo00003Goo00D0
07ooOomoo`0000Eoo`8000Moo`03001oogoo02Ioo`05001oogooOol00005Ool20005Ool01000Oomo
o`009Goo00D007ooOomoo`0000Eoo`05001oogooOol0000]Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol002Moo`05001oogooOol00005Ool20007Ool00`00Oomoo`0@Ool00`00Oomoo`0NOol0
025oo`05001oogooOol00005Ool60002Ool01@00Oomoogoo00002goo1@007goo1P000Woo00D007oo
Oomoo`0000eoo`03001oogoo02Eoo`05001oogooOol00005Ool01@00Oomoogoo0000;Goo00D007oo
Oomoo`0000eoo`03001oogoo02Moo`05001oogooOol0000;Ool5000AOol00`00Oomoo`0NOol0025o
o`05001oogooOol0000=Ool01@00Oomoogoo00002goo00@007ooOol002Qoo`05001oogooOol0000>
Ool00`00Oomoo`0TOol01@00Oomoogoo00001Goo0P000Woo00<007ooOol027oo00<007ooOol087oo
00D007ooOomoo`0000ioo`03001oogoo02Ioo`05001oogooOol0000;Ool01000Oomoo`001Woo0P00
2Woo00<007ooOol07Woo000QOol00`00Oomoo`02Ool00`00Oomoo`0:Ool01@00Oomoogoo000037oo
00<007oo0000:7oo00D007ooOomoo`0000moo`03001oogoo02=oo`03001oogoo009oo`03001oogoo
009oo`05001oogooOol00009Ool3000QOol01@00Oomoogoo00003goo00<007ooOol09Goo00D007oo
Oomoo`0000aoo`03001oo`0000Eoo`<000Yoo`03001oogoo01ioo`008Goo00<007ooOol00Woo00<0
07ooOol02Woo00D007ooOomoo`0000aoo`03001oo`0002Qoo`05001oogooOol0000?Ool00`00Oomo
o`0SOol00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00@007oo0000021oo`05
001oogooOol0000?Ool00`00Oomoo`0UOol01@00Oomoogoo000037oo00<007oo00001Goo00@007oo
Ool000Uoo`03001oogoo01ioo`008Goo00<007ooOol00Woo00<007ooOol02Goo0P000goo00<007oo
Ool02goo0P00:7oo00D007ooOomoo`0000]oo`05001oogooOol0000HOol2000;Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01@00Oomoogoo000027oo00D007ooOomoo`00021oo`05001oogooOol0000;
Ool01@00Oomoogoo00009goo00D007ooOomoo`0000eoo`8000Aoo`80009oo`03001oogoo00Ioo`03
001oogoo01moo`008Goo00<007ooOol00Woo00<007ooOol027oo1P003goo00<007ooOol09goo0`00
3Goo0`0067oo10002Goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Qoo`05001o
ogooOol0000QOol3000=Ool3000YOol3000?Ool00`00Oomoo`02Ool01000Oomoogoo0P001goo00<0
07ooOol07goo000QOol00`00Oomoo`02Ool00`00Oomoo`07Ool20002Ool00`00Oomoo`1SOol20002
Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`06Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool3001HOol3000;Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00
Oomoo`0OOol0021oo`03001oogoo00=oo`03001oogoo00Moo`04001oogooOol2000:Ool4000<Ool2
000/Ool00`00Oomoo`0;Ool3000;Ool01@00Oomoogoo00002Goo00<007ooOol00goo00<007ooOol0
0Woo00D007ooOomoo`0000Qoo`03001oogoo009oo`03001oogoo00Qoo`04001oogoo000<Ool2000j
Ool3000;Ool20002Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0O
Ool0021oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Moo`80009o
o`03001oogoo00Uoo`@000]oo`@000]oo`@000]oo`D000Yoo`80009oo`03001oogoo00Moo`8000Ao
o`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00007Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool01000Oomoogoo0P002Woo10002goo100037oo0`0037oo0`002goo0P00
00=oo`0000002Woo00@007ooOomoo`8000Qoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
01moo`0087oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol01goo00<0
07ooOol00Woo00<007ooOol01goo0P000Woo0P002Goo0P000Woo0P002Goo0P000Woo0P002Goo0P00
0goo00<007ooOol01goo0P000goo0P0027oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000Moo`03001oogoo00=oo`8000Moo`8000Aoo`03001o
ogoo00Moo`03001oogoo009oo`03001oogoo00Moo`80009oo`8000Uoo`80009oo`8000Uoo`8000=o
o`03001oogoo00Moo`8000=oo`8000Qoo`8000Aoo`03001oogoo00Ioo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo01moo`0087oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo
0P001goo00<007ooOol00goo0P001goo0P0017oo0P001goo0P0017oo0P0027oo00<007ooOol00Woo
0P0027oo00<007ooOol00goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol01Woo00<007oo
Ool00goo0P001Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo0P0017oo0P001goo
0P0017oo0P0027oo00<007ooOol00Woo0P0027oo00<007ooOol00goo00<007ooOol01Woo00<007oo
Ool00goo00<007ooOol01Woo00<007ooOol00goo0P001goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol07goo000DOooo0010000EOol001]oo`03001oogoo009oo`03001oogoo00Aoo`05001o
ogooOol00002Ool00`00Oomoo`05Ool20002Ool01000Oomoo`0027oo00@007ooOol0009oo`03001o
ogoo00Ioo`04001oogoo0002Ool20007Ool01000Oomoo`000Woo0P001goo00@007ooOol0009oo`80
00Moo`06001oogooOol007oo0P001goo00D007ooOomoo`00009oo`03001oogoo00Eoo`05001oogoo
Ool00002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool01000
Oomoo`000goo0P001Goo0P000Woo00@007ooOomoo`8000Eoo`05001oogooOol00004Ool00`00Oomo
o`03Ool20003Ool01@00Oomoogoo00001Goo0P000goo00@007ooOomoo`8000Aoo`8000=oo`04001o
ogooOol20004Ool20003Ool01000Oomoogoo0P001Goo00D007ooOomoo`0000=oo`03001oogoo00Ao
o`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0JOol0021oo`03
001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Ioo`05001oogoo001oo`020008Ool20003Ool2
0008Ool20003Ool20009Ool01000Oomoogoo0P002Goo00@007oo001oo`8000Uoo`03001oogoo009o
o`03001oogoo00Ioo`8000Aoo`8000Moo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00=oo`8000Moo`03001oogoo00=oo`03001oogoo00Ioo`8000=o
o`8000Qoo`8000=oo`8000Aoo`03001oogoo009oo`04001oogooOol20009Ool01000Oomoogoo0P00
2Goo0P000goo00<007ooOol01goo00<007ooOol00Woo0P000goo00@007ooOomoo`8000Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo01moo`0087oo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol01Woo0P000goo00<007ooOol027oo0P0000=oo`0000002Woo1@002goo10002goo1000
2Woo0P000Woo0P002Goo0P000goo00<007ooOol01goo00<007ooOol00goo00<007ooOol01Goo00D0
07ooOomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo009oo`8000Uoo`05001o
ogooOol0000:Ool5000;Ool4000;Ool4000;Ool4000:Ool20002Ool20009Ool00`00Oomoo`02Ool2
0007Ool00`00Oomoo`04Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`03001oogoo009oo`80
00Uoo`03001oogoo008000]oo`<003Uoo`@000]oo`03001oogoo008000Uoo`03001oogoo009oo`03
001oogoo00Ioo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomoo`06Ool20003Ool00`00
Oomoo`08Ool4000=Ool2000[Ool2000<Ool4000:Ool20003Ool00`00Oomoo`07Ool00`00Oomoo`03
Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Qoo`@005Mo
o`@000Yoo`03001oogoo009oo`03001oogoo00Ioo`04001oogooOol20003Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool00`00Oomoo`02000<Ool00`00Oomoo`18Ool2000<Ool00`00Oomoo`020009Ool0
0`00Oomoo`03Ool00`00Oomoo`0OOol0021oo`03001oogoo00Eoo`8000=oo`03001oogoo079oo`05
001oogooOol00008Ool01@00Oomoogoo000017oo00<007ooOol00goo00<007ooOol01goo0P0000=o
o`00Ool0IGoo0P0000=oo`00Ool02Goo00<007ooOol00Woo00<007ooOol087oo000OOol00`00Oomo
o`07Ool00`00Oomoo`02001dOol00`00Oomoo`020008Ool01@00Oomoogoo000017oo00<007ooOol0
0goo00<007ooOol027oo0`00Igoo0`002Woo00<007ooOol00Woo00<007ooOol087oo000OOol00`00
Oomoo`07Ool01000Oomoo`00MGoo00@007ooOol000Uoo`05001oogooOol00004Ool00`00Oomoo`02
Ool00`00Oomoo`20Ool00`00Oomoo`02Ool00`00Oomoo`0POol001moo`03001oogoo00Moo`@007Io
o`03001oo`0000Uoo`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`20Ool00`00Oomo
o`02Ool00`00Oomoo`0POol001moo`03001oogoo00Qoo`8007Moo`8000Yoo`04001oogooOol20004
Ool01@00Oomoogoo0000Pgoo00D007ooOomoo`00029oo`007goo00<007ooOol0SGoo00D007ooOomo
o`0000Eoo`05001oogooOol00023Ool01@00Oomoogoo00008Woo000OOol00`00Oomoo`2=Ool01@00
Oomoogoo00001Goo00D007ooOomoo`0008=oo`05001oogooOol0000ROol001moo`03001oogoo08eo
o`05001oogooOol00005Ool01000Oomoo`00Q7oo00D007ooOomoo`00029oo`007goo00<007ooOol0
SGoo00D007ooOomoo`0000Eoo`04001oogoo0024Ool00`00Oomoo`02000ROol001moo`03001oogoo
08eoo`04001oogooOol20004Ool01000Oomoo`00QGoo00<007oo00008goo000OOol00`00Oomoo`2=
Ool01@00Oomoogoo00001Woo00<007oo0000QGoo00<007oo00008goo000OOol00`00Oomoo`2>Ool0
1000Oomoo`001Woo0P00QWoo0`008goo000OOol00`00Oomoo`2>Ool01000Oomoo`001Woo0P00Qgoo
00<007ooOol08Woo000OOol00`00Oomoo`2>Ool01000Oomoo`00]7oo000OOol00`00Oomoo`2>Ool0
0`00Oomoo`02002cOol001moo`03001oogoo08ioo`04001oogoo002dOol001moo`03001oogoo06mo
o`<000Ioo`8000Aoo`D000Aoo`@000=oo`04001oogoo002dOol001moo`03001oogoo06ioo`05001o
ogooOol00005Ool20005Ool01000Oomoo`0027oo00@007ooOol0009oo`03001oogoo0;9oo`007goo
00<007ooOol0KWoo00D007ooOomoo`0000eoo`03001oogoo00Qoo`04001oogoo0002Ool00`00Oomo
o`2bOol001ioo`03001oogoo06moo`05001oogooOol0000>Ool00`00Oomoo`07Ool01000Oomoo`00
0Woo0`00/Woo000NOol00`00Oomoo`1_Ool01@00Oomoogoo00003goo00<007ooOol00Woo10000goo
00@007ooOol00;Aoo`007Woo00<007ooOol0Kgoo00D007ooOomoo`0000moo`03001oogoo009oo`03
001oogoo00Aoo`04001oogoo002dOol001ioo`03001oogoo06moo`05001oogooOol0000;Ool01@00
Oomoogoo000017oo00<007ooOol017oo00@007ooOol00;Aoo`007Woo00<007ooOol0L7oo0`003Goo
0`001Goo10000goo00@007ooOol00;Aoo`007Woo00<007ooOol0Sgoo00<007ooOol00P00/goo000N
Ool00`00Oomoo`2?Ool01000Oomoo`00]7oo000NOol00`00Oomoo`2?Ool01000Oomoo`00]7oo000N
Ool00`00Oomoo`2?Ool01000Oomoo`00]7oo000NOol00`00Oomoo`2?Ool01000Oomoo`00]7oo000N
Ool00`00Oomoo`2?Ool00`00Oomoo`02002cOol001ioo`03001oogoo08moo`04001oogoo002dOol0
01ioo`03001oogoo08moo`04001oogoo002dOol001ioo`03001oogoo091oo`03001oo`000;Aoo`00
7Woo00<007ooOol0T7oo00@007oo00000;=oo`007Woo00<007ooOol0T7oo00<007oo0000]7oo000N
Ool00`00Oomoo`2@Ool00`00Ool0002dOol001ioo`03001oogoo091oo`03001oo`000;Aoo`007Woo
00<007ooOol0T7oo00<007oo0000]7oo000NOol00`00Oomoo`2@Ool01000Ool00000/goo000NOol0
0`00Oomoo`2@Ool00`00Ool0002dOol001ioo`03001oogoo091oo`03001oo`000;Aoo`007Woo00<0
07ooOol0N7oo0`001Woo0P001Goo100017oo00<007oo0000]7oo000MOol00`00Oomoo`1hOol01@00
Oomoogoo00001Goo0P002Goo00L007ooOomoo`00Ool0002dOol001eoo`03001oogoo07Qoo`05001o
ogooOol0000@Ool01P00Oomoogoo001oo`<00;9oo`007Goo00<007ooOol0N7oo00D007ooOomoo`00
011oo`07001oogooOol007oo0000]7oo000MOol00`00Oomoo`1hOol01@00Oomoogoo000037oo1000
17oo00<007oo0000]7oo000MOol00`00Oomoo`1hOol01@00Oomoogoo000037oo00<007ooOol01Goo
00<007oo0000]7oo000MOol00`00Oomoo`1hOol01@00Oomoogoo000037oo00<007ooOol01Goo00<0
07oo0000]7oo000MOol00`00Oomoo`1iOol3000=Ool40004Ool01000Ool00000/goo000MOol00`00
Oomoo`2AOol00`00Ool0002dOol001eoo`03001oogoo095oo`03001oo`000;Aoo`007Goo00<007oo
Ool0TGoo00<007oo0000]7oo000MOol00`00Oomoo`2AOol00`00Ool0002dOol001eoo`03001oogoo
095oo`04001oo`00002cOol001eoo`03001oogoo095oo`03001oo`000;Aoo`007Goo00<007ooOol0
TGoo00<007oo0000]7oo000MOol00`00Oomoo`2AOol00`00Ool0002dOol001eoo`03001oogoo099o
o`800;Aoo`007Goo00<007ooOol0TWoo0`00/goo000MOol00`00Oomoo`2BOol2002dOol001eoo`03
001oogoo099oo`800;Aoo`007Goo00<007ooOol0TWoo0P00]7oo000MOol00`00Oomoo`2BOol2002d
Ool001eoo`03001oogoo099oo`<00;=oo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomo
o`1bOol30006Ool20006Ool00`00Oomoo`04Ool40005Ool2002dOol001aoo`03001oogoo075oo`05
001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`02Ool2002dOol001aoo`03001o
ogoo075oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool2002dOol001aoo`03
001oogoo075oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`02Ool4002bOol001ao
o`03001oogoo075oo`05001oogooOol0000>Ool00`00Oomoo`03Ool40005Ool2002dOol001aoo`03
001oogoo075oo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`06Ool2002dOol001ao
o`03001oogoo075oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01Woo0P00
]7oo000LOol00`00Oomoo`1bOol3000<Ool50004Ool40005Ool2002dOol001aoo`03001oogoo09=o
o`<00;=oo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002dOol001aoo`03
001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol3002c
Ool001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000LOol0
0`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<0
07ooOol0U7oo0P00/goo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Ao
o`03001oogoo0;9oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol0
0`00Oomoo`2bOol001aoo`03001oogoo09Aoo`800;=oo`0077oo00<007ooOol0U7oo00<007ooOol0
/Woo000LOol00`00Oomoo`2:Ool50005Ool00`00Oomoo`2bOol001aoo`03001oogoo08aoo`03001o
ogoo00Eoo`03001oogoo0;9oo`006goo00<007ooOol0SGoo00<007ooOol01Goo00<007ooOol0/Woo
000KOol00`00Oomoo`2=Ool00`00Oomoo`05Ool3002bOol00:]oo`03001oogoo0;Yoo`00Zgoo00<0
07ooOol0^Woo002[Ool00`00Oomoo`2jOol00:Uoo`<00;aoo`00ogooJGoo002ZOol00`00Oomoo`2k
Ool00:Yoo`800;aoo`00PWoo1P000Woo1P000Woo1P0017oo10000Woo1P000goo00<007ooOol02Goo
0`000Woo0`005goo1@0017oo0`00QWoo0023Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<0
07ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Ioo`8000]oo`03001oogoo009oo`03001o
ogoo00Moo`H000Yoo`04001oogoo0003Ool01@00Oomoogoo0000QGoo0023Ool01@00Oomoogoo0000
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001=oo`03001o
ogoo009oo`03001oogoo01Qoo`03001oogoo00=oo`05001oogooOol00025Ool008=oo`03001oo`00
00Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000COol01P00
Ool00000Ool000Uoo`H000aoo`03001oogoo009oo`05001oogooOol00025Ool008=oo`<000Ioo`80
00Ioo`8000Eoo`03001oogoo009oo`04001oogooOol2000BOol01P00Ool00000Ool001aoo`05001o
ogooOol00003Ool00`00Oomoo`23Ool008=oo`05001oo`00Ool00003Ool2000017oo000000000Woo
0P0000Aoo`00000000=oo`@000=oo`800004Ool00000000?Ool20002Ool2000LOol01@00Oomoogoo
00000goo00<007ooOol0Pgoo0023Ool01@00Oomoogoo0000<7oo0P000Woo0P0067oo00D007ooOomo
o`0000=oo`05001oogooOol00025Ool0089oo`H002moo`8000Aoo`8001Qoo`<000Eoo`<008Ioo`00
ogooJGoo003oOomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.309017 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.02412 .606 L
.02446 .59289 L
.02477 .58061 L
.02508 .56885 L
.0254 .5564 L
.02571 .54449 L
.02605 .53193 L
.02636 .51995 L
.02667 .50855 L
.027 .49656 L
.02731 .48518 L
.02762 .47439 L
.02794 .46309 L
.02825 .4524 L
.02858 .44126 L
.0289 .43076 L
.0292 .42088 L
.02953 .41061 L
.02984 .40099 L
.03017 .39104 L
.03049 .38174 L
.0308 .37308 L
.03113 .36416 L
.03145 .35588 L
.03175 .34821 L
.03207 .34035 L
.03239 .33311 L
.03272 .32575 L
.03304 .319 L
.03334 .31282 L
.03367 .3066 L
.03398 .30094 L
.03429 .29581 L
.03461 .29068 L
.03492 .28608 L
.03525 .28154 L
.03556 .2775 L
.03587 .27394 L
.03619 .27047 L
.0365 .26747 L
.03684 .26461 L
.03716 .26219 L
.03746 .26016 L
.03779 .25831 L
.03811 .25683 L
.03841 .25568 L
.03858 .25516 L
.03873 .25474 L
.03889 .25438 L
Mistroke
.03904 .25411 L
.0392 .25389 L
.03928 .25379 L
.03936 .25372 L
.03944 .25367 L
.03949 .25364 L
.03953 .25362 L
.03956 .25361 L
.0396 .2536 L
.03962 .2536 L
.03963 .2536 L
.03964 .2536 L
.03965 .2536 L
.03966 .2536 L
.03967 .25359 L
.03968 .25359 L
.03969 .25359 L
.0397 .25359 L
.0397 .2536 L
.03971 .2536 L
.03972 .2536 L
.03973 .2536 L
.03975 .2536 L
.03977 .2536 L
.03979 .25361 L
.03983 .25362 L
.03987 .25364 L
.03991 .25365 L
.03999 .25371 L
.04007 .25377 L
.04014 .25385 L
.04031 .25406 L
.04062 .25463 L
.04095 .25546 L
.04127 .25647 L
.04157 .25762 L
.0419 .25904 L
.04221 .26058 L
.04252 .2622 L
.04284 .26408 L
.04315 .26601 L
.04348 .2682 L
.04379 .27042 L
.0441 .27265 L
.04442 .27512 L
.04473 .27756 L
.04507 .28023 L
.04538 .28285 L
.04569 .28541 L
.04602 .28816 L
Mistroke
.04633 .29083 L
.04664 .2934 L
.04696 .29613 L
.04727 .29875 L
.0476 .30151 L
.04792 .30413 L
.04822 .30661 L
.04855 .3092 L
.04886 .31162 L
.0492 .31413 L
.04952 .31647 L
.04983 .31864 L
.05015 .32085 L
.05047 .32288 L
.05077 .32474 L
.0511 .32661 L
.05141 .32829 L
.05174 .32997 L
.05206 .33145 L
.05237 .33277 L
.05269 .33404 L
.05301 .33513 L
.05331 .33606 L
.05363 .33692 L
.05394 .33762 L
.05427 .33823 L
.05459 .33869 L
.05489 .339 L
.05505 .33912 L
.05514 .33917 L
.05522 .33921 L
.0553 .33924 L
.05534 .33925 L
.05539 .33926 L
.05543 .33927 L
.05547 .33927 L
.05549 .33927 L
.05551 .33927 L
.05552 .33928 L
.05552 .33928 L
.05553 .33928 L
.05553 .33928 L
.05554 .33928 L
.05555 .33928 L
.05556 .33928 L
.05557 .33928 L
.05558 .33928 L
.05558 .33928 L
.05559 .33928 L
.0556 .33927 L
Mistroke
.05561 .33927 L
.05563 .33927 L
.05565 .33927 L
.05567 .33927 L
.0557 .33926 L
.05575 .33925 L
.05578 .33924 L
.05587 .33922 L
.05595 .33918 L
.05603 .33914 L
.05618 .33904 L
.05649 .33875 L
.05681 .33833 L
.05713 .33781 L
.05746 .33715 L
.05778 .3364 L
.05809 .33559 L
.05841 .33463 L
.05873 .33362 L
.05903 .33256 L
.05936 .33137 L
.05967 .33015 L
.06 .32878 L
.06032 .3274 L
.06063 .32603 L
.06095 .32452 L
.06127 .32303 L
.06157 .32157 L
.06189 .31998 L
.0622 .31844 L
.06253 .31679 L
.06285 .31519 L
.06315 .31365 L
.06347 .31201 L
.06379 .31045 L
.06412 .30881 L
.06444 .30726 L
.06475 .30579 L
.06507 .30427 L
.06539 .30284 L
.06569 .30151 L
.06601 .30015 L
.06633 .29889 L
.06666 .29761 L
.06697 .29644 L
.06728 .29538 L
.06761 .29432 L
.06792 .29338 L
.06825 .29246 L
.06857 .29165 L
Mistroke
.06888 .29095 L
.06921 .29029 L
.06953 .28974 L
.06983 .28929 L
.07015 .2889 L
.07047 .28861 L
.07062 .28849 L
.0708 .28838 L
.07096 .28831 L
.07104 .28828 L
.07112 .28826 L
.07119 .28824 L
.07123 .28823 L
.07127 .28823 L
.07131 .28822 L
.07133 .28822 L
.07135 .28822 L
.07137 .28822 L
.07138 .28822 L
.07139 .28822 L
.0714 .28822 L
.07141 .28822 L
.07141 .28822 L
.07142 .28822 L
.07143 .28822 L
.07144 .28822 L
.07145 .28822 L
.07146 .28822 L
.07147 .28822 L
.07149 .28822 L
.07151 .28822 L
.07155 .28822 L
.07159 .28823 L
.07167 .28824 L
.07175 .28826 L
.07183 .28828 L
.07191 .28831 L
.07208 .28839 L
.07224 .28849 L
.07241 .28861 L
.07274 .28891 L
.07306 .28929 L
.07337 .28972 L
.07369 .29025 L
.07401 .29083 L
.07431 .29145 L
.07463 .29218 L
.07494 .29293 L
.07527 .29379 L
.07559 .29467 L
Mistroke
.0759 .29556 L
.07622 .29655 L
.07654 .29754 L
.07687 .29863 L
.07719 .29972 L
.0775 .30078 L
.07783 .30194 L
.07814 .30307 L
.07845 .30416 L
.07877 .30534 L
.07908 .30647 L
.07941 .30767 L
.07973 .30882 L
.08004 .30991 L
.08036 .31106 L
.08068 .31215 L
.08098 .31317 L
.0813 .31424 L
.08161 .31523 L
.08194 .31624 L
.08226 .31718 L
.08256 .31805 L
.08289 .31892 L
.0832 .31972 L
.08353 .32051 L
.08385 .32121 L
.08416 .32184 L
.08449 .32245 L
.0848 .32297 L
.08511 .32342 L
.08543 .32384 L
.08574 .32418 L
.08607 .32447 L
.08639 .32469 L
.08655 .32477 L
.0867 .32484 L
.08685 .32489 L
.08694 .32491 L
.08702 .32493 L
.0871 .32494 L
.08714 .32495 L
.08718 .32495 L
.08722 .32495 L
.08724 .32495 L
.08725 .32495 L
.08726 .32495 L
.08727 .32495 L
.08728 .32495 L
.08729 .32495 L
.0873 .32495 L
Mistroke
.0873 .32495 L
.08731 .32495 L
.08732 .32495 L
.08733 .32495 L
.08734 .32495 L
.08735 .32495 L
.08737 .32495 L
.08739 .32495 L
.08741 .32495 L
.08745 .32495 L
.08748 .32494 L
.08756 .32493 L
.08765 .32492 L
.08781 .32487 L
.08795 .32482 L
.08826 .32467 L
.08859 .32444 L
.08891 .32415 L
.08922 .32383 L
.08955 .32342 L
.08986 .32298 L
.09016 .32251 L
.09048 .32196 L
.09079 .32138 L
.09112 .32072 L
.09144 .32004 L
.09174 .31936 L
.09207 .31859 L
.09238 .31782 L
.09271 .31697 L
.09303 .31613 L
.09334 .3153 L
.09367 .3144 L
.09398 .31352 L
.09428 .31266 L
.09461 .31174 L
.09492 .31085 L
.09525 .30991 L
.09557 .309 L
.09587 .30814 L
.0962 .30723 L
.09651 .30637 L
.09684 .30547 L
.09716 .30463 L
.09747 .30384 L
.0978 .30303 L
.09812 .30228 L
.09842 .30159 L
.09875 .30089 L
.09906 .30025 L
Mistroke
.09939 .29962 L
.09971 .29905 L
.10001 .29854 L
.10034 .29805 L
.10065 .29763 L
.10096 .29726 L
.10128 .29692 L
.10159 .29665 L
.10192 .29641 L
.10224 .29623 L
.10254 .2961 L
.1027 .29606 L
.10279 .29604 L
.10287 .29602 L
.10295 .29601 L
.10299 .29601 L
.10304 .296 L
.10306 .296 L
.10308 .296 L
.10309 .296 L
.10311 .296 L
.10313 .296 L
.10314 .296 L
.10315 .296 L
.10315 .296 L
.10316 .296 L
.10317 .296 L
.10317 .296 L
.10318 .296 L
.10319 .296 L
.1032 .296 L
.10321 .296 L
.10322 .296 L
.10324 .296 L
.10326 .296 L
.10327 .296 L
.10331 .296 L
.10336 .29601 L
.10343 .29602 L
.1035 .29603 L
.10366 .29606 L
.10383 .29611 L
.10399 .29617 L
.10415 .29624 L
.10446 .29642 L
.10479 .29665 L
.1051 .29693 L
.10543 .29726 L
.10575 .29764 L
.10606 .29804 L
Mistroke
.10639 .2985 L
.1067 .29899 L
.10701 .2995 L
.10733 .30007 L
.10764 .30065 L
.10797 .3013 L
.10829 .30195 L
.1086 .3026 L
.10893 .30331 L
.10924 .30401 L
.10954 .3047 L
.10986 .30545 L
.11017 .30618 L
.1105 .30696 L
.11082 .30772 L
.11112 .30844 L
.11145 .30922 L
.11176 .30995 L
.11209 .31073 L
.11241 .31146 L
.11272 .31215 L
.11305 .31287 L
.11336 .31355 L
.11367 .31417 L
.11399 .31482 L
.1143 .31541 L
.11463 .31601 L
.11495 .31655 L
.11526 .31705 L
.11558 .31754 L
.11589 .31797 L
.11623 .31839 L
.11655 .31876 L
.11686 .31907 L
.11719 .31936 L
.1175 .31959 L
.11781 .31978 L
.11813 .31993 L
.11828 .31999 L
.11844 .32004 L
.11853 .32006 L
.11861 .32007 L
.1187 .32009 L
.11877 .3201 L
.11885 .32011 L
.11889 .32011 L
.11892 .32011 L
.11896 .32011 L
.11898 .32011 L
.119 .32012 L
Mistroke
.11901 .32012 L
.11903 .32012 L
.11903 .32012 L
.11904 .32012 L
.11905 .32012 L
.11906 .32012 L
.11906 .32012 L
.11907 .32012 L
.11908 .32012 L
.11909 .32012 L
.1191 .32012 L
.11911 .32012 L
.11913 .32011 L
.11917 .32011 L
.11922 .32011 L
.11926 .32011 L
.11934 .3201 L
.11942 .32009 L
.11958 .32005 L
.11975 .32001 L
.12005 .3199 L
.12038 .31973 L
.12069 .31954 L
.12102 .31929 L
.12134 .319 L
.12165 .31869 L
.12198 .31833 L
.12229 .31794 L
.12259 .31753 L
.12292 .31707 L
.12323 .3166 L
.12356 .31607 L
.12387 .31553 L
.12418 .31499 L
.12451 .3144 L
.12482 .31381 L
.12515 .31316 L
.12547 .31253 L
.12578 .31191 L
.12611 .31124 L
.12643 .31059 L
.12673 .30997 L
.12705 .3093 L
.12736 .30866 L
.1277 .30798 L
.12801 .30734 L
.12832 .30673 L
.12865 .30609 L
.12896 .30549 L
.12926 .30494 L
Mistroke
.12959 .30436 L
.1299 .30383 L
.13023 .30328 L
.13054 .30278 L
.13085 .30233 L
.13117 .30188 L
.13148 .30147 L
.13182 .30107 L
.13214 .30072 L
.13245 .30042 L
.13277 .30014 L
.13309 .2999 L
.13339 .2997 L
.13371 .29953 L
.13403 .29941 L
.13419 .29936 L
.13436 .29932 L
.13443 .2993 L
.13451 .29929 L
.13459 .29927 L
.13466 .29927 L
.13474 .29926 L
.13479 .29926 L
.13481 .29926 L
.13483 .29926 L
.13485 .29925 L
.13487 .29925 L
.13488 .29925 L
.13489 .29925 L
.1349 .29925 L
.13491 .29925 L
.13492 .29925 L
.13493 .29925 L
.13494 .29925 L
.13495 .29925 L
.13495 .29925 L
.13496 .29925 L
.13497 .29925 L
.135 .29925 L
.13502 .29926 L
.13504 .29926 L
.13508 .29926 L
.13515 .29926 L
.13524 .29927 L
.13532 .29928 L
.13547 .29931 L
.13564 .29935 L
.13596 .29946 L
.13627 .2996 L
.1366 .29979 L
Mistroke
.13692 .3 L
.13723 .30025 L
.13755 .30054 L
.13787 .30085 L
.13817 .30118 L
.13849 .30156 L
.1388 .30195 L
.13913 .3024 L
.13945 .30285 L
.13975 .30331 L
.14008 .30382 L
.14039 .30432 L
.14072 .30488 L
.14104 .30543 L
.14135 .30597 L
.14167 .30655 L
.14199 .30712 L
.14229 .30768 L
.14262 .30827 L
.14293 .30884 L
.14326 .30944 L
.14357 .31002 L
.14388 .31057 L
.14421 .31115 L
.14452 .31169 L
.14485 .31226 L
.14517 .31279 L
.14548 .31328 L
.14581 .31378 L
.14613 .31425 L
.14643 .31467 L
.14675 .3151 L
.14707 .31549 L
.1474 .31587 L
.14772 .31621 L
.14802 .31651 L
.14835 .31679 L
.14867 .31704 L
.14897 .31724 L
.14929 .31743 L
.1496 .31757 L
.14976 .31763 L
.14993 .31769 L
.1501 .31773 L
.15025 .31776 L
.1504 .31779 L
.15049 .3178 L
.15053 .3178 L
.15057 .31781 L
.15061 .31781 L
Mistroke
.15065 .31781 L
.15067 .31781 L
.15069 .31781 L
.15071 .31781 L
.15073 .31782 L
.15075 .31782 L
.15076 .31782 L
.15077 .31782 L
.15078 .31782 L
.15079 .31782 L
.1508 .31782 L
.15081 .31782 L
.15082 .31782 L
.15082 .31782 L
.15083 .31782 L
.15084 .31782 L
.15086 .31781 L
.15088 .31781 L
.15092 .31781 L
.15096 .31781 L
.15103 .31781 L
.15111 .3178 L
.1512 .31779 L
.15135 .31776 L
.15152 .31772 L
.15185 .31762 L
.15217 .31749 L
.15247 .31733 L
.1528 .31713 L
.15311 .31691 L
.15345 .31664 L
.15377 .31635 L
.15408 .31604 L
.1544 .31569 L
.15472 .31532 L
.15502 .31495 L
.15535 .31453 L
.15566 .3141 L
.15599 .31363 L
.15631 .31316 L
.15661 .31269 L
.15694 .31218 L
.15726 .31168 L
.15756 .31119 L
.15788 .31066 L
.15819 .31015 L
.15852 .3096 L
.15884 .30907 L
.15914 .30856 L
.15947 .30802 L
Mistroke
.15978 .30751 L
.16011 .30698 L
.16043 .30647 L
.16074 .30599 L
.16107 .3055 L
.16138 .30505 L
.16168 .30462 L
.16201 .30419 L
.16232 .30379 L
.16265 .30339 L
.16297 .30303 L
.16327 .30271 L
.1636 .30239 L
.16391 .30212 L
.16424 .30185 L
.16457 .30163 L
.16487 .30144 L
.1652 .30127 L
.16552 .30114 L
.16582 .30104 L
.16598 .301 L
.16615 .30097 L
.16623 .30096 L
.16632 .30095 L
.1664 .30094 L
.16644 .30094 L
.16648 .30094 L
.16652 .30093 L
.16656 .30093 L
.16659 .30093 L
.16661 .30093 L
.16662 .30093 L
.16663 .30093 L
.16663 .30093 L
.16664 .30093 L
.16665 .30093 L
.16666 .30093 L
.16667 .30093 L
.16668 .30093 L
.16668 .30093 L
.16669 .30093 L
.1667 .30093 L
.1667 .30093 L
.16671 .30093 L
.16673 .30093 L
.16675 .30093 L
.16679 .30093 L
.16683 .30093 L
.16687 .30094 L
.16694 .30094 L
Mistroke
.16703 .30095 L
.16711 .30096 L
.16726 .30099 L
.16742 .30102 L
.16775 .30111 L
.16806 .30124 L
.16839 .3014 L
.16871 .30158 L
.16902 .30179 L
.16935 .30203 L
.16966 .3023 L
.16997 .30258 L
.17029 .3029 L
.1706 .30323 L
.17093 .30361 L
.17125 .30399 L
.17155 .30438 L
.17188 .30481 L
.17219 .30524 L
.17252 .30571 L
.17285 .30617 L
.17315 .30663 L
.17348 .30712 L
.1738 .30761 L
.1741 .30807 L
.17443 .30857 L
.17474 .30906 L
.17507 .30957 L
.17539 .31006 L
.17569 .31052 L
.17602 .31101 L
.17634 .31147 L
.17664 .3119 L
.17696 .31235 L
.17727 .31277 L
.1776 .31319 L
.17792 .31358 L
.17822 .31395 L
.17855 .31431 L
.17886 .31463 L
.17919 .31496 L
.17951 .31525 L
.17982 .3155 L
.18015 .31574 L
.18046 .31594 L
.18077 .31611 L
.18109 .31626 L
.1814 .31638 L
.18156 .31643 L
.18173 .31648 L
Mistroke
.1819 .31651 L
.18205 .31654 L
.18212 .31655 L
.18221 .31656 L
.18229 .31657 L
.18234 .31657 L
.18237 .31657 L
.18241 .31657 L
.18245 .31657 L
.18247 .31657 L
.18248 .31657 L
.18249 .31657 L
.1825 .31657 L
.18251 .31658 L
.18252 .31658 L
.18253 .31658 L
.18253 .31658 L
.18255 .31658 L
.18255 .31658 L
.18256 .31658 L
.18257 .31658 L
.18257 .31657 L
.18258 .31657 L
.1826 .31657 L
.18262 .31657 L
.18264 .31657 L
.18266 .31657 L
.1827 .31657 L
.18274 .31657 L
.18278 .31657 L
.18285 .31656 L
.18294 .31655 L
.18302 .31654 L
.18317 .31652 L
.18334 .31648 L
.18366 .31639 L
.18398 .31627 L
.18428 .31613 L
.1846 .31596 L
.18491 .31576 L
.18524 .31553 L
.18556 .31527 L
.18586 .31501 L
.18619 .3147 L
.1865 .31439 L
.18683 .31403 L
.18715 .31367 L
.18746 .3133 L
.18779 .31289 L
.1881 .31249 L
Mistroke
.18841 .31208 L
.18873 .31164 L
.18904 .31121 L
.18937 .31074 L
.18969 .31029 L
.18999 .30984 L
.19032 .30937 L
.19063 .30891 L
.19097 .30843 L
.19129 .30797 L
.19159 .30753 L
.19192 .30707 L
.19224 .30663 L
.19254 .30622 L
.19287 .3058 L
.19318 .3054 L
.19351 .305 L
.19383 .30463 L
.19414 .30429 L
.19446 .30395 L
.19478 .30364 L
.19508 .30336 L
.1954 .30309 L
.19571 .30286 L
.19604 .30263 L
.19636 .30244 L
.19667 .30228 L
.19699 .30213 L
.1973 .30202 L
.19746 .30198 L
.19764 .30193 L
.19779 .3019 L
.19787 .30189 L
.19796 .30188 L
.19804 .30187 L
.19812 .30186 L
.1982 .30186 L
.19824 .30185 L
.19828 .30185 L
.19832 .30185 L
.19834 .30185 L
.19836 .30185 L
.19837 .30185 L
.19838 .30185 L
.19839 .30185 L
.1984 .30185 L
.19841 .30185 L
.19841 .30185 L
.19842 .30185 L
.19842 .30185 L
Mistroke
.19843 .30185 L
.19844 .30185 L
.19844 .30185 L
.19845 .30185 L
.19846 .30185 L
.19848 .30185 L
.1985 .30185 L
.19851 .30185 L
.19855 .30185 L
.19859 .30185 L
.19867 .30186 L
.19875 .30187 L
.1989 .30188 L
.19907 .30191 L
.19923 .30194 L
.19954 .30203 L
.19987 .30214 L
.20018 .30228 L
.20049 .30244 L
.20081 .30264 L
.20112 .30285 L
.20145 .3031 L
.20177 .30337 L
.20208 .30364 L
.2024 .30396 L
.20272 .30428 L
.20302 .30461 L
.20334 .30497 L
.20365 .30534 L
.20398 .30575 L
.2043 .30615 L
.2046 .30654 L
.20493 .30697 L
.20524 .3074 L
.20557 .30785 L
.20589 .30829 L
.2062 .30872 L
.20653 .30918 L
.20684 .30961 L
.20715 .31003 L
.20747 .31047 L
.20778 .31089 L
.20811 .31132 L
.20843 .31173 L
.20874 .31211 L
.20906 .31251 L
.20937 .31287 L
.20971 .31324 L
.21003 .31358 L
.21034 .31389 L
Mistroke
.21067 .3142 L
.21098 .31447 L
.21129 .31472 L
.21161 .31496 L
.21192 .31516 L
.21226 .31535 L
.21257 .31551 L
.21288 .31564 L
.21321 .31575 L
.21337 .31579 L
.21352 .31582 L
.21368 .31585 L
.21383 .31587 L
.2139 .31588 L
.21399 .31589 L
.21406 .3159 L
.2141 .3159 L
.21414 .3159 L
.21418 .3159 L
.2142 .3159 L
.21422 .3159 L
.21423 .3159 L
.21424 .3159 L
.21425 .3159 L
.21426 .3159 L
.21426 .3159 L
.21427 .3159 L
.21427 .3159 L
.21428 .3159 L
.21429 .3159 L
.2143 .3159 L
.21431 .3159 L
.21432 .3159 L
.21433 .3159 L
.21434 .3159 L
.21436 .3159 L
.21438 .3159 L
.21441 .3159 L
.21445 .3159 L
.21453 .31589 L
.21462 .31589 L
.2147 .31588 L
.21478 .31587 L
.21493 .31585 L
.2151 .31581 L
.21542 .31573 L
.21573 .31562 L
.21606 .31548 L
.21638 .31532 L
.21668 .31514 L
Mistroke
.21701 .31493 L
.21732 .3147 L
.21766 .31443 L
.21798 .31415 L
.21828 .31386 L
.21861 .31354 L
.21893 .31321 L
.21923 .31287 L
.21956 .3125 L
.21987 .31213 L
.2202 .31173 L
.22052 .31133 L
.22083 .31093 L
.22115 .3105 L
.22147 .31009 L
.22177 .30968 L
.22209 .30925 L
.2224 .30884 L
.22273 .30839 L
.22305 .30797 L
.22335 .30757 L
.22368 .30715 L
.22399 .30675 L
.22432 .30634 L
.22464 .30595 L
.22495 .30559 L
.22528 .30523 L
.2256 .30489 L
.2259 .30458 L
.22622 .30426 L
.22653 .30398 L
.22686 .3037 L
.22718 .30345 L
.22749 .30324 L
.22781 .30303 L
.22813 .30286 L
.22846 .3027 L
.22878 .30257 L
.22909 .30247 L
.22925 .30243 L
.22942 .30239 L
.22959 .30236 L
.22974 .30234 L
.22982 .30234 L
.22989 .30233 L
.22997 .30233 L
.23002 .30232 L
.23004 .30232 L
.23006 .30232 L
.23008 .30232 L
Mistroke
.2301 .30232 L
.23011 .30232 L
.23012 .30232 L
.23013 .30232 L
.23014 .30232 L
.23015 .30232 L
.23016 .30232 L
.23017 .30232 L
.23018 .30232 L
.23018 .30232 L
.23019 .30232 L
.2302 .30232 L
.23021 .30232 L
.23023 .30232 L
.23025 .30232 L
.23029 .30232 L
.23033 .30232 L
.23038 .30233 L
.23045 .30233 L
.23053 .30234 L
.2307 .30236 L
.23086 .30238 L
.23102 .30242 L
.23135 .30251 L
.23167 .30262 L
.23198 .30275 L
.2323 .30291 L
.23261 .30309 L
.23294 .30331 L
.23326 .30354 L
.23357 .30379 L
.2339 .30407 L
.23421 .30436 L
.23452 .30466 L
.23484 .30499 L
.23515 .30532 L
.23548 .30569 L
.2358 .30607 L
.23611 .30643 L
.23643 .30683 L
.23675 .30723 L
.23708 .30765 L
.2374 .30807 L
.23771 .30847 L
.23804 .30891 L
.23835 .30932 L
.23866 .30972 L
.23898 .31014 L
.23929 .31054 L
.23962 .31096 L
Mistroke
.23994 .31136 L
.24025 .31173 L
.24058 .31211 L
.24089 .31247 L
.2412 .3128 L
.24152 .31314 L
.24183 .31344 L
.24216 .31375 L
.24247 .31403 L
.24278 .31428 L
.2431 .31453 L
.24342 .31474 L
.24375 .31494 L
.24407 .31511 L
.24438 .31525 L
.24471 .31538 L
.24502 .31547 L
.24533 .31554 L
.24548 .31556 L
.24565 .31558 L
.24573 .31559 L
.24577 .31559 L
.24582 .3156 L
.24586 .3156 L
.2459 .3156 L
.24592 .3156 L
.24594 .3156 L
.24596 .3156 L
.24598 .3156 L
.24599 .3156 L
.246 .3156 L
.24601 .3156 L
.24601 .3156 L
.24602 .3156 L
.24603 .3156 L
.24604 .3156 L
.24605 .3156 L
.24606 .3156 L
.24606 .3156 L
.24607 .3156 L
.24608 .3156 L
.2461 .3156 L
.24612 .3156 L
.24614 .3156 L
.24618 .3156 L
.24622 .3156 L
.24631 .31559 L
.24639 .31559 L
.24646 .31558 L
.24663 .31556 L
Mistroke
.24678 .31553 L
.24695 .3155 L
.24727 .31541 L
.24758 .3153 L
.24791 .31515 L
.24823 .31499 L
.24854 .31481 L
.24886 .31459 L
.24918 .31437 L
.24948 .31413 L
.2498 .31385 L
.25011 .31357 L
.25044 .31325 L
.25076 .31293 L
.25106 .3126 L
.25139 .31224 L
.2517 .31188 L
.25203 .31148 L
.25235 .31109 L
.25266 .31071 L
.25299 .31029 L
.25331 .30989 L
.25361 .3095 L
.25393 .30908 L
.25424 .30867 L
.25457 .30824 L
.25489 .30784 L
.2552 .30745 L
.25552 .30704 L
.25584 .30666 L
.25617 .30626 L
.25649 .30588 L
.2568 .30554 L
.25713 .30518 L
.25745 .30486 L
.25775 .30456 L
.25807 .30426 L
.25839 .30399 L
.25872 .30373 L
.25904 .30349 L
.25934 .30329 L
.25967 .3031 L
.25999 .30293 L
.26029 .3028 L
.26061 .30268 L
.26092 .30259 L
.26108 .30255 L
.26125 .30252 L
.26142 .3025 L
.26157 .30248 L
Mistroke
.26165 .30247 L
.26169 .30247 L
.26173 .30247 L
.26177 .30247 L
.2618 .30247 L
.26182 .30247 L
.26184 .30247 L
.26186 .30247 L
.26187 .30247 L
.26188 .30247 L
.26189 .30247 L
.2619 .30247 L
.26191 .30247 L
.26192 .30247 L
.26193 .30247 L
.26194 .30247 L
.26194 .30247 L
.26196 .30247 L
.26198 .30247 L
.262 .30247 L
.26203 .30247 L
.26208 .30247 L
.26212 .30247 L
.2622 .30248 L
.26228 .30248 L
.26236 .30249 L
.26251 .30251 L
.26266 .30254 L
.26281 .30257 L
.26312 .30266 L
.26345 .30277 L
.26377 .30291 L
.26408 .30306 L
.2644 .30325 L
.26472 .30346 L
.26505 .3037 L
.26537 .30395 L
.26568 .30421 L
.26601 .30451 L
.26632 .30482 L
.26663 .30513 L
.26695 .30548 L
.26726 .30582 L
.26759 .3062 L
.26791 .30658 L
.26822 .30696 L
.26855 .30736 L
.26886 .30776 L
.26916 .30815 L
.26949 .30857 L
Mistroke
.2698 .30897 L
.27013 .3094 L
.27044 .30981 L
.27075 .3102 L
.27107 .31061 L
.27139 .311 L
.27172 .31141 L
.27204 .3118 L
.27235 .31215 L
.27267 .31252 L
.27299 .31286 L
.27329 .31318 L
.27362 .31349 L
.27393 .31378 L
.27426 .31407 L
.27458 .31433 L
.27488 .31455 L
.27521 .31477 L
.27552 .31496 L
.27582 .31512 L
.27615 .31526 L
.27646 .31538 L
.27678 .31548 L
.27695 .31551 L
.2771 .31554 L
.27725 .31557 L
.27741 .31559 L
.27749 .31559 L
.27753 .3156 L
.27758 .3156 L
.27762 .3156 L
.27764 .3156 L
.27766 .3156 L
.27768 .3156 L
.2777 .3156 L
.27772 .3156 L
.27774 .3156 L
.27775 .3156 L
.27775 .3156 L
.27776 .3156 L
.27777 .3156 L
.27778 .3156 L
.27779 .3156 L
.27779 .3156 L
.2778 .3156 L
.27781 .3156 L
.27782 .3156 L
.27784 .3156 L
.27786 .3156 L
.27788 .3156 L
Mistroke
.2779 .3156 L
.27797 .3156 L
.278 .3156 L
.27804 .31559 L
.2782 .31558 L
.27828 .31557 L
.27836 .31556 L
.27868 .3155 L
.27899 .31542 L
.27931 .3153 L
.27962 .31517 L
.27996 .315 L
.28028 .31481 L
.28058 .31461 L
.28091 .31437 L
.28123 .31412 L
.28153 .31386 L
.28185 .31357 L
.28216 .31327 L
.28249 .31293 L
.28281 .31258 L
.28312 .31224 L
.28344 .31186 L
.28376 .31149 L
.28409 .31108 L
.28441 .31067 L
.28472 .31028 L
.28505 .30985 L
.28537 .30944 L
.28567 .30904 L
.28599 .30861 L
.28631 .30821 L
.28664 .30778 L
.28696 .30736 L
.28726 .30698 L
.28759 .30657 L
.28791 .30619 L
.28821 .30583 L
.28853 .30547 L
.28884 .30512 L
.28917 .30478 L
.28949 .30446 L
.28979 .30418 L
.29012 .30389 L
.29043 .30363 L
.29076 .30338 L
.29108 .30317 L
.29139 .30298 L
.29172 .3028 L
.29204 .30266 L
Mistroke
.29234 .30255 L
.29266 .30245 L
.29297 .30238 L
.29314 .30235 L
.29322 .30235 L
.29331 .30234 L
.29338 .30233 L
.29342 .30233 L
.29346 .30233 L
.2935 .30232 L
.29354 .30232 L
.29357 .30232 L
.29359 .30232 L
.2936 .30232 L
.29361 .30232 L
.29362 .30232 L
.29363 .30232 L
.29364 .30232 L
.29365 .30232 L
.29365 .30232 L
.29366 .30232 L
.29367 .30232 L
.29368 .30232 L
.29368 .30232 L
.29369 .30232 L
.29371 .30232 L
.29373 .30232 L
.29377 .30232 L
.29381 .30232 L
.29386 .30233 L
.29394 .30233 L
.29401 .30234 L
.2941 .30235 L
.29424 .30237 L
.2944 .3024 L
.29455 .30243 L
.29486 .30251 L
.29519 .30263 L
.29551 .30277 L
.29582 .30293 L
.29614 .30312 L
.29646 .30333 L
.29676 .30356 L
.29708 .30381 L
.29739 .30408 L
.29772 .30439 L
.29804 .30471 L
.29834 .30502 L
.29867 .30538 L
.29898 .30574 L
Mistroke
.29931 .30613 L
.29963 .30652 L
.29994 .30691 L
.30027 .30733 L
.30059 .30774 L
.30089 .30814 L
.30121 .30857 L
.30152 .30899 L
.30185 .30944 L
.30217 .30986 L
.30248 .31027 L
.3028 .3107 L
.30312 .31111 L
.30345 .31153 L
.30377 .31193 L
.30408 .3123 L
.30441 .31269 L
.30473 .31304 L
.30503 .31337 L
.30536 .3137 L
.30567 .314 L
.306 .3143 L
.30632 .31457 L
.30663 .3148 L
.30695 .31503 L
.30727 .31523 L
.30757 .3154 L
.30789 .31555 L
.3082 .31567 L
.30853 .31577 L
.3087 .31581 L
.30885 .31584 L
.309 .31587 L
.30916 .31588 L
.30924 .31589 L
.30928 .31589 L
.30933 .3159 L
.30937 .3159 L
.30939 .3159 L
.30941 .3159 L
.30943 .3159 L
.30945 .3159 L
.30946 .3159 L
.30947 .3159 L
.30948 .3159 L
.30949 .3159 L
.3095 .3159 L
.30951 .3159 L
.30952 .3159 L
.30953 .3159 L
Mistroke
.30954 .3159 L
.30955 .3159 L
.30956 .3159 L
.30956 .3159 L
.30958 .3159 L
.30961 .3159 L
.30963 .3159 L
.30965 .3159 L
.30969 .3159 L
.30973 .3159 L
.30982 .31589 L
.3099 .31588 L
.30997 .31588 L
.31014 .31585 L
.31029 .31582 L
.31046 .31579 L
.31078 .31569 L
.3111 .31557 L
.31143 .31542 L
.31175 .31524 L
.31206 .31505 L
.31239 .31482 L
.3127 .31458 L
.31301 .31432 L
.31333 .31403 L
.31364 .31372 L
.31397 .31338 L
.31429 .31303 L
.3146 .31268 L
.31493 .31229 L
.31524 .3119 L
.31554 .31152 L
.31587 .3111 L
.31618 .31069 L
.31651 .31024 L
.31682 .30981 L
.31713 .30939 L
.31745 .30894 L
.31777 .3085 L
.3181 .30804 L
.31842 .3076 L
.31873 .30718 L
.31906 .30674 L
.31937 .30633 L
.31968 .30594 L
.32 .30553 L
.32031 .30516 L
.32064 .30478 L
.32096 .30442 L
.32127 .3041 L
Mistroke
.32159 .30378 L
.32191 .30349 L
.32221 .30323 L
.32253 .30297 L
.32284 .30275 L
.32317 .30254 L
.32348 .30236 L
.32379 .30221 L
.32411 .30208 L
.32442 .30198 L
.32458 .30194 L
.32476 .30191 L
.32492 .30188 L
.325 .30187 L
.32508 .30186 L
.32515 .30186 L
.32523 .30185 L
.32527 .30185 L
.32529 .30185 L
.32531 .30185 L
.32533 .30185 L
.32535 .30185 L
.32536 .30185 L
.32537 .30185 L
.32538 .30185 L
.32539 .30185 L
.3254 .30185 L
.32541 .30185 L
.32542 .30185 L
.32543 .30185 L
.32544 .30185 L
.32545 .30185 L
.32547 .30185 L
.32549 .30185 L
.32551 .30185 L
.32555 .30185 L
.32559 .30186 L
.32564 .30186 L
.32572 .30186 L
.3258 .30187 L
.32588 .30188 L
.32605 .30191 L
.32621 .30194 L
.32637 .30198 L
.32671 .30209 L
.32703 .30222 L
.32733 .30237 L
.32766 .30256 L
.32798 .30277 L
.32828 .30299 L
Mistroke
.3286 .30326 L
.32891 .30353 L
.32924 .30385 L
.32956 .30417 L
.32987 .30451 L
.33019 .30488 L
.33051 .30525 L
.33084 .30567 L
.33116 .30609 L
.33147 .3065 L
.3318 .30695 L
.33212 .30739 L
.33242 .30782 L
.33274 .30829 L
.33306 .30874 L
.33339 .30922 L
.33371 .30969 L
.33401 .31013 L
.33434 .3106 L
.33466 .31105 L
.33496 .31148 L
.33528 .31192 L
.33559 .31233 L
.33592 .31276 L
.33624 .31316 L
.33654 .31353 L
.33687 .31391 L
.33718 .31425 L
.33752 .3146 L
.33784 .31491 L
.33814 .31518 L
.33847 .31545 L
.33879 .31569 L
.33909 .31589 L
.33942 .31607 L
.33973 .31623 L
.34006 .31636 L
.34038 .31646 L
.34052 .31649 L
.34068 .31652 L
.34084 .31655 L
.34093 .31656 L
.34101 .31657 L
.34109 .31657 L
.34113 .31657 L
.34115 .31657 L
.34117 .31657 L
.34119 .31657 L
.34121 .31657 L
.34122 .31657 L
Mistroke
.34123 .31657 L
.34124 .31657 L
.34125 .31658 L
.34126 .31658 L
.34126 .31658 L
.34127 .31658 L
.34128 .31658 L
.34129 .31658 L
.3413 .31657 L
.34131 .31657 L
.34132 .31657 L
.34134 .31657 L
.34136 .31657 L
.3414 .31657 L
.34144 .31657 L
.34148 .31657 L
.34155 .31656 L
.34163 .31656 L
.34179 .31654 L
.34196 .31651 L
.34229 .31642 L
.34261 .31631 L
.34291 .31618 L
.34324 .316 L
.34355 .31581 L
.34386 .3156 L
.34418 .31535 L
.34449 .31508 L
.34482 .31477 L
.34513 .31444 L
.34544 .31411 L
.34576 .31374 L
.34608 .31336 L
.34641 .31294 L
.34673 .31251 L
.34704 .31209 L
.34737 .31162 L
.34768 .31117 L
.34799 .31072 L
.34831 .31023 L
.34862 .30975 L
.34895 .30925 L
.34927 .30875 L
.34957 .30828 L
.3499 .30778 L
.35021 .3073 L
.35052 .30684 L
.35084 .30636 L
.35115 .30591 L
.35148 .30544 L
Mistroke
.35179 .305 L
.3521 .30459 L
.35242 .30417 L
.35273 .30379 L
.35306 .3034 L
.35338 .30305 L
.35369 .30273 L
.35402 .30242 L
.35433 .30214 L
.35464 .3019 L
.35496 .30167 L
.35527 .30148 L
.3556 .3013 L
.35592 .30117 L
.35622 .30106 L
.35639 .30102 L
.35655 .30099 L
.35663 .30097 L
.35671 .30096 L
.35679 .30095 L
.35686 .30094 L
.35694 .30094 L
.35698 .30093 L
.35702 .30093 L
.35704 .30093 L
.35707 .30093 L
.35708 .30093 L
.35709 .30093 L
.3571 .30093 L
.35711 .30093 L
.35712 .30093 L
.35713 .30093 L
.35714 .30093 L
.35715 .30093 L
.35716 .30093 L
.35717 .30093 L
.35717 .30093 L
.35718 .30093 L
.35719 .30093 L
.35721 .30093 L
.35723 .30093 L
.35727 .30093 L
.35731 .30093 L
.35734 .30094 L
.35742 .30094 L
.35751 .30095 L
.35768 .30098 L
.35784 .30101 L
.35815 .30109 L
.35847 .30121 L
Mistroke
.35878 .30136 L
.35912 .30154 L
.35944 .30176 L
.35975 .30199 L
.36008 .30227 L
.36039 .30257 L
.3607 .30288 L
.36102 .30323 L
.36133 .3036 L
.36166 .30401 L
.36198 .30443 L
.36229 .30485 L
.36262 .30532 L
.36293 .30578 L
.36323 .30624 L
.36356 .30675 L
.36387 .30724 L
.3642 .30778 L
.36451 .3083 L
.36482 .30881 L
.36514 .30935 L
.36546 .30987 L
.36579 .31043 L
.36611 .31096 L
.36642 .31146 L
.36675 .31199 L
.36706 .31249 L
.36737 .31295 L
.36769 .31344 L
.368 .31389 L
.36833 .31435 L
.36865 .31477 L
.36896 .31516 L
.36928 .31555 L
.3696 .3159 L
.3699 .31621 L
.37022 .31651 L
.37053 .31678 L
.37086 .31703 L
.37117 .31724 L
.37148 .31741 L
.3718 .31756 L
.37212 .31768 L
.37229 .31772 L
.37245 .31776 L
.37253 .31777 L
.37261 .31779 L
.37268 .3178 L
.37276 .3178 L
.37283 .31781 L
Mistroke
.37287 .31781 L
.37289 .31781 L
.37291 .31781 L
.37293 .31781 L
.37295 .31782 L
.37297 .31782 L
.37297 .31782 L
.37298 .31782 L
.37299 .31782 L
.373 .31782 L
.37301 .31782 L
.37302 .31782 L
.37303 .31782 L
.37304 .31782 L
.37305 .31782 L
.37306 .31782 L
.37308 .31782 L
.3731 .31781 L
.37314 .31781 L
.37318 .31781 L
.37322 .31781 L
.37329 .3178 L
.37337 .31779 L
.37352 .31777 L
.37368 .31774 L
.37401 .31765 L
.37432 .31752 L
.37465 .31735 L
.37497 .31716 L
.37528 .31694 L
.37561 .31667 L
.37592 .31638 L
.37623 .31607 L
.37655 .31571 L
.37686 .31534 L
.37719 .31492 L
.37751 .31449 L
.37782 .31405 L
.37814 .31357 L
.37846 .31308 L
.37879 .31254 L
.37911 .312 L
.37942 .31147 L
.37975 .31089 L
.38006 .31033 L
.38037 .30978 L
.38069 .30919 L
.381 .30862 L
.38134 .30801 L
.38166 .30742 L
Mistroke
.38196 .30686 L
.38229 .30627 L
.3826 .30572 L
.38291 .30519 L
.38323 .30464 L
.38354 .30413 L
.38387 .3036 L
.38419 .30311 L
.38449 .30266 L
.38482 .30221 L
.38513 .3018 L
.38546 .30139 L
.38578 .30102 L
.38609 .3007 L
.38642 .30039 L
.38674 .30012 L
.38704 .2999 L
.38736 .29969 L
.38768 .29953 L
.38783 .29947 L
.38801 .2994 L
.38816 .29936 L
.38833 .29931 L
.38848 .29929 L
.38857 .29927 L
.38865 .29926 L
.38869 .29926 L
.38873 .29926 L
.38877 .29926 L
.38879 .29926 L
.38881 .29925 L
.38883 .29925 L
.38884 .29925 L
.38885 .29925 L
.38886 .29925 L
.38887 .29925 L
.38888 .29925 L
.38889 .29925 L
.3889 .29925 L
.38891 .29925 L
.38892 .29925 L
.38892 .29925 L
.38893 .29925 L
.38894 .29925 L
.38896 .29925 L
.38898 .29926 L
.389 .29926 L
.38904 .29926 L
.38909 .29926 L
.38913 .29927 L
Mistroke
.38922 .29927 L
.38929 .29929 L
.38946 .29932 L
.38961 .29935 L
.38993 .29946 L
.39023 .2996 L
.39056 .29979 L
.39087 .30001 L
.39118 .30025 L
.3915 .30055 L
.39181 .30087 L
.39214 .30124 L
.39245 .30164 L
.39276 .30205 L
.39308 .30251 L
.3934 .30299 L
.39373 .30352 L
.39405 .30406 L
.39436 .3046 L
.39469 .30519 L
.395 .30579 L
.39531 .30637 L
.39563 .30701 L
.39594 .30763 L
.39627 .3083 L
.39659 .30895 L
.3969 .30958 L
.39722 .31026 L
.39754 .3109 L
.39784 .31152 L
.39816 .31217 L
.39847 .31279 L
.3988 .31343 L
.39911 .31404 L
.39942 .31461 L
.39974 .31519 L
.40005 .31574 L
.40039 .31629 L
.40071 .31679 L
.40101 .31725 L
.40134 .3177 L
.40166 .31811 L
.40196 .31847 L
.40228 .31882 L
.40259 .31911 L
.40292 .31939 L
.40324 .31962 L
.40354 .3198 L
.40372 .31988 L
.40387 .31994 L
Mistroke
.40403 .32 L
.40418 .32004 L
.40434 .32008 L
.40442 .32009 L
.4045 .3201 L
.40458 .32011 L
.40462 .32011 L
.40464 .32011 L
.40466 .32011 L
.40468 .32011 L
.4047 .32011 L
.40472 .32012 L
.40473 .32012 L
.40474 .32012 L
.40475 .32012 L
.40475 .32012 L
.40476 .32012 L
.40477 .32012 L
.40478 .32012 L
.40479 .32012 L
.4048 .32012 L
.40481 .32012 L
.40483 .32011 L
.40485 .32011 L
.40489 .32011 L
.40493 .32011 L
.40496 .32011 L
.40504 .3201 L
.40513 .32009 L
.4053 .32005 L
.40546 .32001 L
.40576 .3199 L
.40609 .31973 L
.4064 .31953 L
.40674 .31926 L
.40706 .31897 L
.40737 .31864 L
.4077 .31825 L
.40801 .31784 L
.40832 .31741 L
.40864 .31691 L
.40895 .3164 L
.40928 .31582 L
.4096 .31523 L
.40991 .31464 L
.41024 .31398 L
.41055 .31332 L
.41085 .31267 L
.41118 .31196 L
.41149 .31125 L
Mistroke
.41182 .31049 L
.41213 .30975 L
.41244 .30903 L
.41276 .30825 L
.41308 .30751 L
.41341 .30671 L
.41373 .30596 L
.41404 .30523 L
.41437 .30447 L
.41468 .30376 L
.41499 .30308 L
.41531 .30238 L
.41562 .30173 L
.41595 .30107 L
.41627 .30045 L
.41658 .29989 L
.4169 .29932 L
.41722 .29882 L
.41752 .29836 L
.41784 .29791 L
.41815 .29753 L
.41848 .29716 L
.4188 .29685 L
.4191 .29659 L
.41943 .29637 L
.41974 .2962 L
.41991 .29613 L
.42007 .29608 L
.42015 .29606 L
.42023 .29604 L
.42031 .29603 L
.42038 .29602 L
.42045 .29601 L
.42049 .296 L
.42051 .296 L
.42053 .296 L
.42055 .296 L
.42057 .296 L
.42058 .296 L
.42059 .296 L
.4206 .296 L
.4206 .296 L
.42061 .296 L
.42062 .296 L
.42063 .296 L
.42064 .296 L
.42065 .296 L
.42066 .296 L
.42067 .296 L
.42068 .296 L
Mistroke
.4207 .296 L
.42072 .296 L
.42076 .296 L
.4208 .29601 L
.42084 .29601 L
.42092 .29602 L
.42101 .29604 L
.42116 .29607 L
.42131 .29612 L
.42162 .29625 L
.42196 .29645 L
.42228 .29669 L
.42259 .29698 L
.42291 .29733 L
.42323 .29772 L
.42353 .29814 L
.42385 .29864 L
.42417 .29916 L
.4245 .29976 L
.42481 .30038 L
.42512 .30101 L
.42545 .30172 L
.42576 .30244 L
.42609 .30324 L
.42642 .30404 L
.42672 .30483 L
.42705 .3057 L
.42737 .30656 L
.42767 .3074 L
.428 .30831 L
.42831 .30919 L
.42864 .31014 L
.42896 .31105 L
.42927 .31193 L
.4296 .31286 L
.42991 .31375 L
.43021 .3146 L
.43054 .31548 L
.43085 .31631 L
.43118 .31718 L
.43149 .31798 L
.4318 .31873 L
.43213 .31949 L
.43244 .32019 L
.43277 .32089 L
.43309 .32152 L
.4334 .32209 L
.43373 .32264 L
.43404 .32312 L
.43435 .32353 L
Mistroke
.43467 .32392 L
.43498 .32424 L
.43531 .32451 L
.43548 .32462 L
.43563 .32471 L
.43579 .32479 L
.43594 .32485 L
.43609 .3249 L
.43617 .32492 L
.43625 .32493 L
.43633 .32494 L
.43637 .32495 L
.43641 .32495 L
.43644 .32495 L
.43645 .32495 L
.43646 .32495 L
.43647 .32495 L
.43648 .32495 L
.43649 .32495 L
.4365 .32495 L
.4365 .32495 L
.43651 .32495 L
.43652 .32495 L
.43652 .32495 L
.43653 .32495 L
.43653 .32495 L
.43654 .32495 L
.43655 .32495 L
.43656 .32495 L
.43658 .32495 L
.4366 .32495 L
.43662 .32495 L
.43666 .32495 L
.4367 .32494 L
.43674 .32494 L
.43682 .32492 L
.43689 .32491 L
.43704 .32486 L
.43721 .3248 L
.43754 .32462 L
.43785 .32438 L
.43815 .32409 L
.43848 .32372 L
.43879 .3233 L
.43912 .3228 L
.43943 .32225 L
.43974 .32166 L
.44006 .32098 L
.44038 .32027 L
.44071 .31947 L
Mistroke
.44103 .31863 L
.44134 .31779 L
.44167 .31685 L
.44198 .3159 L
.44229 .31495 L
.44261 .3139 L
.44292 .31287 L
.44325 .31174 L
.44357 .31063 L
.44388 .30955 L
.4442 .30838 L
.44452 .30724 L
.44482 .30615 L
.44514 .30498 L
.44545 .30386 L
.44578 .30267 L
.44609 .30155 L
.4464 .30048 L
.44672 .29937 L
.44703 .29832 L
.44737 .29724 L
.44769 .29624 L
.44799 .29531 L
.44832 .29438 L
.44864 .29352 L
.44894 .29275 L
.44926 .29198 L
.44957 .2913 L
.4499 .29064 L
.45022 .29007 L
.45053 .2896 L
.45085 .28916 L
.45116 .28882 L
.45132 .28867 L
.4515 .28854 L
.45165 .28844 L
.45182 .28835 L
.45198 .28828 L
.45206 .28826 L
.45215 .28824 L
.45219 .28823 L
.45223 .28823 L
.45225 .28822 L
.45227 .28822 L
.45229 .28822 L
.45231 .28822 L
.45233 .28822 L
.45234 .28822 L
.45235 .28822 L
.45235 .28822 L
Mistroke
.45236 .28822 L
.45237 .28822 L
.45238 .28822 L
.45239 .28822 L
.4524 .28822 L
.4524 .28822 L
.45241 .28822 L
.45242 .28822 L
.45244 .28822 L
.45246 .28822 L
.45248 .28822 L
.4525 .28822 L
.45254 .28823 L
.45261 .28824 L
.4527 .28826 L
.45278 .28828 L
.45295 .28835 L
.45309 .28843 L
.45342 .28867 L
.45372 .28898 L
.45405 .2894 L
.45437 .28989 L
.45467 .29044 L
.455 .2911 L
.45531 .29183 L
.45564 .29268 L
.45596 .29359 L
.45627 .29453 L
.4566 .2956 L
.45691 .29671 L
.45721 .29783 L
.45754 .29909 L
.45785 .30036 L
.45818 .30176 L
.45849 .30316 L
.4588 .30456 L
.45912 .30608 L
.45944 .30758 L
.45977 .3092 L
.46009 .31078 L
.4604 .31233 L
.46073 .31398 L
.46104 .31558 L
.46135 .31711 L
.46167 .31873 L
.46198 .32028 L
.46231 .32191 L
.46263 .32344 L
.46294 .32489 L
.46326 .32639 L
Mistroke
.46358 .32778 L
.46388 .32907 L
.4642 .33039 L
.46451 .33159 L
.46484 .33279 L
.46516 .33387 L
.46546 .33483 L
.46579 .33576 L
.4661 .33657 L
.46643 .33732 L
.46675 .33793 L
.46706 .33842 L
.46721 .33862 L
.46738 .33882 L
.46755 .33897 L
.4677 .33909 L
.46786 .33918 L
.46794 .33922 L
.46802 .33924 L
.46806 .33925 L
.4681 .33926 L
.46812 .33927 L
.46814 .33927 L
.46816 .33927 L
.46818 .33927 L
.4682 .33927 L
.46821 .33927 L
.46822 .33928 L
.46823 .33928 L
.46824 .33928 L
.46825 .33928 L
.46825 .33928 L
.46826 .33928 L
.46827 .33928 L
.46827 .33928 L
.46828 .33928 L
.46829 .33928 L
.4683 .33927 L
.46831 .33927 L
.46833 .33927 L
.46835 .33927 L
.46837 .33927 L
.4684 .33926 L
.46844 .33925 L
.46849 .33924 L
.46856 .33922 L
.46863 .33919 L
.46878 .3391 L
.46895 .33897 L
.46927 .33862 L
Mistroke
.46958 .33816 L
.46991 .33753 L
.47023 .33679 L
.47054 .33595 L
.47086 .33492 L
.47118 .33381 L
.47148 .33262 L
.4718 .33122 L
.47211 .32976 L
.47244 .32809 L
.47276 .32635 L
.47306 .32458 L
.47339 .32259 L
.4737 .32057 L
.47403 .31833 L
.47435 .31607 L
.47466 .31382 L
.47498 .31134 L
.4753 .30889 L
.4756 .30648 L
.47592 .30386 L
.47623 .3013 L
.47656 .29854 L
.47688 .29586 L
.47719 .29327 L
.47751 .29051 L
.47783 .28786 L
.47816 .28506 L
.47848 .2824 L
.47879 .27988 L
.47912 .27725 L
.47943 .27478 L
.47974 .27248 L
.48006 .27013 L
.48037 .26795 L
.4807 .26577 L
.48102 .26379 L
.48133 .26201 L
.48165 .26028 L
.48197 .25877 L
.48227 .25749 L
.48259 .2563 L
.4829 .25534 L
.48323 .25454 L
.4834 .25423 L
.48355 .254 L
.4837 .25382 L
.48378 .25374 L
.48385 .25369 L
.48393 .25364 L
Mistroke
.48398 .25362 L
.484 .25361 L
.48402 .25361 L
.48404 .2536 L
.48406 .2536 L
.48407 .2536 L
.48408 .2536 L
.48409 .2536 L
.4841 .2536 L
.48411 .2536 L
.48411 .25359 L
.48412 .25359 L
.48413 .25359 L
.48413 .25359 L
.48414 .25359 L
.48414 .2536 L
.48415 .2536 L
.48416 .2536 L
.48417 .2536 L
.48418 .2536 L
.4842 .2536 L
.48422 .25361 L
.48426 .25362 L
.4843 .25363 L
.48434 .25365 L
.48442 .2537 L
.4845 .25377 L
.48467 .25396 L
.48483 .25423 L
.48514 .25491 L
.48546 .25591 L
.48578 .25716 L
.48611 .2588 L
.48643 .26069 L
.48674 .26281 L
.48707 .26538 L
.48738 .26818 L
.48769 .27118 L
.48801 .2747 L
.48832 .27841 L
.48865 .28271 L
.48897 .28719 L
.48928 .29183 L
.4896 .29711 L
.48992 .30253 L
.49022 .30805 L
.49054 .31426 L
.49085 .32057 L
.49118 .32762 L
.4915 .33475 L
Mistroke
.4918 .3419 L
.49212 .34984 L
.49244 .3578 L
.49277 .36657 L
.49309 .37534 L
.4934 .38406 L
.49372 .39362 L
.49404 .4031 L
.49434 .41247 L
.49466 .42269 L
.49497 .43277 L
.4953 .44374 L
.49562 .45452 L
.49593 .46509 L
.49625 .47653 L
.49657 .48773 L
.4969 .49981 L
.49722 .51161 L
.49753 .5231 L
.49786 .53544 L
.49817 .54744 L
.49848 .55906 L
.4988 .57151 L
.49911 .58356 L
.49944 .59641 L
.49961 .60285 L
.49976 .60882 L
.49991 .61461 L
.49995 .61602 L
.49997 .61676 L
.49999 .61754 L
.49999 .61774 L
.5 .61796 L
.5 .00016 L
.50001 .00038 L
.50003 .00117 L
.50007 .00273 L
.5004 .01567 L
.50072 .02811 L
.50103 .04004 L
.50136 .05268 L
.50167 .06478 L
.50198 .07634 L
.5023 .08854 L
.50261 .10017 L
.50294 .1124 L
.50326 .12404 L
.50357 .13508 L
.50389 .14664 L
.50421 .15759 L
Mistroke
.50454 .16902 L
.50486 .1798 L
.50517 .18995 L
.5055 .20051 L
.50582 .21042 L
.50612 .2197 L
.50644 .22932 L
.50676 .2383 L
.50709 .24754 L
.50741 .25613 L
.50771 .26411 L
.50804 .27228 L
.50836 .27982 L
.50866 .28678 L
.50898 .29387 L
.50929 .30036 L
.50962 .30692 L
.50994 .3129 L
.51024 .31832 L
.51057 .32376 L
.51088 .32865 L
.51122 .33349 L
.51154 .3378 L
.51184 .34163 L
.51217 .34535 L
.51249 .34861 L
.51279 .35144 L
.51312 .35412 L
.51343 .3564 L
.51376 .35849 L
.51408 .36019 L
.51438 .36155 L
.51471 .3627 L
.51487 .36316 L
.51502 .36352 L
.51517 .36382 L
.51533 .36406 L
.5154 .36416 L
.51549 .36425 L
.51556 .36432 L
.51564 .36437 L
.51567 .36439 L
.51572 .36441 L
.51576 .36442 L
.51579 .36443 L
.51581 .36443 L
.51583 .36444 L
.51584 .36444 L
.51585 .36444 L
.51586 .36444 L
Mistroke
.51586 .36444 L
.51587 .36444 L
.51587 .36444 L
.51588 .36444 L
.51588 .36444 L
.51589 .36444 L
.5159 .36444 L
.51591 .36444 L
.51592 .36444 L
.51594 .36443 L
.51596 .36443 L
.51598 .36443 L
.516 .36442 L
.51604 .3644 L
.51612 .36437 L
.5162 .36431 L
.51628 .36424 L
.51643 .36406 L
.5166 .36381 L
.51692 .36315 L
.51723 .36231 L
.51756 .3612 L
.51788 .35994 L
.51818 .35856 L
.51851 .35692 L
.51882 .35518 L
.51915 .35319 L
.51947 .35113 L
.51978 .34903 L
.52011 .34669 L
.52042 .34435 L
.52073 .34201 L
.52105 .33945 L
.52136 .33694 L
.52169 .33421 L
.52201 .33154 L
.52232 .32896 L
.52264 .32619 L
.52296 .32353 L
.52326 .32098 L
.52358 .31827 L
.52389 .3157 L
.52422 .313 L
.52454 .31045 L
.52484 .30805 L
.52517 .30556 L
.52548 .30323 L
.52581 .30084 L
.52613 .29863 L
.52644 .29659 L
Mistroke
.52676 .29452 L
.52708 .29263 L
.52738 .29091 L
.5277 .2892 L
.52801 .28767 L
.52834 .28616 L
.52866 .28484 L
.52897 .28369 L
.52929 .2826 L
.52961 .28167 L
.52994 .28083 L
.53026 .28016 L
.53057 .27963 L
.53073 .27941 L
.5309 .27921 L
.53106 .27905 L
.53121 .27894 L
.53137 .27885 L
.53146 .27881 L
.53149 .2788 L
.53154 .27879 L
.53157 .27878 L
.53161 .27877 L
.53164 .27877 L
.53166 .27876 L
.53168 .27876 L
.53169 .27876 L
.5317 .27876 L
.5317 .27876 L
.53171 .27876 L
.53172 .27876 L
.53173 .27876 L
.53174 .27876 L
.53175 .27876 L
.53176 .27876 L
.53177 .27876 L
.53178 .27876 L
.53179 .27876 L
.5318 .27876 L
.53181 .27876 L
.53182 .27876 L
.53184 .27876 L
.53189 .27877 L
.53193 .27878 L
.532 .2788 L
.53208 .27883 L
.53217 .27887 L
.53233 .27897 L
.5325 .2791 L
.5328 .27943 L
Mistroke
.53313 .27989 L
.53344 .28045 L
.53377 .28115 L
.53409 .28194 L
.5344 .28278 L
.53472 .28377 L
.53504 .28481 L
.53534 .28589 L
.53566 .28711 L
.53597 .28835 L
.5363 .28973 L
.53662 .29112 L
.53693 .29251 L
.53725 .29402 L
.53756 .29552 L
.5379 .29714 L
.53822 .29873 L
.53853 .30027 L
.53885 .30193 L
.53917 .30352 L
.53947 .30506 L
.5398 .30668 L
.54011 .30823 L
.54044 .30985 L
.54076 .31139 L
.54106 .31284 L
.54139 .31434 L
.5417 .31574 L
.54201 .31705 L
.54233 .31839 L
.54264 .31962 L
.54297 .32087 L
.54328 .32201 L
.54359 .32304 L
.54391 .32407 L
.54422 .32498 L
.54456 .32587 L
.54488 .32665 L
.54518 .32732 L
.54551 .32794 L
.54583 .32846 L
.54613 .32888 L
.54645 .32924 L
.54676 .32951 L
.54693 .32962 L
.54709 .3297 L
.54717 .32973 L
.54725 .32976 L
.54733 .32978 L
.5474 .3298 L
Mistroke
.54744 .3298 L
.54748 .32981 L
.54752 .32981 L
.54755 .32981 L
.54756 .32982 L
.54757 .32982 L
.54758 .32982 L
.54759 .32982 L
.5476 .32982 L
.54761 .32982 L
.54762 .32982 L
.54763 .32982 L
.54764 .32982 L
.54765 .32982 L
.54766 .32982 L
.54767 .32982 L
.54769 .32981 L
.54771 .32981 L
.54773 .32981 L
.54777 .32981 L
.54782 .3298 L
.5479 .32979 L
.54797 .32977 L
.54804 .32974 L
.54819 .32968 L
.54836 .32959 L
.54868 .32936 L
.54899 .32905 L
.54932 .32865 L
.54964 .32818 L
.54995 .32767 L
.55027 .32705 L
.55059 .32639 L
.55092 .32563 L
.55124 .32483 L
.55155 .32401 L
.55188 .32308 L
.5522 .32215 L
.5525 .32121 L
.55283 .32017 L
.55314 .31913 L
.55347 .31801 L
.55379 .3169 L
.5541 .31581 L
.55442 .31464 L
.55474 .3135 L
.55504 .3124 L
.55536 .31123 L
.55567 .3101 L
.556 .30892 L
Mistroke
.55632 .30779 L
.55663 .30672 L
.55695 .3056 L
.55727 .30454 L
.5576 .30346 L
.55792 .30244 L
.55823 .3015 L
.55856 .30054 L
.55887 .29966 L
.55918 .29886 L
.5595 .29805 L
.55981 .29733 L
.56014 .29661 L
.56046 .29598 L
.56077 .29543 L
.56109 .29491 L
.56141 .29446 L
.56171 .29409 L
.56203 .29376 L
.56234 .2935 L
.5625 .29339 L
.56267 .29329 L
.56284 .29322 L
.56299 .29316 L
.56315 .29312 L
.56323 .2931 L
.56327 .2931 L
.56331 .29309 L
.56335 .29309 L
.56339 .29308 L
.56341 .29308 L
.56343 .29308 L
.56344 .29308 L
.56345 .29308 L
.56346 .29308 L
.56346 .29308 L
.56347 .29308 L
.56348 .29308 L
.56349 .29308 L
.5635 .29308 L
.56351 .29308 L
.56351 .29308 L
.56352 .29308 L
.56353 .29308 L
.56355 .29308 L
.56357 .29308 L
.56359 .29308 L
.56362 .29309 L
.56366 .29309 L
.5637 .29309 L
Mistroke
.56378 .29311 L
.56386 .29312 L
.56393 .29314 L
.56409 .29319 L
.56424 .29325 L
.56456 .29343 L
.56486 .29366 L
.56519 .29396 L
.5655 .29431 L
.56583 .29474 L
.56615 .29521 L
.56646 .29571 L
.56679 .29629 L
.5671 .29689 L
.56741 .29751 L
.56773 .29822 L
.56804 .29893 L
.56837 .29972 L
.56869 .30052 L
.569 .30131 L
.56932 .30217 L
.56964 .30303 L
.56994 .30386 L
.57026 .30476 L
.57057 .30564 L
.5709 .30658 L
.57122 .30749 L
.57152 .30836 L
.57184 .30928 L
.57216 .31016 L
.57249 .31109 L
.57281 .31196 L
.57312 .31278 L
.57344 .31364 L
.57376 .31443 L
.57406 .31517 L
.57438 .31593 L
.57469 .31663 L
.57502 .31733 L
.57534 .31797 L
.57565 .31854 L
.57597 .31911 L
.57629 .31962 L
.57662 .3201 L
.57694 .32053 L
.57725 .32088 L
.57758 .32121 L
.57789 .32148 L
.5782 .32168 L
.57837 .32178 L
Mistroke
.57852 .32185 L
.57868 .32191 L
.57883 .32196 L
.57899 .322 L
.57907 .32201 L
.57911 .32202 L
.57915 .32202 L
.57919 .32203 L
.57923 .32203 L
.57927 .32203 L
.57929 .32203 L
.57931 .32203 L
.57932 .32203 L
.57933 .32203 L
.57934 .32203 L
.57934 .32203 L
.57935 .32203 L
.57936 .32203 L
.57937 .32203 L
.57938 .32203 L
.57939 .32203 L
.5794 .32203 L
.57941 .32203 L
.57941 .32203 L
.57944 .32203 L
.57945 .32203 L
.57949 .32203 L
.57954 .32203 L
.57962 .32202 L
.5797 .32201 L
.57977 .32199 L
.57992 .32196 L
.58008 .3219 L
.58041 .32176 L
.58072 .32157 L
.58105 .32132 L
.58137 .32103 L
.58168 .32071 L
.58201 .32032 L
.58232 .3199 L
.58262 .31946 L
.58295 .31896 L
.58326 .31844 L
.58359 .31785 L
.5839 .31725 L
.58421 .31665 L
.58453 .31598 L
.58485 .31532 L
.58518 .31459 L
.5855 .31386 L
Mistroke
.58581 .31316 L
.58614 .31239 L
.58645 .31165 L
.58676 .31092 L
.58708 .31015 L
.58739 .30941 L
.58772 .30863 L
.58804 .30787 L
.58835 .30716 L
.58867 .30642 L
.58899 .30571 L
.58929 .30505 L
.58961 .30437 L
.58992 .30373 L
.59025 .30308 L
.59057 .30249 L
.59087 .30194 L
.5912 .30139 L
.59151 .30089 L
.59184 .3004 L
.59216 .29996 L
.59247 .29958 L
.5928 .29922 L
.59311 .29891 L
.59341 .29865 L
.59374 .29841 L
.59405 .29823 L
.5942 .29815 L
.59438 .29808 L
.59454 .29802 L
.5947 .29798 L
.59485 .29795 L
.59494 .29794 L
.59498 .29793 L
.59502 .29793 L
.59506 .29793 L
.5951 .29792 L
.59512 .29792 L
.59514 .29792 L
.59516 .29792 L
.59518 .29792 L
.5952 .29792 L
.59521 .29792 L
.59522 .29792 L
.59523 .29792 L
.59523 .29792 L
.59524 .29792 L
.59525 .29792 L
.59526 .29792 L
.59527 .29792 L
Mistroke
.59528 .29792 L
.59529 .29792 L
.59531 .29792 L
.59533 .29792 L
.59537 .29792 L
.59541 .29792 L
.59548 .29793 L
.59556 .29794 L
.59565 .29796 L
.59581 .29799 L
.59597 .29804 L
.5963 .29816 L
.59662 .29833 L
.59693 .29853 L
.59725 .29878 L
.59757 .29907 L
.59787 .29938 L
.59819 .29974 L
.5985 .30012 L
.59883 .30056 L
.59915 .30102 L
.59945 .30149 L
.59978 .30201 L
.60009 .30254 L
.60042 .30313 L
.60074 .30372 L
.60105 .3043 L
.60137 .30493 L
.60169 .30555 L
.60199 .30616 L
.60231 .30682 L
.60262 .30746 L
.60295 .30814 L
.60327 .30879 L
.60358 .30942 L
.6039 .31009 L
.60422 .31072 L
.60455 .31138 L
.60487 .312 L
.60518 .31259 L
.60551 .31319 L
.60582 .31375 L
.60613 .31428 L
.60645 .31481 L
.60676 .31529 L
.60709 .31578 L
.60741 .31622 L
.60772 .31662 L
.60804 .317 L
.60836 .31734 L
Mistroke
.60866 .31764 L
.60898 .31791 L
.60929 .31815 L
.60962 .31835 L
.60994 .31852 L
.61024 .31864 L
.6104 .31868 L
.61057 .31872 L
.61065 .31874 L
.61074 .31875 L
.61082 .31876 L
.6109 .31877 L
.61094 .31877 L
.61098 .31878 L
.611 .31878 L
.61102 .31878 L
.61103 .31878 L
.61105 .31878 L
.61106 .31878 L
.61107 .31878 L
.61108 .31878 L
.61108 .31878 L
.61109 .31878 L
.6111 .31878 L
.61111 .31878 L
.61112 .31878 L
.61113 .31878 L
.61114 .31878 L
.61114 .31878 L
.61115 .31878 L
.61116 .31878 L
.61117 .31878 L
.61119 .31878 L
.61122 .31878 L
.61126 .31878 L
.61129 .31877 L
.61137 .31877 L
.61145 .31876 L
.61152 .31875 L
.61168 .31872 L
.61182 .31868 L
.61214 .31858 L
.61247 .31843 L
.61279 .31825 L
.6131 .31804 L
.61343 .31778 L
.61374 .3175 L
.61405 .3172 L
.61437 .31684 L
.61468 .31647 L
Mistroke
.61501 .31605 L
.61533 .31562 L
.61564 .31518 L
.61596 .31469 L
.61628 .3142 L
.61658 .31371 L
.6169 .31317 L
.61721 .31264 L
.61754 .31207 L
.61785 .3115 L
.61816 .31095 L
.61848 .31036 L
.6188 .30978 L
.61913 .30917 L
.61945 .30859 L
.61976 .30803 L
.62008 .30744 L
.6204 .30688 L
.6207 .30636 L
.62102 .30581 L
.62133 .3053 L
.62166 .30477 L
.62198 .30428 L
.62229 .30383 L
.62261 .30337 L
.62293 .30296 L
.62326 .30254 L
.62358 .30217 L
.62389 .30184 L
.62422 .30152 L
.62453 .30125 L
.62484 .30101 L
.62516 .30079 L
.62547 .30061 L
.6258 .30046 L
.62597 .3004 L
.62612 .30035 L
.62628 .3003 L
.62643 .30027 L
.62658 .30025 L
.62666 .30024 L
.62675 .30023 L
.62678 .30023 L
.62682 .30022 L
.62684 .30022 L
.62687 .30022 L
.62688 .30022 L
.62691 .30022 L
.62692 .30022 L
.62693 .30022 L
Mistroke
.62694 .30022 L
.62695 .30022 L
.62696 .30022 L
.62696 .30022 L
.62697 .30022 L
.62698 .30022 L
.62699 .30022 L
.62699 .30022 L
.627 .30022 L
.627 .30022 L
.62701 .30022 L
.62702 .30022 L
.62703 .30022 L
.62705 .30022 L
.62707 .30022 L
.62711 .30022 L
.62715 .30022 L
.62723 .30023 L
.62731 .30024 L
.62738 .30025 L
.62754 .30027 L
.62769 .3003 L
.628 .3004 L
.6283 .30052 L
.62863 .30068 L
.62894 .30086 L
.62927 .3011 L
.62958 .30135 L
.62989 .30162 L
.63022 .30194 L
.63053 .30227 L
.63086 .30265 L
.63118 .30305 L
.63149 .30344 L
.63182 .30389 L
.63213 .30434 L
.63244 .30478 L
.63276 .30527 L
.63307 .30576 L
.6334 .30629 L
.63372 .3068 L
.63403 .30731 L
.63436 .30785 L
.63467 .30837 L
.63497 .30888 L
.63529 .30941 L
.6356 .30993 L
.63593 .31047 L
.63625 .31098 L
.63655 .31146 L
Mistroke
.63688 .31196 L
.63719 .31244 L
.63752 .31292 L
.63784 .31337 L
.63815 .31378 L
.63848 .31421 L
.63879 .31459 L
.6391 .31493 L
.63942 .31528 L
.63973 .31559 L
.64006 .31588 L
.64038 .31614 L
.64068 .31636 L
.64101 .31657 L
.64132 .31673 L
.64166 .31688 L
.64182 .31693 L
.64198 .31698 L
.64214 .31702 L
.64229 .31705 L
.64244 .31708 L
.64252 .31709 L
.6426 .31709 L
.64264 .3171 L
.64268 .3171 L
.64271 .3171 L
.64273 .3171 L
.64275 .3171 L
.64277 .3171 L
.64279 .3171 L
.64281 .3171 L
.64282 .3171 L
.64283 .3171 L
.64284 .3171 L
.64285 .3171 L
.64285 .3171 L
.64286 .3171 L
.64287 .3171 L
.64288 .3171 L
.64288 .3171 L
.64289 .3171 L
.6429 .3171 L
.64292 .3171 L
.64293 .3171 L
.64296 .3171 L
.64298 .3171 L
.64302 .3171 L
.64306 .3171 L
.6431 .31709 L
.64319 .31709 L
Mistroke
.64327 .31708 L
.64343 .31705 L
.64357 .31702 L
.64389 .31694 L
.6442 .31682 L
.64452 .31667 L
.64483 .3165 L
.64516 .31628 L
.64548 .31604 L
.64579 .31579 L
.64612 .31549 L
.64643 .31518 L
.64674 .31486 L
.64706 .31449 L
.64737 .31412 L
.6477 .31371 L
.64802 .31329 L
.64832 .31288 L
.64865 .31242 L
.64896 .31197 L
.64929 .31148 L
.64962 .311 L
.64992 .31053 L
.65025 .31002 L
.65057 .30953 L
.65087 .30906 L
.6512 .30856 L
.65151 .30809 L
.65184 .30758 L
.65216 .30711 L
.65246 .30665 L
.65279 .30619 L
.65311 .30575 L
.65341 .30534 L
.65373 .30492 L
.65404 .30453 L
.65437 .30414 L
.65469 .30378 L
.65499 .30346 L
.65532 .30314 L
.65563 .30285 L
.65596 .30258 L
.65628 .30234 L
.65659 .30213 L
.65692 .30194 L
.65723 .30179 L
.65753 .30167 L
.6577 .30162 L
.65786 .30157 L
.65802 .30153 L
Mistroke
.65817 .30151 L
.65832 .30148 L
.6584 .30147 L
.65849 .30147 L
.65853 .30146 L
.65857 .30146 L
.65859 .30146 L
.65862 .30146 L
.65864 .30146 L
.65866 .30146 L
.65867 .30146 L
.65868 .30146 L
.65869 .30146 L
.6587 .30146 L
.6587 .30146 L
.65871 .30146 L
.65872 .30146 L
.65872 .30146 L
.65873 .30146 L
.65873 .30146 L
.65874 .30146 L
.65875 .30146 L
.65876 .30146 L
.65877 .30146 L
.65878 .30146 L
.6588 .30146 L
.65882 .30146 L
.65886 .30146 L
.6589 .30146 L
.65898 .30147 L
.65906 .30147 L
.65913 .30148 L
.65929 .30151 L
.65944 .30153 L
.65976 .30161 L
.66006 .30172 L
.66039 .30186 L
.66071 .30203 L
.66101 .30221 L
.66133 .30243 L
.66164 .30267 L
.66197 .30295 L
.66228 .30324 L
.66259 .30354 L
.66291 .30388 L
.66323 .30423 L
.66356 .30462 L
.66388 .30502 L
.66419 .30541 L
.66451 .30584 L
Mistroke
.66483 .30627 L
.66513 .30668 L
.66545 .30714 L
.66576 .30758 L
.66609 .30806 L
.66641 .30852 L
.66672 .30897 L
.66704 .30944 L
.66736 .30989 L
.66769 .31037 L
.66801 .31082 L
.66832 .31125 L
.66865 .3117 L
.66896 .31211 L
.66927 .3125 L
.66959 .3129 L
.6699 .31327 L
.67024 .31364 L
.67055 .31398 L
.67086 .31429 L
.67119 .3146 L
.6715 .31487 L
.67181 .31511 L
.67213 .31534 L
.67244 .31553 L
.67277 .31571 L
.67308 .31586 L
.67339 .31598 L
.67356 .31603 L
.67371 .31607 L
.67388 .31611 L
.67403 .31614 L
.67418 .31616 L
.67426 .31617 L
.67435 .31617 L
.67442 .31618 L
.67447 .31618 L
.67449 .31618 L
.6745 .31618 L
.67452 .31618 L
.67454 .31618 L
.67456 .31618 L
.67457 .31618 L
.67458 .31618 L
.67459 .31618 L
.6746 .31618 L
.6746 .31618 L
.67461 .31618 L
.67462 .31618 L
.67463 .31618 L
Mistroke
.67464 .31618 L
.67465 .31618 L
.67467 .31618 L
.67469 .31618 L
.67473 .31618 L
.67477 .31618 L
.6748 .31618 L
.67488 .31617 L
.67497 .31617 L
.67514 .31614 L
.6753 .31612 L
.67561 .31604 L
.67593 .31594 L
.67624 .31581 L
.67658 .31565 L
.6769 .31546 L
.67721 .31526 L
.67753 .31502 L
.67785 .31476 L
.67815 .31449 L
.67848 .31419 L
.67879 .31388 L
.67912 .31352 L
.67944 .31317 L
.67975 .31281 L
.68007 .31241 L
.68039 .31202 L
.68069 .31163 L
.68101 .3112 L
.68132 .31079 L
.68165 .31034 L
.68197 .3099 L
.68227 .30948 L
.6826 .30903 L
.68291 .30859 L
.68324 .30814 L
.68356 .3077 L
.68387 .30728 L
.6842 .30685 L
.68451 .30644 L
.68481 .30606 L
.68514 .30566 L
.68545 .3053 L
.68578 .30492 L
.6861 .30458 L
.6864 .30427 L
.68673 .30395 L
.68704 .30367 L
.68738 .3034 L
.6877 .30315 L
Mistroke
.68801 .30294 L
.68833 .30274 L
.68865 .30258 L
.68895 .30244 L
.68928 .30232 L
.68959 .30224 L
.68976 .3022 L
.68992 .30217 L
.69 .30216 L
.69008 .30215 L
.69016 .30214 L
.69023 .30214 L
.6903 .30214 L
.69034 .30213 L
.69036 .30213 L
.69038 .30213 L
.6904 .30213 L
.69042 .30213 L
.69043 .30213 L
.69044 .30213 L
.69045 .30213 L
.69045 .30213 L
.69046 .30213 L
.69047 .30213 L
.69048 .30213 L
.69049 .30213 L
.6905 .30213 L
.69051 .30213 L
.69052 .30213 L
.69053 .30213 L
.69055 .30213 L
.69057 .30213 L
.69061 .30213 L
.69065 .30214 L
.69069 .30214 L
.69077 .30214 L
.69086 .30215 L
.69102 .30217 L
.69116 .30219 L
.69147 .30227 L
.69181 .30237 L
.69213 .30249 L
.69243 .30264 L
.69276 .30282 L
.69308 .30302 L
.69338 .30323 L
.6937 .30348 L
.69401 .30374 L
.69434 .30404 L
.69466 .30435 L
Mistroke
.69497 .30466 L
.69529 .30501 L
.6956 .30537 L
.69594 .30576 L
.69626 .30614 L
.69657 .30653 L
.6969 .30695 L
.69721 .30736 L
.69752 .30776 L
.69784 .30819 L
.69815 .3086 L
.69848 .30905 L
.6988 .30948 L
.69911 .30989 L
.69943 .31032 L
.69975 .31073 L
.70005 .31112 L
.70037 .31152 L
.70068 .3119 L
.70101 .31229 L
.70133 .31265 L
.70163 .31299 L
.70196 .31333 L
.70227 .31364 L
.7026 .31395 L
.70292 .31423 L
.70323 .31447 L
.70356 .31471 L
.70388 .31492 L
.70418 .3151 L
.7045 .31527 L
.70481 .3154 L
.70514 .31552 L
.70531 .31557 L
.70546 .31561 L
.70562 .31564 L
.70577 .31567 L
.70585 .31568 L
.70593 .31569 L
.70601 .3157 L
.70608 .3157 L
.70616 .31571 L
.7062 .31571 L
.70624 .31571 L
.70626 .31571 L
.70627 .31571 L
.70629 .31571 L
.7063 .31571 L
.70631 .31571 L
.70631 .31571 L
Mistroke
.70632 .31571 L
.70633 .31571 L
.70634 .31571 L
.70635 .31571 L
.70635 .31571 L
.70636 .31571 L
.70637 .31571 L
.70638 .31571 L
.70639 .31571 L
.70641 .31571 L
.70643 .31571 L
.70645 .31571 L
.70649 .31571 L
.70653 .31571 L
.70657 .31571 L
.70665 .3157 L
.70672 .3157 L
.70687 .31568 L
.70704 .31565 L
.70736 .31558 L
.70768 .31548 L
.70798 .31537 L
.7083 .31522 L
.70861 .31505 L
.70894 .31485 L
.70926 .31464 L
.70956 .31441 L
.70989 .31414 L
.7102 .31387 L
.71053 .31355 L
.71085 .31323 L
.71116 .31291 L
.71149 .31255 L
.7118 .31219 L
.7121 .31183 L
.71243 .31144 L
.71274 .31106 L
.71307 .31064 L
.71339 .31023 L
.71369 .30983 L
.71402 .3094 L
.71433 .30899 L
.71466 .30855 L
.71499 .30814 L
.71529 .30774 L
.71562 .30732 L
.71594 .30692 L
.71624 .30655 L
.71657 .30616 L
.71688 .3058 L
Mistroke
.71721 .30543 L
.71753 .30508 L
.71784 .30477 L
.71816 .30445 L
.71848 .30416 L
.71878 .30391 L
.7191 .30365 L
.71941 .30343 L
.71974 .30321 L
.72006 .30303 L
.72036 .30287 L
.72069 .30273 L
.721 .30262 L
.72116 .30258 L
.72133 .30253 L
.72149 .3025 L
.72166 .30247 L
.72181 .30245 L
.7219 .30244 L
.72198 .30244 L
.72202 .30244 L
.72207 .30243 L
.72211 .30243 L
.72213 .30243 L
.72215 .30243 L
.72216 .30243 L
.72218 .30243 L
.72219 .30243 L
.7222 .30243 L
.72221 .30243 L
.72222 .30243 L
.72223 .30243 L
.72224 .30243 L
.72225 .30243 L
.72226 .30243 L
.72227 .30243 L
.72227 .30243 L
.72229 .30243 L
.72231 .30243 L
.72233 .30243 L
.72237 .30243 L
.72241 .30244 L
.72244 .30244 L
.72252 .30244 L
.72261 .30245 L
.72277 .30247 L
.72293 .3025 L
.72327 .30257 L
.72359 .30267 L
.7239 .30279 L
Mistroke
.72422 .30294 L
.72454 .30311 L
.72484 .3033 L
.72517 .30352 L
.72548 .30375 L
.72581 .30402 L
.72613 .3043 L
.72644 .30459 L
.72676 .30491 L
.72708 .30524 L
.72738 .30557 L
.7277 .30593 L
.72801 .3063 L
.72834 .30669 L
.72866 .30708 L
.72896 .30746 L
.72929 .30788 L
.7296 .30828 L
.72993 .30871 L
.73025 .30913 L
.73056 .30953 L
.73089 .30995 L
.7312 .31035 L
.73151 .31074 L
.73183 .31114 L
.73214 .31151 L
.73247 .3119 L
.73279 .31227 L
.73309 .31261 L
.73342 .31295 L
.73373 .31327 L
.73407 .31359 L
.73439 .31388 L
.7347 .31414 L
.73503 .31439 L
.73534 .31462 L
.73565 .31481 L
.73597 .315 L
.73628 .31515 L
.73661 .31529 L
.73693 .31539 L
.73724 .31547 L
.7374 .31551 L
.73757 .31553 L
.73764 .31554 L
.73772 .31555 L
.7378 .31556 L
.73787 .31556 L
.73791 .31556 L
.73795 .31556 L
Mistroke
.73799 .31557 L
.73802 .31557 L
.73803 .31557 L
.73804 .31557 L
.73805 .31557 L
.73806 .31557 L
.73806 .31557 L
.73807 .31557 L
.73808 .31557 L
.73809 .31557 L
.7381 .31557 L
.73811 .31557 L
.73812 .31557 L
.73813 .31557 L
.73814 .31557 L
.73815 .31557 L
.73816 .31557 L
.73818 .31557 L
.7382 .31557 L
.73824 .31556 L
.73828 .31556 L
.73835 .31556 L
.73844 .31555 L
.73852 .31554 L
.73867 .31552 L
.73884 .3155 L
.73916 .31542 L
.73948 .31532 L
.73978 .31521 L
.7401 .31506 L
.74042 .31489 L
.74075 .31469 L
.74106 .31447 L
.74137 .31424 L
.74169 .31397 L
.74201 .3137 L
.74234 .31338 L
.74266 .31307 L
.74297 .31274 L
.7433 .31238 L
.74362 .31203 L
.74392 .31167 L
.74424 .31128 L
.74455 .3109 L
.74489 .31048 L
.74521 .31007 L
.74551 .30968 L
.74584 .30926 L
.74615 .30885 L
.74646 .30846 L
Mistroke
.74678 .30804 L
.74709 .30764 L
.74742 .30723 L
.74773 .30683 L
.74804 .30646 L
.74836 .30608 L
.74868 .30572 L
.74901 .30535 L
.74933 .30501 L
.74964 .3047 L
.74997 .30439 L
.75028 .30411 L
.75058 .30385 L
.75091 .3036 L
.75122 .30338 L
.75155 .30317 L
.75187 .30299 L
.75217 .30284 L
.7525 .30271 L
.75281 .3026 L
.75297 .30256 L
.75315 .30252 L
.7533 .30249 L
.75347 .30246 L
.75363 .30245 L
.75372 .30244 L
.7538 .30243 L
.75384 .30243 L
.75386 .30243 L
.75388 .30243 L
.7539 .30243 L
.75391 .30243 L
.75392 .30243 L
.75393 .30243 L
.75394 .30243 L
.75395 .30243 L
.75396 .30243 L
.75397 .30243 L
.75398 .30243 L
.75399 .30243 L
.754 .30243 L
.75401 .30243 L
.75401 .30243 L
.75403 .30243 L
.75405 .30243 L
.75407 .30243 L
.75411 .30243 L
.75415 .30244 L
.75419 .30244 L
.75427 .30244 L
Mistroke
.75435 .30245 L
.75443 .30246 L
.75459 .30248 L
.75476 .30251 L
.75506 .30258 L
.75538 .30269 L
.75569 .30281 L
.75602 .30297 L
.75634 .30314 L
.75664 .30333 L
.75697 .30356 L
.75728 .3038 L
.75761 .30408 L
.75793 .30436 L
.75824 .30466 L
.75857 .30499 L
.75888 .30532 L
.75919 .30565 L
.75951 .30602 L
.75982 .30639 L
.76015 .30679 L
.76047 .30719 L
.76077 .30758 L
.7611 .308 L
.76141 .30841 L
.76175 .30884 L
.76207 .30927 L
.76238 .30967 L
.7627 .3101 L
.76302 .31051 L
.76333 .3109 L
.76365 .3113 L
.76396 .31168 L
.76429 .31208 L
.76461 .31245 L
.76492 .31279 L
.76525 .31314 L
.76556 .31346 L
.76586 .31375 L
.76619 .31404 L
.7665 .3143 L
.76682 .31456 L
.76714 .31478 L
.76745 .31498 L
.76777 .31516 L
.76809 .31531 L
.76842 .31545 L
.76874 .31555 L
.76905 .31563 L
.76921 .31566 L
Mistroke
.76937 .31568 L
.76945 .31569 L
.76953 .3157 L
.76961 .31571 L
.76968 .31571 L
.76972 .31571 L
.76974 .31571 L
.76976 .31571 L
.76978 .31571 L
.76979 .31571 L
.7698 .31571 L
.76981 .31571 L
.76982 .31571 L
.76983 .31571 L
.76984 .31571 L
.76984 .31571 L
.76985 .31571 L
.76986 .31571 L
.76987 .31571 L
.76988 .31571 L
.76989 .31571 L
.76992 .31571 L
.76994 .31571 L
.76996 .31571 L
.77 .31571 L
.77004 .31571 L
.77008 .31571 L
.77017 .3157 L
.77024 .31569 L
.77033 .31568 L
.7705 .31566 L
.77066 .31563 L
.77097 .31555 L
.7713 .31544 L
.77161 .3153 L
.77192 .31515 L
.77224 .31497 L
.77255 .31477 L
.77288 .31453 L
.7732 .31428 L
.77351 .31402 L
.77384 .31372 L
.77415 .31341 L
.77445 .3131 L
.77477 .31275 L
.77508 .3124 L
.77541 .31201 L
.77573 .31163 L
.77604 .31125 L
.77636 .31083 L
Mistroke
.77667 .31043 L
.777 .30999 L
.77732 .30956 L
.77763 .30915 L
.77796 .30871 L
.77828 .30829 L
.77858 .30788 L
.7789 .30746 L
.77921 .30705 L
.77954 .30663 L
.77986 .30623 L
.78017 .30586 L
.78049 .30547 L
.78081 .30512 L
.78114 .30475 L
.78146 .30442 L
.78177 .30412 L
.7821 .30381 L
.78242 .30354 L
.78272 .3033 L
.78305 .30307 L
.78336 .30287 L
.78369 .30268 L
.78401 .30252 L
.78432 .30239 L
.78464 .30229 L
.7848 .30224 L
.78496 .30221 L
.78511 .30218 L
.78526 .30216 L
.78534 .30215 L
.78542 .30214 L
.7855 .30214 L
.78554 .30214 L
.78557 .30213 L
.78561 .30213 L
.78563 .30213 L
.78565 .30213 L
.78566 .30213 L
.78567 .30213 L
.78568 .30213 L
.78569 .30213 L
.7857 .30213 L
.78571 .30213 L
.78571 .30213 L
.78572 .30213 L
.78573 .30213 L
.78574 .30213 L
.78575 .30213 L
.78577 .30213 L
Mistroke
.78579 .30213 L
.7858 .30213 L
.78584 .30213 L
.78588 .30214 L
.78596 .30214 L
.78604 .30215 L
.78621 .30216 L
.78636 .30219 L
.78653 .30222 L
.78685 .30231 L
.78717 .30242 L
.78747 .30255 L
.7878 .30271 L
.78811 .30289 L
.78844 .30311 L
.78875 .30335 L
.78906 .3036 L
.78939 .30388 L
.7897 .30418 L
.79003 .30451 L
.79035 .30486 L
.79066 .3052 L
.79099 .30559 L
.79131 .30597 L
.79161 .30635 L
.79193 .30677 L
.79225 .30718 L
.79258 .30763 L
.7929 .30806 L
.7932 .30849 L
.79353 .30894 L
.79385 .30938 L
.79415 .3098 L
.79447 .31024 L
.79478 .31066 L
.79511 .31111 L
.79543 .31153 L
.79573 .31193 L
.79606 .31234 L
.79637 .31272 L
.7967 .31311 L
.79702 .31347 L
.79733 .3138 L
.79766 .31414 L
.79797 .31444 L
.79828 .31471 L
.7986 .31497 L
.79891 .31521 L
.79924 .31543 L
.79956 .31562 L
Mistroke
.79987 .31577 L
.80019 .31591 L
.80051 .31602 L
.80081 .3161 L
.80096 .31613 L
.80104 .31614 L
.80113 .31615 L
.80121 .31616 L
.80129 .31617 L
.80134 .31618 L
.80138 .31618 L
.80142 .31618 L
.80146 .31618 L
.8015 .31618 L
.80152 .31618 L
.80153 .31618 L
.80154 .31618 L
.80155 .31618 L
.80156 .31618 L
.80157 .31618 L
.80157 .31618 L
.80158 .31618 L
.80159 .31618 L
.8016 .31618 L
.80161 .31618 L
.80162 .31618 L
.80163 .31618 L
.80165 .31618 L
.80167 .31618 L
.80169 .31618 L
.80173 .31618 L
.80178 .31618 L
.80186 .31617 L
.80195 .31617 L
.80211 .31615 L
.80227 .31612 L
.80244 .31608 L
.80274 .316 L
.80306 .31588 L
.80337 .31574 L
.8037 .31556 L
.80402 .31537 L
.80432 .31515 L
.80465 .3149 L
.80496 .31464 L
.80529 .31433 L
.80561 .31401 L
.80592 .31368 L
.80625 .31332 L
.80656 .31295 L
Mistroke
.80686 .31258 L
.80719 .31216 L
.8075 .31176 L
.80783 .31131 L
.80815 .31087 L
.80845 .31044 L
.80878 .30997 L
.80909 .30952 L
.80942 .30904 L
.80975 .30857 L
.81005 .30812 L
.81038 .30765 L
.8107 .30719 L
.811 .30676 L
.81133 .30631 L
.81164 .30589 L
.81197 .30545 L
.81229 .30504 L
.8126 .30466 L
.81292 .30428 L
.81324 .30393 L
.81354 .3036 L
.81386 .30328 L
.81417 .30299 L
.8145 .30271 L
.81482 .30246 L
.81513 .30225 L
.81545 .30205 L
.81576 .30188 L
.8161 .30173 L
.81642 .30162 L
.81673 .30154 L
.81689 .30151 L
.81697 .30149 L
.81705 .30148 L
.81714 .30147 L
.81721 .30147 L
.81725 .30147 L
.81729 .30146 L
.81732 .30146 L
.81736 .30146 L
.81738 .30146 L
.8174 .30146 L
.81741 .30146 L
.81742 .30146 L
.81743 .30146 L
.81744 .30146 L
.81744 .30146 L
.81745 .30146 L
.81746 .30146 L
Mistroke
.81746 .30146 L
.81747 .30146 L
.81748 .30146 L
.81749 .30146 L
.81749 .30146 L
.8175 .30146 L
.81752 .30146 L
.81754 .30146 L
.81756 .30146 L
.8176 .30146 L
.81765 .30146 L
.81768 .30147 L
.81777 .30147 L
.81785 .30148 L
.818 .3015 L
.81816 .30153 L
.81831 .30156 L
.81862 .30166 L
.81893 .30178 L
.81925 .30193 L
.81956 .30211 L
.81989 .30232 L
.82021 .30256 L
.82052 .30281 L
.82085 .30311 L
.82116 .30342 L
.82146 .30374 L
.82178 .3041 L
.82209 .30446 L
.82242 .30487 L
.82274 .30528 L
.82305 .30569 L
.82337 .30615 L
.82368 .30659 L
.82402 .30708 L
.82434 .30756 L
.82464 .30803 L
.82497 .30853 L
.82529 .30901 L
.82559 .30948 L
.82591 .30998 L
.82622 .31046 L
.82655 .31097 L
.82687 .31144 L
.82718 .3119 L
.82751 .31237 L
.82782 .31281 L
.82815 .31326 L
.82847 .31369 L
.82878 .31408 L
Mistroke
.82911 .31447 L
.82943 .31483 L
.82973 .31515 L
.83006 .31548 L
.83037 .31576 L
.8307 .31604 L
.83102 .31628 L
.83133 .31648 L
.83165 .31666 L
.83197 .31681 L
.83227 .31693 L
.83244 .31698 L
.83259 .31702 L
.83275 .31705 L
.8329 .31708 L
.83298 .31708 L
.83306 .31709 L
.8331 .3171 L
.83314 .3171 L
.83318 .3171 L
.8332 .3171 L
.83322 .3171 L
.83324 .3171 L
.83326 .3171 L
.83327 .3171 L
.83328 .3171 L
.83329 .3171 L
.8333 .3171 L
.83331 .3171 L
.83332 .3171 L
.83332 .3171 L
.83333 .3171 L
.83333 .3171 L
.83334 .3171 L
.83335 .3171 L
.83336 .3171 L
.83337 .3171 L
.83338 .3171 L
.8334 .3171 L
.83342 .3171 L
.83346 .3171 L
.8335 .3171 L
.83353 .3171 L
.83361 .31709 L
.83368 .31709 L
.83385 .31706 L
.83401 .31703 L
.83416 .317 L
.83447 .3169 L
.83478 .31677 L
Mistroke
.83511 .31661 L
.83542 .31642 L
.83575 .31619 L
.83607 .31593 L
.83638 .31566 L
.83671 .31534 L
.83703 .31501 L
.83733 .31466 L
.83766 .31428 L
.83797 .31388 L
.8383 .31344 L
.83862 .31299 L
.83892 .31255 L
.83925 .31206 L
.83957 .31157 L
.83987 .31109 L
.84019 .31057 L
.8405 .31007 L
.84083 .30952 L
.84115 .309 L
.84145 .30849 L
.84178 .30794 L
.84209 .30742 L
.84242 .30688 L
.84274 .30636 L
.84305 .30586 L
.84338 .30535 L
.8437 .30487 L
.844 .30442 L
.84432 .30396 L
.84463 .30353 L
.84496 .3031 L
.84528 .30271 L
.84559 .30235 L
.84591 .302 L
.84623 .30169 L
.84653 .30141 L
.84685 .30115 L
.84716 .30093 L
.84749 .30072 L
.84781 .30055 L
.84811 .30042 L
.84828 .30037 L
.84844 .30032 L
.8486 .30028 L
.84875 .30025 L
.84882 .30024 L
.8489 .30023 L
.84898 .30023 L
.84903 .30022 L
Mistroke
.84907 .30022 L
.84911 .30022 L
.84913 .30022 L
.84914 .30022 L
.84915 .30022 L
.84916 .30022 L
.84917 .30022 L
.84918 .30022 L
.84919 .30022 L
.8492 .30022 L
.84921 .30022 L
.84921 .30022 L
.84922 .30022 L
.84923 .30022 L
.84924 .30022 L
.84925 .30022 L
.84927 .30022 L
.84929 .30022 L
.84931 .30022 L
.84934 .30022 L
.84938 .30022 L
.84946 .30023 L
.84953 .30024 L
.8497 .30026 L
.84985 .30029 L
.85002 .30033 L
.85034 .30044 L
.85065 .30058 L
.85099 .30076 L
.85131 .30098 L
.85161 .30121 L
.85194 .30149 L
.85226 .3018 L
.85256 .30212 L
.85288 .30249 L
.85319 .30287 L
.85353 .3033 L
.85384 .30375 L
.85415 .30419 L
.85448 .30469 L
.85479 .30519 L
.85512 .30574 L
.85544 .30628 L
.85575 .30681 L
.85608 .30739 L
.8564 .30796 L
.8567 .30852 L
.85703 .30911 L
.85734 .30968 L
.85767 .31029 L
Mistroke
.85799 .31087 L
.8583 .31143 L
.85862 .31201 L
.85894 .31257 L
.85924 .31309 L
.85956 .31363 L
.85987 .31414 L
.8602 .31465 L
.86052 .31513 L
.86083 .31557 L
.86115 .31602 L
.86146 .31642 L
.8618 .31681 L
.86212 .31717 L
.86243 .31748 L
.86275 .31777 L
.86307 .31802 L
.86337 .31823 L
.8637 .31842 L
.86401 .31856 L
.86417 .31862 L
.86434 .31868 L
.86449 .31871 L
.86458 .31873 L
.86466 .31875 L
.86474 .31876 L
.86481 .31877 L
.8649 .31877 L
.86494 .31878 L
.86496 .31878 L
.86498 .31878 L
.865 .31878 L
.86501 .31878 L
.86502 .31878 L
.86503 .31878 L
.86504 .31878 L
.86505 .31878 L
.86506 .31878 L
.86507 .31878 L
.86508 .31878 L
.86509 .31878 L
.8651 .31878 L
.8651 .31878 L
.86511 .31878 L
.86512 .31878 L
.86513 .31878 L
.86514 .31878 L
.86516 .31878 L
.86518 .31878 L
.86521 .31878 L
Mistroke
.86525 .31877 L
.86529 .31877 L
.86537 .31876 L
.86544 .31875 L
.86561 .31873 L
.86576 .31869 L
.86593 .31864 L
.86626 .31851 L
.86657 .31835 L
.86687 .31816 L
.8672 .31792 L
.86751 .31766 L
.86784 .31734 L
.86815 .317 L
.86846 .31663 L
.86878 .31622 L
.8691 .31578 L
.86943 .31529 L
.86975 .31479 L
.87006 .31429 L
.87038 .31373 L
.8707 .31316 L
.871 .3126 L
.87133 .31199 L
.87164 .31139 L
.87197 .31073 L
.87229 .31009 L
.87259 .30946 L
.87292 .3088 L
.87323 .30815 L
.87353 .30753 L
.87386 .30687 L
.87416 .30623 L
.87449 .30557 L
.87481 .30495 L
.87511 .30435 L
.87544 .30374 L
.87575 .30317 L
.87608 .30258 L
.8764 .30203 L
.87671 .30154 L
.87704 .30103 L
.87735 .30058 L
.87765 .30017 L
.87798 .29976 L
.87829 .29941 L
.87862 .29907 L
.87893 .29879 L
.87924 .29855 L
.87957 .29833 L
Mistroke
.87988 .29817 L
.88004 .2981 L
.88021 .29804 L
.88036 .29799 L
.88045 .29797 L
.88053 .29796 L
.88062 .29794 L
.88069 .29793 L
.88077 .29793 L
.88082 .29792 L
.88084 .29792 L
.88086 .29792 L
.88088 .29792 L
.8809 .29792 L
.88091 .29792 L
.88092 .29792 L
.88093 .29792 L
.88093 .29792 L
.88094 .29792 L
.88094 .29792 L
.88095 .29792 L
.88096 .29792 L
.88097 .29792 L
.88098 .29792 L
.88099 .29792 L
.881 .29792 L
.88102 .29792 L
.88104 .29792 L
.88106 .29792 L
.8811 .29792 L
.88113 .29793 L
.88117 .29793 L
.88124 .29794 L
.88133 .29795 L
.88147 .29798 L
.88164 .29802 L
.88181 .29808 L
.88212 .29821 L
.88244 .29841 L
.88276 .29863 L
.88306 .29889 L
.88339 .29921 L
.8837 .29956 L
.88403 .29996 L
.88435 .3004 L
.88466 .30085 L
.88498 .30137 L
.8853 .3019 L
.8856 .30245 L
.88592 .30305 L
Mistroke
.88623 .30366 L
.88656 .30434 L
.88688 .30501 L
.88719 .30568 L
.88751 .3064 L
.88782 .30712 L
.88816 .30789 L
.88848 .30865 L
.88879 .30938 L
.88911 .31016 L
.88943 .31091 L
.88973 .31163 L
.89006 .3124 L
.89037 .31312 L
.8907 .31388 L
.89102 .3146 L
.89132 .31527 L
.89165 .31597 L
.89196 .31661 L
.89227 .31721 L
.89259 .31782 L
.8929 .31837 L
.89323 .31893 L
.89354 .31943 L
.89385 .31987 L
.89417 .3203 L
.89448 .32067 L
.89481 .32103 L
.89513 .32132 L
.89544 .32155 L
.89577 .32175 L
.89593 .32183 L
.89608 .32189 L
.89624 .32195 L
.89639 .32199 L
.89647 .322 L
.89655 .32202 L
.89659 .32202 L
.89663 .32202 L
.89666 .32203 L
.8967 .32203 L
.89672 .32203 L
.89674 .32203 L
.89676 .32203 L
.89678 .32203 L
.89679 .32203 L
.8968 .32203 L
.8968 .32203 L
.89681 .32203 L
.89682 .32203 L
Mistroke
.89682 .32203 L
.89683 .32203 L
.89683 .32203 L
.89684 .32203 L
.89685 .32203 L
.89685 .32203 L
.89686 .32203 L
.89687 .32203 L
.89688 .32203 L
.89689 .32203 L
.89691 .32203 L
.89695 .32203 L
.89699 .32203 L
.89703 .32202 L
.89711 .32201 L
.89719 .322 L
.89736 .32196 L
.89751 .32191 L
.89768 .32185 L
.89801 .32167 L
.89833 .32145 L
.89864 .32119 L
.89896 .32086 L
.89928 .32049 L
.89961 .32005 L
.89993 .31958 L
.90024 .31908 L
.90057 .3185 L
.90089 .3179 L
.90119 .31728 L
.90151 .31659 L
.90183 .31589 L
.90216 .31511 L
.90248 .31432 L
.90278 .31354 L
.90311 .31269 L
.90343 .31184 L
.90373 .31101 L
.90405 .31012 L
.90436 .30924 L
.90469 .3083 L
.90501 .30739 L
.90531 .30652 L
.90564 .30559 L
.90595 .3047 L
.90628 .30377 L
.90661 .30288 L
.90691 .30205 L
.90724 .30118 L
.90756 .30037 L
Mistroke
.90786 .29962 L
.90818 .29885 L
.9085 .29814 L
.90883 .29742 L
.90915 .29678 L
.90945 .2962 L
.90978 .29563 L
.91009 .29513 L
.91039 .29469 L
.91072 .29428 L
.91103 .29394 L
.91136 .29364 L
.91167 .29341 L
.91198 .29324 L
.91213 .29318 L
.9123 .29313 L
.91238 .29311 L
.91243 .2931 L
.91247 .2931 L
.91251 .29309 L
.91256 .29309 L
.91258 .29309 L
.9126 .29308 L
.91262 .29308 L
.91263 .29308 L
.91265 .29308 L
.91267 .29308 L
.91268 .29308 L
.91269 .29308 L
.91269 .29308 L
.9127 .29308 L
.91271 .29308 L
.91273 .29308 L
.91273 .29308 L
.91274 .29308 L
.91276 .29308 L
.91277 .29308 L
.91278 .29308 L
.9128 .29308 L
.91284 .29309 L
.91289 .29309 L
.91296 .2931 L
.91304 .29312 L
.91312 .29314 L
.91327 .29318 L
.91343 .29325 L
.9136 .29334 L
.9139 .29354 L
.91423 .29382 L
.91454 .29416 L
Mistroke
.91487 .29458 L
.91519 .29505 L
.9155 .29556 L
.91583 .29617 L
.91614 .29681 L
.91645 .29748 L
.91677 .29824 L
.91708 .29903 L
.91741 .29992 L
.91773 .30082 L
.91804 .30172 L
.91836 .30273 L
.91868 .30373 L
.91898 .30472 L
.9193 .30581 L
.91961 .30688 L
.91994 .30803 L
.92025 .30916 L
.92056 .31026 L
.92088 .31144 L
.9212 .31257 L
.92153 .31377 L
.92185 .31493 L
.92215 .31603 L
.92248 .31718 L
.9228 .31827 L
.9231 .31929 L
.92342 .32035 L
.92373 .32134 L
.92406 .32235 L
.92438 .32329 L
.92469 .32414 L
.92501 .32499 L
.92532 .32576 L
.92566 .32651 L
.92598 .32717 L
.92629 .32775 L
.92661 .32828 L
.92693 .32873 L
.92723 .32909 L
.92756 .3294 L
.92787 .32961 L
.92804 .3297 L
.92812 .32973 L
.9282 .32976 L
.92828 .32978 L
.92832 .32979 L
.92836 .3298 L
.9284 .3298 L
.92844 .32981 L
Mistroke
.92847 .32981 L
.92849 .32981 L
.92851 .32982 L
.92853 .32982 L
.92854 .32982 L
.92855 .32982 L
.92856 .32982 L
.92857 .32982 L
.92857 .32982 L
.92858 .32982 L
.92859 .32982 L
.9286 .32982 L
.92861 .32982 L
.92862 .32982 L
.92863 .32982 L
.92865 .32981 L
.92866 .32981 L
.92871 .32981 L
.92875 .3298 L
.92883 .32979 L
.92891 .32977 L
.92899 .32974 L
.92914 .32968 L
.9293 .3296 L
.92944 .3295 L
.92976 .32923 L
.93009 .32885 L
.93041 .3284 L
.93071 .32788 L
.93104 .32724 L
.93136 .32655 L
.93166 .32581 L
.93198 .32494 L
.93229 .32403 L
.93262 .32298 L
.93294 .3219 L
.93324 .3208 L
.93357 .31956 L
.93388 .31831 L
.93421 .31692 L
.93454 .31553 L
.93484 .31415 L
.93517 .31263 L
.93549 .31113 L
.93579 .30966 L
.93611 .30807 L
.93643 .30652 L
.93676 .30486 L
.93707 .30325 L
.93738 .3017 L
Mistroke
.93771 .30006 L
.93802 .29849 L
.93832 .297 L
.93865 .29543 L
.93895 .29395 L
.93928 .29242 L
.9396 .29099 L
.93991 .28966 L
.94023 .2883 L
.94054 .28705 L
.94087 .2858 L
.94119 .28467 L
.9415 .28367 L
.94183 .28268 L
.94214 .28183 L
.94245 .2811 L
.94277 .28042 L
.94308 .27987 L
.94341 .2794 L
.94357 .27922 L
.94373 .27907 L
.94389 .27895 L
.94403 .27886 L
.94411 .27883 L
.9442 .2788 L
.94424 .27878 L
.94428 .27878 L
.94431 .27877 L
.94435 .27876 L
.94437 .27876 L
.94439 .27876 L
.9444 .27876 L
.94441 .27876 L
.94441 .27876 L
.94442 .27876 L
.94443 .27876 L
.94444 .27876 L
.94445 .27876 L
.94445 .27876 L
.94446 .27876 L
.94446 .27876 L
.94447 .27876 L
.94448 .27876 L
.9445 .27876 L
.94452 .27876 L
.94454 .27876 L
.94458 .27877 L
.94461 .27878 L
.94465 .27878 L
.94473 .27881 L
Mistroke
.94481 .27884 L
.94495 .27892 L
.94512 .27905 L
.94529 .2792 L
.94559 .27959 L
.94592 .28013 L
.94623 .28078 L
.94656 .28162 L
.94689 .28256 L
.94719 .28359 L
.94752 .28482 L
.94784 .28614 L
.94814 .28752 L
.94847 .28911 L
.94878 .29076 L
.94911 .29263 L
.94943 .29455 L
.94974 .29649 L
.95007 .29866 L
.95038 .30084 L
.95068 .30302 L
.95101 .30542 L
.95132 .3078 L
.95165 .31039 L
.95196 .31295 L
.95227 .31545 L
.9526 .31816 L
.95291 .32079 L
.95324 .3236 L
.95356 .32633 L
.95387 .32894 L
.9542 .33171 L
.95451 .33435 L
.95482 .33686 L
.95514 .33948 L
.95545 .34194 L
.95578 .34448 L
.9561 .34685 L
.95641 .34904 L
.95674 .35125 L
.95705 .35326 L
.95735 .35508 L
.95767 .35687 L
.95798 .35844 L
.95831 .35994 L
.95863 .3612 L
.95893 .36223 L
.95926 .36313 L
.95957 .36378 L
.95974 .36404 L
Mistroke
.95982 .36414 L
.9599 .36423 L
.95998 .3643 L
.96006 .36436 L
.9601 .36438 L
.96014 .3644 L
.96017 .36441 L
.96021 .36443 L
.96023 .36443 L
.96025 .36443 L
.96026 .36444 L
.96027 .36444 L
.96028 .36444 L
.96029 .36444 L
.9603 .36444 L
.9603 .36444 L
.96031 .36444 L
.96032 .36444 L
.96032 .36444 L
.96033 .36444 L
.96034 .36444 L
.96034 .36444 L
.96035 .36444 L
.96036 .36444 L
.96037 .36444 L
.96038 .36443 L
.9604 .36443 L
.96042 .36443 L
.96046 .36441 L
.9605 .3644 L
.96054 .36438 L
.96062 .36432 L
.9607 .36426 L
.96087 .36406 L
.96102 .36381 L
.96119 .36348 L
.96151 .36259 L
.96183 .36146 L
.96213 .36009 L
.96246 .35835 L
.96277 .35636 L
.9631 .35393 L
.96342 .35126 L
.96372 .34839 L
.96405 .345 L
.96436 .34141 L
.96467 .33765 L
.96499 .33332 L
.9653 .32882 L
.96563 .32368 L
Mistroke
.96594 .31839 L
.96625 .31298 L
.96657 .30689 L
.96688 .30069 L
.96722 .29374 L
.96754 .28671 L
.96784 .27964 L
.96817 .27178 L
.96848 .26389 L
.96879 .25603 L
.96911 .24734 L
.96942 .2387 L
.96975 .22921 L
.97007 .21978 L
.97037 .21045 L
.9707 .20026 L
.97101 .19021 L
.97135 .17927 L
.97167 .16849 L
.97198 .15791 L
.9723 .14646 L
.97262 .13524 L
.97292 .12428 L
.97325 .11246 L
.97356 .10094 L
.97389 .08855 L
.97421 .0765 L
.97452 .06481 L
.97484 .05229 L
.97516 .04016 L
.97546 .02845 L
.97578 .01595 L
.97609 .00389 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ZGoo1@00^Woo002[Ool00`00Oomoo`2jOol00:1oo`H000Eoo`03001oogoo0;Yo
o`00Zgoo00<007ooOol01Goo0`00UGoo00<007ooOol06Woo002[Ool00`00Oomoo`05Ool00`00Oomo
o`2EOol00`00Oomoo`0JOol00:]oo`03001oogoo00Eoo`03001oogoo09Eoo`03001oogoo01Yoo`00
Zgoo00<007ooOol01Goo00<007ooOol0UGoo00<007ooOol06Woo002YOol30007Ool00`00Oomoo`2D
Ool00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007oo
Ool06goo002cOol00`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03001oogoo
01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=o
o`03001oogoo09Aoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol0
0`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03001oogoo01]oo`00/goo0P00
UGoo00<007ooOol06goo002cOol00`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Ao
o`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomo
o`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002AOol30006
Ool20006Ool00`00Oomoo`04Ool40006Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0
0005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool2002EOol00`00Oomoo`0KOol008Qoo`H0
009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`03Ool3002DOol00`00Oomoo`0K
Ool0091oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00Oomoo`03Ool2002EOol00`00Oomo
o`0KOol0091oo`05001oogooOol0000>Ool00`00Oomoo`03Ool40006Ool2002EOol00`00Oomoo`0K
Ool0091oo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`07Ool2002EOol00`00Oomo
o`0KOol0091oo`05001oogooOol0000;Ool01@00Oomoogoo000017oo00<007ooOol01goo0P00UGoo
00<007ooOol06goo002AOol3000<Ool50004Ool40006Ool2002EOol00`00Oomoo`0KOol00;=oo`80
09Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0K
Ool00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol0
0`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002c
Ool2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007oo
Ool06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00
U7oo00<007ooOol077oo002cOol2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01ao
o`00VGoo0`001Woo0P001Goo10001Woo0P00U7oo00<007ooOol077oo002HOol01@00Oomoogoo0000
1Goo0P002Goo00<007ooOol00goo0P00U7oo00<007ooOol077oo002@Ool60002Ool01@00Oomoogoo
000047oo00<007ooOol00goo0P00U7oo00<007ooOol077oo002HOol01@00Oomoogoo000047oo00<0
07ooOol00goo0`00Tgoo00<007ooOol077oo002HOol01@00Oomoogoo000037oo10001Woo0P00U7oo
00<007ooOol077oo002HOol01@00Oomoogoo000037oo00<007ooOol01goo0P00U7oo00<007ooOol0
77oo002HOol01@00Oomoogoo000037oo00<007ooOol01goo0P00U7oo00<007ooOol077oo002IOol3
000=Ool40006Ool2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00
U7oo00<007ooOol077oo002cOol00`00Ool0002COol00`00Oomoo`0LOol00;=oo`03001oo`0009=o
o`03001oogoo01aoo`00/goo00<007oo0000Tgoo00<007ooOol077oo002cOol3002COol00`00Oomo
o`0LOol00;=oo`03001oo`0009=oo`03001oogoo01aoo`00/goo00<007oo0000Tgoo00<007ooOol0
77oo002cOol00`00Ool0002COol00`00Oomoo`0LOol00;=oo`03001oo`0009=oo`03001oogoo01ao
o`00/goo0`00Tgoo00<007ooOol077oo002cOol00`00Ool0002COol00`00Oomoo`0LOol00;=oo`03
001oo`0009=oo`03001oogoo01aoo`00/goo00<007oo0000Tgoo00<007ooOol077oo002cOol00`00
Ool0002COol00`00Oomoo`0LOol00;=oo`<009=oo`03001oogoo01aoo`00/goo00<007oo0000Tgoo
00<007ooOol077oo002AOol30006Ool20004Ool50004Ool40006Ool00`00Ool0002COol00`00Oomo
o`0LOol0091oo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo00<0
07oo0000Tgoo00<007ooOol077oo0028Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00goo00<007oo0000Tgoo00<007ooOol077oo002@Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00goo0`00Tgoo00<007ooOol077oo002@Ool01@00Oomoogoo00003goo
00<007ooOol00Woo10001Woo00<007oo0000TWoo00<007ooOol07Goo002@Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01goo00<007oo0000TWoo00<007ooOol07Goo002@Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oo`00099oo`03001oogoo
01eoo`00TGoo0`003Goo0`001Goo10001Woo0`00TWoo00<007ooOol07Goo002cOol00`00Ool0002B
Ool00`00Oomoo`0MOol0021oo`8008aoo`03001oogoo009oo`03001oo`00099oo`03001oogoo01eo
o`0087oo0P00Rgoo0P0017oo00<007oo0000TWoo00<007ooOol07Goo000POol2002;Ool30003Ool0
0`00Ool0002BOol00`00Oomoo`0MOol0021oo`8008]oo`03001oo`0000=oo`<0099oo`03001oogoo
01eoo`0087oo0`00RWoo00<007oo00000goo00<007oo0000TWoo00<007ooOol07Goo000OOol01000
Oomoo`004Goo0`001Woo0P001Woo0`00:7oo0`001Woo0P0017oo1@00:Goo00<007oo00000goo00<0
07oo0000<7oo0`001Woo0P0017oo1@00:7oo0`001Woo0P001Woo0`004Woo00<007ooOol07Goo000O
Ool01000Oomoo`0047oo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo02Ioo`05001oogooOol0
0005Ool20005Ool01000Oomoo`00:Goo00<007oo00000goo00@007ooOol002ioo`05001oogooOol0
0005Ool20005Ool01000Oomoo`009goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo015oo`03
001oogoo01eoo`007goo00@007ooOol000Qoo`H0009oo`05001oogooOol0000;Ool5000OOol60002
Ool01@00Oomoogoo00003Goo00<007ooOol0:7oo0P0000=oo`00Ool00Woo00@007ooOol002ioo`05
001oogooOol0000=Ool00`00Oomoo`0WOol01@00Oomoogoo00002goo1@004Woo00<007ooOol07Goo
000OOol01000Oomoo`0047oo00D007ooOomoo`0000]oo`04001oogoo000XOol01@00Oomoogoo0000
3Woo00<007ooOol09goo00@007ooOol000=oo`800003Ool007oo00Eoo`03001oogoo02Eoo`05001o
ogooOol0000>Ool00`00Oomoo`0VOol01@00Oomoogoo00002goo00@007ooOol000aoo`03001oogoo
00Aoo`03001oogoo01eoo`007goo00@007ooOol0011oo`05001oogooOol0000<Ool00`00Ool0000X
Ool01@00Oomoogoo00003goo00<007ooOol09Woo00@007ooOol000=oo`04001oogoo0005Ool3000V
Ool01@00Oomoogoo00003goo00<007ooOol09Goo00D007ooOomoo`0000aoo`03001oo`0000]oo`80
00Ioo`03001oogoo01eoo`007goo00@007ooOol0011oo`05001oogooOol0000<Ool00`00Ool0000X
Ool01@00Oomoogoo00003goo00<007ooOol09Woo00@007ooOol000=oo`04001oogoo0005Ool00`00
Ool0000VOol01@00Oomoogoo00003goo00<007ooOol09Goo00D007ooOomoo`0000aoo`03001oo`00
00Yoo`<000Ioo`03001oogoo01eoo`007goo00@007ooOol000Qoo`03001oogoo00Eoo`05001oogoo
Ool0000=Ool2000XOol01@00Oomoogoo00002goo00D007ooOomoo`00021oo`03001oogoo00Eoo`04
001oogoo0003Ool01000Oomoo`001Goo00<007oo00009Woo00D007ooOomoo`0000]oo`05001oogoo
Ool0000WOol01@00Oomoogoo00003Goo0P002Woo00@007ooOol000Eoo`03001oogoo01eoo`007goo
00D007ooOomoo`0000Ioo`8000Qoo`<000moo`03001oogoo02Moo`<000eoo`<0021oo`<000Ioo`04
001oogoo0003Ool01000Oomoo`001Goo00@007oo000002Ioo`<000eoo`<002Uoo`<000moo`03001o
ogoo00Qoo`04001oogoo0005Ool00`00Oomoo`0MOol001moo`05001oogooOol00005Ool4001fOol0
0`00Ool00006Ool01@00Oomoogoo00000Woo0P0000=oo`00Ool017oo00@007ooOol000Moo`8006eo
o`8000Moo`04001oogoo0005Ool00`00Oomoo`0MOol001moo`05001oogooOol00005Ool01000Oomo
o`001goo0P00Hgoo0P001goo00@007ooOol000Ioo`05001oogooOol00002Ool01000Oomoo`0017oo
0P000Woo00<007ooOol017oo00<007oo000027oo0P00FGoo0P001goo10001Woo00@007ooOol000Eo
o`03001oogoo01eoo`007goo00D007ooOomoo`0000Eoo`04001oogoo0006Ool40007Ool30008Ool0
0`00Oomoo`0jOol00`00Oomoo`06Ool20007Ool200000goo001oo`05Ool00`00Oomoo`020005Ool0
1@00Oomoogoo00000Woo00@007ooOol000Aoo`05001oogooOol00006Ool01000Oomoo`001Woo0`00
27oo0P00AGoo0P001goo0`001goo00@007ooOol000Eoo`05001oogooOol00005Ool00`00Oomoo`0M
Ool001moo`05001oogooOol00005Ool00`00Oomoo`020005Ool01000Oomoo`001Woo0P0000=oo`00
Ool01Goo10001goo0`001goo0`001goo0`001goo0`001goo10001Woo10001Woo0P0000=oo`00Ool0
1Goo00@007ooOol000Ioo`05001oogooOol00004Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<0
07ooOol00Woo00D007ooOomoo`0000Eoo`80009oo`03001oogoo00Aoo`04001oogoo0006Ool40006
Ool40007Ool30007Ool30007Ool30007Ool30007Ool30007Ool40006Ool01000Ool000001Goo0P00
0Woo00<007ooOol00goo00D007ooOomoo`0000Eoo`03001oogoo01eoo`007goo00D007ooOomoo`00
00Aoo`8000=oo`03001oogoo00=oo`05001oogooOol00005Ool01@00Oomoogoo00001Goo00<007oo
Ool00P001Goo0P0000=oo`0000001Goo0P0000=oo`0000001Goo0P0000=oo`0000001Goo0P0000=o
o`0000001Goo0P000Woo00<007ooOol00goo0P000Woo0P0017oo0P000Woo0P0017oo0P000goo00<0
07ooOol00Woo0P000goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20004Ool20002Ool20004Ool20002
Ool20005Ool00`00Oomoo`020005Ool00`00Oomoo`020005Ool200000goo00000005Ool200000goo
00000005Ool200000goo00000005Ool200000goo00000005Ool20002Ool00`00Oomoo`03Ool01@00
Oomoogoo00001Goo00@007ooOomoo`8000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo
01eoo`0057ooo`00@0005Goo000KOol01000Oomoo`0017oo00<007ooOol00Woo00D007ooOol007oo
008000=oo`03001oogoo009oo`800004Ool007oo0005Ool01@00Oomoogoo00000Woo00@007ooOol0
009oo`8000Eoo`<00003Ool007oo00Aoo`80009oo`04001oogoo0002Ool20002Ool00`00Oomoo`03
Ool300000goo00000004Ool20002Ool20002Ool01000Ool000000Woo0P0017oo0P0000Aoo`00Ool0
00Aoo`8000=oo`06001oogoo001oo`0017oo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo
009oo`03001oogoo009oo`03001oo`00009oo`03001oogoo009oo`04001oogooOol2000017oo001o
ogoo0P000Woo0P0017oo0`0000=oo`00000017oo0P000Woo0P000Woo00@007oo0000009oo`8000Eo
o`03001oo`00008000Eoo`03001oogoo0080009oo`04001oogoo0003Ool00`00Oomoo`03Ool01@00
Ool007oo00001Goo00D007ooOomoo`00009oo`04001oogoo0003Ool20004Ool00`00Ool00002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol06Woo000NOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`020005Ool00`00Ool000020005Ool200000goo001o
o`05Ool40007Ool30007Ool30007Ool40006Ool40006Ool40006Ool40006Ool00`00Oomoo`020005
Ool01@00Oomoogoo000017oo0P000goo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo009o
o`03001oogoo009oo`05001oogooOol00005Ool20002Ool00`00Oomoo`04Ool01000Oomoo`001Woo
10001Woo10000goo00<007ooOol010001goo0`001goo0`001goo10001Woo00@007oo000000Eoo`80
0003Ool00000009oo`03001oogoo0080009oo`03001oogoo00=oo`05001oogooOol00005Ool01@00
Oomoogoo000087oo000NOol00`00Oomoo`03Ool01@00Oomoogoo00001Goo00@007ooOol000Ioo`@0
00Moo`<000Qoo`03001oogoo02moo`8000Qoo`8000Moo`@000Ioo`04001oogoo0006Ool01@00Oomo
ogoo000017oo00@007ooOol0009oo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00006
Ool01000Ool000001Woo10001goo0P00>Woo0`001goo0`001goo00@007oo000000Ioo`04001oogoo
0005Ool01@00Oomoogoo000087oo000NOol00`00Oomoo`03Ool00`00Oomoo`020005Ool200000goo
001oo`06Ool2001IOol20007Ool200000goo001oo`05Ool01@00Oomoogoo000017oo00@007ooOol0
009oo`05001oogooOol00006Ool01000Oomoo`001Woo0`00HWoo0`001goo00@007ooOol000Eoo`05
001oogooOol0000POol001ioo`03001oogoo00=oo`04001oogoo0007Ool2001]Ool30006Ool01000
Oomoo`001Goo00<007ooOol00P0000=oo`00Ool00Woo00<007ooOol017oo00@007oo000007Eoo`04
001oo`000005Ool01@00Oomoogoo000087oo000NOol00`00Oomoo`03Ool01000Oomoo`00Ogoo00@0
07ooOol000Eoo`04001oogoo0002Ool01@00Oomoogoo00001Woo0`00Mgoo0P001Woo0P000Woo00<0
07ooOol07Woo000NOol00`00Oomoo`03Ool01000Oomoo`00P7oo00<007oo00001Goo00@007ooOol0
009oo`05001oogooOol00007Ool2001gOol20007Ool01000Oomoo`0087oo000NOol00`00Oomoo`03
Ool40020Ool00`00Ool00005Ool01000Oomoo`000goo00@007ooOol008Uoo`04001oogoo000POol0
01ioo`03001oogoo00Aoo`80085oo`<000Eoo`04001oogoo0003Ool01000Oomoo`00RGoo00@007oo
Ool0021oo`007Woo00<007ooOol017oo0P00PWoo00<007ooOol017oo00<007ooOol00P000Woo00@0
07ooOol008Uoo`04001oogoo000POol001ioo`03001oogoo08moo`04001oogoo0003Ool01000Oomo
o`00RGoo00@007ooOol0021oo`007Woo00<007ooOol0Sgoo00@007ooOol000=oo`03001oo`0008Yo
o`04001oogoo000POol001ioo`03001oogoo08moo`04001oogoo0003Ool00`00Ool0002:Ool01000
Oomoo`0087oo000NOol00`00Oomoo`2?Ool01000Oomoo`000goo00<007oo0000RWoo100087oo000N
Ool00`00Oomoo`2@Ool01000Ool000000Woo00<007oo0000Rgoo0P008Goo000NOol00`00Oomoo`2@
Ool00`00Ool00003Ool00`00Ool0002;Ool2000QOol001ioo`03001oogoo091oo`03001oo`0000Ao
o`8008]oo`80025oo`007Woo00<007ooOol0T7oo00<007oo000017oo00<007ooOol0RWoo0P008Goo
000NOol00`00Oomoo`2@Ool00`00Ool0002dOol001ioo`03001oogoo091oo`04001oo`00002cOol0
01ioo`03001oogoo091oo`03001oo`000;Aoo`007Woo00<007ooOol0L7oo0`001Woo0P0017oo1@00
17oo100017oo00<007oo0000]7oo000NOol00`00Oomoo`1_Ool01@00Oomoogoo00001Goo0P001Goo
00@007ooOol000Qoo`07001oogooOol007oo0000]7oo000NOol00`00Oomoo`1_Ool01@00Oomoogoo
00003Goo00<007ooOol027oo00L007ooOomoo`00Ool0002dOol001eoo`03001oogoo071oo`05001o
ogooOol0000>Ool00`00Oomoo`07Ool01P00Oomoogoo001oo`<00;9oo`007Goo00<007ooOol0L7oo
00D007ooOomoo`0000moo`03001oogoo009oo`@000Aoo`03001oo`000;Aoo`007Goo00<007ooOol0
L7oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Eoo`03001oo`000;Aoo`007Goo
00<007ooOol0L7oo00D007ooOomoo`0000]oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00
Ool0002dOol001eoo`03001oogoo075oo`<000eoo`<000Eoo`@000Aoo`03001oo`000;Aoo`007Goo
00<007ooOol0TGoo00@007oo00000;=oo`007Goo00<007ooOol0TGoo00<007oo0000]7oo000MOol0
0`00Oomoo`2AOol00`00Ool0002dOol001eoo`03001oogoo095oo`03001oo`000;Aoo`007Goo00<0
07ooOol0TGoo00<007oo0000]7oo000MOol00`00Oomoo`2AOol01000Ool00000/goo000MOol00`00
Oomoo`2AOol00`00Ool0002dOol001eoo`03001oogoo095oo`03001oo`000;Aoo`007Goo00<007oo
Ool0TGoo00<007oo0000]7oo000MOol00`00Oomoo`2AOol01000Ool00000/goo000MOol00`00Oomo
o`2AOol00`00Ool0002dOol001eoo`03001oogoo095oo`03001oo`000;Aoo`007Goo00<007ooOol0
TWoo0P00]7oo000MOol00`00Oomoo`2BOol2002dOol001eoo`03001oogoo099oo`<00;=oo`007Goo
00<007ooOol0TWoo0P00]7oo000MOol00`00Oomoo`2BOol2002dOol001eoo`03001oogoo07Uoo`<0
00Ioo`8000Eoo`@000Eoo`800;Aoo`007Goo00<007ooOol0N7oo00D007ooOomoo`0000Eoo`8000Uo
o`03001oogoo009oo`800;Aoo`007Goo00<007ooOol0N7oo00D007ooOomoo`00011oo`03001oogoo
009oo`@00;9oo`007Goo00<007ooOol0N7oo00D007ooOomoo`00011oo`03001oogoo009oo`800;Ao
o`007Goo00<007ooOol0N7oo00D007ooOomoo`0000aoo`@000Eoo`800;Aoo`007Goo00<007ooOol0
N7oo00D007ooOomoo`0000aoo`03001oogoo00Ioo`800;Aoo`007Goo00<007ooOol0N7oo00D007oo
Oomoo`0000aoo`03001oogoo00Ioo`800;Aoo`007Goo00<007ooOol0NGoo0`003Goo10001Goo0`00
/goo000MOol00`00Oomoo`2BOol2002dOol001eoo`03001oogoo099oo`800;Aoo`007Goo00<007oo
Ool0TWoo0P00]7oo000MOol00`00Oomoo`2BOol2002dOol001aoo`03001oogoo09=oo`<00;=oo`00
77oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002dOol001aoo`03001oogoo09=o
o`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol3002cOol001aoo`03
001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002d
Ool001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0`00/goo000LOol00`00Oomo
o`2COol2002dOol001aoo`03001oogoo079oo`<000Ioo`8000Ioo`03001oogoo00Aoo`@000Eoo`80
0;Aoo`0077oo00<007ooOol0LGoo00D007ooOomoo`0000Eoo`8000Ioo`03001oogoo00Qoo`03001o
ogoo009oo`800;Aoo`0077oo00<007ooOol0LGoo00D007ooOomoo`0000ioo`03001oogoo00Moo`03
001oogoo009oo`800;Aoo`0077oo00<007ooOol0LGoo00D007ooOomoo`0000ioo`03001oogoo00Mo
o`03001oogoo009oo`@00;9oo`0077oo00<007ooOol0LGoo00D007ooOomoo`0000ioo`03001oogoo
00=oo`@000Eoo`800;Aoo`0077oo00<007ooOol0LGoo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00Ioo`800;Aoo`0077oo00<007ooOol0LGoo00D007ooOomoo`0000]oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool2002dOol001aoo`03001oogoo079oo`<000aoo`D000Aoo`@000Eo
o`800;Aoo`0077oo00<007ooOol0U7oo0P00/goo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol0
01aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000L
Ool00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`800;=oo`0077oo00<007oo
Ool0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo
09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2D
Ool2002cOol001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo00<007oo
Ool0/Woo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`03001oogoo
0;9oo`006goo00<007ooOol0UGoo0P00/goo000KOol00`00Oomoo`2EOol00`00Oomoo`2bOol001]o
o`03001oogoo08]oo`D000Eoo`03001oogoo0;9oo`006goo00<007ooOol0SGoo00<007ooOol01Goo
00<007ooOol0/Woo000KOol00`00Oomoo`2=Ool00`00Oomoo`05Ool00`00Oomoo`2bOol001]oo`03
001oogoo08eoo`03001oogoo00Eoo`<00;9oo`00Zgoo00<007ooOol0^Woo002[Ool00`00Oomoo`2j
Ool00:]oo`03001oogoo0;Yoo`00ZGoo0`00_7oo003oOomYOol00:Yoo`03001oogoo0;]oo`00ZWoo
0P00_7oo0022Ool60002Ool60002Ool60004Ool40002Ool60003Ool00`00Oomoo`09Ool30002Ool3
000HOol30005Ool30026Ool008=oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo0P002goo00<007ooOol00Woo00<007ooOol01goo
1P002Goo00D007ooOomoo`0000=oo`05001oogooOol00025Ool008=oo`05001oogooOol00004Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01@00Oomoogoo00004goo00<007ooOol0
0Woo00<007ooOol06Woo00D007ooOomoo`0000=oo`03001oogoo08=oo`00Pgoo00<007oo00001Woo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001=oo`06001oo`00
001oo`002Goo1P003Goo00D007ooOomoo`0000=oo`03001oogoo08=oo`00Pgoo0`001Woo0P001Woo
0P001Goo00<007ooOol00Woo00@007ooOomoo`80019oo`06001oo`00001oo`006Woo0P0017oo00D0
07ooOomoo`0008Eoo`00Pgoo00D007oo001oo`0000=oo`800004Ool000000002Ool2000017oo0000
00000goo10000goo0P0000Aoo`00000000moo`80009oo`8001aoo`05001oogooOol00003Ool00`00
Oomoo`23Ool008=oo`05001oogooOol0000`Ool20002Ool2000HOol01@00Oomoogoo00000goo00D0
07ooOomoo`0008Eoo`00PWoo1P00;goo0P0017oo0P0067oo0`001Goo0`00QWoo003oOomYOol00?mo
ofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.309017 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.02404 .606 L
.02429 .59289 L
.02453 .58061 L
.02476 .56885 L
.025 .5564 L
.02524 .54449 L
.02549 .53194 L
.02573 .51996 L
.02596 .50856 L
.0262 .49657 L
.02644 .48519 L
.02666 .4744 L
.02691 .4631 L
.02714 .45242 L
.02739 .44128 L
.02762 .43078 L
.02785 .4209 L
.0281 .41063 L
.02833 .40101 L
.02858 .39106 L
.02882 .38177 L
.02905 .3731 L
.0293 .36419 L
.02954 .35591 L
.02977 .34824 L
.03001 .34039 L
.03024 .33315 L
.03049 .32579 L
.03073 .31904 L
.03096 .31287 L
.0312 .30664 L
.03144 .30098 L
.03167 .29585 L
.03191 .29073 L
.03214 .28613 L
.03239 .28158 L
.03262 .27755 L
.03285 .27399 L
.0331 .27053 L
.03333 .26752 L
.03358 .26466 L
.03382 .26224 L
.03405 .26021 L
.0343 .25836 L
.03453 .25689 L
.03476 .25574 L
.03489 .25521 L
.035 .2548 L
.03512 .25443 L
Mistroke
.03523 .25416 L
.03535 .25394 L
.03541 .25385 L
.03547 .25377 L
.03553 .25372 L
.03556 .25369 L
.0356 .25368 L
.03562 .25366 L
.03564 .25366 L
.03565 .25365 L
.03567 .25365 L
.03568 .25365 L
.03569 .25365 L
.0357 .25365 L
.0357 .25365 L
.03571 .25364 L
.03572 .25364 L
.03572 .25364 L
.03573 .25365 L
.03574 .25365 L
.03574 .25365 L
.03575 .25365 L
.03577 .25365 L
.03578 .25365 L
.03579 .25366 L
.03582 .25367 L
.03585 .25369 L
.03588 .2537 L
.03594 .25376 L
.036 .25382 L
.03606 .2539 L
.03618 .25411 L
.03641 .25467 L
.03666 .2555 L
.0369 .25651 L
.03713 .25766 L
.03738 .25908 L
.03761 .26061 L
.03784 .26223 L
.03808 .26411 L
.03831 .26604 L
.03856 .26823 L
.0388 .27044 L
.03902 .27267 L
.03927 .27513 L
.0395 .27757 L
.03975 .28023 L
.03999 .28285 L
.04022 .2854 L
.04047 .28815 L
Mistroke
.0407 .29082 L
.04093 .29338 L
.04117 .29611 L
.0414 .29872 L
.04165 .30148 L
.04189 .30409 L
.04212 .30657 L
.04236 .30915 L
.0426 .31157 L
.04285 .31408 L
.04309 .31641 L
.04332 .31857 L
.04357 .32078 L
.0438 .32281 L
.04403 .32466 L
.04427 .32653 L
.04451 .32821 L
.04476 .32988 L
.045 .33136 L
.04523 .33268 L
.04547 .33394 L
.04571 .33503 L
.04593 .33596 L
.04617 .33682 L
.04641 .33752 L
.04665 .33813 L
.04689 .33859 L
.04712 .3389 L
.04724 .33901 L
.0473 .33907 L
.04736 .3391 L
.04743 .33913 L
.04746 .33915 L
.04749 .33916 L
.04752 .33917 L
.04755 .33917 L
.04757 .33917 L
.04758 .33917 L
.04759 .33917 L
.04759 .33917 L
.0476 .33917 L
.0476 .33917 L
.04761 .33918 L
.04761 .33918 L
.04762 .33918 L
.04763 .33918 L
.04763 .33918 L
.04764 .33917 L
.04764 .33917 L
.04765 .33917 L
Mistroke
.04766 .33917 L
.04767 .33917 L
.04769 .33917 L
.0477 .33917 L
.04773 .33916 L
.04776 .33915 L
.04779 .33914 L
.04785 .33912 L
.04792 .33908 L
.04798 .33904 L
.04809 .33894 L
.04832 .33866 L
.04856 .33824 L
.04879 .33772 L
.04904 .33706 L
.04928 .33632 L
.04952 .33551 L
.04976 .33456 L
.05 .33355 L
.05023 .3325 L
.05047 .33131 L
.0507 .33009 L
.05095 .32873 L
.05119 .32736 L
.05142 .326 L
.05166 .32449 L
.0519 .32301 L
.05213 .32156 L
.05237 .31998 L
.0526 .31844 L
.05285 .3168 L
.05308 .3152 L
.05331 .31367 L
.05356 .31204 L
.05379 .31049 L
.05404 .30886 L
.05428 .30732 L
.05451 .30586 L
.05476 .30434 L
.05499 .30292 L
.05522 .3016 L
.05546 .30024 L
.05569 .29899 L
.05594 .29771 L
.05618 .29655 L
.05641 .2955 L
.05665 .29445 L
.05689 .29351 L
.05714 .29259 L
.05738 .29179 L
Mistroke
.05761 .29109 L
.05786 .29044 L
.05809 .28989 L
.05832 .28944 L
.05857 .28905 L
.0588 .28876 L
.05892 .28864 L
.05905 .28854 L
.05917 .28846 L
.05923 .28843 L
.05929 .28841 L
.05934 .28839 L
.0594 .28838 L
.05943 .28838 L
.05945 .28837 L
.05946 .28837 L
.05948 .28837 L
.05949 .28837 L
.05949 .28837 L
.0595 .28837 L
.05951 .28837 L
.05952 .28837 L
.05952 .28837 L
.05953 .28837 L
.05954 .28837 L
.05954 .28837 L
.05955 .28837 L
.05956 .28837 L
.05957 .28837 L
.05958 .28837 L
.05961 .28838 L
.05964 .28838 L
.05967 .28838 L
.0597 .28839 L
.05976 .28841 L
.05982 .28843 L
.05988 .28846 L
.06001 .28854 L
.06012 .28863 L
.06025 .28875 L
.0605 .28905 L
.06074 .28942 L
.06097 .28984 L
.06121 .29037 L
.06145 .29094 L
.06168 .29156 L
.06192 .29227 L
.06215 .29302 L
.0624 .29386 L
.06264 .29473 L
Mistroke
.06287 .29562 L
.06311 .2966 L
.06335 .29758 L
.0636 .29866 L
.06384 .29973 L
.06407 .30079 L
.06431 .30193 L
.06455 .30305 L
.06478 .30414 L
.06502 .3053 L
.06525 .30642 L
.0655 .30761 L
.06574 .30875 L
.06597 .30983 L
.06622 .31097 L
.06645 .31205 L
.06668 .31306 L
.06692 .31411 L
.06715 .31509 L
.0674 .3161 L
.06764 .31703 L
.06787 .31789 L
.06811 .31875 L
.06834 .31954 L
.06859 .32033 L
.06883 .32103 L
.06906 .32165 L
.06931 .32225 L
.06955 .32277 L
.06977 .32322 L
.07002 .32363 L
.07025 .32397 L
.0705 .32426 L
.07074 .32448 L
.07086 .32456 L
.07096 .32463 L
.07108 .32468 L
.07115 .3247 L
.07121 .32472 L
.07127 .32473 L
.0713 .32474 L
.07133 .32474 L
.07136 .32474 L
.07137 .32475 L
.07139 .32475 L
.0714 .32475 L
.07141 .32475 L
.07141 .32475 L
.07142 .32475 L
.07143 .32475 L
Mistroke
.07143 .32475 L
.07144 .32475 L
.07145 .32475 L
.07145 .32475 L
.07146 .32475 L
.07147 .32475 L
.07148 .32475 L
.07149 .32475 L
.0715 .32474 L
.07153 .32474 L
.07156 .32474 L
.07162 .32473 L
.07167 .32471 L
.07179 .32467 L
.0719 .32462 L
.07213 .32447 L
.07238 .32425 L
.07262 .32398 L
.07285 .32366 L
.0731 .32326 L
.07333 .32283 L
.07356 .32237 L
.0738 .32183 L
.07403 .32126 L
.07428 .32061 L
.07452 .31995 L
.07474 .31927 L
.07499 .31852 L
.07522 .31777 L
.07547 .31694 L
.07571 .31611 L
.07594 .31529 L
.07619 .31441 L
.07642 .31354 L
.07665 .3127 L
.07689 .31179 L
.07712 .31092 L
.07737 .30999 L
.07761 .30909 L
.07784 .30824 L
.07808 .30735 L
.07832 .3065 L
.07857 .30562 L
.07881 .30479 L
.07904 .30401 L
.07929 .30321 L
.07952 .30248 L
.07975 .3018 L
.08 .30111 L
.08023 .30048 L
Mistroke
.08048 .29985 L
.08072 .29929 L
.08095 .29879 L
.08119 .29831 L
.08143 .29789 L
.08165 .29753 L
.0819 .29719 L
.08213 .29692 L
.08238 .29668 L
.08261 .2965 L
.08284 .29637 L
.08296 .29633 L
.08303 .29631 L
.08309 .29629 L
.08315 .29628 L
.08318 .29627 L
.08321 .29627 L
.08324 .29627 L
.08327 .29626 L
.08329 .29626 L
.0833 .29626 L
.08331 .29626 L
.08331 .29626 L
.08332 .29626 L
.08333 .29626 L
.08333 .29626 L
.08333 .29626 L
.08334 .29626 L
.08335 .29626 L
.08336 .29626 L
.08336 .29626 L
.08337 .29626 L
.08338 .29626 L
.0834 .29626 L
.08342 .29627 L
.08345 .29627 L
.08348 .29627 L
.08352 .29628 L
.08358 .29629 L
.08369 .29632 L
.0838 .29636 L
.08404 .29648 L
.08428 .29666 L
.08452 .29688 L
.08475 .29714 L
.08499 .29746 L
.08523 .29781 L
.08548 .29822 L
.08572 .29867 L
.08595 .29913 L
Mistroke
.0862 .29966 L
.08643 .3002 L
.08666 .30075 L
.0869 .30137 L
.08714 .30199 L
.08739 .30267 L
.08762 .30335 L
.08785 .30402 L
.0881 .30474 L
.08833 .30546 L
.08856 .30615 L
.0888 .30689 L
.08903 .30761 L
.08928 .30838 L
.08952 .30912 L
.08975 .30982 L
.08999 .31056 L
.09023 .31126 L
.09047 .31199 L
.09071 .31268 L
.09095 .31332 L
.09119 .31398 L
.09143 .31459 L
.09165 .31516 L
.0919 .31573 L
.09213 .31625 L
.09238 .31678 L
.09262 .31724 L
.09285 .31766 L
.09309 .31807 L
.09333 .31842 L
.09357 .31875 L
.09382 .31903 L
.09405 .31926 L
.09429 .31946 L
.09453 .3196 L
.09476 .31971 L
.09488 .31974 L
.09494 .31976 L
.095 .31977 L
.09506 .31978 L
.0951 .31979 L
.09513 .31979 L
.09514 .31979 L
.09516 .31979 L
.09517 .31979 L
.09519 .31979 L
.0952 .31979 L
.09521 .31979 L
.09522 .31979 L
Mistroke
.09522 .31979 L
.09523 .31979 L
.09523 .31979 L
.09524 .31979 L
.09525 .31979 L
.09525 .31979 L
.09526 .31979 L
.09527 .31979 L
.09527 .31979 L
.09528 .31979 L
.09529 .31979 L
.09531 .31979 L
.09534 .31979 L
.09536 .31979 L
.09542 .31978 L
.09549 .31977 L
.0956 .31974 L
.09573 .3197 L
.09585 .31965 L
.09598 .31959 L
.0962 .31945 L
.09645 .31925 L
.09668 .31903 L
.09693 .31875 L
.09717 .31844 L
.0974 .31811 L
.09765 .31772 L
.09788 .31732 L
.09811 .3169 L
.09835 .31643 L
.09858 .31595 L
.09883 .31541 L
.09907 .31487 L
.0993 .31433 L
.09954 .31374 L
.09978 .31316 L
.10003 .31252 L
.10027 .3119 L
.1005 .31129 L
.10075 .31064 L
.10098 .31001 L
.10121 .30941 L
.10145 .30876 L
.10169 .30815 L
.10194 .3075 L
.10217 .30689 L
.1024 .30631 L
.10265 .30571 L
.10289 .30515 L
.10311 .30463 L
Mistroke
.10335 .30409 L
.10359 .30359 L
.10383 .30309 L
.10407 .30263 L
.1043 .30222 L
.10454 .30181 L
.10478 .30145 L
.10503 .30109 L
.10527 .30079 L
.1055 .30052 L
.10574 .30028 L
.10598 .30008 L
.10621 .29993 L
.10645 .2998 L
.10656 .29975 L
.10668 .29971 L
.10675 .29969 L
.10681 .29968 L
.10687 .29967 L
.10693 .29966 L
.10696 .29965 L
.10699 .29965 L
.10702 .29965 L
.10705 .29964 L
.10707 .29964 L
.10708 .29964 L
.1071 .29964 L
.10711 .29964 L
.10712 .29964 L
.10712 .29964 L
.10713 .29964 L
.10714 .29964 L
.10714 .29964 L
.10715 .29964 L
.10716 .29964 L
.10717 .29964 L
.10717 .29964 L
.10718 .29964 L
.1072 .29964 L
.10721 .29964 L
.10723 .29964 L
.10726 .29964 L
.10729 .29965 L
.10735 .29966 L
.10741 .29966 L
.10753 .29969 L
.10765 .29972 L
.10789 .29982 L
.10813 .29995 L
.10837 .30013 L
Mistroke
.10861 .30033 L
.10884 .30056 L
.10909 .30084 L
.10932 .30113 L
.10955 .30144 L
.10979 .30181 L
.11002 .30218 L
.11027 .3026 L
.11051 .30303 L
.11074 .30347 L
.11098 .30395 L
.11121 .30443 L
.11146 .30496 L
.1117 .30549 L
.11193 .306 L
.11218 .30656 L
.11241 .3071 L
.11264 .30763 L
.11288 .30819 L
.11312 .30874 L
.11336 .30932 L
.1136 .30987 L
.11383 .31039 L
.11408 .31094 L
.11431 .31147 L
.11456 .31201 L
.1148 .31251 L
.11503 .31298 L
.11528 .31346 L
.11552 .31391 L
.11574 .31432 L
.11599 .31473 L
.11622 .3151 L
.11647 .31547 L
.11671 .31579 L
.11694 .31608 L
.11718 .31636 L
.11742 .31659 L
.11765 .31679 L
.11789 .31697 L
.11812 .31711 L
.11824 .31717 L
.11837 .31722 L
.11849 .31727 L
.11861 .3173 L
.11872 .31733 L
.11879 .31734 L
.11885 .31735 L
.11891 .31735 L
.11894 .31736 L
Mistroke
.11895 .31736 L
.11897 .31736 L
.11898 .31736 L
.119 .31736 L
.11901 .31736 L
.11901 .31736 L
.11902 .31736 L
.11903 .31736 L
.11903 .31736 L
.11904 .31736 L
.11905 .31736 L
.11905 .31736 L
.11906 .31736 L
.11907 .31736 L
.11907 .31736 L
.11908 .31736 L
.1191 .31736 L
.11911 .31736 L
.11914 .31736 L
.11917 .31736 L
.1192 .31735 L
.11926 .31735 L
.11931 .31734 L
.11943 .31732 L
.11956 .31728 L
.1198 .31719 L
.12004 .31707 L
.12027 .31693 L
.12052 .31675 L
.12075 .31654 L
.121 .31629 L
.12124 .31602 L
.12147 .31573 L
.12172 .3154 L
.12195 .31506 L
.12218 .3147 L
.12243 .31431 L
.12266 .31391 L
.12291 .31347 L
.12315 .31303 L
.12338 .31259 L
.12362 .31211 L
.12386 .31164 L
.12408 .31118 L
.12432 .31068 L
.12456 .3102 L
.1248 .30968 L
.12504 .30918 L
.12527 .3087 L
.12551 .3082 L
Mistroke
.12575 .30771 L
.126 .30721 L
.12624 .30673 L
.12647 .30628 L
.12671 .30582 L
.12695 .30539 L
.12718 .30499 L
.12742 .30458 L
.12765 .3042 L
.1279 .30382 L
.12814 .30348 L
.12837 .30318 L
.12861 .30288 L
.12885 .30261 L
.1291 .30236 L
.12934 .30214 L
.12957 .30196 L
.12982 .3018 L
.13005 .30167 L
.13028 .30158 L
.1304 .30154 L
.13053 .30151 L
.13059 .3015 L
.13065 .30149 L
.13071 .30148 L
.13074 .30147 L
.13077 .30147 L
.13081 .30147 L
.13084 .30147 L
.13086 .30146 L
.13088 .30146 L
.13089 .30146 L
.13091 .30146 L
.13092 .30146 L
.13092 .30146 L
.13093 .30146 L
.13094 .30146 L
.13095 .30146 L
.13095 .30146 L
.13096 .30146 L
.13097 .30146 L
.13097 .30146 L
.13098 .30146 L
.13098 .30146 L
.131 .30146 L
.13101 .30146 L
.13102 .30146 L
.13105 .30146 L
.13108 .30147 L
.13113 .30147 L
Mistroke
.1312 .30148 L
.13125 .30149 L
.13137 .30151 L
.13149 .30154 L
.13174 .30162 L
.13197 .30173 L
.13222 .30188 L
.13246 .30205 L
.13269 .30224 L
.13293 .30246 L
.13317 .30271 L
.1334 .30297 L
.13364 .30326 L
.13387 .30357 L
.13412 .30392 L
.13436 .30427 L
.13459 .30463 L
.13483 .30503 L
.13507 .30542 L
.13532 .30586 L
.13556 .30629 L
.13579 .30671 L
.13603 .30717 L
.13627 .30762 L
.1365 .30805 L
.13674 .30851 L
.13698 .30896 L
.13722 .30943 L
.13746 .30989 L
.13769 .31032 L
.13794 .31077 L
.13817 .3112 L
.1384 .3116 L
.13864 .31201 L
.13888 .3124 L
.13912 .31279 L
.13936 .31316 L
.13959 .31349 L
.13983 .31383 L
.14007 .31414 L
.14032 .31444 L
.14056 .3147 L
.14079 .31494 L
.14103 .31516 L
.14127 .31535 L
.1415 .31551 L
.14174 .31566 L
.14197 .31577 L
.14209 .31582 L
.14222 .31586 L
Mistroke
.14235 .3159 L
.14246 .31592 L
.14258 .31594 L
.14264 .31595 L
.14267 .31595 L
.1427 .31595 L
.14273 .31596 L
.14276 .31596 L
.14278 .31596 L
.14279 .31596 L
.14281 .31596 L
.14282 .31596 L
.14282 .31596 L
.14283 .31596 L
.14284 .31596 L
.14285 .31596 L
.14285 .31596 L
.14286 .31596 L
.14287 .31596 L
.14287 .31596 L
.14288 .31596 L
.14289 .31596 L
.14289 .31596 L
.14291 .31596 L
.14292 .31596 L
.14294 .31596 L
.14296 .31596 L
.14299 .31595 L
.14306 .31595 L
.14311 .31594 L
.14317 .31594 L
.14329 .31591 L
.1434 .31589 L
.14364 .31581 L
.14387 .31571 L
.14411 .31558 L
.14435 .31543 L
.14458 .31526 L
.14482 .31506 L
.14505 .31484 L
.1453 .31458 L
.14553 .31431 L
.14576 .31404 L
.14601 .31372 L
.14624 .3134 L
.14649 .31305 L
.14673 .31269 L
.14696 .31233 L
.14721 .31194 L
.14744 .31155 L
Mistroke
.14767 .31116 L
.14791 .31075 L
.14814 .31034 L
.14839 .30991 L
.14863 .30949 L
.14886 .30908 L
.1491 .30865 L
.14934 .30824 L
.14959 .30781 L
.14983 .30739 L
.15006 .30701 L
.15031 .3066 L
.15054 .30622 L
.15077 .30587 L
.15102 .30551 L
.15125 .30518 L
.1515 .30484 L
.15174 .30453 L
.15197 .30426 L
.15221 .30398 L
.15245 .30374 L
.15268 .30352 L
.15292 .30332 L
.15315 .30314 L
.1534 .30298 L
.15363 .30284 L
.15386 .30274 L
.15399 .30269 L
.15411 .30266 L
.15423 .30262 L
.15434 .3026 L
.15446 .30258 L
.15452 .30257 L
.15458 .30257 L
.15464 .30256 L
.15467 .30256 L
.15469 .30256 L
.1547 .30256 L
.15471 .30256 L
.15473 .30256 L
.15473 .30256 L
.15474 .30256 L
.15475 .30256 L
.15475 .30256 L
.15476 .30256 L
.15476 .30256 L
.15477 .30256 L
.15478 .30256 L
.15478 .30256 L
.15479 .30256 L
Mistroke
.1548 .30256 L
.15481 .30256 L
.15482 .30256 L
.15484 .30256 L
.15487 .30256 L
.1549 .30256 L
.15493 .30257 L
.15499 .30257 L
.15504 .30258 L
.15515 .30259 L
.15528 .30262 L
.15552 .30269 L
.15576 .30278 L
.15601 .3029 L
.15625 .30305 L
.15648 .30321 L
.15673 .3034 L
.15696 .30361 L
.15719 .30383 L
.15743 .30409 L
.15767 .30435 L
.15792 .30465 L
.15815 .30495 L
.15838 .30526 L
.15863 .3056 L
.15886 .30594 L
.15909 .30628 L
.15933 .30665 L
.15957 .30702 L
.15981 .30741 L
.16005 .3078 L
.16028 .30818 L
.16052 .30858 L
.16076 .30896 L
.16101 .30938 L
.16125 .30977 L
.16148 .31014 L
.16172 .31054 L
.16196 .31091 L
.16219 .31126 L
.16243 .31162 L
.16266 .31196 L
.16291 .3123 L
.16315 .31262 L
.16338 .31292 L
.16362 .31321 L
.16386 .31348 L
.16411 .31374 L
.16435 .31398 L
.16458 .31418 L
Mistroke
.16483 .31438 L
.16506 .31455 L
.16529 .31469 L
.16553 .31482 L
.16577 .31492 L
.16589 .31496 L
.16602 .315 L
.16613 .31503 L
.16626 .31505 L
.16638 .31507 L
.16644 .31508 L
.1665 .31508 L
.16653 .31508 L
.16656 .31509 L
.16658 .31509 L
.16659 .31509 L
.16661 .31509 L
.16662 .31509 L
.16663 .31509 L
.16664 .31509 L
.16665 .31509 L
.16665 .31509 L
.16665 .31509 L
.16666 .31509 L
.16667 .31509 L
.16667 .31509 L
.16668 .31509 L
.16669 .31509 L
.16669 .31509 L
.16671 .31509 L
.16672 .31509 L
.16673 .31509 L
.16676 .31509 L
.16679 .31508 L
.16685 .31508 L
.16691 .31508 L
.16698 .31507 L
.16709 .31505 L
.16722 .31502 L
.16747 .31495 L
.16771 .31486 L
.16794 .31475 L
.16818 .31461 L
.16842 .31445 L
.16865 .31428 L
.16889 .31408 L
.16912 .31387 L
.16937 .31362 L
.16961 .31336 L
.16984 .3131 L
Mistroke
.17008 .31281 L
.17032 .31251 L
.17057 .31218 L
.17081 .31185 L
.17104 .31152 L
.17128 .31116 L
.17152 .31081 L
.17175 .31046 L
.17199 .31009 L
.17223 .30973 L
.17248 .30934 L
.17271 .30897 L
.17294 .30861 L
.17319 .30823 L
.17343 .30787 L
.17365 .30753 L
.17389 .30717 L
.17413 .30683 L
.17437 .30648 L
.17461 .30616 L
.17484 .30586 L
.17508 .30555 L
.17532 .30527 L
.17557 .30499 L
.17581 .30473 L
.17604 .30451 L
.17628 .30428 L
.17652 .30408 L
.17675 .30391 L
.17699 .30375 L
.17722 .30362 L
.17747 .3035 L
.17771 .3034 L
.17794 .30334 L
.17806 .30331 L
.17818 .30329 L
.17825 .30328 L
.17831 .30327 L
.17838 .30326 L
.17843 .30326 L
.17846 .30326 L
.17848 .30326 L
.17849 .30326 L
.17851 .30326 L
.17852 .30326 L
.17853 .30326 L
.17854 .30326 L
.17854 .30326 L
.17855 .30326 L
.17856 .30326 L
Mistroke
.17856 .30326 L
.17857 .30326 L
.17857 .30326 L
.17858 .30326 L
.17859 .30326 L
.17859 .30326 L
.1786 .30326 L
.17861 .30326 L
.17862 .30326 L
.17864 .30326 L
.17867 .30326 L
.1787 .30326 L
.17873 .30326 L
.17879 .30326 L
.17885 .30327 L
.17891 .30328 L
.17902 .3033 L
.17915 .30332 L
.17939 .30339 L
.17963 .30348 L
.17986 .30358 L
.1801 .30371 L
.18033 .30386 L
.18058 .30404 L
.18081 .30423 L
.18104 .30443 L
.18129 .30466 L
.18152 .3049 L
.18177 .30517 L
.18201 .30545 L
.18224 .30573 L
.18249 .30604 L
.18272 .30635 L
.18295 .30666 L
.18319 .30699 L
.18342 .30732 L
.18367 .30768 L
.18391 .30803 L
.18414 .30837 L
.18438 .30873 L
.18462 .30908 L
.18487 .30945 L
.18511 .30981 L
.18534 .31014 L
.18559 .3105 L
.18583 .31083 L
.18605 .31115 L
.1863 .31147 L
.18653 .31178 L
.18678 .31209 L
Mistroke
.18702 .31237 L
.18725 .31263 L
.18749 .3129 L
.18773 .31314 L
.18796 .31335 L
.1882 .31356 L
.18843 .31374 L
.18868 .31392 L
.18892 .31407 L
.18914 .31419 L
.18939 .31431 L
.18962 .31439 L
.18974 .31443 L
.18987 .31446 L
.18999 .31449 L
.19011 .31451 L
.19017 .31451 L
.19023 .31452 L
.19027 .31452 L
.1903 .31453 L
.19033 .31453 L
.19036 .31453 L
.19039 .31453 L
.1904 .31453 L
.19042 .31453 L
.19043 .31453 L
.19044 .31453 L
.19045 .31453 L
.19045 .31453 L
.19046 .31453 L
.19047 .31453 L
.19047 .31453 L
.19048 .31453 L
.19048 .31453 L
.19049 .31453 L
.19049 .31453 L
.1905 .31453 L
.19051 .31453 L
.19051 .31453 L
.19052 .31453 L
.19054 .31453 L
.19055 .31453 L
.19057 .31453 L
.1906 .31453 L
.19063 .31453 L
.19066 .31453 L
.19072 .31452 L
.19078 .31451 L
.19084 .31451 L
.19096 .31449 L
Mistroke
.19109 .31446 L
.19132 .3144 L
.19156 .31431 L
.19179 .3142 L
.19204 .31407 L
.19228 .31392 L
.19251 .31376 L
.19275 .31357 L
.19299 .31337 L
.19322 .31316 L
.19346 .31292 L
.19369 .31267 L
.19394 .3124 L
.19418 .31212 L
.1944 .31184 L
.19465 .31154 L
.19488 .31123 L
.19513 .3109 L
.19537 .31057 L
.1956 .31025 L
.19585 .30991 L
.19609 .30957 L
.19631 .30925 L
.19655 .3089 L
.19679 .30857 L
.19704 .30822 L
.19727 .30788 L
.1975 .30757 L
.19775 .30723 L
.19798 .30692 L
.19823 .3066 L
.19847 .3063 L
.19871 .30603 L
.19895 .30574 L
.19919 .30549 L
.19942 .30525 L
.19966 .30502 L
.1999 .30481 L
.20014 .3046 L
.20038 .30442 L
.20061 .30427 L
.20086 .30412 L
.2011 .304 L
.20132 .3039 L
.20156 .30382 L
.2018 .30376 L
.20192 .30374 L
.20198 .30373 L
.20204 .30372 L
.20211 .30371 L
Mistroke
.20216 .30371 L
.20222 .3037 L
.20225 .3037 L
.20227 .3037 L
.2023 .3037 L
.20232 .3037 L
.20233 .3037 L
.20234 .3037 L
.20235 .3037 L
.20236 .3037 L
.20236 .3037 L
.20237 .3037 L
.20238 .3037 L
.20239 .3037 L
.20239 .3037 L
.2024 .3037 L
.20241 .3037 L
.20241 .3037 L
.20242 .3037 L
.20243 .3037 L
.20245 .3037 L
.20248 .3037 L
.2025 .3037 L
.20256 .3037 L
.20262 .30371 L
.20268 .30371 L
.20274 .30372 L
.20286 .30374 L
.20297 .30376 L
.2032 .30382 L
.20345 .30391 L
.20369 .30401 L
.20392 .30413 L
.20416 .30427 L
.2044 .30443 L
.20465 .30462 L
.20489 .30482 L
.20512 .30502 L
.20537 .30526 L
.2056 .3055 L
.20583 .30575 L
.20608 .30602 L
.20631 .30629 L
.20656 .3066 L
.2068 .3069 L
.20703 .3072 L
.20727 .30752 L
.20751 .30784 L
.20774 .30814 L
.20798 .30848 L
Mistroke
.20821 .3088 L
.20846 .30914 L
.20869 .30947 L
.20892 .30978 L
.20917 .31011 L
.2094 .31043 L
.20965 .31075 L
.20989 .31106 L
.21012 .31135 L
.21037 .31164 L
.2106 .31192 L
.21083 .31217 L
.21107 .31243 L
.21131 .31266 L
.21156 .31289 L
.21179 .3131 L
.21202 .31329 L
.21227 .31347 L
.2125 .31362 L
.21273 .31375 L
.21297 .31388 L
.2132 .31397 L
.21345 .31406 L
.21357 .31409 L
.21369 .31412 L
.2138 .31414 L
.21392 .31416 L
.21397 .31417 L
.21404 .31417 L
.2141 .31418 L
.21415 .31418 L
.21418 .31418 L
.21419 .31418 L
.21421 .31418 L
.21422 .31418 L
.21424 .31418 L
.21424 .31418 L
.21425 .31418 L
.21426 .31418 L
.21426 .31418 L
.21427 .31418 L
.21427 .31418 L
.21428 .31418 L
.21428 .31418 L
.21429 .31418 L
.21429 .31418 L
.2143 .31418 L
.2143 .31418 L
.21431 .31418 L
.21431 .31418 L
Mistroke
.21432 .31418 L
.21433 .31418 L
.21434 .31418 L
.21436 .31418 L
.21439 .31418 L
.21441 .31418 L
.21445 .31418 L
.21451 .31418 L
.21456 .31417 L
.21462 .31416 L
.21474 .31415 L
.21485 .31413 L
.21509 .31407 L
.21532 .31399 L
.21557 .31389 L
.21581 .31377 L
.21603 .31365 L
.21628 .31349 L
.21651 .31332 L
.21676 .31313 L
.21699 .31292 L
.21722 .31271 L
.21747 .31247 L
.2177 .31223 L
.21795 .31196 L
.21819 .31168 L
.21843 .31141 L
.21867 .31111 L
.21891 .31081 L
.21914 .31052 L
.21938 .3102 L
.21962 .30989 L
.21986 .30956 L
.2201 .30923 L
.22033 .30892 L
.22058 .30859 L
.22081 .30828 L
.22104 .30798 L
.22128 .30766 L
.22152 .30736 L
.22176 .30705 L
.222 .30676 L
.22223 .30649 L
.22247 .30622 L
.22271 .30596 L
.22296 .3057 L
.2232 .30546 L
.22343 .30525 L
.22368 .30504 L
.22391 .30485 L
Mistroke
.22414 .30469 L
.22438 .30453 L
.22462 .30439 L
.22486 .30427 L
.2251 .30417 L
.22533 .30409 L
.22545 .30406 L
.22558 .30403 L
.2257 .304 L
.22581 .30399 L
.22593 .30397 L
.22599 .30397 L
.22602 .30397 L
.22605 .30397 L
.22608 .30396 L
.22611 .30396 L
.22613 .30396 L
.22614 .30396 L
.22616 .30396 L
.22616 .30396 L
.22617 .30396 L
.22617 .30396 L
.22618 .30396 L
.22619 .30396 L
.22619 .30396 L
.2262 .30396 L
.22621 .30396 L
.22621 .30396 L
.22622 .30396 L
.22623 .30396 L
.22624 .30396 L
.22625 .30396 L
.22628 .30396 L
.22631 .30397 L
.22634 .30397 L
.2264 .30397 L
.22646 .30398 L
.22652 .30398 L
.22663 .304 L
.22676 .30402 L
.227 .30408 L
.22724 .30415 L
.22747 .30425 L
.22771 .30436 L
.22794 .30449 L
.22819 .30465 L
.22843 .30481 L
.22865 .30499 L
.2289 .3052 L
.22913 .30541 L
Mistroke
.22938 .30565 L
.22962 .30589 L
.22985 .30614 L
.2301 .30641 L
.23033 .30669 L
.23056 .30696 L
.2308 .30726 L
.23104 .30755 L
.23129 .30787 L
.23152 .30818 L
.23175 .30848 L
.232 .3088 L
.23223 .30911 L
.23248 .30944 L
.23272 .30976 L
.23296 .31006 L
.2332 .31038 L
.23344 .31067 L
.23367 .31096 L
.23391 .31125 L
.23415 .31152 L
.23439 .3118 L
.23463 .31205 L
.23486 .31229 L
.23511 .31252 L
.23535 .31274 L
.23557 .31293 L
.23581 .31312 L
.23605 .31328 L
.23629 .31344 L
.23653 .31358 L
.23676 .31369 L
.23701 .31379 L
.23724 .31387 L
.23736 .3139 L
.23749 .31393 L
.23761 .31395 L
.23773 .31397 L
.23779 .31398 L
.23785 .31398 L
.23788 .31399 L
.23792 .31399 L
.23795 .31399 L
.23798 .31399 L
.23801 .31399 L
.23802 .31399 L
.23804 .31399 L
.23805 .31399 L
.23806 .31399 L
.23806 .31399 L
Mistroke
.23807 .31399 L
.23808 .31399 L
.23808 .31399 L
.23809 .31399 L
.2381 .31399 L
.2381 .31399 L
.23811 .31399 L
.23811 .31399 L
.23812 .31399 L
.23813 .31399 L
.23813 .31399 L
.23814 .31399 L
.23816 .31399 L
.23817 .31399 L
.23819 .31399 L
.23822 .31399 L
.23825 .31399 L
.23828 .31399 L
.23833 .31398 L
.23839 .31398 L
.23846 .31397 L
.23858 .31395 L
.23871 .31393 L
.23893 .31387 L
.23918 .31379 L
.23941 .3137 L
.23966 .31358 L
.2399 .31344 L
.24013 .31329 L
.24037 .31312 L
.24061 .31294 L
.24084 .31275 L
.24108 .31253 L
.24131 .31231 L
.24156 .31206 L
.2418 .31181 L
.24203 .31155 L
.24227 .31127 L
.2425 .31099 L
.24275 .31069 L
.24299 .31039 L
.24322 .3101 L
.24347 .30978 L
.24371 .30948 L
.24393 .30918 L
.24418 .30886 L
.24441 .30856 L
.24466 .30824 L
.2449 .30793 L
.24513 .30764 L
Mistroke
.24537 .30734 L
.24561 .30705 L
.24583 .30678 L
.24607 .30651 L
.24631 .30625 L
.24655 .30599 L
.24679 .30575 L
.24702 .30554 L
.24726 .30532 L
.2475 .30513 L
.24775 .30494 L
.24799 .30477 L
.24822 .30462 L
.24846 .30449 L
.2487 .30438 L
.24892 .30428 L
.24917 .30421 L
.2494 .30415 L
.24953 .30413 L
.24965 .30411 L
.2497 .3041 L
.24977 .3041 L
.24982 .30409 L
.24988 .30409 L
.24991 .30409 L
.24992 .30409 L
.24994 .30409 L
.24995 .30409 L
.24996 .30409 L
.24997 .30409 L
.24998 .30409 L
.24998 .30409 L
.24999 .30409 L
.25 .30409 L
.25001 .30409 L
.25001 .30409 L
.25001 .30409 L
.25002 .30409 L
.25002 .30409 L
.25003 .30409 L
.25004 .30409 L
.25006 .30409 L
.25007 .30409 L
.25009 .30409 L
.25012 .30409 L
.25015 .30409 L
.25018 .30409 L
.25023 .3041 L
.25029 .3041 L
.25036 .30411 L
Mistroke
.25047 .30413 L
.2506 .30415 L
.25085 .30421 L
.25109 .30429 L
.25131 .30438 L
.25156 .3045 L
.25179 .30463 L
.25204 .30479 L
.25229 .30496 L
.25252 .30513 L
.25276 .30534 L
.253 .30555 L
.25323 .30577 L
.25347 .30601 L
.25371 .30626 L
.25395 .30654 L
.25419 .30681 L
.25442 .30708 L
.25467 .30738 L
.25491 .30767 L
.25513 .30796 L
.25537 .30826 L
.25561 .30856 L
.25585 .30888 L
.25609 .30919 L
.25632 .30949 L
.25657 .3098 L
.2568 .3101 L
.25705 .31042 L
.25729 .31071 L
.25752 .31099 L
.25777 .31128 L
.258 .31155 L
.25823 .3118 L
.25847 .31205 L
.25871 .31228 L
.25896 .31252 L
.25919 .31273 L
.25942 .31292 L
.25967 .3131 L
.2599 .31326 L
.26013 .3134 L
.26037 .31354 L
.2606 .31365 L
.26085 .31374 L
.26109 .31382 L
.26132 .31387 L
.26144 .31389 L
.26156 .31391 L
.26162 .31392 L
Mistroke
.26169 .31392 L
.26172 .31393 L
.26175 .31393 L
.26178 .31393 L
.26181 .31393 L
.26182 .31393 L
.26184 .31393 L
.26185 .31393 L
.26187 .31393 L
.26187 .31393 L
.26188 .31393 L
.26189 .31393 L
.26189 .31393 L
.2619 .31393 L
.2619 .31393 L
.26191 .31393 L
.26192 .31393 L
.26193 .31393 L
.26193 .31393 L
.26194 .31393 L
.26195 .31393 L
.26197 .31393 L
.26198 .31393 L
.26201 .31393 L
.26204 .31393 L
.26209 .31393 L
.26215 .31392 L
.26226 .31391 L
.26238 .31389 L
.26251 .31387 L
.26274 .31381 L
.26298 .31373 L
.26322 .31364 L
.26347 .31352 L
.26371 .31339 L
.26394 .31324 L
.26418 .31307 L
.26442 .31289 L
.26465 .3127 L
.26489 .31248 L
.26512 .31226 L
.26537 .31201 L
.26561 .31176 L
.26584 .31151 L
.26608 .31123 L
.26632 .31095 L
.26655 .31068 L
.26679 .31038 L
.26702 .31009 L
.26727 .30978 L
Mistroke
.2675 .30947 L
.26773 .30917 L
.26797 .30886 L
.26821 .30856 L
.26846 .30824 L
.2687 .30793 L
.26893 .30764 L
.26917 .30734 L
.26941 .30705 L
.26964 .30678 L
.26988 .30651 L
.27011 .30625 L
.27036 .30599 L
.2706 .30575 L
.27083 .30554 L
.27107 .30532 L
.2713 .30513 L
.27155 .30493 L
.27179 .30477 L
.27203 .30462 L
.27227 .30449 L
.27251 .30437 L
.27274 .30428 L
.27298 .3042 L
.27321 .30415 L
.27334 .30412 L
.27346 .30411 L
.27352 .3041 L
.27358 .3041 L
.27363 .30409 L
.27366 .30409 L
.27369 .30409 L
.27372 .30409 L
.27374 .30409 L
.27375 .30409 L
.27377 .30409 L
.27378 .30409 L
.27379 .30409 L
.27379 .30409 L
.2738 .30409 L
.27381 .30409 L
.27381 .30409 L
.27382 .30409 L
.27383 .30409 L
.27384 .30409 L
.27384 .30409 L
.27385 .30409 L
.27387 .30409 L
.27388 .30409 L
.2739 .30409 L
Mistroke
.27393 .30409 L
.27396 .30409 L
.27399 .30409 L
.27406 .3041 L
.27412 .3041 L
.27418 .30411 L
.27441 .30415 L
.27453 .30418 L
.27465 .30421 L
.2749 .30429 L
.27514 .30439 L
.27537 .3045 L
.27562 .30464 L
.27585 .30479 L
.27608 .30495 L
.27632 .30513 L
.27655 .30533 L
.2768 .30555 L
.27704 .30577 L
.27727 .30601 L
.27751 .30626 L
.27775 .30652 L
.278 .30681 L
.27824 .30709 L
.27847 .30737 L
.27871 .30768 L
.27895 .30798 L
.27918 .30827 L
.27942 .30859 L
.27965 .30889 L
.2799 .30921 L
.28014 .30953 L
.28037 .30982 L
.28062 .31014 L
.28085 .31044 L
.28108 .31072 L
.28132 .31101 L
.28155 .31128 L
.2818 .31157 L
.28203 .31183 L
.28226 .31207 L
.28251 .31232 L
.28274 .31254 L
.28299 .31276 L
.28323 .31296 L
.28346 .31314 L
.28371 .31331 L
.28394 .31346 L
.28417 .31359 L
.28441 .3137 L
Mistroke
.28464 .3138 L
.28489 .31388 L
.28501 .31391 L
.28513 .31393 L
.28525 .31396 L
.28536 .31397 L
.28542 .31398 L
.28548 .31398 L
.28554 .31399 L
.28559 .31399 L
.28562 .31399 L
.28564 .31399 L
.28565 .31399 L
.28567 .31399 L
.28567 .31399 L
.28568 .31399 L
.28569 .31399 L
.28569 .31399 L
.2857 .31399 L
.28571 .31399 L
.28571 .31399 L
.28572 .31399 L
.28573 .31399 L
.28573 .31399 L
.28574 .31399 L
.28575 .31399 L
.28575 .31399 L
.28577 .31399 L
.28578 .31399 L
.2858 .31399 L
.28583 .31399 L
.28586 .31399 L
.28589 .31399 L
.28594 .31398 L
.28601 .31398 L
.28607 .31397 L
.28618 .31396 L
.28631 .31393 L
.28655 .31387 L
.28679 .3138 L
.28704 .31369 L
.28728 .31358 L
.28751 .31344 L
.28775 .31329 L
.28799 .31312 L
.28822 .31294 L
.28846 .31274 L
.2887 .31252 L
.28895 .31229 L
.28919 .31204 L
Mistroke
.28942 .31179 L
.28966 .31152 L
.2899 .31125 L
.29012 .31097 L
.29037 .31068 L
.2906 .31039 L
.29085 .31007 L
.29108 .30976 L
.29131 .30946 L
.29156 .30914 L
.29179 .30883 L
.29204 .3085 L
.29228 .30818 L
.29251 .30788 L
.29276 .30756 L
.293 .30727 L
.29322 .30699 L
.29347 .3067 L
.2937 .30643 L
.29395 .30615 L
.29419 .30589 L
.29442 .30566 L
.29466 .30542 L
.2949 .30521 L
.29512 .30502 L
.29537 .30483 L
.2956 .30466 L
.29584 .30451 L
.29608 .30437 L
.29631 .30426 L
.29655 .30416 L
.29679 .30408 L
.29691 .30405 L
.29704 .30402 L
.29715 .304 L
.29722 .30399 L
.29728 .30398 L
.29734 .30398 L
.2974 .30397 L
.29746 .30397 L
.29749 .30397 L
.29752 .30396 L
.29754 .30396 L
.29755 .30396 L
.29757 .30396 L
.29758 .30396 L
.29759 .30396 L
.2976 .30396 L
.2976 .30396 L
.29761 .30396 L
Mistroke
.29761 .30396 L
.29762 .30396 L
.29763 .30396 L
.29763 .30396 L
.29764 .30396 L
.29764 .30396 L
.29765 .30396 L
.29765 .30396 L
.29767 .30396 L
.29768 .30396 L
.2977 .30396 L
.29772 .30396 L
.29775 .30397 L
.29781 .30397 L
.29787 .30397 L
.29798 .30399 L
.29811 .304 L
.29823 .30403 L
.29846 .30409 L
.29871 .30417 L
.29894 .30427 L
.29917 .30438 L
.29941 .30452 L
.29965 .30467 L
.2999 .30485 L
.30013 .30504 L
.30036 .30524 L
.30061 .30546 L
.30084 .30569 L
.30107 .30593 L
.30131 .30619 L
.30154 .30645 L
.30179 .30674 L
.30203 .30703 L
.30226 .30732 L
.3025 .30763 L
.30273 .30793 L
.30298 .30826 L
.30322 .30858 L
.30345 .30889 L
.3037 .30922 L
.30393 .30954 L
.30416 .30984 L
.3044 .31017 L
.30464 .31047 L
.30488 .31079 L
.30512 .31109 L
.30535 .31137 L
.30559 .31166 L
.30583 .31193 L
Mistroke
.30608 .3122 L
.30632 .31245 L
.30655 .31268 L
.3068 .31291 L
.30703 .31311 L
.30726 .31329 L
.3075 .31347 L
.30774 .31362 L
.30799 .31377 L
.30823 .31388 L
.30846 .31398 L
.3087 .31406 L
.30882 .3141 L
.30894 .31412 L
.30905 .31414 L
.30916 .31416 L
.30922 .31417 L
.30928 .31417 L
.30934 .31418 L
.30939 .31418 L
.30943 .31418 L
.30944 .31418 L
.30946 .31418 L
.30947 .31418 L
.30948 .31418 L
.30949 .31418 L
.3095 .31418 L
.3095 .31418 L
.30951 .31418 L
.30952 .31418 L
.30952 .31418 L
.30953 .31418 L
.30954 .31418 L
.30955 .31418 L
.30955 .31418 L
.30956 .31418 L
.30957 .31418 L
.30958 .31418 L
.3096 .31418 L
.30963 .31418 L
.30966 .31418 L
.30969 .31418 L
.30975 .31418 L
.30981 .31417 L
.30987 .31416 L
.30999 .31415 L
.31012 .31412 L
.31034 .31406 L
.31059 .31398 L
.31082 .31388 L
Mistroke
.31107 .31376 L
.3113 .31362 L
.31153 .31347 L
.31178 .31329 L
.31201 .31311 L
.31226 .31289 L
.3125 .31266 L
.31273 .31243 L
.31298 .31217 L
.31322 .31191 L
.31344 .31164 L
.31369 .31135 L
.31392 .31106 L
.31417 .31074 L
.31441 .31043 L
.31464 .31012 L
.31488 .30979 L
.31512 .30947 L
.31534 .30915 L
.31558 .30882 L
.31582 .3085 L
.31606 .30816 L
.3163 .30784 L
.31653 .30753 L
.31677 .30721 L
.31701 .30691 L
.31725 .30659 L
.31749 .3063 L
.31773 .30603 L
.31797 .30575 L
.31821 .3055 L
.31843 .30527 L
.31868 .30503 L
.31891 .30483 L
.31916 .30462 L
.3194 .30444 L
.31962 .30429 L
.31987 .30414 L
.3201 .30402 L
.32035 .30391 L
.32059 .30383 L
.32083 .30377 L
.32095 .30374 L
.32107 .30372 L
.32113 .30371 L
.32119 .30371 L
.32125 .3037 L
.3213 .3037 L
.32133 .3037 L
.32134 .3037 L
Mistroke
.32136 .3037 L
.32137 .3037 L
.32139 .3037 L
.3214 .3037 L
.32141 .3037 L
.32141 .3037 L
.32142 .3037 L
.32143 .3037 L
.32143 .3037 L
.32144 .3037 L
.32145 .3037 L
.32145 .3037 L
.32146 .3037 L
.32147 .3037 L
.32149 .3037 L
.32151 .3037 L
.32154 .3037 L
.32157 .3037 L
.3216 .3037 L
.32166 .30371 L
.32177 .30372 L
.32189 .30374 L
.32202 .30376 L
.32227 .30383 L
.32251 .30391 L
.32274 .30401 L
.32299 .30414 L
.32322 .30429 L
.32345 .30444 L
.3237 .30463 L
.32393 .30482 L
.32418 .30505 L
.32442 .30528 L
.32465 .30552 L
.32489 .30579 L
.32513 .30606 L
.32536 .30633 L
.3256 .30663 L
.32583 .30693 L
.32608 .30726 L
.32632 .30758 L
.32655 .3079 L
.32679 .30824 L
.32702 .30857 L
.32727 .30893 L
.32751 .30927 L
.32775 .3096 L
.32799 .30995 L
.32823 .31028 L
.32846 .3106 L
Mistroke
.3287 .31093 L
.32893 .31124 L
.32918 .31156 L
.32942 .31186 L
.32965 .31214 L
.32989 .31243 L
.33013 .31269 L
.33036 .31293 L
.3306 .31316 L
.33083 .31338 L
.33108 .31359 L
.33132 .31377 L
.33154 .31393 L
.33179 .31408 L
.33202 .31421 L
.33227 .31432 L
.33251 .3144 L
.33274 .31446 L
.33286 .31449 L
.33292 .3145 L
.33299 .31451 L
.33305 .31452 L
.3331 .31452 L
.33316 .31453 L
.33321 .31453 L
.33324 .31453 L
.33327 .31453 L
.33329 .31453 L
.3333 .31453 L
.3333 .31453 L
.33331 .31453 L
.33332 .31453 L
.33332 .31453 L
.33333 .31453 L
.33333 .31453 L
.33334 .31453 L
.33335 .31453 L
.33336 .31453 L
.33336 .31453 L
.33336 .31453 L
.33338 .31453 L
.33339 .31453 L
.33342 .31453 L
.33344 .31453 L
.33347 .31453 L
.3335 .31453 L
.33356 .31452 L
.33363 .31452 L
.33369 .31451 L
.33382 .31449 L
Mistroke
.33394 .31446 L
.33417 .3144 L
.33442 .31431 L
.33465 .3142 L
.33488 .31408 L
.33512 .31392 L
.33536 .31376 L
.33561 .31356 L
.33584 .31336 L
.33607 .31314 L
.33632 .31289 L
.33655 .31264 L
.33678 .31238 L
.33702 .3121 L
.33725 .31181 L
.3375 .31149 L
.33774 .31117 L
.33797 .31086 L
.33821 .31051 L
.33844 .31018 L
.33869 .30982 L
.33893 .30946 L
.33916 .30912 L
.33941 .30876 L
.33964 .30841 L
.33987 .30807 L
.34011 .30771 L
.34035 .30738 L
.34059 .30703 L
.34083 .30669 L
.34106 .30638 L
.34131 .30606 L
.34154 .30577 L
.34179 .30546 L
.34203 .30518 L
.34226 .30493 L
.34251 .30468 L
.34275 .30445 L
.34297 .30425 L
.34322 .30405 L
.34345 .30388 L
.3437 .30372 L
.34394 .30359 L
.34417 .30348 L
.34441 .30339 L
.34453 .30335 L
.34465 .30332 L
.34476 .3033 L
.34487 .30328 L
.34493 .30327 L
Mistroke
.345 .30327 L
.34505 .30326 L
.34511 .30326 L
.34514 .30326 L
.34515 .30326 L
.34517 .30326 L
.34518 .30326 L
.34519 .30326 L
.3452 .30326 L
.34521 .30326 L
.34522 .30326 L
.34522 .30326 L
.34523 .30326 L
.34524 .30326 L
.34524 .30326 L
.34525 .30326 L
.34526 .30326 L
.34526 .30326 L
.34527 .30326 L
.34528 .30326 L
.3453 .30326 L
.34531 .30326 L
.34534 .30326 L
.34537 .30326 L
.3454 .30326 L
.34546 .30326 L
.34552 .30327 L
.34558 .30328 L
.3457 .3033 L
.34583 .30333 L
.34606 .30339 L
.3463 .30348 L
.34653 .30359 L
.34678 .30373 L
.34702 .30388 L
.34725 .30405 L
.34749 .30425 L
.34772 .30446 L
.34797 .3047 L
.34821 .30496 L
.34845 .30522 L
.34869 .30551 L
.34893 .30581 L
.34916 .3061 L
.3494 .30643 L
.34963 .30676 L
.34988 .30712 L
.35012 .30747 L
.35035 .30781 L
.35059 .30819 L
Mistroke
.35083 .30855 L
.35106 .3089 L
.3513 .30928 L
.35153 .30964 L
.35178 .31003 L
.35201 .31039 L
.35224 .31074 L
.35249 .3111 L
.35272 .31145 L
.35297 .3118 L
.35321 .31213 L
.35344 .31244 L
.35368 .31275 L
.35392 .31304 L
.35415 .3133 L
.35439 .31357 L
.35462 .3138 L
.35487 .31404 L
.35511 .31424 L
.35534 .31442 L
.35558 .31458 L
.35582 .31472 L
.35607 .31485 L
.35631 .31494 L
.35654 .31501 L
.35666 .31504 L
.35679 .31506 L
.35684 .31507 L
.3569 .31508 L
.35696 .31508 L
.35701 .31508 L
.35704 .31509 L
.35706 .31509 L
.35707 .31509 L
.35709 .31509 L
.3571 .31509 L
.35711 .31509 L
.35711 .31509 L
.35712 .31509 L
.35713 .31509 L
.35713 .31509 L
.35714 .31509 L
.35714 .31509 L
.35715 .31509 L
.35715 .31509 L
.35716 .31509 L
.35716 .31509 L
.35717 .31509 L
.35718 .31509 L
.35719 .31509 L
Mistroke
.35719 .31509 L
.35721 .31509 L
.35722 .31509 L
.35725 .31509 L
.35728 .31508 L
.35731 .31508 L
.35737 .31508 L
.35743 .31507 L
.3575 .31506 L
.35762 .31504 L
.35774 .31501 L
.35797 .31494 L
.35822 .31485 L
.35845 .31473 L
.3587 .31458 L
.35894 .31441 L
.35917 .31423 L
.35941 .31402 L
.35965 .31379 L
.35988 .31356 L
.36012 .31329 L
.36035 .31301 L
.3606 .3127 L
.36084 .31239 L
.36107 .31207 L
.36131 .31172 L
.36155 .31137 L
.3618 .31099 L
.36204 .31062 L
.36227 .31025 L
.36251 .30985 L
.36275 .30946 L
.36298 .30909 L
.36322 .30869 L
.36345 .3083 L
.3637 .30789 L
.36394 .3075 L
.36417 .30713 L
.36442 .30675 L
.36465 .30638 L
.36488 .30604 L
.36512 .30569 L
.36535 .30536 L
.3656 .30503 L
.36584 .30472 L
.36607 .30444 L
.36631 .30416 L
.36654 .30391 L
.36679 .30366 L
.36703 .30344 L
Mistroke
.36726 .30326 L
.36751 .30308 L
.36775 .30293 L
.36797 .30282 L
.36822 .30271 L
.36845 .30264 L
.36858 .30261 L
.3687 .30259 L
.36875 .30258 L
.36882 .30257 L
.36887 .30257 L
.36893 .30256 L
.36896 .30256 L
.36897 .30256 L
.36899 .30256 L
.369 .30256 L
.36901 .30256 L
.36902 .30256 L
.36903 .30256 L
.36903 .30256 L
.36904 .30256 L
.36905 .30256 L
.36906 .30256 L
.36906 .30256 L
.36906 .30256 L
.36907 .30256 L
.36908 .30256 L
.36909 .30256 L
.36911 .30256 L
.36912 .30256 L
.36914 .30256 L
.36917 .30256 L
.3692 .30256 L
.36923 .30257 L
.3693 .30257 L
.36935 .30258 L
.36942 .30259 L
.36953 .30261 L
.36964 .30264 L
.36988 .30271 L
.37013 .30282 L
.37036 .30295 L
.37059 .30309 L
.37084 .30327 L
.37107 .30347 L
.3713 .30368 L
.37154 .30392 L
.37177 .30418 L
.37202 .30447 L
.37226 .30477 L
Mistroke
.37249 .30508 L
.37273 .30542 L
.37296 .30576 L
.37321 .30614 L
.37345 .30652 L
.37368 .3069 L
.37393 .30731 L
.37417 .30771 L
.37439 .3081 L
.37463 .30853 L
.37487 .30894 L
.37511 .30937 L
.37535 .30979 L
.37558 .3102 L
.37583 .31062 L
.37606 .31103 L
.37631 .31145 L
.37655 .31185 L
.37678 .31222 L
.37703 .31261 L
.37727 .31297 L
.37749 .3133 L
.37774 .31364 L
.37797 .31394 L
.37822 .31425 L
.37846 .31452 L
.37869 .31477 L
.37893 .315 L
.37917 .31521 L
.3794 .31539 L
.37964 .31555 L
.37987 .31568 L
.38012 .31579 L
.38024 .31584 L
.38036 .31587 L
.38047 .3159 L
.38058 .31593 L
.38064 .31594 L
.38071 .31594 L
.38077 .31595 L
.38082 .31596 L
.38085 .31596 L
.38086 .31596 L
.38088 .31596 L
.38089 .31596 L
.38091 .31596 L
.38091 .31596 L
.38092 .31596 L
.38092 .31596 L
.38093 .31596 L
Mistroke
.38094 .31596 L
.38094 .31596 L
.38095 .31596 L
.38095 .31596 L
.38096 .31596 L
.38096 .31596 L
.38096 .31596 L
.38097 .31596 L
.38098 .31596 L
.38098 .31596 L
.381 .31596 L
.38101 .31596 L
.38102 .31596 L
.38106 .31596 L
.38109 .31596 L
.38112 .31595 L
.38117 .31595 L
.38123 .31594 L
.3813 .31593 L
.38141 .31591 L
.38154 .31588 L
.38179 .31579 L
.38203 .31568 L
.38226 .31555 L
.38251 .31538 L
.38274 .31519 L
.38297 .31499 L
.38322 .31474 L
.38345 .31449 L
.3837 .31419 L
.38394 .31389 L
.38417 .31357 L
.38441 .31322 L
.38465 .31286 L
.38487 .3125 L
.38511 .3121 L
.38535 .3117 L
.38559 .31127 L
.38583 .31084 L
.38606 .31042 L
.3863 .30997 L
.38654 .30952 L
.38679 .30905 L
.38703 .30859 L
.38726 .30815 L
.3875 .30768 L
.38774 .30724 L
.38797 .30681 L
.38821 .30637 L
.38844 .30595 L
Mistroke
.38869 .30552 L
.38893 .30511 L
.38916 .30473 L
.3894 .30435 L
.38964 .304 L
.38989 .30364 L
.39013 .30332 L
.39036 .30303 L
.3906 .30275 L
.39084 .3025 L
.39107 .30228 L
.39131 .30208 L
.39155 .30191 L
.3918 .30176 L
.39203 .30164 L
.39226 .30155 L
.39238 .30152 L
.39251 .30149 L
.39257 .30148 L
.39263 .30148 L
.39268 .30147 L
.39274 .30147 L
.39277 .30146 L
.39278 .30146 L
.3928 .30146 L
.39281 .30146 L
.39282 .30146 L
.39282 .30146 L
.39283 .30146 L
.39284 .30146 L
.39284 .30146 L
.39285 .30146 L
.39286 .30146 L
.39286 .30146 L
.39287 .30146 L
.39287 .30146 L
.39288 .30146 L
.39289 .30146 L
.3929 .30146 L
.39291 .30146 L
.39293 .30146 L
.39294 .30146 L
.39297 .30147 L
.393 .30147 L
.39303 .30147 L
.39309 .30148 L
.39315 .30148 L
.39321 .30149 L
.39333 .30152 L
.39345 .30156 L
Mistroke
.3937 .30165 L
.39393 .30177 L
.39416 .30191 L
.3944 .30209 L
.39464 .30229 L
.39488 .30253 L
.39512 .30279 L
.39535 .30306 L
.39559 .30338 L
.39583 .30371 L
.39608 .30408 L
.39632 .30446 L
.39655 .30485 L
.3968 .30528 L
.39703 .30571 L
.39726 .30613 L
.3975 .3066 L
.39774 .30706 L
.39799 .30756 L
.39823 .30805 L
.39846 .30853 L
.3987 .30904 L
.39894 .30953 L
.39916 .31001 L
.3994 .31051 L
.39964 .31099 L
.39988 .3115 L
.40012 .31198 L
.40035 .31243 L
.40059 .3129 L
.40083 .31334 L
.40108 .31378 L
.40132 .3142 L
.40155 .31458 L
.40179 .31496 L
.40203 .31531 L
.40226 .31562 L
.4025 .31593 L
.40273 .3162 L
.40298 .31646 L
.40322 .31668 L
.40345 .31687 L
.40369 .31703 L
.40393 .31716 L
.40405 .31721 L
.40418 .31726 L
.40429 .3173 L
.40436 .31731 L
.40442 .31733 L
.40448 .31734 L
Mistroke
.40454 .31735 L
.4046 .31735 L
.40463 .31735 L
.40467 .31736 L
.40469 .31736 L
.40471 .31736 L
.40472 .31736 L
.40473 .31736 L
.40474 .31736 L
.40475 .31736 L
.40475 .31736 L
.40476 .31736 L
.40476 .31736 L
.40477 .31736 L
.40477 .31736 L
.40478 .31736 L
.40478 .31736 L
.40479 .31736 L
.4048 .31736 L
.40481 .31736 L
.40483 .31736 L
.40484 .31736 L
.40487 .31736 L
.4049 .31735 L
.40496 .31735 L
.40501 .31734 L
.40514 .31732 L
.40525 .31729 L
.40537 .31725 L
.40561 .31715 L
.40584 .31702 L
.40609 .31685 L
.40633 .31665 L
.40656 .31643 L
.4068 .31616 L
.40703 .31588 L
.40728 .31555 L
.40752 .3152 L
.40775 .31484 L
.408 .31443 L
.40824 .31401 L
.40846 .31359 L
.40871 .31312 L
.40894 .31265 L
.40919 .31214 L
.40942 .31163 L
.40965 .31112 L
.4099 .31057 L
.41013 .31004 L
.41038 .30946 L
Mistroke
.41062 .3089 L
.41085 .30836 L
.4111 .30779 L
.41134 .30723 L
.41157 .30671 L
.41181 .30615 L
.41204 .30563 L
.41229 .30508 L
.41253 .30457 L
.41276 .30409 L
.41301 .3036 L
.41324 .30315 L
.41347 .30273 L
.41371 .30231 L
.41394 .30193 L
.41419 .30155 L
.41443 .30121 L
.41466 .30092 L
.4149 .30063 L
.41513 .30039 L
.41538 .30017 L
.41562 .29999 L
.41585 .29985 L
.41597 .2998 L
.4161 .29974 L
.41622 .2997 L
.41634 .29968 L
.4164 .29966 L
.41645 .29966 L
.41651 .29965 L
.41655 .29965 L
.41656 .29964 L
.41658 .29964 L
.41659 .29964 L
.41661 .29964 L
.41663 .29964 L
.41664 .29964 L
.41664 .29964 L
.41665 .29964 L
.41666 .29964 L
.41666 .29964 L
.41667 .29964 L
.41668 .29964 L
.41668 .29964 L
.41669 .29964 L
.4167 .29964 L
.4167 .29964 L
.41672 .29964 L
.41673 .29964 L
.41676 .29964 L
Mistroke
.41678 .29965 L
.41681 .29965 L
.41688 .29966 L
.41693 .29966 L
.41706 .29969 L
.41717 .29973 L
.4173 .29977 L
.41755 .29989 L
.41778 .30005 L
.41801 .30023 L
.41825 .30046 L
.41849 .30072 L
.41873 .30103 L
.41897 .30136 L
.4192 .30171 L
.41945 .30211 L
.41968 .30253 L
.41991 .30296 L
.42015 .30344 L
.42038 .30393 L
.42063 .30447 L
.42087 .30502 L
.4211 .30556 L
.42134 .30615 L
.42158 .30674 L
.42182 .30737 L
.42206 .308 L
.4223 .3086 L
.42254 .30925 L
.42278 .30988 L
.423 .31048 L
.42325 .31113 L
.42348 .31174 L
.42373 .31238 L
.42397 .31299 L
.4242 .31357 L
.42444 .31416 L
.42467 .31472 L
.42492 .31529 L
.42517 .31582 L
.4254 .3163 L
.42564 .31679 L
.42588 .31723 L
.42611 .31763 L
.42635 .31802 L
.42659 .31836 L
.42683 .31869 L
.42707 .31897 L
.4273 .3192 L
.42755 .3194 L
Mistroke
.42779 .31956 L
.42801 .31968 L
.42813 .31972 L
.42819 .31974 L
.42825 .31976 L
.42831 .31977 L
.42837 .31978 L
.42841 .31978 L
.42844 .31979 L
.42847 .31979 L
.42849 .31979 L
.4285 .31979 L
.42852 .31979 L
.42853 .31979 L
.42854 .31979 L
.42854 .31979 L
.42855 .31979 L
.42855 .31979 L
.42856 .31979 L
.42857 .31979 L
.42857 .31979 L
.42858 .31979 L
.42859 .31979 L
.42859 .31979 L
.4286 .31979 L
.4286 .31979 L
.42862 .31979 L
.42864 .31979 L
.42865 .31979 L
.42868 .31979 L
.42871 .31979 L
.42873 .31978 L
.42879 .31977 L
.42885 .31976 L
.42896 .31974 L
.42908 .3197 L
.42919 .31965 L
.42942 .31952 L
.42967 .31934 L
.42991 .31912 L
.43014 .31887 L
.43038 .31856 L
.43062 .31823 L
.43087 .31783 L
.43111 .3174 L
.43134 .31696 L
.43158 .31646 L
.43182 .31594 L
.43205 .31541 L
.43229 .31482 L
Mistroke
.43253 .31422 L
.43277 .31356 L
.43301 .3129 L
.43324 .31225 L
.43349 .31154 L
.43372 .31084 L
.43395 .31015 L
.43419 .30942 L
.43443 .3087 L
.43467 .30793 L
.43491 .30719 L
.43514 .30649 L
.43538 .30574 L
.43562 .30502 L
.43587 .30428 L
.43611 .30357 L
.43634 .30291 L
.43658 .30223 L
.43682 .30159 L
.43705 .30101 L
.43729 .30041 L
.43752 .29986 L
.43777 .29932 L
.43801 .29883 L
.43824 .29839 L
.43848 .29796 L
.43872 .2976 L
.43897 .29725 L
.43921 .29697 L
.43944 .29673 L
.43969 .29654 L
.43981 .29646 L
.43992 .2964 L
.44004 .29635 L
.44015 .29631 L
.44021 .29629 L
.44028 .29628 L
.4403 .29628 L
.44033 .29627 L
.44036 .29627 L
.44039 .29627 L
.4404 .29626 L
.44042 .29626 L
.44043 .29626 L
.44044 .29626 L
.44045 .29626 L
.44046 .29626 L
.44047 .29626 L
.44047 .29626 L
.44048 .29626 L
Mistroke
.44048 .29626 L
.44049 .29626 L
.4405 .29626 L
.4405 .29626 L
.44051 .29626 L
.44052 .29626 L
.44053 .29626 L
.44056 .29627 L
.44059 .29627 L
.44061 .29627 L
.44067 .29628 L
.44073 .29629 L
.44085 .29632 L
.44097 .29637 L
.44108 .29643 L
.44132 .29658 L
.44155 .29678 L
.44179 .29704 L
.44203 .29734 L
.44227 .29771 L
.44251 .29812 L
.44275 .29855 L
.44299 .29906 L
.44323 .2996 L
.44345 .30015 L
.4437 .30078 L
.44393 .30143 L
.44418 .30215 L
.44442 .30288 L
.44464 .30361 L
.44489 .30441 L
.44512 .30521 L
.44537 .30608 L
.44561 .30695 L
.44585 .30779 L
.44609 .3087 L
.44633 .30958 L
.44656 .31044 L
.4468 .31135 L
.44703 .31223 L
.44728 .31315 L
.44752 .31404 L
.44775 .31487 L
.448 .31575 L
.44823 .31657 L
.44846 .31734 L
.4487 .31814 L
.44893 .31887 L
.44918 .31962 L
.44942 .3203 L
Mistroke
.44965 .32092 L
.44989 .32154 L
.45013 .32209 L
.45038 .32263 L
.45062 .32309 L
.45085 .32349 L
.45109 .32385 L
.45133 .32415 L
.45156 .32438 L
.45168 .32448 L
.4518 .32456 L
.45192 .32463 L
.45203 .32468 L
.45209 .3247 L
.45215 .32472 L
.45221 .32473 L
.45224 .32474 L
.45227 .32474 L
.4523 .32474 L
.45232 .32474 L
.45233 .32475 L
.45234 .32475 L
.45235 .32475 L
.45235 .32475 L
.45236 .32475 L
.45236 .32475 L
.45237 .32475 L
.45238 .32475 L
.45238 .32475 L
.45238 .32475 L
.45239 .32475 L
.45239 .32475 L
.4524 .32475 L
.45241 .32475 L
.45241 .32475 L
.45242 .32475 L
.45243 .32475 L
.45245 .32474 L
.45248 .32474 L
.4525 .32474 L
.45256 .32473 L
.45262 .32471 L
.45269 .32469 L
.45275 .32467 L
.45287 .32461 L
.45298 .32454 L
.45322 .32435 L
.45345 .32411 L
.4537 .32378 L
.45393 .3234 L
Mistroke
.45416 .32298 L
.4544 .32248 L
.45463 .32193 L
.45488 .32129 L
.45512 .32062 L
.45535 .31992 L
.45559 .31913 L
.45582 .31832 L
.45607 .31741 L
.45631 .31648 L
.45654 .31556 L
.45679 .31453 L
.45703 .31352 L
.45725 .31251 L
.4575 .31141 L
.45773 .31034 L
.45798 .30918 L
.45822 .30804 L
.45845 .30695 L
.45869 .30577 L
.45892 .30465 L
.45917 .30345 L
.45942 .30231 L
.45965 .30123 L
.45989 .3001 L
.46013 .29903 L
.46036 .29803 L
.4606 .297 L
.46084 .29604 L
.46108 .29507 L
.46132 .29417 L
.46155 .29336 L
.4618 .29256 L
.46204 .29184 L
.46226 .2912 L
.4625 .29058 L
.46274 .29006 L
.46298 .28957 L
.46322 .28918 L
.46345 .28887 L
.46358 .28873 L
.46369 .28862 L
.46382 .28853 L
.46393 .28846 L
.46404 .28841 L
.46411 .28839 L
.46414 .28839 L
.46417 .28838 L
.4642 .28838 L
.46423 .28837 L
Mistroke
.46424 .28837 L
.46426 .28837 L
.46426 .28837 L
.46427 .28837 L
.46427 .28837 L
.46428 .28837 L
.46428 .28837 L
.46429 .28837 L
.46429 .28837 L
.4643 .28837 L
.46431 .28837 L
.46431 .28837 L
.46433 .28837 L
.46434 .28837 L
.46437 .28837 L
.4644 .28838 L
.46443 .28838 L
.46445 .28839 L
.46452 .28841 L
.46458 .28843 L
.46464 .28846 L
.46477 .28854 L
.46489 .28864 L
.46512 .28889 L
.46536 .28923 L
.4656 .28965 L
.46585 .29019 L
.46609 .29079 L
.46632 .29145 L
.46657 .29224 L
.4668 .29307 L
.46703 .29395 L
.46728 .29495 L
.46751 .29599 L
.46776 .29717 L
.468 .29836 L
.46823 .29958 L
.46847 .30092 L
.46871 .30227 L
.46893 .30361 L
.46918 .30508 L
.46941 .30653 L
.46965 .30811 L
.46989 .30966 L
.47012 .31117 L
.47037 .31279 L
.4706 .31436 L
.47085 .31603 L
.47109 .31764 L
.47132 .31917 L
Mistroke
.47157 .32079 L
.4718 .32232 L
.47203 .32377 L
.47227 .32528 L
.47251 .32669 L
.47275 .32813 L
.47299 .32947 L
.47322 .3307 L
.47347 .33193 L
.4737 .33305 L
.47395 .33415 L
.47419 .33513 L
.47442 .33598 L
.47467 .33678 L
.47491 .33745 L
.47514 .338 L
.47538 .33847 L
.47561 .33882 L
.47574 .33896 L
.4758 .33901 L
.47586 .33906 L
.47592 .3391 L
.47598 .33913 L
.47601 .33914 L
.47604 .33915 L
.47607 .33916 L
.47609 .33916 L
.47611 .33917 L
.47612 .33917 L
.47614 .33917 L
.47615 .33917 L
.47616 .33917 L
.47617 .33917 L
.47617 .33917 L
.47618 .33918 L
.47618 .33918 L
.47619 .33918 L
.47619 .33918 L
.47619 .33918 L
.4762 .33918 L
.4762 .33918 L
.47621 .33918 L
.47621 .33917 L
.47622 .33917 L
.47623 .33917 L
.47624 .33917 L
.47625 .33917 L
.47627 .33917 L
.47628 .33917 L
.47631 .33916 L
Mistroke
.47634 .33915 L
.4764 .33913 L
.47646 .33909 L
.47657 .33901 L
.47669 .33889 L
.47681 .33875 L
.47704 .33837 L
.47727 .33787 L
.47751 .33721 L
.47774 .33645 L
.47799 .3355 L
.47823 .33446 L
.47846 .33333 L
.4787 .33201 L
.47894 .3306 L
.47919 .32898 L
.47943 .3273 L
.47966 .32557 L
.47991 .32362 L
.48015 .32163 L
.48037 .31962 L
.48062 .3174 L
.48085 .31517 L
.4811 .31271 L
.48134 .31027 L
.48157 .30787 L
.48181 .30525 L
.48205 .30267 L
.48228 .30017 L
.48252 .29747 L
.48275 .29485 L
.483 .29206 L
.48324 .28937 L
.48346 .2868 L
.48371 .28408 L
.48394 .2815 L
.48419 .27881 L
.48443 .27627 L
.48466 .2739 L
.48491 .27146 L
.48515 .2692 L
.48537 .26713 L
.48562 .26504 L
.48585 .26316 L
.4861 .26132 L
.48634 .25969 L
.48657 .25829 L
.48681 .25698 L
.48705 .2559 L
.48727 .25505 L
Mistroke
.4874 .25466 L
.48751 .25436 L
.48763 .2541 L
.48775 .25391 L
.48786 .25377 L
.48792 .25371 L
.48795 .25369 L
.48798 .25367 L
.48801 .25366 L
.48803 .25366 L
.48804 .25365 L
.48806 .25365 L
.48806 .25365 L
.48807 .25365 L
.48808 .25365 L
.48809 .25365 L
.48809 .25364 L
.4881 .25364 L
.48811 .25365 L
.48811 .25365 L
.48811 .25365 L
.48812 .25365 L
.48813 .25365 L
.48814 .25365 L
.48816 .25365 L
.48817 .25366 L
.48819 .25367 L
.48822 .25368 L
.48828 .25372 L
.48835 .25379 L
.48841 .25387 L
.48847 .25396 L
.48858 .25418 L
.48871 .25449 L
.48895 .25531 L
.48918 .25636 L
.48943 .25779 L
.48967 .25946 L
.48989 .26136 L
.49014 .26369 L
.49037 .26625 L
.49062 .2693 L
.49086 .27258 L
.49109 .27606 L
.49134 .28009 L
.49157 .28432 L
.4918 .28869 L
.49204 .29369 L
.49228 .29883 L
.49252 .30465 L
Mistroke
.49276 .31061 L
.49299 .31665 L
.49324 .32343 L
.49347 .33028 L
.49372 .33791 L
.49396 .34559 L
.4942 .3533 L
.49444 .36181 L
.49468 .37032 L
.49491 .37878 L
.49515 .38808 L
.49538 .3973 L
.49563 .40739 L
.49587 .41739 L
.4961 .42724 L
.49635 .43796 L
.49658 .44852 L
.49681 .45886 L
.49705 .47009 L
.49729 .48107 L
.49753 .49293 L
.49777 .50452 L
.498 .51581 L
.49824 .52795 L
.49848 .53976 L
.49873 .55242 L
.49897 .56471 L
.4992 .57659 L
.49945 .5893 L
.49968 .60156 L
.4998 .60774 L
.49991 .61338 L
.49994 .61488 L
.49995 .61566 L
.49997 .6165 L
.49998 .61723 L
.49999 .61743 L
.49999 .61765 L
.5 0 L
.50001 .00036 L
.50001 .00074 L
.50003 .00142 L
.50015 .00794 L
.50038 .0198 L
.50062 .03239 L
.50086 .04447 L
.50111 .05725 L
.50135 .06948 L
.50158 .08117 L
.50182 .09349 L
Mistroke
.50206 .10523 L
.50229 .11639 L
.50253 .12812 L
.50276 .13925 L
.50301 .1509 L
.50325 .16192 L
.50348 .17233 L
.50372 .18318 L
.50396 .1934 L
.50421 .204 L
.50445 .21396 L
.50468 .22328 L
.50493 .23291 L
.50516 .24189 L
.50539 .25026 L
.50563 .25887 L
.50587 .26686 L
.50612 .27502 L
.50636 .28255 L
.50659 .28948 L
.50683 .29653 L
.50707 .30298 L
.50729 .30887 L
.50753 .31481 L
.50777 .3202 L
.50801 .32557 L
.50825 .33041 L
.50848 .33474 L
.50872 .339 L
.50896 .34278 L
.50921 .34644 L
.50945 .34962 L
.50968 .35238 L
.50993 .35498 L
.51016 .35717 L
.51039 .35898 L
.51063 .36062 L
.51087 .3619 L
.51111 .36296 L
.51124 .36338 L
.51135 .3637 L
.51147 .36397 L
.51158 .36416 L
.51164 .36423 L
.51169 .36429 L
.51172 .36432 L
.51176 .36434 L
.51179 .36436 L
.51182 .36437 L
.51183 .36438 L
Mistroke
.51185 .36438 L
.51186 .36438 L
.51187 .36439 L
.51188 .36439 L
.51189 .36439 L
.5119 .36439 L
.5119 .36439 L
.5119 .36439 L
.51191 .36439 L
.51192 .36439 L
.51192 .36439 L
.51193 .36439 L
.51194 .36439 L
.51195 .36438 L
.51197 .36438 L
.51199 .36437 L
.51202 .36436 L
.51205 .36435 L
.5121 .3643 L
.51216 .36425 L
.51228 .36408 L
.5124 .36386 L
.51252 .3636 L
.51276 .36289 L
.51299 .362 L
.51323 .36085 L
.51347 .35956 L
.51369 .35816 L
.51393 .3565 L
.51417 .35475 L
.51441 .35275 L
.51465 .35069 L
.51488 .3486 L
.51512 .34627 L
.51536 .34393 L
.51561 .34136 L
.51585 .33882 L
.51608 .33632 L
.51632 .33361 L
.51656 .33098 L
.51679 .32842 L
.51703 .32568 L
.51726 .32305 L
.51751 .32026 L
.51775 .3176 L
.51798 .31507 L
.51822 .31241 L
.51846 .3099 L
.51871 .3073 L
.51895 .30486 L
Mistroke
.51918 .30258 L
.51943 .30025 L
.51966 .29808 L
.51989 .29609 L
.52013 .29408 L
.52037 .29224 L
.52062 .2904 L
.52086 .28875 L
.52109 .28727 L
.52133 .28583 L
.52157 .28456 L
.52179 .28346 L
.52204 .28242 L
.52227 .28154 L
.52252 .28074 L
.52275 .28011 L
.52298 .27962 L
.52311 .2794 L
.52323 .27924 L
.52335 .27909 L
.52346 .27899 L
.52352 .27895 L
.52358 .27892 L
.52364 .27889 L
.52367 .27888 L
.5237 .27887 L
.52373 .27887 L
.52375 .27886 L
.52376 .27886 L
.52378 .27886 L
.52379 .27886 L
.52379 .27886 L
.5238 .27886 L
.52381 .27886 L
.52382 .27886 L
.52382 .27886 L
.52382 .27886 L
.52383 .27886 L
.52384 .27886 L
.52385 .27886 L
.52387 .27886 L
.52388 .27886 L
.52391 .27887 L
.52393 .27888 L
.52399 .2789 L
.52405 .27892 L
.52417 .279 L
.52429 .27911 L
.5244 .27924 L
.52464 .2796 L
Mistroke
.52487 .28005 L
.52512 .28064 L
.52535 .28132 L
.5256 .28214 L
.52584 .28304 L
.52607 .28398 L
.52632 .28508 L
.52656 .28621 L
.52678 .28737 L
.52703 .28867 L
.52726 .28998 L
.52751 .29143 L
.52775 .29288 L
.52798 .29431 L
.52822 .29587 L
.52846 .29741 L
.52869 .2989 L
.52893 .3005 L
.52916 .30206 L
.52941 .30372 L
.52964 .30531 L
.52987 .30683 L
.53012 .30843 L
.53035 .30996 L
.5306 .31155 L
.53084 .31305 L
.53107 .31445 L
.53132 .3159 L
.53155 .31725 L
.53178 .3185 L
.53202 .31977 L
.53226 .32093 L
.5325 .3221 L
.53274 .32316 L
.53297 .32411 L
.53322 .32504 L
.53345 .32586 L
.5337 .32665 L
.53394 .32733 L
.53417 .3279 L
.53442 .32842 L
.53466 .32884 L
.53489 .32916 L
.53501 .3293 L
.53513 .32941 L
.53525 .32951 L
.53536 .32957 L
.53542 .3296 L
.53548 .32962 L
.53554 .32964 L
Mistroke
.53557 .32965 L
.5356 .32966 L
.53563 .32966 L
.53565 .32966 L
.53567 .32966 L
.53567 .32966 L
.53568 .32966 L
.53569 .32966 L
.53569 .32966 L
.5357 .32966 L
.53571 .32966 L
.53572 .32966 L
.53572 .32966 L
.53573 .32966 L
.53573 .32966 L
.53574 .32966 L
.53575 .32966 L
.53575 .32966 L
.53577 .32966 L
.53578 .32966 L
.53581 .32966 L
.53584 .32965 L
.53587 .32965 L
.5359 .32964 L
.53595 .32962 L
.53601 .3296 L
.53608 .32957 L
.5362 .3295 L
.53632 .3294 L
.53657 .32914 L
.53681 .32881 L
.53704 .32842 L
.53729 .32793 L
.53752 .32739 L
.53775 .3268 L
.53799 .32612 L
.53822 .3254 L
.53847 .32458 L
.53871 .32373 L
.53894 .32287 L
.53918 .32191 L
.53942 .32094 L
.53967 .31988 L
.53991 .31882 L
.54014 .31778 L
.54039 .31664 L
.54063 .31553 L
.54085 .31445 L
.5411 .31329 L
.54133 .31216 L
Mistroke
.54158 .31097 L
.54182 .30983 L
.54205 .30874 L
.54229 .30759 L
.54253 .3065 L
.54276 .30548 L
.543 .30441 L
.54323 .30341 L
.54348 .30239 L
.54372 .30144 L
.54394 .30056 L
.54419 .29967 L
.54442 .29886 L
.54467 .29805 L
.54491 .29733 L
.54514 .29668 L
.54539 .29605 L
.54563 .2955 L
.54585 .29503 L
.5461 .29458 L
.54633 .29422 L
.54658 .29389 L
.54682 .29365 L
.54705 .29347 L
.54716 .2934 L
.54722 .29337 L
.54729 .29335 L
.54735 .29333 L
.54741 .29331 L
.54746 .2933 L
.54749 .2933 L
.54752 .29329 L
.54753 .29329 L
.54755 .29329 L
.54756 .29329 L
.54757 .29329 L
.54758 .29329 L
.54759 .29329 L
.54759 .29329 L
.5476 .29329 L
.54761 .29329 L
.54761 .29329 L
.54762 .29329 L
.54763 .29329 L
.54763 .29329 L
.54764 .29329 L
.54765 .29329 L
.54765 .29329 L
.54767 .29329 L
.54768 .29329 L
Mistroke
.54769 .29329 L
.54773 .29329 L
.54776 .2933 L
.54782 .29331 L
.54788 .29332 L
.548 .29337 L
.54812 .29342 L
.54824 .2935 L
.54849 .2937 L
.54872 .29395 L
.54895 .29424 L
.54919 .29461 L
.54942 .29501 L
.54967 .2955 L
.54991 .29602 L
.55014 .29656 L
.55038 .29718 L
.55061 .29782 L
.55086 .29854 L
.5511 .29928 L
.55133 .30001 L
.55158 .30082 L
.55182 .30163 L
.55204 .30243 L
.55229 .3033 L
.55252 .30415 L
.55277 .30506 L
.55301 .30595 L
.55323 .30682 L
.55348 .30773 L
.55371 .30862 L
.55396 .30955 L
.5542 .31043 L
.55444 .31127 L
.55468 .31215 L
.55492 .31298 L
.55515 .31375 L
.55539 .31454 L
.55563 .31528 L
.55587 .31604 L
.55611 .31673 L
.55634 .31736 L
.55659 .31799 L
.55683 .31856 L
.55705 .31906 L
.55729 .31956 L
.55753 .31999 L
.55777 .3204 L
.55801 .32075 L
.55824 .32103 L
Mistroke
.55848 .32129 L
.55872 .32148 L
.55884 .32156 L
.55897 .32163 L
.55909 .32169 L
.55915 .32171 L
.55921 .32173 L
.55927 .32174 L
.55932 .32175 L
.55938 .32176 L
.55941 .32177 L
.55943 .32177 L
.55945 .32177 L
.55946 .32177 L
.55947 .32177 L
.55949 .32177 L
.5595 .32177 L
.5595 .32177 L
.5595 .32177 L
.55951 .32177 L
.55952 .32177 L
.55953 .32177 L
.55953 .32177 L
.55954 .32177 L
.55954 .32177 L
.55955 .32177 L
.55956 .32177 L
.55957 .32177 L
.55958 .32177 L
.55959 .32177 L
.55962 .32177 L
.55965 .32176 L
.55968 .32176 L
.55973 .32175 L
.55979 .32174 L
.55991 .32171 L
.56003 .32166 L
.56016 .32159 L
.56039 .32144 L
.56063 .32123 L
.56087 .32098 L
.5611 .3207 L
.56134 .32035 L
.56157 .31997 L
.56182 .31953 L
.56206 .31907 L
.56229 .31858 L
.56254 .31803 L
.56277 .31747 L
.563 .31691 L
Mistroke
.56324 .31628 L
.56347 .31565 L
.56372 .31496 L
.56396 .31427 L
.56419 .3136 L
.56443 .31286 L
.56467 .31215 L
.56492 .31138 L
.56516 .31064 L
.56539 .30992 L
.56563 .30916 L
.56587 .30843 L
.5661 .30774 L
.56634 .30701 L
.56657 .30632 L
.56682 .3056 L
.56706 .30493 L
.56729 .3043 L
.56753 .30366 L
.56777 .30307 L
.56802 .30246 L
.56826 .30192 L
.56849 .30142 L
.56874 .30092 L
.56897 .30048 L
.5692 .30009 L
.56945 .29971 L
.56968 .29939 L
.56993 .29909 L
.57017 .29884 L
.5704 .29864 L
.57064 .29847 L
.57077 .29841 L
.57088 .29835 L
.571 .29831 L
.57111 .29828 L
.57117 .29827 L
.57123 .29826 L
.57126 .29825 L
.57129 .29825 L
.57131 .29825 L
.57134 .29824 L
.57136 .29824 L
.57137 .29824 L
.57138 .29824 L
.57139 .29824 L
.5714 .29824 L
.5714 .29824 L
.57141 .29824 L
.57142 .29824 L
Mistroke
.57142 .29824 L
.57142 .29824 L
.57143 .29824 L
.57143 .29824 L
.57144 .29824 L
.57144 .29824 L
.57144 .29824 L
.57145 .29824 L
.57145 .29824 L
.57147 .29824 L
.57148 .29824 L
.57148 .29824 L
.5715 .29824 L
.57153 .29824 L
.57156 .29825 L
.57159 .29825 L
.57165 .29826 L
.5717 .29827 L
.57183 .2983 L
.57195 .29834 L
.57206 .29839 L
.5723 .29852 L
.57253 .29869 L
.57277 .29891 L
.57301 .29915 L
.57326 .29946 L
.5735 .29979 L
.57373 .30014 L
.57398 .30055 L
.57421 .30097 L
.57444 .30141 L
.57468 .3019 L
.57492 .30239 L
.57517 .30295 L
.57541 .3035 L
.57564 .30405 L
.57588 .30466 L
.57612 .30525 L
.57634 .30584 L
.57659 .30647 L
.57682 .30708 L
.57706 .30773 L
.5773 .30837 L
.57753 .30898 L
.57778 .30962 L
.57801 .31023 L
.57826 .31088 L
.5785 .31148 L
.57873 .31206 L
.57898 .31265 L
Mistroke
.57921 .31321 L
.57944 .31372 L
.57968 .31425 L
.57992 .31473 L
.58017 .31522 L
.5804 .31566 L
.58063 .31606 L
.58088 .31645 L
.58111 .3168 L
.58134 .3171 L
.58158 .31739 L
.58181 .31764 L
.58206 .31786 L
.5823 .31804 L
.58253 .31818 L
.58265 .31824 L
.58277 .31829 L
.58289 .31833 L
.583 .31836 L
.58306 .31837 L
.58312 .31838 L
.58318 .31839 L
.58321 .31839 L
.58324 .31839 L
.58326 .31839 L
.58327 .31839 L
.58328 .31839 L
.58329 .31839 L
.5833 .31839 L
.58331 .31839 L
.58331 .31839 L
.58332 .31839 L
.58333 .31839 L
.58333 .31839 L
.58334 .31839 L
.58334 .31839 L
.58335 .31839 L
.58336 .31839 L
.58336 .31839 L
.58338 .31839 L
.58339 .31839 L
.58342 .31839 L
.58345 .31839 L
.58348 .31839 L
.58354 .31838 L
.58359 .31837 L
.58372 .31835 L
.58383 .31831 L
.58396 .31827 L
.5842 .31815 L
Mistroke
.58443 .318 L
.58468 .31781 L
.58492 .31759 L
.58515 .31734 L
.5854 .31705 L
.58564 .31674 L
.58586 .31641 L
.58611 .31603 L
.58634 .31564 L
.58659 .31521 L
.58683 .31476 L
.58705 .31431 L
.5873 .31382 L
.58753 .31333 L
.58778 .31279 L
.58803 .31225 L
.58826 .31173 L
.5885 .31117 L
.58874 .31062 L
.58897 .31008 L
.58921 .30952 L
.58945 .30897 L
.58969 .30839 L
.58993 .30784 L
.59016 .30732 L
.59041 .30677 L
.59065 .30626 L
.59087 .30577 L
.59111 .30527 L
.59135 .30481 L
.59159 .30433 L
.59183 .3039 L
.59206 .3035 L
.59231 .3031 L
.59254 .30274 L
.59279 .30239 L
.59303 .30207 L
.59326 .3018 L
.59351 .30154 L
.59374 .30132 L
.59397 .30114 L
.59421 .30098 L
.59445 .30086 L
.59457 .30081 L
.5947 .30076 L
.59482 .30073 L
.59488 .30071 L
.59494 .3007 L
.59499 .30069 L
.59505 .30068 L
Mistroke
.59511 .30068 L
.59514 .30068 L
.59516 .30068 L
.59517 .30068 L
.59519 .30068 L
.59519 .30067 L
.5952 .30067 L
.59521 .30067 L
.59522 .30067 L
.59522 .30067 L
.59523 .30067 L
.59524 .30067 L
.59524 .30067 L
.59525 .30067 L
.59526 .30067 L
.59526 .30067 L
.59527 .30067 L
.59527 .30067 L
.59529 .30068 L
.5953 .30068 L
.59532 .30068 L
.59535 .30068 L
.59537 .30068 L
.5954 .30068 L
.59546 .30069 L
.59552 .3007 L
.59563 .30072 L
.59576 .30075 L
.59588 .30079 L
.59611 .30089 L
.59635 .30103 L
.59659 .30119 L
.59681 .30138 L
.59706 .30161 L
.59729 .30185 L
.59754 .30214 L
.59777 .30245 L
.598 .30277 L
.59825 .30313 L
.59848 .3035 L
.59873 .30391 L
.59897 .30433 L
.5992 .30475 L
.59945 .30521 L
.59968 .30567 L
.59991 .30612 L
.60015 .30661 L
.60039 .30709 L
.60063 .3076 L
.60087 .3081 L
Mistroke
.6011 .30858 L
.60135 .3091 L
.60158 .30959 L
.60181 .31006 L
.60205 .31055 L
.60228 .31101 L
.60253 .3115 L
.60277 .31196 L
.60299 .31238 L
.60324 .31282 L
.60347 .31323 L
.60372 .31364 L
.60396 .31401 L
.60419 .31435 L
.60444 .3147 L
.60467 .315 L
.6049 .31527 L
.60514 .31553 L
.60537 .31575 L
.60562 .31597 L
.60586 .31614 L
.60609 .31628 L
.60633 .3164 L
.60657 .31649 L
.6067 .31652 L
.60676 .31653 L
.60682 .31654 L
.60687 .31655 L
.60694 .31656 L
.60697 .31656 L
.607 .31657 L
.60702 .31657 L
.60705 .31657 L
.60706 .31657 L
.60708 .31657 L
.6071 .31657 L
.60711 .31657 L
.60712 .31657 L
.60712 .31657 L
.60713 .31657 L
.60713 .31657 L
.60714 .31657 L
.60714 .31657 L
.60715 .31657 L
.60715 .31657 L
.60716 .31657 L
.60716 .31657 L
.60717 .31657 L
.60718 .31657 L
.60719 .31657 L
Mistroke
.60721 .31657 L
.60723 .31657 L
.60727 .31657 L
.6073 .31657 L
.60736 .31656 L
.60741 .31655 L
.60754 .31653 L
.60766 .3165 L
.60777 .31647 L
.60801 .31638 L
.60824 .31626 L
.60849 .3161 L
.60873 .31593 L
.60896 .31573 L
.6092 .3155 L
.60943 .31525 L
.60968 .31496 L
.60992 .31465 L
.61015 .31434 L
.6104 .31399 L
.61063 .31363 L
.61086 .31328 L
.6111 .31288 L
.61133 .31248 L
.61158 .31205 L
.61182 .31162 L
.61205 .3112 L
.61229 .31074 L
.61253 .3103 L
.61278 .30982 L
.61302 .30936 L
.61325 .30892 L
.61349 .30845 L
.61373 .30801 L
.61396 .30758 L
.6142 .30714 L
.61443 .30672 L
.61468 .30628 L
.61492 .30588 L
.61515 .3055 L
.61539 .30511 L
.61563 .30476 L
.61586 .30443 L
.6161 .3041 L
.61633 .30381 L
.61658 .30352 L
.61681 .30326 L
.61704 .30303 L
.61729 .30282 L
.61752 .30264 L
Mistroke
.61777 .30247 L
.61801 .30234 L
.61824 .30223 L
.61836 .30219 L
.61848 .30215 L
.61861 .30212 L
.61872 .3021 L
.61878 .30209 L
.61884 .30209 L
.6189 .30208 L
.61893 .30208 L
.61895 .30208 L
.61896 .30208 L
.61898 .30208 L
.61899 .30208 L
.61901 .30207 L
.61902 .30207 L
.61902 .30207 L
.61903 .30207 L
.61903 .30207 L
.61904 .30207 L
.61905 .30207 L
.61906 .30207 L
.61906 .30207 L
.61907 .30207 L
.61907 .30207 L
.61908 .30207 L
.61909 .30207 L
.6191 .30208 L
.61911 .30208 L
.61914 .30208 L
.61917 .30208 L
.6192 .30208 L
.61926 .30209 L
.61932 .30209 L
.61943 .30211 L
.61955 .30214 L
.61966 .30217 L
.6199 .30225 L
.62013 .30235 L
.62037 .30249 L
.6206 .30265 L
.62085 .30284 L
.62109 .30305 L
.62132 .30328 L
.62156 .30354 L
.6218 .30381 L
.62205 .30412 L
.62229 .30444 L
.62252 .30476 L
Mistroke
.62277 .30512 L
.62301 .30548 L
.62323 .30584 L
.62348 .30623 L
.62371 .30662 L
.62396 .30704 L
.6242 .30745 L
.62443 .30786 L
.62467 .30829 L
.62491 .30871 L
.62514 .30911 L
.62538 .30953 L
.62561 .30994 L
.62586 .31037 L
.6261 .31077 L
.62633 .31115 L
.62657 .31155 L
.62681 .31192 L
.62706 .3123 L
.6273 .31265 L
.62753 .31298 L
.62777 .3133 L
.62801 .3136 L
.62824 .31387 L
.62848 .31413 L
.62871 .31437 L
.62896 .3146 L
.6292 .31479 L
.62943 .31496 L
.62968 .31511 L
.62991 .31523 L
.63014 .31533 L
.63026 .31537 L
.63038 .3154 L
.6305 .31543 L
.63061 .31545 L
.63067 .31546 L
.63073 .31546 L
.63079 .31547 L
.63082 .31547 L
.63085 .31547 L
.63088 .31547 L
.63089 .31547 L
.63091 .31547 L
.63092 .31547 L
.63092 .31547 L
.63093 .31547 L
.63094 .31547 L
.63094 .31547 L
.63095 .31547 L
Mistroke
.63095 .31547 L
.63095 .31547 L
.63096 .31547 L
.63097 .31547 L
.63097 .31547 L
.63098 .31547 L
.63098 .31547 L
.631 .31547 L
.63101 .31547 L
.63102 .31547 L
.63105 .31547 L
.63108 .31547 L
.63114 .31547 L
.6312 .31546 L
.63131 .31545 L
.63143 .31542 L
.63154 .3154 L
.63177 .31533 L
.63202 .31522 L
.63225 .3151 L
.63248 .31496 L
.63273 .31478 L
.63296 .31459 L
.63321 .31437 L
.63345 .31413 L
.63368 .31388 L
.63393 .3136 L
.63417 .31331 L
.63439 .31302 L
.63464 .31269 L
.63487 .31236 L
.63512 .312 L
.63536 .31164 L
.63559 .31128 L
.63583 .3109 L
.63607 .31052 L
.63629 .31015 L
.63653 .30975 L
.63676 .30937 L
.63701 .30896 L
.63725 .30857 L
.63748 .3082 L
.63772 .3078 L
.63795 .30743 L
.6382 .30704 L
.63844 .30668 L
.63867 .30633 L
.63892 .30598 L
.63916 .30565 L
.63938 .30535 L
Mistroke
.63962 .30505 L
.63986 .30477 L
.6401 .30449 L
.64034 .30425 L
.64057 .30403 L
.64082 .30381 L
.64105 .30363 L
.6413 .30345 L
.64154 .30331 L
.64177 .30319 L
.64202 .30309 L
.64214 .30305 L
.64226 .30302 L
.64237 .303 L
.64248 .30298 L
.64254 .30297 L
.64261 .30296 L
.64266 .30295 L
.64272 .30295 L
.64275 .30295 L
.64276 .30295 L
.64278 .30295 L
.64279 .30295 L
.6428 .30295 L
.64282 .30295 L
.64282 .30295 L
.64283 .30295 L
.64284 .30295 L
.64284 .30295 L
.64285 .30295 L
.64285 .30295 L
.64286 .30295 L
.64286 .30295 L
.64287 .30295 L
.64287 .30295 L
.64288 .30295 L
.64289 .30295 L
.64291 .30295 L
.64292 .30295 L
.64294 .30295 L
.64295 .30295 L
.64299 .30295 L
.64302 .30295 L
.64308 .30296 L
.64314 .30296 L
.6432 .30297 L
.64332 .30299 L
.64343 .30302 L
.64367 .30308 L
.64391 .30318 L
Mistroke
.64415 .3033 L
.64438 .30343 L
.64463 .30359 L
.64487 .30377 L
.64509 .30397 L
.64533 .30419 L
.64557 .30442 L
.64581 .30469 L
.64605 .30496 L
.64628 .30524 L
.64652 .30555 L
.64676 .30586 L
.64701 .3062 L
.64725 .30654 L
.64748 .30688 L
.64773 .30725 L
.64796 .30761 L
.64819 .30796 L
.64843 .30833 L
.64867 .3087 L
.64892 .30908 L
.64915 .30946 L
.64938 .30981 L
.64963 .31019 L
.64986 .31054 L
.65009 .31088 L
.65033 .31122 L
.65056 .31155 L
.65081 .31189 L
.65105 .3122 L
.65128 .31249 L
.65152 .31278 L
.65175 .31304 L
.652 .31331 L
.65224 .31354 L
.65247 .31375 L
.65272 .31396 L
.65296 .31413 L
.65318 .31428 L
.65343 .31442 L
.65366 .31454 L
.65391 .31463 L
.65403 .31467 L
.65414 .3147 L
.65426 .31473 L
.65437 .31475 L
.65443 .31476 L
.6545 .31476 L
.65455 .31477 L
.65461 .31477 L
Mistroke
.65464 .31478 L
.65467 .31478 L
.65468 .31478 L
.6547 .31478 L
.65471 .31478 L
.65472 .31478 L
.65473 .31478 L
.65474 .31478 L
.65474 .31478 L
.65475 .31478 L
.65475 .31478 L
.65476 .31478 L
.65476 .31478 L
.65476 .31478 L
.65477 .31478 L
.65477 .31478 L
.65478 .31478 L
.65479 .31478 L
.65479 .31478 L
.6548 .31478 L
.65481 .31478 L
.65483 .31478 L
.65485 .31478 L
.65489 .31478 L
.65492 .31477 L
.65497 .31477 L
.65503 .31476 L
.6551 .31476 L
.65522 .31474 L
.65534 .31471 L
.65557 .31465 L
.65581 .31456 L
.65604 .31445 L
.65629 .31432 L
.65652 .31417 L
.65675 .314 L
.657 .31381 L
.65723 .31361 L
.65748 .31337 L
.65772 .31312 L
.65795 .31287 L
.65819 .31259 L
.65843 .3123 L
.65866 .31202 L
.6589 .3117 L
.65913 .31139 L
.65938 .31105 L
.65962 .31071 L
.65985 .31038 L
.66009 .31002 L
Mistroke
.66033 .30967 L
.66058 .3093 L
.66082 .30894 L
.66105 .3086 L
.66129 .30824 L
.66153 .30789 L
.66176 .30757 L
.662 .30722 L
.66223 .3069 L
.66248 .30657 L
.66272 .30626 L
.66295 .30597 L
.6632 .30568 L
.66343 .30541 L
.66366 .30516 L
.6639 .30492 L
.66413 .3047 L
.66438 .30448 L
.66462 .30429 L
.66485 .30413 L
.66509 .30398 L
.66532 .30385 L
.66557 .30373 L
.66581 .30364 L
.66604 .30358 L
.66616 .30355 L
.66629 .30353 L
.66635 .30352 L
.66641 .30352 L
.66646 .30351 L
.66652 .30351 L
.66655 .30351 L
.66658 .3035 L
.66659 .3035 L
.66661 .3035 L
.66663 .3035 L
.66664 .3035 L
.66664 .3035 L
.66665 .3035 L
.66666 .3035 L
.66666 .3035 L
.66667 .3035 L
.66668 .3035 L
.66668 .3035 L
.66669 .3035 L
.66669 .3035 L
.6667 .3035 L
.66672 .3035 L
.66673 .3035 L
.66676 .3035 L
Mistroke
.66679 .30351 L
.66682 .30351 L
.66689 .30351 L
.66694 .30352 L
.667 .30352 L
.66712 .30354 L
.66723 .30356 L
.66747 .30363 L
.6677 .30371 L
.66795 .30381 L
.66819 .30394 L
.66841 .30408 L
.66866 .30424 L
.66889 .30442 L
.66914 .30463 L
.66938 .30485 L
.66961 .30507 L
.66985 .30533 L
.67009 .30559 L
.67031 .30585 L
.67055 .30614 L
.67078 .30643 L
.67103 .30675 L
.67127 .30706 L
.6715 .30737 L
.67174 .30771 L
.67198 .30804 L
.67222 .30839 L
.67246 .30873 L
.67269 .30906 L
.67294 .30941 L
.67318 .30975 L
.6734 .31007 L
.67365 .3104 L
.67388 .31072 L
.67413 .31105 L
.67436 .31136 L
.67459 .31164 L
.67484 .31194 L
.67507 .31221 L
.67532 .31248 L
.67556 .31274 L
.67579 .31296 L
.67604 .31319 L
.67628 .31339 L
.67651 .31356 L
.67675 .31373 L
.67698 .31387 L
.67723 .31401 L
.67747 .31411 L
Mistroke
.6777 .3142 L
.67782 .31423 L
.67794 .31426 L
.67807 .31429 L
.67818 .31431 L
.6783 .31432 L
.67836 .31433 L
.67839 .31433 L
.67842 .31433 L
.67845 .31433 L
.67848 .31433 L
.6785 .31433 L
.67851 .31434 L
.67852 .31434 L
.67853 .31434 L
.67854 .31434 L
.67855 .31434 L
.67855 .31434 L
.67856 .31434 L
.67857 .31434 L
.67857 .31434 L
.67858 .31434 L
.67859 .31434 L
.67859 .31434 L
.6786 .31434 L
.67861 .31434 L
.67862 .31434 L
.67864 .31434 L
.67865 .31433 L
.67868 .31433 L
.67871 .31433 L
.67877 .31433 L
.67883 .31432 L
.67888 .31432 L
.679 .3143 L
.67911 .31428 L
.67935 .31423 L
.67957 .31415 L
.67981 .31405 L
.68005 .31394 L
.68029 .3138 L
.68053 .31364 L
.68076 .31347 L
.68101 .31328 L
.68124 .31308 L
.68149 .31284 L
.68173 .3126 L
.68196 .31236 L
.68221 .31208 L
.68244 .31181 L
Mistroke
.68267 .31153 L
.68291 .31123 L
.68315 .31093 L
.6834 .3106 L
.68364 .31028 L
.68386 .30997 L
.68411 .30964 L
.68435 .30931 L
.68457 .309 L
.68481 .30867 L
.68505 .30835 L
.68529 .30801 L
.68553 .30769 L
.68576 .30739 L
.686 .30708 L
.68624 .30678 L
.68648 .30648 L
.68672 .3062 L
.68696 .30594 L
.6872 .30567 L
.68744 .30543 L
.68766 .30521 L
.68791 .305 L
.68814 .30481 L
.68839 .30462 L
.68863 .30446 L
.68886 .30432 L
.6891 .30419 L
.68933 .30408 L
.68958 .30399 L
.68971 .30396 L
.68983 .30393 L
.68994 .3039 L
.69006 .30388 L
.69017 .30387 L
.69023 .30386 L
.69029 .30386 L
.69032 .30385 L
.69036 .30385 L
.69037 .30385 L
.69039 .30385 L
.69041 .30385 L
.69042 .30385 L
.69044 .30385 L
.69044 .30385 L
.69045 .30385 L
.69046 .30385 L
.69046 .30385 L
.69046 .30385 L
.69047 .30385 L
Mistroke
.69048 .30385 L
.69048 .30385 L
.69048 .30385 L
.69049 .30385 L
.6905 .30385 L
.6905 .30385 L
.69051 .30385 L
.69053 .30385 L
.69054 .30385 L
.69057 .30385 L
.6906 .30385 L
.69066 .30386 L
.69072 .30386 L
.69078 .30387 L
.6909 .30388 L
.69102 .3039 L
.69127 .30396 L
.69151 .30404 L
.69173 .30413 L
.69198 .30425 L
.69221 .30438 L
.69246 .30454 L
.6927 .30471 L
.69293 .30489 L
.69318 .3051 L
.69341 .30532 L
.69364 .30554 L
.69388 .30579 L
.69411 .30604 L
.69436 .30633 L
.6946 .30661 L
.69483 .30689 L
.69507 .30719 L
.69531 .30749 L
.69556 .30782 L
.6958 .30813 L
.69603 .30844 L
.69628 .30878 L
.69651 .30909 L
.69674 .3094 L
.69698 .30973 L
.69722 .31004 L
.69747 .31036 L
.6977 .31067 L
.69793 .31096 L
.69818 .31126 L
.69842 .31153 L
.69864 .31179 L
.69888 .31206 L
.69912 .3123 L
Mistroke
.69936 .31254 L
.6996 .31277 L
.69983 .31296 L
.70007 .31316 L
.70031 .31333 L
.70056 .31349 L
.7008 .31363 L
.70103 .31375 L
.70127 .31386 L
.70151 .31394 L
.70174 .314 L
.70185 .31402 L
.70198 .31404 L
.70204 .31405 L
.70211 .31406 L
.70217 .31406 L
.70223 .31407 L
.70226 .31407 L
.70227 .31407 L
.70229 .31407 L
.7023 .31407 L
.70232 .31407 L
.70234 .31407 L
.70235 .31407 L
.70236 .31407 L
.70236 .31407 L
.70237 .31407 L
.70238 .31407 L
.70238 .31407 L
.70239 .31407 L
.7024 .31407 L
.7024 .31407 L
.70241 .31407 L
.70242 .31407 L
.70243 .31407 L
.70245 .31407 L
.70246 .31407 L
.70249 .31407 L
.70252 .31407 L
.70258 .31406 L
.70264 .31406 L
.70271 .31405 L
.70282 .31404 L
.70295 .31401 L
.70318 .31396 L
.70342 .31388 L
.70365 .31379 L
.7039 .31367 L
.70414 .31354 L
.70437 .31339 L
Mistroke
.70462 .31322 L
.70485 .31304 L
.70508 .31285 L
.70532 .31263 L
.70555 .31241 L
.7058 .31216 L
.70604 .3119 L
.70626 .31165 L
.70651 .31137 L
.70674 .31109 L
.70699 .31078 L
.70723 .31048 L
.70746 .31019 L
.70771 .30987 L
.70794 .30956 L
.70817 .30926 L
.70841 .30894 L
.70865 .30863 L
.70889 .3083 L
.70913 .30799 L
.70936 .3077 L
.7096 .30739 L
.70984 .3071 L
.71009 .3068 L
.71033 .30652 L
.71056 .30626 L
.71081 .306 L
.71104 .30576 L
.71127 .30554 L
.71152 .30532 L
.71175 .30512 L
.712 .30492 L
.71224 .30475 L
.71247 .3046 L
.71271 .30446 L
.71295 .30435 L
.71317 .30425 L
.71342 .30417 L
.71365 .30411 L
.71377 .30409 L
.7139 .30407 L
.71395 .30406 L
.71401 .30405 L
.71407 .30405 L
.71412 .30405 L
.71415 .30404 L
.71419 .30404 L
.7142 .30404 L
.71422 .30404 L
.71423 .30404 L
Mistroke
.71424 .30404 L
.71424 .30404 L
.71425 .30404 L
.71426 .30404 L
.71427 .30404 L
.71428 .30404 L
.71428 .30404 L
.71429 .30404 L
.71429 .30404 L
.7143 .30404 L
.7143 .30404 L
.71431 .30404 L
.71431 .30404 L
.71432 .30404 L
.71433 .30404 L
.71434 .30404 L
.71436 .30404 L
.71437 .30404 L
.7144 .30404 L
.71443 .30404 L
.71449 .30405 L
.71455 .30405 L
.71462 .30406 L
.71475 .30408 L
.71487 .3041 L
.7151 .30415 L
.71534 .30423 L
.71557 .30433 L
.71582 .30444 L
.71606 .30458 L
.7163 .30472 L
.71654 .3049 L
.71678 .30508 L
.71701 .30527 L
.71725 .30548 L
.71748 .30571 L
.71773 .30596 L
.71797 .30621 L
.7182 .30646 L
.71844 .30674 L
.71868 .30702 L
.71891 .3073 L
.71915 .3076 L
.71938 .30789 L
.71963 .30821 L
.71986 .30852 L
.72009 .30881 L
.72034 .30913 L
.72057 .30944 L
.72082 .30976 L
Mistroke
.72106 .31007 L
.72129 .31036 L
.72154 .31067 L
.72177 .31095 L
.722 .31122 L
.72224 .3115 L
.72248 .31176 L
.72272 .31202 L
.72296 .31226 L
.72319 .31248 L
.72344 .3127 L
.72367 .3129 L
.72392 .31309 L
.72416 .31326 L
.72439 .3134 L
.72464 .31354 L
.72488 .31365 L
.7251 .31375 L
.72535 .31383 L
.72558 .31388 L
.72571 .31391 L
.72583 .31392 L
.72589 .31393 L
.72595 .31394 L
.726 .31394 L
.72606 .31394 L
.72609 .31395 L
.72611 .31395 L
.72612 .31395 L
.72613 .31395 L
.72615 .31395 L
.72615 .31395 L
.72616 .31395 L
.72617 .31395 L
.72618 .31395 L
.72618 .31395 L
.72619 .31395 L
.7262 .31395 L
.7262 .31395 L
.7262 .31395 L
.72621 .31395 L
.72622 .31395 L
.72622 .31395 L
.72623 .31395 L
.72624 .31395 L
.72627 .31395 L
.72629 .31395 L
.7263 .31395 L
.72636 .31394 L
.72639 .31394 L
Mistroke
.72642 .31394 L
.72653 .31393 L
.72665 .31391 L
.72678 .31389 L
.72703 .31383 L
.72727 .31375 L
.7275 .31366 L
.72774 .31354 L
.72798 .31341 L
.7282 .31327 L
.72845 .3131 L
.72868 .31292 L
.72893 .31272 L
.72917 .3125 L
.72939 .31229 L
.72964 .31204 L
.72987 .3118 L
.73012 .31152 L
.73036 .31125 L
.7306 .31098 L
.73084 .31068 L
.73108 .31039 L
.73131 .3101 L
.73155 .30979 L
.73178 .30949 L
.73203 .30917 L
.73227 .30886 L
.7325 .30856 L
.73275 .30824 L
.73298 .30794 L
.73321 .30766 L
.73345 .30736 L
.73368 .30708 L
.73393 .30679 L
.73417 .30652 L
.7344 .30627 L
.73464 .30601 L
.73487 .30578 L
.73512 .30554 L
.73536 .30533 L
.73559 .30514 L
.73584 .30495 L
.73608 .30478 L
.7363 .30464 L
.73655 .30451 L
.73678 .3044 L
.73703 .3043 L
.73726 .30422 L
.73749 .30416 L
.73761 .30414 L
Mistroke
.73774 .30412 L
.7378 .30412 L
.73787 .30411 L
.7379 .30411 L
.73793 .30411 L
.73796 .3041 L
.73799 .3041 L
.738 .3041 L
.73802 .3041 L
.73803 .3041 L
.73805 .3041 L
.73806 .3041 L
.73807 .3041 L
.73808 .3041 L
.73808 .3041 L
.73809 .3041 L
.7381 .3041 L
.73811 .3041 L
.73811 .3041 L
.73812 .3041 L
.73813 .3041 L
.73813 .3041 L
.73815 .3041 L
.73816 .3041 L
.73819 .3041 L
.73822 .3041 L
.73828 .30411 L
.73833 .30411 L
.73839 .30412 L
.73845 .30412 L
.73858 .30414 L
.7387 .30416 L
.73893 .30422 L
.73918 .3043 L
.73941 .3044 L
.73964 .3045 L
.73988 .30464 L
.74011 .30478 L
.74036 .30495 L
.7406 .30513 L
.74082 .30532 L
.74107 .30554 L
.7413 .30576 L
.74155 .30601 L
.74179 .30626 L
.74202 .30651 L
.74227 .30679 L
.7425 .30707 L
.74273 .30735 L
.74297 .30765 L
Mistroke
.74321 .30794 L
.74345 .30825 L
.74369 .30856 L
.74392 .30886 L
.74417 .30918 L
.7444 .30948 L
.74465 .3098 L
.74489 .31011 L
.74512 .3104 L
.74537 .3107 L
.74561 .31099 L
.74583 .31126 L
.74608 .31153 L
.74631 .31179 L
.74656 .31205 L
.7468 .31229 L
.74703 .31251 L
.74727 .31273 L
.74751 .31292 L
.74774 .31309 L
.74798 .31326 L
.74821 .31341 L
.74846 .31354 L
.7487 .31366 L
.74892 .31375 L
.74917 .31383 L
.7494 .31389 L
.74953 .31391 L
.74965 .31393 L
.74971 .31393 L
.74977 .31394 L
.74983 .31394 L
.74985 .31394 L
.74988 .31394 L
.7499 .31395 L
.74991 .31395 L
.74993 .31395 L
.74994 .31395 L
.74996 .31395 L
.74997 .31395 L
.74998 .31395 L
.74999 .31395 L
.74999 .31395 L
.75 .31395 L
.75001 .31395 L
.75002 .31395 L
.75002 .31395 L
.75002 .31395 L
.75003 .31395 L
.75005 .31395 L
Mistroke
.75006 .31395 L
.75008 .31395 L
.75009 .31395 L
.75013 .31394 L
.75016 .31394 L
.75019 .31394 L
.75024 .31394 L
.75037 .31392 L
.75049 .31391 L
.7506 .31389 L
.75083 .31383 L
.75108 .31375 L
.75132 .31365 L
.75155 .31354 L
.7518 .3134 L
.75204 .31325 L
.75226 .31309 L
.75251 .31291 L
.75274 .31271 L
.75299 .31249 L
.75323 .31226 L
.75346 .31203 L
.7537 .31177 L
.75394 .31151 L
.75416 .31125 L
.75441 .31097 L
.75464 .31069 L
.75488 .31038 L
.75512 .31008 L
.75535 .30978 L
.75559 .30947 L
.75583 .30916 L
.75608 .30884 L
.75632 .30852 L
.75655 .30823 L
.75679 .30791 L
.75703 .30761 L
.75726 .30733 L
.7575 .30703 L
.75773 .30676 L
.75798 .30647 L
.75822 .30621 L
.75845 .30597 L
.75869 .30572 L
.75893 .3055 L
.75918 .30527 L
.75942 .30507 L
.75965 .30489 L
.7599 .30472 L
.76014 .30457 L
Mistroke
.76036 .30445 L
.76061 .30433 L
.76084 .30424 L
.76109 .30416 L
.76121 .30412 L
.76133 .3041 L
.76145 .30408 L
.76156 .30406 L
.76167 .30405 L
.76173 .30405 L
.76176 .30404 L
.76179 .30404 L
.76182 .30404 L
.76184 .30404 L
.76185 .30404 L
.76187 .30404 L
.76187 .30404 L
.76188 .30404 L
.76189 .30404 L
.76189 .30404 L
.7619 .30404 L
.76191 .30404 L
.76192 .30404 L
.76192 .30404 L
.76192 .30404 L
.76193 .30404 L
.76194 .30404 L
.76195 .30404 L
.76197 .30404 L
.76198 .30404 L
.762 .30404 L
.76203 .30404 L
.76209 .30405 L
.76215 .30405 L
.76222 .30406 L
.76228 .30407 L
.7624 .30408 L
.76251 .3041 L
.76275 .30417 L
.76298 .30424 L
.76323 .30434 L
.76347 .30446 L
.76369 .30459 L
.76393 .30474 L
.76417 .3049 L
.76442 .3051 L
.76465 .3053 L
.76488 .3055 L
.76513 .30574 L
.76536 .30598 L
Mistroke
.76561 .30625 L
.76585 .30651 L
.76608 .30678 L
.76633 .30708 L
.76657 .30737 L
.7668 .30766 L
.76704 .30797 L
.76727 .30827 L
.76752 .3086 L
.76776 .30891 L
.76799 .30922 L
.76823 .30954 L
.76847 .30985 L
.7687 .31014 L
.76894 .31045 L
.76917 .31075 L
.76942 .31105 L
.76966 .31134 L
.76988 .3116 L
.77013 .31187 L
.77036 .31213 L
.77061 .31238 L
.77085 .31261 L
.77108 .31282 L
.77133 .31303 L
.77157 .31321 L
.77179 .31337 L
.77203 .31353 L
.77227 .31366 L
.77252 .31378 L
.77275 .31388 L
.77298 .31395 L
.77311 .31399 L
.77323 .31401 L
.77335 .31403 L
.77346 .31405 L
.77352 .31406 L
.77358 .31406 L
.77364 .31407 L
.77367 .31407 L
.7737 .31407 L
.77374 .31407 L
.77375 .31407 L
.77376 .31407 L
.77377 .31407 L
.77378 .31407 L
.77378 .31407 L
.77379 .31407 L
.7738 .31407 L
.7738 .31407 L
Mistroke
.77381 .31407 L
.77381 .31407 L
.77382 .31407 L
.77383 .31407 L
.77383 .31407 L
.77384 .31407 L
.77386 .31407 L
.77387 .31407 L
.77389 .31407 L
.77391 .31407 L
.77394 .31407 L
.774 .31406 L
.77406 .31406 L
.77418 .31405 L
.7743 .31403 L
.77442 .31401 L
.77467 .31394 L
.7749 .31386 L
.77513 .31377 L
.77537 .31365 L
.7756 .31352 L
.77585 .31336 L
.77609 .31318 L
.77631 .313 L
.77656 .3128 L
.77679 .31258 L
.77704 .31234 L
.77728 .31209 L
.77751 .31184 L
.77776 .31156 L
.77799 .31128 L
.77822 .311 L
.77846 .3107 L
.7787 .3104 L
.77894 .31008 L
.77918 .30976 L
.77941 .30945 L
.77966 .30912 L
.77989 .30881 L
.78014 .30847 L
.78038 .30815 L
.78061 .30784 L
.78086 .30752 L
.7811 .30722 L
.78132 .30693 L
.78157 .30663 L
.7818 .30636 L
.78205 .30607 L
.78229 .30581 L
.78252 .30557 L
Mistroke
.78276 .30533 L
.783 .30512 L
.78323 .30492 L
.78347 .30473 L
.7837 .30456 L
.78395 .3044 L
.78419 .30426 L
.78442 .30415 L
.78466 .30405 L
.78489 .30397 L
.78501 .30394 L
.78514 .30391 L
.78526 .30389 L
.78532 .30388 L
.78538 .30387 L
.78545 .30386 L
.7855 .30386 L
.78556 .30385 L
.7856 .30385 L
.78563 .30385 L
.78564 .30385 L
.78566 .30385 L
.78566 .30385 L
.78567 .30385 L
.78568 .30385 L
.78569 .30385 L
.78569 .30385 L
.7857 .30385 L
.78571 .30385 L
.78571 .30385 L
.78572 .30385 L
.78572 .30385 L
.78573 .30385 L
.78574 .30385 L
.78574 .30385 L
.78575 .30385 L
.78576 .30385 L
.78578 .30385 L
.78581 .30385 L
.78583 .30385 L
.78586 .30385 L
.78592 .30386 L
.78598 .30386 L
.78609 .30387 L
.78622 .3039 L
.78634 .30392 L
.78657 .30398 L
.78682 .30407 L
.78705 .30417 L
.78728 .30429 L
Mistroke
.78752 .30443 L
.78776 .30458 L
.788 .30477 L
.78824 .30496 L
.78847 .30517 L
.78872 .3054 L
.78895 .30564 L
.78918 .30588 L
.78942 .30615 L
.78965 .30642 L
.7899 .30672 L
.79014 .30701 L
.79037 .30731 L
.79061 .30763 L
.79085 .30794 L
.7911 .30828 L
.79134 .30861 L
.79157 .30893 L
.79181 .30927 L
.79205 .30959 L
.79228 .3099 L
.79252 .31023 L
.79275 .31055 L
.793 .31087 L
.79324 .31118 L
.79347 .31147 L
.79371 .31177 L
.79395 .31204 L
.7942 .31232 L
.79444 .31258 L
.79467 .31281 L
.79492 .31304 L
.79515 .31325 L
.79538 .31344 L
.79562 .31362 L
.79586 .31377 L
.79611 .31392 L
.79635 .31404 L
.79658 .31414 L
.79682 .31422 L
.79694 .31425 L
.79706 .31428 L
.79717 .3143 L
.79728 .31432 L
.79734 .31432 L
.79741 .31433 L
.79743 .31433 L
.79746 .31433 L
.79749 .31433 L
.79752 .31433 L
Mistroke
.79753 .31433 L
.79755 .31434 L
.79756 .31434 L
.79758 .31434 L
.79759 .31434 L
.7976 .31434 L
.7976 .31434 L
.79761 .31434 L
.79761 .31434 L
.79762 .31434 L
.79762 .31434 L
.79762 .31434 L
.79763 .31434 L
.79763 .31434 L
.79764 .31434 L
.79765 .31434 L
.79765 .31434 L
.79766 .31434 L
.79768 .31434 L
.79769 .31433 L
.7977 .31433 L
.79773 .31433 L
.79777 .31433 L
.79782 .31433 L
.79789 .31432 L
.79801 .31431 L
.79813 .31429 L
.79825 .31426 L
.7985 .31419 L
.79874 .3141 L
.79897 .314 L
.79921 .31387 L
.79945 .31373 L
.7997 .31355 L
.79994 .31336 L
.80017 .31317 L
.80042 .31294 L
.80065 .31271 L
.80088 .31247 L
.80113 .3122 L
.80136 .31193 L
.80161 .31163 L
.80185 .31133 L
.80208 .31103 L
.80232 .31071 L
.80256 .31038 L
.80278 .31007 L
.80303 .30973 L
.80326 .3094 L
.80351 .30905 L
Mistroke
.80374 .30871 L
.80397 .30838 L
.80422 .30804 L
.80445 .30771 L
.8047 .30736 L
.80494 .30704 L
.80517 .30673 L
.80542 .30641 L
.80565 .30612 L
.80588 .30584 L
.80612 .30556 L
.80636 .30531 L
.8066 .30505 L
.80684 .30482 L
.80707 .30461 L
.80732 .30441 L
.80755 .30423 L
.8078 .30406 L
.80804 .30392 L
.80828 .3038 L
.80852 .30369 L
.80876 .30361 L
.80899 .30356 L
.80911 .30354 L
.80923 .30352 L
.80929 .30351 L
.80932 .30351 L
.80936 .30351 L
.80939 .30351 L
.80942 .3035 L
.80944 .3035 L
.80945 .3035 L
.80947 .3035 L
.80948 .3035 L
.80949 .3035 L
.80949 .3035 L
.8095 .3035 L
.8095 .3035 L
.80951 .3035 L
.80952 .3035 L
.80953 .3035 L
.80953 .3035 L
.80954 .3035 L
.80954 .3035 L
.80955 .3035 L
.80956 .3035 L
.80957 .3035 L
.80959 .3035 L
.80961 .3035 L
.80963 .3035 L
Mistroke
.80966 .30351 L
.80973 .30351 L
.80979 .30352 L
.80984 .30352 L
.80997 .30354 L
.81008 .30356 L
.81021 .30359 L
.81045 .30367 L
.81068 .30376 L
.81093 .30388 L
.81117 .30402 L
.8114 .30417 L
.81165 .30435 L
.81189 .30455 L
.81211 .30475 L
.81235 .30498 L
.81259 .30522 L
.81284 .30549 L
.81307 .30577 L
.8133 .30605 L
.81355 .30636 L
.81378 .30667 L
.81403 .30701 L
.81427 .30734 L
.81451 .30767 L
.81475 .30803 L
.81499 .30837 L
.81522 .30871 L
.81546 .30907 L
.81569 .30942 L
.81594 .30979 L
.81618 .31014 L
.81641 .31048 L
.81666 .31083 L
.81689 .31116 L
.81712 .31147 L
.81736 .3118 L
.81759 .3121 L
.81784 .3124 L
.81808 .31269 L
.81831 .31295 L
.81855 .31321 L
.81879 .31344 L
.81904 .31367 L
.81928 .31388 L
.81951 .31406 L
.81975 .31423 L
.81999 .31437 L
.82022 .31449 L
.82046 .31459 L
Mistroke
.82069 .31467 L
.82081 .3147 L
.82094 .31473 L
.82107 .31475 L
.82113 .31476 L
.82118 .31477 L
.82123 .31477 L
.82129 .31478 L
.82132 .31478 L
.82134 .31478 L
.82136 .31478 L
.82137 .31478 L
.82139 .31478 L
.82139 .31478 L
.8214 .31478 L
.8214 .31478 L
.82141 .31478 L
.82142 .31478 L
.82142 .31478 L
.82143 .31478 L
.82144 .31478 L
.82144 .31478 L
.82145 .31478 L
.82146 .31478 L
.82147 .31478 L
.82149 .31478 L
.8215 .31478 L
.82153 .31478 L
.82156 .31478 L
.82159 .31477 L
.82165 .31477 L
.82171 .31476 L
.82177 .31476 L
.82189 .31474 L
.82201 .31471 L
.82212 .31468 L
.82236 .3146 L
.82259 .31451 L
.82284 .31438 L
.82307 .31424 L
.8233 .31409 L
.82354 .3139 L
.82377 .3137 L
.82402 .31347 L
.82426 .31323 L
.82449 .31298 L
.82473 .31271 L
.82497 .31242 L
.82521 .3121 L
.82545 .31179 L
Mistroke
.82569 .31147 L
.82593 .31112 L
.82617 .31078 L
.8264 .31044 L
.82664 .31007 L
.82687 .30971 L
.82712 .30933 L
.82736 .30896 L
.82759 .3086 L
.82783 .30822 L
.82807 .30785 L
.82832 .30747 L
.82856 .30711 L
.82879 .30676 L
.82904 .30641 L
.82927 .30607 L
.8295 .30576 L
.82974 .30545 L
.82998 .30515 L
.83023 .30486 L
.83047 .30459 L
.8307 .30435 L
.83094 .30411 L
.83118 .3039 L
.83141 .30371 L
.83165 .30353 L
.83188 .30339 L
.83213 .30325 L
.83237 .30314 L
.83259 .30306 L
.83272 .30302 L
.83284 .303 L
.83296 .30298 L
.83307 .30296 L
.83313 .30295 L
.83316 .30295 L
.83319 .30295 L
.83322 .30295 L
.83325 .30295 L
.83327 .30295 L
.83329 .30295 L
.8333 .30295 L
.8333 .30295 L
.83331 .30295 L
.83332 .30295 L
.83332 .30295 L
.83333 .30295 L
.83334 .30295 L
.83335 .30295 L
.83335 .30295 L
Mistroke
.83336 .30295 L
.83336 .30295 L
.83338 .30295 L
.83339 .30295 L
.83339 .30295 L
.83342 .30295 L
.83345 .30295 L
.83348 .30295 L
.83353 .30295 L
.8336 .30296 L
.83365 .30297 L
.83378 .30299 L
.83389 .30301 L
.83401 .30304 L
.83426 .30313 L
.83449 .30323 L
.83474 .30336 L
.83498 .30352 L
.83522 .30368 L
.83546 .30389 L
.8357 .3041 L
.83593 .30433 L
.83617 .30459 L
.8364 .30485 L
.83665 .30516 L
.83689 .30546 L
.83712 .30577 L
.83737 .30612 L
.8376 .30646 L
.83783 .3068 L
.83807 .30717 L
.8383 .30754 L
.83855 .30794 L
.83879 .30832 L
.83902 .3087 L
.83926 .3091 L
.8395 .30949 L
.83975 .3099 L
.83999 .31029 L
.84022 .31067 L
.84046 .31106 L
.8407 .31143 L
.84093 .31178 L
.84117 .31214 L
.8414 .31248 L
.84165 .31282 L
.84189 .31314 L
.84212 .31343 L
.84236 .31372 L
.8426 .31398 L
Mistroke
.84283 .31422 L
.84307 .31445 L
.8433 .31465 L
.84354 .31484 L
.84378 .31501 L
.84401 .31514 L
.84425 .31526 L
.84449 .31535 L
.84461 .31539 L
.84474 .31542 L
.84486 .31544 L
.84492 .31545 L
.84498 .31546 L
.84503 .31547 L
.84509 .31547 L
.84512 .31547 L
.84515 .31547 L
.84516 .31547 L
.84518 .31547 L
.84519 .31547 L
.8452 .31547 L
.8452 .31547 L
.84521 .31547 L
.84522 .31547 L
.84523 .31547 L
.84523 .31547 L
.84523 .31547 L
.84524 .31547 L
.84525 .31547 L
.84526 .31547 L
.84526 .31547 L
.84527 .31547 L
.84529 .31547 L
.8453 .31547 L
.84533 .31547 L
.84536 .31547 L
.84539 .31547 L
.84545 .31546 L
.84551 .31546 L
.84557 .31545 L
.84569 .31543 L
.84581 .3154 L
.84593 .31537 L
.84617 .31528 L
.8464 .31517 L
.84664 .31503 L
.84688 .31487 L
.84711 .3147 L
.84735 .31449 L
.84758 .31427 L
Mistroke
.84783 .31401 L
.84807 .31374 L
.8483 .31346 L
.84854 .31314 L
.84878 .31282 L
.84903 .31246 L
.84927 .3121 L
.8495 .31174 L
.84975 .31135 L
.84998 .31095 L
.85021 .31057 L
.85045 .31015 L
.85069 .30975 L
.85094 .30931 L
.85118 .30889 L
.85141 .30848 L
.85165 .30805 L
.85189 .30764 L
.85211 .30724 L
.85236 .30683 L
.85259 .30644 L
.85284 .30603 L
.85307 .30565 L
.8533 .3053 L
.85355 .30493 L
.85378 .3046 L
.85403 .30426 L
.85427 .30396 L
.8545 .30368 L
.85475 .3034 L
.85498 .30316 L
.85521 .30295 L
.85545 .30275 L
.85569 .30258 L
.85594 .30242 L
.85618 .3023 L
.85641 .30221 L
.85652 .30217 L
.85665 .30213 L
.85677 .30211 L
.85689 .30209 L
.85694 .30208 L
.85698 .30208 L
.85701 .30208 L
.85703 .30208 L
.85706 .30208 L
.85707 .30208 L
.85709 .30208 L
.8571 .30208 L
.8571 .30207 L
Mistroke
.85711 .30207 L
.85712 .30207 L
.85712 .30207 L
.85713 .30207 L
.85714 .30207 L
.85715 .30207 L
.85715 .30207 L
.85716 .30207 L
.85716 .30207 L
.85717 .30207 L
.85718 .30207 L
.85719 .30208 L
.8572 .30208 L
.85723 .30208 L
.85726 .30208 L
.85729 .30208 L
.85735 .30209 L
.85742 .30209 L
.85748 .3021 L
.85759 .30212 L
.85771 .30215 L
.85782 .30218 L
.85805 .30228 L
.85828 .30239 L
.85852 .30253 L
.85875 .3027 L
.859 .3029 L
.85924 .30312 L
.85947 .30336 L
.85971 .30363 L
.85995 .30391 L
.86019 .30424 L
.86044 .30457 L
.86067 .30491 L
.86091 .30529 L
.86115 .30567 L
.86138 .30605 L
.86162 .30647 L
.86185 .30689 L
.8621 .30734 L
.86234 .30778 L
.86257 .30821 L
.86281 .30867 L
.86305 .30912 L
.8633 .3096 L
.86354 .31006 L
.86377 .3105 L
.86402 .31096 L
.86425 .3114 L
.86448 .31182 L
Mistroke
.86473 .31225 L
.86496 .31266 L
.86521 .31307 L
.86545 .31346 L
.86568 .31382 L
.86592 .31418 L
.86616 .31451 L
.86639 .3148 L
.86663 .3151 L
.86686 .31536 L
.86711 .31561 L
.86735 .31583 L
.86758 .31601 L
.86782 .31618 L
.86805 .31632 L
.8683 .31643 L
.86843 .31647 L
.86854 .31651 L
.86866 .31653 L
.86871 .31654 L
.86878 .31655 L
.86884 .31656 L
.86889 .31657 L
.86892 .31657 L
.86895 .31657 L
.86896 .31657 L
.86898 .31657 L
.86899 .31657 L
.869 .31657 L
.86901 .31657 L
.86902 .31657 L
.86903 .31657 L
.86903 .31657 L
.86904 .31657 L
.86905 .31657 L
.86905 .31657 L
.86906 .31657 L
.86907 .31657 L
.86907 .31657 L
.86908 .31657 L
.86908 .31657 L
.86909 .31657 L
.86911 .31657 L
.86912 .31657 L
.86915 .31657 L
.86918 .31657 L
.86923 .31656 L
.86929 .31656 L
.86935 .31655 L
.86947 .31652 L
Mistroke
.86959 .31649 L
.86972 .31645 L
.86996 .31635 L
.8702 .31622 L
.87043 .31607 L
.87067 .31588 L
.8709 .31567 L
.87115 .31542 L
.87139 .31515 L
.87162 .31487 L
.87187 .31454 L
.8721 .3142 L
.87233 .31386 L
.87257 .31347 L
.8728 .31308 L
.87305 .31264 L
.87329 .31221 L
.87352 .31178 L
.87376 .3113 L
.874 .31084 L
.87425 .31033 L
.87449 .30984 L
.87472 .30936 L
.87496 .30885 L
.8752 .30835 L
.87543 .30787 L
.87567 .30737 L
.8759 .30689 L
.87615 .30638 L
.87639 .3059 L
.87662 .30545 L
.87686 .30499 L
.8771 .30455 L
.87733 .30415 L
.87757 .30374 L
.8778 .30336 L
.87805 .30298 L
.87828 .30263 L
.87851 .30233 L
.87875 .30202 L
.87899 .30176 L
.87924 .30151 L
.87948 .30129 L
.87971 .30112 L
.87995 .30096 L
.88019 .30084 L
.88042 .30076 L
.88053 .30073 L
.88066 .3007 L
.88072 .30069 L
Mistroke
.88075 .30069 L
.88079 .30068 L
.88082 .30068 L
.88085 .30068 L
.88086 .30068 L
.88088 .30068 L
.88089 .30068 L
.88091 .30067 L
.88092 .30067 L
.88093 .30067 L
.88094 .30067 L
.88094 .30067 L
.88095 .30067 L
.88096 .30067 L
.88096 .30067 L
.88097 .30067 L
.88097 .30067 L
.88098 .30067 L
.88099 .30067 L
.881 .30067 L
.88101 .30068 L
.88103 .30068 L
.88106 .30068 L
.88109 .30068 L
.88115 .30069 L
.88121 .30069 L
.88128 .30071 L
.8814 .30073 L
.88152 .30077 L
.88165 .30082 L
.88187 .30092 L
.88212 .30107 L
.88235 .30124 L
.8826 .30146 L
.88284 .3017 L
.88307 .30196 L
.88331 .30227 L
.88355 .30259 L
.8838 .30296 L
.88404 .30335 L
.88427 .30374 L
.88451 .30418 L
.88475 .30463 L
.88498 .30508 L
.88522 .30557 L
.88546 .30607 L
.88571 .30661 L
.88595 .30714 L
.88618 .30766 L
.88642 .30822 L
Mistroke
.88666 .30877 L
.88688 .3093 L
.88713 .30986 L
.88736 .3104 L
.88761 .31098 L
.88784 .31153 L
.88807 .31205 L
.88832 .31259 L
.88855 .3131 L
.8888 .31363 L
.88904 .31412 L
.88927 .31458 L
.88952 .31505 L
.88976 .31548 L
.88998 .31586 L
.89023 .31625 L
.89046 .3166 L
.89071 .31694 L
.89095 .31724 L
.89118 .31749 L
.89142 .31773 L
.89166 .31793 L
.89188 .31809 L
.89212 .31822 L
.89236 .31831 L
.89248 .31835 L
.89254 .31836 L
.8926 .31837 L
.89266 .31838 L
.89272 .31839 L
.89275 .31839 L
.89276 .31839 L
.89278 .31839 L
.89279 .31839 L
.89281 .31839 L
.89282 .31839 L
.89283 .31839 L
.89283 .31839 L
.89284 .31839 L
.89284 .31839 L
.89285 .31839 L
.89285 .31839 L
.89286 .31839 L
.89287 .31839 L
.89287 .31839 L
.89287 .31839 L
.89288 .31839 L
.89289 .31839 L
.89289 .31839 L
.89291 .31839 L
Mistroke
.89292 .31839 L
.89295 .31839 L
.89298 .31839 L
.89301 .31839 L
.89306 .31838 L
.89312 .31837 L
.89318 .31836 L
.8933 .31833 L
.89342 .31829 L
.89353 .31824 L
.89377 .31812 L
.894 .31797 L
.89424 .31776 L
.89448 .31754 L
.89473 .31726 L
.89497 .31695 L
.8952 .31662 L
.89544 .31624 L
.89568 .31585 L
.89591 .31544 L
.89615 .31498 L
.89638 .31451 L
.89663 .31398 L
.89687 .31345 L
.8971 .31292 L
.89734 .31234 L
.89758 .31176 L
.89781 .31119 L
.89805 .31058 L
.89828 .30997 L
.89853 .30933 L
.89876 .3087 L
.89899 .30809 L
.89923 .30744 L
.89947 .30683 L
.89972 .30617 L
.89996 .30555 L
.90019 .30496 L
.90043 .30435 L
.90067 .30378 L
.9009 .30324 L
.90114 .30269 L
.90137 .30218 L
.90162 .30167 L
.90186 .3012 L
.90209 .30077 L
.90233 .30035 L
.90256 .29998 L
.90281 .29962 L
.90305 .29931 L
Mistroke
.90329 .29904 L
.90353 .2988 L
.90377 .29861 L
.904 .29846 L
.90412 .29839 L
.90424 .29834 L
.90436 .2983 L
.90447 .29827 L
.90453 .29826 L
.90459 .29825 L
.90464 .29825 L
.90467 .29824 L
.9047 .29824 L
.90472 .29824 L
.90473 .29824 L
.90474 .29824 L
.90475 .29824 L
.90475 .29824 L
.90475 .29824 L
.90476 .29824 L
.90477 .29824 L
.90477 .29824 L
.90478 .29824 L
.90478 .29824 L
.90479 .29824 L
.90479 .29824 L
.9048 .29824 L
.90481 .29824 L
.90482 .29824 L
.90485 .29824 L
.90488 .29825 L
.90494 .29825 L
.905 .29826 L
.90506 .29828 L
.90518 .29831 L
.9053 .29835 L
.90543 .29841 L
.90566 .29855 L
.9059 .29873 L
.90614 .29895 L
.90638 .29923 L
.90662 .29954 L
.90685 .29988 L
.9071 .30028 L
.90734 .3007 L
.90756 .30114 L
.9078 .30164 L
.90804 .30215 L
.90828 .30273 L
.90852 .30331 L
Mistroke
.90875 .3039 L
.90899 .30455 L
.90923 .3052 L
.90948 .30591 L
.90972 .30661 L
.90995 .3073 L
.9102 .30805 L
.91043 .30877 L
.91066 .30948 L
.9109 .31023 L
.91114 .31095 L
.91138 .31172 L
.91162 .31245 L
.91185 .31315 L
.9121 .31388 L
.91233 .31457 L
.91256 .31521 L
.9128 .31588 L
.91303 .3165 L
.91328 .31713 L
.91352 .31772 L
.91375 .31825 L
.91399 .31878 L
.91422 .31926 L
.91447 .31972 L
.91471 .32013 L
.91494 .32049 L
.91519 .32082 L
.91542 .3211 L
.91565 .32132 L
.91589 .32151 L
.91613 .32164 L
.91625 .3217 L
.91631 .32172 L
.91637 .32173 L
.91644 .32175 L
.91649 .32176 L
.91652 .32176 L
.91655 .32177 L
.91658 .32177 L
.9166 .32177 L
.91662 .32177 L
.91663 .32177 L
.91664 .32177 L
.91664 .32177 L
.91665 .32177 L
.91665 .32177 L
.91666 .32177 L
.91667 .32177 L
.91667 .32177 L
Mistroke
.91668 .32177 L
.91669 .32177 L
.91669 .32177 L
.9167 .32177 L
.91672 .32177 L
.91673 .32177 L
.91675 .32177 L
.91678 .32177 L
.91681 .32176 L
.91684 .32176 L
.9169 .32175 L
.91696 .32173 L
.91707 .3217 L
.91719 .32165 L
.9173 .32159 L
.91753 .32144 L
.91778 .32121 L
.91802 .32095 L
.91825 .32065 L
.91849 .32028 L
.91873 .31988 L
.91898 .3194 L
.91922 .31889 L
.91945 .31836 L
.9197 .31775 L
.91993 .31712 L
.92016 .31648 L
.92041 .31577 L
.92064 .31505 L
.92089 .31426 L
.92113 .31346 L
.92136 .31267 L
.9216 .31181 L
.92184 .31096 L
.92207 .31014 L
.92231 .30924 L
.92254 .30837 L
.92279 .30745 L
.92303 .30655 L
.92326 .30569 L
.9235 .30478 L
.92373 .30392 L
.92398 .30301 L
.92422 .30216 L
.92446 .30135 L
.9247 .30052 L
.92494 .29975 L
.92517 .29903 L
.92541 .29831 L
.92564 .29764 L
Mistroke
.92589 .29698 L
.92613 .29638 L
.92636 .29585 L
.9266 .29533 L
.92684 .29488 L
.92707 .2945 L
.92731 .29415 L
.92754 .29387 L
.92779 .29362 L
.92791 .29353 L
.92802 .29345 L
.92814 .29339 L
.92825 .29334 L
.92831 .29332 L
.92838 .29331 L
.9284 .2933 L
.92843 .2933 L
.92846 .29329 L
.92849 .29329 L
.9285 .29329 L
.92852 .29329 L
.92853 .29329 L
.92854 .29329 L
.92854 .29329 L
.92855 .29329 L
.92855 .29329 L
.92856 .29329 L
.92857 .29329 L
.92857 .29329 L
.92858 .29329 L
.92859 .29329 L
.9286 .29329 L
.9286 .29329 L
.92862 .29329 L
.92863 .29329 L
.92866 .29329 L
.92869 .29329 L
.92871 .2933 L
.92877 .29331 L
.92883 .29332 L
.92895 .29337 L
.92907 .29343 L
.92918 .2935 L
.92942 .29369 L
.92965 .29394 L
.92989 .29426 L
.93013 .29464 L
.93038 .2951 L
.93062 .29562 L
.93085 .29616 L
Mistroke
.93109 .29681 L
.93133 .29748 L
.93156 .29818 L
.9318 .29897 L
.93203 .29979 L
.93228 .3007 L
.93252 .30162 L
.93275 .30254 L
.933 .30356 L
.93323 .30458 L
.93346 .30558 L
.9337 .30667 L
.93393 .30774 L
.93418 .3089 L
.93441 .31003 L
.93464 .31112 L
.93489 .31229 L
.93512 .31341 L
.93537 .3146 L
.93561 .31573 L
.93584 .31681 L
.93608 .31794 L
.93632 .319 L
.93655 .32 L
.93679 .32102 L
.93702 .32198 L
.93727 .32295 L
.93751 .32384 L
.93774 .32464 L
.93798 .32545 L
.93822 .32617 L
.93847 .32687 L
.93871 .32748 L
.93894 .328 L
.93918 .32848 L
.93942 .32887 L
.93965 .32917 L
.93978 .32931 L
.93989 .32942 L
.94001 .32951 L
.94013 .32957 L
.94024 .32962 L
.9403 .32964 L
.94033 .32965 L
.94036 .32965 L
.94039 .32966 L
.94041 .32966 L
.94042 .32966 L
.94044 .32966 L
.94045 .32966 L
Mistroke
.94045 .32966 L
.94046 .32966 L
.94047 .32966 L
.94047 .32966 L
.94048 .32966 L
.94049 .32966 L
.9405 .32966 L
.9405 .32966 L
.94051 .32966 L
.94053 .32966 L
.94054 .32966 L
.94057 .32966 L
.94061 .32965 L
.94064 .32964 L
.94067 .32964 L
.94072 .32962 L
.94085 .32956 L
.94097 .32948 L
.94108 .32939 L
.94132 .32914 L
.94155 .32881 L
.94179 .32838 L
.94202 .32788 L
.94227 .32726 L
.94251 .32658 L
.94274 .32585 L
.94299 .32499 L
.94322 .32408 L
.94345 .32315 L
.94369 .32208 L
.94392 .32098 L
.94417 .31974 L
.94441 .31849 L
.94464 .31724 L
.94488 .31585 L
.94512 .31446 L
.94537 .31294 L
.94561 .31144 L
.94584 .30996 L
.94608 .30836 L
.94632 .3068 L
.94655 .30529 L
.94679 .30367 L
.94703 .3021 L
.94727 .30044 L
.94751 .29885 L
.94774 .29734 L
.94799 .29575 L
.94822 .29425 L
.94845 .29284 L
Mistroke
.94869 .29138 L
.94892 .29003 L
.94917 .28864 L
.94941 .28737 L
.94963 .28621 L
.94988 .28505 L
.95011 .28401 L
.95036 .28299 L
.9506 .2821 L
.95083 .28134 L
.95108 .28064 L
.95131 .28006 L
.95154 .27961 L
.95167 .2794 L
.95178 .27924 L
.9519 .2791 L
.95202 .279 L
.95213 .27893 L
.95219 .2789 L
.95222 .27889 L
.95225 .27888 L
.95228 .27887 L
.9523 .27887 L
.95232 .27886 L
.95233 .27886 L
.95234 .27886 L
.95235 .27886 L
.95235 .27886 L
.95236 .27886 L
.95236 .27886 L
.95237 .27886 L
.95237 .27886 L
.95237 .27886 L
.95238 .27886 L
.95238 .27886 L
.95239 .27886 L
.9524 .27886 L
.95241 .27886 L
.95241 .27886 L
.95242 .27886 L
.95243 .27886 L
.95245 .27886 L
.95247 .27887 L
.9525 .27888 L
.95256 .27889 L
.95262 .27892 L
.95269 .27896 L
.95275 .27901 L
.95287 .27913 L
.95298 .27926 L
Mistroke
.95322 .27965 L
.95345 .28014 L
.9537 .2808 L
.95393 .28157 L
.95418 .28252 L
.95442 .28358 L
.95465 .28472 L
.9549 .28606 L
.95514 .28748 L
.95537 .28896 L
.95561 .29065 L
.95584 .2924 L
.95609 .29437 L
.95633 .29637 L
.95656 .29839 L
.95681 .30064 L
.95704 .3029 L
.95727 .30514 L
.95751 .30759 L
.95775 .31002 L
.95799 .31267 L
.95823 .31526 L
.95846 .31779 L
.9587 .32052 L
.95894 .32316 L
.95919 .32598 L
.95943 .32869 L
.95966 .33129 L
.95991 .33404 L
.96014 .33664 L
.96037 .3391 L
.96061 .34167 L
.96085 .34407 L
.9611 .34653 L
.96133 .34881 L
.96156 .3509 L
.96181 .35301 L
.96204 .35491 L
.96227 .3566 L
.96251 .35825 L
.96274 .35968 L
.96299 .36101 L
.96323 .3621 L
.96346 .36297 L
.96359 .36336 L
.9637 .36367 L
.96382 .36393 L
.96394 .36413 L
.96405 .36427 L
.96411 .36432 L
Mistroke
.96414 .36434 L
.96418 .36436 L
.96419 .36437 L
.96421 .36438 L
.96422 .36438 L
.96424 .36438 L
.96424 .36439 L
.96425 .36439 L
.96426 .36439 L
.96427 .36439 L
.96427 .36439 L
.96428 .36439 L
.96429 .36439 L
.96429 .36439 L
.9643 .36439 L
.9643 .36439 L
.96431 .36439 L
.96431 .36439 L
.96432 .36439 L
.96432 .36439 L
.96434 .36438 L
.96436 .36438 L
.96439 .36437 L
.96442 .36435 L
.96448 .36431 L
.96454 .36425 L
.96465 .36409 L
.96477 .36387 L
.96488 .3636 L
.96511 .36283 L
.96536 .36171 L
.9656 .36034 L
.96583 .35873 L
.96608 .35671 L
.96632 .35445 L
.96654 .35199 L
.96679 .34905 L
.96702 .34589 L
.96727 .3422 L
.96751 .3383 L
.96774 .33422 L
.96798 .32955 L
.96822 .32471 L
.96844 .31974 L
.96868 .31412 L
.96892 .30838 L
.96916 .30193 L
.9694 .29537 L
.96963 .28876 L
.96987 .28139 L
Mistroke
.97011 .27397 L
.97036 .26576 L
.9706 .25752 L
.97083 .2493 L
.97107 .24025 L
.97131 .23125 L
.97153 .22233 L
.97178 .21256 L
.97201 .20291 L
.97226 .19237 L
.9725 .18198 L
.97272 .17177 L
.97297 .16068 L
.9732 .1498 L
.97345 .13804 L
.97369 .12652 L
.97393 .11528 L
.97417 .10317 L
.97441 .09137 L
.97464 .07991 L
.97488 .06761 L
.97511 .05568 L
.97536 .04293 L
.9756 .03058 L
.97583 .01867 L
.97608 .00596 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ZGoo1@00^Woo002[Ool00`00Oomoo`2jOol00:1oo`H000Eoo`03001oogoo0;Yo
o`00Zgoo00<007ooOol01Goo0`00UGoo00<007ooOol06Woo002[Ool00`00Oomoo`05Ool00`00Oomo
o`2EOol00`00Oomoo`0JOol00:]oo`03001oogoo00Eoo`03001oogoo09Eoo`03001oogoo01Yoo`00
Zgoo00<007ooOol01Goo00<007ooOol0UGoo00<007ooOol06Woo002YOol30007Ool00`00Oomoo`2E
Ool00`00Oomoo`0JOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007oo
Ool06goo002cOol00`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03001oogoo
01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=o
o`03001oogoo09Aoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol0
0`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03001oogoo01]oo`00/goo0P00
UGoo00<007ooOol06goo002cOol00`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Ao
o`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomo
o`0KOol00;=oo`03001oogoo09Aoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol0
6goo002AOol30006Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`2DOol00`00Oomoo`0K
Ool0091oo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomo
o`2DOol00`00Oomoo`0KOol008Qoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool3002DOol00`00Oomoo`0KOol0091oo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0000>Ool00`00Oomoo`03
Ool40006Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool2002EOol00`00Oomoo`0KOol0091oo`05001oogooOol0000;Ool01@00Oomoogoo
000017oo00<007ooOol01goo0P00UGoo00<007ooOol06goo002AOol3000<Ool50004Ool40006Ool2
002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol0
6goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo
00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00
/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001o
ogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`80
09Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0K
Ool00;=oo`8009Eoo`03001oogoo01]oo`00VGoo0`001Woo0P001Goo10001Woo0P00UGoo00<007oo
Ool06goo002HOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00goo0P00UGoo00<007ooOol0
6goo002@Ool60002Ool01@00Oomoogoo000047oo00<007ooOol00goo0P00UGoo00<007ooOol06goo
002HOol01@00Oomoogoo000047oo00<007ooOol00goo0`00U7oo00<007ooOol06goo002HOol01@00
Oomoogoo000037oo10001Woo0P00UGoo00<007ooOol06goo002HOol01@00Oomoogoo000037oo00<0
07ooOol01goo0P00UGoo00<007ooOol06goo002HOol01@00Oomoogoo000037oo00<007ooOol01goo
0P00UGoo00<007ooOol06goo002IOol3000=Ool40006Ool2002EOol00`00Oomoo`0KOol00;=oo`80
09Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0K
Ool00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00U7oo00<007ooOol077oo002cOol2002DOol0
0`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00U7oo00<007ooOol077oo002c
Ool2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00U7oo00<007oo
Ool077oo002cOol2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00
U7oo00<007ooOol077oo002cOol2002DOol00`00Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01ao
o`00/goo0P00U7oo00<007ooOol077oo002AOol30006Ool20004Ool50004Ool40006Ool2002DOol0
0`00Oomoo`0LOol0091oo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol0
0goo0P00U7oo00<007ooOol077oo0028Ool60002Ool01@00Oomoogoo00003Goo00<007ooOol027oo
00<007ooOol00goo00<007oo0000Tgoo00<007ooOol077oo002@Ool01@00Oomoogoo00003Woo00<0
07ooOol01goo00<007ooOol00goo0`00Tgoo00<007ooOol077oo002@Ool01@00Oomoogoo00003goo
00<007ooOol00Woo10001Woo00<007oo0000Tgoo00<007ooOol077oo002@Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01goo00<007oo0000Tgoo00<007ooOol077oo002@Ool01@00
Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oo`0009=oo`03001oogoo
01aoo`00TGoo0`003Goo0`001Goo10001Woo0`00Tgoo00<007ooOol077oo002cOol00`00Ool0002C
Ool00`00Oomoo`0LOol001moo`03001oogoo08eoo`07001oogooOol007oo0000Tgoo00<007ooOol0
77oo000OOol2002>Ool20002Ool00`00Ool0002COol00`00Oomoo`0LOol001moo`8008ioo`80009o
o`03001oo`0009=oo`03001oogoo01aoo`007goo0P00SWoo0P000Woo0`00Tgoo00<007ooOol077oo
000OOol2002=Ool00`00Ool00002Ool00`00Ool0002COol00`00Oomoo`0LOol001ioo`03001oo`00
01=oo`<000Ioo`8000Ioo`<002Qoo`<000Ioo`8000Aoo`D002Yoo`03001oo`00009oo`03001oo`00
031oo`<000Ioo`8000Aoo`D002Qoo`<000Ioo`8000Ioo`<001=oo`03001oogoo01aoo`007Woo00<0
07oo00004Woo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo02Ioo`05001oogooOol00005Ool2
0005Ool01000Oomoo`00:Woo00<007oo00000Woo00<007oo0000;goo00D007ooOomoo`0000Eoo`80
00Eoo`04001oogoo000WOol01@00Oomoogoo00001Goo0P001goo00<007ooOol04Woo00<007ooOol0
77oo000NOol00`00Ool0000:Ool60002Ool01@00Oomoogoo00002goo1@007goo1P000Woo00D007oo
Oomoo`0000eoo`03001oogoo02Yoo`03001oo`00009oo`03001oo`0002moo`05001oogooOol0000=
Ool00`00Oomoo`0WOol01@00Oomoogoo00002goo1@004goo00<007ooOol077oo000NOol00`00Ool0
000BOol01@00Oomoogoo00002goo00@007ooOol002Qoo`05001oogooOol0000>Ool00`00Oomoo`0Y
Ool00`00Ool00002Ool30005Ool00`00Oomoo`0WOol01@00Oomoogoo00003Woo00<007ooOol09Woo
00D007ooOomoo`0000]oo`04001oogoo000>Ool00`00Oomoo`03Ool00`00Oomoo`0LOol001ioo`03
001oo`00019oo`05001oogooOol0000<Ool00`00Ool0000XOol01@00Oomoogoo00003goo00<007oo
Ool0:7oo00<007oo00000Woo00<007oo000017oo0P00:Goo00D007ooOomoo`0000moo`03001oogoo
02Eoo`05001oogooOol0000<Ool00`00Ool0000>Ool20004Ool00`00Oomoo`0LOol001ioo`04001o
ogoo000AOol01@00Oomoogoo000037oo00<007oo0000:7oo00D007ooOomoo`0000moo`03001oogoo
02Qoo`03001oo`00009oo`03001oo`0000Aoo`8002Uoo`05001oogooOol0000?Ool00`00Oomoo`0U
Ool01@00Oomoogoo000037oo00<007oo00003Goo00<007oo000017oo00<007ooOol077oo000NOol0
1000Oomoo`001Goo00<007ooOol02Goo00D007ooOomoo`0000eoo`8002Qoo`05001oogooOol0000;
Ool01@00Oomoogoo000097oo00<007ooOol00goo00<007oo00000Woo00<007oo000017oo0`00:7oo
00D007ooOomoo`0000]oo`05001oogooOol0000WOol01@00Oomoogoo00003Goo0P003Goo00<007oo
000017oo00<007ooOol077oo000NOol01000Oomoo`0017oo0P0037oo0`003goo00<007ooOol09goo
0`003Goo0`0097oo0P001Goo00<007oo00000Woo00<007oo000017oo00<007oo0000:Goo0`003Goo
0`00:Goo0`003goo00<007ooOol02goo00<007oo000017oo00<007ooOol077oo000NOol01000Oomo
o`0017oo0`00OWoo0`0017oo00<007oo00000Woo0`000goo00@007ooOol000Eoo`8007Moo`8000Eo
o`03001oo`0000Aoo`03001oogoo01aoo`007Woo00@007ooOol000Aoo`03001oo`0000Eoo`8006mo
o`<000Aoo`800003Ool007oo009oo`800007Ool007ooOol007oo00000goo00@007ooOol000Aoo`<0
07Moo`8000Eoo`03001oo`0000=oo`03001oogoo01eoo`007Woo00@007ooOol000=oo`800003Ool0
07oo00=oo`<000Eoo`80065oo`8000Eoo`03001oo`0000Aoo`04001oogoo0003Ool02@00Oomoogoo
001oo`00Ool00003Ool01000Oomoo`0017oo00<007oo00001Goo0`001Goo0P00FGoo0P001Goo0`00
17oo10000goo00@007ooOol000=oo`03001oogoo01eoo`007Woo00@007ooOol000=oo`04001oogoo
0004Ool01000Ool0000017oo00<007oo00001Goo0P001Goo0`001Goo0P001Woo0P001Woo00<007oo
Ool017oo0P001Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol017oo0P001Woo0P001Goo
0`0017oo100017oo00<007oo000017oo00@007ooOol000=oo`09001oogooOol007oo001oo`0000=o
o`04001oogoo0004Ool01000Ool0000017oo00<007oo000017oo0`001Goo0`001Goo0P001Woo00<0
07ooOol01Goo00<007ooOol017oo0P001Woo00<007ooOol017oo0P001Woo00<007ooOol017oo0P00
1Woo0P001Goo0`0017oo0`001Goo00<007oo000017oo00@007ooOol000=oo`05001oogooOol00002
Ool00`00Oomoo`0MOol001ioo`04001oogoo0003Ool00`00Oomoo`020003Ool01000Oomoo`000goo
0P0000=oo`0000000goo00@007ooOol000Aoo`04001oo`000003Ool40004Ool40003Ool40004Ool4
0004Ool30004Ool40004Ool40003Ool40004Ool40003Ool200000goo001oo`03Ool01000Oomoo`00
0goo0P0000=oo`0000000goo00@007ooOol000=oo`09001oogooOol007oo001oo`0000=oo`03001o
ogoo008000=oo`04001oogoo0003Ool01000Oomoo`0017oo00@007oo000000=oo`800003Ool007oo
00=oo`@000Aoo`<000Aoo`@000Aoo`@000=oo`@000Aoo`@000Aoo`<000Aoo`@000Aoo`04001oo`00
0003Ool200000goo001oo`03Ool01000Ool000000goo00@007ooOol000Aoo`04001oogoo0003Ool0
1@00Oomoogoo00000Woo00<007ooOol07Goo000DOooo0010000EOol001]oo`04001oogoo0002Ool0
1@00Oomoogoo00000goo00@007oo000000=oo`80009oo`06001oogooOol007oo0P0017oo00@007oo
000000=oo`@000Aoo`@000=oo`D000=oo`@000Aoo`@000=oo`@000Aoo`@000=oo`800003Ool00000
00=oo`@000=oo`800003Ool0000000=oo`04001oo`000003Ool20002Ool01P00Oomoogoo001oo`<0
009oo`80009oo`09001oogooOol007oo001oo`0000=oo`05001oogooOol00002Ool01@00Ool007oo
00000goo00D007ooOomoo`00009oo`04001oo`00Ool200000goo00000003Ool2000017oo001oo`00
0Woo00@007oo000000=oo`800006Ool007ooOol007oo10000goo0P0000Ioo`00001oo`00Ool40004
Ool01`00Ool00000Ool007oo00800003Ool007oo00=oo`07001oo`00001oo`00Ool00P0000=oo`00
00000goo00L007ooOol007oo001oo`0200000goo00000003Ool02000Oomoo`00Ool007oo0003Ool0
1@00Oomoogoo00000Woo00@007ooOol001aoo`007Woo00<007ooOol00P000Woo00D007ooOomoo`00
009oo`03001oogoo009oo`04001oo`000004Ool30004Ool30005Ool30005Ool20005Ool30005Ool2
0006Ool20005Ool20006Ool20005Ool30005Ool20005Ool30004Ool40004Ool01000Ool000000goo
00@007ooOol000Aoo`04001oogoo0003Ool01@00Ool007oo00000goo00D007ooOomoo`00009oo`03
001oogoo009oo`03001oo`0000Aoo`@000Aoo`<000Eoo`<000Aoo`<000Eoo`<0009oo`03001oogoo
008000Eoo`<000Eoo`8000Ioo`8000Eoo`8000Eoo`<000Eoo`<000Aoo`@00007Ool007ooOol007oo
000017oo00@007ooOol000Aoo`04001oogoo0003Ool01000Oomoo`007goo000NOol01@00Oomoogoo
00000Woo00@007ooOomoo`800003Ool007oo00=oo`<000Eoo`8005Uoo`8000Eoo`<000Eoo`03001o
o`0000Aoo`04001oogoo0003Ool01@00Ool007oo00000goo00D007ooOomoo`00009oo`03001oogoo
009oo`03001oo`0000Eoo`8000Ioo`03001oogoo051oo`8000Eoo`<000Eoo`<000Aoo`04001oo`00
0003Ool01000Oomoo`007goo000NOol01`00Oomoogoo001oo`0000Eoo`<000Eoo`03001oogoo06Mo
o`03001oogoo00Aoo`<000Aoo`04001oogoo0003Ool01@00Ool007oo00000goo00H007ooOomoo`00
Ool20004Ool3001_Ool20005Ool00`00Ool00004Ool01000Oomoo`007goo000NOol01`00Oomoogoo
001oo`0000Eoo`8007Moo`8000Eoo`04001oogoo0003Ool02000Ool00000Ool007oo0004Ool3001n
Ool00`00Ool00004Ool01000Oomoo`007goo000NOol01`00Oomoogoo001oo`0008Eoo`03001oo`00
00Aoo`03001oo`00009oo`03001oo`0000Eoo`8007moo`8000Aoo`04001oogoo000OOol001eoo`03
001oogoo009oo`03001oo`0008Eoo`<000Aoo`03001oo`00009oo`03001oo`0000Eoo`8007moo`80
00Aoo`04001oogoo000OOol001eoo`03001oogoo009oo`03001oo`0008Ioo`8000Aoo`03001oo`00
009oo`03001oo`0008aoo`04001oogoo000OOol001eoo`03001oogoo009oo`<008Ioo`8000Aoo`03
001oo`00009oo`03001oo`0008eoo`03001oo`0001moo`007Goo00<007ooOol00goo00<007ooOol0
QGoo0P0017oo00P007oo000007oo001oo`00SGoo00<007oo00007goo000MOol00`00Oomoo`2AOol0
0`00Ool00002Ool00`00Ool0002=Ool00`00Ool0000OOol001eoo`03001oogoo095oo`03001oo`00
009oo`03001oo`0008eoo`03001oo`0001moo`007Goo00<007ooOol0TGoo00<007oo00000Woo00<0
07oo0000SGoo00<007oo00007goo000MOol00`00Oomoo`2AOol00`00Ool00002Ool00`00Ool0002=
Ool00`00Ool0000OOol001eoo`03001oogoo095oo`05001oo`00001oo`03002=Ool2000POol001eo
o`03001oogoo095oo`03001oo`00009oo`8008ioo`80021oo`007Goo00<007ooOol0TGoo00<007oo
00000Woo0P00SWoo0P0087oo000MOol00`00Oomoo`2AOol00`00Ool00003Ool00`00Oomoo`2=Ool0
0`00Oomoo`0NOol001eoo`03001oogoo095oo`03001oo`000;Aoo`007Goo00<007ooOol0TGoo00@0
07oo00000;=oo`007Goo00<007ooOol0TGoo00<007oo0000]7oo000MOol00`00Oomoo`1aOol30006
Ool20004Ool50004Ool40004Ool00`00Ool0002dOol001eoo`03001oogoo071oo`05001oogooOol0
0005Ool20005Ool01000Oomoo`0027oo00L007ooOomoo`00Ool0002dOol001eoo`03001oogoo071o
o`05001oogooOol0000=Ool00`00Oomoo`08Ool01`00Oomoogoo001oo`000;Aoo`007Goo00<007oo
Ool0L7oo00D007ooOomoo`0000ioo`03001oogoo00Moo`06001oogooOol007oo0`00/Woo000MOol0
0`00Oomoo`1`Ool01@00Oomoogoo00003goo00<007ooOol00Woo100017oo00<007oo0000]7oo000M
Ool00`00Oomoo`1`Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Woo0P00]7oo
000MOol00`00Oomoo`1`Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Io
o`800;Aoo`007Goo00<007ooOol0LGoo0`003Goo0`001Goo10001Goo0P00]7oo000MOol00`00Oomo
o`2BOol3002cOol001eoo`03001oogoo099oo`800;Aoo`007Goo00<007ooOol0TWoo0P00]7oo000M
Ool00`00Oomoo`2BOol2002dOol001eoo`03001oogoo099oo`800;Aoo`007Goo00<007ooOol0TWoo
0`00/goo000MOol00`00Oomoo`2BOol2002dOol001eoo`03001oogoo099oo`800;Aoo`007Goo00<0
07ooOol0TWoo0P00]7oo000MOol00`00Oomoo`2BOol3002cOol001eoo`03001oogoo099oo`800;Ao
o`007Goo00<007ooOol0TWoo0P00]7oo000MOol00`00Oomoo`2BOol2002dOol001eoo`03001oogoo
099oo`800;Aoo`007Goo00<007ooOol0TWoo0`00/goo000LOol00`00Oomoo`2COol2002dOol001ao
o`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0NWoo0`001Woo0P001Goo10001Goo0P00]7oo
000LOol00`00Oomoo`1iOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol00Woo0P00]7oo000L
Ool00`00Oomoo`1iOol01@00Oomoogoo000047oo00<007ooOol00Woo1000/Woo000LOol00`00Oomo
o`1iOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00]7oo000LOol00`00Oomoo`1iOol01@00
Oomoogoo000037oo10001Goo0P00]7oo000LOol00`00Oomoo`1iOol01@00Oomoogoo000037oo00<0
07ooOol01Woo0P00]7oo000LOol00`00Oomoo`1iOol01@00Oomoogoo000037oo00<007ooOol01Woo
0P00]7oo000LOol00`00Oomoo`1jOol3000=Ool40005Ool3002cOol001aoo`03001oogoo09=oo`80
0;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002dOol001aoo`03001o
ogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0`00/goo000LOol00`00Oomoo`2COol2002dOol0
01aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2C
Ool2002dOol001aoo`03001oogoo09=oo`<00;=oo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol0
0`00Oomoo`2COol2002dOol001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00
]7oo000LOol00`00Oomoo`2COol3002cOol001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007oo
Ool0LWoo0`001Woo0P001Woo00<007ooOol017oo10001Goo0P00]7oo000LOol00`00Oomoo`1aOol0
1@00Oomoogoo00001Goo0P001Woo00<007ooOol027oo00<007ooOol00Woo0P00]7oo000LOol00`00
Oomoo`1aOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00goo00<007ooOol0/Woo
000LOol00`00Oomoo`1aOol01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00goo0`00
/Woo000LOol00`00Oomoo`1aOol01@00Oomoogoo00003Woo00<007ooOol00goo10001Woo00<007oo
Ool0/Woo000LOol00`00Oomoo`1aOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol0/Woo000LOol00`00Oomoo`1aOol01@00Oomoogoo00002goo00D007ooOomoo`00
00Aoo`03001oogoo00Moo`03001oogoo0;9oo`0077oo00<007ooOol0LWoo0`0037oo1@0017oo1000
1Woo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol2002cOol001aoo`03001oogoo09Aoo`03001o
ogoo0;9oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol00`00Oomo
o`2bOol001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo0P00/goo000L
Ool00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo
00<007ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03
001oogoo09Aoo`800;=oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2D
Ool00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo
00<007ooOol0/Woo000KOol00`00Oomoo`2EOol2002cOol001]oo`03001oogoo09Eoo`03001oogoo
0;9oo`006goo00<007ooOol0Rgoo1@001Goo00<007ooOol0/Woo000KOol00`00Oomoo`2=Ool00`00
Oomoo`05Ool00`00Oomoo`2bOol001]oo`03001oogoo08eoo`03001oogoo00Eoo`03001oogoo0;9o
o`006goo00<007ooOol0SGoo00<007ooOol01Goo0`00/Woo002[Ool00`00Oomoo`2jOol00:]oo`03
001oogoo0;Yoo`00Zgoo00<007ooOol0^Woo002YOol3002lOol00?moofUoo`00ZWoo00<007ooOol0
^goo002ZOol2002lOol0089oo`H0009oo`H0009oo`H000Aoo`@0009oo`H000=oo`03001oogoo00Uo
o`<0009oo`<001Uoo`<000Aoo`<008Ioo`00Pgoo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo009oo`05001oogooOol00006Ool2000;Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool6000<Ool00`00Oomoo`02Ool01@00Oomoogoo0000QGoo0023Ool01@00Oomoogoo0000
17oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0001=oo`03001o
ogoo009oo`03001oogoo01Ioo`D000=oo`05001oogooOol00025Ool008=oo`03001oo`0000Ioo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol0000COol01P00Ool00000
Ool000Uoo`H000Uoo`04001oogoo0004Ool01@00Oomoogoo0000QGoo0023Ool30006Ool20006Ool2
0005Ool00`00Oomoo`02Ool01000Oomoogoo0P004Woo00H007oo000007oo000IOol00`00Ool00004
Ool01@00Oomoogoo0000QGoo0023Ool01@00Ool007oo00000goo0P0000Aoo`000000009oo`800004
Ool000000003Ool40003Ool2000017oo000000003goo0P000Woo0P006Goo00<007oo000017oo00D0
07ooOomoo`0008Eoo`00Pgoo00D007ooOomoo`00031oo`80009oo`8001Yoo`8000Aoo`05001oogoo
Ool00025Ool0089oo`H002moo`8000Aoo`8001Yoo`03001oogoo00=oo`<008Ioo`00ogooJGoo003o
OomYOol00?moofUoo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.952381 0.309017 0.309017 [
[.11905 .29652 -12 -9 ]
[.11905 .29652 12 0 ]
[.30952 .29652 -12 -9 ]
[.30952 .29652 12 0 ]
[.69048 .29652 -9 -9 ]
[.69048 .29652 9 0 ]
[.88095 .29652 -9 -9 ]
[.88095 .29652 9 0 ]
[.4875 0 -12 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .07725 -30 -4.5 ]
[.4875 .07725 0 4.5 ]
[.4875 .15451 -24 -4.5 ]
[.4875 .15451 0 4.5 ]
[.4875 .23176 -30 -4.5 ]
[.4875 .23176 0 4.5 ]
[.4875 .38627 -24 -4.5 ]
[.4875 .38627 0 4.5 ]
[.4875 .46353 -18 -4.5 ]
[.4875 .46353 0 4.5 ]
[.4875 .54078 -24 -4.5 ]
[.4875 .54078 0 4.5 ]
[.4875 .61803 -6 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30902 m
.11905 .31527 L
s
[(-0.4)] .11905 .29652 0 1 Mshowa
.30952 .30902 m
.30952 .31527 L
s
[(-0.2)] .30952 .29652 0 1 Mshowa
.69048 .30902 m
.69048 .31527 L
s
[(0.2)] .69048 .29652 0 1 Mshowa
.88095 .30902 m
.88095 .31527 L
s
[(0.4)] .88095 .29652 0 1 Mshowa
.125 Mabswid
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.07143 .30902 m
.07143 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.97619 .30902 m
.97619 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1)] .4875 0 1 0 Mshowa
.5 .07725 m
.50625 .07725 L
s
[(-0.75)] .4875 .07725 1 0 Mshowa
.5 .15451 m
.50625 .15451 L
s
[(-0.5)] .4875 .15451 1 0 Mshowa
.5 .23176 m
.50625 .23176 L
s
[(-0.25)] .4875 .23176 1 0 Mshowa
.5 .38627 m
.50625 .38627 L
s
[(0.25)] .4875 .38627 1 0 Mshowa
.5 .46353 m
.50625 .46353 L
s
[(0.5)] .4875 .46353 1 0 Mshowa
.5 .54078 m
.50625 .54078 L
s
[(0.75)] .4875 .54078 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .01545 m
.50375 .01545 L
s
.5 .0309 m
.50375 .0309 L
s
.5 .04635 m
.50375 .04635 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .09271 m
.50375 .09271 L
s
.5 .10816 m
.50375 .10816 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .13906 m
.50375 .13906 L
s
.5 .16996 m
.50375 .16996 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .20086 m
.50375 .20086 L
s
.5 .21631 m
.50375 .21631 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26266 m
.50375 .26266 L
s
.5 .27812 m
.50375 .27812 L
s
.5 .29357 m
.50375 .29357 L
s
.5 .32447 m
.50375 .32447 L
s
.5 .33992 m
.50375 .33992 L
s
.5 .35537 m
.50375 .35537 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .40172 m
.50375 .40172 L
s
.5 .41717 m
.50375 .41717 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .44807 m
.50375 .44807 L
s
.5 .47898 m
.50375 .47898 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .50988 m
.50375 .50988 L
s
.5 .52533 m
.50375 .52533 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57168 m
.50375 .57168 L
s
.5 .58713 m
.50375 .58713 L
s
.5 .60258 m
.50375 .60258 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Error) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
117.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .61803 m
.024 .606 L
.0242 .59289 L
.02439 .58062 L
.02457 .56886 L
.02476 .5564 L
.02495 .5445 L
.02515 .53194 L
.02534 .51996 L
.02553 .50856 L
.02572 .49658 L
.02591 .4852 L
.02609 .47441 L
.02629 .46311 L
.02647 .45243 L
.02667 .44129 L
.02686 .43079 L
.02705 .42091 L
.02724 .41065 L
.02743 .40102 L
.02763 .39108 L
.02782 .38179 L
.02801 .37312 L
.0282 .36421 L
.02839 .35593 L
.02857 .34826 L
.02877 .34041 L
.02895 .33316 L
.02915 .32581 L
.02934 .31906 L
.02953 .31289 L
.02972 .30666 L
.02991 .301 L
.03009 .29587 L
.03029 .29075 L
.03047 .28615 L
.03067 .28161 L
.03086 .27757 L
.03104 .27401 L
.03124 .27055 L
.03143 .26754 L
.03163 .26469 L
.03182 .26227 L
.032 .26023 L
.0322 .25839 L
.03239 .25691 L
.03257 .25576 L
.03267 .25523 L
.03276 .25482 L
.03286 .25446 L
Mistroke
.03295 .25418 L
.03304 .25397 L
.03309 .25387 L
.03314 .2538 L
.03319 .25374 L
.03321 .25372 L
.03324 .2537 L
.03326 .25369 L
.03327 .25368 L
.03329 .25368 L
.0333 .25367 L
.03331 .25367 L
.03331 .25367 L
.03332 .25367 L
.03332 .25367 L
.03333 .25367 L
.03333 .25367 L
.03334 .25367 L
.03334 .25367 L
.03335 .25367 L
.03336 .25367 L
.03336 .25367 L
.03337 .25367 L
.03339 .25368 L
.0334 .25368 L
.03342 .25369 L
.03344 .25371 L
.03347 .25373 L
.03352 .25378 L
.03356 .25385 L
.03361 .25392 L
.03371 .25413 L
.03389 .25469 L
.03409 .25552 L
.03428 .25653 L
.03447 .25768 L
.03466 .25909 L
.03485 .26063 L
.03503 .26225 L
.03522 .26412 L
.03541 .26605 L
.03561 .26823 L
.0358 .27045 L
.03598 .27268 L
.03617 .27513 L
.03636 .27757 L
.03656 .28023 L
.03675 .28285 L
.03694 .2854 L
.03713 .28815 L
Mistroke
.03732 .29081 L
.0375 .29337 L
.0377 .2961 L
.03788 .29871 L
.03808 .30146 L
.03827 .30407 L
.03846 .30655 L
.03865 .30913 L
.03884 .31155 L
.03904 .31405 L
.03923 .31638 L
.03942 .31854 L
.03961 .32074 L
.0398 .32277 L
.03999 .32462 L
.04018 .32649 L
.04037 .32817 L
.04057 .32984 L
.04076 .33132 L
.04094 .33263 L
.04114 .3339 L
.04133 .33499 L
.04151 .33592 L
.0417 .33678 L
.04189 .33748 L
.04208 .33808 L
.04227 .33854 L
.04246 .33885 L
.04255 .33897 L
.04265 .33906 L
.0427 .33909 L
.04273 .3391 L
.04275 .33911 L
.04278 .33912 L
.04279 .33912 L
.0428 .33912 L
.04282 .33913 L
.04283 .33913 L
.04283 .33913 L
.04284 .33913 L
.04285 .33913 L
.04285 .33913 L
.04286 .33913 L
.04286 .33913 L
.04286 .33913 L
.04287 .33913 L
.04288 .33913 L
.04288 .33913 L
.04289 .33913 L
.0429 .33913 L
Mistroke
.04291 .33912 L
.04293 .33912 L
.04295 .33911 L
.04297 .33911 L
.043 .3391 L
.04304 .33907 L
.04313 .339 L
.04322 .33891 L
.04341 .33862 L
.0436 .3382 L
.0438 .33768 L
.04398 .33708 L
.04417 .33634 L
.04436 .33553 L
.04456 .33457 L
.04475 .33355 L
.04494 .33249 L
.04514 .33128 L
.04532 .33005 L
.04551 .32881 L
.0457 .32742 L
.04589 .32604 L
.04609 .32453 L
.04628 .32302 L
.04646 .32155 L
.04666 .31995 L
.04685 .3184 L
.04703 .31689 L
.04722 .31528 L
.04741 .31372 L
.0476 .31208 L
.04779 .31051 L
.04798 .30901 L
.04817 .30745 L
.04836 .30597 L
.04856 .30443 L
.04875 .30299 L
.04893 .30165 L
.04913 .30028 L
.04932 .29901 L
.0495 .29784 L
.04969 .29666 L
.04988 .29559 L
.05008 .29453 L
.05027 .29358 L
.05045 .29273 L
.05065 .29191 L
.05084 .2912 L
.05104 .29054 L
.05123 .28998 L
Mistroke
.05141 .28952 L
.05161 .28912 L
.0518 .28883 L
.05198 .28862 L
.05208 .28855 L
.05213 .28851 L
.05218 .28849 L
.05223 .28847 L
.05225 .28846 L
.05228 .28845 L
.0523 .28845 L
.05233 .28844 L
.05234 .28844 L
.05235 .28844 L
.05236 .28844 L
.05236 .28844 L
.05237 .28844 L
.05237 .28844 L
.05237 .28844 L
.05238 .28844 L
.05238 .28844 L
.05239 .28844 L
.05239 .28844 L
.0524 .28844 L
.05241 .28844 L
.05241 .28844 L
.05243 .28844 L
.05244 .28844 L
.05245 .28845 L
.05247 .28845 L
.05249 .28845 L
.05252 .28846 L
.05257 .28848 L
.05262 .2885 L
.05266 .28853 L
.05276 .2886 L
.05285 .28869 L
.05295 .28881 L
.05315 .28909 L
.05333 .28945 L
.05353 .2899 L
.05372 .29041 L
.05391 .29096 L
.05411 .29162 L
.05429 .29232 L
.05448 .29304 L
.05467 .29386 L
.05486 .29471 L
.05505 .29565 L
.05524 .2966 L
Mistroke
.05543 .29756 L
.05562 .29861 L
.05581 .29965 L
.05601 .30078 L
.0562 .30189 L
.05639 .30298 L
.05658 .30414 L
.05677 .30527 L
.05696 .30636 L
.05715 .30752 L
.05734 .30863 L
.05754 .30979 L
.05773 .3109 L
.05791 .31195 L
.05811 .31304 L
.0583 .31406 L
.05848 .31501 L
.05867 .316 L
.05886 .3169 L
.05905 .31783 L
.05924 .31867 L
.05943 .31943 L
.05962 .3202 L
.05981 .32089 L
.06001 .32156 L
.0602 .32214 L
.06039 .32265 L
.06058 .32313 L
.06077 .32354 L
.06095 .32387 L
.06115 .32415 L
.06133 .32437 L
.06143 .32446 L
.06153 .32453 L
.06163 .32459 L
.06167 .32461 L
.06172 .32462 L
.06175 .32463 L
.06177 .32464 L
.0618 .32464 L
.06182 .32465 L
.06183 .32465 L
.06184 .32465 L
.06185 .32465 L
.06186 .32465 L
.06187 .32465 L
.06188 .32465 L
.06188 .32465 L
.06189 .32465 L
.06189 .32465 L
Mistroke
.0619 .32465 L
.0619 .32465 L
.06191 .32465 L
.06191 .32465 L
.06192 .32465 L
.06192 .32465 L
.06193 .32465 L
.06194 .32465 L
.06195 .32465 L
.06196 .32465 L
.06198 .32465 L
.06201 .32464 L
.06206 .32463 L
.06211 .32462 L
.0622 .32458 L
.0623 .32452 L
.0624 .32444 L
.0625 .32435 L
.06268 .32414 L
.06288 .32385 L
.06307 .32352 L
.06325 .32316 L
.06344 .32271 L
.06363 .32224 L
.06383 .32168 L
.06402 .3211 L
.0642 .3205 L
.06439 .31982 L
.06458 .31913 L
.06478 .31836 L
.06497 .31759 L
.06516 .31682 L
.06535 .31598 L
.06554 .31514 L
.06572 .31433 L
.06592 .31344 L
.0661 .31259 L
.0663 .31167 L
.06649 .31078 L
.06668 .30992 L
.06687 .30902 L
.06706 .30815 L
.06726 .30725 L
.06745 .30639 L
.06764 .30558 L
.06783 .30474 L
.06802 .30395 L
.0682 .30322 L
.0684 .30247 L
.06859 .30179 L
Mistroke
.06878 .30109 L
.06898 .30046 L
.06916 .29989 L
.06936 .29932 L
.06954 .29882 L
.06973 .29838 L
.06992 .29796 L
.07011 .2976 L
.0703 .29726 L
.07049 .29699 L
.07068 .29678 L
.07087 .2966 L
.07096 .29653 L
.07106 .29648 L
.07111 .29645 L
.07116 .29643 L
.07121 .29641 L
.07126 .2964 L
.0713 .29639 L
.07133 .29639 L
.07135 .29639 L
.07137 .29638 L
.07139 .29638 L
.07139 .29638 L
.0714 .29638 L
.07141 .29638 L
.07141 .29638 L
.07141 .29638 L
.07142 .29638 L
.07142 .29638 L
.07143 .29638 L
.07143 .29638 L
.07144 .29638 L
.07144 .29638 L
.07145 .29638 L
.07146 .29638 L
.07146 .29638 L
.07147 .29638 L
.07148 .29638 L
.0715 .29638 L
.07152 .29639 L
.07154 .29639 L
.07159 .2964 L
.07164 .29641 L
.07173 .29645 L
.07182 .29649 L
.07201 .29661 L
.07221 .2968 L
.0724 .29702 L
.07259 .29729 L
Mistroke
.07278 .29761 L
.07297 .29797 L
.07316 .29835 L
.07335 .29879 L
.07354 .29926 L
.07374 .29979 L
.07393 .30033 L
.07411 .30089 L
.07431 .30151 L
.07449 .30213 L
.07468 .30274 L
.07487 .30342 L
.07505 .30409 L
.07525 .30482 L
.07544 .30553 L
.07563 .30622 L
.07582 .30696 L
.07601 .30768 L
.07621 .30845 L
.0764 .30918 L
.07658 .30988 L
.07678 .31062 L
.07697 .31131 L
.07715 .31197 L
.07734 .31266 L
.07753 .3133 L
.07773 .31395 L
.07792 .31456 L
.0781 .31512 L
.0783 .31569 L
.07849 .31621 L
.07869 .31673 L
.07888 .31719 L
.07906 .3176 L
.07926 .318 L
.07945 .31834 L
.07963 .31864 L
.07983 .31891 L
.08002 .31914 L
.08021 .31933 L
.08041 .31947 L
.08049 .31953 L
.08059 .31957 L
.08069 .31961 L
.08074 .31962 L
.08079 .31963 L
.08083 .31964 L
.08086 .31964 L
.08088 .31965 L
.08089 .31965 L
Mistroke
.08091 .31965 L
.08092 .31965 L
.08092 .31965 L
.08093 .31965 L
.08093 .31965 L
.08094 .31965 L
.08095 .31965 L
.08095 .31965 L
.08096 .31965 L
.08096 .31965 L
.08097 .31965 L
.08097 .31965 L
.08098 .31965 L
.08098 .31965 L
.08099 .31965 L
.08101 .31965 L
.08102 .31965 L
.08104 .31964 L
.08107 .31964 L
.08111 .31963 L
.08116 .31962 L
.08125 .3196 L
.08135 .31956 L
.08145 .3195 L
.08155 .31944 L
.08173 .3193 L
.08193 .3191 L
.08212 .31888 L
.0823 .31862 L
.08249 .31832 L
.08268 .31799 L
.08288 .31761 L
.08307 .3172 L
.08325 .31679 L
.08345 .31632 L
.08364 .31584 L
.08384 .3153 L
.08403 .31477 L
.08421 .31423 L
.08441 .31364 L
.0846 .31306 L
.08478 .31249 L
.08498 .31187 L
.08516 .31127 L
.08536 .31062 L
.08555 .31 L
.08574 .30939 L
.08593 .30875 L
.08612 .30814 L
.0863 .30756 L
Mistroke
.0865 .30696 L
.08668 .30638 L
.08688 .30579 L
.08707 .30523 L
.08725 .30471 L
.08745 .30417 L
.08764 .30368 L
.08783 .30319 L
.08803 .30274 L
.08821 .30233 L
.08841 .30192 L
.0886 .30156 L
.08878 .30125 L
.08897 .30094 L
.08916 .30068 L
.08936 .30044 L
.08955 .30025 L
.08973 .30009 L
.08983 .30002 L
.08993 .29996 L
.09003 .29991 L
.09012 .29988 L
.09021 .29985 L
.09026 .29984 L
.09031 .29983 L
.09035 .29982 L
.09038 .29982 L
.0904 .29982 L
.09042 .29981 L
.09044 .29981 L
.09044 .29981 L
.09045 .29981 L
.09045 .29981 L
.09046 .29981 L
.09046 .29981 L
.09047 .29981 L
.09047 .29981 L
.09048 .29981 L
.09049 .29981 L
.09049 .29981 L
.0905 .29981 L
.0905 .29981 L
.09052 .29981 L
.09053 .29981 L
.09054 .29981 L
.09057 .29982 L
.09059 .29982 L
.09063 .29982 L
.09068 .29983 L
.09078 .29986 L
Mistroke
.09088 .29989 L
.09106 .29998 L
.09126 .30012 L
.09145 .30028 L
.09163 .30046 L
.09182 .30069 L
.09201 .30095 L
.0922 .30125 L
.09239 .30157 L
.09258 .3019 L
.09277 .30228 L
.09296 .30267 L
.09316 .30311 L
.09335 .30356 L
.09353 .30401 L
.09373 .3045 L
.09392 .305 L
.0941 .30548 L
.09429 .30601 L
.09448 .30653 L
.09468 .30708 L
.09487 .30763 L
.09505 .30815 L
.09525 .30871 L
.09544 .30925 L
.09564 .30981 L
.09583 .31035 L
.09601 .31086 L
.09621 .3114 L
.0964 .3119 L
.09658 .31237 L
.09678 .31285 L
.09696 .3133 L
.09716 .31376 L
.09735 .31418 L
.09754 .31456 L
.09773 .31494 L
.09792 .31529 L
.0981 .31559 L
.0983 .31589 L
.09848 .31615 L
.09868 .31639 L
.09887 .3166 L
.09905 .31676 L
.09925 .31691 L
.09944 .31702 L
.09953 .31706 L
.09964 .3171 L
.09969 .31712 L
.09974 .31713 L
Mistroke
.09979 .31714 L
.09983 .31715 L
.09987 .31715 L
.0999 .31716 L
.09992 .31716 L
.09993 .31716 L
.09994 .31716 L
.09995 .31716 L
.09997 .31716 L
.09997 .31716 L
.09998 .31716 L
.09998 .31716 L
.09999 .31716 L
.09999 .31716 L
.1 .31716 L
.1 .31716 L
.10001 .31716 L
.10001 .31716 L
.10002 .31716 L
.10002 .31716 L
.10003 .31716 L
.10003 .31716 L
.10005 .31716 L
.10006 .31716 L
.10008 .31716 L
.1001 .31715 L
.10015 .31715 L
.1002 .31714 L
.1003 .31712 L
.1004 .31709 L
.1005 .31705 L
.1006 .317 L
.10078 .31689 L
.10098 .31674 L
.10117 .31657 L
.10135 .31637 L
.10155 .31613 L
.10173 .31588 L
.10193 .31558 L
.10212 .31527 L
.10231 .31495 L
.1025 .31458 L
.10269 .31421 L
.10287 .31384 L
.10306 .31342 L
.10325 .313 L
.10345 .31255 L
.10364 .31209 L
.10382 .31165 L
.10402 .31117 L
Mistroke
.1042 .3107 L
.1044 .31019 L
.10459 .3097 L
.10478 .30923 L
.10498 .30873 L
.10517 .30825 L
.10535 .3078 L
.10554 .30732 L
.10573 .30687 L
.10593 .3064 L
.10612 .30596 L
.1063 .30555 L
.1065 .30513 L
.10668 .30475 L
.10688 .30435 L
.10708 .304 L
.10726 .30367 L
.10746 .30335 L
.10765 .30307 L
.10783 .30282 L
.10803 .30258 L
.10821 .30237 L
.10841 .30218 L
.1086 .30203 L
.10879 .30191 L
.10888 .30186 L
.10898 .30181 L
.10908 .30177 L
.10917 .30174 L
.10926 .30172 L
.10931 .30171 L
.10937 .3017 L
.10941 .3017 L
.10944 .30169 L
.10945 .30169 L
.10946 .30169 L
.10947 .30169 L
.10948 .30169 L
.10949 .30169 L
.1095 .30169 L
.10951 .30169 L
.10951 .30169 L
.10952 .30169 L
.10952 .30169 L
.10953 .30169 L
.10953 .30169 L
.10954 .30169 L
.10954 .30169 L
.10955 .30169 L
.10956 .30169 L
Mistroke
.10957 .30169 L
.10958 .30169 L
.1096 .30169 L
.10964 .3017 L
.10967 .3017 L
.10969 .3017 L
.10974 .30171 L
.10983 .30173 L
.10993 .30176 L
.11013 .30184 L
.11032 .30194 L
.1105 .30207 L
.11069 .30223 L
.11088 .30241 L
.11108 .30263 L
.11127 .30286 L
.11145 .30311 L
.11165 .3034 L
.11184 .30369 L
.11204 .30403 L
.11223 .30437 L
.11241 .30472 L
.11261 .30511 L
.1128 .30549 L
.11298 .30588 L
.11318 .30629 L
.11336 .3067 L
.11356 .30715 L
.11375 .30759 L
.11394 .30801 L
.11413 .30846 L
.11432 .3089 L
.1145 .30931 L
.1147 .30976 L
.11488 .31018 L
.11508 .31062 L
.11527 .31103 L
.11545 .31143 L
.11565 .31183 L
.11584 .31221 L
.11603 .3126 L
.11623 .31296 L
.11641 .31328 L
.11661 .31361 L
.1168 .31391 L
.11698 .31418 L
.11717 .31444 L
.11736 .31468 L
.11756 .3149 L
.11775 .31509 L
Mistroke
.11793 .31525 L
.11813 .31539 L
.11832 .3155 L
.11841 .31555 L
.11852 .3156 L
.11861 .31563 L
.11871 .31566 L
.11881 .31568 L
.11886 .31568 L
.11891 .31569 L
.11893 .31569 L
.11896 .3157 L
.11897 .3157 L
.11898 .3157 L
.11899 .3157 L
.119 .3157 L
.11902 .3157 L
.11903 .3157 L
.11903 .3157 L
.11904 .3157 L
.11904 .3157 L
.11905 .3157 L
.11905 .3157 L
.11906 .3157 L
.11906 .3157 L
.11907 .3157 L
.11908 .3157 L
.11908 .3157 L
.11909 .3157 L
.11911 .3157 L
.11912 .3157 L
.11914 .3157 L
.11916 .31569 L
.11919 .31569 L
.11923 .31569 L
.11928 .31568 L
.11937 .31566 L
.11946 .31564 L
.11966 .31556 L
.11984 .31547 L
.12004 .31534 L
.12023 .3152 L
.12041 .31504 L
.12061 .31484 L
.1208 .31463 L
.12099 .31438 L
.12119 .31412 L
.12137 .31385 L
.12157 .31355 L
.12176 .31324 L
Mistroke
.12194 .31293 L
.12213 .31258 L
.12232 .31223 L
.12252 .31185 L
.12271 .31147 L
.12289 .3111 L
.12309 .3107 L
.12327 .31031 L
.12347 .30989 L
.12367 .30948 L
.12385 .30909 L
.12405 .30867 L
.12424 .30828 L
.12442 .3079 L
.12462 .3075 L
.1248 .30712 L
.125 .30673 L
.12519 .30637 L
.12538 .30603 L
.12557 .30568 L
.12576 .30536 L
.12594 .30506 L
.12614 .30476 L
.12632 .3045 L
.12652 .30423 L
.12671 .30399 L
.12689 .30378 L
.12709 .30358 L
.12728 .30341 L
.12748 .30325 L
.12767 .30313 L
.12785 .30303 L
.12795 .30299 L
.12805 .30295 L
.12815 .30291 L
.12824 .30289 L
.12833 .30287 L
.12838 .30287 L
.12843 .30286 L
.12846 .30286 L
.12848 .30286 L
.1285 .30286 L
.12851 .30286 L
.12853 .30285 L
.12854 .30285 L
.12855 .30285 L
.12855 .30285 L
.12856 .30285 L
.12856 .30285 L
.12857 .30285 L
Mistroke
.12857 .30285 L
.12858 .30285 L
.12859 .30285 L
.12859 .30285 L
.12859 .30285 L
.12861 .30285 L
.12862 .30285 L
.12863 .30286 L
.12864 .30286 L
.12867 .30286 L
.12869 .30286 L
.12871 .30286 L
.12876 .30287 L
.1288 .30287 L
.1289 .30289 L
.129 .30291 L
.12919 .30298 L
.12938 .30307 L
.12956 .30318 L
.12976 .30332 L
.12995 .30347 L
.13014 .30366 L
.13034 .30386 L
.13052 .30407 L
.13072 .30432 L
.1309 .30457 L
.13108 .30483 L
.13128 .30512 L
.13146 .30542 L
.13166 .30575 L
.13185 .30607 L
.13203 .3064 L
.13223 .30676 L
.13242 .30711 L
.13262 .30748 L
.13281 .30786 L
.13299 .30822 L
.13319 .3086 L
.13338 .30897 L
.13356 .30933 L
.13375 .30971 L
.13394 .31006 L
.13414 .31044 L
.13433 .3108 L
.13451 .31113 L
.13471 .31148 L
.1349 .3118 L
.1351 .31213 L
.13529 .31244 L
.13548 .31272 L
Mistroke
.13567 .313 L
.13586 .31325 L
.13604 .31348 L
.13624 .3137 L
.13643 .3139 L
.13663 .31409 L
.13682 .31425 L
.137 .31438 L
.1372 .31451 L
.13739 .3146 L
.13757 .31467 L
.13766 .3147 L
.13776 .31472 L
.13781 .31473 L
.13786 .31474 L
.13791 .31475 L
.13796 .31475 L
.13798 .31475 L
.13801 .31475 L
.13802 .31476 L
.13803 .31476 L
.13804 .31476 L
.13805 .31476 L
.13807 .31476 L
.13807 .31476 L
.13808 .31476 L
.13808 .31476 L
.13809 .31476 L
.13809 .31476 L
.1381 .31476 L
.13811 .31476 L
.13811 .31476 L
.13811 .31476 L
.13812 .31476 L
.13813 .31476 L
.13814 .31476 L
.13815 .31476 L
.13818 .31475 L
.1382 .31475 L
.13825 .31475 L
.1383 .31474 L
.13835 .31474 L
.13844 .31472 L
.13854 .31469 L
.13873 .31463 L
.13892 .31455 L
.13911 .31444 L
.1393 .31431 L
.1395 .31416 L
.13968 .314 L
Mistroke
.13987 .3138 L
.14006 .3136 L
.14026 .31336 L
.14045 .31312 L
.14064 .31287 L
.14084 .31259 L
.14103 .31231 L
.14121 .31202 L
.1414 .31171 L
.14159 .3114 L
.14179 .31106 L
.14198 .31072 L
.14216 .31039 L
.14236 .31004 L
.14255 .30969 L
.14273 .30936 L
.14292 .30901 L
.14311 .30867 L
.14331 .30831 L
.1435 .30796 L
.14368 .30764 L
.14388 .3073 L
.14406 .30698 L
.14426 .30665 L
.14445 .30634 L
.14464 .30606 L
.14484 .30577 L
.14503 .3055 L
.14521 .30526 L
.1454 .30502 L
.14559 .3048 L
.14579 .30459 L
.14598 .3044 L
.14616 .30424 L
.14636 .30409 L
.14654 .30396 L
.14674 .30385 L
.14694 .30376 L
.14712 .3037 L
.14722 .30367 L
.14732 .30365 L
.14737 .30364 L
.14741 .30364 L
.14746 .30363 L
.1475 .30363 L
.14753 .30363 L
.14755 .30363 L
.14757 .30363 L
.14758 .30363 L
.14759 .30363 L
Mistroke
.1476 .30363 L
.1476 .30363 L
.14761 .30363 L
.14761 .30363 L
.14762 .30363 L
.14763 .30363 L
.14763 .30363 L
.14764 .30363 L
.14764 .30363 L
.14765 .30363 L
.14766 .30363 L
.14767 .30363 L
.14768 .30363 L
.14769 .30363 L
.14772 .30363 L
.14774 .30363 L
.14779 .30363 L
.14784 .30364 L
.14788 .30365 L
.14797 .30366 L
.14807 .30368 L
.14826 .30375 L
.14845 .30383 L
.14865 .30393 L
.14884 .30405 L
.14902 .30419 L
.14921 .30435 L
.1494 .30452 L
.1496 .30473 L
.14979 .30494 L
.14998 .30516 L
.15017 .30541 L
.15036 .30567 L
.15054 .30592 L
.15074 .30621 L
.15092 .30649 L
.15112 .3068 L
.15131 .30711 L
.1515 .30741 L
.15169 .30774 L
.15188 .30806 L
.15208 .30841 L
.15227 .30874 L
.15246 .30906 L
.15266 .3094 L
.15285 .30972 L
.15303 .31003 L
.15322 .31036 L
.15341 .31066 L
.15361 .31098 L
Mistroke
.1538 .31128 L
.15398 .31156 L
.15418 .31184 L
.15437 .31211 L
.15455 .31235 L
.15474 .31259 L
.15493 .31281 L
.15513 .31302 L
.15532 .31321 L
.1555 .31338 L
.1557 .31354 L
.15588 .31368 L
.15608 .31381 L
.15628 .31391 L
.15646 .31399 L
.15655 .31402 L
.15666 .31405 L
.15676 .31408 L
.15685 .31409 L
.15694 .31411 L
.15699 .31411 L
.15701 .31411 L
.15704 .31412 L
.15706 .31412 L
.15709 .31412 L
.1571 .31412 L
.15711 .31412 L
.15712 .31412 L
.15712 .31412 L
.15713 .31412 L
.15713 .31412 L
.15714 .31412 L
.15714 .31412 L
.15715 .31412 L
.15715 .31412 L
.15716 .31412 L
.15716 .31412 L
.15716 .31412 L
.15717 .31412 L
.15718 .31412 L
.15719 .31412 L
.1572 .31412 L
.15722 .31412 L
.15725 .31412 L
.15727 .31411 L
.15732 .31411 L
.15736 .3141 L
.15741 .3141 L
.1575 .31408 L
.15759 .31406 L
Mistroke
.15778 .31401 L
.15796 .31393 L
.15816 .31384 L
.15835 .31372 L
.15854 .31359 L
.15874 .31343 L
.15892 .31327 L
.15912 .31308 L
.1593 .31288 L
.15949 .31268 L
.15968 .31245 L
.15986 .31221 L
.16006 .31195 L
.16025 .31169 L
.16044 .31142 L
.16063 .31113 L
.16082 .31085 L
.16102 .31053 L
.16121 .31023 L
.16139 .30993 L
.16159 .30961 L
.16178 .3093 L
.16196 .309 L
.16216 .30868 L
.16234 .30838 L
.16254 .30806 L
.16273 .30776 L
.16291 .30747 L
.16311 .30717 L
.1633 .30689 L
.1635 .3066 L
.16369 .30634 L
.16388 .30609 L
.16407 .30584 L
.16426 .30562 L
.16445 .30541 L
.16464 .30521 L
.16483 .30503 L
.16503 .30486 L
.16522 .3047 L
.1654 .30458 L
.1656 .30446 L
.16579 .30436 L
.16597 .30429 L
.16607 .30425 L
.16616 .30422 L
.16626 .3042 L
.16635 .30418 L
.16644 .30417 L
.16649 .30417 L
Mistroke
.16651 .30416 L
.16654 .30416 L
.16656 .30416 L
.16659 .30416 L
.1666 .30416 L
.16661 .30416 L
.16662 .30416 L
.16663 .30416 L
.16664 .30416 L
.16664 .30416 L
.16665 .30416 L
.16665 .30416 L
.16665 .30416 L
.16666 .30416 L
.16667 .30416 L
.16667 .30416 L
.16667 .30416 L
.16668 .30416 L
.16668 .30416 L
.16669 .30416 L
.16669 .30416 L
.1667 .30416 L
.1667 .30416 L
.16672 .30416 L
.16674 .30416 L
.16676 .30416 L
.16678 .30416 L
.16683 .30417 L
.16688 .30417 L
.16694 .30418 L
.16704 .30419 L
.16713 .30422 L
.16732 .30427 L
.16751 .30435 L
.1677 .30444 L
.1679 .30455 L
.16809 .30468 L
.16828 .30483 L
.16847 .30499 L
.16866 .30517 L
.16885 .30535 L
.16904 .30556 L
.16923 .30578 L
.16943 .30602 L
.16962 .30627 L
.1698 .30651 L
.17 .30678 L
.17019 .30705 L
.17037 .30732 L
.17056 .30761 L
Mistroke
.17075 .30789 L
.17095 .3082 L
.17114 .30849 L
.17132 .30878 L
.17151 .30909 L
.1717 .30938 L
.1719 .30969 L
.17209 .30999 L
.17228 .31027 L
.17247 .31056 L
.17266 .31083 L
.17285 .31109 L
.17304 .31136 L
.17323 .3116 L
.17343 .31185 L
.17362 .31208 L
.1738 .31229 L
.174 .3125 L
.17418 .31268 L
.17436 .31285 L
.17456 .31301 L
.17474 .31315 L
.17494 .31328 L
.17513 .31339 L
.17531 .31348 L
.17551 .31356 L
.1757 .31361 L
.1758 .31363 L
.17589 .31365 L
.17594 .31366 L
.17599 .31366 L
.17603 .31367 L
.17608 .31367 L
.1761 .31367 L
.17612 .31367 L
.17613 .31367 L
.17614 .31367 L
.17615 .31367 L
.17616 .31367 L
.17617 .31367 L
.17617 .31367 L
.17618 .31367 L
.17618 .31367 L
.17618 .31367 L
.17619 .31367 L
.17619 .31367 L
.1762 .31367 L
.1762 .31367 L
.17621 .31367 L
.17621 .31367 L
Mistroke
.17622 .31367 L
.17623 .31367 L
.17625 .31367 L
.17627 .31367 L
.1763 .31367 L
.17632 .31367 L
.17636 .31367 L
.17641 .31366 L
.17646 .31365 L
.17656 .31364 L
.17666 .31362 L
.17686 .31356 L
.17705 .31349 L
.17724 .3134 L
.17743 .31329 L
.17762 .31317 L
.1778 .31303 L
.178 .31287 L
.17818 .31271 L
.17838 .31252 L
.17857 .31232 L
.17876 .31211 L
.17895 .31188 L
.17914 .31165 L
.17934 .3114 L
.17953 .31114 L
.17972 .31089 L
.17991 .31061 L
.1801 .31033 L
.18029 .31007 L
.18048 .30978 L
.18067 .3095 L
.18087 .3092 L
.18106 .30891 L
.18124 .30863 L
.18144 .30834 L
.18163 .30806 L
.18181 .3078 L
.182 .30752 L
.18219 .30726 L
.18239 .30699 L
.18258 .30674 L
.18276 .30651 L
.18296 .30628 L
.18314 .30606 L
.18334 .30584 L
.18354 .30565 L
.18372 .30547 L
.18392 .3053 L
.18411 .30515 L
Mistroke
.18429 .30502 L
.18448 .3049 L
.18467 .30479 L
.18487 .3047 L
.18506 .30463 L
.18524 .30458 L
.18534 .30456 L
.18539 .30456 L
.18544 .30455 L
.18549 .30454 L
.18553 .30454 L
.18557 .30453 L
.18562 .30453 L
.18564 .30453 L
.18566 .30453 L
.18568 .30453 L
.18568 .30453 L
.18569 .30453 L
.1857 .30453 L
.1857 .30453 L
.1857 .30453 L
.18571 .30453 L
.18571 .30453 L
.18572 .30453 L
.18573 .30453 L
.18573 .30453 L
.18573 .30453 L
.18574 .30453 L
.18575 .30453 L
.18576 .30453 L
.18578 .30453 L
.1858 .30453 L
.18583 .30453 L
.18585 .30453 L
.1859 .30454 L
.18595 .30454 L
.186 .30455 L
.1861 .30457 L
.1862 .30459 L
.18638 .30464 L
.18658 .30471 L
.18677 .3048 L
.18695 .3049 L
.18714 .30502 L
.18733 .30515 L
.18752 .3053 L
.18771 .30547 L
.1879 .30564 L
.18809 .30584 L
.18828 .30604 L
Mistroke
.18848 .30626 L
.18867 .30649 L
.18886 .30672 L
.18905 .30697 L
.18924 .30722 L
.18942 .30747 L
.18962 .30774 L
.1898 .308 L
.19 .30829 L
.19019 .30856 L
.19038 .30883 L
.19057 .30911 L
.19076 .30939 L
.19096 .30968 L
.19115 .30995 L
.19134 .31021 L
.19154 .31048 L
.19173 .31074 L
.19191 .31098 L
.1921 .31122 L
.19229 .31145 L
.19249 .31169 L
.19268 .3119 L
.19287 .31209 L
.19306 .31229 L
.19325 .31246 L
.19343 .31261 L
.19363 .31276 L
.19381 .31289 L
.19401 .31301 L
.1942 .31311 L
.19438 .31319 L
.19458 .31326 L
.19477 .31331 L
.19487 .31333 L
.19492 .31334 L
.19497 .31335 L
.19501 .31335 L
.19506 .31336 L
.19511 .31336 L
.19513 .31336 L
.19515 .31336 L
.19518 .31336 L
.19519 .31336 L
.1952 .31336 L
.19521 .31336 L
.19521 .31336 L
.19522 .31336 L
.19522 .31336 L
.19523 .31336 L
Mistroke
.19524 .31336 L
.19524 .31336 L
.19524 .31336 L
.19525 .31336 L
.19526 .31336 L
.19526 .31336 L
.19527 .31336 L
.19527 .31336 L
.19528 .31336 L
.1953 .31336 L
.19532 .31336 L
.19534 .31336 L
.19539 .31336 L
.19544 .31335 L
.19552 .31334 L
.19562 .31333 L
.19571 .31331 L
.1959 .31326 L
.1961 .31319 L
.19629 .3131 L
.19647 .31301 L
.19667 .31289 L
.19686 .31276 L
.19704 .31262 L
.19724 .31245 L
.19743 .31228 L
.19762 .31209 L
.19782 .31189 L
.198 .31169 L
.1982 .31146 L
.19838 .31124 L
.19857 .31101 L
.19876 .31076 L
.19894 .31052 L
.19914 .31025 L
.19933 .30999 L
.19952 .30974 L
.19971 .30946 L
.1999 .3092 L
.2001 .30891 L
.20029 .30864 L
.20048 .30838 L
.20067 .30811 L
.20086 .30785 L
.20104 .30761 L
.20124 .30736 L
.20142 .30712 L
.20162 .30687 L
.20181 .30665 L
.202 .30644 L
Mistroke
.20219 .30622 L
.20238 .30603 L
.20256 .30586 L
.20276 .30568 L
.20294 .30553 L
.20314 .30538 L
.20333 .30525 L
.20351 .30514 L
.20371 .30504 L
.20389 .30496 L
.20409 .30489 L
.20419 .30486 L
.20428 .30484 L
.20438 .30482 L
.20447 .30481 L
.20456 .3048 L
.20461 .30479 L
.20463 .30479 L
.20466 .30479 L
.20468 .30479 L
.20471 .30479 L
.20472 .30479 L
.20473 .30479 L
.20473 .30479 L
.20474 .30479 L
.20475 .30479 L
.20475 .30479 L
.20475 .30479 L
.20476 .30479 L
.20476 .30479 L
.20476 .30479 L
.20477 .30479 L
.20477 .30479 L
.20477 .30479 L
.20478 .30479 L
.20478 .30479 L
.20479 .30479 L
.2048 .30479 L
.20481 .30479 L
.20482 .30479 L
.20483 .30479 L
.20486 .30479 L
.20488 .30479 L
.2049 .30479 L
.20495 .3048 L
.205 .3048 L
.20505 .30481 L
.20515 .30482 L
.20525 .30484 L
.20543 .30489 L
Mistroke
.20562 .30496 L
.20581 .30504 L
.20601 .30514 L
.2062 .30525 L
.20638 .30538 L
.20658 .30552 L
.20676 .30568 L
.20696 .30585 L
.20716 .30604 L
.20734 .30622 L
.20754 .30644 L
.20773 .30665 L
.20791 .30686 L
.20811 .3071 L
.20829 .30733 L
.20849 .30759 L
.20868 .30784 L
.20887 .30809 L
.20907 .30836 L
.20925 .30862 L
.20944 .30887 L
.20963 .30913 L
.20981 .30939 L
.21001 .30966 L
.2102 .30992 L
.21039 .31016 L
.21058 .31041 L
.21077 .31065 L
.21097 .3109 L
.21116 .31113 L
.21135 .31135 L
.21154 .31156 L
.21173 .31176 L
.21191 .31195 L
.21211 .31213 L
.2123 .31229 L
.21249 .31245 L
.21269 .31259 L
.21287 .31271 L
.21306 .31282 L
.21325 .31291 L
.21343 .31299 L
.21363 .31305 L
.21381 .3131 L
.21391 .31312 L
.21396 .31313 L
.21401 .31313 L
.21406 .31314 L
.2141 .31314 L
.21415 .31315 L
Mistroke
.21419 .31315 L
.21422 .31315 L
.21423 .31315 L
.21424 .31315 L
.21425 .31315 L
.21426 .31315 L
.21427 .31315 L
.21427 .31315 L
.21428 .31315 L
.21428 .31315 L
.21429 .31315 L
.21429 .31315 L
.21429 .31315 L
.2143 .31315 L
.21431 .31315 L
.21431 .31315 L
.21432 .31315 L
.21433 .31315 L
.21436 .31315 L
.21438 .31315 L
.2144 .31315 L
.21443 .31315 L
.21448 .31314 L
.21453 .31314 L
.21458 .31313 L
.21467 .31312 L
.21476 .3131 L
.21494 .31306 L
.21514 .31299 L
.21533 .31291 L
.21551 .31282 L
.21571 .3127 L
.2159 .31258 L
.2161 .31244 L
.21629 .31228 L
.21647 .31212 L
.21667 .31194 L
.21686 .31175 L
.21704 .31156 L
.21724 .31135 L
.21742 .31114 L
.21762 .3109 L
.21781 .31067 L
.218 .31044 L
.21819 .31018 L
.21838 .30994 L
.21856 .3097 L
.21875 .30944 L
.21894 .30919 L
.21914 .30892 L
Mistroke
.21933 .30867 L
.21951 .30842 L
.2197 .30816 L
.21989 .30792 L
.22009 .30766 L
.22028 .30742 L
.22047 .3072 L
.22066 .30696 L
.22085 .30675 L
.22103 .30655 L
.22123 .30635 L
.22141 .30617 L
.22161 .30598 L
.2218 .30582 L
.22198 .30567 L
.22218 .30553 L
.22237 .30541 L
.22257 .30529 L
.22276 .3052 L
.22294 .30512 L
.22314 .30506 L
.22324 .30503 L
.22333 .30501 L
.22342 .30499 L
.22351 .30498 L
.22356 .30497 L
.22361 .30497 L
.22366 .30496 L
.2237 .30496 L
.22372 .30496 L
.22373 .30496 L
.22375 .30496 L
.22376 .30496 L
.22377 .30496 L
.22378 .30496 L
.22378 .30496 L
.22379 .30496 L
.22379 .30496 L
.2238 .30496 L
.2238 .30496 L
.22381 .30496 L
.22381 .30496 L
.22381 .30496 L
.22382 .30496 L
.22382 .30496 L
.22383 .30496 L
.22384 .30496 L
.22385 .30496 L
.22386 .30496 L
.22389 .30496 L
Mistroke
.22391 .30496 L
.22394 .30496 L
.22399 .30496 L
.22403 .30497 L
.22408 .30497 L
.22417 .30498 L
.22427 .305 L
.22446 .30505 L
.22465 .30511 L
.22485 .30519 L
.22504 .30528 L
.22522 .30539 L
.22542 .30551 L
.22561 .30565 L
.22579 .30579 L
.22598 .30595 L
.22617 .30612 L
.22636 .30631 L
.22656 .30651 L
.22674 .3067 L
.22693 .30692 L
.22712 .30714 L
.22732 .30738 L
.22751 .30762 L
.2277 .30785 L
.22789 .30811 L
.22808 .30835 L
.22827 .30859 L
.22846 .30885 L
.22865 .3091 L
.22885 .30936 L
.22904 .30961 L
.22922 .30985 L
.22942 .31011 L
.2296 .31035 L
.22979 .31057 L
.22998 .3108 L
.23016 .31102 L
.23036 .31124 L
.23055 .31145 L
.23073 .31163 L
.23093 .31182 L
.23112 .31199 L
.23131 .31216 L
.23151 .31231 L
.23169 .31245 L
.23189 .31257 L
.23208 .31268 L
.23226 .31277 L
.23245 .31285 L
Mistroke
.23264 .31292 L
.23273 .31294 L
.23284 .31297 L
.23294 .31299 L
.23303 .313 L
.23312 .31301 L
.23317 .31302 L
.2332 .31302 L
.23322 .31302 L
.23324 .31302 L
.23327 .31302 L
.23328 .31302 L
.23329 .31302 L
.2333 .31302 L
.23331 .31302 L
.23331 .31302 L
.23332 .31302 L
.23332 .31302 L
.23333 .31302 L
.23333 .31302 L
.23334 .31302 L
.23334 .31302 L
.23335 .31302 L
.23336 .31302 L
.23336 .31302 L
.23337 .31302 L
.23338 .31302 L
.23341 .31302 L
.23343 .31302 L
.23346 .31302 L
.2335 .31301 L
.23355 .31301 L
.2336 .31301 L
.23369 .31299 L
.23379 .31297 L
.23399 .31293 L
.23418 .31286 L
.23437 .31279 L
.23456 .3127 L
.23475 .31259 L
.23495 .31247 L
.23514 .31233 L
.23533 .31219 L
.23553 .31202 L
.23572 .31185 L
.2359 .31167 L
.23609 .31148 L
.23628 .31128 L
.23648 .31106 L
.23667 .31084 L
Mistroke
.23685 .31062 L
.23705 .31038 L
.23724 .31014 L
.23742 .30991 L
.23761 .30966 L
.2378 .30942 L
.238 .30916 L
.23819 .30891 L
.23837 .30867 L
.23857 .30841 L
.23875 .30817 L
.23895 .30792 L
.23915 .30768 L
.23933 .30745 L
.23953 .30722 L
.23972 .307 L
.2399 .3068 L
.24009 .30659 L
.24028 .3064 L
.24048 .30621 L
.24067 .30604 L
.24085 .30589 L
.24105 .30574 L
.24124 .3056 L
.24142 .30549 L
.24161 .30538 L
.2418 .30529 L
.242 .30521 L
.24219 .30515 L
.24237 .3051 L
.24246 .30509 L
.24256 .30507 L
.24261 .30507 L
.24267 .30506 L
.24272 .30506 L
.24276 .30505 L
.24279 .30505 L
.2428 .30505 L
.24281 .30505 L
.24282 .30505 L
.24283 .30505 L
.24283 .30505 L
.24284 .30505 L
.24284 .30505 L
.24285 .30505 L
.24285 .30505 L
.24286 .30505 L
.24287 .30505 L
.24287 .30505 L
.24287 .30505 L
Mistroke
.24288 .30505 L
.24288 .30505 L
.24289 .30505 L
.2429 .30505 L
.24291 .30505 L
.24293 .30505 L
.24295 .30505 L
.24297 .30506 L
.243 .30506 L
.24304 .30506 L
.24309 .30506 L
.24314 .30507 L
.24323 .30508 L
.24333 .3051 L
.24353 .30515 L
.24371 .30521 L
.24391 .30529 L
.24411 .30538 L
.24429 .30549 L
.24449 .30561 L
.24468 .30575 L
.24486 .30589 L
.24505 .30605 L
.24524 .30621 L
.24544 .3064 L
.24563 .3066 L
.24581 .30679 L
.24601 .30701 L
.2462 .30722 L
.24638 .30744 L
.24657 .30767 L
.24676 .3079 L
.24695 .30815 L
.24714 .30839 L
.24733 .30863 L
.24752 .30888 L
.24771 .30912 L
.24791 .30938 L
.2481 .30963 L
.24828 .30987 L
.24848 .31012 L
.24867 .31035 L
.24885 .31057 L
.24904 .3108 L
.24923 .31101 L
.24943 .31123 L
.24962 .31143 L
.2498 .31161 L
.25 .3118 L
.25018 .31197 L
Mistroke
.25038 .31213 L
.25058 .31228 L
.25076 .31241 L
.25096 .31253 L
.25115 .31264 L
.25133 .31272 L
.25152 .3128 L
.25171 .31286 L
.25181 .31289 L
.25191 .31291 L
.252 .31293 L
.2521 .31294 L
.25215 .31295 L
.2522 .31295 L
.25222 .31295 L
.25225 .31295 L
.25227 .31296 L
.2523 .31296 L
.25231 .31296 L
.25232 .31296 L
.25233 .31296 L
.25234 .31296 L
.25235 .31296 L
.25236 .31296 L
.25237 .31296 L
.25237 .31296 L
.25238 .31296 L
.25238 .31296 L
.25239 .31296 L
.25239 .31296 L
.2524 .31296 L
.2524 .31296 L
.25241 .31296 L
.25242 .31296 L
.25243 .31296 L
.25244 .31296 L
.25246 .31296 L
.25249 .31296 L
.25253 .31295 L
.25258 .31295 L
.25268 .31294 L
.25278 .31292 L
.25286 .31291 L
.25306 .31286 L
.25324 .3128 L
.25344 .31272 L
.25363 .31263 L
.25381 .31253 L
.254 .31241 L
.25419 .31228 L
Mistroke
.25438 .31213 L
.25457 .31197 L
.25476 .31181 L
.25495 .31162 L
.25514 .31144 L
.25534 .31123 L
.25553 .31101 L
.25572 .3108 L
.25591 .31057 L
.2561 .31034 L
.25629 .31012 L
.25648 .30987 L
.25667 .30964 L
.25686 .30938 L
.25706 .30913 L
.25724 .30889 L
.25744 .30864 L
.25762 .3084 L
.25781 .30817 L
.258 .30792 L
.25818 .30769 L
.25838 .30746 L
.25857 .30723 L
.25875 .30702 L
.25895 .30681 L
.25914 .30661 L
.25934 .30642 L
.25953 .30623 L
.25971 .30607 L
.25991 .30591 L
.2601 .30576 L
.26028 .30564 L
.26047 .30552 L
.26066 .30541 L
.26086 .30532 L
.26105 .30524 L
.26123 .30518 L
.26133 .30515 L
.26143 .30513 L
.26152 .30512 L
.26161 .3051 L
.26171 .30509 L
.26176 .30509 L
.26178 .30509 L
.26181 .30509 L
.26183 .30509 L
.26185 .30508 L
.26186 .30508 L
.26188 .30508 L
.26188 .30508 L
Mistroke
.26189 .30508 L
.26189 .30508 L
.26189 .30508 L
.2619 .30508 L
.26191 .30508 L
.26191 .30508 L
.26192 .30508 L
.26192 .30508 L
.26193 .30508 L
.26194 .30508 L
.26195 .30508 L
.26196 .30508 L
.26197 .30508 L
.26199 .30509 L
.26201 .30509 L
.26204 .30509 L
.26208 .30509 L
.26213 .30509 L
.26218 .3051 L
.26227 .30511 L
.26237 .30513 L
.26256 .30518 L
.26275 .30524 L
.26295 .30532 L
.26315 .30541 L
.26333 .30551 L
.26353 .30564 L
.26372 .30577 L
.2639 .30591 L
.2641 .30607 L
.26428 .30623 L
.26448 .30642 L
.26467 .30661 L
.26486 .30681 L
.26505 .30702 L
.26524 .30724 L
.26542 .30745 L
.26562 .30768 L
.2658 .30791 L
.266 .30816 L
.26619 .30841 L
.26638 .30864 L
.26657 .3089 L
.26676 .30914 L
.26696 .3094 L
.26715 .30965 L
.26734 .30988 L
.26753 .31013 L
.26772 .31036 L
.2679 .31058 L
Mistroke
.2681 .31081 L
.26829 .31102 L
.26848 .31124 L
.26868 .31144 L
.26886 .31163 L
.26906 .31181 L
.26924 .31198 L
.26942 .31213 L
.26962 .31228 L
.2698 .31241 L
.27 .31253 L
.27019 .31263 L
.27037 .31272 L
.27057 .3128 L
.27076 .31286 L
.27085 .31289 L
.27096 .31291 L
.27105 .31293 L
.27115 .31294 L
.27119 .31295 L
.27124 .31295 L
.27127 .31295 L
.2713 .31295 L
.27132 .31296 L
.27134 .31296 L
.27136 .31296 L
.27137 .31296 L
.27138 .31296 L
.27139 .31296 L
.2714 .31296 L
.27141 .31296 L
.27141 .31296 L
.27142 .31296 L
.27142 .31296 L
.27143 .31296 L
.27144 .31296 L
.27144 .31296 L
.27144 .31296 L
.27145 .31296 L
.27145 .31296 L
.27146 .31296 L
.27147 .31296 L
.27149 .31296 L
.27151 .31296 L
.27153 .31296 L
.27158 .31295 L
.27163 .31295 L
.27173 .31294 L
.27182 .31292 L
.27191 .31291 L
Mistroke
.27211 .31286 L
.27229 .3128 L
.27249 .31272 L
.27268 .31263 L
.27286 .31253 L
.27305 .31241 L
.27324 .31228 L
.27344 .31212 L
.27363 .31196 L
.27381 .3118 L
.27401 .31161 L
.2742 .31142 L
.27438 .31123 L
.27457 .31102 L
.27476 .31081 L
.27495 .31058 L
.27514 .31035 L
.27533 .31012 L
.27552 .30988 L
.27571 .30964 L
.27591 .30938 L
.2761 .30913 L
.27628 .30889 L
.27648 .30863 L
.27667 .30839 L
.27685 .30816 L
.27704 .30791 L
.27723 .30768 L
.27743 .30744 L
.27762 .30722 L
.2778 .30701 L
.278 .30679 L
.27819 .30659 L
.27838 .30639 L
.27858 .30621 L
.27876 .30604 L
.27896 .30588 L
.27915 .30573 L
.27933 .30561 L
.27953 .30548 L
.27971 .30538 L
.27991 .30528 L
.2801 .30521 L
.28029 .30515 L
.28038 .30512 L
.28048 .3051 L
.28058 .30508 L
.28067 .30507 L
.28072 .30506 L
.28076 .30506 L
Mistroke
.28081 .30506 L
.28084 .30506 L
.28086 .30505 L
.28089 .30505 L
.2809 .30505 L
.28091 .30505 L
.28093 .30505 L
.28093 .30505 L
.28094 .30505 L
.28094 .30505 L
.28095 .30505 L
.28095 .30505 L
.28096 .30505 L
.28096 .30505 L
.28097 .30505 L
.28097 .30505 L
.28098 .30505 L
.28098 .30505 L
.281 .30505 L
.28101 .30505 L
.28103 .30505 L
.28105 .30505 L
.2811 .30506 L
.28115 .30506 L
.28123 .30507 L
.28134 .30508 L
.28143 .3051 L
.28162 .30515 L
.28181 .30521 L
.282 .30529 L
.28218 .30538 L
.28238 .30548 L
.28256 .3056 L
.28276 .30574 L
.28295 .30589 L
.28314 .30604 L
.28333 .30621 L
.28352 .30639 L
.28372 .30659 L
.28391 .3068 L
.28409 .307 L
.28429 .30723 L
.28448 .30745 L
.28466 .30768 L
.28486 .30792 L
.28504 .30816 L
.28524 .30841 L
.28543 .30866 L
.28562 .3089 L
.28581 .30916 L
Mistroke
.286 .30941 L
.28618 .30964 L
.28638 .30989 L
.28656 .31013 L
.28676 .31038 L
.28695 .31061 L
.28713 .31083 L
.28733 .31105 L
.28751 .31126 L
.28771 .31147 L
.28791 .31167 L
.28809 .31184 L
.28829 .31202 L
.28848 .31218 L
.28866 .31232 L
.28885 .31246 L
.28904 .31258 L
.28923 .31269 L
.28943 .31278 L
.28961 .31286 L
.2898 .31292 L
.28999 .31297 L
.2901 .31299 L
.29019 .313 L
.29024 .31301 L
.29029 .31301 L
.29033 .31302 L
.29038 .31302 L
.2904 .31302 L
.29042 .31302 L
.29043 .31302 L
.29044 .31302 L
.29045 .31302 L
.29045 .31302 L
.29046 .31302 L
.29047 .31302 L
.29047 .31302 L
.29048 .31302 L
.29048 .31302 L
.29049 .31302 L
.29049 .31302 L
.2905 .31302 L
.2905 .31302 L
.29051 .31302 L
.29052 .31302 L
.29054 .31302 L
.29055 .31302 L
.29057 .31302 L
.29062 .31302 L
.29067 .31301 L
Mistroke
.29075 .313 L
.29086 .31299 L
.29095 .31297 L
.29114 .31293 L
.29133 .31286 L
.29152 .31279 L
.2917 .3127 L
.29189 .31259 L
.29208 .31247 L
.29228 .31233 L
.29247 .31219 L
.29265 .31203 L
.29284 .31186 L
.29303 .31168 L
.29323 .31147 L
.29342 .31127 L
.29361 .31106 L
.2938 .31084 L
.29399 .31061 L
.29417 .31039 L
.29437 .31014 L
.29455 .3099 L
.29475 .30964 L
.29494 .30939 L
.29512 .30915 L
.29532 .30889 L
.29551 .30864 L
.29571 .30838 L
.2959 .30813 L
.29608 .30789 L
.29628 .30764 L
.29647 .3074 L
.29665 .30718 L
.29685 .30696 L
.29703 .30674 L
.29723 .30653 L
.29742 .30633 L
.29761 .30615 L
.2978 .30597 L
.29799 .30581 L
.29817 .30567 L
.29837 .30553 L
.29855 .30541 L
.29875 .3053 L
.29894 .3052 L
.29912 .30513 L
.29932 .30506 L
.29951 .30501 L
.29961 .30499 L
.29971 .30498 L
Mistroke
.29975 .30497 L
.2998 .30497 L
.29984 .30496 L
.29989 .30496 L
.29991 .30496 L
.29993 .30496 L
.29994 .30496 L
.29995 .30496 L
.29996 .30496 L
.29997 .30496 L
.29998 .30496 L
.29998 .30496 L
.29999 .30496 L
.29999 .30496 L
.3 .30496 L
.3 .30496 L
.30001 .30496 L
.30001 .30496 L
.30001 .30496 L
.30002 .30496 L
.30003 .30496 L
.30003 .30496 L
.30004 .30496 L
.30006 .30496 L
.30008 .30496 L
.30011 .30496 L
.30013 .30496 L
.30018 .30496 L
.30022 .30497 L
.30028 .30497 L
.30037 .30499 L
.30047 .30501 L
.30067 .30506 L
.30086 .30512 L
.30105 .3052 L
.30125 .3053 L
.30143 .3054 L
.30162 .30552 L
.30181 .30566 L
.302 .30581 L
.3022 .30598 L
.30239 .30616 L
.30257 .30634 L
.30277 .30654 L
.30295 .30674 L
.30314 .30695 L
.30333 .30718 L
.30351 .3074 L
.30371 .30765 L
.3039 .30789 L
Mistroke
.30408 .30813 L
.30428 .30839 L
.30447 .30864 L
.30467 .30891 L
.30486 .30917 L
.30504 .30942 L
.30524 .30968 L
.30543 .30993 L
.30561 .31017 L
.3058 .31042 L
.30599 .31066 L
.30619 .3109 L
.30638 .31113 L
.30656 .31134 L
.30676 .31155 L
.30694 .31175 L
.30714 .31195 L
.30734 .31212 L
.30752 .31228 L
.30772 .31244 L
.30791 .31258 L
.30809 .3127 L
.30829 .31281 L
.30847 .31291 L
.30867 .31299 L
.30886 .31305 L
.30905 .3131 L
.30914 .31312 L
.30924 .31313 L
.30929 .31314 L
.30934 .31314 L
.30938 .31315 L
.30942 .31315 L
.30945 .31315 L
.30946 .31315 L
.30947 .31315 L
.30948 .31315 L
.30949 .31315 L
.30949 .31315 L
.3095 .31315 L
.3095 .31315 L
.30951 .31315 L
.30951 .31315 L
.30952 .31315 L
.30952 .31315 L
.30953 .31315 L
.30953 .31315 L
.30954 .31315 L
.30955 .31315 L
.30955 .31315 L
Mistroke
.30956 .31315 L
.30958 .31315 L
.30959 .31315 L
.30961 .31315 L
.30964 .31315 L
.30966 .31315 L
.3097 .31314 L
.30976 .31314 L
.3098 .31313 L
.3099 .31312 L
.31 .3131 L
.31019 .31305 L
.31038 .31299 L
.31056 .31291 L
.31076 .31281 L
.31094 .31271 L
.31114 .31258 L
.31133 .31244 L
.31151 .31229 L
.31171 .31212 L
.3119 .31194 L
.3121 .31174 L
.31229 .31154 L
.31247 .31134 L
.31267 .31111 L
.31286 .31088 L
.31304 .31065 L
.31324 .3104 L
.31342 .31016 L
.31362 .3099 L
.31381 .30964 L
.314 .30939 L
.31419 .30912 L
.31438 .30886 L
.31456 .30861 L
.31475 .30834 L
.31494 .30809 L
.31514 .30783 L
.31533 .30758 L
.31551 .30734 L
.31571 .3071 L
.31589 .30687 L
.31609 .30663 L
.31628 .30642 L
.31647 .30622 L
.31667 .30602 L
.31685 .30584 L
.31704 .30568 L
.31723 .30552 L
.31742 .30538 L
Mistroke
.31761 .30525 L
.31781 .30514 L
.31799 .30504 L
.31818 .30496 L
.31837 .30489 L
.31847 .30486 L
.31857 .30484 L
.31866 .30482 L
.31876 .30481 L
.31881 .3048 L
.31886 .3048 L
.31889 .30479 L
.31891 .30479 L
.31894 .30479 L
.31896 .30479 L
.31898 .30479 L
.319 .30479 L
.31901 .30479 L
.31901 .30479 L
.31902 .30479 L
.31903 .30479 L
.31903 .30479 L
.31904 .30479 L
.31904 .30479 L
.31905 .30479 L
.31905 .30479 L
.31906 .30479 L
.31906 .30479 L
.31907 .30479 L
.31907 .30479 L
.31908 .30479 L
.31909 .30479 L
.3191 .30479 L
.31913 .30479 L
.31915 .30479 L
.3192 .30479 L
.31924 .3048 L
.31934 .30481 L
.31943 .30482 L
.31953 .30484 L
.31973 .30489 L
.31991 .30496 L
.32011 .30504 L
.3203 .30514 L
.32048 .30525 L
.32068 .30539 L
.32086 .30553 L
.32106 .30569 L
.32125 .30586 L
.32144 .30604 L
Mistroke
.32163 .30624 L
.32182 .30645 L
.32201 .30666 L
.3222 .30689 L
.32238 .30712 L
.32258 .30737 L
.32277 .30762 L
.32296 .30787 L
.32315 .30813 L
.32334 .30839 L
.32354 .30867 L
.32373 .30894 L
.32392 .30921 L
.32411 .30948 L
.3243 .30975 L
.32449 .31 L
.32468 .31027 L
.32487 .31052 L
.32507 .31078 L
.32526 .31103 L
.32544 .31126 L
.32564 .31149 L
.32583 .31171 L
.32601 .31191 L
.3262 .31211 L
.32639 .31229 L
.32658 .31246 L
.32677 .31262 L
.32696 .31276 L
.32715 .3129 L
.32734 .31301 L
.32754 .31311 L
.32773 .3132 L
.32792 .31326 L
.32801 .31329 L
.32811 .31331 L
.32821 .31333 L
.3283 .31335 L
.32835 .31335 L
.32839 .31336 L
.32842 .31336 L
.32845 .31336 L
.32847 .31336 L
.32849 .31336 L
.32852 .31336 L
.32853 .31336 L
.32854 .31336 L
.32855 .31336 L
.32855 .31336 L
.32856 .31336 L
Mistroke
.32856 .31336 L
.32857 .31336 L
.32857 .31336 L
.32858 .31336 L
.32859 .31336 L
.32859 .31336 L
.32859 .31336 L
.3286 .31336 L
.32862 .31336 L
.32863 .31336 L
.32864 .31336 L
.32866 .31336 L
.32868 .31336 L
.32873 .31336 L
.32878 .31335 L
.32888 .31334 L
.32897 .31333 L
.32907 .3133 L
.32927 .31325 L
.32946 .31318 L
.32964 .3131 L
.32983 .31299 L
.33002 .31287 L
.33022 .31274 L
.33041 .31259 L
.33059 .31243 L
.33079 .31225 L
.33098 .31206 L
.33116 .31187 L
.33135 .31165 L
.33154 .31143 L
.33173 .31119 L
.33192 .31095 L
.33211 .31071 L
.3323 .31044 L
.33249 .31018 L
.33269 .3099 L
.33288 .30963 L
.33306 .30936 L
.33326 .30908 L
.33345 .3088 L
.33363 .30854 L
.33383 .30826 L
.33401 .30799 L
.33421 .30771 L
.3344 .30745 L
.33458 .3072 L
.33478 .30694 L
.33497 .3067 L
.33517 .30645 L
Mistroke
.33536 .30623 L
.33554 .30602 L
.33574 .30581 L
.33593 .30562 L
.33611 .30545 L
.33631 .30528 L
.3365 .30514 L
.33669 .305 L
.33689 .30488 L
.33707 .30478 L
.33727 .3047 L
.33745 .30463 L
.33764 .30458 L
.33773 .30456 L
.33778 .30455 L
.33783 .30455 L
.33788 .30454 L
.33792 .30454 L
.33795 .30453 L
.33798 .30453 L
.338 .30453 L
.33803 .30453 L
.33804 .30453 L
.33805 .30453 L
.33806 .30453 L
.33806 .30453 L
.33807 .30453 L
.33807 .30453 L
.33808 .30453 L
.33809 .30453 L
.33809 .30453 L
.3381 .30453 L
.3381 .30453 L
.33811 .30453 L
.33811 .30453 L
.33812 .30453 L
.33813 .30453 L
.33814 .30453 L
.33815 .30453 L
.33817 .30453 L
.33819 .30453 L
.33822 .30453 L
.33827 .30454 L
.33831 .30454 L
.33841 .30455 L
.3385 .30457 L
.3386 .30459 L
.33879 .30465 L
.33898 .30472 L
.33918 .30481 L
Mistroke
.33937 .30492 L
.33955 .30504 L
.33975 .30518 L
.33993 .30533 L
.34013 .30551 L
.34033 .3057 L
.34051 .30589 L
.34071 .30611 L
.3409 .30633 L
.34108 .30655 L
.34127 .3068 L
.34146 .30704 L
.34166 .30731 L
.34185 .30758 L
.34203 .30785 L
.34223 .30813 L
.34242 .30841 L
.3426 .30868 L
.34279 .30897 L
.34298 .30925 L
.34318 .30955 L
.34337 .30984 L
.34355 .31011 L
.34374 .31039 L
.34393 .31066 L
.34413 .31094 L
.34432 .3112 L
.34451 .31145 L
.3447 .3117 L
.34489 .31193 L
.34507 .31214 L
.34527 .31235 L
.34545 .31254 L
.34565 .31273 L
.34584 .3129 L
.34603 .31305 L
.34622 .31319 L
.34641 .31331 L
.34661 .31342 L
.3468 .31351 L
.34699 .31357 L
.34708 .3136 L
.34719 .31363 L
.34728 .31365 L
.34738 .31366 L
.34743 .31366 L
.34747 .31367 L
.34752 .31367 L
.34754 .31367 L
.34756 .31367 L
Mistroke
.34757 .31367 L
.34758 .31367 L
.34759 .31367 L
.3476 .31367 L
.3476 .31367 L
.34761 .31367 L
.34761 .31367 L
.34761 .31367 L
.34762 .31367 L
.34763 .31367 L
.34763 .31367 L
.34764 .31367 L
.34764 .31367 L
.34765 .31367 L
.34766 .31367 L
.34767 .31367 L
.34768 .31367 L
.3477 .31367 L
.34773 .31367 L
.34775 .31367 L
.3478 .31367 L
.34785 .31366 L
.34795 .31365 L
.34804 .31363 L
.34814 .3136 L
.34834 .31354 L
.34853 .31347 L
.34871 .31337 L
.3489 .31326 L
.34909 .31313 L
.34929 .31298 L
.34948 .31282 L
.34967 .31264 L
.34986 .31245 L
.35005 .31224 L
.35023 .31203 L
.35043 .3118 L
.35061 .31156 L
.35081 .3113 L
.351 .31104 L
.35119 .31077 L
.35138 .31049 L
.35157 .31021 L
.35177 .3099 L
.35196 .30961 L
.35215 .30932 L
.35234 .30901 L
.35253 .30871 L
.35272 .30843 L
.35291 .30813 L
Mistroke
.3531 .30784 L
.3533 .30754 L
.35349 .30725 L
.35367 .30698 L
.35387 .30671 L
.35406 .30645 L
.35424 .30621 L
.35443 .30596 L
.35462 .30574 L
.35481 .30551 L
.355 .30531 L
.35519 .30513 L
.35538 .30495 L
.35557 .3048 L
.35577 .30465 L
.35596 .30452 L
.35615 .30442 L
.35634 .30433 L
.35653 .30426 L
.35671 .30421 L
.35681 .30419 L
.35691 .30417 L
.35696 .30417 L
.35698 .30416 L
.35701 .30416 L
.35703 .30416 L
.35706 .30416 L
.35707 .30416 L
.35708 .30416 L
.35709 .30416 L
.35711 .30416 L
.35712 .30416 L
.35712 .30416 L
.35713 .30416 L
.35713 .30416 L
.35714 .30416 L
.35714 .30416 L
.35715 .30416 L
.35716 .30416 L
.35716 .30416 L
.35716 .30416 L
.35717 .30416 L
.35718 .30416 L
.35719 .30416 L
.3572 .30416 L
.35723 .30416 L
.35725 .30416 L
.3573 .30416 L
.35735 .30417 L
.3574 .30418 L
Mistroke
.3575 .30419 L
.3576 .30421 L
.3577 .30424 L
.35788 .3043 L
.35807 .30439 L
.35826 .30449 L
.35846 .30461 L
.35865 .30475 L
.35884 .3049 L
.35903 .30508 L
.35922 .30526 L
.3594 .30545 L
.35959 .30567 L
.35978 .3059 L
.35998 .30615 L
.36017 .3064 L
.36035 .30666 L
.36054 .30694 L
.36073 .30722 L
.36093 .30753 L
.36112 .30783 L
.36131 .30812 L
.3615 .30844 L
.36169 .30875 L
.36187 .30904 L
.36207 .30936 L
.36225 .30967 L
.36245 .30999 L
.36264 .3103 L
.36283 .31059 L
.36302 .31089 L
.36321 .31118 L
.36341 .31148 L
.3636 .31175 L
.36379 .31201 L
.36399 .31227 L
.36418 .3125 L
.36436 .31272 L
.36455 .31293 L
.36474 .31313 L
.36494 .31332 L
.36513 .31348 L
.36531 .31362 L
.36551 .31375 L
.3657 .31386 L
.36588 .31395 L
.36607 .31402 L
.36626 .31407 L
.36635 .31409 L
.3664 .3141 L
Mistroke
.36646 .31411 L
.36651 .31411 L
.36655 .31411 L
.36657 .31412 L
.3666 .31412 L
.36661 .31412 L
.36662 .31412 L
.36663 .31412 L
.36664 .31412 L
.36665 .31412 L
.36665 .31412 L
.36666 .31412 L
.36666 .31412 L
.36666 .31412 L
.36667 .31412 L
.36667 .31412 L
.36668 .31412 L
.36668 .31412 L
.36669 .31412 L
.36669 .31412 L
.3667 .31412 L
.36671 .31412 L
.36672 .31412 L
.36673 .31412 L
.36676 .31412 L
.36678 .31411 L
.36683 .31411 L
.36688 .31411 L
.36693 .3141 L
.36703 .31408 L
.36712 .31406 L
.36722 .31403 L
.36742 .31396 L
.36761 .31387 L
.36779 .31377 L
.36799 .31364 L
.36818 .31349 L
.36838 .31332 L
.36857 .31314 L
.36876 .31295 L
.36895 .31272 L
.36914 .31249 L
.36932 .31226 L
.36952 .312 L
.3697 .31174 L
.3699 .31144 L
.37009 .31115 L
.37028 .31086 L
.37047 .31054 L
.37066 .31023 L
Mistroke
.37084 .30993 L
.37104 .3096 L
.37122 .30928 L
.37142 .30894 L
.37161 .30861 L
.37179 .30829 L
.37199 .30796 L
.37218 .30764 L
.37238 .30731 L
.37257 .30699 L
.37275 .3067 L
.37295 .30639 L
.37314 .30611 L
.37332 .30584 L
.37351 .30558 L
.3737 .30533 L
.3739 .30508 L
.37409 .30486 L
.37427 .30466 L
.37447 .30447 L
.37466 .3043 L
.37486 .30414 L
.37505 .304 L
.37523 .30389 L
.37543 .30379 L
.37562 .30372 L
.3758 .30367 L
.3759 .30365 L
.37595 .30364 L
.376 .30364 L
.37605 .30363 L
.37607 .30363 L
.3761 .30363 L
.37612 .30363 L
.37614 .30363 L
.37615 .30363 L
.37615 .30363 L
.37616 .30363 L
.37617 .30363 L
.37617 .30363 L
.37617 .30363 L
.37618 .30363 L
.37618 .30363 L
.37618 .30363 L
.37619 .30363 L
.37619 .30363 L
.3762 .30363 L
.3762 .30363 L
.37621 .30363 L
.37621 .30363 L
Mistroke
.37621 .30363 L
.37622 .30363 L
.37623 .30363 L
.37624 .30363 L
.37627 .30363 L
.37629 .30363 L
.37633 .30363 L
.37638 .30364 L
.37643 .30364 L
.37648 .30365 L
.37658 .30367 L
.37667 .30369 L
.37677 .30372 L
.37697 .3038 L
.37716 .3039 L
.37735 .30402 L
.37754 .30416 L
.37773 .30431 L
.37791 .30448 L
.37811 .30468 L
.37829 .30488 L
.37849 .30512 L
.37868 .30537 L
.37887 .30562 L
.37906 .3059 L
.37925 .30618 L
.37945 .30649 L
.37964 .30681 L
.37983 .30712 L
.38002 .30746 L
.38021 .30779 L
.3804 .30811 L
.38059 .30847 L
.38078 .30881 L
.38098 .30917 L
.38117 .30952 L
.38135 .30986 L
.38155 .31021 L
.38174 .31055 L
.38192 .31087 L
.38211 .31121 L
.3823 .31153 L
.38249 .31185 L
.38268 .31215 L
.38287 .31243 L
.38306 .31272 L
.38325 .31298 L
.38345 .31324 L
.38364 .31348 L
.38383 .31369 L
Mistroke
.38402 .31389 L
.38421 .31407 L
.38439 .31422 L
.38459 .31437 L
.38477 .31448 L
.38497 .31459 L
.38516 .31466 L
.38526 .31469 L
.38535 .31472 L
.38544 .31473 L
.38549 .31474 L
.38554 .31475 L
.38559 .31475 L
.38561 .31475 L
.38564 .31476 L
.38566 .31476 L
.38567 .31476 L
.38568 .31476 L
.38569 .31476 L
.38569 .31476 L
.3857 .31476 L
.3857 .31476 L
.38571 .31476 L
.38571 .31476 L
.38572 .31476 L
.38572 .31476 L
.38573 .31476 L
.38573 .31476 L
.38574 .31476 L
.38575 .31476 L
.38576 .31476 L
.38578 .31476 L
.3858 .31475 L
.38582 .31475 L
.38587 .31475 L
.38592 .31474 L
.38601 .31473 L
.3861 .31471 L
.38629 .31465 L
.38649 .31457 L
.38668 .31447 L
.38686 .31435 L
.38706 .3142 L
.38725 .31403 L
.38743 .31386 L
.38762 .31365 L
.38781 .31343 L
.388 .31318 L
.38819 .31292 L
.38838 .31265 L
Mistroke
.38857 .31236 L
.38876 .31206 L
.38896 .31172 L
.38915 .31139 L
.38933 .31106 L
.38953 .3107 L
.38972 .31035 L
.3899 .31 L
.3901 .30963 L
.39028 .30926 L
.39048 .30887 L
.39067 .3085 L
.39085 .30814 L
.39105 .30776 L
.39124 .3074 L
.39144 .30702 L
.39163 .30666 L
.39182 .30633 L
.39201 .30598 L
.3922 .30565 L
.39239 .30535 L
.39258 .30505 L
.39277 .30477 L
.39297 .30449 L
.39316 .30424 L
.39334 .30401 L
.39354 .30379 L
.39373 .3036 L
.39391 .30344 L
.3941 .30328 L
.39429 .30315 L
.39448 .30304 L
.39467 .30296 L
.39486 .3029 L
.39495 .30288 L
.395 .30287 L
.39505 .30287 L
.3951 .30286 L
.39513 .30286 L
.39516 .30286 L
.39517 .30286 L
.39518 .30286 L
.39519 .30285 L
.3952 .30285 L
.39521 .30285 L
.39522 .30285 L
.39522 .30285 L
.39522 .30285 L
.39523 .30285 L
.39523 .30285 L
Mistroke
.39524 .30285 L
.39524 .30285 L
.39525 .30285 L
.39525 .30285 L
.39526 .30285 L
.39526 .30285 L
.39528 .30285 L
.39529 .30285 L
.3953 .30286 L
.39532 .30286 L
.39535 .30286 L
.39539 .30286 L
.39544 .30287 L
.39553 .30288 L
.39563 .30291 L
.39573 .30294 L
.39583 .30297 L
.39601 .30305 L
.39621 .30317 L
.39639 .3033 L
.39659 .30346 L
.39679 .30365 L
.39697 .30384 L
.39717 .30407 L
.39736 .30432 L
.39754 .30457 L
.39773 .30486 L
.39792 .30515 L
.39812 .30548 L
.39831 .30581 L
.39849 .30614 L
.39869 .30651 L
.39888 .30687 L
.39906 .30723 L
.39925 .30762 L
.39944 .308 L
.39964 .30842 L
.39983 .30882 L
.40001 .3092 L
.4002 .30962 L
.40039 .31001 L
.40059 .31043 L
.40078 .31083 L
.40097 .31121 L
.40116 .3116 L
.40135 .31197 L
.40154 .31232 L
.40173 .31267 L
.40192 .313 L
.40211 .31334 L
Mistroke
.40231 .31365 L
.40249 .31393 L
.40268 .31421 L
.40287 .31445 L
.40307 .3147 L
.40327 .31491 L
.40345 .31509 L
.40365 .31525 L
.40384 .31539 L
.40402 .3155 L
.40421 .31559 L
.4043 .31562 L
.4044 .31565 L
.40446 .31566 L
.4045 .31567 L
.40455 .31568 L
.4046 .31569 L
.40464 .31569 L
.40467 .31569 L
.40469 .3157 L
.4047 .3157 L
.40472 .3157 L
.40472 .3157 L
.40473 .3157 L
.40474 .3157 L
.40474 .3157 L
.40475 .3157 L
.40475 .3157 L
.40476 .3157 L
.40476 .3157 L
.40477 .3157 L
.40477 .3157 L
.40478 .3157 L
.40478 .3157 L
.40479 .3157 L
.4048 .3157 L
.40481 .3157 L
.40484 .3157 L
.40486 .31569 L
.40489 .31569 L
.40493 .31569 L
.40497 .31568 L
.40506 .31566 L
.40516 .31564 L
.40536 .31557 L
.40555 .31547 L
.40575 .31535 L
.40594 .3152 L
.40612 .31503 L
.40632 .31483 L
Mistroke
.40651 .31461 L
.40669 .31438 L
.40688 .31411 L
.40707 .31383 L
.40727 .31351 L
.40746 .31318 L
.40764 .31285 L
.40784 .31248 L
.40802 .31211 L
.40822 .3117 L
.40842 .3113 L
.4086 .3109 L
.4088 .31046 L
.40899 .31004 L
.40917 .30962 L
.40937 .30918 L
.40955 .30875 L
.40975 .30829 L
.40994 .30785 L
.41013 .30743 L
.41032 .30698 L
.41051 .30656 L
.41069 .30616 L
.41089 .30575 L
.41107 .30537 L
.41127 .30497 L
.41146 .3046 L
.41164 .30426 L
.41184 .30392 L
.41203 .30361 L
.41223 .3033 L
.41242 .30303 L
.4126 .30278 L
.4128 .30255 L
.41299 .30235 L
.41317 .30218 L
.41336 .30203 L
.41355 .30191 L
.41365 .30185 L
.41375 .30181 L
.41384 .30177 L
.41394 .30174 L
.41403 .30172 L
.41409 .30171 L
.41414 .3017 L
.41418 .3017 L
.41421 .30169 L
.41422 .30169 L
.41423 .30169 L
.41424 .30169 L
Mistroke
.41425 .30169 L
.41426 .30169 L
.41427 .30169 L
.41427 .30169 L
.41428 .30169 L
.41428 .30169 L
.41429 .30169 L
.41429 .30169 L
.4143 .30169 L
.4143 .30169 L
.41431 .30169 L
.41432 .30169 L
.41433 .30169 L
.41435 .30169 L
.41437 .30169 L
.41439 .3017 L
.41442 .3017 L
.41446 .3017 L
.41452 .30171 L
.41461 .30173 L
.4147 .30176 L
.41489 .30184 L
.41508 .30195 L
.41528 .30208 L
.41546 .30224 L
.41565 .30243 L
.41584 .30265 L
.41602 .30288 L
.41622 .30315 L
.4164 .30344 L
.4166 .30376 L
.41679 .3041 L
.41697 .30445 L
.41717 .30483 L
.41736 .30522 L
.41756 .30565 L
.41775 .30608 L
.41793 .30651 L
.41813 .30698 L
.41832 .30744 L
.4185 .30789 L
.41869 .30838 L
.41888 .30885 L
.41908 .30935 L
.41927 .30984 L
.41945 .31031 L
.41965 .3108 L
.41984 .31127 L
.42004 .31177 L
.42023 .31223 L
Mistroke
.42041 .31267 L
.42061 .31312 L
.4208 .31354 L
.42098 .31393 L
.42118 .31433 L
.42136 .31469 L
.42156 .31506 L
.42176 .31538 L
.42194 .31568 L
.42214 .31596 L
.42232 .31621 L
.42251 .31642 L
.4227 .31662 L
.42289 .31679 L
.42308 .31693 L
.42327 .31703 L
.42337 .31707 L
.42346 .3171 L
.42355 .31713 L
.4236 .31714 L
.42365 .31715 L
.4237 .31715 L
.42372 .31716 L
.42374 .31716 L
.42375 .31716 L
.42376 .31716 L
.42377 .31716 L
.42378 .31716 L
.42378 .31716 L
.42379 .31716 L
.42379 .31716 L
.4238 .31716 L
.4238 .31716 L
.42381 .31716 L
.42381 .31716 L
.42382 .31716 L
.42383 .31716 L
.42383 .31716 L
.42384 .31716 L
.42385 .31716 L
.42386 .31716 L
.42389 .31716 L
.42391 .31716 L
.42393 .31715 L
.42398 .31715 L
.42402 .31714 L
.42412 .31712 L
.42422 .31709 L
.42442 .317 L
.42461 .31688 L
Mistroke
.42479 .31673 L
.42498 .31655 L
.42517 .31634 L
.42537 .31608 L
.42557 .31581 L
.42575 .31552 L
.42595 .31518 L
.42614 .31483 L
.42632 .31446 L
.42651 .31405 L
.4267 .31364 L
.4269 .31318 L
.42709 .31271 L
.42727 .31225 L
.42747 .31174 L
.42766 .31123 L
.42784 .31074 L
.42803 .3102 L
.42822 .30968 L
.42842 .30912 L
.42861 .30858 L
.42879 .30805 L
.42899 .3075 L
.42917 .30697 L
.42937 .30641 L
.42956 .30587 L
.42975 .30537 L
.42995 .30485 L
.43013 .30436 L
.43032 .30391 L
.43051 .30344 L
.4307 .30301 L
.4309 .30258 L
.43109 .30219 L
.43127 .30183 L
.43147 .30148 L
.43165 .30117 L
.43185 .30088 L
.43205 .30062 L
.43223 .30041 L
.43243 .30022 L
.43262 .30007 L
.4328 .29995 L
.4329 .29991 L
.433 .29987 L
.43305 .29985 L
.4331 .29984 L
.43314 .29983 L
.43317 .29983 L
.4332 .29982 L
Mistroke
.43322 .29982 L
.43324 .29982 L
.43326 .29982 L
.43327 .29981 L
.43328 .29981 L
.43329 .29981 L
.4333 .29981 L
.4333 .29981 L
.43331 .29981 L
.43332 .29981 L
.43332 .29981 L
.43332 .29981 L
.43333 .29981 L
.43333 .29981 L
.43333 .29981 L
.43334 .29981 L
.43334 .29981 L
.43335 .29981 L
.43335 .29981 L
.43336 .29981 L
.43337 .29981 L
.43338 .29981 L
.43339 .29981 L
.43341 .29982 L
.43344 .29982 L
.43349 .29982 L
.43353 .29983 L
.43358 .29984 L
.43368 .29987 L
.43376 .29991 L
.43396 .30001 L
.43414 .30014 L
.43434 .30032 L
.43453 .30053 L
.43471 .30076 L
.4349 .30104 L
.43509 .30134 L
.43529 .3017 L
.43548 .30207 L
.43566 .30246 L
.43586 .3029 L
.43604 .30336 L
.43624 .30386 L
.43644 .30438 L
.43662 .30489 L
.43682 .30546 L
.43701 .30602 L
.43719 .30658 L
.43739 .30718 L
.43757 .30778 L
Mistroke
.43777 .30841 L
.43796 .30904 L
.43815 .30964 L
.43834 .31028 L
.43853 .31089 L
.43871 .31148 L
.43891 .3121 L
.43909 .31269 L
.43929 .31331 L
.43948 .31389 L
.43966 .31443 L
.43986 .31498 L
.44005 .3155 L
.44025 .31602 L
.44044 .3165 L
.44062 .31694 L
.44082 .31737 L
.44101 .31776 L
.44119 .3181 L
.44138 .31843 L
.44157 .31871 L
.44177 .31898 L
.44196 .31919 L
.44214 .31936 L
.44224 .31943 L
.44234 .31949 L
.44244 .31955 L
.44253 .31959 L
.44262 .31962 L
.44267 .31963 L
.4427 .31963 L
.44272 .31964 L
.44274 .31964 L
.44277 .31964 L
.44278 .31964 L
.44279 .31965 L
.4428 .31965 L
.44282 .31965 L
.44283 .31965 L
.44283 .31965 L
.44284 .31965 L
.44284 .31965 L
.44285 .31965 L
.44285 .31965 L
.44286 .31965 L
.44286 .31965 L
.44287 .31965 L
.44288 .31965 L
.44288 .31965 L
.44289 .31965 L
Mistroke
.44289 .31965 L
.4429 .31965 L
.44292 .31965 L
.44293 .31965 L
.44295 .31964 L
.44297 .31964 L
.443 .31964 L
.44304 .31963 L
.44309 .31962 L
.44318 .31959 L
.44327 .31955 L
.44347 .31943 L
.44365 .31928 L
.44385 .31907 L
.44404 .31883 L
.44422 .31856 L
.44442 .31824 L
.44461 .31788 L
.44481 .31747 L
.445 .31703 L
.44518 .31658 L
.44538 .31606 L
.44557 .31553 L
.44575 .31499 L
.44594 .31439 L
.44613 .31379 L
.44633 .31312 L
.44652 .31246 L
.4467 .31181 L
.4469 .3111 L
.44709 .3104 L
.44729 .30965 L
.44748 .30892 L
.44767 .30821 L
.44786 .30745 L
.44805 .30672 L
.44823 .30603 L
.44843 .30529 L
.44862 .3046 L
.44881 .30387 L
.44901 .30319 L
.44919 .30255 L
.44939 .30188 L
.44958 .30127 L
.44976 .30071 L
.44995 .30014 L
.45014 .29962 L
.45033 .2991 L
.45053 .29864 L
.45071 .29823 L
Mistroke
.4509 .29784 L
.45109 .2975 L
.45129 .29718 L
.45148 .29693 L
.45167 .29673 L
.45176 .29664 L
.45186 .29656 L
.45196 .2965 L
.45205 .29646 L
.45215 .29642 L
.4522 .2964 L
.45222 .2964 L
.45225 .29639 L
.45227 .29639 L
.45229 .29639 L
.45231 .29639 L
.45232 .29638 L
.45233 .29638 L
.45234 .29638 L
.45235 .29638 L
.45236 .29638 L
.45236 .29638 L
.45237 .29638 L
.45238 .29638 L
.45238 .29638 L
.45239 .29638 L
.45239 .29638 L
.4524 .29638 L
.4524 .29638 L
.45241 .29638 L
.45242 .29638 L
.45243 .29638 L
.45245 .29639 L
.45248 .29639 L
.45252 .2964 L
.45258 .29641 L
.45262 .29642 L
.45272 .29646 L
.45282 .29651 L
.45301 .29666 L
.4532 .29685 L
.45338 .29708 L
.45358 .29738 L
.45377 .29771 L
.45396 .29812 L
.45416 .29855 L
.45434 .29902 L
.45454 .29956 L
.45472 .30012 L
.45491 .30069 L
Mistroke
.4551 .30135 L
.45528 .30201 L
.45548 .30275 L
.45567 .30349 L
.45586 .30423 L
.45605 .30505 L
.45624 .30586 L
.45644 .30674 L
.45663 .3076 L
.45681 .30844 L
.45701 .30935 L
.4572 .31023 L
.45738 .31108 L
.45758 .31198 L
.45776 .31285 L
.45796 .31376 L
.45815 .31462 L
.45834 .31544 L
.45853 .3163 L
.45872 .3171 L
.45892 .31792 L
.45911 .31868 L
.4593 .31939 L
.4595 .3201 L
.45969 .32075 L
.45987 .32133 L
.46006 .32191 L
.46025 .32242 L
.46045 .32291 L
.46064 .32332 L
.46082 .32368 L
.46102 .32399 L
.46121 .32424 L
.46139 .32443 L
.46148 .3245 L
.46158 .32457 L
.46163 .32459 L
.46169 .32461 L
.46174 .32463 L
.46178 .32464 L
.46181 .32464 L
.46182 .32465 L
.46183 .32465 L
.46185 .32465 L
.46186 .32465 L
.46187 .32465 L
.46188 .32465 L
.46189 .32465 L
.46189 .32465 L
.4619 .32465 L
Mistroke
.4619 .32465 L
.46191 .32465 L
.46191 .32465 L
.46192 .32465 L
.46192 .32465 L
.46193 .32465 L
.46194 .32465 L
.46195 .32465 L
.46196 .32465 L
.46197 .32465 L
.462 .32465 L
.46202 .32464 L
.46206 .32463 L
.46211 .32462 L
.46217 .32459 L
.46226 .32454 L
.46236 .32447 L
.46254 .3243 L
.46274 .32405 L
.46292 .32375 L
.46312 .32337 L
.46331 .32294 L
.4635 .32246 L
.46369 .3219 L
.46388 .3213 L
.46408 .3206 L
.46427 .31987 L
.46446 .31913 L
.46465 .31828 L
.46484 .31742 L
.46503 .31655 L
.46522 .31558 L
.46541 .31462 L
.46561 .31356 L
.4658 .3125 L
.46598 .31147 L
.46618 .31034 L
.46637 .30924 L
.46655 .30817 L
.46674 .30702 L
.46693 .30591 L
.46713 .30473 L
.46732 .3036 L
.4675 .30252 L
.46769 .30138 L
.46788 .3003 L
.46808 .29918 L
.46827 .29813 L
.46846 .29715 L
.46866 .29615 L
Mistroke
.46885 .29522 L
.46903 .29437 L
.46922 .29351 L
.46941 .29274 L
.46961 .29197 L
.4698 .2913 L
.46998 .29071 L
.47018 .29016 L
.47037 .28969 L
.47055 .28931 L
.47074 .28897 L
.47092 .28873 L
.47102 .28863 L
.47112 .28855 L
.47117 .28852 L
.47122 .28849 L
.47126 .28847 L
.4713 .28846 L
.47133 .28845 L
.47135 .28845 L
.47137 .28844 L
.47138 .28844 L
.47139 .28844 L
.47139 .28844 L
.4714 .28844 L
.47141 .28844 L
.47141 .28844 L
.47141 .28844 L
.47142 .28844 L
.47143 .28844 L
.47143 .28844 L
.47143 .28844 L
.47144 .28844 L
.47144 .28844 L
.47144 .28844 L
.47145 .28844 L
.47146 .28844 L
.47147 .28844 L
.47148 .28844 L
.4715 .28845 L
.47153 .28845 L
.47155 .28846 L
.4716 .28847 L
.47165 .28849 L
.47169 .28852 L
.47179 .28859 L
.47187 .28867 L
.47206 .28891 L
.47225 .28922 L
.47244 .28963 L
Mistroke
.47263 .29011 L
.47283 .29071 L
.47302 .29138 L
.47321 .2921 L
.4734 .29294 L
.47359 .29383 L
.47377 .29476 L
.47397 .29581 L
.47415 .2969 L
.47435 .29812 L
.47454 .29936 L
.47473 .30061 L
.47492 .30199 L
.47511 .30336 L
.47531 .30488 L
.4755 .30637 L
.47569 .30784 L
.47589 .30944 L
.47608 .311 L
.47626 .31251 L
.47645 .31413 L
.47664 .3157 L
.47684 .31736 L
.47703 .31895 L
.47721 .32047 L
.47741 .32206 L
.4776 .32356 L
.47778 .32497 L
.47797 .32644 L
.47816 .3278 L
.47836 .3292 L
.47855 .33048 L
.47873 .33165 L
.47893 .33282 L
.47912 .33387 L
.47931 .3349 L
.47951 .33579 L
.47969 .33657 L
.47989 .33728 L
.48008 .33787 L
.48026 .33833 L
.48036 .33855 L
.48045 .33871 L
.48055 .33886 L
.48064 .33897 L
.48073 .33905 L
.48078 .33908 L
.48081 .33909 L
.48083 .3391 L
.48085 .33911 L
Mistroke
.48088 .33912 L
.4809 .33912 L
.48091 .33913 L
.48092 .33913 L
.48093 .33913 L
.48093 .33913 L
.48094 .33913 L
.48094 .33913 L
.48095 .33913 L
.48095 .33913 L
.48096 .33913 L
.48096 .33913 L
.48097 .33913 L
.48097 .33913 L
.48098 .33913 L
.48099 .33913 L
.481 .33912 L
.48101 .33912 L
.48104 .33912 L
.48106 .33911 L
.48111 .33908 L
.48116 .33906 L
.4812 .33902 L
.48129 .33893 L
.48139 .33879 L
.48159 .33843 L
.48177 .33795 L
.48197 .33731 L
.48216 .33655 L
.48235 .3357 L
.48254 .33466 L
.48273 .33353 L
.48291 .33232 L
.48311 .33091 L
.48329 .32944 L
.48349 .32775 L
.48368 .32601 L
.48386 .32422 L
.48406 .32222 L
.48425 .32019 L
.48445 .31793 L
.48464 .31566 L
.48482 .3134 L
.48502 .31092 L
.48521 .30846 L
.48539 .30604 L
.48558 .30342 L
.48577 .30085 L
.48597 .29809 L
.48616 .29541 L
Mistroke
.48634 .29282 L
.48654 .29006 L
.48673 .28741 L
.48691 .28488 L
.4871 .28222 L
.48729 .2797 L
.48748 .27708 L
.48767 .27462 L
.48786 .27233 L
.48805 .26998 L
.48824 .26782 L
.48844 .26564 L
.48863 .26367 L
.48881 .26191 L
.48901 .26019 L
.4892 .2587 L
.48938 .25743 L
.48957 .25626 L
.48976 .25532 L
.48986 .25492 L
.48996 .25455 L
.49006 .25424 L
.49015 .25402 L
.49024 .25385 L
.4903 .25378 L
.49032 .25375 L
.49034 .25373 L
.49037 .25371 L
.49039 .25369 L
.4904 .25369 L
.49042 .25368 L
.49043 .25368 L
.49044 .25367 L
.49045 .25367 L
.49046 .25367 L
.49046 .25367 L
.49047 .25367 L
.49047 .25367 L
.49048 .25367 L
.49049 .25367 L
.49049 .25367 L
.4905 .25367 L
.4905 .25367 L
.49051 .25367 L
.49052 .25367 L
.49053 .25368 L
.49055 .25369 L
.49058 .2537 L
.49062 .25374 L
.49067 .2538 L
Mistroke
.49072 .25388 L
.49081 .25407 L
.49092 .25434 L
.49111 .25511 L
.4913 .25614 L
.49149 .25739 L
.49168 .25903 L
.49187 .2609 L
.49207 .26322 L
.49226 .26579 L
.49245 .26856 L
.49265 .27185 L
.49284 .27535 L
.49302 .27902 L
.49321 .28327 L
.4934 .28769 L
.4936 .29275 L
.49379 .29797 L
.49398 .30332 L
.49417 .30935 L
.49436 .3155 L
.49454 .32172 L
.49473 .32868 L
.49492 .33569 L
.49512 .34348 L
.49531 .35131 L
.49549 .35914 L
.49569 .36778 L
.49588 .3764 L
.49607 .38586 L
.49627 .39527 L
.49645 .40459 L
.49665 .41478 L
.49684 .42484 L
.49702 .43474 L
.49721 .44551 L
.4974 .45609 L
.4976 .46756 L
.49779 .47881 L
.49797 .48979 L
.49817 .50165 L
.49836 .51322 L
.49854 .52446 L
.49873 .53656 L
.49892 .54831 L
.49912 .56089 L
.49931 .57309 L
.49949 .58487 L
.49968 .59746 L
.49987 .60961 L
Mistroke
.49992 .61279 L
.49995 .61447 L
.49997 .61625 L
.49998 .617 L
.49999 .61741 L
.5 .6178 L
.5 .61802 L
.5 .00023 L
.50001 .00045 L
.50001 .00065 L
.50002 .00148 L
.50007 .00449 L
.50026 .01668 L
.50046 .02962 L
.50065 .04204 L
.50083 .05393 L
.50103 .06652 L
.50122 .07854 L
.5014 .09001 L
.5016 .10211 L
.50178 .11362 L
.50198 .1257 L
.50217 .13717 L
.50236 .14803 L
.50255 .1594 L
.50274 .17014 L
.50292 .18027 L
.50312 .19083 L
.5033 .20076 L
.5035 .21105 L
.50369 .22071 L
.50388 .22974 L
.50407 .23906 L
.50426 .24775 L
.50446 .25667 L
.50465 .26495 L
.50483 .27262 L
.50503 .28045 L
.50522 .28767 L
.5054 .2943 L
.5056 .30103 L
.50578 .30718 L
.50598 .31337 L
.50617 .31899 L
.50635 .32407 L
.50655 .32912 L
.50674 .33366 L
.50694 .33812 L
.50713 .34206 L
.50732 .34554 L
Mistroke
.50751 .34889 L
.5077 .35179 L
.50789 .35428 L
.50808 .35661 L
.50827 .35855 L
.50847 .3603 L
.50866 .36167 L
.50884 .36271 L
.50894 .36314 L
.50904 .36354 L
.50914 .36385 L
.50923 .36406 L
.50932 .36422 L
.50937 .36429 L
.5094 .36431 L
.50942 .36433 L
.50945 .36434 L
.50947 .36436 L
.50948 .36436 L
.50949 .36436 L
.5095 .36436 L
.5095 .36436 L
.50951 .36437 L
.50951 .36437 L
.50952 .36437 L
.50952 .36437 L
.50953 .36437 L
.50953 .36437 L
.50954 .36437 L
.50954 .36437 L
.50955 .36436 L
.50955 .36436 L
.50956 .36436 L
.50957 .36436 L
.50958 .36435 L
.50961 .36434 L
.50963 .36433 L
.50965 .36431 L
.5097 .36426 L
.50975 .3642 L
.50979 .36413 L
.50988 .36393 L
.50997 .3637 L
.51016 .36304 L
.51034 .36221 L
.51054 .36112 L
.51072 .35989 L
.51092 .3584 L
.51111 .35678 L
.5113 .35509 L
Mistroke
.51149 .35313 L
.51168 .35112 L
.51188 .34886 L
.51207 .34657 L
.51226 .34428 L
.51245 .34175 L
.51264 .33925 L
.51283 .33679 L
.51302 .33412 L
.51321 .33152 L
.51341 .32873 L
.5136 .32603 L
.51378 .32343 L
.51398 .32067 L
.51417 .31804 L
.51435 .31553 L
.51454 .3129 L
.51473 .31041 L
.51493 .30783 L
.51512 .3054 L
.5153 .30314 L
.51549 .30081 L
.51568 .29865 L
.51588 .29646 L
.51607 .29445 L
.51626 .29261 L
.51646 .29077 L
.51664 .28912 L
.51683 .28764 L
.51702 .28618 L
.51721 .2849 L
.51741 .28367 L
.5176 .28262 L
.51778 .28173 L
.51798 .28092 L
.51816 .28027 L
.51835 .27976 L
.51845 .27953 L
.51854 .27936 L
.51863 .2792 L
.51872 .27909 L
.51881 .279 L
.51886 .27896 L
.51889 .27895 L
.51891 .27894 L
.51894 .27893 L
.51896 .27892 L
.51899 .27891 L
.519 .27891 L
.51901 .27891 L
Mistroke
.51902 .27891 L
.51902 .27891 L
.51903 .27891 L
.51903 .27891 L
.51904 .27891 L
.51905 .27891 L
.51905 .27891 L
.51906 .27891 L
.51906 .27891 L
.51907 .27891 L
.51908 .27891 L
.51909 .27891 L
.5191 .27891 L
.51911 .27891 L
.51914 .27892 L
.51916 .27893 L
.51921 .27895 L
.51926 .27898 L
.5193 .27901 L
.51939 .2791 L
.51949 .27923 L
.51968 .27957 L
.51987 .28001 L
.52006 .2806 L
.52025 .28126 L
.52044 .282 L
.52063 .28288 L
.52082 .28382 L
.52102 .28491 L
.52121 .28604 L
.5214 .2872 L
.52159 .2885 L
.52178 .28982 L
.52196 .29114 L
.52216 .29259 L
.52234 .29403 L
.52254 .2956 L
.52273 .29714 L
.52292 .29865 L
.52311 .30027 L
.5233 .30184 L
.5235 .30351 L
.52369 .30512 L
.52388 .30666 L
.52408 .30828 L
.52427 .30982 L
.52445 .31128 L
.52464 .3128 L
.52483 .31422 L
.52503 .31569 L
Mistroke
.52522 .31706 L
.5254 .31833 L
.5256 .31961 L
.52579 .3208 L
.52597 .32187 L
.52616 .32295 L
.52635 .32392 L
.52655 .32487 L
.52674 .32571 L
.52692 .32644 L
.52712 .32714 L
.52731 .32773 L
.5275 .32827 L
.5277 .32871 L
.52788 .32904 L
.52798 .32918 L
.52808 .32931 L
.52818 .32942 L
.52827 .32949 L
.52836 .32954 L
.52841 .32957 L
.52844 .32957 L
.52846 .32958 L
.52848 .32959 L
.52851 .32959 L
.52852 .32959 L
.52853 .32959 L
.52855 .32959 L
.52855 .32959 L
.52855 .32959 L
.52856 .32959 L
.52856 .32959 L
.52857 .32959 L
.52857 .32959 L
.52858 .32959 L
.52859 .32959 L
.52859 .32959 L
.5286 .32959 L
.5286 .32959 L
.52861 .32959 L
.52862 .32959 L
.52865 .32959 L
.52867 .32958 L
.52869 .32958 L
.52874 .32956 L
.52879 .32954 L
.52884 .32951 L
.52893 .32945 L
.52903 .32936 L
.52923 .32911 L
Mistroke
.52942 .3288 L
.5296 .32843 L
.52979 .32796 L
.52998 .32744 L
.53018 .32681 L
.53037 .32615 L
.53055 .32545 L
.53075 .32465 L
.53094 .32382 L
.53112 .32298 L
.53131 .32204 L
.5315 .3211 L
.5317 .32006 L
.53189 .31902 L
.53207 .318 L
.53227 .31688 L
.53245 .31579 L
.53265 .31462 L
.53284 .31348 L
.53303 .31238 L
.53323 .3112 L
.53342 .31007 L
.5336 .309 L
.53379 .30787 L
.53398 .30679 L
.53418 .30567 L
.53437 .30462 L
.53455 .30363 L
.53475 .30262 L
.53493 .30167 L
.53512 .3008 L
.53531 .29992 L
.53549 .29911 L
.53569 .2983 L
.53588 .29758 L
.53606 .29693 L
.53626 .29629 L
.53645 .29573 L
.53664 .2952 L
.53684 .29476 L
.53702 .29438 L
.53722 .29405 L
.53741 .29379 L
.53759 .29361 L
.53768 .29353 L
.53778 .29347 L
.53783 .29344 L
.53788 .29342 L
.53793 .2934 L
.53798 .29339 L
Mistroke
.538 .29339 L
.53802 .29339 L
.53803 .29339 L
.53804 .29338 L
.53805 .29338 L
.53806 .29338 L
.53807 .29338 L
.53807 .29338 L
.53808 .29338 L
.53808 .29338 L
.53809 .29338 L
.53809 .29338 L
.5381 .29338 L
.5381 .29338 L
.53811 .29338 L
.53811 .29338 L
.53812 .29338 L
.53812 .29338 L
.53813 .29338 L
.53814 .29338 L
.53817 .29339 L
.53819 .29339 L
.53822 .29339 L
.53826 .29341 L
.53831 .29342 L
.53835 .29344 L
.53844 .29349 L
.53854 .29355 L
.53874 .29373 L
.53892 .29396 L
.53912 .29426 L
.53931 .29461 L
.5395 .295 L
.53969 .29547 L
.53988 .29596 L
.54008 .29654 L
.54027 .29715 L
.54046 .29777 L
.54065 .29847 L
.54084 .29918 L
.54103 .2999 L
.54122 .30069 L
.54141 .30148 L
.54161 .30234 L
.5418 .30319 L
.54198 .30402 L
.54218 .30492 L
.54237 .30579 L
.54255 .30664 L
.54274 .30754 L
Mistroke
.54293 .3084 L
.54313 .30932 L
.54332 .31019 L
.5435 .31102 L
.54369 .31188 L
.54388 .3127 L
.54408 .31354 L
.54427 .31433 L
.54446 .31506 L
.54466 .31581 L
.54485 .31649 L
.54503 .31712 L
.54522 .31775 L
.54541 .31831 L
.54561 .31887 L
.5458 .31937 L
.54598 .3198 L
.54618 .32021 L
.54637 .32056 L
.54655 .32085 L
.54674 .32111 L
.54692 .32132 L
.54702 .3214 L
.54712 .32148 L
.54722 .32154 L
.54731 .32159 L
.54741 .32162 L
.54746 .32163 L
.54748 .32164 L
.54751 .32164 L
.54753 .32165 L
.54755 .32165 L
.54757 .32165 L
.54758 .32165 L
.54758 .32165 L
.54759 .32165 L
.5476 .32165 L
.5476 .32165 L
.54761 .32165 L
.54761 .32165 L
.54762 .32165 L
.54762 .32165 L
.54763 .32165 L
.54764 .32165 L
.54764 .32165 L
.54765 .32165 L
.54766 .32165 L
.54767 .32165 L
.54769 .32165 L
.54771 .32165 L
Mistroke
.54774 .32164 L
.54778 .32163 L
.54783 .32162 L
.54788 .3216 L
.54798 .32156 L
.54808 .32151 L
.54827 .32136 L
.54846 .32117 L
.54865 .32094 L
.54884 .32065 L
.54903 .32032 L
.54923 .31994 L
.54942 .31952 L
.54961 .31908 L
.5498 .31858 L
.54999 .31806 L
.55017 .31753 L
.55037 .31694 L
.55055 .31634 L
.55075 .31568 L
.55094 .31503 L
.55113 .31437 L
.55132 .31366 L
.55151 .31297 L
.55171 .31222 L
.5519 .31148 L
.55209 .31077 L
.55229 .31002 L
.55248 .30929 L
.55266 .30859 L
.55285 .30786 L
.55304 .30716 L
.55324 .30643 L
.55343 .30575 L
.55361 .3051 L
.55381 .30444 L
.554 .30382 L
.55418 .30325 L
.55437 .30267 L
.55456 .30214 L
.55476 .30161 L
.55495 .30113 L
.55513 .3007 L
.55533 .30028 L
.55552 .29992 L
.55571 .29957 L
.55591 .29927 L
.55609 .29903 L
.55629 .29881 L
.55648 .29864 L
Mistroke
.55666 .29852 L
.55675 .29847 L
.55685 .29843 L
.5569 .29842 L
.55696 .29841 L
.55698 .2984 L
.55701 .2984 L
.55703 .29839 L
.55705 .29839 L
.55708 .29839 L
.55709 .29839 L
.5571 .29839 L
.5571 .29839 L
.55711 .29839 L
.55712 .29839 L
.55712 .29839 L
.55713 .29839 L
.55713 .29839 L
.55713 .29839 L
.55714 .29839 L
.55714 .29839 L
.55715 .29839 L
.55715 .29839 L
.55716 .29839 L
.55716 .29839 L
.55717 .29839 L
.55718 .29839 L
.55719 .29839 L
.55721 .29839 L
.55723 .29839 L
.55726 .29839 L
.55728 .2984 L
.55733 .29841 L
.55737 .29842 L
.55743 .29843 L
.55752 .29847 L
.55762 .29852 L
.55782 .29865 L
.55801 .29882 L
.5582 .29902 L
.55839 .29927 L
.55858 .29955 L
.55876 .29985 L
.55895 .3002 L
.55914 .30058 L
.55934 .30101 L
.55953 .30145 L
.55971 .3019 L
.55991 .30241 L
.56009 .30292 L
Mistroke
.56029 .30349 L
.56049 .30405 L
.56067 .30461 L
.56087 .30522 L
.56106 .30581 L
.56124 .3064 L
.56143 .30702 L
.56162 .30763 L
.56182 .30828 L
.56201 .30891 L
.56219 .3095 L
.56239 .31013 L
.56258 .31073 L
.56276 .3113 L
.56295 .31189 L
.56314 .31244 L
.56333 .31302 L
.56352 .31355 L
.56371 .31404 L
.5639 .31454 L
.56409 .315 L
.56429 .31546 L
.56448 .31587 L
.56466 .31624 L
.56486 .3166 L
.56505 .31692 L
.56523 .31719 L
.56542 .31745 L
.56561 .31766 L
.56581 .31785 L
.566 .318 L
.56618 .3181 L
.56628 .31814 L
.56638 .31818 L
.56643 .31819 L
.56648 .3182 L
.5665 .31821 L
.56653 .31821 L
.56655 .31822 L
.56658 .31822 L
.5666 .31822 L
.56661 .31822 L
.56662 .31822 L
.56663 .31822 L
.56663 .31822 L
.56664 .31822 L
.56665 .31822 L
.56665 .31822 L
.56666 .31822 L
.56666 .31822 L
Mistroke
.56666 .31822 L
.56667 .31822 L
.56667 .31822 L
.56668 .31822 L
.56668 .31822 L
.56669 .31822 L
.56669 .31822 L
.5667 .31822 L
.56671 .31822 L
.56674 .31822 L
.56676 .31822 L
.56678 .31821 L
.56681 .31821 L
.56685 .3182 L
.5669 .31819 L
.56695 .31818 L
.56705 .31815 L
.56715 .31811 L
.56735 .31799 L
.56754 .31784 L
.56773 .31767 L
.56792 .31745 L
.56811 .3172 L
.5683 .31694 L
.56849 .31663 L
.56868 .3163 L
.56888 .31592 L
.56907 .31553 L
.56925 .31513 L
.56945 .31469 L
.56964 .31424 L
.56982 .31379 L
.57001 .31329 L
.5702 .3128 L
.5704 .31227 L
.57059 .31174 L
.57077 .31123 L
.57096 .31068 L
.57115 .31014 L
.57135 .30957 L
.57154 .30902 L
.57173 .3085 L
.57193 .30794 L
.57211 .30742 L
.5723 .30692 L
.57249 .3064 L
.57268 .30591 L
.57288 .30541 L
.57307 .30494 L
.57325 .30451 L
Mistroke
.57345 .30407 L
.57364 .30366 L
.57382 .3033 L
.57401 .30293 L
.57419 .30261 L
.57439 .30229 L
.57458 .30201 L
.57477 .30177 L
.57496 .30154 L
.57515 .30136 L
.57535 .30119 L
.57554 .30106 L
.57572 .30097 L
.57582 .30094 L
.57587 .30092 L
.57592 .30091 L
.57597 .3009 L
.57601 .30089 L
.57606 .30088 L
.57608 .30088 L
.5761 .30088 L
.57611 .30088 L
.57613 .30088 L
.57614 .30088 L
.57615 .30088 L
.57616 .30087 L
.57617 .30087 L
.57617 .30087 L
.57618 .30087 L
.57618 .30087 L
.57619 .30087 L
.5762 .30087 L
.5762 .30087 L
.57621 .30087 L
.57621 .30087 L
.57622 .30087 L
.57623 .30087 L
.57624 .30088 L
.57626 .30088 L
.57628 .30088 L
.57633 .30088 L
.57638 .30089 L
.57642 .3009 L
.57647 .30091 L
.57658 .30094 L
.57667 .30098 L
.57686 .30107 L
.57706 .3012 L
.57724 .30136 L
.57743 .30154 L
Mistroke
.57762 .30176 L
.57781 .30199 L
.57801 .30227 L
.5782 .30257 L
.57838 .30288 L
.57858 .30323 L
.57876 .30359 L
.57896 .30399 L
.57916 .3044 L
.57934 .30481 L
.57954 .30526 L
.57973 .3057 L
.57991 .30614 L
.58011 .30662 L
.58029 .30709 L
.58049 .30759 L
.58068 .30807 L
.58087 .30854 L
.58106 .30904 L
.58125 .30952 L
.58144 .30998 L
.58163 .31046 L
.58182 .31092 L
.58201 .31139 L
.5822 .31184 L
.58239 .31225 L
.58258 .31268 L
.58277 .31308 L
.58297 .31348 L
.58316 .31385 L
.58335 .31418 L
.58354 .31451 L
.58373 .31481 L
.58392 .31507 L
.58411 .31533 L
.5843 .31555 L
.58449 .31575 L
.58469 .31592 L
.58487 .31606 L
.58507 .31617 L
.58516 .31622 L
.58525 .31626 L
.58534 .31629 L
.58544 .31631 L
.58548 .31632 L
.58553 .31633 L
.58558 .31634 L
.58562 .31634 L
.58565 .31634 L
.58566 .31634 L
Mistroke
.58567 .31634 L
.58568 .31634 L
.58569 .31634 L
.5857 .31634 L
.5857 .31634 L
.58571 .31634 L
.58571 .31634 L
.58571 .31634 L
.58572 .31634 L
.58573 .31634 L
.58573 .31634 L
.58574 .31634 L
.58574 .31634 L
.58575 .31634 L
.58577 .31634 L
.58579 .31634 L
.58581 .31634 L
.58585 .31633 L
.5859 .31633 L
.58599 .31631 L
.58609 .31629 L
.58619 .31625 L
.58637 .31617 L
.58657 .31605 L
.58676 .31591 L
.58694 .31575 L
.58713 .31556 L
.58732 .31535 L
.58752 .3151 L
.58771 .31483 L
.58789 .31456 L
.58809 .31424 L
.58827 .31392 L
.58847 .31356 L
.58867 .31319 L
.58885 .31283 L
.58905 .31242 L
.58924 .31202 L
.58942 .31163 L
.58961 .3112 L
.5898 .31078 L
.59 .31032 L
.59019 .30989 L
.59037 .30946 L
.59057 .30901 L
.59076 .30858 L
.59094 .30816 L
.59113 .30773 L
.59132 .30731 L
.59151 .30688 L
Mistroke
.5917 .30648 L
.59189 .3061 L
.59208 .30571 L
.59227 .30535 L
.59247 .30499 L
.59266 .30465 L
.59284 .30435 L
.59304 .30404 L
.59323 .30377 L
.59341 .30353 L
.5936 .30329 L
.59379 .30309 L
.59399 .3029 L
.59418 .30274 L
.59436 .30261 L
.59456 .3025 L
.59475 .30242 L
.59485 .30239 L
.59494 .30237 L
.59499 .30236 L
.59504 .30235 L
.59508 .30234 L
.59513 .30234 L
.59516 .30234 L
.59517 .30234 L
.59518 .30234 L
.59519 .30234 L
.5952 .30234 L
.59521 .30234 L
.59522 .30234 L
.59522 .30234 L
.59523 .30234 L
.59523 .30234 L
.59524 .30234 L
.59524 .30234 L
.59525 .30234 L
.59525 .30234 L
.59525 .30234 L
.59526 .30234 L
.59527 .30234 L
.59527 .30234 L
.59528 .30234 L
.5953 .30234 L
.59532 .30234 L
.59535 .30234 L
.59537 .30234 L
.59542 .30235 L
.59547 .30235 L
.59552 .30236 L
.59561 .30239 L
Mistroke
.59571 .30242 L
.59591 .3025 L
.59611 .30261 L
.59629 .30273 L
.59649 .30289 L
.59668 .30307 L
.59686 .30326 L
.59706 .30349 L
.59724 .30373 L
.59744 .30401 L
.59763 .30429 L
.59782 .30458 L
.59801 .30491 L
.5982 .30524 L
.59838 .30557 L
.59858 .30593 L
.59876 .30629 L
.59896 .30669 L
.59915 .30707 L
.59934 .30745 L
.59953 .30786 L
.59972 .30826 L
.59992 .30868 L
.60011 .30909 L
.60029 .30948 L
.60049 .30989 L
.60068 .31028 L
.60086 .31065 L
.60106 .31104 L
.60124 .3114 L
.60144 .31178 L
.60163 .31213 L
.60182 .31245 L
.60201 .31278 L
.6022 .31308 L
.60238 .31335 L
.60258 .31363 L
.60276 .31387 L
.60296 .31411 L
.60315 .31432 L
.60333 .3145 L
.60353 .31467 L
.60371 .31481 L
.60391 .31494 L
.60411 .31504 L
.60429 .31511 L
.60439 .31513 L
.60443 .31514 L
.60449 .31515 L
.60454 .31516 L
Mistroke
.60458 .31517 L
.60463 .31517 L
.60467 .31518 L
.60469 .31518 L
.60471 .31518 L
.60473 .31518 L
.60473 .31518 L
.60474 .31518 L
.60474 .31518 L
.60475 .31518 L
.60476 .31518 L
.60476 .31518 L
.60477 .31518 L
.60477 .31518 L
.60478 .31518 L
.60479 .31518 L
.6048 .31518 L
.60481 .31518 L
.60483 .31518 L
.60485 .31518 L
.60488 .31518 L
.6049 .31517 L
.60494 .31517 L
.60499 .31516 L
.60504 .31515 L
.60514 .31513 L
.60524 .3151 L
.60544 .31503 L
.60563 .31493 L
.60582 .31481 L
.60601 .31467 L
.6062 .3145 L
.60638 .31432 L
.60658 .31412 L
.60676 .3139 L
.60696 .31364 L
.60715 .31338 L
.60734 .31311 L
.60753 .31281 L
.60772 .31251 L
.6079 .3122 L
.6081 .31187 L
.60828 .31153 L
.60848 .31117 L
.60867 .31081 L
.60885 .31046 L
.60905 .31009 L
.60923 .30972 L
.60943 .30933 L
.60962 .30896 L
Mistroke
.60981 .3086 L
.61 .30821 L
.61019 .30785 L
.61037 .30751 L
.61057 .30715 L
.61075 .30681 L
.61095 .30647 L
.61114 .30614 L
.61133 .30584 L
.61152 .30553 L
.61171 .30525 L
.61191 .30497 L
.6121 .30472 L
.61229 .30449 L
.61248 .30427 L
.61267 .30408 L
.61285 .30391 L
.61305 .30375 L
.61324 .30362 L
.61343 .3035 L
.61363 .30341 L
.61381 .30335 L
.6139 .30332 L
.61401 .3033 L
.61405 .30329 L
.6141 .30329 L
.61414 .30328 L
.61419 .30328 L
.61421 .30328 L
.61422 .30328 L
.61423 .30328 L
.61424 .30328 L
.61425 .30328 L
.61426 .30328 L
.61426 .30328 L
.61427 .30328 L
.61427 .30328 L
.61428 .30328 L
.61428 .30328 L
.61429 .30328 L
.61429 .30328 L
.6143 .30328 L
.6143 .30328 L
.61431 .30328 L
.61431 .30328 L
.61433 .30328 L
.61434 .30328 L
.61435 .30328 L
.61438 .30328 L
.6144 .30328 L
Mistroke
.61442 .30328 L
.61447 .30329 L
.61452 .30329 L
.61457 .3033 L
.61466 .30332 L
.61476 .30335 L
.61495 .30342 L
.61514 .3035 L
.61532 .30361 L
.61552 .30374 L
.6157 .30389 L
.6159 .30407 L
.61609 .30426 L
.61628 .30446 L
.61647 .30469 L
.61666 .30493 L
.61686 .3052 L
.61705 .30548 L
.61723 .30576 L
.61743 .30606 L
.61762 .30637 L
.6178 .30668 L
.618 .30701 L
.61818 .30734 L
.61838 .30769 L
.61857 .30804 L
.61876 .30837 L
.61895 .30873 L
.61914 .30908 L
.61932 .30941 L
.61952 .30976 L
.6197 .31009 L
.6199 .31044 L
.62009 .31077 L
.62027 .31108 L
.62047 .3114 L
.62065 .3117 L
.62085 .31201 L
.62104 .31229 L
.62123 .31255 L
.62142 .31281 L
.62161 .31304 L
.6218 .31325 L
.62199 .31346 L
.62218 .31364 L
.62237 .31381 L
.62256 .31396 L
.62275 .31408 L
.62294 .31419 L
.62313 .31427 L
Mistroke
.62323 .31431 L
.62333 .31434 L
.62342 .31436 L
.62352 .31438 L
.62357 .31439 L
.62362 .3144 L
.62365 .3144 L
.62367 .3144 L
.62369 .3144 L
.62372 .31441 L
.62374 .31441 L
.62376 .31441 L
.62377 .31441 L
.62378 .31441 L
.62378 .31441 L
.62379 .31441 L
.62379 .31441 L
.6238 .31441 L
.62381 .31441 L
.62381 .31441 L
.62382 .31441 L
.62382 .31441 L
.62382 .31441 L
.62383 .31441 L
.62383 .31441 L
.62384 .31441 L
.62385 .31441 L
.62386 .31441 L
.62389 .31441 L
.62391 .31441 L
.62396 .3144 L
.624 .3144 L
.6241 .31438 L
.6242 .31436 L
.62429 .31434 L
.62448 .31428 L
.62467 .31419 L
.62487 .31409 L
.62506 .31396 L
.62524 .31382 L
.62543 .31366 L
.62562 .31348 L
.62582 .31327 L
.62601 .31306 L
.6262 .31284 L
.62639 .31259 L
.62658 .31233 L
.62676 .31207 L
.62696 .31179 L
.62714 .3115 L
Mistroke
.62734 .31119 L
.62753 .31088 L
.62771 .31058 L
.62791 .31025 L
.6281 .30993 L
.6283 .30959 L
.62849 .30925 L
.62867 .30893 L
.62887 .30859 L
.62906 .30827 L
.62924 .30796 L
.62944 .30764 L
.62962 .30733 L
.62982 .30702 L
.63001 .30672 L
.6302 .30644 L
.63039 .30616 L
.63058 .3059 L
.63076 .30566 L
.63095 .30542 L
.63114 .3052 L
.63134 .30499 L
.63153 .3048 L
.63171 .30463 L
.63191 .30447 L
.63209 .30434 L
.63229 .30421 L
.63248 .30412 L
.63267 .30404 L
.63276 .30401 L
.63287 .30398 L
.63296 .30395 L
.63305 .30394 L
.6331 .30393 L
.63315 .30393 L
.63317 .30392 L
.6332 .30392 L
.63322 .30392 L
.63325 .30392 L
.63327 .30392 L
.63329 .30392 L
.63329 .30392 L
.6333 .30392 L
.6333 .30392 L
.63331 .30392 L
.63332 .30392 L
.63332 .30392 L
.63333 .30392 L
.63333 .30392 L
.63334 .30392 L
Mistroke
.63334 .30392 L
.63335 .30392 L
.63335 .30392 L
.63336 .30392 L
.63337 .30392 L
.63338 .30392 L
.63339 .30392 L
.63342 .30392 L
.63344 .30392 L
.63349 .30392 L
.63353 .30393 L
.63362 .30394 L
.63372 .30396 L
.63381 .30398 L
.634 .30404 L
.63418 .30411 L
.63437 .30421 L
.63456 .30433 L
.63476 .30447 L
.63495 .30462 L
.63513 .30478 L
.63533 .30498 L
.63552 .30517 L
.6357 .30538 L
.63589 .30561 L
.63608 .30585 L
.63627 .30611 L
.63646 .30638 L
.63665 .30664 L
.63684 .30693 L
.63703 .30722 L
.63723 .30753 L
.63742 .30784 L
.6376 .30814 L
.6378 .30846 L
.63799 .30877 L
.63817 .30906 L
.63836 .30938 L
.63855 .30968 L
.63875 .31 L
.63894 .31031 L
.63912 .31059 L
.63932 .31089 L
.63951 .31117 L
.63971 .31145 L
.6399 .31172 L
.64008 .31196 L
.64028 .31221 L
.64047 .31243 L
.64065 .31264 L
Mistroke
.64085 .31284 L
.64103 .31302 L
.64123 .31319 L
.64142 .31334 L
.64161 .31347 L
.6418 .31358 L
.64199 .31368 L
.64217 .31375 L
.64227 .31379 L
.64237 .31381 L
.64246 .31384 L
.64255 .31385 L
.64264 .31386 L
.64269 .31387 L
.64272 .31387 L
.64274 .31387 L
.64277 .31387 L
.64279 .31388 L
.6428 .31388 L
.64282 .31388 L
.64282 .31388 L
.64283 .31388 L
.64283 .31388 L
.64284 .31388 L
.64284 .31388 L
.64284 .31388 L
.64285 .31388 L
.64285 .31388 L
.64286 .31388 L
.64286 .31388 L
.64287 .31388 L
.64287 .31388 L
.64288 .31388 L
.64288 .31388 L
.64289 .31388 L
.64289 .31388 L
.64291 .31388 L
.64292 .31388 L
.64294 .31387 L
.64296 .31387 L
.64299 .31387 L
.64304 .31387 L
.64309 .31386 L
.64314 .31386 L
.64324 .31384 L
.64334 .31382 L
.64352 .31376 L
.64371 .31368 L
.6439 .31359 L
.6441 .31347 L
Mistroke
.64429 .31334 L
.64448 .3132 L
.64467 .31303 L
.64486 .31286 L
.64505 .31267 L
.64524 .31246 L
.64543 .31224 L
.64563 .312 L
.64582 .31176 L
.646 .31151 L
.6462 .31124 L
.64638 .31097 L
.64657 .3107 L
.64676 .31042 L
.64694 .31013 L
.64714 .30983 L
.64733 .30953 L
.64751 .30925 L
.64771 .30894 L
.6479 .30865 L
.6481 .30834 L
.64829 .30804 L
.64847 .30776 L
.64867 .30747 L
.64886 .3072 L
.64904 .30694 L
.64923 .30668 L
.64942 .30643 L
.64962 .30618 L
.64981 .30595 L
.64999 .30574 L
.65019 .30554 L
.65038 .30535 L
.65057 .30517 L
.65077 .30501 L
.65095 .30487 L
.65115 .30474 L
.65134 .30463 L
.65152 .30455 L
.65172 .30447 L
.6519 .30442 L
.65201 .3044 L
.6521 .30438 L
.65215 .30437 L
.6522 .30437 L
.65224 .30437 L
.65229 .30436 L
.65231 .30436 L
.65232 .30436 L
.65233 .30436 L
Mistroke
.65234 .30436 L
.65236 .30436 L
.65236 .30436 L
.65237 .30436 L
.65237 .30436 L
.65238 .30436 L
.65239 .30436 L
.65239 .30436 L
.65239 .30436 L
.6524 .30436 L
.6524 .30436 L
.65241 .30436 L
.65242 .30436 L
.65243 .30436 L
.65244 .30436 L
.65246 .30436 L
.65248 .30436 L
.65253 .30437 L
.65258 .30437 L
.65263 .30438 L
.65268 .30438 L
.65277 .3044 L
.65287 .30442 L
.65306 .30448 L
.65325 .30455 L
.65345 .30465 L
.65364 .30476 L
.65383 .30488 L
.65402 .30502 L
.65421 .30518 L
.65439 .30534 L
.65459 .30553 L
.65477 .30573 L
.65497 .30595 L
.65516 .30617 L
.65534 .3064 L
.65554 .30665 L
.65573 .3069 L
.65593 .30717 L
.65612 .30745 L
.6563 .30771 L
.6565 .308 L
.65669 .30828 L
.65687 .30856 L
.65707 .30885 L
.65725 .30913 L
.65745 .30943 L
.65764 .30971 L
.65783 .30999 L
.65802 .31027 L
Mistroke
.65821 .31054 L
.65839 .31079 L
.65859 .31105 L
.65877 .3113 L
.65897 .31154 L
.65916 .31177 L
.65934 .31198 L
.65954 .3122 L
.65972 .31239 L
.65992 .31257 L
.66012 .31274 L
.6603 .31289 L
.6605 .31303 L
.66069 .31314 L
.66087 .31324 L
.66106 .31333 L
.66125 .3134 L
.66134 .31343 L
.66145 .31345 L
.66155 .31347 L
.66164 .31349 L
.66168 .31349 L
.66173 .3135 L
.66176 .3135 L
.66178 .3135 L
.66181 .3135 L
.66183 .3135 L
.66184 .3135 L
.66186 .3135 L
.66187 .3135 L
.66187 .3135 L
.66188 .3135 L
.66188 .3135 L
.66189 .3135 L
.6619 .3135 L
.6619 .3135 L
.66191 .3135 L
.66191 .3135 L
.66192 .3135 L
.66192 .3135 L
.66193 .3135 L
.66194 .3135 L
.66195 .3135 L
.66196 .3135 L
.66197 .3135 L
.662 .3135 L
.66202 .3135 L
.66207 .3135 L
.66211 .31349 L
.66221 .31348 L
Mistroke
.66231 .31346 L
.6624 .31344 L
.66259 .31339 L
.66277 .31332 L
.66297 .31323 L
.66316 .31313 L
.66334 .31301 L
.66353 .31288 L
.66372 .31273 L
.66391 .31256 L
.6641 .31238 L
.66429 .3122 L
.66448 .31199 L
.66467 .31177 L
.66487 .31154 L
.66506 .3113 L
.66524 .31106 L
.66544 .3108 L
.66563 .31055 L
.66581 .31029 L
.666 .31002 L
.66619 .30975 L
.66639 .30947 L
.66658 .30919 L
.66676 .30892 L
.66696 .30864 L
.66715 .30837 L
.66735 .30808 L
.66754 .30781 L
.66772 .30756 L
.66792 .30729 L
.66811 .30704 L
.66829 .30681 L
.66849 .30657 L
.66867 .30636 L
.66887 .30614 L
.66906 .30593 L
.66925 .30575 L
.66944 .30557 L
.66963 .30542 L
.66981 .30528 L
.67001 .30514 L
.67019 .30503 L
.67039 .30492 L
.67058 .30484 L
.67076 .30478 L
.67087 .30475 L
.67096 .30472 L
.67106 .3047 L
.67115 .30469 L
Mistroke
.67119 .30468 L
.67124 .30468 L
.67129 .30468 L
.67131 .30467 L
.67134 .30467 L
.67136 .30467 L
.67138 .30467 L
.67139 .30467 L
.67139 .30467 L
.6714 .30467 L
.67141 .30467 L
.67141 .30467 L
.67142 .30467 L
.67142 .30467 L
.67143 .30467 L
.67143 .30467 L
.67144 .30467 L
.67144 .30467 L
.67145 .30467 L
.67145 .30467 L
.67146 .30467 L
.67147 .30467 L
.67148 .30467 L
.6715 .30467 L
.67152 .30467 L
.67155 .30467 L
.67157 .30468 L
.67162 .30468 L
.67167 .30468 L
.67172 .30469 L
.67181 .30471 L
.67191 .30473 L
.67211 .30478 L
.6723 .30485 L
.67249 .30493 L
.67269 .30504 L
.67288 .30516 L
.67306 .30528 L
.67325 .30543 L
.67344 .30559 L
.67364 .30577 L
.67383 .30596 L
.67401 .30615 L
.67421 .30637 L
.6744 .30658 L
.67458 .3068 L
.67477 .30704 L
.67496 .30728 L
.67515 .30754 L
.67534 .3078 L
Mistroke
.67553 .30805 L
.67572 .30832 L
.67591 .30858 L
.67611 .30886 L
.6763 .30914 L
.67648 .3094 L
.67668 .30967 L
.67687 .30993 L
.67705 .31018 L
.67725 .31044 L
.67743 .31068 L
.67763 .31094 L
.67782 .31117 L
.678 .31139 L
.6782 .31161 L
.67839 .31181 L
.67859 .31202 L
.67878 .3122 L
.67897 .31237 L
.67916 .31253 L
.67935 .31267 L
.67953 .31279 L
.67973 .31291 L
.67992 .313 L
.68011 .31309 L
.68031 .31315 L
.68049 .3132 L
.68059 .31322 L
.68063 .31322 L
.68069 .31323 L
.68074 .31324 L
.68078 .31324 L
.68082 .31324 L
.68085 .31324 L
.68087 .31324 L
.68088 .31325 L
.68089 .31325 L
.6809 .31325 L
.68091 .31325 L
.68092 .31325 L
.68093 .31325 L
.68093 .31325 L
.68094 .31325 L
.68095 .31325 L
.68095 .31325 L
.68096 .31325 L
.68096 .31325 L
.68097 .31325 L
.68097 .31325 L
.68098 .31325 L
Mistroke
.68099 .31325 L
.681 .31325 L
.68101 .31325 L
.68103 .31325 L
.68105 .31324 L
.6811 .31324 L
.68115 .31324 L
.68123 .31323 L
.68134 .31321 L
.68143 .31319 L
.68162 .31315 L
.68181 .31308 L
.682 .313 L
.68218 .3129 L
.68238 .31279 L
.68256 .31266 L
.68276 .31252 L
.68295 .31236 L
.68314 .3122 L
.68333 .31201 L
.68352 .31182 L
.68372 .31161 L
.68391 .3114 L
.6841 .31118 L
.68429 .31094 L
.68448 .3107 L
.68466 .31047 L
.68486 .31021 L
.68505 .30996 L
.68524 .30969 L
.68544 .30943 L
.68562 .30918 L
.68582 .30891 L
.686 .30865 L
.68619 .3084 L
.68638 .30814 L
.68656 .30789 L
.68676 .30763 L
.68695 .30739 L
.68714 .30716 L
.68733 .30693 L
.68752 .30671 L
.68772 .30649 L
.68791 .30628 L
.68809 .3061 L
.68829 .30592 L
.68848 .30575 L
.68866 .3056 L
.68885 .30546 L
.68904 .30534 L
Mistroke
.68924 .30522 L
.68943 .30513 L
.68961 .30505 L
.68981 .30498 L
.69 .30493 L
.6901 .30491 L
.6902 .3049 L
.69024 .30489 L
.69029 .30489 L
.69034 .30489 L
.69036 .30489 L
.69038 .30488 L
.6904 .30488 L
.69041 .30488 L
.69042 .30488 L
.69043 .30488 L
.69044 .30488 L
.69045 .30488 L
.69046 .30488 L
.69046 .30488 L
.69047 .30488 L
.69048 .30488 L
.69048 .30488 L
.69049 .30488 L
.69049 .30488 L
.6905 .30488 L
.6905 .30488 L
.69051 .30488 L
.69052 .30488 L
.69054 .30488 L
.69055 .30488 L
.69058 .30488 L
.6906 .30489 L
.69063 .30489 L
.69067 .30489 L
.69077 .3049 L
.69087 .30492 L
.69095 .30493 L
.69114 .30498 L
.69132 .30504 L
.69152 .30512 L
.6917 .30522 L
.6919 .30533 L
.69209 .30545 L
.69227 .30559 L
.69247 .30574 L
.69266 .3059 L
.69285 .30609 L
.69305 .30628 L
.69323 .30647 L
Mistroke
.69343 .30668 L
.69362 .3069 L
.6938 .30712 L
.69399 .30735 L
.69418 .30759 L
.69438 .30784 L
.69457 .30809 L
.69475 .30834 L
.69495 .3086 L
.69513 .30885 L
.69533 .30912 L
.69553 .30938 L
.69571 .30963 L
.69591 .30989 L
.6961 .31014 L
.69628 .31037 L
.69647 .31062 L
.69666 .31084 L
.69686 .31108 L
.69705 .3113 L
.69723 .3115 L
.69743 .3117 L
.69762 .31188 L
.6978 .31205 L
.69799 .31222 L
.69818 .31237 L
.69838 .31251 L
.69857 .31263 L
.69875 .31274 L
.69895 .31283 L
.69913 .31291 L
.69933 .31298 L
.69943 .31301 L
.69952 .31303 L
.69962 .31305 L
.69971 .31306 L
.6998 .31307 L
.69985 .31307 L
.69987 .31307 L
.6999 .31308 L
.69992 .31308 L
.69993 .31308 L
.69995 .31308 L
.69996 .31308 L
.69996 .31308 L
.69997 .31308 L
.69998 .31308 L
.69998 .31308 L
.69999 .31308 L
.69999 .31308 L
Mistroke
.7 .31308 L
.7 .31308 L
.70001 .31308 L
.70001 .31308 L
.70001 .31308 L
.70002 .31308 L
.70002 .31308 L
.70004 .31308 L
.70004 .31308 L
.70005 .31308 L
.70007 .31308 L
.7001 .31308 L
.70014 .31307 L
.70019 .31307 L
.70028 .31306 L
.70038 .31304 L
.70048 .31303 L
.70067 .31298 L
.70086 .31291 L
.70105 .31284 L
.70123 .31275 L
.70143 .31264 L
.70161 .31252 L
.70181 .31237 L
.702 .31222 L
.70219 .31207 L
.70238 .31189 L
.70257 .3117 L
.70275 .31152 L
.70295 .31131 L
.70313 .3111 L
.70333 .31087 L
.70352 .31064 L
.7037 .31042 L
.7039 .31017 L
.70409 .30993 L
.70428 .30967 L
.70448 .30941 L
.70466 .30917 L
.70486 .30891 L
.70505 .30866 L
.70523 .30842 L
.70542 .30816 L
.70561 .30792 L
.70581 .30767 L
.706 .30744 L
.70618 .30722 L
.70638 .30699 L
.70656 .30678 L
.70676 .30656 L
Mistroke
.70696 .30637 L
.70714 .30619 L
.70734 .30601 L
.70753 .30585 L
.70771 .30571 L
.70791 .30557 L
.70809 .30545 L
.70829 .30534 L
.70848 .30525 L
.70867 .30517 L
.70886 .30511 L
.70896 .30508 L
.70905 .30506 L
.70914 .30505 L
.70923 .30503 L
.70928 .30503 L
.70933 .30502 L
.70938 .30502 L
.70942 .30502 L
.70944 .30501 L
.70946 .30501 L
.70947 .30501 L
.70948 .30501 L
.70949 .30501 L
.7095 .30501 L
.7095 .30501 L
.70951 .30501 L
.70951 .30501 L
.70952 .30501 L
.70952 .30501 L
.70953 .30501 L
.70953 .30501 L
.70954 .30501 L
.70955 .30501 L
.70955 .30501 L
.70956 .30501 L
.70957 .30501 L
.70958 .30501 L
.70961 .30501 L
.70963 .30502 L
.70966 .30502 L
.7097 .30502 L
.70975 .30502 L
.7098 .30503 L
.7099 .30504 L
.71 .30506 L
.71018 .30511 L
.71037 .30517 L
.71056 .30524 L
.71076 .30534 L
Mistroke
.71095 .30545 L
.71113 .30556 L
.71133 .3057 L
.71151 .30585 L
.71171 .30601 L
.71191 .30619 L
.71209 .30636 L
.71229 .30656 L
.71248 .30677 L
.71266 .30697 L
.71286 .30719 L
.71304 .30741 L
.71324 .30766 L
.71343 .3079 L
.71362 .30813 L
.71381 .30838 L
.714 .30863 L
.71418 .30887 L
.71438 .30912 L
.71456 .30937 L
.71476 .30962 L
.71495 .30987 L
.71513 .3101 L
.71533 .31034 L
.71551 .31057 L
.71571 .31081 L
.71591 .31103 L
.71609 .31124 L
.71629 .31144 L
.71648 .31164 L
.71666 .31181 L
.71685 .31198 L
.71704 .31214 L
.71724 .31229 L
.71743 .31243 L
.71761 .31254 L
.71781 .31265 L
.71799 .31274 L
.71819 .31283 L
.71839 .31289 L
.71857 .31293 L
.71867 .31295 L
.71872 .31296 L
.71877 .31296 L
.71882 .31297 L
.71886 .31297 L
.71891 .31298 L
.71895 .31298 L
.71897 .31298 L
.71899 .31298 L
Mistroke
.719 .31298 L
.71901 .31298 L
.71902 .31298 L
.71902 .31298 L
.71903 .31298 L
.71904 .31298 L
.71904 .31298 L
.71905 .31298 L
.71905 .31298 L
.71905 .31298 L
.71906 .31298 L
.71906 .31298 L
.71907 .31298 L
.71908 .31298 L
.71908 .31298 L
.71909 .31298 L
.71912 .31298 L
.71914 .31298 L
.71916 .31298 L
.71918 .31298 L
.71923 .31297 L
.71928 .31297 L
.71933 .31296 L
.71942 .31295 L
.71952 .31293 L
.71972 .31288 L
.71991 .31282 L
.72009 .31275 L
.72029 .31266 L
.72047 .31255 L
.72067 .31243 L
.72086 .31229 L
.72105 .31215 L
.72125 .31199 L
.72143 .31182 L
.72162 .31164 L
.72181 .31145 L
.722 .31125 L
.72219 .31103 L
.72238 .31081 L
.72257 .3106 L
.72276 .31036 L
.72295 .31013 L
.72315 .30988 L
.72334 .30963 L
.72353 .30939 L
.72373 .30913 L
.72392 .30889 L
.7241 .30865 L
.72429 .3084 L
Mistroke
.72448 .30816 L
.72468 .30791 L
.72487 .30767 L
.72505 .30745 L
.72525 .30722 L
.72544 .307 L
.72562 .3068 L
.72581 .3066 L
.726 .30641 L
.7262 .30623 L
.72639 .30606 L
.72657 .3059 L
.72677 .30576 L
.72695 .30563 L
.72715 .3055 L
.72734 .30539 L
.72753 .30531 L
.72773 .30523 L
.72792 .30517 L
.7281 .30512 L
.72819 .30511 L
.72829 .30509 L
.72834 .30509 L
.72839 .30508 L
.72842 .30508 L
.72844 .30508 L
.72847 .30508 L
.72849 .30508 L
.72851 .30508 L
.72852 .30508 L
.72853 .30508 L
.72854 .30508 L
.72855 .30508 L
.72855 .30508 L
.72855 .30508 L
.72856 .30508 L
.72857 .30508 L
.72857 .30508 L
.72858 .30508 L
.72858 .30508 L
.72859 .30508 L
.72859 .30508 L
.7286 .30508 L
.72862 .30508 L
.72863 .30508 L
.72865 .30508 L
.72867 .30508 L
.72872 .30508 L
.72877 .30508 L
.72886 .30509 L
Mistroke
.72895 .30511 L
.72904 .30512 L
.72923 .30517 L
.72942 .30523 L
.72961 .30531 L
.7298 .30539 L
.72999 .3055 L
.73019 .30562 L
.73037 .30575 L
.73057 .3059 L
.73075 .30605 L
.73094 .30621 L
.73113 .3064 L
.73131 .30658 L
.73151 .30679 L
.7317 .307 L
.73189 .3072 L
.73208 .30743 L
.73227 .30766 L
.73247 .3079 L
.73266 .30815 L
.73284 .30838 L
.73304 .30863 L
.73323 .30888 L
.73341 .30911 L
.7336 .30937 L
.73379 .30961 L
.73399 .30986 L
.73418 .3101 L
.73436 .31033 L
.73456 .31056 L
.73475 .31078 L
.73495 .31101 L
.73514 .31122 L
.73532 .31142 L
.73552 .31162 L
.73571 .3118 L
.73589 .31196 L
.73609 .31212 L
.73628 .31226 L
.73647 .3124 L
.73667 .31252 L
.73685 .31262 L
.73705 .31272 L
.73724 .31279 L
.73742 .31285 L
.73752 .31288 L
.73761 .3129 L
.73771 .31292 L
.7378 .31293 L
Mistroke
.73789 .31294 L
.73794 .31294 L
.73796 .31295 L
.73799 .31295 L
.73801 .31295 L
.73804 .31295 L
.73805 .31295 L
.73806 .31295 L
.73807 .31295 L
.73807 .31295 L
.73808 .31295 L
.73808 .31295 L
.73809 .31295 L
.73809 .31295 L
.73809 .31295 L
.7381 .31295 L
.73811 .31295 L
.73811 .31295 L
.73812 .31295 L
.73812 .31295 L
.73814 .31295 L
.73815 .31295 L
.73816 .31295 L
.73819 .31295 L
.73821 .31295 L
.73824 .31295 L
.73829 .31294 L
.73834 .31294 L
.73839 .31293 L
.73848 .31292 L
.73857 .3129 L
.73875 .31286 L
.73895 .31279 L
.73914 .31272 L
.73933 .31263 L
.73952 .31252 L
.73971 .31241 L
.73991 .31227 L
.7401 .31212 L
.74029 .31197 L
.74048 .31179 L
.74067 .31161 L
.74085 .31143 L
.74105 .31123 L
.74124 .31102 L
.74143 .31079 L
.74163 .31057 L
.74181 .31035 L
.74201 .31011 L
.74219 .30987 L
Mistroke
.74238 .30964 L
.74257 .30939 L
.74275 .30915 L
.74295 .30889 L
.74314 .30864 L
.74333 .30841 L
.74352 .30816 L
.74371 .30792 L
.74391 .30768 L
.7441 .30745 L
.74428 .30723 L
.74448 .307 L
.74467 .3068 L
.74485 .30661 L
.74505 .30641 L
.74523 .30624 L
.74543 .30606 L
.74562 .3059 L
.74581 .30576 L
.746 .30562 L
.74619 .30551 L
.74639 .3054 L
.74658 .3053 L
.74677 .30523 L
.74696 .30517 L
.74706 .30514 L
.74715 .30512 L
.74725 .30511 L
.74734 .30509 L
.74738 .30509 L
.74744 .30508 L
.74748 .30508 L
.74752 .30508 L
.74755 .30508 L
.74756 .30508 L
.74757 .30508 L
.74758 .30508 L
.74759 .30508 L
.74759 .30508 L
.7476 .30508 L
.7476 .30508 L
.74761 .30508 L
.74761 .30508 L
.74762 .30508 L
.74763 .30508 L
.74763 .30508 L
.74763 .30508 L
.74764 .30508 L
.74765 .30508 L
.74765 .30508 L
Mistroke
.74766 .30508 L
.74767 .30508 L
.74769 .30508 L
.74771 .30508 L
.74774 .30508 L
.74776 .30508 L
.7478 .30508 L
.74785 .30509 L
.7479 .30509 L
.74799 .30511 L
.74809 .30512 L
.74829 .30517 L
.74847 .30523 L
.74867 .30531 L
.74887 .3054 L
.74905 .30551 L
.74925 .30563 L
.74944 .30576 L
.74962 .3059 L
.74981 .30606 L
.75 .30623 L
.7502 .30642 L
.75039 .30661 L
.75057 .3068 L
.75076 .30702 L
.75095 .30723 L
.75115 .30747 L
.75135 .3077 L
.75153 .30793 L
.75173 .30818 L
.75192 .30842 L
.7521 .30866 L
.75229 .30891 L
.75248 .30916 L
.75268 .30941 L
.75287 .30966 L
.75306 .3099 L
.75325 .31014 L
.75344 .31038 L
.75362 .3106 L
.75382 .31083 L
.754 .31104 L
.7542 .31126 L
.75439 .31146 L
.75457 .31164 L
.75477 .31183 L
.75495 .31199 L
.75515 .31216 L
.75535 .31231 L
.75553 .31243 L
Mistroke
.75573 .31256 L
.75592 .31266 L
.7561 .31275 L
.75629 .31283 L
.75648 .31289 L
.75657 .31291 L
.75668 .31293 L
.75677 .31295 L
.75682 .31296 L
.75687 .31297 L
.75692 .31297 L
.75696 .31297 L
.75701 .31298 L
.75704 .31298 L
.75706 .31298 L
.75708 .31298 L
.75709 .31298 L
.7571 .31298 L
.75711 .31298 L
.75712 .31298 L
.75712 .31298 L
.75713 .31298 L
.75713 .31298 L
.75714 .31298 L
.75714 .31298 L
.75715 .31298 L
.75715 .31298 L
.75716 .31298 L
.75716 .31298 L
.75717 .31298 L
.75717 .31298 L
.75718 .31298 L
.75719 .31298 L
.7572 .31298 L
.75722 .31298 L
.75725 .31298 L
.75729 .31298 L
.75734 .31297 L
.75743 .31296 L
.75753 .31295 L
.75763 .31293 L
.75781 .31288 L
.75801 .31282 L
.7582 .31274 L
.75838 .31266 L
.75857 .31255 L
.75876 .31243 L
.75895 .31229 L
.75915 .31215 L
.75933 .31199 L
Mistroke
.75952 .31182 L
.75971 .31164 L
.75991 .31144 L
.7601 .31123 L
.76029 .31103 L
.76048 .3108 L
.76067 .31058 L
.76085 .31036 L
.76105 .31012 L
.76123 .30988 L
.76143 .30962 L
.76162 .30937 L
.76181 .30913 L
.762 .30888 L
.76219 .30863 L
.76239 .30837 L
.76258 .30812 L
.76277 .30788 L
.76297 .30764 L
.76316 .30741 L
.76334 .30719 L
.76353 .30697 L
.76372 .30676 L
.76392 .30655 L
.76411 .30635 L
.76429 .30618 L
.76449 .306 L
.76468 .30584 L
.76486 .3057 L
.76505 .30557 L
.76524 .30545 L
.76544 .30534 L
.76563 .30525 L
.76581 .30517 L
.76601 .30511 L
.76619 .30506 L
.7663 .30504 L
.76634 .30504 L
.76639 .30503 L
.76644 .30502 L
.76649 .30502 L
.76654 .30502 L
.76656 .30502 L
.76658 .30501 L
.7666 .30501 L
.76662 .30501 L
.76663 .30501 L
.76663 .30501 L
.76664 .30501 L
.76665 .30501 L
Mistroke
.76665 .30501 L
.76666 .30501 L
.76666 .30501 L
.76666 .30501 L
.76667 .30501 L
.76668 .30501 L
.76668 .30501 L
.76669 .30501 L
.76669 .30501 L
.7667 .30501 L
.76671 .30501 L
.76672 .30501 L
.76675 .30501 L
.76677 .30502 L
.76682 .30502 L
.76686 .30502 L
.76695 .30503 L
.76705 .30504 L
.76714 .30506 L
.76732 .30511 L
.76752 .30517 L
.76772 .30525 L
.7679 .30534 L
.7681 .30545 L
.76829 .30557 L
.76847 .3057 L
.76866 .30585 L
.76885 .30601 L
.76905 .30619 L
.76924 .30638 L
.76943 .30656 L
.76962 .30677 L
.76981 .30699 L
.76999 .3072 L
.77018 .30743 L
.77037 .30766 L
.77057 .30791 L
.77076 .30815 L
.77094 .30839 L
.77114 .30865 L
.77132 .3089 L
.77152 .30916 L
.77172 .30942 L
.7719 .30966 L
.7721 .30992 L
.77229 .31016 L
.77247 .31039 L
.77266 .31063 L
.77285 .31086 L
.77305 .31109 L
Mistroke
.77324 .3113 L
.77342 .3115 L
.77362 .3117 L
.77381 .31189 L
.77401 .31207 L
.7742 .31223 L
.77438 .31238 L
.77458 .31252 L
.77477 .31264 L
.77495 .31274 L
.77515 .31284 L
.77534 .31292 L
.77553 .31298 L
.77563 .31301 L
.77573 .31303 L
.77582 .31305 L
.77591 .31306 L
.776 .31307 L
.77605 .31307 L
.77607 .31307 L
.7761 .31308 L
.77612 .31308 L
.77613 .31308 L
.77615 .31308 L
.77616 .31308 L
.77616 .31308 L
.77617 .31308 L
.77617 .31308 L
.77618 .31308 L
.77619 .31308 L
.77619 .31308 L
.7762 .31308 L
.7762 .31308 L
.7762 .31308 L
.77621 .31308 L
.77622 .31308 L
.77623 .31308 L
.77624 .31308 L
.77625 .31308 L
.77626 .31308 L
.77629 .31308 L
.77634 .31307 L
.77639 .31307 L
.77644 .31306 L
.77649 .31306 L
.77659 .31304 L
.77667 .31303 L
.77687 .31298 L
.77705 .31291 L
.77725 .31283 L
Mistroke
.77744 .31274 L
.77762 .31263 L
.77781 .31251 L
.778 .31237 L
.7782 .31222 L
.77839 .31205 L
.77857 .31188 L
.77877 .31169 L
.77896 .3115 L
.77915 .31128 L
.77935 .31106 L
.77953 .31084 L
.77973 .3106 L
.77992 .31036 L
.7801 .31013 L
.7803 .30987 L
.78048 .30962 L
.78068 .30936 L
.78087 .3091 L
.78106 .30885 L
.78125 .30859 L
.78144 .30833 L
.78162 .30809 L
.78182 .30784 L
.782 .3076 L
.7822 .30735 L
.78239 .30712 L
.78258 .3069 L
.78277 .30668 L
.78296 .30647 L
.78316 .30626 L
.78335 .30607 L
.78353 .3059 L
.78373 .30573 L
.78392 .30558 L
.7841 .30545 L
.7843 .30533 L
.78448 .30522 L
.78468 .30512 L
.78487 .30504 L
.78506 .30498 L
.78515 .30495 L
.78525 .30493 L
.78535 .30491 L
.78544 .3049 L
.78548 .30489 L
.78553 .30489 L
.78558 .30489 L
.78561 .30488 L
.78563 .30488 L
Mistroke
.78566 .30488 L
.78567 .30488 L
.78568 .30488 L
.78568 .30488 L
.78569 .30488 L
.78569 .30488 L
.7857 .30488 L
.78571 .30488 L
.78571 .30488 L
.78572 .30488 L
.78572 .30488 L
.78573 .30488 L
.78573 .30488 L
.78574 .30488 L
.78574 .30488 L
.78576 .30488 L
.78577 .30488 L
.78578 .30488 L
.7858 .30488 L
.78582 .30488 L
.78587 .30489 L
.78591 .30489 L
.78601 .3049 L
.78611 .30492 L
.78621 .30494 L
.7864 .30499 L
.78659 .30505 L
.78677 .30513 L
.78696 .30523 L
.78715 .30534 L
.78735 .30547 L
.78754 .30561 L
.78772 .30576 L
.78792 .30593 L
.7881 .30611 L
.7883 .30631 L
.7885 .30651 L
.78868 .30672 L
.78888 .30695 L
.78907 .30717 L
.78925 .3074 L
.78944 .30765 L
.78963 .30789 L
.78983 .30816 L
.79002 .30842 L
.7902 .30867 L
.7904 .30894 L
.79058 .3092 L
.79078 .30947 L
.79098 .30974 L
Mistroke
.79116 .30999 L
.79136 .31025 L
.79155 .3105 L
.79173 .31073 L
.79193 .31098 L
.79211 .3112 L
.79231 .31143 L
.7925 .31165 L
.79269 .31184 L
.79289 .31204 L
.79307 .31222 L
.79326 .31238 L
.79345 .31253 L
.79363 .31267 L
.79383 .3128 L
.79402 .31291 L
.79421 .313 L
.7944 .31309 L
.79459 .31315 L
.79469 .31318 L
.79479 .3132 L
.79488 .31322 L
.79493 .31323 L
.79498 .31323 L
.79503 .31324 L
.79508 .31324 L
.79513 .31324 L
.79515 .31324 L
.79517 .31325 L
.79518 .31325 L
.79519 .31325 L
.7952 .31325 L
.79521 .31325 L
.79522 .31325 L
.79522 .31325 L
.79522 .31325 L
.79523 .31325 L
.79524 .31325 L
.79524 .31325 L
.79525 .31325 L
.79525 .31325 L
.79525 .31325 L
.79526 .31325 L
.79527 .31325 L
.79527 .31325 L
.79529 .31325 L
.7953 .31325 L
.79532 .31324 L
.79534 .31324 L
.79536 .31324 L
Mistroke
.79541 .31324 L
.79546 .31324 L
.79555 .31322 L
.79565 .31321 L
.79575 .31319 L
.79593 .31314 L
.79613 .31307 L
.79632 .31298 L
.7965 .31288 L
.79669 .31277 L
.79688 .31264 L
.79708 .31249 L
.79727 .31233 L
.79746 .31216 L
.79765 .31197 L
.79784 .31177 L
.79802 .31158 L
.79821 .31136 L
.7984 .31113 L
.7986 .31089 L
.79879 .31064 L
.79897 .3104 L
.79917 .31014 L
.79935 .30989 L
.79955 .30961 L
.79975 .30934 L
.79993 .30908 L
.80013 .3088 L
.80032 .30853 L
.8005 .30828 L
.80069 .30801 L
.80088 .30775 L
.80108 .30749 L
.80127 .30723 L
.80145 .307 L
.80165 .30676 L
.80184 .30653 L
.80202 .30633 L
.80221 .30612 L
.8024 .30592 L
.80259 .30573 L
.80278 .30556 L
.80297 .30541 L
.80316 .30526 L
.80335 .30513 L
.80355 .30502 L
.80374 .30492 L
.80392 .30484 L
.80412 .30477 L
.80422 .30474 L
Mistroke
.80431 .30472 L
.8044 .3047 L
.80449 .30469 L
.80454 .30468 L
.80459 .30468 L
.80463 .30468 L
.80466 .30467 L
.80468 .30467 L
.8047 .30467 L
.80471 .30467 L
.80472 .30467 L
.80473 .30467 L
.80473 .30467 L
.80474 .30467 L
.80474 .30467 L
.80475 .30467 L
.80476 .30467 L
.80476 .30467 L
.80477 .30467 L
.80477 .30467 L
.80477 .30467 L
.80478 .30467 L
.80479 .30467 L
.8048 .30467 L
.80481 .30467 L
.80482 .30467 L
.80484 .30467 L
.80486 .30467 L
.80491 .30468 L
.80496 .30468 L
.80505 .30469 L
.80515 .30471 L
.80524 .30472 L
.80542 .30477 L
.80561 .30484 L
.8058 .30492 L
.80599 .30502 L
.80619 .30514 L
.80638 .30528 L
.80656 .30542 L
.80675 .30558 L
.80694 .30575 L
.80714 .30595 L
.80734 .30615 L
.80752 .30636 L
.80772 .30659 L
.80791 .30682 L
.80809 .30706 L
.80828 .30731 L
.80847 .30756 L
Mistroke
.80867 .30784 L
.80886 .30811 L
.80905 .30837 L
.80924 .30865 L
.80943 .30893 L
.80961 .30919 L
.80981 .30947 L
.80999 .30974 L
.81019 .31003 L
.81038 .3103 L
.81056 .31055 L
.81076 .31082 L
.81095 .31106 L
.81115 .31132 L
.81134 .31156 L
.81152 .31178 L
.81172 .312 L
.81191 .3122 L
.81209 .31238 L
.81229 .31257 L
.81247 .31273 L
.81267 .31288 L
.81286 .31302 L
.81305 .31313 L
.81324 .31324 L
.81343 .31333 L
.81361 .31339 L
.81371 .31342 L
.8138 .31345 L
.8139 .31347 L
.81399 .31348 L
.81408 .31349 L
.81413 .3135 L
.81415 .3135 L
.81418 .3135 L
.8142 .3135 L
.81423 .3135 L
.81424 .3135 L
.81425 .3135 L
.81426 .3135 L
.81427 .3135 L
.81427 .3135 L
.81427 .3135 L
.81428 .3135 L
.81428 .3135 L
.81429 .3135 L
.81429 .3135 L
.81429 .3135 L
.8143 .3135 L
.81431 .3135 L
Mistroke
.81431 .3135 L
.81432 .3135 L
.81433 .3135 L
.81434 .3135 L
.81435 .3135 L
.81438 .3135 L
.8144 .3135 L
.81443 .3135 L
.81447 .3135 L
.81452 .31349 L
.81457 .31348 L
.81466 .31347 L
.81476 .31345 L
.81496 .31339 L
.81515 .31332 L
.81533 .31324 L
.81553 .31313 L
.81572 .31301 L
.81592 .31287 L
.81611 .31271 L
.81629 .31255 L
.81649 .31236 L
.81668 .31217 L
.81686 .31197 L
.81705 .31175 L
.81724 .31152 L
.81744 .31127 L
.81763 .31102 L
.81781 .31077 L
.81801 .3105 L
.8182 .31023 L
.8184 .30993 L
.81859 .30965 L
.81878 .30937 L
.81897 .30908 L
.81916 .30879 L
.81935 .30851 L
.81954 .30822 L
.81973 .30795 L
.81993 .30765 L
.82012 .30738 L
.8203 .30712 L
.8205 .30685 L
.82069 .3066 L
.82087 .30637 L
.82106 .30613 L
.82125 .30592 L
.82145 .3057 L
.82164 .3055 L
.82182 .30532 L
Mistroke
.82202 .30515 L
.8222 .305 L
.8224 .30485 L
.8226 .30473 L
.82278 .30463 L
.82298 .30453 L
.82317 .30446 L
.82335 .30441 L
.82344 .30439 L
.82354 .30438 L
.82359 .30437 L
.82364 .30437 L
.82367 .30437 L
.82369 .30436 L
.82372 .30436 L
.82374 .30436 L
.82376 .30436 L
.82377 .30436 L
.82378 .30436 L
.82379 .30436 L
.82379 .30436 L
.82379 .30436 L
.8238 .30436 L
.8238 .30436 L
.82381 .30436 L
.82381 .30436 L
.82382 .30436 L
.82382 .30436 L
.82383 .30436 L
.82383 .30436 L
.82385 .30436 L
.82386 .30436 L
.82388 .30436 L
.8239 .30436 L
.82392 .30436 L
.82397 .30437 L
.82402 .30437 L
.82411 .30438 L
.82421 .3044 L
.8243 .30442 L
.82449 .30448 L
.82467 .30455 L
.82486 .30464 L
.82505 .30475 L
.82525 .30488 L
.82544 .30502 L
.82562 .30517 L
.82582 .30535 L
.82601 .30554 L
.82619 .30573 L
Mistroke
.82638 .30595 L
.82657 .30618 L
.82677 .30642 L
.82696 .30668 L
.82714 .30693 L
.82734 .3072 L
.82752 .30747 L
.82772 .30777 L
.82791 .30806 L
.8281 .30835 L
.8283 .30865 L
.82849 .30895 L
.82867 .30923 L
.82886 .30954 L
.82905 .30983 L
.82925 .31013 L
.82944 .31043 L
.82962 .3107 L
.82982 .31099 L
.83001 .31126 L
.83019 .31151 L
.83038 .31176 L
.83057 .312 L
.83076 .31224 L
.83095 .31246 L
.83114 .31266 L
.83133 .31286 L
.83152 .31303 L
.83172 .3132 L
.83191 .31335 L
.83209 .31348 L
.83229 .31359 L
.83248 .31368 L
.83266 .31376 L
.83276 .31379 L
.83285 .31382 L
.83295 .31384 L
.83304 .31385 L
.83313 .31387 L
.83318 .31387 L
.8332 .31387 L
.83323 .31387 L
.83325 .31387 L
.83328 .31388 L
.83329 .31388 L
.8333 .31388 L
.83331 .31388 L
.83332 .31388 L
.83332 .31388 L
.83333 .31388 L
Mistroke
.83333 .31388 L
.83333 .31388 L
.83334 .31388 L
.83334 .31388 L
.83335 .31388 L
.83335 .31388 L
.83336 .31388 L
.83337 .31388 L
.83338 .31388 L
.83339 .31388 L
.83341 .31387 L
.83343 .31387 L
.83345 .31387 L
.83348 .31387 L
.83353 .31387 L
.83358 .31386 L
.83363 .31385 L
.83372 .31384 L
.83381 .31382 L
.834 .31376 L
.8342 .31368 L
.83439 .31359 L
.83457 .31348 L
.83477 .31334 L
.83495 .31319 L
.83515 .31302 L
.83535 .31284 L
.83553 .31264 L
.83573 .31242 L
.83592 .3122 L
.8361 .31197 L
.8363 .31171 L
.83648 .31146 L
.83668 .31117 L
.83687 .31089 L
.83706 .31061 L
.83725 .3103 L
.83744 .31 L
.83762 .30971 L
.83782 .3094 L
.838 .30909 L
.8382 .30877 L
.83839 .30845 L
.83857 .30815 L
.83877 .30784 L
.83896 .30754 L
.83916 .30723 L
.83935 .30693 L
.83953 .30666 L
.83973 .30637 L
Mistroke
.83992 .30611 L
.8401 .30586 L
.8403 .30562 L
.84048 .30539 L
.84068 .30516 L
.84087 .30496 L
.84106 .30478 L
.84125 .30461 L
.84144 .30446 L
.84162 .30433 L
.84182 .30421 L
.842 .30412 L
.8422 .30404 L
.8423 .304 L
.84239 .30398 L
.84248 .30395 L
.84257 .30394 L
.84262 .30393 L
.84267 .30393 L
.84272 .30392 L
.84276 .30392 L
.84278 .30392 L
.84279 .30392 L
.84281 .30392 L
.84282 .30392 L
.84282 .30392 L
.84283 .30392 L
.84283 .30392 L
.84284 .30392 L
.84284 .30392 L
.84285 .30392 L
.84285 .30392 L
.84286 .30392 L
.84286 .30392 L
.84287 .30392 L
.84287 .30392 L
.84288 .30392 L
.84289 .30392 L
.8429 .30392 L
.84291 .30392 L
.84292 .30392 L
.84295 .30392 L
.84297 .30392 L
.84299 .30392 L
.84304 .30392 L
.84309 .30393 L
.84314 .30394 L
.84323 .30395 L
.84333 .30398 L
.84352 .30404 L
Mistroke
.84371 .30412 L
.84391 .30422 L
.8441 .30434 L
.84429 .30447 L
.84448 .30464 L
.84467 .30481 L
.84485 .30499 L
.84505 .3052 L
.84523 .30542 L
.84543 .30567 L
.84562 .30592 L
.84581 .30617 L
.846 .30646 L
.84619 .30674 L
.84639 .30705 L
.84658 .30736 L
.84677 .30766 L
.84697 .30799 L
.84716 .30831 L
.84734 .30863 L
.84753 .30896 L
.84772 .30929 L
.84792 .30963 L
.84811 .30996 L
.8483 .31027 L
.84849 .3106 L
.84868 .31091 L
.84886 .31121 L
.84906 .31151 L
.84924 .3118 L
.84944 .31209 L
.84963 .31236 L
.84981 .31261 L
.85001 .31285 L
.8502 .31308 L
.8504 .3133 L
.85059 .3135 L
.85077 .31367 L
.85097 .31384 L
.85116 .31398 L
.85134 .3141 L
.85154 .3142 L
.85172 .31428 L
.85182 .31432 L
.85192 .31435 L
.85201 .31437 L
.85207 .31438 L
.85211 .31439 L
.85216 .31439 L
.85221 .3144 L
Mistroke
.85226 .3144 L
.85228 .31441 L
.8523 .31441 L
.85231 .31441 L
.85232 .31441 L
.85233 .31441 L
.85234 .31441 L
.85236 .31441 L
.85236 .31441 L
.85237 .31441 L
.85237 .31441 L
.85238 .31441 L
.85238 .31441 L
.85239 .31441 L
.85239 .31441 L
.85239 .31441 L
.8524 .31441 L
.8524 .31441 L
.85241 .31441 L
.85242 .31441 L
.85243 .31441 L
.85244 .31441 L
.85245 .31441 L
.85249 .3144 L
.85252 .3144 L
.85254 .3144 L
.85259 .3144 L
.85268 .31438 L
.85277 .31436 L
.85287 .31434 L
.85306 .31427 L
.85325 .31419 L
.85343 .31409 L
.85363 .31396 L
.85381 .31381 L
.85401 .31364 L
.8542 .31346 L
.85438 .31326 L
.85458 .31304 L
.85477 .31281 L
.85497 .31254 L
.85516 .31227 L
.85534 .312 L
.85554 .3117 L
.85573 .3114 L
.85591 .3111 L
.85611 .31077 L
.85629 .31044 L
.85649 .31009 L
.85668 .30975 L
Mistroke
.85687 .30941 L
.85706 .30906 L
.85725 .30871 L
.85743 .30838 L
.85762 .30803 L
.85781 .30769 L
.85801 .30734 L
.8582 .30701 L
.85838 .30669 L
.85857 .30636 L
.85876 .30606 L
.85896 .30575 L
.85915 .30546 L
.85934 .3052 L
.85953 .30493 L
.85972 .30469 L
.8599 .30447 L
.8601 .30426 L
.86028 .30407 L
.86048 .3039 L
.86067 .30374 L
.86086 .30362 L
.86105 .3035 L
.86124 .30341 L
.86133 .30338 L
.86144 .30334 L
.86153 .30332 L
.86158 .30331 L
.86163 .3033 L
.86168 .30329 L
.86173 .30329 L
.86178 .30328 L
.8618 .30328 L
.86183 .30328 L
.86185 .30328 L
.86186 .30328 L
.86187 .30328 L
.86188 .30328 L
.86189 .30328 L
.86189 .30328 L
.8619 .30328 L
.8619 .30328 L
.8619 .30328 L
.86191 .30328 L
.86191 .30328 L
.86192 .30328 L
.86192 .30328 L
.86192 .30328 L
.86193 .30328 L
.86193 .30328 L
Mistroke
.86194 .30328 L
.86196 .30328 L
.86197 .30328 L
.86199 .30328 L
.86201 .30328 L
.86206 .30328 L
.86211 .30329 L
.8622 .3033 L
.8623 .30333 L
.8624 .30335 L
.86258 .30342 L
.86278 .30351 L
.86297 .30363 L
.86315 .30376 L
.86334 .30392 L
.86353 .30409 L
.86373 .3043 L
.86392 .30452 L
.86411 .30474 L
.8643 .305 L
.86449 .30527 L
.86467 .30554 L
.86487 .30584 L
.86505 .30615 L
.86525 .30649 L
.86544 .30682 L
.86562 .30715 L
.86582 .30752 L
.86601 .30787 L
.86621 .30825 L
.8664 .30863 L
.86658 .30899 L
.86678 .30938 L
.86697 .30975 L
.86715 .3101 L
.86735 .31048 L
.86753 .31084 L
.86773 .31121 L
.86792 .31156 L
.86811 .31189 L
.8683 .31223 L
.86849 .31254 L
.86867 .31283 L
.86887 .31313 L
.86905 .3134 L
.86925 .31367 L
.86944 .31391 L
.86962 .31413 L
.86982 .31433 L
.87 .31452 L
Mistroke
.8702 .31469 L
.8704 .31483 L
.87058 .31494 L
.87078 .31504 L
.87087 .31508 L
.87097 .31511 L
.87106 .31513 L
.87115 .31515 L
.87119 .31516 L
.87124 .31517 L
.87129 .31517 L
.87133 .31518 L
.87136 .31518 L
.87137 .31518 L
.87138 .31518 L
.8714 .31518 L
.8714 .31518 L
.87141 .31518 L
.87141 .31518 L
.87142 .31518 L
.87142 .31518 L
.87143 .31518 L
.87143 .31518 L
.87144 .31518 L
.87144 .31518 L
.87145 .31518 L
.87145 .31518 L
.87147 .31518 L
.87148 .31518 L
.8715 .31518 L
.87152 .31518 L
.87157 .31517 L
.87162 .31517 L
.8717 .31515 L
.87181 .31513 L
.8719 .3151 L
.87209 .31503 L
.87229 .31493 L
.87247 .31481 L
.87266 .31468 L
.87285 .31451 L
.87304 .31432 L
.87324 .3141 L
.87343 .31387 L
.87361 .31363 L
.87381 .31335 L
.87399 .31307 L
.87418 .31278 L
.87437 .31246 L
.87455 .31213 L
Mistroke
.87475 .31177 L
.87494 .31141 L
.87512 .31105 L
.87532 .31067 L
.87551 .31029 L
.8757 .30987 L
.8759 .30947 L
.87608 .30908 L
.87628 .30867 L
.87647 .30827 L
.87665 .30789 L
.87684 .30748 L
.87703 .3071 L
.87723 .30669 L
.87742 .30631 L
.8776 .30596 L
.87779 .30559 L
.87798 .30525 L
.87818 .3049 L
.87837 .30458 L
.87856 .30429 L
.87876 .30399 L
.87895 .30373 L
.87913 .3035 L
.87932 .30327 L
.87951 .30307 L
.87971 .30289 L
.8799 .30273 L
.88008 .30261 L
.88028 .3025 L
.88038 .30246 L
.88047 .30242 L
.88056 .30239 L
.88065 .30237 L
.8807 .30236 L
.88075 .30235 L
.88079 .30235 L
.88083 .30234 L
.88086 .30234 L
.88087 .30234 L
.88089 .30234 L
.8809 .30234 L
.88091 .30234 L
.88092 .30234 L
.88092 .30234 L
.88093 .30234 L
.88093 .30234 L
.88094 .30234 L
.88094 .30234 L
.88095 .30234 L
Mistroke
.88095 .30234 L
.88096 .30234 L
.88096 .30234 L
.88097 .30234 L
.88097 .30234 L
.88098 .30234 L
.88099 .30234 L
.881 .30234 L
.88102 .30234 L
.88105 .30234 L
.88107 .30234 L
.88112 .30235 L
.88117 .30235 L
.88121 .30236 L
.8813 .30238 L
.8814 .30241 L
.88159 .30248 L
.88178 .30258 L
.88198 .30272 L
.88217 .30287 L
.88235 .30304 L
.88254 .30325 L
.88273 .30347 L
.88293 .30373 L
.88312 .304 L
.88331 .30429 L
.88351 .30461 L
.88369 .30494 L
.88388 .30527 L
.88407 .30564 L
.88426 .30601 L
.88446 .30642 L
.88465 .30682 L
.88483 .30722 L
.88503 .30765 L
.88522 .30808 L
.8854 .30849 L
.88559 .30893 L
.88577 .30936 L
.88597 .30982 L
.88616 .31025 L
.88635 .31067 L
.88654 .31111 L
.88673 .31153 L
.88693 .31196 L
.88712 .31237 L
.8873 .31275 L
.8875 .31314 L
.88769 .3135 L
.88787 .31384 L
Mistroke
.88806 .31417 L
.88825 .31448 L
.88845 .31478 L
.88864 .31505 L
.88882 .31529 L
.88902 .31552 L
.88921 .31571 L
.8894 .31589 L
.8896 .31604 L
.88978 .31615 L
.88988 .3162 L
.88998 .31624 L
.89008 .31628 L
.89017 .31631 L
.89026 .31632 L
.89031 .31633 L
.89034 .31634 L
.89036 .31634 L
.89039 .31634 L
.89041 .31634 L
.89042 .31634 L
.89044 .31634 L
.89045 .31634 L
.89045 .31634 L
.89046 .31634 L
.89046 .31634 L
.89047 .31634 L
.89047 .31634 L
.89048 .31634 L
.89048 .31634 L
.89049 .31634 L
.89049 .31634 L
.8905 .31634 L
.89051 .31634 L
.89052 .31634 L
.89053 .31634 L
.89055 .31634 L
.89057 .31634 L
.8906 .31634 L
.89064 .31633 L
.89069 .31632 L
.89074 .31632 L
.89083 .31629 L
.89093 .31626 L
.89113 .31617 L
.89132 .31606 L
.8915 .31592 L
.8917 .31575 L
.89188 .31556 L
.89208 .31533 L
Mistroke
.89227 .31507 L
.89246 .31481 L
.89265 .3145 L
.89284 .31418 L
.89302 .31385 L
.89322 .31348 L
.8934 .31311 L
.8936 .31269 L
.89379 .31228 L
.89398 .31186 L
.89417 .31141 L
.89436 .31096 L
.89456 .31047 L
.89475 .30999 L
.89494 .30953 L
.89513 .30903 L
.89532 .30854 L
.8955 .30808 L
.8957 .30758 L
.89589 .30711 L
.89608 .30662 L
.89628 .30615 L
.89646 .30571 L
.89666 .30525 L
.89684 .30482 L
.89702 .30442 L
.89722 .30401 L
.8974 .30364 L
.8976 .30326 L
.89779 .30291 L
.89797 .3026 L
.89817 .3023 L
.89836 .30203 L
.89856 .30177 L
.89875 .30155 L
.89893 .30137 L
.89913 .30121 L
.89932 .30108 L
.8995 .30098 L
.89959 .30095 L
.89969 .30092 L
.89974 .3009 L
.89979 .30089 L
.89984 .30089 L
.89989 .30088 L
.89992 .30088 L
.89993 .30088 L
.89994 .30088 L
.89995 .30088 L
.89996 .30088 L
Mistroke
.89997 .30087 L
.89997 .30087 L
.89998 .30087 L
.89998 .30087 L
.89999 .30087 L
.9 .30087 L
.9 .30087 L
.90001 .30087 L
.90001 .30087 L
.90002 .30087 L
.90002 .30087 L
.90003 .30087 L
.90004 .30088 L
.90006 .30088 L
.90008 .30088 L
.9001 .30088 L
.90013 .30088 L
.90017 .30089 L
.90022 .3009 L
.90027 .30091 L
.90037 .30094 L
.90047 .30097 L
.90065 .30106 L
.90085 .30119 L
.90103 .30135 L
.90123 .30155 L
.90142 .30177 L
.90161 .30201 L
.9018 .3023 L
.90199 .3026 L
.90217 .30292 L
.90236 .30328 L
.90255 .30365 L
.90275 .30408 L
.90294 .3045 L
.90312 .30493 L
.90332 .30541 L
.9035 .30588 L
.9037 .3064 L
.90389 .30692 L
.90408 .30742 L
.90427 .30797 L
.90446 .3085 L
.90464 .30902 L
.90484 .30957 L
.90502 .3101 L
.90522 .31067 L
.90541 .31121 L
.9056 .31172 L
.90579 .31226 L
Mistroke
.90598 .31277 L
.90618 .3133 L
.90637 .31379 L
.90656 .31425 L
.90675 .31471 L
.90694 .31514 L
.90713 .31554 L
.90732 .31593 L
.90751 .31629 L
.90771 .31664 L
.9079 .31694 L
.90808 .31721 L
.90828 .31746 L
.90847 .31767 L
.90865 .31784 L
.90884 .31799 L
.90903 .3181 L
.90912 .31814 L
.90922 .31818 L
.90927 .31819 L
.90932 .3182 L
.90936 .31821 L
.90941 .31821 L
.90943 .31822 L
.90945 .31822 L
.90948 .31822 L
.90949 .31822 L
.9095 .31822 L
.9095 .31822 L
.90951 .31822 L
.90951 .31822 L
.90951 .31822 L
.90952 .31822 L
.90952 .31822 L
.90953 .31822 L
.90954 .31822 L
.90954 .31822 L
.90955 .31822 L
.90955 .31822 L
.90956 .31822 L
.90957 .31822 L
.90958 .31822 L
.9096 .31822 L
.90962 .31822 L
.90965 .31821 L
.9097 .31821 L
.90975 .3182 L
.9098 .31818 L
.90989 .31815 L
.90998 .31812 L
Mistroke
.91016 .31801 L
.91036 .31787 L
.91055 .31769 L
.91074 .31748 L
.91093 .31723 L
.91112 .31695 L
.91132 .31662 L
.91151 .31627 L
.9117 .3159 L
.91189 .31548 L
.91208 .31505 L
.91226 .3146 L
.91246 .31411 L
.91265 .31361 L
.91284 .31305 L
.91304 .3125 L
.91322 .31195 L
.91341 .31135 L
.9136 .31077 L
.91378 .31019 L
.91398 .30957 L
.91416 .30897 L
.91436 .30832 L
.91455 .3077 L
.91473 .3071 L
.91493 .30647 L
.91512 .30587 L
.91531 .30524 L
.91551 .30465 L
.91569 .30409 L
.91589 .30351 L
.91608 .30297 L
.91626 .30248 L
.91645 .30197 L
.91664 .30151 L
.91684 .30104 L
.91703 .30062 L
.91721 .30025 L
.91741 .29989 L
.91759 .29957 L
.91779 .29928 L
.91799 .29903 L
.91817 .29882 L
.91837 .29865 L
.91847 .29858 L
.91856 .29852 L
.91865 .29848 L
.91874 .29844 L
.91879 .29843 L
.91884 .29841 L
Mistroke
.91888 .2984 L
.91893 .29839 L
.91895 .29839 L
.91897 .29839 L
.91898 .29839 L
.919 .29839 L
.91901 .29839 L
.91902 .29839 L
.91902 .29839 L
.91903 .29839 L
.91904 .29839 L
.91904 .29839 L
.91904 .29839 L
.91905 .29839 L
.91905 .29839 L
.91906 .29839 L
.91906 .29839 L
.91907 .29839 L
.91907 .29839 L
.91908 .29839 L
.91909 .29839 L
.9191 .29839 L
.91912 .29839 L
.91914 .29839 L
.91916 .29839 L
.91921 .2984 L
.91926 .29841 L
.9193 .29842 L
.9194 .29846 L
.91949 .2985 L
.91969 .29863 L
.91988 .29879 L
.92008 .299 L
.92027 .29925 L
.92045 .29953 L
.92065 .29987 L
.92084 .30023 L
.92102 .30061 L
.92121 .30106 L
.9214 .30152 L
.9216 .30205 L
.92179 .30259 L
.92197 .30313 L
.92216 .30374 L
.92235 .30435 L
.92255 .30502 L
.92274 .30569 L
.92293 .30635 L
.92313 .30707 L
.92332 .30778 L
Mistroke
.9235 .30846 L
.92369 .3092 L
.92388 .30992 L
.92408 .31068 L
.92427 .31141 L
.92445 .31211 L
.92465 .31285 L
.92484 .31355 L
.92502 .31421 L
.92521 .3149 L
.9254 .31555 L
.9256 .31621 L
.92579 .31682 L
.92597 .31739 L
.92616 .31796 L
.92635 .31848 L
.92655 .319 L
.92674 .31946 L
.92693 .31986 L
.92712 .32025 L
.92731 .32059 L
.92749 .32087 L
.92769 .32112 L
.92787 .32132 L
.92797 .3214 L
.92807 .32148 L
.92817 .32154 L
.92826 .32159 L
.92836 .32162 L
.92841 .32163 L
.92843 .32164 L
.92846 .32164 L
.92848 .32165 L
.92851 .32165 L
.92852 .32165 L
.92853 .32165 L
.92854 .32165 L
.92854 .32165 L
.92855 .32165 L
.92856 .32165 L
.92856 .32165 L
.92857 .32165 L
.92857 .32165 L
.92858 .32165 L
.92858 .32165 L
.92859 .32165 L
.9286 .32165 L
.9286 .32165 L
.92861 .32165 L
.92862 .32165 L
Mistroke
.92864 .32165 L
.92867 .32165 L
.92869 .32164 L
.92874 .32163 L
.92878 .32162 L
.92884 .3216 L
.92893 .32156 L
.92903 .32151 L
.92923 .32135 L
.92942 .32115 L
.9296 .32091 L
.9298 .3206 L
.92999 .32026 L
.93017 .31989 L
.93036 .31944 L
.93055 .31897 L
.93074 .31842 L
.93093 .31785 L
.93112 .31727 L
.93131 .31661 L
.9315 .31594 L
.9317 .31519 L
.93189 .31443 L
.93208 .31368 L
.93227 .31286 L
.93246 .31204 L
.93264 .31124 L
.93284 .31037 L
.93302 .30951 L
.93322 .3086 L
.93341 .30771 L
.93359 .30686 L
.93379 .30595 L
.93398 .30508 L
.93418 .30416 L
.93437 .30329 L
.93455 .30247 L
.93475 .30161 L
.93494 .30081 L
.93512 .30006 L
.93532 .29929 L
.9355 .29859 L
.9357 .29787 L
.93589 .29723 L
.93608 .29664 L
.93628 .29607 L
.93646 .29556 L
.93664 .29511 L
.93684 .29469 L
.93702 .29434 L
Mistroke
.93722 .29402 L
.93741 .29378 L
.93759 .29359 L
.93769 .29352 L
.93779 .29346 L
.93784 .29344 L
.93789 .29342 L
.93794 .2934 L
.93799 .29339 L
.93801 .29339 L
.93802 .29339 L
.93804 .29338 L
.93805 .29338 L
.93806 .29338 L
.93806 .29338 L
.93807 .29338 L
.93807 .29338 L
.93808 .29338 L
.93808 .29338 L
.93809 .29338 L
.93809 .29338 L
.9381 .29338 L
.9381 .29338 L
.9381 .29338 L
.93811 .29338 L
.93811 .29338 L
.93812 .29338 L
.93812 .29338 L
.93813 .29338 L
.93814 .29338 L
.93815 .29338 L
.93818 .29339 L
.9382 .29339 L
.93823 .2934 L
.93827 .29341 L
.93832 .29342 L
.93837 .29345 L
.93847 .2935 L
.93857 .29357 L
.93877 .29377 L
.93896 .29403 L
.93914 .29434 L
.93934 .29473 L
.93953 .29516 L
.93971 .29564 L
.93991 .29621 L
.94009 .29681 L
.94029 .29751 L
.94048 .29824 L
.94067 .29899 L
Mistroke
.94086 .29983 L
.94105 .30069 L
.94123 .30156 L
.94143 .30252 L
.94161 .30348 L
.94181 .30454 L
.942 .30558 L
.94218 .30661 L
.94238 .30773 L
.94256 .30882 L
.94276 .31 L
.94295 .31114 L
.94314 .31224 L
.94334 .31342 L
.94352 .31454 L
.94371 .31561 L
.9439 .31674 L
.94409 .31781 L
.94428 .31892 L
.94448 .31996 L
.94466 .32093 L
.94485 .32193 L
.94504 .32285 L
.94524 .32378 L
.94544 .32462 L
.94562 .32538 L
.94582 .32614 L
.94601 .3268 L
.94619 .32738 L
.94638 .32792 L
.94657 .32838 L
.94677 .32879 L
.94696 .32911 L
.94715 .32934 L
.94724 .32943 L
.94734 .32951 L
.94739 .32953 L
.94744 .32956 L
.94748 .32957 L
.94752 .32958 L
.94755 .32959 L
.94756 .32959 L
.94757 .32959 L
.94758 .32959 L
.94759 .32959 L
.94759 .32959 L
.9476 .32959 L
.9476 .32959 L
.94761 .32959 L
.94761 .32959 L
Mistroke
.94762 .32959 L
.94762 .32959 L
.94763 .32959 L
.94763 .32959 L
.94764 .32959 L
.94764 .32959 L
.94765 .32959 L
.94766 .32959 L
.94767 .32959 L
.94769 .32959 L
.94771 .32958 L
.94774 .32958 L
.94776 .32957 L
.9478 .32955 L
.94786 .32953 L
.9479 .3295 L
.948 .32943 L
.9481 .32933 L
.94829 .32907 L
.94848 .32873 L
.94866 .32833 L
.94886 .32782 L
.94904 .32725 L
.94924 .32655 L
.94943 .3258 L
.94961 .325 L
.94981 .32407 L
.95 .3231 L
.9502 .322 L
.95039 .32087 L
.95057 .31971 L
.95077 .31843 L
.95096 .31713 L
.95114 .31583 L
.95134 .3144 L
.95152 .31298 L
.95172 .31143 L
.95191 .30991 L
.9521 .30842 L
.95229 .30681 L
.95248 .30524 L
.95266 .30373 L
.95286 .30212 L
.95304 .30056 L
.95324 .29893 L
.95343 .29736 L
.95361 .29588 L
.95381 .29433 L
.954 .29288 L
.95419 .29137 L
Mistroke
.95439 .28997 L
.95457 .28868 L
.95477 .28737 L
.95496 .28617 L
.95514 .28509 L
.95533 .28402 L
.95552 .28307 L
.95572 .28215 L
.95591 .28137 L
.95609 .28071 L
.95629 .28011 L
.95648 .27964 L
.95657 .27945 L
.95668 .27927 L
.95677 .27914 L
.95682 .27908 L
.95687 .27903 L
.95692 .27899 L
.95696 .27896 L
.95701 .27893 L
.95704 .27892 L
.95707 .27892 L
.95709 .27891 L
.9571 .27891 L
.95711 .27891 L
.95712 .27891 L
.95712 .27891 L
.95713 .27891 L
.95714 .27891 L
.95714 .27891 L
.95714 .27891 L
.95715 .27891 L
.95715 .27891 L
.95716 .27891 L
.95716 .27891 L
.95716 .27891 L
.95717 .27891 L
.95717 .27891 L
.95718 .27891 L
.95719 .27891 L
.9572 .27891 L
.95723 .27892 L
.95725 .27892 L
.9573 .27895 L
.95735 .27898 L
.95743 .27905 L
.95753 .27916 L
.95762 .27929 L
.9578 .27966 L
.958 .28018 L
Mistroke
.95819 .28082 L
.95837 .28156 L
.95857 .28248 L
.95875 .28349 L
.95895 .2847 L
.95914 .286 L
.95933 .28736 L
.95952 .28894 L
.95971 .29058 L
.9599 .29226 L
.96009 .29417 L
.96028 .2961 L
.96047 .29826 L
.96066 .30044 L
.96085 .30261 L
.96104 .30501 L
.96123 .30739 L
.96143 .30999 L
.96162 .31256 L
.96181 .31508 L
.96201 .31779 L
.9622 .32044 L
.96238 .323 L
.96257 .32574 L
.96276 .32838 L
.96296 .33117 L
.96315 .33384 L
.96333 .33637 L
.96353 .33902 L
.96372 .34151 L
.9639 .34385 L
.96409 .34625 L
.96428 .34848 L
.96448 .35074 L
.96467 .35279 L
.96485 .35465 L
.96504 .35648 L
.96523 .3581 L
.96543 .35964 L
.96562 .36094 L
.96581 .36201 L
.966 .36294 L
.9661 .36333 L
.96619 .36363 L
.96629 .36389 L
.96638 .36408 L
.96642 .36417 L
.96647 .36424 L
.96652 .36429 L
.96656 .36433 L
Mistroke
.96659 .36434 L
.9666 .36435 L
.96661 .36436 L
.96663 .36436 L
.96663 .36436 L
.96664 .36436 L
.96664 .36436 L
.96665 .36437 L
.96666 .36437 L
.96666 .36437 L
.96667 .36437 L
.96667 .36437 L
.96668 .36437 L
.96668 .36436 L
.96669 .36436 L
.96669 .36436 L
.9667 .36436 L
.96672 .36436 L
.96673 .36435 L
.96675 .36434 L
.96678 .36432 L
.9668 .3643 L
.96685 .36426 L
.96689 .36419 L
.96695 .36409 L
.96704 .36387 L
.96714 .36357 L
.96733 .36282 L
.96752 .36175 L
.96771 .36043 L
.9679 .35872 L
.9681 .35676 L
.96828 .35458 L
.96848 .35194 L
.96866 .34908 L
.96885 .34604 L
.96904 .34246 L
.96922 .3387 L
.96942 .33435 L
.96961 .32982 L
.96979 .32515 L
.96999 .31983 L
.97018 .31437 L
.97038 .30821 L
.97057 .30194 L
.97075 .29557 L
.97095 .28847 L
.97114 .28129 L
.97132 .27409 L
.97151 .26611 L
Mistroke
.9717 .25812 L
.9719 .24931 L
.97209 .24052 L
.97227 .23178 L
.97247 .2222 L
.97266 .21271 L
.97286 .20234 L
.97305 .19208 L
.97323 .18198 L
.97343 .171 L
.97362 .16021 L
.9738 .14964 L
.974 .1382 L
.97419 .12701 L
.97438 .11494 L
.97458 .10316 L
.97476 .0917 L
.97496 .07938 L
.97514 .06742 L
.97533 .05584 L
.97552 .04343 L
.97571 .03144 L
.9759 .01864 L
.97609 .00629 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool00?moofUoo`00ZGoo1@00^Woo002[Ool00`00Oomoo`2jOol00:1oo`H000Eoo`03001oogoo0;Yo
o`00Zgoo00<007ooOol01Goo0`00UGoo00<007ooOol06Woo002[Ool00`00Oomoo`05Ool00`00Oomo
o`2EOol00`00Oomoo`0JOol00:]oo`03001oogoo00Eoo`03001oogoo09Eoo`03001oogoo01Yoo`00
Zgoo00<007ooOol01Goo00<007ooOol0UGoo00<007ooOol06Woo002YOol30007Ool00`00Oomoo`2E
Ool00`00Oomoo`0JOol00;=oo`8009Ioo`03001oogoo01Yoo`00/goo00<007ooOol0UGoo00<007oo
Ool06Woo002cOol00`00Oomoo`2EOol00`00Oomoo`0JOol00;=oo`03001oogoo09Eoo`03001oogoo
01Yoo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=o
o`03001oogoo09Aoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol0
0`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03001oogoo01]oo`00/goo0P00
UGoo00<007ooOol06goo002cOol00`00Oomoo`2DOol00`00Oomoo`0KOol00;=oo`03001oogoo09Ao
o`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol06goo002cOol2002EOol00`00Oomo
o`0KOol00;=oo`03001oogoo09Aoo`03001oogoo01]oo`00/goo00<007ooOol0U7oo00<007ooOol0
6goo002AOol30006Ool20006Ool00`00Oomoo`04Ool40006Ool00`00Oomoo`2DOol00`00Oomoo`0K
Ool0091oo`05001oogooOol00005Ool20006Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomo
o`2DOol00`00Oomoo`0KOol008Qoo`H0009oo`05001oogooOol0000>Ool00`00Oomoo`07Ool00`00
Oomoo`03Ool3002DOol00`00Oomoo`0KOol0091oo`05001oogooOol0000>Ool00`00Oomoo`07Ool0
0`00Oomoo`03Ool00`00Oomoo`2DOol00`00Oomoo`0KOol0091oo`05001oogooOol0000>Ool00`00
Oomoo`03Ool40006Ool00`00Oomoo`2DOol00`00Oomoo`0KOol0091oo`05001oogooOol0000?Ool0
0`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2DOol00`00Oomoo`0KOol0091oo`05001oogoo
Ool0000;Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol0U7oo00<007ooOol06goo
002AOol3000<Ool50004Ool40006Ool2002EOol00`00Oomoo`0KOol00;=oo`03001oogoo09Aoo`03
001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=o
o`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomo
o`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002E
Ool00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo
002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<0
07ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00VGoo
0`001Woo0P001Goo10001Woo0P00UGoo00<007ooOol06goo002HOol01@00Oomoogoo00001Goo0P00
2Goo00<007ooOol00goo0P00UGoo00<007ooOol06goo002@Ool60002Ool01@00Oomoogoo000047oo
00<007ooOol00goo0P00UGoo00<007ooOol06goo002HOol01@00Oomoogoo000047oo00<007ooOol0
0goo0`00U7oo00<007ooOol06goo002HOol01@00Oomoogoo000037oo10001Woo0P00UGoo00<007oo
Ool06goo002HOol01@00Oomoogoo000037oo00<007ooOol01goo0P00UGoo00<007ooOol06goo002H
Ool01@00Oomoogoo000037oo00<007ooOol01goo0P00UGoo00<007ooOol06goo002IOol3000=Ool4
0006Ool2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo0P00UGoo00<0
07ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo01]oo`00/goo
0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eoo`03001oogoo
01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol00;=oo`8009Eo
o`03001oogoo01]oo`00/goo0P00UGoo00<007ooOol06goo002cOol2002EOol00`00Oomoo`0KOol0
0;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00U7oo00<007ooOol077oo002cOol2002DOol00`00
Oomoo`0LOol00;=oo`8009Aoo`03001oogoo01aoo`00/goo0P00U7oo00<007ooOol077oo002AOol3
0006Ool20004Ool50004Ool40006Ool2002DOol00`00Oomoo`0LOol0091oo`05001oogooOol00005
Ool20005Ool01000Oomoo`0027oo00<007ooOol00goo0P00U7oo00<007ooOol077oo0028Ool60002
Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol00goo0P00U7oo00<007ooOol077oo
002@Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007ooOol00goo0`00Tgoo00<007ooOol0
77oo002@Ool01@00Oomoogoo00003goo00<007ooOol00Woo10001Woo0P00U7oo00<007ooOol077oo
002@Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01goo0P00U7oo00<007ooOol0
77oo002@Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Moo`8009Aoo`03
001oogoo01aoo`00TGoo0`003Goo0`001Goo10001Woo0P00U7oo00<007ooOol077oo002cOol2002D
Ool00`00Oomoo`0LOol001moo`03001oogoo08ioo`03001oogoo008009Aoo`03001oogoo01aoo`00
7Woo0P00T7oo00<007ooOol00P00U7oo00<007ooOol077oo000NOol2002@Ool00`00Oomoo`02002D
Ool00`00Oomoo`0LOol001ioo`8008moo`80009oo`8009Aoo`03001oogoo01aoo`007Woo0P00Sgoo
0`0000=oo`000000U7oo00<007ooOol077oo000NOol2000DOol30006Ool20006Ool3000XOol30006
Ool20004Ool5000[Ool01000Ool007oo0P00<Goo0`001Woo0P0017oo1@00:7oo0`001Woo0P001Woo
0`004goo00<007ooOol077oo000NOol2000COol01@00Oomoogoo00001Goo0P001goo00<007ooOol0
9Woo00D007ooOomoo`0000Eoo`8000Eoo`04001oogoo000[Ool01`00Ool007oo001oo`0002moo`05
001oogooOol00005Ool20005Ool01000Oomoo`009goo00D007ooOomoo`0000Eoo`8000Moo`03001o
ogoo019oo`03001oogoo01aoo`007Woo0P002goo1P000Woo00D007ooOomoo`0000]oo`D001moo`H0
009oo`05001oogooOol0000=Ool00`00Oomoo`0[Ool01`00Ool007oo001oo`0002moo`05001oogoo
Ool0000=Ool00`00Oomoo`0WOol01@00Oomoogoo00002goo1@004goo00<007ooOol077oo000NOol2
000COol01@00Oomoogoo00002goo00@007ooOol002Qoo`05001oogooOol0000>Ool00`00Oomoo`0Z
Ool01000Ool007oo0`000goo00<007ooOol0:Goo00D007ooOomoo`0000ioo`03001oogoo02Ioo`05
001oogooOol0000;Ool01000Oomoo`0047oo00D007ooOomoo`0001ioo`007Woo0P004goo00D007oo
Oomoo`0000aoo`03001oo`0002Qoo`05001oogooOol0000?Ool00`00Oomoo`0YOol01`00Ool007oo
001oo`0000=oo`03001oogoo02Uoo`05001oogooOol0000?Ool00`00Oomoo`0UOol01@00Oomoogoo
000037oo00<007oo00003goo0P000goo00<007ooOol077oo000NOol00`00Ool0000BOol01@00Oomo
ogoo000037oo00<007oo0000:7oo00D007ooOomoo`0000moo`03001oogoo02Uoo`07001oo`00Ool0
07oo00000Woo0`00:Woo00D007ooOomoo`0000moo`03001oogoo02Eoo`05001oogooOol0000<Ool0
0`00Ool0000?Ool20003Ool00`00Oomoo`0LOol001ioo`03001oo`0000Aoo`03001oogoo00]oo`05
001oogooOol0000=Ool2000XOol01@00Oomoogoo00002goo00D007ooOomoo`0002Ioo`03001oogoo
009oo`07001oo`00Ool007oo00000Woo00<007oo0000:Woo00D007ooOomoo`0000]oo`05001oogoo
Ool0000WOol01@00Oomoogoo00003Goo0P003goo0P000goo00<007ooOol077oo000MOol01000Oomo
o`000goo0P003Woo0`003goo00<007ooOol09goo0`003Goo0`009Woo0P0017oo00L007oo001oo`00
Ool00002Ool00`00Ool0000[Ool3000=Ool3000YOol3000?Ool00`00Oomoo`0=Ool20003Ool00`00
Oomoo`0LOol001eoo`04001oogoo0003Ool20023Ool30003Ool01000Ool007oo0`000Woo00<007oo
000017oo00<007ooOol0O7oo0P000goo0`000goo00<007ooOol077oo000MOol01000Oomoo`000goo
0P0017oo0P00Mgoo0P0017oo00<007oo00000goo00L007oo001oo`00Ool00002Ool00`00Ool00003
Ool3001mOol20003Ool01000Oomoo`000Woo00<007ooOol077oo000MOol01000Oomoo`000Woo0P00
00=oo`00Ool00Woo0P0017oo0P00Jgoo0P0017oo0`000goo00<007oo00000goo00L007oo001oo`00
Ool00002Ool00`00Ool00003Ool00`00Ool00004Ool20004Ool2001UOol20004Ool20004Ool20003
Ool01000Oomoo`000Woo00<007ooOol077oo000MOol01000Oomoo`000Woo00@007ooOol000=oo`<0
00=oo`<000=oo`8000Aoo`8000Eoo`03001oogoo00=oo`03001oogoo03Yoo`03001oogoo009oo`80
00Aoo`8000Aoo`8000Aoo`<000=oo`03001oo`0000=oo`03001oo`00009oo`08001oogoo001oo`00
Ool0009oo`03001oo`0000=oo`03001oo`0000=oo`03001oo`0000=oo`<000Aoo`8000Aoo`8000Ao
o`8000Eoo`03001oogoo03=oo`03001oogoo00=oo`03001oogoo00=oo`8000Aoo`8000Aoo`8000=o
o`<000=oo`04001oo`000002Ool01000Oomoo`000Woo00<007ooOol077oo000MOol01000Oomoo`00
0Woo00@007ooOol0009oo`04001oogoo0002Ool2000017oo001oogoo10000goo0`000goo0`000goo
0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo
10000Woo10000Woo10000Woo0P0000Aoo`00Oomoo`800004Ool007ooOol2000017oo001oogoo0P00
00Eoo`00Oomoo`00009oo`05001oo`00Ool00002Ool01000Oomoo`000Woo00@007oo0000009oo`04
001oo`000002Ool01000Ool000000Woo10000Woo10000Woo10000Woo10000goo0`000goo0`000goo
0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo0`000goo
00@007oo0000009oo`04001oo`000002Ool01000Oomoo`000Woo00@007ooOol0009oo`03001oogoo
01aoo`0057ooo`00@0005Goo000KOol00`00Ool00002Ool01000Oomoo`000Woo00D007ooOol007oo
0080009oo`03001oogoo00800004Ool007ooOol40003Ool00`00Ool00003Ool300000goo001oo`03
0003Ool30003Ool30003Ool30003Ool300000goo001oo`030003Ool30003Ool40002Ool40002Ool4
00000goo000000030002Ool40002Ool40002Ool2000017oo001oogoo0P0000=oo`00Ool00`0000Eo
o`00Oomoo`00009oo`08001oogoo001oo`00Ool0009oo`04001oogoo0002Ool00`00Oomoo`040002
Ool01000Ool000000Woo00<007oo00000P0000=oo`0000000P000Woo10000Woo10000Woo10000Woo
100000=oo`0000000`000goo0`000goo0`000goo0`000goo0`0000=oo`00Ool00`000goo0`000goo
0`000goo0`000goo00<007oo00000P0000=oo`00Ool00P000Woo00@007oo0000009oo`800005Ool0
07ooOol00002Ool01000Oomoo`000Woo00<007oo000077oo000MOol01000Oomoo`000Woo00@007oo
Ool0009oo`04001oogooOol30003Ool30003Ool30003Ool20004Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`0QOol00`00Oomoo`03Ool20004Ool20004Ool20004Ool20004Ool20004Ool30003Ool0
0`00Ool00003Ool00`00Ool00003Ool00`00Ool00002Ool01@00Ool007oo00000Woo00H007ooOol0
07oo0003Ool00`00Ool00003Ool30003Ool30004Ool20004Ool20004Ool20004Ool20008Ool00`00
Oomoo`0TOol00`00Oomoo`03Ool20004Ool20004Ool200000goo001oo`030003Ool30003Ool40002
Ool01000Oomoo`000Woo00@007ooOol001ioo`007Goo00@007ooOol0009oo`04001oogooOol30003
Ool20004Ool2001UOol20004Ool30003Ool00`00Ool00003Ool00`00Ool00002Ool01@00Ool007oo
00000Woo00H007ooOol007oo0003Ool30004Ool2001[Ool20004Ool20003Ool01000Oomoo`000Woo
00@007ooOol001ioo`007Goo00@007ooOol0009oo`04001oogooOol20005Ool00`00Oomoo`1`Ool0
0`00Oomoo`02Ool30003Ool00`00Ool00002Ool01`00Ool007oo001oo`0000=oo`03001oo`0000Ao
o`8007Moo`8000Aoo`8000=oo`04001oogoo000NOol001eoo`03001oogoo00@000=oo`8007eoo`80
00Aoo`03001oo`00009oo`03001oo`0000800003Ool007oo009oo`<008=oo`8000=oo`04001oogoo
000NOol001eoo`04001oogooOol20029Ool00`00Ool00002Ool01`00Ool007oo001oo`0000Aoo`80
08=oo`8000=oo`04001oogoo000NOol001eoo`04001oogooOol20029Ool00`00Ool00002Ool01`00
Ool007oo001oo`0000Aoo`03001oogoo089oo`8000=oo`04001oogoo000NOol001eoo`04001oogoo
Ool20029Ool30002Ool01`00Ool007oo001oo`0008ioo`03001oo`0001moo`007Goo00@007ooOomo
o`8008Uoo`8000=oo`07001oo`00Ool007oo0000Sgoo0P007goo000MOol01000Oomoogoo0P00RWoo
00H007ooOomoo`00Ool300000goo001oo`2>Ool2000OOol001eoo`03001oogoo095oo`07001oo`00
Ool007oo0000Sgoo0P007goo000MOol00`00Oomoo`2AOol01`00Ool007oo001oo`0008moo`8001mo
o`007Goo00<007ooOol0TWoo0P0000Aoo`00Ool008moo`8001moo`007Goo00<007ooOol0TWoo0P00
00Aoo`00Ool008moo`8001moo`007Goo00<007ooOol0TWoo0`0000=oo`000000Sgoo0P007goo000M
Ool00`00Oomoo`2BOol20002Ool00`00Oomoo`2>Ool2000OOol001eoo`03001oogoo099oo`80009o
o`03001oogoo08ioo`8001moo`007Goo00<007ooOol0TWoo0P000Woo00<007ooOol0SWoo0P007goo
000MOol00`00Oomoo`2BOol2002dOol001eoo`03001oogoo099oo`<00;=oo`007Goo00<007ooOol0
TWoo0P00]7oo000MOol00`00Oomoo`1aOol30006Ool20004Ool50004Ool40005Ool2002dOol001eo
o`03001oogoo071oo`05001oogooOol00005Ool20005Ool01000Oomoo`0027oo00<007ooOol00Woo
0P00]7oo000MOol00`00Oomoo`1`Ool01@00Oomoogoo00003Goo00<007ooOol027oo00<007ooOol0
0Woo0P00]7oo000MOol00`00Oomoo`1`Ool01@00Oomoogoo00003Woo00<007ooOol01goo00<007oo
Ool00Woo1000/Woo000MOol00`00Oomoo`1`Ool01@00Oomoogoo00003goo00<007ooOol00Woo1000
1Goo0P00]7oo000MOol00`00Oomoo`1`Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007oo
Ool01Woo0P00]7oo000MOol00`00Oomoo`1`Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ao
o`03001oogoo00Ioo`800;Aoo`007Goo00<007ooOol0LGoo0`003Goo0`001Goo10001Goo0P00]7oo
000MOol00`00Oomoo`2BOol3002cOol001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0
Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002dOol001aoo`03001oogoo09=oo`800;Aoo`0077oo
00<007ooOol0Tgoo0`00/goo000LOol00`00Oomoo`2COol2002dOol001aoo`03001oogoo09=oo`80
0;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol3002cOol001aoo`03001o
ogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002dOol0
01aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0`00/goo000LOol00`00Oomoo`2C
Ool2002dOol001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0NWoo0`001Woo0P001Goo
10001Goo0P00]7oo000LOol00`00Oomoo`1iOol01@00Oomoogoo00001Goo0P002Goo00<007ooOol0
0Woo0P00]7oo000LOol00`00Oomoo`1iOol01@00Oomoogoo000047oo00<007ooOol00Woo1000/Woo
000LOol00`00Oomoo`1iOol01@00Oomoogoo000047oo00<007ooOol00Woo0P00]7oo000LOol00`00
Oomoo`1iOol01@00Oomoogoo000037oo10001Goo0P00]7oo000LOol00`00Oomoo`1iOol01@00Oomo
ogoo000037oo00<007ooOol01Woo0P00]7oo000LOol00`00Oomoo`1iOol01@00Oomoogoo000037oo
00<007ooOol01Woo0P00]7oo000LOol00`00Oomoo`1jOol3000=Ool40005Ool3002cOol001aoo`03
001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000LOol00`00Oomoo`2COol2002d
Ool001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0`00/goo000LOol00`00Oomo
o`2COol2002dOol001aoo`03001oogoo09=oo`800;Aoo`0077oo00<007ooOol0Tgoo0P00]7oo000L
Ool00`00Oomoo`2COol2002dOol001aoo`03001oogoo09=oo`<00;=oo`0077oo00<007ooOol0Tgoo
0P00]7oo000LOol00`00Oomoo`2COol2002dOol001aoo`03001oogoo09=oo`800;Aoo`0077oo00<0
07ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol2002cOol001aoo`03001oogoo09Ao
o`03001oogoo0;9oo`0077oo00<007ooOol0LWoo0`001Woo0P001Woo00<007ooOol017oo10001Woo
00<007ooOol0/Woo000LOol00`00Oomoo`1aOol01@00Oomoogoo00001Goo0P001Woo00<007ooOol0
27oo00<007ooOol00goo00<007ooOol0/Woo000LOol00`00Oomoo`1aOol01@00Oomoogoo00003Woo
00<007ooOol01goo00<007ooOol00goo00<007ooOol0/Woo000LOol00`00Oomoo`1aOol01@00Oomo
ogoo00003Woo00<007ooOol01goo00<007ooOol00goo0`00/Woo000LOol00`00Oomoo`1aOol01@00
Oomoogoo00003Woo00<007ooOol00goo10001Woo00<007ooOol0/Woo000LOol00`00Oomoo`1aOol0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0/Woo000LOol00`00
Oomoo`1aOol01@00Oomoogoo00002goo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo
0;9oo`0077oo00<007ooOol0LWoo0`0037oo1@0017oo10001Woo00<007ooOol0/Woo000LOol00`00
Oomoo`2DOol2002cOol001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo
00<007ooOol0/Woo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`03
001oogoo0;9oo`0077oo00<007ooOol0U7oo0P00/goo000LOol00`00Oomoo`2DOol00`00Oomoo`2b
Ool001aoo`03001oogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo
000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001oogoo09Aoo`800;=oo`0077oo00<0
07ooOol0U7oo00<007ooOol0/Woo000LOol00`00Oomoo`2DOol00`00Oomoo`2bOol001aoo`03001o
ogoo09Aoo`03001oogoo0;9oo`0077oo00<007ooOol0U7oo00<007ooOol0/Woo000KOol00`00Oomo
o`2EOol2002cOol001]oo`03001oogoo09Eoo`03001oogoo0;9oo`006goo00<007ooOol0Rgoo1@00
1Goo00<007ooOol0/Woo000KOol00`00Oomoo`2=Ool00`00Oomoo`05Ool00`00Oomoo`2bOol001]o
o`03001oogoo08eoo`03001oogoo00Eoo`03001oogoo0;9oo`006goo00<007ooOol0SGoo00<007oo
Ool01Goo0`00/Woo002[Ool00`00Oomoo`2jOol00:]oo`03001oogoo0;Yoo`00Zgoo00<007ooOol0
^Woo002YOol3002lOol00?moofUoo`00ZWoo00<007ooOol0^goo002ZOol2002lOol0089oo`H0009o
o`H0009oo`H000Aoo`@0009oo`H000=oo`03001oogoo00Uoo`<0009oo`<001Qoo`@000Aoo`<008Io
o`00Pgoo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`05
001oogooOol00006Ool2000;Ool00`00Oomoo`02Ool00`00Oomoo`07Ool6000>Ool01000Oomoo`00
0goo00<007ooOol0Pgoo0023Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol00Woo00D007ooOomoo`0001=oo`03001oogoo009oo`03001oogoo01]oo`04001oogoo
0003Ool00`00Oomoo`23Ool008=oo`03001oo`0000Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo009oo`05001oogooOol0000COol01P00Ool00000Ool000Uoo`H000ioo`04001oogoo0003
Ool00`00Oomoo`23Ool008=oo`<000Ioo`8000Ioo`8000Eoo`03001oogoo009oo`04001oogooOol2
000BOol01P00Ool00000Ool001Uoo`@000=oo`05001oogooOol00025Ool008=oo`05001oo`00Ool0
0003Ool2000017oo000000000Woo0P0000Aoo`00000000=oo`@000=oo`800004Ool00000000?Ool2
0002Ool2000IOol00`00Oomoo`04Ool01@00Oomoogoo0000QGoo0023Ool01@00Oomoogoo0000<7oo
0P000Woo0P006Goo00<007ooOol017oo00D007ooOomoo`0008Eoo`00PWoo1P00;goo0P0017oo0P00
67oo100017oo0`00QWoo003oOomYOol00?moofUoo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The error has a maximum value of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)\)]],
  " at the discontinuity points",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t = m\ T/2\)\)\)]],
  ", independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ".  This maximum error is easy to understand: the square wave takes on the \
values ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)\)]],
  " at these points, but the Fourier series is zero there because at ",
  Cell[BoxData[
      \(TraditionalForm\`t = m\ T/2\)]],
  " the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th term in the series is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`sin(n\ m\ \[Pi]) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Furthermore, each successive peak in the error has a value that is \
independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ": the first peak on the right side of the origin is at about 0.2, the next \
is at about 0.1, and so on, independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ".   In fact, in the next subsection we will show that the maximum size of \
error of the first peak is 0.1789..., that of the second is 0.0662..., ",
  "independent of",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`M\)],
    FontSlant->"Italic"],
  ". The constancy of these maximum errors as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases is most easily observed by animating the above set of graphs. \
What you can see from the animation, however, is that while the height of the \
peaks is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ",  the ",
  StyleBox["width",
    FontSlant->"Italic"],
  " of the peaks shrinks as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases, and the peaks crowd in toward the origin. This strange \
behavior is called the ",
  StyleBox[ButtonBox["Gibbs phenomenon",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Gibbs.html"]\
, None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:16"],

Cell[TextData[{
  "\tAs a result of the Gibbs phenomenon,  for any finite value of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", no matter how large, there is always a small region around the \
discontinuity points where the magnitude of the error is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". Although this region shrinks in size as ",
  StyleBox["M",
    FontSlant->"Italic"],
  " increases, the fact that the error is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " within this region distinguishes the behavior of this Fourier series from \
that of a function that satisfies the restrictions of Theorem 2.1, such as \
the triangle wave studied previously. There, the error in the series \
decreased ",
  StyleBox["uniformly ",
    FontSlant->"Italic"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increased.  By this we mean that, as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases, ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftBracketingBar]\(f\_approx\)(t, M) - 
            f(t)\[RightBracketingBar] \[Rule] 0\)]],
  " ",
  StyleBox["for all ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`t\)],
    FontSlant->"Italic"],
  " . This is called ",
  StyleBox["uniform convergence of error",
    FontSlant->"Italic"],
  ", and it is necessary in order for us to state that the left-hand and ",
  "right-hand",
  " sides of Eq. ",
  ButtonBox["(2.1.3)",
    ButtonData:>"(2.1.3)",
    ButtonStyle->"Hyperlink"],
  " are strictly equal to one another for every ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tMore precisely, as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  " increases,  a uniformly convergent series satisfies"
}], "Text",
  CellTags->"i:11"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[LeftBracketingBar]\(f\_approx\)(t, M) - 
          f(t)\[RightBracketingBar] < \[Epsilon](M)\)]]], "NumberedEquation",
  CellTags->"(2.1.15)"],

Cell[TextData[{
  "where",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon](M)\)]],
  " is some small number that is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and that approaches zero as ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ". Thus, the error in the series is bounded by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon](M)\)]],
  ", and this error goes to zero as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  " increases, independent of the particular value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tOn the other hand, the behavior of the error in the series \
representation of the square wave is an example of ",
  StyleBox["nonuniform convergence",
    FontSlant->"Italic"],
  ".  Here Eq. ",
  ButtonBox["(2.1.15)",
    ButtonData:>"(2.1.15)",
    ButtonStyle->"Hyperlink"],
  " is not satisfied for every value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ": we can find a small range of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "-values around the discontinuities for which the error is ",
  StyleBox["not small",
    FontSlant->"Italic"],
  ", no matter how large we take ",
  StyleBox["M.",
    FontSlant->"Italic"],
  "  "
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  "\t",
  StyleBox["Functions thay satisfy the restrictions of Theorem 2.1 have \
Fourier series representations that converge uniformly. ",
    FontSlant->"Italic"],
  " But even for nonuniformly convergent series,  the previous analysis of \
the square wave series show that the series can still provide  a reasonably \
accurate representation of the function, provided that we stay away from the \
discontinuity points. Thus, Fourier series are often used to approximately \
describe functions that have discontinuities, and even singularities. The \
description is not exact for all ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", but the error can be concentrated into small regions around the \
discontinuities and singularities by taking ",
  StyleBox["M",
    FontSlant->"Italic"],
  "  large. This is often sufficient for many purposes in scientific \
applications, particularly in that there are no real discontinuities or \
singularities in nature; such discontinuities and singularities are always \
the result of an idealization, and therefore we usually need not be too \
concerned if the series representation of such functions does not quite \
describe the singular behavior."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.6 Gibbs Phenomenon for the Square Wave", "Subsubtitle",
  CellTags->{"i:17", "c:8"}],

Cell[TextData[{
  " The fact that the width of the oscillations in the error decreases as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases suggests that we attempt to understand the Gibbs phenomenon by \
applying a scale transformation to the time: let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = M\ t/T\)]],
  " . For constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " the actual time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " approaches zero as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases. The hope is  that in these scaled time units, the compression \
of the error toward the origin observed in the above animation will \
disappear, so that on this time scale the series will become independent of \
",
  StyleBox["M",
    FontSlant->"Italic"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases."
}], "Text"],

Cell[TextData[{
  "\t In these scaled dimensionless time units, the series, Eq. ",
  ButtonBox["(2.1.14)",
    ButtonData:>"(2.1.14)",
    ButtonStyle->"Hyperlink"],
  " takes the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\_approx\)(\[Tau], \ M)\), "=", 
          RowBox[{
            StyleBox[\(\(\(4\)\(\ \)\)\/\[Pi]\),
              FontSize->14], 
            UnderoverscriptBox[
              StyleBox["\[CapitalSigma]",
                FontSize->19], \(\(n = 1\) \((n\ odd)\)\), "M"], 
            StyleBox[\(1\/n\),
              FontSize->14], \(sin(2\ \[Pi]\ n\ \[Tau]/M)\), " "}]}], 
        TraditionalForm]]],
  " ."
}], "NumberedEquation",
  CellTags->"(2.1.16)"],

Cell[TextData[{
  "There is still ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "-dependence in this function, so we will perform another scale \
transformation, defining ",
  Cell[BoxData[
      \(TraditionalForm\`s = M\ n\)]],
  ". Substituting this transformation into Eq. ",
  ButtonBox["(2.1.16)",
    ButtonData:>"(2.1.16)",
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\_approx\)(\[Tau], \ M)\), "=", 
          RowBox[{
            StyleBox[\(\(\(4\)\(\ \)\)\/\(\[Pi]\ M\)\),
              FontSize->14], 
            UnderoverscriptBox[
              StyleBox["\[CapitalSigma]",
                FontSize->19], 
              RowBox[{
                RowBox[{"s", "=", 
                  FormBox[\(1\/M\),
                    "TraditionalForm"]}], ",", 
                FormBox[\(3\/M\),
                  "TraditionalForm"], ",", 
                RowBox[{
                  FormBox[\(5\/M\),
                    "TraditionalForm"], "..."}]}], "1"], 
            StyleBox[\(1\/s\),
              FontSize->14], \(sin(2\ \[Pi]\ s\ \[Tau])\), " "}]}], 
        TraditionalForm]]],
  " ."
}], "NumberedEquation",
  CellTags->"(2.1.17)"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\((sin\ 2\ \[Pi]\ s\ \[Tau])\)/s\)]],
  "  is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " and is well behaved as ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " varies  on [0,1], taking the value ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\[Tau]\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`s = 0\)]],
  ". Furthermore, the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]s = 2/M\)]],
  " between successive",
  StyleBox[" s",
    FontSlant->"Italic"],
  "-values decreases to zero as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases, so we can replace the sum by an integral over ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  " from 0 to 1:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(lim\+\(\(\[CapitalDelta]s\)\(\[Rule]\)\(\ \)\(0\)\(\ \ \)\)\
\), 
          RowBox[{"(", 
            RowBox[{"\[CapitalDelta]s", " ", 
              UnderoverscriptBox[
                StyleBox["\[CapitalSigma]",
                  FontSize->19], 
                RowBox[{
                  RowBox[{"s", "=", 
                    FormBox[\(\[CapitalDelta]s\/2\),
                      "TraditionalForm"]}], ",", 
                  FormBox[\(\(3  \[CapitalDelta]s\)\/2\),
                    "TraditionalForm"], ",", 
                  RowBox[{
                    FormBox[\(\(\(5  \[CapitalDelta]s\)\/2\)\(,\)\),
                      "TraditionalForm"], "..."}]}], "1"], 
              StyleBox[\(1\/s\),
                FontSize->14], \(sin(2\ \[Pi]\ s\ \[Tau])\)}], ")"}]}], "=", 
        RowBox[{\(\[Integral]\_0\%1\), 
          RowBox[{
            StyleBox[\(1\/s\),
              FontSize->14], \(sin(2\ \[Pi]\ s\ \[Tau])\), 
            " ", \(\(\[DifferentialD]s\)\(.\)\)}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(2.1.18)"],

Cell[TextData[{
  "Substituting this integral into Eq. ",
  ButtonBox["(2.1.17)",
    ButtonData:>"(2.1.17)",
    ButtonStyle->"Hyperlink"],
  " yields the following result for ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\_approx\)(\[Tau], \ M)\), "=", 
          RowBox[{\(2\/\[Pi]\), 
            RowBox[{\(\[Integral]\_0\%1\), 
              RowBox[{
                StyleBox[\(1\/s\),
                  FontSize->14], \(sin(2\ \[Pi]\ s\ \[Tau])\), 
                " ", \(\[DifferentialD]s\)}]}]}]}], TraditionalForm]]],
  " "
}], "NumberedEquation",
  CellTags->"(2.1.19)"],

Cell[TextData[{
  "As we hoped, ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  " is now independent of ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "when written in terms of the scaled time",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  ". It can be evaluated in terms of a special function called a ",
  StyleBox["sine integral",
    FontSlant->"Italic"],
  ":"
}], "Text",
  CellTags->"i:21"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\_approx[\[Tau]_]\  = \ 
      Simplify[2/Pi\ Integrate[Sin[2\ Pi\ s\ \[Tau]]/s, {s, 0, 1}], 
        Im[\[Tau]] \[Equal] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.18"],

Cell[BoxData[
    \(\(2\ SinIntegral[2\ \[Pi]\ \[Tau]]\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "A plot of this function vs. scaled time \[Tau] (Cell ",
  ButtonBox["2.19",
    ButtonData:>"Cell 2.19",
    ButtonStyle->"Hyperlink"],
  ") reveals the characteristic oscillations of the Gibb's phenomenon that we \
observed previously. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f\_approx[\[Tau]], {\[Tau], \(-3\), 3}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.19"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.15873 0.309016 0.249625 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 .05939 -12 -4.5 ]
[.4875 .05939 0 4.5 ]
[.4875 .1842 -24 -4.5 ]
[.4875 .1842 0 4.5 ]
[.4875 .43383 -18 -4.5 ]
[.4875 .43383 0 4.5 ]
[.4875 .55864 -6 -4.5 ]
[.4875 .55864 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-3)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-2)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-1)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(1)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(2)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.05556 .30902 m
.05556 .31277 L
s
.0873 .30902 m
.0873 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.46825 .30902 m
.46825 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.72222 .30902 m
.72222 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.84921 .30902 m
.84921 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 .05939 m
.50625 .05939 L
s
[(-1)] .4875 .05939 1 0 Mshowa
.5 .1842 m
.50625 .1842 L
s
[(-0.5)] .4875 .1842 1 0 Mshowa
.5 .43383 m
.50625 .43383 L
s
[(0.5)] .4875 .43383 1 0 Mshowa
.5 .55864 m
.50625 .55864 L
s
[(1)] .4875 .55864 1 0 Mshowa
.125 Mabswid
.5 .08435 m
.50375 .08435 L
s
.5 .10932 m
.50375 .10932 L
s
.5 .13428 m
.50375 .13428 L
s
.5 .15924 m
.50375 .15924 L
s
.5 .20917 m
.50375 .20917 L
s
.5 .23413 m
.50375 .23413 L
s
.5 .25909 m
.50375 .25909 L
s
.5 .28405 m
.50375 .28405 L
s
.5 .33398 m
.50375 .33398 L
s
.5 .35894 m
.50375 .35894 L
s
.5 .3839 m
.50375 .3839 L
s
.5 .40887 m
.50375 .40887 L
s
.5 .45879 m
.50375 .45879 L
s
.5 .48375 m
.50375 .48375 L
s
.5 .50872 m
.50375 .50872 L
s
.5 .53368 m
.50375 .53368 L
s
.5 .03443 m
.50375 .03443 L
s
.5 .00947 m
.50375 .00947 L
s
.5 .5836 m
.50375 .5836 L
s
.5 .60857 m
.50375 .60857 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .06778 m
.06244 .05925 L
.07216 .05574 L
.08255 .05243 L
.08852 .05097 L
.09135 .05042 L
.09396 .05001 L
.09658 .04969 L
.09795 .04957 L
.09866 .04951 L
.09942 .04946 L
.10069 .0494 L
.10187 .04937 L
.1026 .04936 L
.10329 .04935 L
.10458 .04937 L
.10586 .04941 L
.10707 .04947 L
.10816 .04955 L
.10933 .04965 L
.11197 .04997 L
.11439 .05035 L
.11882 .05128 L
.1235 .05256 L
.13335 .05608 L
.14415 .06074 L
.15417 .06511 L
.16366 .06864 L
.1689 .07014 L
.17186 .0708 L
.1746 .07128 L
.1769 .07158 L
.17821 .0717 L
.17944 .07179 L
.18073 .07186 L
.18191 .07188 L
.18321 .07188 L
.18386 .07187 L
.18458 .07185 L
.1859 .07178 L
.18711 .07168 L
.18845 .07154 L
.18986 .07135 L
.19224 .07095 L
.19485 .07038 L
.19967 .06898 L
.20419 .06732 L
.22514 .05646 L
.23554 .05068 L
.24067 .04817 L
Mistroke
.24542 .04618 L
.24972 .04473 L
.25192 .04413 L
.25429 .04361 L
.25566 .04337 L
.25691 .04319 L
.2581 .04306 L
.25937 .04295 L
.2605 .0429 L
.26156 .04287 L
.26272 .04288 L
.26396 .04293 L
.26518 .04301 L
.26588 .04308 L
.26653 .04316 L
.26796 .04336 L
.26926 .04359 L
.27162 .04414 L
.27416 .04488 L
.27956 .04703 L
.28524 .05003 L
.30537 .06482 L
.31494 .07233 L
.3202 .07601 L
.32516 .07899 L
.32978 .0812 L
.33239 .08216 L
.33479 .08284 L
.33682 .08326 L
.33797 .08344 L
.33904 .08355 L
.34017 .08363 L
.34121 .08365 L
.3424 .08362 L
.34353 .08355 L
.34467 .08342 L
.3459 .08322 L
.34705 .08297 L
.34811 .0827 L
.35058 .08188 L
.35317 .08075 L
.35806 .07785 L
.36342 .0736 L
.37295 .06358 L
.38183 .05224 L
.40054 .02775 L
.40567 .02239 L
.40848 .01994 L
.4111 .01801 L
.41334 .01669 L
Mistroke
.41574 .01562 L
.41639 .0154 L
.41711 .01519 L
.41841 .01491 L
.41967 .01475 L
.42085 .01472 L
.42154 .01475 L
.42219 .01481 L
.42289 .01492 L
.42363 .01508 L
.42489 .01545 L
.42626 .01602 L
.42749 .01668 L
.4288 .01753 L
.43117 .01947 L
.43412 .02266 L
.43692 .0265 L
.44217 .03588 L
.44718 .04761 L
.45182 .06089 L
.46231 .09936 L
.48099 .19313 L
.5016 .31906 L
.52259 .44493 L
.53177 .49214 L
.54182 .53518 L
.54655 .55191 L
.55159 .56713 L
.55595 .57807 L
.56068 .5876 L
.56347 .59211 L
.56603 .59556 L
.56844 .59818 L
.57108 .60042 L
.57223 .60118 L
.57345 .60187 L
.57451 .60235 L
.57567 .60276 L
.57697 .60309 L
.57821 .60327 L
.57941 .60332 L
.58053 .60327 L
.58182 .60308 L
.58247 .60295 L
.58319 .60276 L
.58563 .60185 L
.587 .60116 L
.58848 .60029 L
.59113 .59841 L
.60111 .58836 L
Mistroke
.61973 .56371 L
.62994 .55112 L
.63532 .54559 L
.64103 .54082 L
.64601 .5377 L
.64884 .53638 L
.6502 .53586 L
.65149 .53545 L
.65266 .53513 L
.65393 .53485 L
.65508 .53465 L
.65615 .53452 L
.65742 .53442 L
.65858 .53438 L
.65922 .53439 L
.65991 .53441 L
.66116 .5345 L
.6624 .53465 L
.66353 .53483 L
.66607 .53541 L
.66843 .53615 L
.67066 .53702 L
.67566 .53949 L
.68109 .54288 L
.70215 .55922 L
.71235 .56652 L
.71734 .56945 L
.72192 .57166 L
.72672 .57343 L
.72924 .57411 L
.7319 .57465 L
.73322 .57485 L
.73394 .57493 L
.73463 .575 L
.73526 .57506 L
.73596 .5751 L
.73716 .57515 L
.73786 .57516 L
.73862 .57516 L
.73942 .57514 L
.74016 .57511 L
.74086 .57506 L
.74149 .57501 L
.74292 .57486 L
.74421 .57468 L
.74543 .57447 L
.7477 .57399 L
.75279 .5725 L
.75719 .5708 L
.76194 .56862 L
Mistroke
.78267 .55714 L
.793 .55192 L
.79805 .54985 L
.80264 .54833 L
.80497 .5477 L
.80749 .54714 L
.80888 .54688 L
.81016 .54668 L
.81138 .54651 L
.81269 .54637 L
.814 .54626 L
.81524 .54619 L
.81595 .54617 L
.8167 .54615 L
.81734 .54614 L
.81804 .54615 L
.81879 .54616 L
.81946 .54618 L
.82024 .54622 L
.82098 .54627 L
.82229 .54637 L
.82371 .54653 L
.82608 .54686 L
.82862 .54733 L
.8332 .54845 L
.84362 .55203 L
.86467 .56114 L
.87482 .56494 L
.88056 .5666 L
.8833 .56723 L
.88588 .56773 L
.88829 .5681 L
.89051 .56836 L
.89171 .56847 L
.89297 .56856 L
.89424 .56863 L
.89496 .56865 L
.89562 .56867 L
.89627 .56868 L
.89697 .56868 L
.89825 .56866 L
.89949 .56862 L
.90063 .56857 L
.90187 .56848 L
.90323 .56836 L
.90599 .56803 L
.90848 .56764 L
.91119 .56713 L
.91613 .56595 L
.9254 .56313 L
Mistroke
.94629 .55573 L
.95374 .55347 L
.96076 .55181 L
.96465 .55114 L
.96669 .55085 L
.96885 .55061 L
.97068 .55046 L
.97171 .55039 L
.97268 .55034 L
.97356 .5503 L
.97437 .55028 L
.97531 .55026 L
.97619 .55026 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oegoo00<007ooOol0
eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol3
003FOol00=Moo`03001oogoo0=Ioo`00/goo1@007goo00<007ooOol0eWoo002aOol20004Ool2000N
Ool00`00Oomoo`3FOol00:moo`8000Qoo`8001aoo`03001oogoo0=Ioo`00[Woo00<007ooOol02Woo
00<007ooOol06Goo00<007ooOol0eWoo002^Ool00`00Oomoo`0:Ool00`00Oomoo`0IOol00`00Oomo
o`3FOol00:eoo`03001oogoo00aoo`03001oogoo01Qoo`03001oogoo0=Ioo`00[7oo00<007ooOol0
3Goo00<007ooOol067oo00<007ooOol0eWoo002/Ool00`00Oomoo`0>Ool00`00Oomoo`0GOol00`00
Oomoo`3FOol00:]oo`03001oogoo00moo`03001oogoo01Moo`<00=Ioo`00ZWoo00<007ooOol04Goo
00<007ooOol05Woo00<007ooOol0eWoo002YOol00`00Oomoo`0BOol00`00Oomoo`0FOol00`00Oomo
o`3FOol00:Qoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo0=Ioo`00KGoo2000<goo00<0
07ooOol057oo00<007ooOol05Goo00<007ooOol0eWoo001[Ool20008Ool3000_Ool00`00Oomoo`0E
Ool00`00Oomoo`0EOol00`00Oomoo`3FOol006Ioo`D000eoo`<002]oo`03001oogoo01Moo`03001o
ogoo01Aoo`03001oogoo0=Ioo`009goo3000<Goo0P005Goo0P00:7oo00<007ooOol067oo00<007oo
Ool057oo00<007ooOol0eWoo000ROol5000<Ool4000/Ool00`00Oomoo`0GOol00`00Oomoo`0TOol0
0`00Oomoo`0JOol00`00Oomoo`0COol00`00Oomoo`3FOol0021oo`8001Eoo`8002Uoo`03001oogoo
01Uoo`03001oogoo02=oo`03001oogoo01Yoo`03001oogoo00Moo`D000Moo`03001oogoo0=Ioo`00
7Goo0`006Goo0P009Goo0P007Goo00<007ooOol08Goo00<007ooOol06goo00<007ooOol02Goo00<0
07ooOol01goo00<007ooOol0eWoo000IOol4000NOol3000POol2000POol00`00Oomoo`0OOol00`00
Oomoo`0MOol00`00Oomoo`08Ool00`00Oomoo`07Ool4003EOol001Eoo`@002Eoo`8001aoo`8002=o
o`03001oogoo01eoo`03001oogoo01eoo`L000Eoo`03001oogoo00Moo`03001oogoo0=Ioo`0047oo
1@00:goo0P006Goo00<007ooOol097oo00<007ooOol06goo00<007ooOol07goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol0eWoo000<Ool4000bOol3000DOol2000XOol2000JOol00`00Oomo
o`0POol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`3FOol000Yoo`8003Uoo`@000aoo`@0
02aoo`03001oogoo01Ioo`03001oogoo029oo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
0=Ioo`00BGoo100017oo1000<Goo00<007ooOol057oo00<007ooOol08goo00<007ooOol01Goo0`00
2Goo00<007ooOol0eWoo001=Ool4000fOol3000BOol00`00Oomoo`0TOol00`00Oomoo`06Ool20009
Ool00`00Oomoo`3FOol008Yoo`03001oogoo00ioo`03001oogoo02Ioo`03001oogoo011oo`03001o
ogoo0=Ioo`00Rgoo00<007ooOol02goo0P00:Goo00<007ooOol047oo00<007ooOol0eWoo002<Ool2
000:Ool00`00Oomoo`0YOol00`00Oomoo`0@Ool00`00Oomoo`3FOol008ioo`@000=oo`<002eoo`03
001oogoo00moo`03001oogoo0=Ioo`00TGoo1000<7oo00<007ooOol03goo0`00eWoo0035Ool00`00
Oomoo`0?Ool00`00Oomoo`3FOol00<Ioo`03001oogoo00ioo`03001oogoo0=Ioo`00aWoo00<007oo
Ool03Woo00<007ooOol0eWoo0036Ool00`00Oomoo`0>Ool00`00Oomoo`3FOol00<Moo`03001oogoo
00eoo`03001oogoo0=Ioo`00agoo00<007ooOol03Goo00<007ooOol0eWoo0037Ool00`00Oomoo`0=
Ool00`00Oomoo`3FOol00<Moo`03001oogoo00eoo`03001oogoo0=Ioo`00agoo00<007ooOol03Goo
00<007ooOol0eWoo0038Ool00`00Oomoo`0<Ool00`00Oomoo`3FOol00<Qoo`03001oogoo00aoo`<0
0=Ioo`00b7oo00<007ooOol037oo00<007ooOol0eWoo0038Ool00`00Oomoo`0<Ool00`00Oomoo`3F
Ool00<Qoo`03001oogoo00aoo`03001oogoo0=Ioo`00bGoo00<007ooOol02goo00<007ooOol0eWoo
0039Ool00`00Oomoo`0;Ool00`00Oomoo`3FOol00<Uoo`03001oogoo00]oo`03001oogoo0=Ioo`00
bGoo00<007ooOol02goo00<007ooOol0eWoo0039Ool00`00Oomoo`0;Ool00`00Oomoo`3FOol00<Yo
o`03001oogoo00Yoo`03001oogoo0=Ioo`00bWoo00<007ooOol02Woo0`00eWoo003:Ool00`00Oomo
o`0:Ool00`00Oomoo`3FOol00<Yoo`03001oogoo00Yoo`03001oogoo0=Ioo`00bWoo00<007ooOol0
2Woo00<007ooOol0eWoo003;Ool00`00Oomoo`09Ool00`00Oomoo`3FOol00<]oo`03001oogoo00Uo
o`03001oogoo0=Ioo`00bgoo00<007ooOol02Goo00<007ooOol0eWoo003;Ool00`00Oomoo`09Ool0
0`00Oomoo`3FOol00<]oo`03001oogoo00Uoo`03001oogoo0=Ioo`00c7oo00<007ooOol027oo00<0
07ooOol0eWoo003<Ool00`00Oomoo`08Ool00`00Oomoo`3FOol00<aoo`03001oogoo00Qoo`<00=Io
o`00c7oo00<007ooOol027oo00<007ooOol0eWoo003<Ool00`00Oomoo`08Ool00`00Oomoo`3FOol0
0<eoo`03001oogoo00Moo`03001oogoo0=Ioo`00cGoo00<007ooOol01goo00<007ooOol0eWoo003=
Ool00`00Oomoo`07Ool00`00Oomoo`3FOol00<eoo`03001oogoo00Moo`03001oogoo0=Ioo`00cGoo
00<007ooOol01goo00<007ooOol0eWoo002jOol20007Ool30005Ool40008Ool00`00Oomoo`3FOol0
0;Uoo`04001oogoo0006Ool30004Ool01000Oomoogoo0P001goo00<007ooOol0eWoo002hOol00`00
Oomoo`02Ool00`00Oomoo`03Ool30008Ool20007Ool00`00Oomoo`3FOol00:moo`L0009oo`03001o
ogoo009oo`03001oogoo00ioo`8000Moo`@00=Eoo`00^7oo00<007ooOol00Woo00<007ooOol02Woo
00@007ooOomoo`8000Moo`03001oogoo0=Ioo`00^7oo00<007ooOol00Woo00<007ooOol02Woo1P00
1goo00<007ooOol0eWoo002hOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool00`00Oomoo`3FOol00;Uoo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`3FOol00;Yoo`8000ioo`H000Moo`03001oogoo0=Ioo`00cgoo00<007ooOol01Goo
00<007ooOol0eWoo003?Ool00`00Oomoo`05Ool00`00Oomoo`3FOol00=1oo`03001oogoo00Aoo`03
001oogoo0=Ioo`00d7oo00<007ooOol017oo00<007ooOol0eWoo003@Ool00`00Oomoo`04Ool00`00
Oomoo`3FOol00=1oo`03001oogoo00Aoo`<00=Ioo`00d7oo00<007ooOol017oo00<007ooOol0eWoo
003@Ool00`00Oomoo`04Ool00`00Oomoo`3FOol00=5oo`03001oogoo00=oo`03001oogoo0=Ioo`00
dGoo00<007ooOol00goo00<007ooOol0eWoo003AOol00`00Oomoo`03Ool00`00Oomoo`3FOol00=5o
o`03001oogoo00=oo`03001oogoo0=Ioo`00dGoo00<007ooOol00goo00<007ooOol0eWoo003AOol0
0`00Oomoo`03Ool00`00Oomoo`3FOol00=9oo`03001oogoo009oo`03001oogoo0=Ioo`00dWoo00<0
07ooOol00Woo0`00eWoo003BOol00`00Oomoo`02Ool00`00Oomoo`3FOol00=9oo`03001oogoo009o
o`03001oogoo0=Ioo`00dWoo00<007ooOol00Woo00<007ooOol0eWoo003BOol00`00Oomoo`02Ool0
0`00Oomoo`3FOol00==oo`05001oogooOol0003HOol00==oo`05001oogooOol0003HOol00==oo`05
001oogooOol0003HOol00==oo`05001oogooOol0003HOol00==oo`05001oogooOol0003HOol00==o
o`05001oogooOol0003HOol00=Aoo`03001oogoo00<00=Ioo`00e7oo00@007ooOol00=Qoo`00e7oo
00@007ooOol00=Qoo`00e7oo00@007ooOol00=Qoo`00e7oo00@007ooOol00=Qoo`00e7oo00@007oo
Ool00=Qoo`0037oo1000?goo1P00@7oo1@00>goo00<007oo0000@Goo1@00?Woo1P00?goo10002goo
000;Ool00`00Oomoo`02Ool00`00Oomoo`0mOol01@00Oomoogoo0000@Woo00<007ooOol0>goo00<0
07oo0000@goo00<007ooOol0?goo00D007ooOomoo`0003ioo`03001oogoo009oo`03001oogoo00Qo
o`0047oo00<007ooOol0?Woo00<007ooOol0@goo00<007ooOol0>goo00<007oo0000@goo00<007oo
Ool0@7oo00<007ooOol0A7oo00<007ooOol027oo0002Ool70007Ool00`00Oomoo`0cOol70005Ool0
0`00Oomoo`0fOol70005Ool00`00Oomoo`0kOol00`00Ool00013Ool00`00Oomoo`11Ool00`00Oomo
o`13Ool00`00Oomoo`08Ool000eoo`<004=oo`03001oogoo045oo`03001oogoo03]oo`03001oo`00
04=oo`03001oogoo049oo`03001oogoo03moo`<000]oo`0047oo00<007ooOol0@Goo00<007ooOol0
@7oo00<007ooOol0>goo00<007oo00000P00@Goo00<007ooOol0@goo00<007ooOol0@Goo00<007oo
Ool027oo000@Ool00`00Oomoo`11Ool00`00Oomoo`10Ool00`00Oomoo`0lOol20013Ool00`00Oomo
o`13Ool00`00Oomoo`11Ool00`00Oomoo`08Ool000]oo`03001oogoo009oo`03001oogoo03aoo`03
001oogoo009oo`03001oogoo03ioo`<003ioo`80045oo`<0041oo`03001oogoo009oo`03001oogoo
03aoo`03001oogoo009oo`03001oogoo00Qoo`0037oo1000@7oo1000@Woo0P00?Woo0P00@Woo0P00
@Goo1000@7oo10002goo003FOol2003HOol00=Ioo`800=Qoo`00eWoo0P00f7oo003GOol00`00Oomo
o`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00?l0
0;00005oo`002Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo
00<007ooOol02goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol02goo00<007ooOol02Woo
00<007ooOol02goo00<007ooOol02Goo000:Ool00`00Oomoo`11Ool00`00Oomoo`12Ool00`00Oomo
o`11Ool20012Ool00`00Oomoo`12Ool00`00Oomoo`11Ool00`00Oomoo`09Ool00=Moo`800=Moo`00
egoo0P00egoo003GOol2003GOol00=Moo`800=Moo`00egoo0P00egoo003GOol00`00Ool0003FOol0
0=Moo`03001oo`000=Ioo`00egoo0`00eWoo003GOol00`00Ool0003FOol00=Moo`03001oo`000=Io
o`00egoo00<007oo0000eWoo003GOol01000Oomoo`00eGoo003GOol01000Oomoo`00eGoo003GOol0
1000Oomoo`00eGoo003GOol01000Oomoo`00eGoo003GOol01000Oomoo`00eGoo003GOol01000Oomo
o`00eGoo003GOol01@00Oomoogoo0000e7oo003GOol300000goo001oo`3COol00=Moo`05001oogoo
Ool0003DOol00=Moo`05001oogooOol0003DOol00=Moo`05001oogooOol0003DOol00=Moo`05001o
ogooOol0003DOol00=Moo`03001oogoo009oo`03001oogoo0=5oo`00egoo00<007ooOol00Woo00<0
07ooOol0dGoo003GOol00`00Oomoo`02Ool00`00Oomoo`3AOol00=Moo`03001oogoo009oo`03001o
ogoo0=5oo`00egoo00<007ooOol00Woo00<007ooOol0dGoo003GOol00`00Oomoo`02Ool00`00Oomo
o`3AOol00=Moo`<000=oo`03001oogoo0=1oo`00egoo00<007ooOol00goo00<007ooOol0d7oo003G
Ool00`00Oomoo`03Ool00`00Oomoo`3@Ool00=Moo`03001oogoo00=oo`03001oogoo0=1oo`00egoo
00<007ooOol00goo00<007ooOol0d7oo003GOol00`00Oomoo`03Ool00`00Oomoo`3@Ool00=Moo`03
001oogoo00Aoo`03001oogoo0<moo`00egoo00<007ooOol017oo00<007ooOol0cgoo003GOol00`00
Oomoo`04Ool00`00Oomoo`3?Ool00=Moo`03001oogoo00Aoo`03001oogoo0<moo`00egoo00<007oo
Ool017oo00<007ooOol0cgoo003GOol30004Ool00`00Oomoo`3?Ool00=Moo`03001oogoo00Eoo`03
001oogoo0<ioo`00egoo00<007ooOol01Goo00<007ooOol0cWoo003GOol00`00Oomoo`05Ool00`00
Oomoo`3>Ool00=Moo`03001oogoo00Eoo`03001oogoo0<ioo`00egoo00<007ooOol01Goo00<007oo
Ool0cWoo003GOol00`00Oomoo`05Ool00`00Oomoo`3>Ool00=Moo`03001oogoo00Ioo`03001oogoo
0<eoo`00^Woo0P001goo0`001Goo100027oo00<007ooOol01Woo00<007ooOol0cGoo002iOol01000
Oomoo`001Woo0`0017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Woo00<007ooOol0
cGoo002hOol00`00Oomoo`02Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`05Ool40005Ool00`00
Oomoo`3=Ool00;Qoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00Io
o`03001oogoo0<eoo`00^7oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol01Woo00<007ooOol0cGoo002hOol00`00Oomoo`02Ool00`00Oomoo`0:Ool5
0008Ool00`00Oomoo`07Ool00`00Oomoo`3<Ool00;Qoo`03001oogoo009oo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Moo`03001oogoo0<aoo`00^Goo00@007ooOol000eoo`03001oogoo
00Yoo`03001oogoo00Moo`03001oogoo0<aoo`00^Woo0P003Woo1@0027oo00<007ooOol01goo00<0
07ooOol0c7oo003GOol00`00Oomoo`07Ool00`00Oomoo`3<Ool00=Moo`03001oogoo00Qoo`03001o
ogoo0<]oo`00egoo00<007ooOol027oo00<007ooOol0bgoo003GOol00`00Oomoo`08Ool00`00Oomo
o`3;Ool00=Moo`<000Qoo`03001oogoo0<]oo`00egoo00<007ooOol027oo00<007ooOol0bgoo003G
Ool00`00Oomoo`09Ool00`00Oomoo`3:Ool00=Moo`03001oogoo00Uoo`03001oogoo0<Yoo`00egoo
00<007ooOol02Goo00<007ooOol0bWoo003GOol00`00Oomoo`09Ool00`00Oomoo`3:Ool00=Moo`03
001oogoo00Uoo`03001oogoo0<Yoo`00egoo00<007ooOol02Woo00<007ooOol0bGoo003GOol00`00
Oomoo`0:Ool00`00Oomoo`39Ool00=Moo`03001oogoo00Yoo`03001oogoo0<Uoo`00egoo00<007oo
Ool02Woo00<007ooOol0bGoo003GOol3000:Ool00`00Oomoo`39Ool00=Moo`03001oogoo00]oo`03
001oogoo0<Qoo`00egoo00<007ooOol02goo00<007ooOol0b7oo003GOol00`00Oomoo`0;Ool00`00
Oomoo`38Ool00=Moo`03001oogoo00]oo`03001oogoo0<Qoo`00egoo00<007ooOol02goo00<007oo
Ool0b7oo003GOol00`00Oomoo`0<Ool00`00Oomoo`37Ool00=Moo`03001oogoo00aoo`03001oogoo
0<Moo`00egoo00<007ooOol037oo00<007ooOol0agoo003GOol00`00Oomoo`0<Ool00`00Oomoo`37
Ool00=Moo`<000aoo`03001oogoo0<Moo`00egoo00<007ooOol03Goo00<007ooOol0aWoo003GOol0
0`00Oomoo`0=Ool00`00Oomoo`36Ool00=Moo`03001oogoo00eoo`03001oogoo0<Ioo`00egoo00<0
07ooOol03Goo00<007ooOol0aWoo003GOol00`00Oomoo`0=Ool00`00Oomoo`36Ool00=Moo`03001o
ogoo00ioo`03001oogoo0<Eoo`00egoo00<007ooOol03Woo00<007ooOol0aGoo003GOol00`00Oomo
o`0>Ool00`00Oomoo`35Ool00=Moo`03001oogoo00ioo`03001oogoo0<Eoo`00egoo00<007ooOol0
3Woo00<007ooOol0aGoo003GOol3000?Ool00`00Oomoo`34Ool00=Moo`03001oogoo00moo`03001o
ogoo02]oo`T0091oo`00egoo00<007ooOol03goo00<007ooOol0:Goo0P002Goo0`00SGoo003GOol0
0`00Oomoo`0?Ool00`00Oomoo`0WOol2000>Ool2002;Ool00=Moo`03001oogoo011oo`03001oogoo
02Eoo`03001oogoo011oo`8008Uoo`00egoo00<007ooOol047oo00<007ooOol097oo00<007ooOol0
4goo00<007ooOol0QWoo003GOol00`00Oomoo`0@Ool00`00Oomoo`0TOol00`00Oomoo`0DOol00`00
Oomoo`0_Ool<001:Ool00=Moo`03001oogoo015oo`03001oogoo029oo`03001oogoo01Ioo`8002]o
o`@000aoo`@003Moo`@000]oo`00bgoo1@001goo00<007ooOol04Goo00<007ooOol08Goo00<007oo
Ool06Goo00<007ooOol09Woo0P0057oo0`00;goo1P003Woo003=Ool00`00Oomoo`07Ool00`00Oomo
o`0AOol00`00Oomoo`0POol00`00Oomoo`0KOol00`00Oomoo`0SOol2000IOol2000ZOol3000DOol0
0<eoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo01moo`03001oogoo01eoo`03001oogoo
021oo`8001eoo`<002Aoo`<001Moo`00cGoo00<007ooOol01goo10004Goo00<007ooOol07Goo00<0
07ooOol07goo0P007Woo0P008Woo0P007goo0`006Woo003=Ool00`00Oomoo`07Ool00`00Oomoo`0B
Ool00`00Oomoo`0LOol00`00Oomoo`0ROol00`00Oomoo`0IOol2000VOol2000JOol3000MOol00<eo
o`03001oogoo00Moo`03001oogoo019oo`03001oogoo01]oo`03001oogoo02Aoo`03001oogoo01Mo
o`03001oogoo02Qoo`8001Aoo`@0021oo`00cGoo00<007ooOol01goo00<007ooOol04goo00<007oo
Ool06Woo00<007ooOol09Goo00<007ooOol057oo0P00;Goo10003Goo0`0097oo003;Ool30009Ool0
0`00Oomoo`0COol00`00Oomoo`0IOol00`00Oomoo`0WOol00`00Oomoo`0AOol2000cOol=000WOol0
0<aoo`8000Uoo`03001oogoo01=oo`03001oogoo01Qoo`03001oogoo02Uoo`8000moo`8006Uoo`00
egoo00<007ooOol057oo00<007ooOol05Woo00<007ooOol0;7oo10002Goo0P00Jgoo003GOol00`00
Oomoo`0DOol00`00Oomoo`0FOol00`00Oomoo`0`Ool9001]Ool00=Moo`03001oogoo01Eoo`03001o
ogoo01Aoo`03001oogoo0:Moo`00egoo00<007ooOol05Goo00<007ooOol04goo00<007ooOol0Z7oo
003GOol00`00Oomoo`0FOol00`00Oomoo`0BOol00`00Oomoo`2XOol00=Moo`<001Ioo`03001oogoo
015oo`03001oogoo0:Uoo`00egoo00<007ooOol05goo00<007ooOol03goo00<007ooOol0ZWoo003G
Ool00`00Oomoo`0GOol00`00Oomoo`0>Ool00`00Oomoo`2[Ool00=Moo`03001oogoo01Qoo`03001o
ogoo00aoo`03001oogoo0:aoo`00egoo00<007ooOol067oo00<007ooOol02goo00<007ooOol0[Goo
003GOol00`00Oomoo`0IOol00`00Oomoo`09Ool00`00Oomoo`2^Ool00=Moo`03001oogoo01Yoo`80
00Qoo`03001oogoo0:moo`00egoo00<007ooOol077oo00<007ooOol00goo0P00/Woo003GOol00`00
Oomoo`0MOol6002cOol00=Moo`03001oogoo0=Ioo`00egoo0`00eWoo003GOol00`00Oomoo`3FOol0
0=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.812, 0}} -> {-3, -1, 0, 0}}]
}, Open  ]],

Cell["\<\
The largest error in the function occurs at the first extremum (see \
Cell 2.20).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[f\_approx[\[Tau]], \[Tau]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.20"],

Cell[BoxData[
    \(\(2\ Sin[2\ \[Pi]\ \[Tau]]\)\/\(\[Pi]\ \[Tau]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This derivative vanishes at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = n/2, \ n \[NotEqual] 0\)]],
  ". The plot of  ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  " shows that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 1/2\)]],
  " is the location of the first extremum. The maximum value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  " is  therefore"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\_approx[1/2]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.21"],

Cell[BoxData[
    \(\(2\ SinIntegral[\[Pi]]\)\/\[Pi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // N\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.22"],

Cell[BoxData[
    \(1.1789797444721675`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Thus, the maximum  overshoot of the oscillation above 1 is 0.17898.... The \
next maximum in ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  "occurs at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau] = 3/2\)]],
  ", with an overshoot above 1 of  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\_approx[3/2]\  - 1\  // N\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.23"],

Cell[BoxData[
    \(0.06618647523654397`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tIf we return to regular time units and plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(f\_approx\),
            "TraditionalForm"]}], TraditionalForm]]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " for different values of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", we can reproduce the  manner in which the oscillations crowd toward the \
origin as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M\)\(\ \)\)\)]],
  " increases - see Cell ",
  ButtonBox["2.24",
    ButtonData:>"Cell 2.24",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = 1; 
    Table[Plot[f\_approx[M\ t], {t, \(-1\), 1}, 
        PlotRange \[Rule] {\(-1.5\), 1.5}, 
        PlotLabel \[Rule] "\<M = \>" <> ToString[M]], {M, 4, 20, 
        4}];\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.24"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10821 m
.02499 .1082 L
.02605 .10817 L
.02729 .10812 L
.02846 .10805 L
.03053 .10788 L
.03279 .10763 L
.03527 .10727 L
.0379 .1068 L
.04262 .10578 L
.06244 .10023 L
.06743 .099 L
.07018 .09842 L
.0728 .09795 L
.07522 .0976 L
.0765 .09745 L
.07786 .09731 L
.07912 .09721 L
.08026 .09714 L
.08141 .0971 L
.0825 .09707 L
.08378 .09707 L
.0845 .09708 L
.08518 .09709 L
.0859 .09712 L
.08655 .09715 L
.08802 .09725 L
.08927 .09736 L
.09063 .09751 L
.0931 .09785 L
.09599 .09838 L
.09906 .09906 L
.10458 .10056 L
.11417 .10368 L
.12427 .10694 L
.12844 .10806 L
.1329 .109 L
.13546 .10941 L
.13778 .10968 L
.13891 .10978 L
.14012 .10985 L
.14127 .1099 L
.14233 .10992 L
.14344 .10992 L
.14464 .10989 L
.14577 .10984 L
.14681 .10977 L
.14801 .10967 L
.14933 .10952 L
.15173 .10916 L
Mistroke
.15423 .10868 L
.15689 .10805 L
.16168 .10665 L
.18253 .09872 L
.18755 .09707 L
.19285 .09573 L
.19562 .09524 L
.19719 .09503 L
.19794 .09495 L
.19865 .09488 L
.1993 .09483 L
.2 .09479 L
.20123 .09474 L
.20192 .09472 L
.20266 .09472 L
.20329 .09473 L
.20399 .09475 L
.20526 .09482 L
.2059 .09487 L
.2066 .09493 L
.209 .09523 L
.21036 .09546 L
.2118 .09575 L
.2144 .09639 L
.21952 .09804 L
.22417 .09991 L
.2343 .1047 L
.23984 .10736 L
.24501 .10961 L
.24979 .11132 L
.25188 .11193 L
.25416 .11248 L
.25545 .11273 L
.25664 .11292 L
.25786 .11308 L
.259 .1132 L
.2602 .11328 L
.26084 .1133 L
.26152 .11332 L
.2622 .11332 L
.26292 .1133 L
.2642 .11324 L
.26544 .11314 L
.26661 .11299 L
.2688 .11262 L
.27116 .11206 L
.27372 .11129 L
.27834 .10946 L
.28259 .10735 L
.29299 .10114 L
Mistroke
.30272 .09522 L
.30735 .09286 L
.31175 .09109 L
.31418 .09035 L
.31546 .09004 L
.31682 .08977 L
.31808 .08958 L
.31923 .08946 L
.32038 .08939 L
.32146 .08937 L
.32266 .0894 L
.32397 .0895 L
.32463 .08957 L
.32534 .08967 L
.32662 .0899 L
.32911 .09053 L
.33137 .09132 L
.33688 .09401 L
.34209 .09748 L
.36032 .11295 L
.36532 .11684 L
.36794 .11861 L
.3707 .1202 L
.37313 .12134 L
.37441 .12184 L
.37578 .12228 L
.37705 .12259 L
.3782 .12281 L
.37935 .12295 L
.38044 .12302 L
.38158 .12301 L
.38284 .12292 L
.38416 .12272 L
.38538 .12244 L
.38653 .1221 L
.38758 .12171 L
.38994 .1206 L
.39247 .11903 L
.39522 .11689 L
.40023 .11193 L
.41126 .09727 L
.42124 .08248 L
.42613 .076 L
.4287 .07305 L
.43141 .0704 L
.43379 .06853 L
.43505 .06774 L
.43639 .06706 L
.43763 .06659 L
.43876 .0663 L
Mistroke
.4399 .06615 L
.44097 .06615 L
.44218 .06631 L
.44286 .06647 L
.44351 .06669 L
.44481 .06727 L
.4462 .06816 L
.44749 .06921 L
.44872 .07043 L
.45103 .07331 L
.45374 .07769 L
.45626 .08278 L
.46196 .09801 L
.46703 .11589 L
.47252 .13968 L
.48247 .19332 L
.50108 .31648 L
.52062 .44266 L
.52597 .47104 L
.53171 .49709 L
.53709 .51698 L
.54207 .53132 L
.54715 .5419 L
.54982 .54589 L
.55119 .54752 L
.55267 .54897 L
.55395 .54999 L
.55513 .55073 L
.55626 .55126 L
.55744 .55164 L
.55875 .55186 L
.55996 .55189 L
.56066 .55183 L
.56129 .55172 L
.56202 .55155 L
.56271 .55133 L
.5638 .55089 L
.565 .55027 L
.56741 .54862 L
.57175 .5445 L
.58154 .53152 L
.59151 .51673 L
.60098 .50479 L
.6062 .49998 L
.60916 .49795 L
.61057 .49717 L
.6119 .49654 L
.61311 .49606 L
.61443 .49564 L
.61563 .49535 L
Mistroke
.61673 .49517 L
.61792 .49505 L
.61923 .49501 L
.61989 .49503 L
.6206 .49508 L
.62187 .49524 L
.62309 .49547 L
.62444 .49582 L
.62717 .49682 L
.6297 .49804 L
.63207 .49943 L
.64314 .50805 L
.65276 .51648 L
.65821 .52078 L
.66327 .52411 L
.66804 .52648 L
.6707 .52745 L
.67312 .52808 L
.67446 .52833 L
.67568 .5285 L
.67633 .52857 L
.67703 .52862 L
.67777 .52865 L
.67846 .52866 L
.67972 .52864 L
.68088 .52856 L
.68152 .5285 L
.68222 .52841 L
.68349 .52821 L
.6857 .52772 L
.68814 .52698 L
.6931 .52497 L
.702 .52004 L
.7114 .51416 L
.72131 .50874 L
.7265 .50667 L
.72944 .50581 L
.73085 .50548 L
.73218 .50523 L
.73339 .50504 L
.73471 .50488 L
.7359 .50479 L
.737 .50473 L
.73819 .50472 L
.73951 .50474 L
.74017 .50478 L
.74088 .50483 L
.74216 .50495 L
.74349 .50513 L
.7447 .50533 L
Mistroke
.7474 .50592 L
.75227 .5074 L
.7633 .51216 L
.77376 .5172 L
.77835 .51918 L
.78339 .52099 L
.78573 .52168 L
.78823 .52229 L
.7906 .52274 L
.79275 .52304 L
.79402 .52316 L
.79519 .52324 L
.79647 .5233 L
.79712 .52331 L
.79783 .52331 L
.79903 .52329 L
.80031 .52323 L
.80153 .52314 L
.80264 .52302 L
.80515 .52267 L
.80749 .52223 L
.81279 .52086 L
.82346 .51703 L
.83399 .51289 L
.83916 .51111 L
.84393 .50977 L
.84826 .50887 L
.85045 .50854 L
.85168 .5084 L
.85285 .50829 L
.85411 .5082 L
.85526 .50814 L
.85649 .50811 L
.8572 .50811 L
.85784 .50811 L
.85903 .50814 L
.86011 .50819 L
.86135 .50828 L
.86252 .50838 L
.86494 .50868 L
.86719 .50905 L
.87231 .51016 L
.88264 .51328 L
.8915 .51625 L
.90113 .51902 L
.90377 .51961 L
.90658 .52013 L
.90897 .52048 L
.91035 .52064 L
.91161 .52076 L
Mistroke
.91287 .52085 L
.91408 .52091 L
.91534 .52095 L
.91606 .52096 L
.91673 .52097 L
.91795 .52095 L
.91905 .52092 L
.92032 .52086 L
.92153 .52077 L
.92378 .52056 L
.92617 .52024 L
.93044 .51949 L
.9401 .5171 L
.97619 .50983 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002N0?ooo`@000004@3oool0
0`000000oooo0?ooo`2b0?ooo`00W@3oool2000000<0oooo0P00000?0?ooo`030000003oool0oooo
0;80oooo002L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool03@3oool00`000000
oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00d0oooo
00<000000?ooo`3oool0/P3oool009/0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo0;80oooo002J0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool02`3oool200000;<0oooo002J0?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`2b0?ooo`00N03oool5000001`0oooo00<000000?ooo`3o
ool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0;80oooo001e0?ooo`@00000
103oool2000001T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0:0?ooo`030000
003oool0oooo0;80oooo001A0?ooo`T000006@3oool2000000X0oooo0P00000G0?ooo`030000003o
ool0oooo00/0oooo00<000000?ooo`3oool0100000000`0A4A40oooo0?ooo`030?ooo`030000003o
ool0oooo0;80oooo000Y0?ooo``00000603oool4000000T0oooo00<000000?ooo`3oool05@3oool0
0`000000oooo0?ooo`0<0?ooo`800000503oool00`000000oooo0?ooo`0=0?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`2b0?ooo`009@3oool4000000`0oooo0`00000B
0?ooo`<000003P3oool300000180oooo0P00000A0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool01`3oool6000000030?ooo`000000oooo0080oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`2b0?ooo`008@3oool4000001<0oooo0`00000=0?ooo`800000503oool20000
00l0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0100oooo00@000000?ooo`3oool000001`3oool300000;80oooo000K0?ooo`H000006P3oool30000
00L0oooo0`00000H0?ooo`8000002`3oool2000001H0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0A0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0/P3oool0
03h0oooo1`00000M0?ooo`<000001@3oool3000001T0oooo00<000000?ooo`3oool02P3oool00`00
0000oooo0?ooo`0B0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0/P3oool0
06D0oooo1@00000M0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo000000070?ooo`030000003oool0oooo0;80oooo00280?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0503oool00`000000EEEE000000070?ooo`030000003oool0oooo0;80
oooo00290?ooo`<00000103oool2000001L0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`2b0?ooo`00R`3oool5000001T0oooo00<000000?ooo`3oool01`3oool200000;<0oooo002Y
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0/P3oool00:X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`2b0?ooo`00ZP3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo0;80oooo002Z0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
/P3oool00:X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2b0?ooo`00ZP3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0;80oooo002Z0?ooo`030000003oool0oooo
00H0oooo0P00002c0?ooo`00ZP3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0;80
oooo002[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0/P3oool00:/0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`2b0?ooo`00Z`3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0;80oooo002[0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool0/P3oool00:/0oooo00<000000?ooo`3oool01@3oool200000;<0oooo002/0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0/P3oool00:`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`2b0?ooo`00[03oool00`000000oooo0?ooo`040?ooo`030000003oool0
oooo0;80oooo002/0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0/P3oool00:`0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2b0?ooo`00[03oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0;80oooo002]0?ooo`030000003oool0oooo00<0oooo0P00
002c0?ooo`00[@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo002]0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/P3oool00:d0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`2b0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R850?ooo`0504A4A0000000000003<c<`0000001@3oool00`000000oooo0?ooo`2b0?oo
o`00V03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`000000oooo
00@0oooo00<000000?ooo`3oool0/P3oool00900oooo1P0000020?ooo`05014A4@3oool0oooo0?oo
o`0A4A40403oool2000000@0oooo0`00002b0?ooo`00V03oool01@000000oooo0?ooo`3oool00000
00l0oooo00<0MgMg03<c<`000000103oool00`000000oooo0?ooo`2b0?ooo`00V03oool01@000000
oooo0?ooo`3oool0000000`0oooo00H00000028R8P000000<c<c0<c<c00000040?ooo`030000003o
ool0oooo0;80oooo002H0?ooo`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0/P3oool009P0oooo00D0MgMg
09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`2b0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo1000
00000`3oool000000?ooo`030?ooo`030000003oool0oooo0;80oooo002^0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0/P3oool00:l0oooo00@000000?ooo`3oool0oooo0P00002c
0?ooo`00[`3oool01@000000oooo0?ooo`3oool000000;@0oooo002_0?ooo`050000003oool0oooo
0?ooo`000000]03oool00:l0oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00[`3oool01@00
0000oooo0?ooo`3oool000000;@0oooo002_0?ooo`050000003oool0oooo0?ooo`000000]03oool0
0:l0oooo00@000000?ooo`3oool0oooo0P00002c0?ooo`00/03oool010000000oooo0?ooo`00002d
0?ooo`00/03oool010000000oooo0?ooo`00002d0?ooo`00/03oool010000000oooo0?ooo`00002d
0?ooo`00/03oool010000000oooo0?ooo`00002d0?ooo`00/03oool010000000oooo0?ooo`00002d
0?ooo`00/03oool010000000oooo0?ooo`00002d0?ooo`007@3oool400000003014A4@3oool0oooo
03`0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c
<c<0gMgM03/0oooo00@000000?ooo`0000000000?`3oool01@3^k^h0<c<c0000000c<c<0k^k^00D0
oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0?`3oool400000003014A4@3oool0oooo
01P0oooo000O0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R203oool00`1gMgL0<c<c0?ooo`0j0?ooo`030000003oool000000400oooo00D0MgMg09VI
V@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`100?ooo`030000003oool0
oooo01X0oooo000D0?ooo`H000001@3oool00`000000oooo0?ooo`0f0?ooo`H000000P3oool01@0A
4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool0>@3oool00`000000oooo00000010
0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`0o0?ooo`030000003o
ool0oooo01X0oooo000O0?ooo`030000003oool0oooo03h0oooo00D000000?ooo`3oool0oooo0000
000?0?ooo`0307MgM`0c<c<0oooo03X0oooo00<000000?ooo`000000@03oool01@000000oooo0?oo
o`3oool0000000l0oooo00<0MgMg03<c<`3oool0@03oool00`000000oooo0?ooo`0J0?ooo`007`3o
ool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R
0000000c<c<0c<c<03/0oooo00<000000?ooo`000000@03oool01@000000oooo0?ooo`3oool00000
00`0oooo00D00000028R8P000000<c<c0<c<c0110?ooo`030000003oool0oooo01X0oooo000O0?oo
o`030000003oool0oooo03h0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0
oooo03d0oooo00<000000?ooo`000000@03oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0J0?ooo`007`3oool00`000000oooo0?ooo`0n
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`0m0?ooo`030000003o
ool000000400oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool06P3oool001d0oooo0P1EEED00`000000oooo0?ooo`0n0?ooo`050>k^kP0c
<c<0000003<c<`3^k^h0303oool4000003d0oooo0`00000o0?ooo`050>k^kP0c<c<0000003<c<`3^
k^h0303oool400000400oooo0P1EEED00`000000oooo0?ooo`0J0?ooo`00/P3oool200000;@0oooo
002b0?ooo`800000]03oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`80
0000]03oool001@0ooooo`000010000001D0oooo000K0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`006`3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`19
0?ooo`030000003oool0oooo01X0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0
oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?oo
o`<00000/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00<000000?ooo`000000
/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00<000000?ooo`000000/P3oool0
0;<0oooo00@000000?ooo`3oool00000/@3oool00;<0oooo00@000000?ooo`3oool00000/@3oool0
0;<0oooo0P0000000`3oool000000?ooo`2`0?ooo`00/`3oool010000000oooo0?ooo`00002a0?oo
o`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool010000000oooo0?ooo`00002a0?oo
o`00/`3oool01@000000oooo0?ooo`3oool000000;00oooo002c0?ooo`050000003oool0oooo0?oo
o`000000/03oool00;<0oooo0P0000020?ooo`030000003oool0oooo0:h0oooo002c0?ooo`050000
003oool0oooo0?ooo`000000/03oool00;<0oooo00D000000?ooo`3oool0oooo0000002`0?ooo`00
/`3oool01@000000oooo0?ooo`3oool000000;00oooo002H0?ooo`050>k^kP0c<c<0000003<c<`3^
k^h01@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0[@3oool009P0oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?oo
o`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0[@3oool009P0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2]0?ooo`00V03oool01@000000
oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0103oool300000080oooo00<000000?oo
o`3oool0[@3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000000R8R800000
03<c<`3<c<`01@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:d0oooo002H0?oo
o`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0[03oool009P0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2/
0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo100000060?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool0[03oool00;<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`2/0?ooo`00/`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0:`0
oooo002c0?ooo`800000103oool00`000000oooo0?ooo`2/0?ooo`00/`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0:/0oooo002c0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0Z`3oool00;<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2[0?oo
o`00/`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0:/0oooo002c0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0Z`3oool00;<0oooo0P0000050?ooo`030000003o
ool0oooo0:/0oooo002c0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Z`3oool0
0;<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`2Z0?ooo`00/`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0:X0oooo002c0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`3oool0ZP3oool00;<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`2Z0?ooo`00/`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0:X0oooo002c0?oo
o`8000001P3oool00`000000oooo0?ooo`2Z0?ooo`00/`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo0:X0oooo002c0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
Z@3oool00;<0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`2Y0?ooo`00/`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0:T0oooo002c0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0Z@3oool00;<0oooo0P0000080?ooo`030000003oool0oooo01P0
oooo0`00002=0?ooo`00/`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01H0oooo
0P0000020?ooo`<00000R`3oool00;<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0D0?ooo`8000001`3oool2000008T0oooo002c0?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01`0oooo0`00001W
0?ooo`00Z@3oool400000003014A4@3oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool05`3oool50000
00030?ooo`000000000000<00000H`3oool00:/0oooo00<000000?ooo`3oool01@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool2000001D0
oooo0P00000;0?ooo`8000005`3oool?000001/0oooo1000000L0?ooo`00Z`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo00l0oooo0`00000?0?ooo`<000004P3oool2000000l0oooo
0`00000B0?ooo`H00000803oool00:/0oooo00<000000?ooo`3oool01@3oool3000000T0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00d0oooo00<0
00000?ooo`3oool04`3oool2000000d0oooo0`00000D0?ooo`<000002`3oool4000002H0oooo002[
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool2000001P0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0H0?ooo`<00000103oool4000002X0oooo002[0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo01<0oooo0P00000:0?ooo`030000003oool0oooo01T0oooo2`00000N0?oo
o`@00000;P3oool00:/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool05P3oool2000000L0oooo00<000000?ooo`3o
ool0M@3oool00:T0oooo0P1EEED00`000000oooo0?ooo`050?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0H0?ooo`L00000N03oool00;<0oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09P0oooo002c
0?ooo`8000002`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo09P0oooo002c0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`2I0?oo
o`00/`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool0VP3oool00;<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`040?ooo`800000
W@3oool00;<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo09d0oooo002c0?ooo`030000003oool0oooo00h0oooo1@00002O0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000
/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo0P0R
8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?ooo`2b0?ooo`00V`3o
ool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003o
ool0oooo0;80oooo002K0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool00`3oool0
0`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`0>0?ooo`0307MgM`0c<c<0oooo
00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`050000000R8R80000003<c
<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`2l0?ooo`00
V`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo002I0?ooo`80EEEE00<0
00000?ooo`3oool02`3oool400000;/0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0
oooo002P0?ooo`80000000H04A4A0?ooo`3oool04A4A0000000A4A4I0?ooo`80000000<04A4A0?oo
o`3oool0XP3oool00:40oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`070?ooo`H0
0000303oool00`000000oooo0?ooo`2S0?ooo`00X@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo01H0oooo1@00002T0?ooo`00X@3oool01P000000oooo04A4A00c<c<0oooo000000T0
oooo1P0000090?ooo`0404A4A03MgMd0oooo00000:D0oooo002Q0?ooo`060000003MgMd0<c<c05EE
E@3MgMd00000603oool0103MgMd0EEEE0?ooo`00002U0?ooo`00X@3oool01P000000R8R80:ZZZP2k
^k/0EEEE000001T0oooo00<0MgMg0<c<c0000000Y@3oool00:40oooo00H0000003<c<`3oool0oooo
03<c<`00000I0?ooo`030>k^kP14A4@000000:D0oooo002P0?ooo`03014A4@000000R8R80080oooo
00<0R8R80000000A4A406@3oool00`1gMgL000000?ooo`2T0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10561 m
.02499 .10559 L
.02605 .10554 L
.02729 .10544 L
.02846 .1053 L
.03053 .10498 L
.03279 .10451 L
.04262 .10186 L
.0452 .10123 L
.04762 .10075 L
.04884 .10056 L
.05015 .1004 L
.05089 .10034 L
.0516 .10029 L
.05223 .10025 L
.05293 .10023 L
.05418 .10023 L
.05532 .10027 L
.05663 .10037 L
.05786 .10051 L
.05901 .10067 L
.06006 .10086 L
.06244 .10137 L
.06756 .1028 L
.07304 .10442 L
.0757 .10508 L
.07701 .10535 L
.07822 .10556 L
.07929 .10572 L
.08048 .10585 L
.08167 .10594 L
.08293 .10598 L
.08358 .10598 L
.08427 .10597 L
.0855 .10591 L
.08681 .10578 L
.08756 .10569 L
.08826 .10559 L
.09067 .10512 L
.09325 .10447 L
.09915 .10263 L
.10173 .10181 L
.10458 .10099 L
.10582 .10069 L
.10715 .1004 L
.1083 .1002 L
.10955 .10002 L
.11029 .09994 L
.11097 .09988 L
.11162 .09984 L
Mistroke
.11231 .09981 L
.11363 .0998 L
.11482 .09985 L
.11552 .0999 L
.11626 .09998 L
.11757 .10015 L
.11899 .10041 L
.12054 .10075 L
.12593 .10238 L
.13096 .10413 L
.13373 .10501 L
.13635 .1057 L
.13754 .10595 L
.13879 .10617 L
.13945 .10626 L
.14017 .10634 L
.14144 .10644 L
.1426 .10648 L
.14384 .10646 L
.14501 .10639 L
.14608 .10628 L
.15603 .10356 L
.16149 .1015 L
.16417 .1006 L
.16664 .09994 L
.16785 .09968 L
.16898 .09949 L
.17016 .09934 L
.17145 .09925 L
.17277 .09922 L
.17397 .09926 L
.17463 .0993 L
.17535 .09937 L
.17666 .09956 L
.17775 .09977 L
.17895 .10004 L
.18138 .10076 L
.18575 .1024 L
.19036 .10431 L
.19288 .10528 L
.19522 .10605 L
.19655 .10642 L
.19776 .10669 L
.1991 .10693 L
.19984 .10702 L
.20054 .10709 L
.20176 .10716 L
.20289 .10717 L
.20412 .1071 L
.20543 .10696 L
Mistroke
.20657 .10677 L
.20762 .10654 L
.20997 .10588 L
.21423 .10424 L
.21931 .10191 L
.22391 .09999 L
.2251 .09958 L
.22637 .0992 L
.22748 .09892 L
.22869 .09868 L
.22997 .0985 L
.23068 .09843 L
.23133 .0984 L
.23251 .09838 L
.23377 .09845 L
.23495 .09858 L
.23623 .09881 L
.23744 .09909 L
.23855 .09942 L
.24291 .10114 L
.24806 .10373 L
.25076 .10509 L
.25361 .10637 L
.25611 .10728 L
.25753 .10767 L
.25884 .10794 L
.26006 .10811 L
.26117 .10819 L
.26244 .1082 L
.26364 .10812 L
.26472 .10798 L
.26591 .10774 L
.26715 .10742 L
.26831 .10704 L
.27261 .10513 L
.27759 .1023 L
.28232 .09966 L
.28481 .09853 L
.28612 .09804 L
.28752 .09762 L
.28881 .09733 L
.28998 .09716 L
.29115 .09707 L
.29226 .09708 L
.29356 .09719 L
.29422 .09728 L
.29493 .09742 L
.2962 .09775 L
.29739 .09814 L
.30007 .09932 L
Mistroke
.30293 .10094 L
.30788 .10422 L
.31314 .1075 L
.31588 .10879 L
.31744 .10933 L
.31819 .10953 L
.3189 .10968 L
.31954 .10979 L
.32024 .10987 L
.32147 .10993 L
.32216 .1099 L
.3229 .10984 L
.32359 .10974 L
.32423 .10962 L
.32549 .10929 L
.32682 .10881 L
.3292 .10764 L
.33459 .10394 L
.3397 .09989 L
.34436 .09674 L
.34669 .09563 L
.34801 .09518 L
.34923 .0949 L
.35029 .09476 L
.35146 .09472 L
.35268 .09483 L
.35383 .09505 L
.35508 .09543 L
.35638 .09597 L
.35872 .09731 L
.36124 .09919 L
.36399 .10164 L
.36851 .10603 L
.3709 .10825 L
.37342 .11031 L
.37562 .11176 L
.37688 .11239 L
.37805 .11284 L
.37913 .11313 L
.38011 .11328 L
.38124 .11331 L
.38232 .11321 L
.38356 .11292 L
.38487 .11242 L
.38611 .11176 L
.38723 .11103 L
.38999 .10868 L
.39259 .10591 L
.39713 .10033 L
.40192 .09461 L
Mistroke
.40443 .09219 L
.40575 .09117 L
.40648 .0907 L
.40717 .09031 L
.40848 .08975 L
.40966 .08946 L
.41078 .08937 L
.41199 .0895 L
.4133 .08989 L
.41404 .09024 L
.41473 .09064 L
.41614 .09168 L
.41765 .09313 L
.42037 .09651 L
.42287 .10032 L
.42759 .1085 L
.43204 .11593 L
.4345 .11926 L
.4358 .12065 L
.43717 .12181 L
.43832 .1225 L
.43959 .12294 L
.44075 .12302 L
.44182 .12281 L
.44249 .12255 L
.44321 .12213 L
.44453 .12105 L
.44581 .11959 L
.447 .11789 L
.44969 .11285 L
.45256 .10594 L
.45776 .0909 L
.46004 .08415 L
.46253 .07732 L
.46473 .07225 L
.46594 .06999 L
.46709 .06827 L
.46839 .0669 L
.46957 .06624 L
.47068 .06618 L
.47188 .06679 L
.4731 .06815 L
.47378 .06928 L
.47443 .07058 L
.47573 .07393 L
.47713 .07866 L
.47966 .09031 L
.48197 .10452 L
.48645 .1415 L
.49134 .19454 L
Mistroke
.50024 .31235 L
.50511 .37862 L
.51037 .44341 L
.51535 .49283 L
.51771 .51131 L
.51992 .52539 L
.52247 .5378 L
.52382 .54272 L
.52527 .54677 L
.526 .54834 L
.52679 .54971 L
.52753 .55069 L
.52823 .55133 L
.52953 .55189 L
.53019 .55186 L
.53092 .5516 L
.53221 .55058 L
.5334 .54909 L
.5347 .54691 L
.53607 .54407 L
.54089 .53116 L
.54581 .51659 L
.55044 .50489 L
.55301 .50013 L
.55445 .4981 L
.55579 .49668 L
.55691 .49582 L
.55814 .49523 L
.55943 .49501 L
.56064 .49515 L
.56178 .49558 L
.56302 .49636 L
.56419 .49736 L
.56527 .49851 L
.5695 .50452 L
.57446 .51315 L
.57901 .52064 L
.58144 .52388 L
.58273 .5253 L
.58411 .52655 L
.58549 .52753 L
.58678 .52817 L
.58754 .52843 L
.58826 .52858 L
.58891 .52865 L
.58961 .52866 L
.5908 .52849 L
.59212 .52806 L
.59279 .52775 L
.5935 .52735 L
Mistroke
.59479 .52647 L
.59729 .52424 L
.59958 .52174 L
.60859 .51081 L
.61118 .50827 L
.61246 .50723 L
.61363 .50643 L
.61467 .50584 L
.61582 .50533 L
.61698 .50497 L
.6182 .50476 L
.61948 .50473 L
.62065 .50486 L
.6213 .505 L
.622 .50521 L
.62328 .50572 L
.62448 .50633 L
.62575 .50713 L
.62803 .50886 L
.63717 .51746 L
.63961 .51952 L
.64224 .52133 L
.64345 .52198 L
.64473 .52254 L
.64582 .52289 L
.64701 .52316 L
.64774 .52326 L
.64844 .52331 L
.64973 .52327 L
.65046 .52319 L
.65113 .52307 L
.65186 .52289 L
.65264 .52265 L
.65514 .52157 L
.65788 .5199 L
.66265 .51629 L
.66785 .51227 L
.67022 .51072 L
.67153 .50999 L
.67276 .50941 L
.67391 .50895 L
.67515 .50856 L
.67628 .50831 L
.67731 .50817 L
.67862 .50811 L
.67984 .50817 L
.68055 .50826 L
.68118 .50837 L
.68192 .50853 L
.68262 .50872 L
Mistroke
.6853 .50975 L
.68822 .51131 L
.69337 .51466 L
.6982 .51777 L
.70041 .51895 L
.70273 .51994 L
.70395 .52033 L
.70459 .5205 L
.70528 .52066 L
.70649 .52085 L
.70761 .52095 L
.70831 .52097 L
.70896 .52096 L
.70966 .52091 L
.71041 .52083 L
.71167 .52061 L
.71238 .52044 L
.71305 .52025 L
.71544 .5194 L
.71799 .51821 L
.72328 .51522 L
.72618 .51356 L
.7289 .51216 L
.73145 .51108 L
.73289 .51061 L
.73421 .51026 L
.73532 .51005 L
.73654 .5099 L
.73782 .50983 L
.73901 .50985 L
.74033 .50997 L
.74157 .51017 L
.74269 .51042 L
.74391 .51076 L
.74664 .51176 L
.74915 .5129 L
.75441 .51559 L
.7572 .51695 L
.7602 .51819 L
.76155 .51865 L
.76284 .51901 L
.76399 .51927 L
.76524 .51948 L
.76643 .5196 L
.76769 .51965 L
.76888 .51963 L
.76996 .51954 L
.77061 .51946 L
.7713 .51936 L
.77252 .51911 L
Mistroke
.77384 .51877 L
.77529 .51832 L
.78031 .51629 L
.78555 .5139 L
.78813 .51283 L
.79051 .512 L
.79268 .51142 L
.79377 .51121 L
.79497 .51103 L
.79617 .51091 L
.79747 .51086 L
.7987 .51089 L
.79982 .51097 L
.80104 .51113 L
.80234 .51136 L
.80468 .51195 L
.80747 .51288 L
.81001 .51387 L
.81522 .51603 L
.81807 .51709 L
.82073 .51791 L
.82191 .51819 L
.82302 .51842 L
.82431 .51862 L
.82548 .51874 L
.82678 .51881 L
.82798 .51881 L
.82931 .51874 L
.83004 .51867 L
.83071 .51859 L
.8319 .5184 L
.83299 .51818 L
.83545 .51754 L
.83991 .51602 L
.84515 .51404 L
.8477 .51317 L
.85003 .5125 L
.85121 .51222 L
.85249 .51197 L
.85319 .51185 L
.85384 .51176 L
.85513 .51163 L
.85641 .51156 L
.85715 .51155 L
.85783 .51156 L
.85856 .51159 L
.85922 .51164 L
.85995 .5117 L
.86071 .5118 L
.871 .51458 L
Mistroke
.87606 .51632 L
.87828 .51697 L
.88071 .51757 L
.88177 .51777 L
.8829 .51795 L
.88397 .51808 L
.88495 .51817 L
.88605 .51822 L
.88725 .51823 L
.88838 .5182 L
.88943 .51812 L
.89055 .518 L
.8916 .51785 L
.894 .51739 L
.89634 .51679 L
.89887 .51604 L
.90385 .51443 L
.90657 .51361 L
.90911 .51296 L
.91128 .51252 L
.91249 .51234 L
.9136 .51221 L
.91481 .51211 L
.91612 .51205 L
.91737 .51206 L
.91851 .51211 L
.91972 .5122 L
.92101 .51236 L
.92224 .51255 L
.92335 .51275 L
.92869 .51411 L
.93391 .51567 L
.93678 .51647 L
.93947 .51708 L
.94177 .51748 L
.94306 .51763 L
.94425 .51774 L
.94525 .51779 L
.94636 .51781 L
.94751 .51779 L
.94858 .51774 L
.94968 .51765 L
.95071 .51753 L
.95266 .51723 L
.95475 .51681 L
.95703 .51626 L
.97619 .51242 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002Y0?ooo`800000203oool0
0`000000oooo0?ooo`2b0?ooo`00Z03oool010000000oooo0?ooo`0000070?ooo`030000003oool0
oooo0;80oooo002X0?ooo`040000003oool0oooo000000L0oooo00<000000?ooo`3oool0/P3oool0
0:L0oooo00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0;80oooo002W0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2b0?oo
o`00YP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo0P00002c0?ooo`00
YP3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
/P3oool009H0oooo0`00000=0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`2b0?ooo`00U@3oool00`000000oooo0?ooo`02000000`0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo00220?oo
o`@000003P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool01@0000050?ooo`030000003oool0oooo0;80oooo00190?ooo`@000003P3oool6000000`0
oooo1`00000=0?ooo`030000003oool0oooo0080oooo0P00000;0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`030?ooo`030000003oool0000000D0
oooo00<000000?ooo`3oool0/P3oool00200oooo2`0000080?ooo`/00000203oool400000080oooo
100000090?ooo`<000001@3oool2000000T0oooo00<000000?ooo`3oool01@3oool2000000T0oooo
0P0000070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`030?ooo`H000001@3oool00`000000oooo000000050?ooo`030000003oool0oooo0;80oooo
000K0?ooo`D000002`3oool8000000/0oooo0`0000030?ooo`8000002P3oool2000000D0oooo0P00
000:0?ooo`8000001@3oool2000000X0oooo0P0000060?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<0
00000?ooo`3oool0103oool00`000000oooo000000050?ooo`<00000/P3oool00400oooo1000000>
0?ooo`D000003P3oool5000000h0oooo00@000000?ooo`3oool0oooo0P00000;0?ooo`8000001@3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0103o
ool00`000000oooo000000050?ooo`030000003oool0oooo0;80oooo001i0?ooo`<000003`3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?oo
o`050?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0/P3oool008`0oooo0`00000>
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo00000005
0?ooo`030000003oool0oooo0;80oooo002M0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0103oool205EEE@040000003oool0oooo000000@0oooo00<000000?ooo`3oool0/P3oool0
09h0oooo0P0000000`3oool000000000000;0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0/P3oool009l0oooo0`00000<0?ooo`030000003oool0oooo0080oooo0P00002c0?ooo`00
[P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0;80oooo002^0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0/P3oool00:h0oooo00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`2b0?ooo`00[`3oool01@000000oooo0?ooo`3oool000000;@0oooo002_0?oo
o`050000003oool0oooo0?ooo`000000]03oool00:l0oooo00D000000?ooo`3oool0oooo0000002d
0?ooo`00[`3oool010000000oooo0?ooo`3oool200000;<0oooo002_0?ooo`050000003oool0oooo
0?ooo`000000]03oool00:l0oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00[`3oool01@00
0000oooo0?ooo`3oool000000;@0oooo002_0?ooo`050000003oool0oooo0?ooo`000000]03oool0
0:l0oooo00D000000?ooo`3oool0oooo0000002d0?ooo`00[`3oool010000000oooo0?ooo`3oool2
00000;<0oooo002_0?ooo`050000003oool0oooo0?ooo`000000]03oool00;00oooo00@000000?oo
o`3oool00000]03oool00;00oooo00@000000?ooo`3oool00000]03oool00;00oooo00@000000?oo
o`3oool00000]03oool00;00oooo00@000000?ooo`3oool00000]03oool00;00oooo00@000000?oo
o`3oool00000]03oool00;00oooo00<000000?ooo`3oool00P00002c0?ooo`00/03oool010000000
oooo0?ooo`00002d0?ooo`00/03oool010000000oooo0?ooo`00002d0?ooo`00/03oool010000000
oooo0?ooo`00002d0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?oo
o`0504A4A0000000000003<c<`3MgMd00P3oool010000000oooo0?ooo`00002d0?ooo`00V03oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0507MgM`0c<c<0oooo0?ooo`000000
0P3oool00`000000oooo0?ooo`2b0?ooo`00T03oool600000080oooo00D04A4A0?ooo`3oool0oooo
014A4@0@0?ooo`040000003oool0oooo00000080oooo0`00002b0?ooo`00V03oool01@000000oooo
0?ooo`3oool0000000l0oooo00D0MgMg03<c<`3oool0oooo000000020?ooo`030000003oool0oooo
0;80oooo002H0?ooo`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0
c<c<0080oooo00@000000?ooo`3oool00000]03oool009P0oooo00D04A4A0?ooo`3oool0oooo014A
4@0<0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool00000]03oool009P0oooo00D0
MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`000000
]03oool009P0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@00000103oool00`000000oooo
0000002d0?ooo`00/@3oool00`000000oooo0000002d0?ooo`00/@3oool010000000oooo00000000
002c0?ooo`00/@3oool00`000000oooo0000002d0?ooo`00/@3oool00`000000oooo0000002d0?oo
o`00/@3oool00`000000oooo0000002d0?ooo`00/@3oool00`000000oooo0000002d0?ooo`00/@3o
ool00`000000oooo0000002d0?ooo`00/@3oool010000000oooo00000000002c0?ooo`00/@3oool0
0`000000oooo0000002d0?ooo`00/@3oool00`000000oooo0000002d0?ooo`00/P3oool200000;@0
oooo002b0?ooo`800000]03oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo000M0?oo
o`@0000000<04A4A0?ooo`3oool0?03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R85
0?ooo`0504A4A0000000000003<c<`3MgMd0?03oool3000003l0oooo00D0k^k^03<c<`000000<c<c
0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM03l0oooo100000000`0A4A40
oooo0?ooo`0H0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VIV@1g
MgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0>`3oool200000400oooo00D0MgMg09VIV@3o
ool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`100?ooo`030000003oool0oooo
01X0oooo000D0?ooo`H000001@3oool00`000000oooo0?ooo`0f0?ooo`H000000P3oool01@0A4A40
oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool0>P3oool200000400oooo00D04A4A0?oo
o`3oool0oooo014A4@0@0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3oool06P3oool0
01l0oooo00<000000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg
03<c<`3oool0>`3oool200000400oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c
<c<0oooo0400oooo00<000000?ooo`3oool06P3oool001l0oooo00<000000?ooo`3oool0?P3oool0
1@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c00l0?ooo`800000
@03oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0110?oo
o`030000003oool0oooo01X0oooo000O0?ooo`030000003oool0oooo03h0oooo00D04A4A0?ooo`3o
ool0oooo014A4@0<0?ooo`030000003oool0oooo03h0oooo0P0000100?ooo`05014A4@3oool0oooo
0?ooo`0A4A40303oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01X0oooo000O0?oo
o`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0
oooo03h0oooo0P0000100?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo01X0oooo000M0?ooo`80EEEE00<000000?ooo`3oool0?P3oool0
1@3^k^h0<c<c0000000c<c<0k^k^00`0oooo1000000m0?ooo`<00000?`3oool01@3^k^h0<c<c0000
000c<c<0k^k^00`0oooo100000100?ooo`80EEEE00<000000?ooo`3oool06P3oool00;80oooo0P00
002d0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00503o
oooo0000040000005@3oool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?oo
o`3oool06P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00
002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00
/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool20000
0;<0oooo002c0?ooo`030000003oool000000;80oooo002c0?ooo`030000003oool000000;80oooo
002c0?ooo`<00000/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00<000000?oo
o`000000/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00<000000?ooo`000000
/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo0`00002b0?ooo`00/`3oool00`00
0000oooo0000002b0?ooo`00/`3oool00`000000oooo0000002b0?ooo`00/`3oool00`000000oooo
0000002b0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4
A0000000000003<c<`3MgMd01@3oool00`000000oooo0000002b0?ooo`00V03oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0oooo00<000000?ooo`00
0000/P3oool009P0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`000000/P3oool009P0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`03
07MgM`0c<c<0oooo00@0oooo1000002a0?ooo`00V03oool01@000000oooo0?ooo`3oool0000000`0
oooo00D00000028R8P000000<c<c0<c<c0050?ooo`040000003oool0oooo00000;40oooo002H0?oo
o`05014A4@3oool0oooo0?ooo`0A4A40303oool00`000000oooo0?ooo`070?ooo`040000003oool0
oooo00000;40oooo002H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?oo
o`070?ooo`040000003oool0oooo00000;40oooo002H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0
303oool4000000H0oooo00@000000?ooo`3oool00000/@3oool00;<0oooo00@000000?ooo`3oool0
0000/@3oool00;<0oooo0P0000000`3oool000000?ooo`2`0?ooo`00/`3oool010000000oooo0?oo
o`00002a0?ooo`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool010000000oooo0?oo
o`00002a0?ooo`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool010000000oooo0?oo
o`00002a0?ooo`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool2000000030?ooo`00
0000oooo0;00oooo002c0?ooo`040000003oool0oooo00000;40oooo002c0?ooo`050000003oool0
oooo0?ooo`000000/03oool00;<0oooo00D000000?ooo`3oool0oooo0000002`0?ooo`00/`3oool0
1@000000oooo0?ooo`3oool000000;00oooo002c0?ooo`050000003oool0oooo0?ooo`000000/03o
ool00;<0oooo00D000000?ooo`3oool0oooo0000002`0?ooo`00/`3oool200000080oooo00<00000
0?ooo`3oool0[P3oool00;<0oooo00D000000?ooo`3oool0oooo0000002`0?ooo`00/`3oool01@00
0000oooo0?ooo`3oool000000;00oooo002c0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool0[@3oool00;<0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2]0?ooo`00
/`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:d0oooo002c0?ooo`8000000`3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo09l0oooo002c0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool02@3oool2000000030?ooo`000000000009l0oooo002c0?oo
o`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool01@000000oooo0?ooo`3oool0
000009l0oooo002c0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0S03oool00:T0
oooo100000000`0A4A40oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00/0oooo0P0000000`3oool0
00000000002<0?ooo`00Z`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool00`3oool2000000/0oooo1P00000>0?ooo`D000003`3oool3000005@0oooo
002[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0103oool2000000X0oooo0P00
00050?ooo`8000002@3oool5000000030?ooo`0000000000008000002@3oool9000000/0oooo2@00
000;0?ooo`@00000703oool00:/0oooo00<000000?ooo`3oool01@3oool3000000<0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`040?ooo`8000002@3oool00`000000oooo0?ooo`05
0?ooo`8000002@3oool2000000H0oooo00<000000?ooo`3oool0203oool2000000H0oooo00<00000
0?ooo`3oool01`3oool3000000@0oooo1@0000080?ooo`<000000`3oool500000200oooo002[0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool300000080oooo0P00000=0?oo
o`H000003@3oool6000000d0oooo1@00000?0?ooo`<000009@3oool00:/0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00X0oooo1@00000?0?ooo`<0
0000L@3oool00:/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool02@3oool200000080oooo0P00002E0?ooo`00Z@3o
ool205EEE@030000003oool0oooo00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`050?ooo`030000003oool0oooo00X0oooo1000002F0?ooo`00/`3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0Y@3oool00;<0oooo0P0000050?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool0Y@3oool00;<0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0:H0oooo002c0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2V0?ooo`00/`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000:T0oooo002c0?ooo`030000003o
ool0oooo00D0oooo00@000000?ooo`3oool00000Z@3oool00;<0oooo00<000000?ooo`3oool01P3o
ool300000:T0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0
oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<0
00000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002I0?ooo`@00000
00<04A4A0?ooo`3oool00P3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@050?ooo`03
0000003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo00@0oooo0P0R8R880?ooo`0307Mg
M`0c<c<0oooo00@0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0;80oooo002K0?ooo`030000003oool0
oooo00h0oooo00<0MgMg03<c<`3oool0103oool300000;80oooo002K0?ooo`030000003oool0oooo
00/0oooo00D00000028R8P000000<c<c0<c<c02j0?ooo`00V`3oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo0;`0oooo002K0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3o
ool0_03oool009T0oooo0P1EEED00`000000oooo0?ooo`0;0?ooo`@00000^`3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00:00oooo0P0000001P0A4A40oooo0?ooo`0A4A400000
014A4AL0oooo00D0c<c<028R8P0000008R8R0<c<c02T0?ooo`00X@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00L0oooo1P0000090?ooo`05028R8P2IVIT0oooo09VIV@0R8R80Y03o
ool00:40oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`050000003oool0
oooo0?ooo`000000Y03oool00:40oooo00H000000?ooo`14A4@0<c<c0?ooo`0000090?ooo`H00000
2@3oool01@0c<c<0VIVI0?ooo`2IVIT0<c<c0:@0oooo002Q0?ooo`060000003MgMd0<c<c05EEE@3M
gMd00000603oool01@3<c<`00000000000000000c<c<0:@0oooo002Q0?ooo`0600000028R8P0ZZZZ
0;^k^`1EEED00000603oool01@0A4A40^k^k0?ooo`2k^k/04A4A0:@0oooo002Q0?ooo`060000000c
<c<0oooo0?ooo`0c<c<00000603oool01@000000^k^k0?ooo`2k^k/000000:@0oooo002P0?ooo`03
014A4@000000R8R80080oooo00<0R8R80000000A4A405`3oool01@2ZZZX04A4A0000000A4A40ZZZZ
0:@0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10474 m
.06244 .10488 L
.06361 .1049 L
.06484 .10486 L
.06548 .10481 L
.06619 .10473 L
.06744 .10454 L
.06861 .10431 L
.06988 .104 L
.07216 .10336 L
.075 .10249 L
.0776 .10178 L
.07882 .1015 L
.07946 .10138 L
.08014 .10127 L
.08139 .10111 L
.08255 .10103 L
.08332 .10102 L
.08403 .10103 L
.08481 .10107 L
.08563 .10115 L
.08635 .10124 L
.08702 .10135 L
.08853 .10166 L
.09115 .10237 L
.09396 .10326 L
.09681 .10413 L
.09821 .10449 L
.09951 .10475 L
.10069 .10493 L
.10194 .10505 L
.10319 .10509 L
.10391 .10508 L
.10458 .10504 L
.10578 .10492 L
.10689 .10474 L
.10811 .10448 L
.10942 .10414 L
.11451 .10249 L
.11697 .10173 L
.11817 .10142 L
.11929 .10118 L
.1203 .10101 L
.12137 .10088 L
.12244 .10082 L
.12362 .10082 L
.12428 .10085 L
.12499 .10092 L
.12629 .1011 L
.12756 .10136 L
Mistroke
.12874 .10166 L
.13423 .1035 L
.13671 .10432 L
.13792 .10466 L
.13904 .10491 L
.14033 .10514 L
.141 .10522 L
.14172 .10529 L
.14288 .10532 L
.14415 .10527 L
.14546 .10513 L
.14667 .10491 L
.148 .10459 L
.14941 .10417 L
.15438 .10236 L
.15652 .10162 L
.15764 .10129 L
.15881 .101 L
.16013 .10075 L
.16134 .10061 L
.16247 .10055 L
.1637 .10058 L
.16438 .10064 L
.16512 .10073 L
.16581 .10085 L
.16645 .10098 L
.16895 .10167 L
.17455 .10382 L
.17708 .10471 L
.17832 .10506 L
.17945 .10531 L
.18064 .1055 L
.18192 .1056 L
.18258 .10561 L
.18331 .10559 L
.18463 .10547 L
.18584 .10526 L
.18696 .10499 L
.18947 .10417 L
.19401 .10229 L
.19663 .10129 L
.1979 .10089 L
.19906 .1006 L
.20029 .10038 L
.2016 .10025 L
.20228 .10023 L
.20303 .10024 L
.20373 .10029 L
.20438 .10036 L
.20559 .10058 L
Mistroke
.20688 .10091 L
.20923 .10173 L
.21457 .10409 L
.21596 .10465 L
.21747 .10519 L
.21816 .10539 L
.21889 .10558 L
.21958 .10573 L
.22022 .10584 L
.22089 .10592 L
.22161 .10597 L
.22292 .10597 L
.22412 .10585 L
.22538 .10562 L
.2266 .10529 L
.22793 .10483 L
.23034 .1038 L
.23487 .10163 L
.23743 .10062 L
.23872 .10023 L
.23946 .10007 L
.24015 .09994 L
.24137 .09982 L
.2425 .09981 L
.24373 .09991 L
.24503 .10015 L
.24618 .10046 L
.24723 .10083 L
.24957 .10185 L
.25379 .10404 L
.25616 .10516 L
.2574 .10564 L
.25872 .10605 L
.25987 .1063 L
.26114 .10645 L
.26229 .10647 L
.26337 .10639 L
.26462 .10616 L
.26532 .10598 L
.26596 .10578 L
.26836 .10479 L
.27379 .10179 L
.27624 .10055 L
.27752 .10002 L
.27823 .09978 L
.27888 .0996 L
.28007 .09935 L
.28138 .09922 L
.28249 .09924 L
.28367 .09939 L
Mistroke
.28492 .09969 L
.28606 .10008 L
.28866 .10132 L
.29338 .10419 L
.29559 .10546 L
.29767 .1064 L
.29871 .10675 L
.29983 .10701 L
.30107 .10716 L
.30221 .10715 L
.3035 .10698 L
.30471 .10667 L
.3058 .10627 L
.30698 .10572 L
.31205 .10248 L
.31437 .10092 L
.31563 .10016 L
.31681 .09954 L
.3179 .09907 L
.3189 .09874 L
.32 .0985 L
.32119 .09838 L
.32247 .09844 L
.32312 .09855 L
.32384 .09871 L
.3251 .09915 L
.32628 .09971 L
.32895 .10138 L
.33183 .10356 L
.33439 .10548 L
.33579 .1064 L
.33709 .10712 L
.3382 .10761 L
.33939 .10798 L
.34071 .10819 L
.34191 .10818 L
.3431 .10799 L
.34422 .10764 L
.34544 .10709 L
.34675 .10632 L
.35189 .10216 L
.35435 .10007 L
.35557 .09917 L
.35669 .09844 L
.3578 .09786 L
.35879 .09746 L
.3599 .09717 L
.36109 .09707 L
.36239 .09719 L
.36305 .09735 L
Mistroke
.36377 .09759 L
.36504 .09821 L
.36623 .09897 L
.36892 .10123 L
.3718 .1041 L
.37451 .10672 L
.37584 .10783 L
.37707 .10868 L
.37819 .10928 L
.37938 .10971 L
.38057 .10991 L
.38188 .10985 L
.3831 .10952 L
.38424 .10899 L
.38548 .10817 L
.38681 .10705 L
.39199 .10123 L
.39449 .09839 L
.39572 .09719 L
.39685 .09626 L
.39788 .09558 L
.39896 .09506 L
.40006 .09478 L
.40126 .09474 L
.40192 .09486 L
.40265 .09508 L
.40334 .0954 L
.40398 .09578 L
.40518 .09671 L
.40646 .09798 L
.41204 .10559 L
.41435 .10879 L
.41556 .11025 L
.41683 .11154 L
.41751 .1121 L
.41825 .1126 L
.41956 .11317 L
.4202 .11329 L
.42089 .11331 L
.42212 .11303 L
.42335 .11235 L
.42405 .11179 L
.4247 .11115 L
.42744 .1075 L
.43234 .09859 L
.43508 .09388 L
.43643 .09201 L
.43769 .09067 L
.43838 .09011 L
.43912 .08968 L
Mistroke
.43994 .08942 L
.44069 .08938 L
.44137 .08951 L
.4421 .08984 L
.4428 .09032 L
.44343 .09092 L
.4446 .09237 L
.44585 .09441 L
.4481 .09917 L
.45323 .11242 L
.45456 .11564 L
.45601 .11866 L
.45667 .11984 L
.45738 .12091 L
.45864 .12231 L
.45985 .12297 L
.46099 .12291 L
.46223 .12204 L
.46293 .12118 L
.46358 .12015 L
.46485 .11744 L
.46606 .11411 L
.46832 .10615 L
.47338 .08405 L
.47551 .07552 L
.47667 .07169 L
.47776 .06889 L
.47894 .06688 L
.48023 .06614 L
.48133 .06687 L
.48251 .06923 L
.48317 .07133 L
.48388 .07421 L
.48516 .08111 L
.48668 .09231 L
.48806 .10529 L
.49077 .13869 L
.49332 .17871 L
.50321 .37468 L
.50566 .42136 L
.50828 .4653 L
.5107 .49874 L
.513 .52296 L
.51424 .53288 L
.51558 .54121 L
.5168 .54661 L
.51793 .54987 L
.51918 .55166 L
.51989 .5519 L
.52055 .55164 L
Mistroke
.52125 .55091 L
.52189 .54986 L
.52263 .54824 L
.52333 .54633 L
.52832 .52641 L
.53077 .51561 L
.53302 .5069 L
.53508 .50076 L
.53611 .49847 L
.53725 .49661 L
.53839 .49546 L
.53961 .49501 L
.54077 .49531 L
.54182 .49615 L
.54304 .49774 L
.54417 .49971 L
.54673 .50552 L
.55139 .51765 L
.55262 .52052 L
.55394 .52324 L
.55511 .52524 L
.55634 .52687 L
.55765 .52804 L
.55884 .52858 L
.56016 .52859 L
.56091 .52834 L
.56161 .52793 L
.56275 .52695 L
.564 .52547 L
.56626 .52196 L
.57049 .51412 L
.57289 .51002 L
.5742 .50816 L
.57543 .50674 L
.57647 .50582 L
.5776 .50513 L
.57885 .50475 L
.57999 .50477 L
.58128 .50518 L
.58249 .50594 L
.58358 .50688 L
.58476 .50814 L
.58985 .51521 L
.59216 .51841 L
.59343 .51993 L
.59461 .52113 L
.5957 .52203 L
.5967 .52265 L
.59781 .52311 L
.59899 .52331 L
Mistroke
.60028 .52319 L
.60093 .52301 L
.60164 .52271 L
.60291 .52195 L
.60409 .52101 L
.60964 .51484 L
.61201 .51216 L
.61449 .50988 L
.6158 .50903 L
.61654 .50866 L
.61722 .5084 L
.61843 .50814 L
.61972 .50815 L
.62096 .50842 L
.62166 .50869 L
.62232 .509 L
.62364 .50982 L
.62506 .51094 L
.62998 .51574 L
.63141 .51711 L
.63296 .51846 L
.63433 .51945 L
.63508 .5199 L
.63579 .52025 L
.63648 .52054 L
.63723 .52076 L
.63854 .52096 L
.63919 .52096 L
.63987 .5209 L
.64109 .52061 L
.64235 .52011 L
.6435 .51948 L
.64607 .51762 L
.65071 .51362 L
.65331 .51168 L
.65477 .51083 L
.65547 .51051 L
.65613 .51027 L
.65731 .50996 L
.65861 .50983 L
.65988 .50991 L
.6606 .51005 L
.66125 .51023 L
.66253 .51073 L
.66375 .51136 L
.66601 .51284 L
.67109 .51668 L
.67323 .51806 L
.67439 .51866 L
.67548 .5191 L
Mistroke
.67666 .51944 L
.67795 .51963 L
.67905 .51964 L
.68023 .5195 L
.6809 .51935 L
.68161 .51913 L
.6829 .51863 L
.6858 .51701 L
.68852 .51516 L
.69107 .51344 L
.69333 .51217 L
.6946 .51161 L
.69577 .51123 L
.69697 .51097 L
.69829 .51086 L
.69896 .51088 L
.69967 .51094 L
.70095 .51119 L
.70218 .51158 L
.70354 .51214 L
.70628 .51363 L
.71119 .51664 L
.71261 .51738 L
.71396 .51796 L
.7147 .51823 L
.71551 .51846 L
.71625 .51863 L
.71693 .51873 L
.71763 .5188 L
.71829 .51882 L
.71953 .51874 L
.72022 .51864 L
.72086 .5185 L
.72229 .51808 L
.72733 .51561 L
.7301 .51404 L
.73146 .51334 L
.73272 .51276 L
.73388 .51231 L
.73516 .51193 L
.73645 .51167 L
.73715 .51159 L
.73781 .51156 L
.73898 .51159 L
.74004 .51172 L
.74121 .51197 L
.74244 .51234 L
.74717 .5145 L
.74977 .51586 L
.75222 .51699 L
Mistroke
.75333 .51741 L
.75451 .51777 L
.7558 .51805 L
.75698 .5182 L
.75805 .51824 L
.75904 .51819 L
.76013 .51804 L
.7613 .51779 L
.76257 .51742 L
.76396 .5169 L
.76647 .51578 L
.77118 .51356 L
.77259 .51301 L
.7739 .5126 L
.77462 .51242 L
.77527 .51228 L
.776 .51217 L
.77679 .51209 L
.778 .51205 L
.77932 .51214 L
.77998 .51223 L
.7807 .51236 L
.78198 .51268 L
.78694 .51462 L
.78966 .51584 L
.7922 .51684 L
.79353 .51724 L
.79421 .51741 L
.79495 .51756 L
.79576 .51769 L
.79653 .51777 L
.79728 .5178 L
.79797 .5178 L
.79867 .51777 L
.79933 .51771 L
.80055 .51752 L
.80187 .51721 L
.8033 .51677 L
.8084 .51472 L
.81119 .51362 L
.81255 .51318 L
.81379 .51285 L
.81493 .51263 L
.81601 .51249 L
.81715 .51242 L
.81839 .51245 L
.81966 .51258 L
.82031 .51268 L
.82101 .51282 L
.82344 .51349 L
Mistroke
.82836 .51537 L
.83105 .51636 L
.83235 .51676 L
.83354 .51706 L
.83464 .51727 L
.83568 .5174 L
.83678 .51747 L
.83796 .51747 L
.83919 .51737 L
.84048 .51718 L
.84158 .51694 L
.8428 .51662 L
.848 .51478 L
.85086 .51378 L
.85227 .51337 L
.85358 .51307 L
.8548 .51287 L
.8561 .51274 L
.85684 .51271 L
.85754 .51272 L
.85885 .51279 L
.86005 .51295 L
.86116 .51316 L
.86366 .51383 L
.86838 .51546 L
.87097 .51629 L
.87225 .51663 L
.87343 .51688 L
.87454 .51706 L
.87571 .51718 L
.87689 .51722 L
.87819 .51718 L
.87927 .51708 L
.88043 .51691 L
.88153 .51668 L
.88253 .51644 L
.8876 .51483 L
.89028 .51398 L
.89175 .51359 L
.89313 .51329 L
.89445 .51309 L
.89519 .51301 L
.89587 .51297 L
.89708 .51294 L
.89836 .513 L
.89956 .51313 L
.90067 .51332 L
.9019 .51357 L
.90321 .51391 L
.90814 .51544 L
Mistroke
.91084 .51622 L
.91217 .51653 L
.91338 .51675 L
.91469 .51692 L
.91538 .51697 L
.91611 .51701 L
.91685 .51701 L
.91755 .517 L
.91831 .51695 L
.91912 .51687 L
.91981 .51678 L
.92056 .51665 L
.92191 .51637 L
.92444 .51571 L
.92952 .51419 L
.93076 .51387 L
.93209 .51358 L
.93285 .51344 L
.93354 .51334 L
.93424 .51325 L
.93491 .51319 L
.93607 .51314 L
.9373 .51315 L
.93847 .51322 L
.93952 .51334 L
.94077 .51354 L
.94212 .51383 L
.94456 .51446 L
.9481 .51549 L
.95005 .51601 L
.9519 .51641 L
.95294 .51658 L
.95408 .51673 L
.95511 .51681 L
.95606 .51684 L
.95696 .51683 L
.95795 .51679 L
.95898 .51669 L
.95995 .51656 L
.96194 .51618 L
.96403 .51567 L
.96777 .51464 L
.96971 .51413 L
.97179 .5137 L
.97299 .51351 L
.97407 .51339 L
.97516 .51331 L
.97619 .51329 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002/0?ooo`8000001@3oool0
0`000000oooo0?ooo`2b0?ooo`00[03oool3000000@0oooo00<000000?ooo`3oool0/P3oool00:`0
oooo00<000000?ooo`000000103oool00`000000oooo0?ooo`2b0?ooo`00Z`3oool010000000oooo
0?ooo`0000040?ooo`030000003oool0oooo0;80oooo002[0?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`3oool0/P3oool00:/0oooo00@000000?ooo`3oool00000103oool200000;<0
oooo002[0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0/P3oool009l0oooo
0`0000090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`2b0?ooo`00
W`3oool00`000000oooo000000090?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000
oooo0?ooo`2b0?ooo`00TP3oool3000000T0oooo00D000000?ooo`3oool0oooo000000060?ooo`@0
000000<04A4A0?ooo`0000000`3oool00`000000oooo0?ooo`2b0?ooo`00K@3oool3000000T0oooo
100000080?ooo`@00000203oool200000080oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`050000003oool0oooo0?ooo`00
0000]03oool002`0oooo1P0000060?ooo`L000001@3oool7000000H0oooo1`0000060?ooo`L00000
1@3oool300000080oooo0P0000060?ooo`800000103oool00`000000oooo0?ooo`040?ooo`800000
0`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`06000000@0oooo0P0000030?ooo`050000003oool0oooo0?ooo`00
0000]03oool001/0oooo4@0000060?ooo`H000001`3oool5000000L0oooo1P0000070?ooo`H00000
1`3oool2000000030?ooo`000000000000L0oooo0P0000030?ooo`030000003oool0oooo00@0oooo
0P0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool0oooo0`00002b0?ooo`00
IP3oool3000000X0oooo0`0000090?ooo`@00000203oool2000000030?ooo`000000000000P0oooo
00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`00
00000`3oool01@000000oooo0?ooo`3oool000000;@0oooo002<0?ooo`<000002@3oool200000003
0?ooo`000000oooo00H0oooo00<000000?ooo`3oool00`3oool00`000000oooo000000030?ooo`05
0000003oool0oooo0?ooo`000000]03oool009T0oooo0`0000080?ooo`050000003oool0oooo0?oo
o`0000000P3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0/P3oool0
0:D0oooo00@000000?ooo`3oool000000P1EEED01@000000oooo0?ooo`3oool0000000<0oooo00<0
00000?ooo`3oool0/P3oool00:D0oooo00<000000?ooo`0000001`3oool01@000000oooo0?ooo`3o
ool000000;@0oooo002V0?ooo`800000203oool00`000000oooo0?ooo`0200000;<0oooo002`0?oo
o`040000003oool0oooo00000;@0oooo002`0?ooo`040000003oool0oooo00000;@0oooo002`0?oo
o`040000003oool0oooo00000;@0oooo002`0?ooo`040000003oool0oooo00000;@0oooo002`0?oo
o`040000003oool0oooo00000;@0oooo002`0?ooo`040000003oool0oooo00000;@0oooo002`0?oo
o`030000003oool0oooo00800000/`3oool00;00oooo00@000000?ooo`3oool00000]03oool00;00
oooo00@000000?ooo`3oool00000]03oool00;00oooo00@000000?ooo`3oool00000]03oool00;00
oooo00@000000?ooo`3oool00000]03oool00;40oooo00<000000?ooo`000000]03oool00;40oooo
00@000000?ooo`0000000000/`3oool00;40oooo00<000000?ooo`000000]03oool00;40oooo00<0
00000?ooo`000000]03oool00;40oooo00<000000?ooo`000000]03oool00;40oooo00<000000?oo
o`000000]03oool00;40oooo00<000000?ooo`000000]03oool00;40oooo00<000000?ooo`000000
]03oool00;40oooo00@000000?ooo`0000000000/`3oool00;40oooo00<000000?ooo`000000]03o
ool00;40oooo00<000000?ooo`000000]03oool00;40oooo00<000000?ooo`000000]03oool009P0
oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0
gMgM00<0oooo00<000000?ooo`000000]03oool009P0oooo00D0MgMg09VIV@3oool0VIVI07MgM`05
0?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`020?ooo`030000003oool000000;@0oooo002@0?oo
o`H000000P3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00H000000?ooo`3oool0oooo0000
003oool300000;80oooo002H0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c
0?ooo`020?ooo`030000003oool000000;@0oooo002H0?ooo`050000003oool0oooo0?ooo`000000
303oool01@0000008R8R0000000c<c<0c<c<00<0oooo00<000000?ooo`000000]03oool009P0oooo
00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo00H0oooo0P00002d0?ooo`00
V03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01P3oool200000;@0
oooo002H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000000D0oooo0P00002d0?ooo`00
/P3oool200000;@0oooo002b0?ooo`<00000/`3oool00;80oooo0P00002d0?ooo`00/P3oool20000
0;@0oooo002b0?ooo`800000]03oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b
0?ooo`<00000/`3oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000
]03oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000]03oool001d0
oooo100000000`0A4A40oooo0?ooo`0l0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R
8PD0oooo00D0A4A4000000000000<c<c0=gMg@0l0?ooo`<00000?`3oool01@3^k^h0<c<c0000000c
<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0?`3oool400000003014A
4@3oool0oooo01P0oooo000O0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`0k0?ooo`800000@03oool01@1gMgL0VIVI
0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo0400oooo00<000000?ooo`3o
ool06P3oool001@0oooo1P0000050?ooo`030000003oool0oooo03H0oooo1P0000020?ooo`05014A
4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`0j0?ooo`800000@03oool01@0A4A40
oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0J0?oo
o`007`3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1g
MgL0<c<c0?ooo`0k0?ooo`800000@03oool01@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg
03<c<`3oool0@03oool00`000000oooo0?ooo`0J0?ooo`007`3oool00`000000oooo0?ooo`0n0?oo
o`050000003oool0oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<03d0oooo00<0
00000?ooo`3oool0?P3oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P000000
<c<c0<c<c0110?ooo`030000003oool0oooo01X0oooo000O0?ooo`030000003oool0oooo03h0oooo
00D04A4A0?ooo`3oool0oooo014A4@0<0?ooo`030000003oool0oooo03l0oooo00<000000?ooo`3o
ool0?P3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`0J0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VI
V@1gMgL0303oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VI
V@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool06P3oool0
01d0oooo0P1EEED00`000000oooo0?ooo`0n0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4
000003h0oooo0P00000o0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool400000400oooo0P1E
EED00`000000oooo0?ooo`0J0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00503ooooo0000040000005@3oool0
01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01X0oooo000K0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0B@3oool00`000000
oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool06P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0
oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?oo
o`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3o
ool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo
0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?oo
o`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`000000/P3o
ool009P0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000
000c<c<0gMgM00D0oooo00<000000?ooo`000000/P3oool009P0oooo00D0MgMg09VIV@3oool0VIVI
07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`040?ooo`030000003oool000000;80oooo
002H0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`030?ooo`030000
003oool000000;80oooo002H0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c
0?ooo`040?ooo`<00000/P3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`050000
000R8R80000003<c<`3<c<`01@3oool00`000000oooo0000002b0?ooo`00V03oool01@0A4A40oooo
0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0000002b0?ooo`00
V03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0000002b0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0k^k^00`0oooo100000060?ooo`03
0000003oool000000;80oooo002c0?ooo`030000003oool000000;80oooo002c0?ooo`<00000/P3o
ool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0
oooo00<000000?ooo`000000/P3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00@0
00000?ooo`3oool00000/@3oool00;<0oooo00@000000?ooo`3oool00000/@3oool00;<0oooo0P00
00000`3oool000000?ooo`2`0?ooo`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool0
10000000oooo0?ooo`00002a0?ooo`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool0
10000000oooo0?ooo`00002a0?ooo`00/`3oool010000000oooo0?ooo`00002a0?ooo`00/`3oool0
10000000oooo0?ooo`00002a0?ooo`00/`3oool2000000030?ooo`000000oooo0;00oooo002c0?oo
o`040000003oool0oooo00000;40oooo002c0?ooo`040000003oool0oooo00000;40oooo002c0?oo
o`040000003oool0oooo00000;40oooo002c0?ooo`040000003oool0oooo00000;40oooo002c0?oo
o`040000003oool0oooo00000;40oooo002c0?ooo`80000000<0oooo0000003oool01`3oool20000
0:L0oooo002c0?ooo`040000003oool0oooo000000L0oooo1000002V0?ooo`00/`3oool010000000
oooo0?ooo`0000070?ooo`040000003oool0oooo00000:H0oooo002c0?ooo`040000003oool0oooo
000000L0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`2I0?ooo`00Z@3oool4
00000003014A4@3oool0oooo00<0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?oo
o`3oool0000000P0oooo1000002I0?ooo`00Z`3oool00`000000oooo0?ooo`050?ooo`040000003o
ool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000070?ooo`8000000P3oool00`000000
oooo0?ooo`060?ooo`D00000203oool4000000X0oooo0P00001d0?ooo`00Z`3oool00`000000oooo
0?ooo`050?ooo`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`050?ooo`05
0000003oool0oooo0?ooo`0000001`3oool200000080oooo0P0000070?ooo`80000000@0oooo0000
0000000000001P3oool6000000L0oooo1@0000080?ooo`H000001`3oool5000000L0oooo1P000006
0?ooo`H00000203oool3000001`0oooo002[0?ooo`030000003oool0oooo00D0oooo0`0000000`3o
ool000000?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool20000
00D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`8000001P3oool20000
00<0oooo00<000000?ooo`3oool0103oool300000080oooo0P0000050?ooo`@0000000@0oooo0000
0000000000001P3oool7000000D0oooo1`0000060?ooo`H000001P3oool8000001l0oooo002[0?oo
o`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo000000050?ooo`030000003oool0
oooo00<0oooo0P0000030?ooo`030000003oool0oooo00D0oooo0P0000030?ooo`030000003oool0
oooo00D0oooo0P000000103oool000000000000000070?ooo`@000002@3oool4000000T0oooo0`00
000:0?ooo`<000002P3oool2000004P0oooo002[0?ooo`030000003oool0oooo00D0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00D0oooo00D000000?ooo`3oool0oooo
000000080?ooo`@000002P3oool2000008L0oooo002[0?ooo`030000003oool0oooo00D0oooo00D0
00000?ooo`3oool0oooo000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`000000
X03oool00:T0oooo0P1EEED00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D0
00000?ooo`3oool0oooo000000080?ooo`<00000X03oool00;<0oooo00<000000?ooo`3oool00P3o
ool01@000000oooo0?ooo`3oool000000:/0oooo002c0?ooo`8000000`3oool010000000oooo0?oo
o`00002/0?ooo`00/`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000:`0oooo
002c0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000[03oool00;<0oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0000002]0?ooo`00/`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool000000:d0oooo002c0?ooo`030000003oool0oooo00<0oooo0P00002]0?oo
o`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003o
ool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo
0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo
002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool400000003014A4@3oool0
oooo0080oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool00`000000oooo0?oo
o`2b0?ooo`00V`3oool00`000000oooo0?ooo`040?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`04
0?ooo`030000003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`0>0?ooo`03
07MgM`0c<c<0oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`050000
000R8R80000003<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`2l0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0;`0oooo002I
0?ooo`80EEEE00<000000?ooo`3oool02`3oool400000;/0oooo003o0?ooofT0oooo003o0?ooofT0
oooo003o0?ooofT0oooo002M0?ooo`80000000H04A4A0?ooo`3oool04A4A0000000A4A4H0?ooo`@0
000000<04A4A0?ooo`3oool01@00002O0?ooo`00WP3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo00L0oooo1P00000<0?ooo`030000003oool0oooo0080oooo00D0VIVI028R8P3^k^h0
oooo04A4A02O0?ooo`00WP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01T0oooo
00<000000?ooo`3oool00`3oool00`2IVIT08R8R0>k^kP2P0?ooo`00WP3oool01P000000oooo04A4
A00c<c<0oooo000000T0oooo1P00000<0?ooo`030000003oool0oooo00@0oooo00<0VIVI028R8P3^
k^h0W`3oool009h0oooo00H000000=gMg@0c<c<0EEEE0=gMg@00000K0?ooo`030000003oool0oooo
00D0oooo00<0MgMg06IVIP3oool0WP3oool009h0oooo00H0000008R8R02ZZZX0^k^k05EEE@00000K
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0W@3oool009h0oooo00H0000003<c
<`3oool0oooo03<c<`00000K0?ooo`030000003oool0oooo0080oooo00D000000;^k^`3oool0VIVI
014A4@2O0?ooo`00W@3oool00`0A4A40000008R8R0020?ooo`0308R8R00000004A4A01P0oooo0P1E
EED00`000000oooo0?ooo`020?ooo`0509VIV@0A4A400000028R8P3<c<`0W`3oool00?l0ooooJ@3o
ool00?l0ooooJ@3oool00?l0ooooJ@3oool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10431 m
.02499 .10427 L
.02605 .10417 L
.02729 .10397 L
.02846 .10373 L
.03279 .10257 L
.03398 .10227 L
.03524 .102 L
.03631 .10182 L
.0375 .1017 L
.03877 .10166 L
.03949 .10168 L
.04014 .10172 L
.04141 .10188 L
.04262 .1021 L
.04721 .10333 L
.04842 .10366 L
.04972 .10397 L
.05096 .10419 L
.0521 .10433 L
.05275 .10438 L
.05347 .1044 L
.05421 .10438 L
.05491 .10434 L
.05614 .1042 L
.05746 .10395 L
.06007 .10327 L
.06244 .10257 L
.06379 .1022 L
.06505 .10192 L
.06637 .1017 L
.06707 .10163 L
.06783 .10158 L
.06909 .10158 L
.06973 .10162 L
.07043 .10169 L
.07166 .10189 L
.07281 .10214 L
.07585 .10301 L
.07734 .10346 L
.07872 .10385 L
.07994 .10413 L
.08059 .10425 L
.08129 .10436 L
.08199 .10444 L
.08265 .10448 L
.0834 .1045 L
.08408 .10448 L
.08534 .10436 L
.08651 .10417 L
Mistroke
.0878 .10388 L
.08917 .10349 L
.09149 .10276 L
.09399 .10203 L
.09472 .10186 L
.09548 .10171 L
.09614 .10161 L
.09686 .10152 L
.09753 .10148 L
.09825 .10146 L
.09955 .10152 L
.1002 .10159 L
.1009 .1017 L
.10218 .10197 L
.10458 .10267 L
.10692 .10344 L
.10815 .10382 L
.10944 .10416 L
.11058 .10439 L
.11182 .10455 L
.11295 .10461 L
.114 .10458 L
.11466 .10452 L
.11536 .10443 L
.11664 .10418 L
.11788 .10385 L
.11903 .1035 L
.1218 .10255 L
.12316 .10212 L
.12439 .10179 L
.1256 .10154 L
.12674 .10139 L
.12795 .10134 L
.12926 .1014 L
.1299 .10147 L
.13061 .10159 L
.13204 .10192 L
.13461 .10274 L
.13729 .10369 L
.1387 .10412 L
.13947 .10432 L
.14018 .10448 L
.14148 .10467 L
.14217 .10473 L
.14291 .10474 L
.14422 .10467 L
.14541 .1045 L
.1466 .10422 L
.14772 .1039 L
.15025 .103 L
Mistroke
.15293 .10204 L
.1541 .1017 L
.15538 .10141 L
.15656 .10125 L
.15765 .10119 L
.1587 .10123 L
.15981 .10136 L
.1611 .10163 L
.16231 .10198 L
.16458 .1028 L
.16711 .10377 L
.16849 .10423 L
.16978 .10457 L
.17088 .10478 L
.17206 .10489 L
.17337 .10488 L
.17456 .10474 L
.17523 .10462 L
.17594 .10445 L
.17722 .10407 L
.18011 .10296 L
.18267 .10196 L
.18396 .10155 L
.18469 .10136 L
.18536 .10122 L
.18659 .10106 L
.1879 .10103 L
.18911 .10113 L
.19026 .10135 L
.19138 .10165 L
.19241 .102 L
.19474 .10295 L
.19728 .10401 L
.19852 .10444 L
.19965 .10476 L
.20085 .10498 L
.20213 .10509 L
.2028 .10508 L
.20353 .10503 L
.20421 .10494 L
.20485 .10481 L
.20913 .10328 L
.21146 .10224 L
.21364 .10142 L
.21478 .1011 L
.216 .10089 L
.2167 .10083 L
.21736 .10081 L
.21859 .1009 L
.21972 .1011 L
Mistroke
.22077 .10139 L
.22313 .10231 L
.22579 .10356 L
.22828 .1046 L
.22953 .10498 L
.23024 .10514 L
.23088 .10524 L
.23158 .10531 L
.23235 .10532 L
.23307 .10528 L
.23374 .10519 L
.23504 .1049 L
.23627 .10449 L
.23857 .10347 L
.24107 .10222 L
.24244 .1016 L
.24371 .10112 L
.24478 .10082 L
.24593 .10062 L
.24721 .10055 L
.24837 .10065 L
.24942 .10086 L
.25057 .10121 L
.25266 .10212 L
.25506 .10337 L
.25632 .10402 L
.25765 .10464 L
.25882 .10508 L
.26009 .10543 L
.26126 .10559 L
.26234 .1056 L
.26356 .10545 L
.26471 .10516 L
.26575 .10479 L
.26688 .10428 L
.27173 .10164 L
.27308 .10102 L
.27435 .10058 L
.27567 .1003 L
.27637 .10024 L
.27713 .10023 L
.27776 .10028 L
.27846 .1004 L
.27973 .10075 L
.28096 .10125 L
.2821 .10183 L
.28462 .10331 L
.28594 .10409 L
.28734 .10484 L
.28857 .10537 L
Mistroke
.28926 .10561 L
.28991 .10578 L
.29105 .10596 L
.29227 .10596 L
.29301 .10587 L
.2938 .10568 L
.29455 .10544 L
.29525 .10516 L
.29796 .10367 L
.30064 .10194 L
.30182 .10125 L
.30311 .1006 L
.30428 .10016 L
.30537 .0999 L
.30652 .0998 L
.30775 .0999 L
.3084 .10004 L
.3091 .10026 L
.31037 .1008 L
.31275 .10223 L
.31483 .10368 L
.31706 .10513 L
.31834 .10578 L
.31951 .1062 L
.32069 .10644 L
.3218 .10647 L
.3231 .10627 L
.3243 .10586 L
.32561 .10519 L
.32701 .10428 L
.32986 .10215 L
.33125 .10114 L
.33253 .10035 L
.33363 .0998 L
.33479 .09941 L
.33595 .09923 L
.33722 .09929 L
.33852 .09963 L
.33925 .09993 L
.33991 .10028 L
.34241 .10202 L
.34491 .10409 L
.34725 .10583 L
.34842 .10649 L
.34969 .10696 L
.3504 .10711 L
.35109 .10717 L
.35237 .10704 L
.35348 .10669 L
.35465 .10609 L
Mistroke
.35576 .10534 L
.35677 .10453 L
.3591 .10242 L
.36156 .10028 L
.36284 .0994 L
.36352 .09903 L
.36424 .09872 L
.36552 .09841 L
.36671 .09842 L
.36742 .09857 L
.3682 .09884 L
.36894 .09921 L
.36962 .09964 L
.37227 .10192 L
.37479 .1045 L
.37716 .10665 L
.37834 .10745 L
.37963 .10801 L
.38032 .10816 L
.38105 .10821 L
.38235 .10798 L
.38728 .10406 L
.38988 .10105 L
.3913 .09953 L
.39262 .09836 L
.39378 .09761 L
.39503 .09715 L
.39574 .09707 L
.39641 .09711 L
.39767 .09751 L
.39883 .09824 L
.3999 .09918 L
.40232 .10204 L
.4045 .10497 L
.40564 .10643 L
.40685 .1078 L
.40791 .10877 L
.40907 .10952 L
.41013 .10987 L
.41111 .1099 L
.41235 .10951 L
.41348 .10875 L
.41479 .10743 L
.41602 .10584 L
.42047 .09897 L
.42169 .09731 L
.42284 .09606 L
.42403 .09516 L
.42535 .09473 L
.42649 .09487 L
Mistroke
.42753 .09542 L
.42873 .09653 L
.42987 .09802 L
.43243 .10247 L
.43516 .10774 L
.43649 .10998 L
.43774 .11168 L
.43887 .11273 L
.44008 .11328 L
.44129 .11316 L
.44198 .11279 L
.44262 .11225 L
.44391 .11059 L
.4453 .10809 L
.4501 .09656 L
.4515 .0935 L
.45224 .09214 L
.45303 .09096 L
.45372 .09017 L
.45448 .08961 L
.45517 .08938 L
.45582 .08944 L
.45713 .09035 L
.45833 .09214 L
.45965 .09506 L
.46103 .09903 L
.46339 .10705 L
.46594 .11568 L
.46711 .11891 L
.46834 .12145 L
.4694 .12271 L
.47057 .12297 L
.47126 .12253 L
.4719 .12171 L
.47263 .12028 L
.47332 .11843 L
.47456 .11406 L
.4759 .10788 L
.47845 .09348 L
.48076 .08001 L
.4819 .07427 L
.48313 .06946 L
.4843 .06674 L
.48537 .06619 L
.48651 .06804 L
.48776 .07331 L
.48906 .08278 L
.49028 .09546 L
.49251 .12844 L
.49455 .16874 L
Mistroke
.49912 .28464 L
.50393 .41383 L
.50657 .47258 L
.50786 .49601 L
.50905 .51394 L
.51005 .52639 L
.51115 .53706 L
.51225 .54477 L
.51341 .54976 L
.51462 .55183 L
.5159 .55097 L
.51712 .54774 L
.51822 .5432 L
.52335 .51408 L
.52476 .50695 L
.52553 .50363 L
.52624 .50097 L
.52751 .49744 L
.52819 .49619 L
.52891 .49535 L
.5302 .4951 L
.53094 .49563 L
.53161 .49652 L
.53286 .49903 L
.53418 .5027 L
.53899 .51908 L
.54035 .52296 L
.54161 .52578 L
.54293 .52774 L
.54363 .52834 L
.54437 .52864 L
.54501 .52862 L
.5457 .52832 L
.54696 .52708 L
.54819 .52513 L
.54932 .52282 L
.55187 .5166 L
.55462 .51012 L
.55543 .50855 L
.5562 .50728 L
.55694 .50627 L
.55764 .50555 L
.55829 .50507 L
.55899 .50478 L
.55976 .50473 L
.56046 .50492 L
.56173 .5058 L
.56289 .50715 L
.56416 .50911 L
.56551 .51156 L
Mistroke
.5678 .51602 L
.57026 .52021 L
.57095 .52112 L
.5716 .52186 L
.57282 .52285 L
.57397 .52328 L
.57522 .52319 L
.57587 .52292 L
.57659 .52246 L
.57734 .5218 L
.57804 .52105 L
.58065 .51736 L
.58292 .51376 L
.58417 .51193 L
.58535 .51045 L
.58602 .50974 L
.58674 .50911 L
.58801 .50836 L
.58929 .50811 L
.59048 .50833 L
.59172 .50899 L
.59288 .50996 L
.59551 .51308 L
.59824 .51672 L
.59958 .51831 L
.60083 .51952 L
.60191 .5203 L
.60306 .52081 L
.60434 .52096 L
.60549 .52074 L
.60655 .52024 L
.60769 .51943 L
.60975 .5174 L
.61215 .51463 L
.61346 .51315 L
.61471 .51191 L
.61587 .51098 L
.61713 .51025 L
.61828 .5099 L
.61934 .50984 L
.62047 .51006 L
.62153 .51052 L
.6227 .51127 L
.62396 .51232 L
.62886 .51719 L
.63024 .51829 L
.63152 .51906 L
.63217 .51934 L
.63286 .51954 L
.63362 .51965 L
Mistroke
.63432 .51964 L
.63555 .51939 L
.63625 .51912 L
.63689 .51879 L
.63806 .51803 L
.63931 .51704 L
.6418 .51478 L
.64415 .51276 L
.64546 .51188 L
.64619 .51149 L
.64687 .51121 L
.64807 .51091 L
.64935 .51089 L
.65002 .511 L
.65075 .5112 L
.65206 .51179 L
.65282 .51225 L
.65362 .5128 L
.65506 .51391 L
.6578 .51618 L
.65914 .51717 L
.66039 .51792 L
.66155 .51843 L
.66278 .51875 L
.66401 .51881 L
.66472 .51873 L
.66538 .51858 L
.66652 .51817 L
.66756 .51764 L
.66991 .51605 L
.67241 .51416 L
.67373 .51325 L
.67514 .51244 L
.67583 .51213 L
.67649 .51189 L
.67771 .51161 L
.67886 .51156 L
.6801 .51173 L
.68125 .51209 L
.68232 .51257 L
.68475 .51406 L
.68732 .51585 L
.68844 .51657 L
.68966 .51725 L
.6908 .51774 L
.69184 .51805 L
.69284 .51821 L
.69391 .51822 L
.69502 .51806 L
.69607 .51776 L
Mistroke
.69722 .51728 L
.69846 .51663 L
.70309 .51373 L
.70442 .51302 L
.70568 .51251 L
.70681 .5122 L
.70804 .51206 L
.70869 .51206 L
.70941 .51213 L
.71016 .51227 L
.71086 .51246 L
.71212 .51294 L
.71346 .51361 L
.71608 .51515 L
.71851 .51653 L
.71982 .51712 L
.72049 .51736 L
.72122 .51756 L
.72202 .51772 L
.72277 .5178 L
.7235 .5178 L
.72417 .51775 L
.72542 .51752 L
.72612 .5173 L
.72678 .51706 L
.72954 .51571 L
.73204 .51431 L
.73327 .51368 L
.73441 .51318 L
.73571 .51275 L
.7364 .51259 L
.73713 .51248 L
.73831 .51242 L
.73961 .51255 L
.76064 .51496 L
.76312 .51379 L
.76434 .51333 L
.76547 .513 L
.76676 .51277 L
.76745 .51272 L
.76817 .51272 L
.76933 .51282 L
.77062 .51309 L
.77183 .51347 L
.77293 .5139 L
.77541 .51504 L
.77773 .51609 L
.77875 .51649 L
.77988 .51683 L
.78102 .51708 L
Mistroke
.78222 .51721 L
.78353 .51719 L
.78476 .51703 L
.78592 .51675 L
.78698 .51641 L
.78938 .51542 L
.79199 .51427 L
.79327 .51377 L
.79443 .5134 L
.79566 .51312 L
.79697 .51296 L
.79765 .51294 L
.7984 .51297 L
.7991 .51304 L
.79975 .51315 L
.80445 .51474 L
.80704 .51582 L
.80832 .51628 L
.80951 .51663 L
.81061 .51686 L
.81179 .51699 L
.81309 .517 L
.81428 .51688 L
.81536 .51667 L
.81652 .51635 L
.81864 .51559 L
.8211 .51459 L
.82339 .51377 L
.82455 .51346 L
.82578 .51324 L
.82649 .51317 L
.82716 .51313 L
.82841 .51318 L
.82949 .51332 L
.83064 .51356 L
.83163 .51384 L
.83271 .5142 L
.83499 .51507 L
.83739 .51596 L
.83867 .51634 L
.83934 .51651 L
.84006 .51665 L
.84133 .51681 L
.84252 .51684 L
.84323 .5168 L
.844 .51672 L
.84474 .5166 L
.84541 .51646 L
.84804 .51567 L
.85051 .51475 L
Mistroke
.85285 .51396 L
.85415 .51363 L
.85488 .51349 L
.85556 .51339 L
.85675 .5133 L
.85802 .51332 L
.85917 .51345 L
.8604 .51368 L
.86157 .51399 L
.86264 .51432 L
.86507 .51518 L
.86636 .51563 L
.86774 .51605 L
.86893 .51635 L
.87002 .51655 L
.87112 .51667 L
.87215 .5167 L
.87332 .51664 L
.87439 .51649 L
.87557 .51625 L
.87681 .51592 L
.88155 .51435 L
.88291 .51396 L
.88421 .51368 L
.88537 .51351 L
.88664 .51343 L
.88738 .51343 L
.88804 .51347 L
.88881 .51355 L
.88954 .51366 L
.89083 .51394 L
.89223 .51433 L
.89475 .51515 L
.89615 .51559 L
.89746 .51597 L
.89869 .51625 L
.89939 .51638 L
.90003 .51647 L
.90117 .51656 L
.90238 .51656 L
.9035 .51647 L
.90456 .51632 L
.90572 .51607 L
.90697 .51574 L
.90938 .515 L
.91195 .51422 L
.91271 .51403 L
.91343 .51387 L
.91413 .51375 L
.91478 .51366 L
Mistroke
.91604 .51355 L
.9167 .51354 L
.9174 .51356 L
.91872 .51368 L
.91995 .51388 L
.9213 .51419 L
.92276 .5146 L
.92565 .51548 L
.92707 .51587 L
.92839 .51616 L
.92961 .51635 L
.93091 .51645 L
.93165 .51647 L
.93235 .51645 L
.93366 .51633 L
.93486 .51613 L
.93597 .51589 L
.93847 .5152 L
.94078 .51452 L
.94192 .51423 L
.94297 .51399 L
.94417 .51379 L
.94549 .51366 L
.9466 .51364 L
.94778 .51369 L
.94881 .51381 L
.94991 .514 L
.95191 .51446 L
.95646 .51573 L
.95763 .51599 L
.95886 .5162 L
.95958 .51629 L
.96022 .51634 L
.96148 .51637 L
.96279 .51631 L
.96352 .51623 L
.9642 .51613 L
.96545 .5159 L
.96676 .51558 L
.97619 .51372 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002^0?ooo`8000000`3oool0
0`000000oooo0?ooo`2b0?ooo`00[P3oool2000000<0oooo00<000000?ooo`3oool0/P3oool00:d0
oooo00<000000?ooo`0000000`3oool00`000000oooo0?ooo`2b0?ooo`00[@3oool00`000000oooo
000000030?ooo`030000003oool0oooo0;80oooo002]0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0/P3oool00:d0oooo00@000000?ooo`3oool000000P3oool200000;<0oooo
002]0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0/P3oool00:@0oooo0P00
00060?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`2b0?ooo`00Y03o
ool3000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0;80oooo
002J0?ooo`<000001P3oool2000000040?ooo`000000oooo0?ooo`@0000000@04A4A0?ooo`3oool0
00000P3oool00`000000oooo0?ooo`2b0?ooo`00OP3oool3000000H0oooo0`0000060?ooo`@00000
1P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`0000000`3oool20000
00<0oooo00@000000?ooo`3oool00000]03oool001h0oooo1@0000050?ooo`@000001@3oool50000
00D0oooo1@0000050?ooo`@000001@3oool4000000D0oooo1@0000050?ooo`@000001@3oool50000
00D0oooo100000050?ooo`80000000<0oooo000000000000103oool200000080oooo00<000000?oo
o`3oool00`3oool01@000000oooo0?ooo`3oool0000000@0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`H0000000<0oooo0000003oool00P3oool2000000<0oooo00@000000?ooo`3oool00000
]03oool001/0oooo0`0000050?ooo`D00000103oool5000000D0oooo1@0000050?ooo`D00000103o
ool5000000@0oooo1@0000050?ooo`D00000103oool5000000@0oooo1P0000040?ooo`80000000<0
oooo0000000000001@3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`00
00001@3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool00`00002b
0?ooo`00NP3oool2000000L0oooo0`0000060?ooo`<000001P3oool4000000D0oooo00D000000?oo
o`3oool0oooo000000040?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?oo
o`00002d0?ooo`00UP3oool2000000L0oooo00<000000?ooo`0000001@3oool01@000000oooo0?oo
o`3oool0000000@0oooo00@000000?ooo`3oool00000]03oool00:00oooo0P0000060?ooo`040000
003oool0oooo000000D0oooo00<000000?ooo`000000]03oool00:P0oooo00@0000005EEE@1EEED0
00001@3oool00`000000oooo0000002d0?ooo`00Z@3oool2000000H0oooo00<000000?ooo`000000
]03oool00:T0oooo0P0000060?ooo`040000003oool0000000000;<0oooo002a0?ooo`030000003o
ool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool00000
0;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo
002a0?ooo`030000003oool000000;@0oooo002a0?ooo`040000003oool0000000000;<0oooo002a
0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`03
0000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003o
ool000000;@0oooo002a0?ooo`040000003oool0000000000;<0oooo002a0?ooo`030000003oool0
00000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0
oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a
0?ooo`030000003oool000000;@0oooo002a0?ooo`040000003oool0000000000;<0oooo002a0?oo
o`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000
003oool000000;@0oooo002H0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2028R8PD0oooo
00D0A4A4000000000000<c<c0=gMg@040?ooo`800000]03oool009P0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`030?ooo`800000]03oool00900oooo
1P0000020?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`020?ooo`@0
0000/P3oool009P0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo00<0
oooo0P00002d0?ooo`00V03oool01@000000oooo0?ooo`3oool0000000`0oooo00D00000028R8P00
0000<c<c0<c<c0040?ooo`800000]03oool009P0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?oo
o`030000003oool0oooo00H0oooo0P00002d0?ooo`00V03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg
00`0oooo00<000000?ooo`3oool01P3oool200000;@0oooo002H0?ooo`050>k^kP0c<c<0000003<c
<`3^k^h0303oool4000000D0oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`<00000
/`3oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000]03oool00;80
oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`<00000/`3oool00;80oooo0P00002d
0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000]03oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
01d0oooo100000000`0A4A40oooo0?ooo`0l0?ooo`050>k^kP0c<c<0000003<c<`3^k^h01@3oool2
028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@0m0?ooo`800000?`3oool01@3^k^h0<c<c0000
000c<c<0k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0?`3oool400000003
014A4@3oool0oooo01P0oooo000O0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0
VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`0l0?ooo`030000003oool0oooo03h0
oooo00D0MgMg09VIV@3oool0VIVI07MgM`050?ooo`808R8R203oool00`1gMgL0<c<c0?ooo`100?oo
o`030000003oool0oooo01X0oooo000D0?ooo`H000001@3oool00`000000oooo0?ooo`0f0?ooo`H0
00000P3oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3oool0>`3oool00`00
0000oooo0?ooo`0n0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo01X0oooo000O0?ooo`030000003oool0oooo03h0oooo00D000000?oo
o`3oool0oooo0000000?0?ooo`0307MgM`0c<c<0oooo03`0oooo00<000000?ooo`3oool0?P3oool0
1@000000oooo0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0@03oool00`000000oooo0?oo
o`0J0?ooo`007`3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0oooo0?ooo`000000303o
ool01@0000008R8R0000000c<c<0c<c<03d0oooo00<000000?ooo`3oool0?P3oool01@000000oooo
0?ooo`3oool0000000`0oooo00D00000028R8P000000<c<c0<c<c0110?ooo`030000003oool0oooo
01X0oooo000O0?ooo`030000003oool0oooo03h0oooo00D04A4A0?ooo`3oool0oooo014A4@0<0?oo
o`030000003oool0oooo03l0oooo00<000000?ooo`3oool0?P3oool01@0A4A40oooo0?ooo`3oool0
4A4A00`0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0J0?ooo`007`3oool00`00
0000oooo0?ooo`0n0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`0o
0?ooo`030000003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003o
ool0oooo04<0oooo00<000000?ooo`3oool06P3oool001d0oooo0P1EEED00`000000oooo0?ooo`0n
0?ooo`050>k^kP0c<c<0000003<c<`3^k^h0303oool4000003h0oooo0P00000o0?ooo`050>k^kP0c
<c<0000003<c<`3^k^h0303oool400000400oooo0P1EEED00`000000oooo0?ooo`0J0?ooo`00/`3o
ool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`00
0000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00503ooooo0000040000005@3oool001/0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01X0oooo000K0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool0B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool06P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0
oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?oo
o`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3o
ool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo
0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?oo
o`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool009P0oooo00D0k^k^03<c<`000000<c<c
0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00D0oooo0P00002c0?ooo`00
V03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo00@0
oooo0P00002c0?ooo`00V03oool01@0A4A40oooo0?ooo`3oool04A4A0100oooo00<000000?ooo`3o
ool00`3oool200000;<0oooo002H0?ooo`050000003oool0oooo0?ooo`0000003`3oool00`1gMgL0
<c<c0?ooo`040?ooo`<00000/P3oool009P0oooo00D000000?ooo`3oool0oooo0000000<0?ooo`05
0000000R8R80000003<c<`3<c<`01@3oool200000;<0oooo002H0?ooo`05014A4@3oool0oooo0?oo
o`0A4A40303oool00`000000oooo0?ooo`070?ooo`800000/`3oool009P0oooo00D0MgMg09VIV@3o
ool0VIVI07MgM`0<0?ooo`030000003oool0oooo00L0oooo0P00002c0?ooo`00V03oool01@3^k^h0
<c<c0000000c<c<0k^k^00`0oooo100000060?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00
/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool20000
0;<0oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`000000/P3oool00;<0oooo00<0
00000?ooo`000000/P3oool00;<0oooo0`00002b0?ooo`00/`3oool00`000000oooo0000002b0?oo
o`00/`3oool00`000000oooo0000002b0?ooo`00/`3oool00`000000oooo0000002b0?ooo`00/`3o
ool00`000000oooo0000002b0?ooo`00/`3oool00`000000oooo0000002b0?ooo`00/`3oool00`00
0000oooo0000002b0?ooo`00/`3oool300000;80oooo002c0?ooo`030000003oool000000;80oooo
002c0?ooo`030000003oool000000;80oooo002c0?ooo`030000003oool000000;80oooo002c0?oo
o`040000003oool0oooo00000;40oooo002c0?ooo`040000003oool0oooo00000;40oooo002c0?oo
o`80000000<0oooo0000003oool0103oool200000:X0oooo002c0?ooo`040000003oool0oooo0000
00D0oooo0P00002Z0?ooo`00/`3oool010000000oooo0?ooo`0000040?ooo`030000003oool00000
0:X0oooo002c0?ooo`040000003oool0oooo000000@0oooo00@000000?ooo`3oool000001`3oool0
0`000000oooo0?ooo`2O0?ooo`00Z@3oool400000003014A4@3oool0oooo00<0oooo00@000000?oo
o`3oool00000103oool010000000oooo0?ooo`0000060?ooo`<00000X03oool00:/0oooo00<00000
0?ooo`3oool01@3oool010000000oooo0?ooo`0000040?ooo`040000003oool0oooo000000D0oooo
0P0000000`3oool000000?ooo`050?ooo`@000001P3oool3000000L0oooo0P0000240?ooo`00Z`3o
ool00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool200000080
oooo00<000000?ooo`3oool00`3oool2000000030?ooo`000000000000D0oooo100000050?ooo`D0
0000103oool5000000D0oooo1`0000030?ooo`@000001@3oool4000000H0oooo100000050?ooo`@0
00001P3oool3000000H0oooo100000060?ooo`<000001`3oool2000001`0oooo002[0?ooo`030000
003oool0oooo00D0oooo100000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000103oool010000000
oooo0?ooo`3oool2000000@0oooo00<000000?ooo`3oool00P0000040?ooo`8000000P3oool00`00
0000oooo0?ooo`030?ooo`040000003oool0oooo000000D0oooo0P0000000`3oool0000000000007
0?ooo`<00000103oool5000000@0oooo1P0000040?ooo`H000000`3oool6000000<0oooo1P000004
0?ooo`H000000`3oool7000001h0oooo002[0?ooo`030000003oool0oooo00D0oooo00@000000?oo
o`3oool000000`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`0000001P3o
ool4000000H0oooo0`0000070?ooo`8000001`3oool3000006`0oooo002[0?ooo`030000003oool0
oooo00D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`030?ooo`040000003o
ool0oooo000000H0oooo0`0000070?ooo`800000TP3oool00:/0oooo00<000000?ooo`3oool01@3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`000000
Y@3oool00:T0oooo0P1EEED00`000000oooo0?ooo`050?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool0103oool200000:D0oooo002c0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0[03oool00;<0oooo0P0000020?ooo`030000003oool000000:h0oooo002c
0?ooo`070000003oool0oooo0?ooo`000000oooo0000002^0?ooo`00/`3oool01`000000oooo0?oo
o`3oool000000?ooo`000000[P3oool00;<0oooo00L000000?ooo`3oool0oooo0000003oool00000
0:h0oooo002c0?ooo`040000003oool0oooo0?ooo`800000[`3oool00;<0oooo00@000000?ooo`3o
ool0oooo0P00002_0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo
00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00V@3oool4
00000003014A4@3oool0oooo0080oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3o
ool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000oooo0?ooo`040?ooo`808R8R203oool0
0`1gMgL0<c<c0?ooo`040?ooo`030000003oool0oooo0;80oooo002K0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`2b0?ooo`00V`3oool00`000000
oooo0?ooo`0>0?ooo`0307MgM`0c<c<0oooo00@0oooo0`00002b0?ooo`00V`3oool00`000000oooo
0?ooo`0;0?ooo`050000000R8R80000003<c<`3<c<`0^P3oool009/0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`2l0?ooo`00V`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo0;`0oooo002I0?ooo`80EEEE00<000000?ooo`3oool02`3oool400000;/0oooo003o0?oo
ofT0oooo003o0?ooofT0oooo003o0?ooofT0oooo002M0?ooo`80000000H04A4A0?ooo`3oool04A4A
0000000A4A4H0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`0000004A4A0<c<c9l0oooo002N
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01`3oool6000000`0oooo00<00000
0?ooo`3oool00P3oool01@1EEED0MgMg0?ooo`2IVIT08R8R09l0oooo002N0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`020?ooo`050000003oool0
oooo0?ooo`000000W`3oool009h0oooo00H000000?ooo`14A4@0<c<c0?ooo`0000090?ooo`H00000
303oool00`000000oooo0?ooo`020?ooo`050000002IVIT0oooo09VIV@0R8R80W`3oool009h0oooo
00H000000=gMg@0c<c<0EEEE0=gMg@00000K0?ooo`030000003oool0oooo0080oooo00D0000005EE
E@0000004A4A0<c<c02O0?ooo`00WP3oool01P000000R8R80:ZZZP2k^k/0EEEE000001/0oooo00<0
00000?ooo`3oool00P3oool00`1EEED0R8R80?ooo`2Q0?ooo`00WP3oool01P000000<c<c0?ooo`3o
ool0<c<c000001/0oooo00<000000?ooo`3oool00P3oool00`3MgMd04A4A09VIV@2Q0?ooo`00W@3o
ool00`0A4A40000008R8R0020?ooo`0308R8R00000004A4A01P0oooo0P1EEED00`000000oooo0?oo
o`030?ooo`040<c<c014A4@00000014A4Il0oooo003o0?ooofT0oooo003o0?ooofT0oooo003o0?oo
ofT0oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.476191 0.309017 0.206011 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.2619 .29652 -12 -9 ]
[.2619 .29652 12 0 ]
[.7381 .29652 -9 -9 ]
[.7381 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .10301 -12 -4.5 ]
[.4875 .10301 0 4.5 ]
[.4875 .20601 -24 -4.5 ]
[.4875 .20601 0 4.5 ]
[.4875 .41202 -18 -4.5 ]
[.4875 .41202 0 4.5 ]
[.4875 .51503 -6 -4.5 ]
[.4875 .51503 0 4.5 ]
[.4875 .61803 -18 -4.5 ]
[.4875 .61803 0 4.5 ]
[.5 .63053 -20 0 ]
[.5 .63053 20 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-1)] .02381 .29652 0 1 Mshowa
.2619 .30902 m
.2619 .31527 L
s
[(-0.5)] .2619 .29652 0 1 Mshowa
.7381 .30902 m
.7381 .31527 L
s
[(0.5)] .7381 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(1)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.21429 .30902 m
.21429 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.59524 .30902 m
.59524 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.5 0 m
.50625 0 L
s
[(-1.5)] .4875 0 1 0 Mshowa
.5 .10301 m
.50625 .10301 L
s
[(-1)] .4875 .10301 1 0 Mshowa
.5 .20601 m
.50625 .20601 L
s
[(-0.5)] .4875 .20601 1 0 Mshowa
.5 .41202 m
.50625 .41202 L
s
[(0.5)] .4875 .41202 1 0 Mshowa
.5 .51503 m
.50625 .51503 L
s
[(1)] .4875 .51503 1 0 Mshowa
.5 .61803 m
.50625 .61803 L
s
[(1.5)] .4875 .61803 1 0 Mshowa
.125 Mabswid
.5 .0206 m
.50375 .0206 L
s
.5 .0412 m
.50375 .0412 L
s
.5 .0618 m
.50375 .0618 L
s
.5 .0824 m
.50375 .0824 L
s
.5 .12361 m
.50375 .12361 L
s
.5 .14421 m
.50375 .14421 L
s
.5 .16481 m
.50375 .16481 L
s
.5 .18541 m
.50375 .18541 L
s
.5 .22661 m
.50375 .22661 L
s
.5 .24721 m
.50375 .24721 L
s
.5 .26781 m
.50375 .26781 L
s
.5 .28842 m
.50375 .28842 L
s
.5 .32962 m
.50375 .32962 L
s
.5 .35022 m
.50375 .35022 L
s
.5 .37082 m
.50375 .37082 L
s
.5 .39142 m
.50375 .39142 L
s
.5 .43262 m
.50375 .43262 L
s
.5 .45322 m
.50375 .45322 L
s
.5 .47383 m
.50375 .47383 L
s
.5 .49443 m
.50375 .49443 L
s
.5 .53563 m
.50375 .53563 L
s
.5 .55623 m
.50375 .55623 L
s
.5 .57683 m
.50375 .57683 L
s
.5 .59743 m
.50375 .59743 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(M) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .10405 m
.04262 .10328 L
.04376 .10359 L
.04498 .10385 L
.04561 .10395 L
.04631 .10404 L
.04754 .1041 L
.0487 .10406 L
.04995 .1039 L
.05112 .10367 L
.0522 .10339 L
.05495 .1026 L
.0563 .10226 L
.05756 .10202 L
.05869 .1019 L
.0599 .10188 L
.06058 .10192 L
.06123 .10199 L
.06244 .1022 L
.06488 .10284 L
.06745 .10358 L
.06879 .1039 L
.06955 .10403 L
.07026 .10411 L
.07151 .10416 L
.07222 .10414 L
.07286 .10408 L
.07409 .10389 L
.07524 .10362 L
.07784 .10285 L
.07894 .10252 L
.08011 .10222 L
.08138 .10197 L
.08255 .10184 L
.0838 .10182 L
.08451 .10187 L
.08517 .10195 L
.08636 .10218 L
.08763 .10251 L
.09032 .10334 L
.09173 .10375 L
.09251 .10393 L
.09323 .10407 L
.09399 .10417 L
.09482 .10423 L
.09553 .10423 L
.09629 .10419 L
.09707 .10409 L
.0978 .10396 L
.09918 .10362 L
Mistroke
.10196 .10274 L
.10333 .10233 L
.10458 .10202 L
.10576 .10182 L
.107 .10174 L
.10825 .10179 L
.10896 .10188 L
.10962 .102 L
.11078 .10228 L
.11183 .1026 L
.11419 .10339 L
.11541 .10376 L
.11671 .10407 L
.11739 .10419 L
.11814 .10427 L
.11945 .1043 L
.12069 .10419 L
.12138 .10407 L
.12202 .10393 L
.12442 .10319 L
.1265 .10248 L
.12764 .10214 L
.12871 .10189 L
.12998 .1017 L
.13114 .10166 L
.13222 .10173 L
.13339 .10193 L
.13453 .10222 L
.13578 .10262 L
.1383 .10351 L
.13943 .10387 L
.14064 .10417 L
.14178 .10434 L
.14282 .1044 L
.144 .10433 L
.1451 .10416 L
.14632 .10385 L
.14762 .10343 L
.15011 .10252 L
.15146 .10208 L
.15272 .10177 L
.15382 .10161 L
.155 .10157 L
.15631 .10169 L
.1575 .10193 L
.15858 .10224 L
.15976 .10266 L
.16189 .10347 L
.16309 .10388 L
.16438 .10423 L
Mistroke
.16512 .10437 L
.1658 .10446 L
.16648 .10449 L
.16713 .10449 L
.16779 .10443 L
.1685 .10432 L
.16978 .10402 L
.1713 .1035 L
.17268 .10296 L
.17514 .10205 L
.17582 .10185 L
.17653 .10168 L
.17781 .10149 L
.179 .10147 L
.18011 .10159 L
.18133 .10185 L
.18264 .10227 L
.1852 .10331 L
.18661 .10385 L
.18793 .10426 L
.18905 .1045 L
.19026 .10461 L
.19091 .1046 L
.19159 .10454 L
.19282 .10431 L
.1956 .10334 L
.19712 .10269 L
.19856 .10211 L
.1999 .10168 L
.20066 .10151 L
.20135 .1014 L
.20259 .10134 L
.20389 .10147 L
.20503 .10173 L
.20626 .10214 L
.20847 .10309 L
.21088 .10409 L
.21154 .10431 L
.21224 .1045 L
.21351 .10471 L
.21427 .10474 L
.21499 .10471 L
.21563 .10464 L
.21633 .1045 L
.21701 .10431 L
.21772 .10407 L
.219 .10355 L
.22158 .10236 L
.22285 .10185 L
.22402 .10148 L
Mistroke
.22518 .10126 L
.22641 .10119 L
.22764 .10132 L
.22834 .10148 L
.229 .10167 L
.23118 .10257 L
.23353 .1037 L
.23483 .10425 L
.23552 .10448 L
.23626 .10468 L
.23696 .10482 L
.2376 .10489 L
.23885 .10487 L
.24005 .10465 L
.24135 .10424 L
.24258 .10371 L
.24371 .10315 L
.24576 .10212 L
.24689 .10164 L
.24796 .1013 L
.24923 .10106 L
.25038 .10103 L
.25146 .10116 L
.25263 .10148 L
.25497 .10252 L
.2575 .10385 L
.25866 .10438 L
.25988 .1048 L
.26092 .10502 L
.26206 .10509 L
.26329 .10495 L
.26441 .10465 L
.26571 .10412 L
.26693 .10349 L
.26913 .10226 L
.27033 .10166 L
.27146 .10122 L
.27269 .1009 L
.27334 .10083 L
.27404 .10081 L
.27529 .10098 L
.27643 .10132 L
.27712 .1016 L
.27776 .10191 L
.2792 .10271 L
.28183 .10422 L
.28315 .10482 L
.28389 .10506 L
.28458 .10522 L
.28584 .10532 L
Mistroke
.28647 .10528 L
.28717 .10515 L
.28837 .10477 L
.28967 .10416 L
.292 .10275 L
.2934 .10191 L
.29413 .10151 L
.29491 .10115 L
.29559 .10089 L
.29634 .10069 L
.29703 .10058 L
.29767 .10055 L
.29897 .10071 L
.30016 .10109 L
.30146 .10172 L
.30283 .10257 L
.30541 .10424 L
.30668 .10492 L
.30785 .10536 L
.30891 .10558 L
.31003 .10559 L
.31116 .10537 L
.3124 .10489 L
.31732 .10168 L
.318 .10128 L
.31874 .10089 L
.31939 .10062 L
.32008 .1004 L
.32139 .10023 L
.3226 .10036 L
.32372 .10072 L
.32493 .10135 L
.32712 .10287 L
.32954 .10463 L
.33077 .10533 L
.33146 .10563 L
.3321 .10583 L
.33327 .10598 L
.33434 .10588 L
.33557 .10548 L
.33673 .10485 L
.34098 .10159 L
.34213 .10081 L
.34336 .10018 L
.34453 .09985 L
.3456 .09981 L
.34684 .10008 L
.34755 .10038 L
.3482 .10074 L
.35068 .10264 L
Mistroke
.35191 .10372 L
.35324 .10482 L
.3545 .10568 L
.35566 .10622 L
.3563 .10639 L
.35701 .10648 L
.35775 .10644 L
.35844 .10628 L
.35966 .10573 L
.36096 .10483 L
.36333 .10268 L
.36459 .10151 L
.36592 .10042 L
.36707 .09972 L
.36835 .09928 L
.36952 .09925 L
.37061 .09954 L
.37168 .10011 L
.37282 .10098 L
.37484 .10296 L
.37703 .10517 L
.37826 .10618 L
.3794 .10683 L
.38065 .10716 L
.38128 .10716 L
.38198 .10702 L
.38323 .10643 L
.38441 .10552 L
.38674 .10305 L
.38895 .10058 L
.39018 .09947 L
.39088 .09899 L
.39152 .09866 L
.39266 .09838 L
.39387 .09854 L
.39455 .09884 L
.3953 .09932 L
.39664 .10055 L
.39915 .10363 L
.40031 .1051 L
.40156 .10649 L
.40274 .10749 L
.40381 .10804 L
.40501 .1082 L
.40615 .10786 L
.40739 .10698 L
.40808 .10629 L
.40872 .10553 L
.41108 .10224 L
.41224 .10058 L
Mistroke
.41332 .09919 L
.41429 .09818 L
.41532 .09743 L
.41647 .09707 L
.41752 .09722 L
.41867 .09789 L
.41991 .09918 L
.42109 .10081 L
.42217 .10256 L
.42455 .10649 L
.42521 .10744 L
.42591 .10832 L
.42717 .10946 L
.42836 .10991 L
.42948 .10973 L
.43048 .10905 L
.43157 .10779 L
.43275 .10596 L
.43399 .10364 L
.43623 .09924 L
.43741 .09722 L
.43866 .09565 L
.43931 .09511 L
.44002 .09478 L
.44128 .09491 L
.44247 .09587 L
.44374 .09773 L
.44493 .10013 L
.44602 .10266 L
.44869 .10897 L
.44942 .11042 L
.4502 .11169 L
.45086 .11251 L
.45159 .11309 L
.4529 .11322 L
.45363 .11275 L
.4543 .11197 L
.45561 .10959 L
.45684 .10645 L
.45944 .09849 L
.46071 .09476 L
.46188 .09196 L
.46295 .09021 L
.46407 .08939 L
.4652 .08978 L
.46644 .09166 L
.46713 .09332 L
.46778 .09527 L
.469 .09971 L
.47174 .11156 L
Mistroke
.47288 .11618 L
.4741 .1201 L
.47474 .12156 L
.47544 .12262 L
.47667 .12286 L
.47783 .121 L
.47906 .11684 L
.4801 .11163 L
.48124 .10449 L
.48362 .08704 L
.48493 .07787 L
.48616 .07094 L
.48732 .06696 L
.48858 .06648 L
.48972 .07031 L
.49078 .07795 L
.49177 .08904 L
.49286 .10575 L
.49507 .15352 L
.49985 .30372 L
.50237 .3893 L
.50375 .43208 L
.50506 .46758 L
.5063 .49617 L
.50764 .52049 L
.50886 .53643 L
.50998 .54595 L
.51103 .55075 L
.51219 .55178 L
.5134 .54892 L
.51453 .54347 L
.51725 .5245 L
.51981 .50692 L
.5205 .50324 L
.52123 .50003 L
.52203 .49739 L
.52277 .49582 L
.52405 .49505 L
.52478 .49567 L
.52546 .49687 L
.52674 .50052 L
.52797 .50521 L
.53026 .51525 L
.53146 .5201 L
.53273 .52434 L
.53347 .52619 L
.53413 .52743 L
.53543 .52862 L
.53663 .52826 L
.53776 .52676 L
Mistroke
.53899 .52407 L
.54031 .52033 L
.54295 .51216 L
.54425 .50876 L
.54545 .50642 L
.54657 .50512 L
.54776 .50472 L
.54896 .50535 L
.55028 .50709 L
.55137 .50919 L
.55255 .51189 L
.55468 .51703 L
.5559 .51962 L
.5572 .52175 L
.55795 .52259 L
.55863 .52308 L
.55932 .5233 L
.55997 .52326 L
.56064 .52296 L
.56136 .52237 L
.56264 .52074 L
.56402 .51834 L
.56554 .51534 L
.56681 .51287 L
.56802 .51083 L
.56868 .5099 L
.56941 .50909 L
.57068 .50824 L
.57189 .50816 L
.57318 .50883 L
.57439 .51008 L
.57549 .51161 L
.57802 .5158 L
.57926 .51774 L
.58038 .51921 L
.58157 .52033 L
.58284 .52092 L
.58351 .52096 L
.58423 .5208 L
.58554 .52 L
.58665 .51888 L
.58787 .51731 L
.59034 .51374 L
.59144 .5123 L
.59263 .51104 L
.59375 .51023 L
.59478 .50987 L
.59599 .50993 L
.59729 .51056 L
.59852 .51162 L
Mistroke
.59963 .51286 L
.60239 .51636 L
.6036 .51773 L
.60429 .51838 L
.60493 .51888 L
.60621 .51952 L
.60687 .51964 L
.60757 .51963 L
.60834 .51943 L
.60906 .51908 L
.60972 .51864 L
.61043 .51805 L
.61292 .51538 L
.61423 .51389 L
.61561 .5125 L
.61681 .51158 L
.61813 .51098 L
.61933 .51087 L
.62045 .51114 L
.6216 .51176 L
.62264 .51257 L
.62499 .5149 L
.62623 .51617 L
.62755 .51736 L
.62823 .51787 L
.62899 .51831 L
.62968 .5186 L
.63032 .51876 L
.63159 .51876 L
.63275 .5184 L
.63339 .51807 L
.63408 .51761 L
.63536 .51658 L
.63807 .51403 L
.6394 .51292 L
.64063 .51215 L
.64132 .51184 L
.64204 .51163 L
.64277 .51156 L
.64358 .51162 L
.64424 .51178 L
.64496 .51207 L
.64625 .51284 L
.64877 .51491 L
.65115 .51686 L
.65234 .51759 L
.65362 .51809 L
.65432 .51821 L
.65505 .51823 L
.65635 .51796 L
Mistroke
.65766 .51735 L
.65888 .51655 L
.66164 .51435 L
.66286 .51345 L
.66401 .51276 L
.66464 .51247 L
.66533 .51223 L
.66653 .51205 L
.66722 .51208 L
.66787 .5122 L
.66857 .51242 L
.66933 .51275 L
.67088 .51368 L
.6723 .51472 L
.67363 .51572 L
.67505 .51668 L
.67574 .51706 L
.67639 .51736 L
.67761 .51772 L
.67884 .5178 L
.67998 .51762 L
.68123 .51716 L
.68255 .51643 L
.68533 .51451 L
.68669 .51363 L
.68793 .51299 L
.68909 .51259 L
.69019 .51243 L
.69135 .51249 L
.69261 .51282 L
.6939 .5134 L
.69527 .51422 L
.69773 .51583 L
.69893 .51652 L
.70025 .5171 L
.70149 .51741 L
.70264 .51748 L
.70378 .51732 L
.70481 .517 L
.70601 .51645 L
.70713 .51582 L
.7095 .51435 L
.71079 .51364 L
.71199 .51313 L
.7133 .51279 L
.71399 .51272 L
.71473 .51273 L
.71605 .51296 L
.71725 .51338 L
.72175 .51586 L
Mistroke
.72298 .51648 L
.72429 .51695 L
.72541 .51718 L
.72665 .51721 L
.7278 .51703 L
.72885 .51671 L
.73001 .51621 L
.73124 .51557 L
.7333 .51442 L
.73439 .51387 L
.73555 .5134 L
.73618 .5132 L
.73688 .51305 L
.73812 .51294 L
.73937 .51306 L
.74054 .51336 L
.74169 .5138 L
.74273 .5143 L
.74508 .51555 L
.7463 .51613 L
.74758 .51662 L
.74833 .51682 L
.749 .51695 L
.75031 .51701 L
.75154 .51685 L
.75223 .51668 L
.75287 .51648 L
.75528 .5154 L
.75733 .51437 L
.75847 .51387 L
.75954 .51349 L
.7608 .51321 L
.76195 .51313 L
.76304 .51322 L
.76421 .51347 L
.76534 .51385 L
.76659 .51439 L
.76911 .5156 L
.77024 .51609 L
.77145 .5165 L
.77259 .51675 L
.77364 .51684 L
.77492 .51677 L
.77613 .51651 L
.77721 .51616 L
.77839 .51568 L
.78085 .51455 L
.7822 .51399 L
.78346 .51359 L
.78455 .51337 L
Mistroke
.78572 .51329 L
.78702 .51339 L
.78821 .51365 L
.78929 .514 L
.79046 .51447 L
.79259 .51542 L
.79378 .5159 L
.79506 .51633 L
.7958 .51651 L
.79647 .51662 L
.79712 .51668 L
.7978 .5167 L
.79846 .51666 L
.79917 .51656 L
.80044 .51626 L
.80122 .516 L
.80196 .51573 L
.80334 .51515 L
.80566 .5142 L
.80683 .51382 L
.80812 .51353 L
.80879 .51345 L
.80951 .51342 L
.81081 .51351 L
.81211 .51378 L
.8133 .51415 L
.81575 .51512 L
.81806 .516 L
.81934 .51635 L
.82007 .51647 L
.82073 .51655 L
.8219 .51656 L
.82315 .51642 L
.82423 .51617 L
.8254 .51581 L
.8275 .515 L
.82871 .51453 L
.82999 .51409 L
.83108 .51379 L
.83229 .51359 L
.83295 .51355 L
.83366 .51354 L
.83495 .51367 L
.83569 .51382 L
.83647 .51402 L
.83785 .51447 L
.84059 .5155 L
.84192 .51595 L
.84313 .51625 L
.8443 .51642 L
Mistroke
.84541 .51647 L
.84658 .51638 L
.84785 .51614 L
.84915 .51577 L
.85053 .51529 L
.85301 .51439 L
.85422 .51403 L
.85554 .51376 L
.85679 .51364 L
.85794 .51367 L
.85909 .51382 L
.86012 .51404 L
.86132 .5144 L
.86245 .51478 L
.86482 .51561 L
.86611 .51599 L
.86732 .51624 L
.86863 .51637 L
.86932 .51637 L
.87007 .51633 L
.87139 .51613 L
.87259 .51583 L
.87478 .51512 L
.8771 .51435 L
.87831 .51403 L
.879 .51389 L
.87964 .5138 L
.88078 .51373 L
.882 .51377 L
.88308 .51392 L
.88426 .51419 L
.88665 .51493 L
.88886 .51565 L
.88983 .51591 L
.8909 .51613 L
.89214 .51627 L
.89345 .51628 L
.89413 .51622 L
.89487 .51612 L
.89557 .51598 L
.8962 .51583 L
.8986 .51511 L
.89986 .5147 L
.9012 .51431 L
.90239 .51403 L
.9037 .51385 L
.90488 .5138 L
.906 .51387 L
.90714 .51403 L
.90819 .51427 L
Mistroke
.91055 .51497 L
.91291 .51568 L
.91423 .51598 L
.91543 .51616 L
.91611 .51621 L
.91685 .51622 L
.91754 .51619 L
.91819 .51613 L
.91944 .51592 L
.92007 .51577 L
.92076 .51559 L
.92344 .51479 L
.92491 .51437 L
.92564 .5142 L
.92632 .51407 L
.92761 .51391 L
.9283 .51387 L
.92903 .51388 L
.93034 .51399 L
.93152 .5142 L
.9364 .51556 L
.93758 .51584 L
.93886 .51605 L
.93959 .51613 L
.94025 .51615 L
.94155 .51611 L
.94273 .51596 L
.94382 .51575 L
.94629 .51508 L
.94845 .51447 L
.94967 .5142 L
.95078 .51403 L
.95199 .51394 L
.95326 .51396 L
.95437 .51408 L
.95558 .5143 L
.95691 .51462 L
.95833 .51502 L
.95966 .51539 L
.96088 .51569 L
.96154 .51583 L
.96227 .51595 L
.963 .51604 L
.96377 .51609 L
.96445 .5161 L
.96518 .51607 L
.9665 .51592 L
.96716 .51581 L
.96787 .51566 L
.96917 .51533 L
Mistroke
.97161 .51466 L
.97275 .51439 L
.97383 .51418 L
.97507 .51403 L
.97619 .51398 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.2197,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00V@3oool400000003014A4@3oool0oooo0080oooo
0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd0^P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0^@3oool00900oooo1P0000050?ooo`030000003o
ool0oooo00l0oooo00<000000?ooo`3oool0^03oool009/0oooo00<000000?ooo`3oool03P3oool0
0`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool009/0oooo00<000000?ooo`3oool02`3oool01@00
00008R8R0000000c<c<0c<c<00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?oo
o`3oool02`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0;80oooo002K0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`2b0?ooo`00
V@3oool205EEE@030000003oool0oooo00/0oooo100000060?ooo`030000003oool0oooo0;80oooo
002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<000000?oo
o`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0
/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00
/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002_0?ooo`050000003oool0
oooo0?ooo`000000]03oool00:l0oooo0P0000020?ooo`030000003oool0oooo0;80oooo002_0?oo
o`8000000P3oool00`000000oooo0?ooo`2b0?ooo`00[P3oool00`000000oooo000000020?ooo`03
0000003oool0oooo0;80oooo002^0?ooo`030000003oool000000080oooo00<000000?ooo`3oool0
/P3oool00:h0oooo00<000000?ooo`0000000P3oool200000;<0oooo002^0?ooo`030000003oool0
00000080oooo00<000000?ooo`3oool0/P3oool00:L0oooo0P0000050?ooo`030000003oool00000
0080oooo00<000000?ooo`3oool0/P3oool00:L0oooo0`0000040?ooo`030000003oool000000080
oooo00<000000?ooo`3oool0/P3oool009l0oooo0`0000040?ooo`030000003oool0oooo00@00000
00@04A4A0000003oool000000P3oool00`000000oooo0?ooo`2b0?ooo`00R@3oool2000000D0oooo
0`0000040?ooo`@00000103oool00`000000oooo000000040?ooo`080000003oool0oooo0000003o
ool000000?ooo`0000030?ooo`030000003oool000000;@0oooo000U0?ooo`@00000103oool40000
00<0oooo100000040?ooo`@00000103oool4000000@0oooo0`0000040?ooo`<00000103oool40000
00@0oooo100000030?ooo`D000000`3oool4000000<0oooo100000040?ooo`@000000`3oool20000
00030?ooo`000000000000@0oooo00<000000?ooo`000000103oool010000000oooo0?ooo`000004
0?ooo`P000000P3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`000000]03o
ool001/0oooo2P0000040?ooo`@00000103oool3000000@0oooo100000040?ooo`@000000`3oool5
000000<0oooo100000030?ooo`D000000`3oool4000000@0oooo100000040?ooo`<00000103oool3
000000@0oooo100000040?ooo`@000000`3oool2000000030?ooo`000000000000<0oooo00@00000
0?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`3oool0
00000`3oool01@000000oooo0000003oool0000000<0oooo00<000000?ooo`0000000P00002b0?oo
o`00Q@3oool2000000D0oooo0`0000050?ooo`<00000103oool00`000000oooo000000050?ooo`03
0000003oool0000000@0oooo0P0000000`3oool000000?ooo`020?ooo`030000003oool000000;@0
oooo002L0?ooo`8000001@3oool3000000@0oooo0P0000000`3oool000000?ooo`020?ooo`030000
003oool000000;@0oooo002S0?ooo`8000001@3oool2000000030?ooo`000000oooo0080oooo00<0
00000?ooo`000000]03oool00:T0oooo00@0EEEE0000000000000000103oool00`000000oooo0000
002d0?ooo`00Z`3oool2000000@0oooo00<000000?ooo`000000]03oool00:/0oooo0P0000040?oo
o`040000003oool0000000000;<0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`03
0000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003o
ool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool00000
0;@0oooo002a0?ooo`040000003oool0000000000;<0oooo002a0?ooo`030000003oool000000;@0
oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a
0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`04
0000003oool0000000000;<0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000
003oool000000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool0
00000;@0oooo002a0?ooo`030000003oool000000;@0oooo002a0?ooo`030000003oool000000;@0
oooo002a0?ooo`040000003oool0000000000;<0oooo002a0?ooo`030000003oool000000;@0oooo
002a0?ooo`030000003oool000000;@0oooo002b0?ooo`800000]03oool009P0oooo00D0k^k^03<c
<`000000<c<c0>k^kP050?ooo`808R8R1@3oool01@14A4@000000000000c<c<0gMgM00@0oooo0P00
002d0?ooo`00V03oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c
<c<0oooo00<0oooo0P00002d0?ooo`00T03oool600000080oooo00D04A4A0?ooo`3oool0oooo014A
4@0@0?ooo`030000003oool0oooo0080oooo1000002b0?ooo`00V03oool01@000000oooo0?ooo`3o
ool0000000l0oooo00<0MgMg03<c<`3oool00`3oool200000;@0oooo002H0?ooo`050000003oool0
oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<00@0oooo0P00002d0?ooo`00V03o
ool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`3oool01P3oool200000;@0oooo
002H0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0303oool00`000000oooo0?ooo`060?ooo`800000
]03oool009P0oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@000001@3oool200000;@0oooo
002b0?ooo`800000]03oool00;80oooo0`00002c0?ooo`00/P3oool200000;@0oooo002b0?ooo`80
0000]03oool00;80oooo0P00002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000]03oool0
0;80oooo0`00002c0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000]03oool00;80oooo0P00
002d0?ooo`00/P3oool200000;@0oooo002b0?ooo`800000]03oool00;80oooo0P00002d0?ooo`00
7@3oool400000003014A4@3oool0oooo03`0oooo00D0k^k^03<c<`000000<c<c0>k^kP050?ooo`80
8R8R1@3oool01@14A4@000000000000c<c<0gMgM03d0oooo0P00000o0?ooo`050>k^kP0c<c<00000
03<c<`3^k^h01@3oool2028R8PD0oooo00D0A4A4000000000000<c<c0=gMg@0o0?ooo`@0000000<0
4A4A0?ooo`3oool0603oool001l0oooo00<000000?ooo`3oool0?P3oool01@1gMgL0VIVI0?ooo`2I
VIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo03`0oooo00<000000?ooo`3oool0?P3o
ool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R880?ooo`0307MgM`0c<c<0oooo0400oooo
00<000000?ooo`3oool06P3oool001@0oooo1P0000050?ooo`030000003oool0oooo03H0oooo1P00
00020?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo03h0oooo00D04A4A0?ooo`3oool0oooo014A4@0@0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool06P3oool001l0oooo00<000000?ooo`3oool0?P3oool01@000000oooo
0?ooo`3oool0000000l0oooo00<0MgMg03<c<`3oool0?03oool00`000000oooo0?ooo`0n0?ooo`05
0000003oool0oooo0?ooo`0000003`3oool00`1gMgL0<c<c0?ooo`100?ooo`030000003oool0oooo
01X0oooo000O0?ooo`030000003oool0oooo03h0oooo00D000000?ooo`3oool0oooo0000000<0?oo
o`050000000R8R80000003<c<`3<c<`0?@3oool00`000000oooo0?ooo`0n0?ooo`050000003oool0
oooo0?ooo`000000303oool01@0000008R8R0000000c<c<0c<c<0440oooo00<000000?ooo`3oool0
6P3oool001l0oooo00<000000?ooo`3oool0?P3oool01@0A4A40oooo0?ooo`3oool04A4A00`0oooo
00<000000?ooo`3oool0?`3oool00`000000oooo0?ooo`0n0?ooo`05014A4@3oool0oooo0?ooo`0A
4A40303oool00`000000oooo0?ooo`130?ooo`030000003oool0oooo01X0oooo000O0?ooo`030000
003oool0oooo03h0oooo00D0MgMg09VIV@3oool0VIVI07MgM`0<0?ooo`030000003oool0oooo03l0
oooo00<000000?ooo`3oool0?P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00`0oooo00<000000?oo
o`3oool0@`3oool00`000000oooo0?ooo`0J0?ooo`007@3oool205EEE@030000003oool0oooo03h0
oooo00D0k^k^03<c<`000000<c<c0>k^kP0<0?ooo`@00000?P3oool2000003l0oooo00D0k^k^03<c
<`000000<c<c0>k^kP0<0?ooo`@00000@03oool205EEE@030000003oool0oooo01X0oooo002c0?oo
o`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo000D0?ooool00000@000000E0?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0=0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool06P3oool001/0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`190?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0
B@3oool00`000000oooo0?ooo`0J0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool0
0`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000
oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000003oool0oooo0;80oooo002c
0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`03
0000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3o
ool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo
0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?oo
o`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool2
00000;<0oooo002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo
002c0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00V03oool01@3^k^h0<c<c0000000c<c<0
k^k^00D0oooo0P0R8R850?ooo`0504A4A0000000000003<c<`3MgMd01@3oool200000;<0oooo002H
0?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01@3oool2028R8PP0oooo00<0MgMg03<c<`3oool0103o
ool200000;<0oooo002H0?ooo`05014A4@3oool0oooo0?ooo`0A4A40403oool00`000000oooo0?oo
o`030?ooo`800000/`3oool009P0oooo00D000000?ooo`3oool0oooo0000000?0?ooo`0307MgM`0c
<c<0oooo00@0oooo0`00002b0?ooo`00V03oool01@000000oooo0?ooo`3oool0000000`0oooo00D0
0000028R8P000000<c<c0<c<c0050?ooo`800000/`3oool009P0oooo00D04A4A0?ooo`3oool0oooo
014A4@0<0?ooo`030000003oool0oooo00L0oooo0P00002c0?ooo`00V03oool01@1gMgL0VIVI0?oo
o`2IVIT0MgMg00`0oooo00<000000?ooo`3oool01`3oool200000;<0oooo002H0?ooo`050>k^kP0c
<c<0000003<c<`3^k^h0303oool4000000H0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c
0?ooo`800000/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000
/`3oool00;<0oooo0P00002c0?ooo`00/`3oool200000;<0oooo002c0?ooo`800000/`3oool00;<0
oooo0`00002b0?ooo`00/`3oool00`000000oooo0000002b0?ooo`00/`3oool00`000000oooo0000
002b0?ooo`00/`3oool00`000000oooo0000002b0?ooo`00/`3oool00`000000oooo0000002b0?oo
o`00/`3oool00`000000oooo0000002b0?ooo`00/`3oool00`000000oooo0000002b0?ooo`00/`3o
ool300000;80oooo002c0?ooo`030000003oool000000;80oooo002c0?ooo`030000003oool00000
0;80oooo002c0?ooo`030000003oool000000;80oooo002c0?ooo`030000003oool000000;80oooo
002c0?ooo`030000003oool000000;80oooo002c0?ooo`<000001@3oool00`000000oooo0?ooo`2Z
0?ooo`00/`3oool00`000000oooo000000040?ooo`800000[03oool00;<0oooo00<000000?ooo`00
0000103oool00`000000oooo0000002[0?ooo`00/`3oool00`000000oooo000000040?ooo`030000
003oool0000000D0oooo00<000000?ooo`3oool0X`3oool00:T0oooo100000000`0A4A40oooo0?oo
o`030?ooo`030000003oool0000000<0oooo00@000000?ooo`3oool00000103oool300000:@0oooo
002[0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`0000000`3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0000000D0oooo0`0000040?ooo`<000001P3oool00`000000oooo
0?ooo`2<0?ooo`00Z`3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000<0oooo00D0
00000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00@000000?ooo`3o
ool00000103oool010000000oooo0000000000030?ooo`80000000<0oooo0000003oool00`3oool4
000000@0oooo0`0000040?ooo`@00000103oool4000000@0oooo0`0000040?ooo`<000001@3oool3
000000@0oooo100000040?ooo`<000001@3oool3000000@0oooo0`0000050?ooo`<000001@3oool3
000000@0oooo0`0000050?ooo`800000703oool00:/0oooo00<000000?ooo`3oool01@3oool30000
00<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000<0oooo00D0
00000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool0
00000`3oool2000000030?ooo`000000oooo0080oooo0P0000000`3oool00000000000030?ooo`80
000000<0oooo0000000000000`3oool5000000<0oooo100000030?ooo`D000000P3oool500000080
oooo1P0000030?ooo`D000000P3oool500000080oooo1P0000020?ooo`D000000`3oool5000000<0
oooo1@0000000`3oool0000000000005000001d0oooo002[0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0
oooo00<000000?ooo`000000103oool4000000@0oooo0`0000050?ooo`<000001@3oool2000000H0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1a0?ooo`00Z`3oool00`000000oooo
0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000040?ooo`<000001@3oool2000009T0oooo002[0?ooo`030000003oool0oooo00D0oooo
00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`<00000Z03oool00:T0oooo0P1E
EED00`000000oooo0?ooo`050?ooo`030000003oool000000080oooo00<000000?ooo`3oool00`3o
ool200000:P0oooo002c0?ooo`060000003oool0oooo0000003oool00000[`3oool00;<0oooo0P00
0000103oool000000?ooo`00002_0?ooo`00/`3oool01P000000oooo0?ooo`000000oooo00000:l0
oooo002c0?ooo`060000003oool0oooo0000003oool00000[`3oool00;<0oooo00H000000?ooo`3o
ool000000?ooo`00002_0?ooo`00/`3oool01P000000oooo0?ooo`000000oooo00000:l0oooo002c
0?ooo`050000003oool0oooo0?ooo`000000/03oool00;<0oooo00<000000?ooo`3oool0/P3oool0
0;<0oooo0P00002c0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo
0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool00`000000oooo0?ooo`2b
0?ooo`00/`3oool00`000000oooo0?ooo`2b0?ooo`00/`3oool200000;<0oooo002c0?ooo`030000
003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0
oooo0;80oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`030000003oool0oooo0;80
oooo002c0?ooo`030000003oool0oooo0;80oooo002c0?ooo`800000/`3oool00;<0oooo00<00000
0?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3oool0/P3oool00;<0oooo00<000000?ooo`3o
ool0/P3oool009T0oooo100000000`0A4A40oooo0?ooo`020?ooo`808R8R1@3oool01@14A4@00000
0000000c<c<0gMgM00D0oooo00<000000?ooo`3oool0/P3oool009/0oooo00<000000?ooo`3oool0
103oool2028R8PP0oooo00<0MgMg03<c<`3oool0103oool00`000000oooo0?ooo`2b0?ooo`00V`3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0/P3o
ool009/0oooo00<000000?ooo`3oool03P3oool00`1gMgL0<c<c0?ooo`040?ooo`<00000/P3oool0
09/0oooo00<000000?ooo`3oool02`3oool01@0000008R8R0000000c<c<0c<c<0;X0oooo002K0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool0_03oool009/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`2l0?ooo`00V@3oool205EEE@030000003oool0oooo00/0oooo
1000002k0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00W@3oool200000006
014A4@3oool0oooo014A4@0000004A4A5`3oool5000000<0oooo00D0k^k^03<c<`000000<c<c0>k^
kP2O0?ooo`00WP3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00L0oooo1P000009
0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@00`3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg09l0oooo
002N0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool00`2IVIT08R8R0>k^
kP040?ooo`05014A4@3oool0oooo0?ooo`0A4A40W`3oool009h0oooo00H000000?ooo`14A4@0<c<c
0?ooo`0000090?ooo`H000002`3oool00`2IVIT08R8R0>k^kP030?ooo`050000003oool0oooo0?oo
o`000000W`3oool009h0oooo00H000000=gMg@0c<c<0EEEE0=gMg@00000K0?ooo`0307MgM`1VIVH0
oooo0080oooo00D000000?ooo`3oool0oooo0000002O0?ooo`00WP3oool01P000000R8R80:ZZZP2k
^k/0EEEE000001`0oooo00D000000?ooo`3oool0oooo014A4@030?ooo`03014A4@3oool0oooo09d0
oooo002N0?ooo`060000000c<c<0oooo0?ooo`0c<c<00000603oool01@000000^k^k0?ooo`2IVIT0
4A4A00<0oooo00D0MgMg09VIV@3oool0VIVI07MgM`2O0?ooo`00W@3oool00`0A4A40000008R8R002
0?ooo`0308R8R00000004A4A01L0oooo00D0VIVI014A4@0000008R8R0<c<c0030?ooo`050>k^kP0c
<c<0000003<c<`3^k^h0W`3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00?l0ooooJ@3oool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Near the time origin, the result looks identical to the behavior of the \
square wave Fourier series plotted in Cell ",
  ButtonBox["2.16",
    ButtonData:>"Cell 2.16",
    ButtonStyle->"Hyperlink"],
  ", except that now ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  " is no longer periodic in",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\)\)\)]],
  ". The periodic nature of ",
  Cell[BoxData[
      \(TraditionalForm\`f\_approx\)]],
  "  has been lost, because our integral approximation in Eq. ",
  ButtonBox["(2.1.18)",
    ButtonData:>"(2.1.18)",
    ButtonStyle->"Hyperlink"],
  " is correct only for ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " close to zero. [Equation ",
  ButtonBox["(2.1.18)",
    ButtonData:>"(2.1.18)",
    ButtonStyle->"Hyperlink"],
  " assumes  \[Tau] remains finite as ",
  Cell[BoxData[
      \(TraditionalForm\`M \[Rule] \ \[Infinity]\)]],
  ", so ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \ 0\)]],
  ".]"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.7 Exponential Notation for Fourier Series", "Subsubtitle",
  CellTags->"c:9"],

Cell[TextData[{
  "In Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:45"},
    ButtonStyle->"Hyperlink"],
  " we found that it could be useful to write a real periodic oscillation ",
  Cell[BoxData[
      \(TraditionalForm\`a\ cos\ \[Omega]\ t\  + \ b\ sin\ \[Omega]\ t\)]],
  " in the more compact complex notation, ",
  Cell[BoxData[
      \(TraditionalForm\`Re[C\ \(exp(\(-\[ImaginaryI]\)\ \[Omega]\ t)\)]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a complex number. We can do the same thing for a Fourier series \
representation of a real periodic function of period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = 
        a\_o + \[Sum]\+\(n = 1\)\%\[Infinity]\( a\_n\) 
              cos\ \((n\ \[CapitalDelta]\[Omega]\ t)\) + \[Sum]\+\(n = 1\)\%\
\[Infinity]\(\( 
                  b\_n\) \(sin\)\(\ \)\((n\ \[CapitalDelta]\[Omega]\ t)\)\(\ \
\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.20)"],

Cell[TextData[{
  "Here we have written the series in terms of the  quantity ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\  = \ 2  \[Pi]/T\)]],
  ", which is the fundamental frequency of the periodic function  (see Sec. \
",
  ButtonBox["2.1.1",
    ButtonData:>"c:3",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell["\<\
\tIn order to write this series in complex form, we will use the \
trigonometric identities\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(cos\ x\), " ", "=", " ", 
            RowBox[{
              RowBox[{"(", 
                
                FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ x\) + \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ x\)\),
                  "TraditionalForm"], ")"}], "/", "2"}]}], ","}], 
        TraditionalForm]]],
  "    ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(sin\ x\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                
                FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ x\) - \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ x\)\),
                  "TraditionalForm"], ")"}], "/", "2"}], "\[ImaginaryI]"}]}], 
        TraditionalForm]]],
  " ."
}], "NumberedEquation",
  CellTags->"(2.1.21)"],

Cell[TextData[{
  "When these identities are employed in Eq. ",
  ButtonBox["(2.1.20)",
    ButtonData:>"(2.1.20)",
    ButtonStyle->"Hyperlink"],
  ",",
  " and we combine the common terms involving ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[CapitalDelta]\
\[Omega]\ t\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \
\[CapitalDelta]\[Omega]\ t\)\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = 
        a\_o + \ \[Sum]\+\(n = 1\)\%\[Infinity]\( a\_n + \[ImaginaryI]\ \
b\_n\)\/2\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ \
t\) + \[Sum]\+\(n = 1\)\%\[Infinity]\( a\_n - \[ImaginaryI]\ b\_n\)\/2\ \
\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[CapitalDelta]\[Omega]\ t\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.22)"],

Cell[TextData[{
  "Note that, for real ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  ", the second sum is the complex conjugate of the first sum. Using the fact \
that ",
  Cell[BoxData[
      \(TraditionalForm\`z\  + \ \(z\^*\) = 2  Re\ z\)]],
  " for any complex number ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", we see that Eq. ",
  ButtonBox["(2.1.22)",
    ButtonData:>"(2.1.22)",
    ButtonStyle->"Hyperlink"],
  " can be expressed as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        a\_o + Re[\[Sum]\+\(n = 1\)\%\[Infinity]\((a\_n + \[ImaginaryI]\ \
b\_n)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\
\)]\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.23)"],

Cell[TextData[{
  "If we now introduce complex Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n\)]],
  ", defined as "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`C\_o = a\_o, \[IndentingNewLine]C\_n\  = \ 
      a\_\(\(n\)\(\ \)\) + \ \[ImaginaryI]\ b\_n, \ \ n > 
      0, \)]]], "NumberedEquation",
  CellTags->"(2.1.24)"],

Cell[TextData[{
  "we can write Eq. (",
  ButtonBox["2.1.22",
    ButtonData:>"(2.1.22)",
    ButtonStyle->"Hyperlink"],
  ")  in the following compact form:",
  "\t"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        Re[\[Sum]\+\(n = 0\)\%\[Infinity] C\_n\ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)]\)]],
  "."
}], "NumberedEquation",
  CellTags->{"(2.1.25)", "i:18"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.1.25)",
    ButtonData:>"(2.1.25)",
    ButtonStyle->"Hyperlink"],
  " is one form for an exponential Fourier series, valid for real functions \
",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". Another form that can also be useful follows from Eq. ",
  ButtonBox["(2.1.22)",
    ButtonData:>"(2.1.22)",
    ButtonStyle->"Hyperlink"],
  " by defining  a different set of complex Fourier coefficients  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\_n\)\(\ \)\)\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`c\_o = 
      a\_o, \[IndentingNewLine]c\_n = \((\ 
          a\_\(\(n\)\(\ \)\) + \ \[ImaginaryI]\ b\_n)\)/2, \ \ n > 
      0, \[IndentingNewLine]c\_n = \((\ 
          a\_\(\(-n\)\(\ \)\) - \ \[ImaginaryI]\ b\_\(-n\))\)/2, \ \ n < 
      0. \)]]], "NumberedEquation",
  CellTags->"(2.1.26)"],

Cell[TextData[{
  "The definition of these coefficients is extended to ",
  Cell[BoxData[
      \(TraditionalForm\`n < 0\)]],
  " for the following reason: this extension allows us to express the second  \
sum in Eq. ",
  ButtonBox["(2.1.22)",
    ButtonData:>"(2.1.22)",
    ButtonStyle->"Hyperlink"],
  " as  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity]\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(c\_\(-n\)\),
            
            FontSize->
              11], \(\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[CapitalDelta]\
\[Omega]\ t\)\)}], TraditionalForm]]],
  ". Then by taking ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Rule] \ \(-n\)\)]],
  " in this sum, and noting that this inversion changes the range of the sum \
to -\[Infinity] to -1, we can combine the two sums and obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] c\_n\ \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)\)]],
  "."
}], "NumberedEquation",
  CellTags->{"(2.1.27)", "i:19"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  " is a second form for the exponential Fourier series. It differs from the \
first form in that the real part is not  taken, and instead the sum runs over \
both negative and positive ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)]],
  " to +",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  ". Also, note that we did not assume that ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " are real, so Eq. ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  " works for complex periodic functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " as well as for real periodic  functions. For this reason, Eq. ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  " is somewhat more general than Eq. ",
  ButtonBox["(2.1.25)",
    ButtonData:>"(2.1.25)",
    ButtonStyle->"Hyperlink"],
  ", which applies only to real functions."
}], "Text"],

Cell[TextData[{
  "\tWe are now left with the question of how to determine the complex \
Fourier coefficients. Of course, we could determine the real coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_n\)\(\ \)\)\)]],
  "and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(b\_n\)\(\ \)\)\)]],
  "and then use either Eqs. ",
  ButtonBox["(2.1.24)",
    ButtonData:>"(2.1.24)",
    ButtonStyle->"Hyperlink"],
  " or Eqs. ",
  ButtonBox["(2.1.26)",
    ButtonData:>"(2.1.26)",
    ButtonStyle->"Hyperlink"],
  ", but it would be better if we could determine the complex coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(c\_n\)\(\ \)\)\)]],
  "(or ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n\)]],
  ") directly without reference to the real coefficients. This can be done by \
using a new set of orthogonality relations, valid for complex exponential \
functions."
}], "Text"],

Cell[TextData[{
  "\tBefore we can consider these orthogonality relations, we must first \
extend the notion of orthogonality, Eq. ",
  ButtonBox["(2.1.4)",
    ButtonData:>"(2.1.4)",
    ButtonStyle->"Hyperlink"],
  ",  to cover complex functions. Two complex functions ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " are said to be orthogonal on the interval",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  StyleBox[" ",
    FontSlant->"Italic"],
  "if they satisfy "
}], "Text",
  CellTags->"i:6"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( g(
              t)\) \(\(h(t)\)\^*\) \[DifferentialD]t = 0\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.28)"],

Cell[TextData[{
  "The complex conjugation is added to the definition so that we can again \
say that a function cannot be orthogonal with itself: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( g(
              t)\) \(\(g(
                  t)\)\^*\) \[DifferentialD]t = \[Integral]\_a\%b\(\(|\)\(g(
              t)\)\( | \^2\)\(\[DifferentialD]t \[GreaterEqual] \ 0\)\)\)]],
  ", with equality only for a function that equals zero across the interval. \
Of course, we could equally well have taken the complex conjugate of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " in this definition, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\(\( g(t)\)\^*\) \(h(
              t)\) \[DifferentialD]t = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe complex exponential Fourier modes, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \
\[CapitalDelta]\[Omega]\ t\)\)]],
  "( with ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\  = \ 2\ \[Pi]/T\)]],
  "), satisfy the following orthogonality relations on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o + T\)]],
  ", for any choice of  ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", \(t\_o\), 
              RowBox[{" ", 
                FormBox[\(t\_o + T\),
                  
                  "TraditionalForm"]}]], \(\(\(\(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)\)(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \
\[DifferentialD]t\)}], "=", "0"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`m \[NotEqual] n\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.29)"],

Cell["\<\
This can easily be proven using a couple of lines of algebra:\
\>", \
"Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubsuperscriptBox["\[Integral]", \(t\_o\), 
            RowBox[{" ", 
              FormBox[\(t\_o + T\),
                
                "TraditionalForm"]}]], \(\(\(\(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)\)(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \
\[DifferentialD]t\)}], "=", 
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", \(t\_o\), 
              RowBox[{" ", 
                FormBox[\(t\_o + T\),
                  
                  "TraditionalForm"]}]], \(\(\[ExponentialE]\^\(\(-2\) \[Pi]\ \
\(\[ImaginaryI](n - m)\)\ \ t/T\)\) \[DifferentialD]t\)}], 
          "=", \(\(T\/\(\(-2\) \[Pi]\ \(\[ImaginaryI](
                      n - m)\)\)\)[\[ExponentialE]\^\(\(-2\) \[Pi]\ \(\
\[ImaginaryI](n - m)\)\ \ \((t\_o + T)\)/T\) - \[ExponentialE]\^\(\(-2\) \
\[Pi]\ \(\[ImaginaryI](n - m)\)\ \ t\_o/T\)] = \ \(\(T\/\(\(-2\) \[Pi]\ \(\
\[ImaginaryI](n - m)\)\)\) \(\[ExponentialE]\^\(\(-2\) \[Pi]\ \(\[ImaginaryI](
                          n - m)\)\ \ t\_o/
                          T\)\)[\[ExponentialE]\^\(\(-2\) \(\[Pi]\)\(\ \)\(\
\[ImaginaryI](n - m)\)\(\ \ \)\) - 1]\  = \ 0. \)\)}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(2.1.30)"],

Cell[TextData[{
  "The case where ",
  Cell[BoxData[
      \(TraditionalForm\`m = n\)]],
  " is even simpler:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", \(t\_o\), 
              RowBox[{" ", 
                FormBox[\(t\_o + T\),
                  
                  "TraditionalForm"]}]], \(\(\(\(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)\)(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \
\[DifferentialD]t\)}], "=", 
          RowBox[{
            RowBox[{
              SubsuperscriptBox["\[Integral]", \(t\_o\), 
                RowBox[{" ", 
                  FormBox[\(t\_o + T\),
                    
                    "TraditionalForm"]}]], \(\(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ 0\)\) \[DifferentialD]t\)}], "=", "T"}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.31)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.1.29)",
    ButtonData:>"(2.1.29)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.30)",
    ButtonData:>"(2.1.30)",
    ButtonStyle->"Hyperlink"],
  " can now be used to determine the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  "  for a given function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". To do so, we multiply both sides of the equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \
\[CapitalDelta]\[Omega]\ t\))\)\^*\)\)]],
  ", and integrate over one period :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubsuperscriptBox["\[Integral]", \(t\_o\), 
              RowBox[{" ", 
                FormBox[\(t\_o + T\),
                  
                  "TraditionalForm"]}]], \(\(\((\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \(f(
                t)\) \[DifferentialD]t\)}], "=", 
          RowBox[{\(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\), 
            RowBox[{\(c\_n\), " ", 
              RowBox[{
                SubsuperscriptBox["\[Integral]", \(t\_o\), 
                  RowBox[{" ", 
                    FormBox[\(t\_o + T\),
                      
                      "TraditionalForm"]}]], \(\(\((\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \
\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)\) \(\
\(\[DifferentialD]t\)\(.\)\)\)}]}]}]}], TraditionalForm]]],
  " "
}], "NumberedEquation",
  CellTags->"(2.1.32)"],

Cell[TextData[{
  "Then, according to Eq. ",
  ButtonBox["(2.1.29)",
    ButtonData:>"(2.1.29)",
    ButtonStyle->"Hyperlink"],
  ", all terms in the sum vanish, except for the ",
  Cell[BoxData[
      \(TraditionalForm\`n = m\)]],
  " term, which, after applying Eq. ",
  ButtonBox["(2.1.31)",
    ButtonData:>"(2.1.31)",
    ButtonStyle->"Hyperlink"],
  ", equals ",
  Cell[BoxData[
      \(TraditionalForm\`c\_m\ T\)]],
  ". Thus, we find"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_m\), " ", "=", 
          RowBox[{\(1\/T\), " ", 
            RowBox[{
              SubsuperscriptBox["\[Integral]", \(t\_o\), 
                RowBox[{" ", 
                  FormBox[\(t\_o + T\),
                    
                    "TraditionalForm"]}]], \(\(\((\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \(f(
                  t)\) \[DifferentialD]t\)}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->{"(2.1.33)", "i:20"}],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.1.33)",
    ButtonData:>"(2.1.33)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  " allow us to write any periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " as an exponential Fourier series. Of course, the function must satisfy \
the requirements of Theorem 2.1 in order for the series to converge uniformly \
to ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor real ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " we can also write the series in the form of Eq. ",
  ButtonBox["(2.1.25)",
    ButtonData:>"(2.1.25)",
    ButtonStyle->"Hyperlink"],
  " by using Eq. ",
  ButtonBox["(2.1.33)",
    ButtonData:>"(2.1.33)",
    ButtonStyle->"Hyperlink"],
  " along with the relations "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`C\_o = c\_o, \[IndentingNewLine]C\_n = 2  c\_n, \ 
    n > 0, \)]]], "NumberedEquation",
  CellTags->"(2.1.34)"],

Cell[TextData[{
  "which follow from comparing Eqs. ",
  ButtonBox["(2.1.24)",
    ButtonData:>"(2.1.24)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.26)",
    ButtonData:>"(2.1.26)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Two representations of an exponential Fourier series (the first is valid \
only for real ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  "):\n ",
  Cell[BoxData[
      \(TraditionalForm\`\((1)\)\ \ \(f(t)\) = 
        Re[\[Sum]\+\(n = 0\)\%\[Infinity] C\_n\ \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)]\ , \[IndentingNewLine]\((2)\
\)\ \ \(f(
            t)\) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] c\_n\ \(\(\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\)\)\(.\)\
\)\)]],
  "\nwhere\n ",
  Cell[BoxData[
      \(TraditionalForm\`C\_o = c\_o, \[IndentingNewLine]C\_n = 2  c\_n, \ 
      n > 0, \)]],
  "\nand\n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_n\), " ", "=", 
          RowBox[{\(1\/T\), " ", 
            RowBox[{
              SubsuperscriptBox["\[Integral]", \(t\_o\), 
                RowBox[{" ", 
                  FormBox[\(t\_o + T\),
                    
                    "TraditionalForm"]}]], \(\(\((\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\))\)\^*\) \(f(
                  t)\) \[DifferentialD]t\)}]}]}], TraditionalForm]]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.8 Response of a Damped Oscillator to Periodic Forcing", \
"Subsubtitle",
  CellTags->{"i:22", "c:10"}],

Cell[TextData[{
  "Armed with the knowledge we have gained in previous sections, we can now \
return to the question put forward at the beginning of the chapter: what is \
the response of a damped oscillator to general periodic forcing ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  "?"
}], "Text"],

Cell[TextData[{
  "\t We will find a particular solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_p\)(t)\)\(\ \)\)\)]],
  "to the oscillator equation (",
  ButtonBox["(1.6.2)",
    ButtonData:>{"Chapter1.nb", "(1.6.2)"},
    ButtonStyle->"Hyperlink"],
  ") in the form of an exponential Fourier series:"
}], "Text"],

Cell[TextData[{
  "\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t)\  = \ \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                x\_n\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \
\[CapitalDelta]\[Omega]\ t\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(2.1.35)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " is the complex Fourier coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\  = \ 2  \[Pi]/T\)]],
  " is the fundamental frequency of the given periodic forcing function, and \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\)\(\ \)\)\)]],
  "is the fundamental period of the forcing. If we substitute Eq. ",
  ButtonBox["(2.1.35)",
    ButtonData:>"(2.1.35)",
    ButtonStyle->"Hyperlink"],
  " into Eq. (",
  ButtonBox["1.6.2",
    ButtonData:>{"Chapter1.nb", "(1.6.2)"},
    ButtonStyle->"Hyperlink"],
  "), we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\
\[Infinity] x\_n\ [\(-\((\ n\ \[CapitalDelta]\[Omega])\)\^2\)\  - \
\[ImaginaryI]\ \[Gamma]\ \ n\ \[CapitalDelta]\[Omega]\  + \[Omega]\_o\%2] \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ t\) = 
        f(t)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(2.1.36)"],

Cell[TextData[{
  "Finally, we can  extract the Fourier coefficient  ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n\)]],
  " by multiplying both sides by  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \
\[CapitalDelta]\[Omega]\ t\))\)\^*\)\)]],
  ", integrating over a period of the force, and using the orthogonality \
relations Eq. ",
  ButtonBox["(2.1.29)",
    ButtonData:>"(2.1.29)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.31)",
    ButtonData:>"(2.1.31)",
    ButtonStyle->"Hyperlink"],
  ". The result is"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`x\_n = 
        c\_n/\([\(-\((\ n\ \[CapitalDelta]\[Omega])\)\^2\)\  - \[ImaginaryI]\ \
\[Gamma]\ n\ \[CapitalDelta]\[Omega]\  + \[Omega]\_o\%2]\)\)], 
    "NumberedEquation"], "NumberedEquation"],
  StyleBox[",", "NumberedEquation"]
}], "NumberedEquation",
  CellTags->"(2.1.37)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th  Fourier coefficient of the forcing function, given by Eq. ",
  ButtonBox["(2.1.33)",
    ButtonData:>"(2.1.33)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThis simple expression contains a considerable amount of physics. First, \
note that each Fourier mode in the force drives a single Fourier mode in the \
oscillator response. For the case of a strictly sinusoidal force, Eqs. ",
  ButtonBox["(2.137)",
    ButtonData:>"(3.137)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.35)",
    ButtonData:>"(2.1.35)",
    ButtonStyle->"Hyperlink"],
  " reduce to  Eq. ",
  ButtonBox["(1.6.45)",
    ButtonData:>{"Chapter1.nb", "(1.6.45)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tSecond, the principle of superposition is implicitly coming into play: \
according to Eq. ",
  ButtonBox["(2.1.35)",
    ButtonData:>"(2.1.35)",
    ButtonStyle->"Hyperlink"],
  ", the total oscillator response is a linear superposition of the responses \
from the individual Fourier modes. However, each mode is independently \
excited, and has no effect on other modes."
}], "Text"],

Cell[TextData[{
  "\tThird, note that for high-",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " Fourier modes, the response is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n~\(-c\_n\)/\((\ n\ \[CapitalDelta]\[Omega])\)\^2\
\)]],
  ", which approaches zero more rapidly with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " than do the forcing coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  ". Basically, this is an effect due to inertia of the oscillator: a very \
high frequency forcing causes almost no effect on an oscillator,  because the \
oscillator's inertia doesn't allow it to respond before the force changes \
sign."
}], "Text"],

Cell[TextData[{
  "\tFourth, for very low-frequency forcing, such that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\ n\ \[CapitalDelta]\[Omega])\)\^2\)]],
  "<< ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\%2\)]],
  " for all Fourier modes entering the force, the response is ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n~c\_n/\[Omega]\_o\%2\)]],
  ". We can then re-sum the series according to Eq. ",
  ButtonBox["(2.1.35)",
    ButtonData:>"(2.1.35)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  ", to find that the oscillator amplitude tracks the forcing as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_p\)(t)\)~\(f(t)\)/\[Omega]\_o\%2\)]],
  ". This makes sense intuitively: according to Hooke's law, when you slowly \
change the force on a spring, it responds by changing its length in \
proportion to the applied force."
}], "Text"],

Cell[TextData[{
  "\tFinally, note that some Fourier modes are excited to higher levels than \
other modes. For  Fourier modes that satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\((\ n\ \[CapitalDelta]\[Omega])\)\^2 \[TildeEqual] \
\[Omega]\_o\%2\)]],
  ", the denominator in Eq. ",
  ButtonBox["(2.1.37)",
    ButtonData:>"(2.1.37)",
    ButtonStyle->"Hyperlink"],
  " is close to zero if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is small, and the system response exhibits the resonance phenomenon \
discussed in Sec. ",
  ButtonBox["1.6.4",
    ButtonData:>{"Chapter1.nb", "c:46"},
    ButtonStyle->"Hyperlink"],
  ". These resonant modes are driven to large amplitude. For the case of an \
undamped oscillator ( ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 0\)]],
  ") and exact resonance (",
  Cell[BoxData[
      FormBox[
        RowBox[{\(n\ \[CapitalDelta]\[Omega]\), " ", "=", " ", 
          FormBox[\(\[Omega]\_o\),
            "TraditionalForm"]}], TraditionalForm]]],
  " for some value of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "), Eq. ",
  ButtonBox["(2.1.37)",
    ButtonData:>"(2.1.37)",
    ButtonStyle->"Hyperlink"],
  " does not apply. The resonant response is no-longer described by a Fourier \
mode, but rather by a growing oscillation. The form of this oscillation can \
be found using the methods for exact resonance discussed in Sec. ",
  ButtonBox["1.6.4",
    ButtonData:>{"Chapter1.nb", "c:46"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:23"],

Cell["\<\
\tResonance phenomena are of great importance in a number of \
systems, including the system to be discussed in the next section.\
\>", \
"Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1.9 Fourier Analysis, Sound, and Hearing", "Subsubtitle",
  CellTags->{"i:24", "c:11"}],

Cell[TextData[{
  "\tThe sound that a sinusoidal oscillation makes is a pure tone. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can play such sounds with the intrinsic function ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". For example, the sound of the pure note \"middle A\" is a sinusoid with \
frequency \[Omega] = 2 \[Pi] \[Cross] 440 ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["s",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  "; the command and visible response are shown in Cell ",
  ButtonBox["2.25",
    ButtonData:>"Cell 2.25",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:25"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Play[Sin[2\ Pi\ 440\ t], {t, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.25"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 8192 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oo`00/@0000000`00
Oomoo`3oOon]Ool100000003001oo`000?l00:`0005oo`40000000<007oo00003@0000=oo`00Ool0
0P0000=oo`0000004@0000=oo`0000002P0000=oo`00Ool0300000=oo`0000004@0000Ioo`00001o
o`00OolL00000goo001oo`0200000goo0000000A00000goo0000000:00000goo001oo`0<00000goo
0000000A00001Woo000007oo001ooa/0009oo`03001oo`0001D00003Ool0000000L00004Ool00000
Ool>00000goo0000000?00000goo001oo`0400000goo0000000I0002Ool00`00Ool0000E00000goo
00000007000017oo000007oo3P0000=oo`0000003`0000=oo`00Ool0100000=oo`00000030000Goo
0@0000001@00Ool00000Ool00P0000=oo`0000000P0000=oo`0000000P0000=oo`0000000P0000=o
o`0000001`0000=oo`0000000P0000=oo`0000001@0000=oo`0000000P0000=oo`0000000P0000=o
o`0000000P0000=oo`0000000P0000=oo`0000001@0000=oo`0000000P0000=oo`0000001`0000=o
o`0000000P0000=oo`0000000P0000=oo`0000000P0000Aoo`00001oo`@00004Ool00000Ool40000
0goo0000000200000goo0000000200000goo0000000700000goo0000000200000goo000000050000
0goo0000000200000goo0000000200000goo0000000200000goo0000000200000goo000000050000
0goo0000000200000goo0000000700000goo0000000700000goo00000002000017oo000007oo1000
00Aoo`00001oo`@00003Ool0000000800003Ool0000000@00003Ool0000000D00003Ool000000080
0003Ool0000000D00003Ool0000000800003Ool0000000800003Ool0000000800003Ool000000080
0003Ool0000000D00003Ool0000000800003Ool0000000L00003Ool0000000L00003Ool000000080
0004Ool00000Ool4000017oo000007oo1P0000Aoo`00001oo`H00003Ool0000000D00003Ool00000
00800003Ool0000000D00003Ool0000000800003Ool0000000800003Ool0000000800003Ool00000
00800003Ool0000000D00003Ool0000000800003Ool0000000L00003Ool0000000L00003Ool00000
00800004Ool00000Ool20001Ool100000006001oo`00Ool007oo0P0000Ioo`00001oo`00Ool40000
1Woo000007oo001oo`@00006Ool00000Ool007oo0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool2
00000goo001oo`0200000goo001oo`0200000goo001oo`0200000goo001oo`0200001Woo000007oo
001oo`800003Ool007oo00800003Ool0000000800003Ool007oo00800008Ool00000Ool007oo001o
o`800006Ool00000Ool007oo0P0000=oo`00Ool00P0000Qoo`00001oo`00Ool007oo0P0000Ioo`00
001oo`00Ool400001Woo000007oo001oo`800003Ool007oo00800006Ool00000Ool007oo0P0000=o
o`00Ool00P0000=oo`00Ool0100000Ioo`00001oo`00Ool200001Woo000007oo001oo`800003Ool0
07oo00800003Ool0000000800003Ool007oo00800003Ool0000000800003Ool007oo00800006Ool0
0000Ool007oo0P0000=oo`00Ool00P0000Qoo`00001oo`00Ool007oo0P0000Qoo`00001oo`00Ool0
07oo0P0000Ioo`00001oo`00Ool200000goo001oo`0200001Woo000007oo001oo`800003Ool007oo
00800003Ool007oo00@00006Ool00000Ool007oo0P0000Ioo`00001oo`00Ool200000goo001oo`04
00001Woo000007oo001oo`800003Ool0000000800003Ool007oo00800006Ool00000Ool007oo0P00
00=oo`00Ool00P0000=oo`0000000P0000=oo`00Ool00P0000Qoo`00001oo`00Ool007oo0P0000Io
o`00001oo`00Ool200000goo001oo`0200001goo000007oo001oo`00009oo`07001oo`00001oo`00
Ool0100000Ioo`00001oo`00Ool200001Woo000007oo001oo`800003Ool007oo00@00006Ool00000
Ool007oo100000Ioo`00001oo`00Ool2000027oo000007oo001oo`00Ool100000005001oo`00001o
o`07000017oo000000000Woo00H007ooOol007oo0002Ool01000Oomoogoo0P0000=oo`0000000P00
00Aoo`00001oo`@00003Ool0000000@0009oo`03001oo`00009oo`03001oo`0000<00003Ool00000
00800004Ool00000Ool400000goo00000003Ool01P00Oomoo`00Ool0009oo`07001oogoo001oo`00
Ool01`0000=oo`0000000P0000=oo`0000001@0000Aoo`00Ool0009oo`07001oogoo001oo`00Ool0
0P000goo0P0000=oo`0000000P0000Aoo`00001oo`@00003Ool0000000800007Ool007ooOol007oo
00000Woo1P0000=oo`0000000P0000Aoo`00001oo`@00003Ool0000000=oo`06001oogoo001oo`00
0Woo00<007ooOol00`0000=oo`0000001@0000=oo`0000000P0000=oo`0000001@0000Aoo`00Ool0
009oo`07001oogoo001oo`00Ool00P000goo0P0000=oo`0000000P0000Aoo`00001oo`@00003Ool0
000000800007Ool007ooOol007oo00000Woo1P0000=oo`0000000P0000Aoo`00001oo`@00003Ool0
000000=oo`06001oogoo001oo`000Woo00<007ooOol00`0000=oo`0000001@0000=oo`0000000P00
00=oo`00000010000Woo00<007oo00000Woo00L007ooOol007oo001oo`020003Ool200000goo0000
0002000017oo000007oo100000=oo`00Ool00P0000Qoo`00Oomoo`00Ool007oo1`0000=oo`000000
0P0000Aoo`00001oo`@00003Ool0000000=oo`06001oogoo001oo`000Woo00<007oo00000`0000=o
o`0000001@0000Aoo`00001oo`40000000D007oo000007oo00L00004Ool00000Ool200001Woo0000
07oo001oo`800003Ool0000000<00003Ool0000000800004Ool00000Ool400000goo000000030000
1Woo000007oo001oo`800003Ool007oo00<00003Ool0000000800004Ool00000Ool400000goo0000
000600000goo001oo`0200001Woo000007oo001oo`P00003Ool0000000800003Ool0000000H00003
Ool007oo00800006Ool00000Ool007oo200000=oo`0000000P0000Aoo`00001oo`@00007Ool00000
001oo`00Ool00P0000=oo`00Ool00P0000=oo`0000000`0000=oo`0000000P0000Aoo`00001oo`@0
0003Ool0000000<00006Ool00000Ool007oo0P0000Aoo`00001oo`800003Ool0000000D00003Ool0
000000800003Ool0000000H00003Ool007oo00800006Ool00000Ool007oo200000=oo`0000000P00
00Aoo`00001oo`@00007Ool00000001oo`00Ool00P0000=oo`00Ool00P0000=oo`0000000`0000=o
o`0000000P0000Aoo`00001oo`@00003Ool0000000<00006Ool00000Ool007oo0P0000Aoo`00001o
o`800003Ool0000000D00003Ool0000000800003Ool0000000H00003Ool007oo00800004Ool00000
Ool200000goo0000000500000goo00000002000017oo000007oo1@0000Ioo`00001oo`00Ool20000
0goo001oo`0800000goo00000002000017oo000007oo100000=oo`0000000`0000Ioo`00001oo`00
Ool200000goo0000000300000goo00000005000017oo000007oo0@0000001@00Ool007oo00000Woo
00<007oo00000Woo0P0000Eoo`00000007oo00<00004Ool000000002Ool20002Ool01P00Ool00000
Ool0009oo`06001oo`00001oo`000Woo0P000Woo0`0000Aoo`000000009oo`80009oo`06001oo`00
001oo`000Woo00H007oo000007oo0002Ool01000Ool007oo0`0000Eoo`00000007oo00<00003Ool0
0000009oo`03001oo`00009oo`06001oo`00001oo`000Woo00@007oo001oo`<00005Ool00000001o
o`03000027oo00000000Ool007oo0002Ool01P00Ool00000Ool0009oo`06001oo`00001oo`000Woo
0P000Woo0`0000Aoo`000000009oo`80009oo`06001oo`00001oo`000Woo00H007oo000007oo0002
Ool20002Ool300001Goo00000000Ool00`0000=oo`0000000Woo00<007oo00000Woo00H007oo0000
07oo0002Ool01000Ool007oo0`0000Eoo`00000007oo00<00008Ool00000001oo`00Ool0009oo`06
001oo`00001oo`000Woo00H007oo000007oo0002Ool20002Ool3000017oo000000000Woo0P000Woo
00H007oo000007oo0002Ool01P00Ool00000Ool0009oo`80009oo`<00005Ool00000001oo`040000
1goo001oogoo001oo`00009oo`06001oo`00001oo`000Woo00@007oo001oo`<00005Ool00000001o
o`0300000goo00000002Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`03001oo`0000<0009o
o`80009oo`<00008Ool00000001oo`00Ool0009oo`06001oo`00001oo`000Woo00H007oo000007oo
0002Ool20002Ool300001Goo00000000Ool0100000Moo`00Oomoo`00Ool00002Ool01000Ool007oo
0@0000001@00Oomoo`00Ool00P0000=oo`00Ool0100000Ioo`00001oo`00Ool200000goo00000002
00000goo0000000200001Woo001oogoo001oo`800006Ool007ooOol007oo100000=oo`0000000P00
00=oo`0000000P0000=oo`0000000P0000Ioo`00Oomoo`00Ool200001Woo001oogoo001oo`800003
Ool007oo00@00006Ool00000Ool007oo0P0000=oo`0000000P0000=oo`00Ool00P0000Ioo`00Oomo
o`00Ool200000goo001oo`0400001Woo000007oo001oo`800003Ool0000000800003Ool007oo0080
0006Ool007ooOol007oo0P0000Aoo`00Oomoo`<00004Ool00000Ool400000goo0000000200000goo
0000000200001Woo001oogoo001oo`800006Ool007ooOol007oo100000=oo`0000000P0000Ioo`00
001oo`00Ool200000goo0000000200000goo001oo`0200001Woo001oogoo001oo`800003Ool007oo
00@00006Ool00000Ool007oo0P0000=oo`0000000P0000=oo`00Ool00P0000Ioo`00Oomoo`00Ool2
000017oo001oogoo0`0000Aoo`00001oo`@00003Ool0000000800003Ool0000000800006Ool007oo
Ool007oo0P0000Ioo`00Oomoo`00Ool400000goo0000000200001Woo000007oo001oo`800003Ool0
07oo00800003Ool007oo00800006Ool007ooOol007oo0P0000=oo`00Ool0100000Ioo`00001oo`00
Ool200000goo0000000200000goo001oo`0200001Woo001oogoo001oo`800004Ool007ooOol30000
17oo000007oo100000=oo`0000000P0000=oo`00Ool00P0000Ioo`00Oomoo`00Ool2000017oo001o
ogoo0`0000Aoo`00001oo`@00006Ool00000Ool007oo0P0000=oo`00Ool00P0000=oo`00Ool00P00
00Aoo`00Oomoo`40000000H007oo001oo`00Ool200000goo0000000200001Woo001oogoo001oo`80
0003Ool007oo00800003Ool007oo00800003Ool007oo00800003Ool0000000800007Ool00000Ool0
07oo00000Woo00L007oo000007oo001oo`02000027oo001oogoo001oo`00Ool200000goo00000002
00001Woo000007oo001oo`800003Ool007oo00800003Ool007oo00800006Ool007ooOol007oo1000
00Ioo`00001oo`00Ool200000goo001oo`0200000goo0000000200001Woo001oogoo001oo`800003
Ool007oo00800003Ool007oo00800003Ool007oo00800003Ool0000000800007Ool00000Ool007oo
00000Woo00L007oo000007oo001oo`02000027oo001oogoo001oo`00Ool200000goo000000020000
1goo000007oo001oo`00009oo`07001oo`00001oo`00Ool00P0000Ioo`00Oomoo`00Ool400001Woo
000007oo001oo`800003Ool007oo00800003Ool007oo00800006Ool007ooOol007oo0P0000=oo`00
Ool00P0000=oo`00Ool00P0000=oo`00Ool00P0000=oo`0000000P0000=oo`0000000P0000Ioo`00
Oomoo`00Ool200000goo001oo`0200000goo001oo`0200000goo001oo`0200000goo000000020000
1goo000007oo001oo`00009oo`07001oo`00001oo`00Ool00P0000Qoo`00Oomoo`00Ool007oo0P00
00Ioo`00001oo`00Ool200000goo001oo`0200000goo001oo`0200001Woo001oogoo001oo`800003
Ool007oo00@00006Ool00000Ool007oo0P0000=oo`0000000P0000=oo`0000000P0000Ioo`00Oomo
o`00Ool200000goo001oo`0200000goo001oo`0200000goo001oo`0200000goo0000000200001goo
000007oo001oo`00009oo`07001oo`00001oo`00Ool00P0000Qoo`00Oomoo`00Ool007oo0P0000Qo
o`00001oo`00Ool007oo0@0000000`00Ool00002Ool300000goo00000002Ool01P00Ool00000Ool0
009oo`03001oo`00009oo`03001oo`0000<0009oo`80009oo`<00007Ool00000001oo`00Ool00P00
00Moo`00Oomoo`00Ool00002Ool01`00Ool00000Ool007oo00<00004Ool000000002Ool20002Ool4
00001goo001oogoo001oo`00009oo`06001oo`00001oo`000Woo0P0000Aoo`000000009oo`80009o
o`<00003Ool00000009oo`06001oo`00001oo`000Woo00<007oo00000Woo00<007oo00000`000Woo
0P000Woo0`0000Moo`00000007oo001oo`0200001goo001oogoo001oo`00009oo`07001oo`00001o
o`00Ool00`0000Aoo`000000009oo`80009oo`@00007Ool007ooOol007oo00000Woo00H007oo0000
07oo0002Ool2000017oo000000000Woo0P000Woo100000Ioo`00Oomoo`00Ool200001goo001oogoo
001oo`00009oo`03001oo`0000<0009oo`80009oo`<00003Ool00000009oo`06001oo`00001oo`00
0Woo00<007oo00000Woo00<007oo00000`0000Eoo`00000007oo00<0009oo`80009oo`06001oo`00
001oo`000Woo00<007oo00000Woo00L007oo000007oo001oo`03000017oo000000000Woo0P000Woo
100000Ioo`00Oomoo`00Ool200001goo001oogoo001oo`00009oo`800004Ool000000002Ool20002
Ool300000goo00000002Ool01P00Ool00000Ool0009oo`03001oo`00009oo`03001oo`0000<00005
Ool00000001oo`030002Ool20002Ool01P00Ool00000Ool0009oo`03001oo`00009oo`07001oo`00
001oo`00Ool00`0000Aoo`000000009oo`40005oo`40000000D007oo000007oo00800004Ool00000
Ool200000goo0000000200000goo0000000500000goo0000000300000goo001oo`0200001Woo0000
07oo001oo`<00003Ool0000000800003Ool0000000D00003Ool0000000800007Ool00000001oo`00
Ool00P0000Ioo`00001oo`00Ool500000goo0000000500000goo00000002000017oo000007oo0P00
00Aoo`00001oo`@00004Ool00000Ool2000017oo000007oo100000=oo`0000001@0000=oo`000000
0`0000=oo`00Ool00P0000Ioo`00001oo`00Ool300000goo0000000200000goo0000000500000goo
0000000200001goo00000000Ool007oo00800006Ool00000Ool007oo1@0000=oo`0000001@0000=o
o`0000000P0000Moo`00000007oo001oo`0200000goo0000000200000goo00000003000017oo0000
07oo100000=oo`0000001@0000Aoo`00001oo`800003Ool007oo00800004Ool00000Ool2000017oo
000007oo100000=oo`0000001@0000=oo`0000000`0000Ioo`00001oo`00Ool2000017oo000007oo
0P0000=oo`0000000P0000=oo`0000001@0000=oo`0000000P0000Moo`00000007oo001oo`020000
0goo0000000200000goo00000003000017oo000007oo100000=oo`0000001@0000Aoo`00001oo`80
0003Ool007oo00800004Ool00000Ool2000017oo000007oo100000=oo`0000001@0000=oo`000000
0`0000Ioo`00001oo`00Ool2000017oo000007oo0P0000=oo`0000000P0000=oo`0000001@0000=o
o`0000000P0000Moo`00000007oo001oo`02000017oo000007oo0@0000001@00Oomoogoo00000Woo
0`0000Aoo`00001oo`@00003Ool0000000D00003Ool0000000800003Ool007oo00800008Ool007oo
Ool007oo001oo`800003Ool0000000800003Ool0000000=oo`800003Ool0000000800007Ool00000
Ool007oo00000Woo00L007oo000007oo001oo`0400000goo0000000500000goo00000002000017oo
000007oo0`000Woo00<007ooOol00Woo00<007ooOol00`0000Aoo`00001oo`@00003Ool0000000D0
0003Ool0000000800003Ool007oo00800008Ool007ooOol007oo001oo`800003Ool0000000800003
Ool0000000=oo`800003Ool0000000800007Ool00000Ool007oo00000Woo00L007oo000007oo001o
o`0400000goo0000000500000goo0000000200001goo000007oo001oo`00009oo`03001oogoo009o
o`03001oogoo00<00004Ool00000Ool400000goo00000005000017oo000000000Woo00H007oo0000
07oo0002Ool3000017oo000007oo100000=oo`0000000goo0P0000=oo`0000000P0000Moo`00Oomo
o`00Ool00002Ool00`00Ool0000300000goo0000000200000goo0000000500000goo000000020000
1goo000007oo001oo`00009oo`03001oogoo009oo`03001oo`0000<00004Ool00000Ool400000goo
00000005000017oo000000000Woo00H007oo000007oo0002Ool3000017oo000007oo100000=oo`00
00000goo0P0000=oo`0000000P0000Moo`00Oomoo`00Ool00002Ool00`00Ool0000300000goo0000
000200000goo0000000500000goo0000000200001goo000007oo001oo`00009oo`04001oogooOol1
00000005001oo`00001oo`0200000goo001oo`0400000goo0000000500000goo00000002000017oo
000007oo0`000Woo00L007oo000007oo001oo`0400000goo0000000500000goo0000000500000goo
0000000200000goo001oo`02000017oo001oogoo0`0000Aoo`00001oo`@00003Ool0000000D00003
Ool0000000800003Ool0000000800003Ool0000000800003Ool0000000800003Ool0000000800003
Ool0000000D00003Ool0000000800004Ool00000Ool30002Ool01`00Ool00000Ool007oo00@00003
Ool0000000D00003Ool0000000D00003Ool0000000800003Ool007oo00800004Ool007ooOol30000
17oo000007oo100000=oo`0000001@0000=oo`0000000P0000=oo`00Ool00P0000=oo`0000000P00
00=oo`0000000P0000=oo`0000000P0000=oo`0000001@0000=oo`0000000P0000=oo`0000000P00
00Ioo`00Oomoo`00Ool200000goo001oo`0400000goo0000000500000goo0000000500000goo0000
000200000goo001oo`0200000goo001oo`04000017oo000007oo100000=oo`0000001@0000=oo`00
00000P0000=oo`00Ool00P0000=oo`0000001`0000=oo`0000000P0000=oo`0000001@0000=oo`00
00000P0000=oo`0000000P0000Ioo`00Oomoo`00Ool400000goo0000000200000goo000000050000
0goo0000000500000goo0000000200000goo001oo`0200000goo001oo`04000017oo000007oo1000
00=oo`0000001@0000=oo`0000000P0000=oo`00Ool00P0000Aoo`00001oo`40000000D007oo001o
o`00009oo`<00003Ool0000000D00003Ool0000000800004Ool00000Ool400000goo000000020000
1Woo001oogoo001oo`@00003Ool0000000800003Ool0000000D00003Ool0000000800003Ool00000
00@0009oo`03001oo`0000<00003Ool0000000800004Ool00000Ool400000goo0000000500000goo
0000000200000goo001oo`0200000goo001oo`0400000goo0000000500000goo00000002000017oo
000007oo100000=oo`00Ool00P0000Aoo`00Oomoo`H00003Ool0000000800003Ool0000000D00003
Ool0000000800003Ool0000000800006Ool007ooOol007oo100000=oo`0000000P0000Aoo`00001o
o`@00003Ool0000000D00004Ool000000002Ool01`00Ool00000Ool007oo00@00003Ool0000000D0
0003Ool0000000800004Ool00000Ool400000goo001oo`02000017oo001oogoo1P0000=oo`000000
0P0000=oo`0000001@0000=oo`0000000P0000=oo`0000000P0000Ioo`00Oomoo`00Ool400000goo
00000002000017oo000007oo100000=oo`0000001@0000Aoo`000000009oo`03001oo`0000<00003
Ool0000000800003Ool0000000D00003Ool0000000800004Ool00000Ool400000goo001oo`020000
0goo001oo`0700000goo0000000200000goo0000000500000goo0000000200000goo001oo`020000
17oo001oogoo0`0000Aoo`00001oo`@00004Ool00000Ool400000goo00000007000027oo001oogoo
001oo`00Ool100000005001oo`00001oo`0900000goo0000000D00001Woo000007oo001ooaT00003
Ool0000000800003Ool007oo01@00003Ool0000000L00003Ool0000000`00003Ool0000001800003
Ool007oo00@00003Ool0000001L00003Ool007oo00800003Ool0000001@00003Ool0000000L00003
Ool0000000`00003Ool0000001800003Ool007oo00@00003Ool0000001L00003Ool007oo00800003
Ool0000001@00003Ool0000000L00003Ool0000000`00003Ool0000000l00004Ool00000Ool60000
0goo0000000F0002Ool00`00Ool0000H00000goo00000004000017oo000007oo0P000Goo0@000000
0`00Ool0003o002/0001Ool100000003001oogoo0?moojeoo`400000o`00/@0000000`00Oomoo`3o
Oon]Ool100000003001oo`000?l00:`0005oo`40000000@007ooOol0009oo`03001oogoo009oo`06
001oogoo001oo`000Woo00<007ooOol00Woo00@007ooOol000Ioo`03001oo`00009oo`03001oogoo
009oo`06001oogoo001oo`001goo00@007ooOol000=oo`06001oogoo001oo`000Woo00<007ooOol0
0Woo00@007ooOol000Moo`03001oo`00009oo`05001oogooOol00002Ool00`00Ool00007Ool01000
Oomoo`0017oo00H007ooOol007oo0002Ool00`00Oomoo`02Ool00`00Ool00007Ool00`00Ool00002
Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000Moo`04001oogoo0003Ool01P00Oomoo`00Ool0009o
o`03001oogoo009oo`04001oogoo0007Ool00`00Ool00002Ool01@00Oomoogoo00000Woo00<007oo
00001goo00@007ooOol000Aoo`06001oogoo001oo`000Woo00D007ooOomoo`00009oo`03001oogoo
00Eoo`03001oo`00009oo`03001oogoo009oo`06001oogoo001oo`001goo00@007ooOol000=oo`06
001oogoo001oo`000Woo00<007ooOol00Woo00@007ooOol000Moo`03001oo`00009oo`05001oogoo
Ool00002Ool00`00Ool00007Ool01000Oomoo`0017oo00H007ooOol007oo0002Ool01@00Oomoogoo
00000Woo00<007ooOol01Goo00<007oo00000Woo00<007ooOol00Woo00H007ooOol007oo0007Ool0
0`00Ool00004Ool01P00Oomoo`00Ool0009oo`03001oogoo009oo`04001oogoo0007Ool00`00Ool0
0002Ool01@00Oomoogoo00000Woo00<007oo00001goo0@0000000`00Oomoo`05Ool2000;Ool20005
Ool2000;Ool2000;Ool20005Ool00`00Ool0000:Ool20006Ool2000;Ool2000:Ool20006Ool2000;
Ool20005Ool2000;Ool2000;Ool20005Ool2000;Ool20006Ool2000:Ool00`00Ool0000:Ool20006
Ool2000;Ool20005Ool2000;Ool2000;Ool20005Ool2000;Ool20006Ool2000:Ool00`00Ool0000:
Ool20006Ool2000;Ool20005Ool2000;Ool2000;Ool20005Ool2000;Ool20006Ool2000:Ool2000;
Ool20001Ool100000004001oogooOol20007Ool01@00Oomoogoo00001goo00<007ooOol01Goo00D0
07ooOomoo`0000Qoo`05001oogooOol00007Ool20006Ool01@00Oomoogoo00001goo0P001goo00D0
07ooOomoo`0000Moo`05001oogooOol00007Ool20007Ool01@00Oomoogoo00001goo00<007ooOol0
1Goo00D007ooOomoo`0000Qoo`05001oogooOol00007Ool20006Ool01@00Oomoogoo00001goo0P00
1goo00D007ooOomoo`0000Moo`05001oogooOol00007Ool20007Ool01@00Oomoogoo00001goo00<0
07ooOol01Goo00D007ooOomoo`0000Qoo`05001oogooOol00007Ool00`00Oomoo`05Ool01@00Oomo
ogoo00001goo0P001goo00D007ooOomoo`0000Moo`05001oogooOol00007Ool20007Ool01@00Oomo
ogoo00001Woo0P001goo00D007ooOomoo`0000Qoo`05001oogooOol00007Ool00`00Oomoo`05Ool0
1@00Oomoogoo00001goo0P001goo00D007ooOomoo`0000Moo`05001oogooOol00006Ool100000003
001oogoo00Moo`03001oo`0000Eoo`03001oo`0000Uoo`03001oo`0000Eoo`03001oogoo00Aoo`03
001oogoo00=oo`03001oo`0000Uoo`03001oo`0000Eoo`03001oo`0000Yoo`03001oo`0000Eoo`03
001oogoo00=oo`03001oogoo00=oo`03001oo`0000Yoo`03001oo`0000Eoo`03001oo`0000Uoo`03
001oo`0000Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Uoo`03001oo`0000Eoo`03
001oo`0000Yoo`03001oo`0000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Yoo`03
001oo`0000Eoo`03001oo`0000Uoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo00=oo`03
001oo`0000Uoo`03001oo`0000Eoo`03001oo`0000Yoo`03001oo`0000Eoo`03001oogoo00=oo`03
001oogoo00=oo`03001oo`0000Yoo`03001oo`0000Eoo`03001oo`0000Uoo`03001oo`0000Eoo`03
001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Uoo`03001oo`0000Eoo`03001oo`0000Yoo`03
001oo`0000Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000=oo`40000000<007oo0000
17oo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00@007ooOol0
00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00eoo`05001oogooOol00007Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<0
07oo000017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo009oo`03
001oogoo00aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oo`0000Aoo`03
001oogoo00Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol00Woo00<007oo000017oo00<007ooOol01Woo0@0000000`00
Ool0000<Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool10000
0003001oogoo00Aoo`04001oogoo0009Ool01000Oomoo`001Woo00<007ooOol01goo00@007ooOol0
00Uoo`03001oogoo00Aoo`04001oogoo0009Ool01000Oomoo`001goo00<007ooOol01goo00@007oo
Ool000Qoo`03001oogoo00Eoo`04001oogoo0009Ool01000Oomoo`001Woo00<007ooOol01goo00@0
07ooOol000Uoo`03001oogoo00Aoo`04001oogoo0009Ool01000Oomoo`001goo00<007ooOol01Woo
00D007ooOomoo`0000Qoo`03001oogoo00Eoo`04001oogoo0009Ool01000Oomoo`001Woo00<007oo
Ool01goo00@007ooOol000Uoo`03001oogoo00Aoo`04001oogoo0009Ool01000Oomoo`001goo00<0
07ooOol01Woo00@007ooOol000Uoo`03001oogoo00Eoo`04001oogoo0009Ool01000Oomoo`001Woo
00<007ooOol01goo00@007ooOol000Uoo`03001oogoo00Aoo`04001oogoo0009Ool01000Oomoo`00
1goo00<007ooOol01Woo00@007ooOol000Uoo`04001oogooOol100000003001oogoo00Uoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`40000000@007oo001oo`8000Moo`05001oogoo
Ool00006Ool00`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`09Ool20006Ool01@00Oomoogoo
00001goo0P002goo00<007ooOol01Goo00<007ooOol02Goo0P001goo00D007ooOomoo`0000Ioo`03
001oo`0000Yoo`03001oogoo00Ioo`03001oogoo00Uoo`8000Ioo`05001oogooOol00007Ool2000;
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool20007Ool01@00Oomoogoo00001Woo00<007oo00002Woo
00<007ooOol01Woo00<007ooOol027oo00<007oo00001Woo00D007ooOomoo`0000Moo`8000]oo`03
001oogoo00Eoo`03001oogoo00Uoo`8000Moo`05001oogooOol00006Ool2000;Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool00`00Ool00006Ool01@00Oomoogoo00001goo0P002goo00<007ooOol01Goo
00<007ooOol027oo0@0000000`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomo
ogoo000047oo00D007ooOomoo`0000Moo`03001oogoo00Uoo`03001oogoo00Ioo`05001oogooOol0
000?Ool01@00Oomoogoo000027oo00<007ooOol02Goo00<007ooOol01Goo00D007ooOomoo`00011o
o`05001oogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo00D0
07ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`05001oogooOol0000@Ool01@00Oomo
ogoo00001goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomoo`0000moo`05001oogooOol0
0008Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomoogoo000047oo00D007ooOomoo`0000Mo
o`03001oogoo00Uoo`03001oogoo00Ioo`05001oogooOol0000?Ool01@00Oomoogoo00000Woo0@00
00000`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool2000<Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool2000<Ool00`00Oomoo`04
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04
Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool2000<Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool10001Ool100000003001oogoo00]o
o`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`03001oo`00019oo`03001oogoo00]o
o`03001oogoo011oo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`03001oo`00019o
o`03001oogoo00]oo`03001oogoo011oo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00mo
o`03001oo`00019oo`03001oogoo00]oo`03001oogoo011oo`03001oo`00015oo`03001oogoo00ao
o`03001oogoo00moo`03001oo`00019oo`03001oogoo00]oo`03001oogoo00Eoo`40000000@007oo
Ool0009oo`03001oogoo00moo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001o
o`00015oo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`004Goo00<0
07oo00002Goo00<007ooOol027oo00<007ooOol01goo00<007oo00004Goo00@007ooOol000Uoo`03
001oogoo00Moo`03001oogoo00Moo`04001oogoo000AOol00`00Ool00009Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Ool0000AOol01000Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo
00@007ooOol0015oo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oo`00015o
o`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool100000003001oogoo00Qoo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo009oo`40000000<007ooOol027oo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol00Woo0@0000001000Oomoo`000Woo00<007ooOol03Woo00D007ooOomoo`0000]oo`03
001oogoo009oo`03001oogoo00Yoo`04001oogoo000@Ool01000Oomoo`0037oo00D007ooOomoo`00
00aoo`04001oogoo000@Ool01@00Oomoogoo00002goo00<007ooOol00Woo00<007ooOol02Woo00@0
07ooOol0011oo`04001oogoo000<Ool01@00Oomoogoo000037oo00@007ooOol0011oo`05001oogoo
Ool0000;Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01@00Oomoogoo000047oo00@007ooOol000ao
o`05001oogooOol0000<Ool01000Oomoo`0047oo00@007ooOol000aoo`03001oogoo009oo`03001o
ogoo00Uoo`05001oogooOol0000@Ool01000Oomoo`0037oo00D007ooOomoo`0000aoo`40000000<0
07ooOol02goo00<007oo00004goo00<007ooOol027oo00<007ooOol04Goo00<007oo000057oo00<0
07ooOol01goo00<007ooOol04Woo00<007oo00004goo00<007ooOol027oo00<007ooOol04Goo00<0
07oo000057oo00<007ooOol01goo00<007ooOol04Woo00<007oo00004goo00<007ooOol027oo00<0
07ooOol04Goo00<007oo000057oo00<007ooOol01goo00<007ooOol04Woo00<007oo00004goo00<0
07ooOol027oo00<007ooOol04Goo00<007oo000057oo00<007ooOol01goo00<007ooOol01goo0@00
00000`00Oomoo`05Ool2000;Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20006Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Ool0000:Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2000;Ool20005Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool0000:Ool20006
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool2000;Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20006Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool2000;Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool2000:Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool2000;Ool20006Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool10001Ool100000003001oogoo01Yoo`05001o
ogooOol0000@Ool01@00Oomoogoo000077oo00D007ooOomoo`0000moo`05001oogooOol0000LOol0
1@00Oomoogoo000047oo00D007ooOomoo`0001aoo`05001oogooOol0000?Ool01@00Oomoogoo0000
77oo00D007ooOomoo`00011oo`05001oogooOol0000LOol01@00Oomoogoo00003goo00D007ooOomo
o`0001aoo`05001oogooOol0000@Ool01@00Oomoogoo000077oo00D007ooOomoo`0000moo`05001o
ogooOol00002Ool100000005001oogooOol00008Ool01@00Oomoogoo00001goo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00D007ooOomoo`0000Qoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`05001oogooOol00007Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomoogoo000027oo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomoo`00
00Moo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`05001oogoo
Ool00008Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01@00
Oomoogoo00001goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo
00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Qoo`40000000<0
07ooOol00Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol04Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<0
07ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Goo0@0000000`00Oomoo`09Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0@
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0?
Ool00`00Oomoo`03Ool100000003001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo01Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo01=oo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo00Moo`03001o
ogoo00Moo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo01=oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo01Aoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo01=oo`04001oogooOol100000003
001oogoo00Aoo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000AOol00`00Oomoo`0<Ool0
0`00Oomoo`0?Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool01000Oomoo`004Goo
00<007ooOol037oo00<007ooOol03goo00<007oo00004Goo00<007ooOol037oo00<007ooOol03goo
00@007ooOol0015oo`03001oogoo00aoo`03001oogoo00moo`03001oo`00015oo`03001oogoo00ao
o`03001oogoo00moo`04001oogoo000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Ool0000=
Ool100000003001oo`0001Uoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo01Ioo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo01Moo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo01Moo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`40000000<007ooOol037oo00<007ooOol04Goo
00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Woo0@0000000`00Ool00004Ool00`00Oomo
o`0=Ool01@00Oomoogoo000077oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo009oo`03001oogoo00eoo`05001oogooOol0000LOol01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0001ao
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomo
o`0=Ool01@00Oomoogoo000077oo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo01Yo
o`40000000<007ooOol01goo00<007ooOol01goo00<007ooOol04Goo00@007ooOol001Aoo`03001o
ogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`07Ool00`00Oomoo`0AOol0
1000Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0001=oo`03001oogoo
00Moo`03001oogoo015oo`04001oogoo000COol00`00Oomoo`07Ool00`00Oomoo`0AOol01@00Oomo
ogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001=oo`03001oogoo00Moo`03
001oogoo015oo`05001oogooOol0000<Ool100000003001oogoo01]oo`03001oo`00019oo`03001o
o`0001ioo`03001oo`00015oo`03001oo`0001ioo`03001oo`00019oo`03001oo`0001ioo`03001o
o`00015oo`03001oo`0001ioo`03001oo`00019oo`03001oo`0001ioo`03001oo`00015oo`03001o
o`0001ioo`03001oo`00019oo`03001oo`0001ioo`03001oo`00015oo`03001oo`0000=oo`400000
00<007ooOol02Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo
00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo
00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo
00<007ooOol04Woo00<007ooOol00goo00<007ooOol02Goo0@0000001000Oomoogoo0P004Woo00<0
07oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P00
7goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<0
07oo00004Woo0P007Woo0@0000000`00Oomoo`0:Ool01@00Oomoogoo00004goo00<007ooOol01Woo
00<007ooOol04Goo00D007ooOomoo`0001Aoo`03001oogoo00Ioo`03001oogoo015oo`05001oogoo
Ool0000COol00`00Oomoo`06Ool00`00Oomoo`0AOol01@00Oomoogoo000057oo00<007ooOol01Woo
00<007ooOol04Goo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo015oo`05001oogoo
Ool0000COol00`00Oomoo`06Ool00`00Oomoo`0BOol01@00Oomoogoo00004goo00<007ooOol01Woo
00<007ooOol04Goo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo00Qoo`40000000<0
07ooOol06Woo00D007ooOomoo`00011oo`05001oogooOol0000LOol01@00Oomoogoo00003goo00D0
07ooOomoo`0001aoo`05001oogooOol0000@Ool01@00Oomoogoo000077oo00D007ooOomoo`0000mo
o`05001oogooOol0000LOol01@00Oomoogoo000047oo00D007ooOomoo`0001aoo`05001oogooOol0
000?Ool01@00Oomoogoo000077oo00D007ooOomoo`00011oo`05001oogooOol0000LOol01@00Oomo
ogoo00003goo00D007ooOomoo`00009oo`40000000<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool04Goo0P004goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol02Goo
00<007ooOol04Goo0P004goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Woo00<007oo
Ool02Goo00<007ooOol04Goo0P004goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol04Goo0P004goo00<007ooOol02Goo00<007ooOol04Woo00<007oo
Ool037oo0@0000000`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool0
0`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0UOol0
0`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool0
0`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0POol100000003001oogoo01Yoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo
00]oo`03001oogoo00=oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo
01Qoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo
00=oo`40005oo`40000000@007ooOol0009oo`03001oogoo00Eoo`03001oo`0000Moo`03001oo`00
00Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oo`0000Moo`03001oo`0000Moo`04001oogoo
0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`001goo00<007oo00001goo00<007oo
00002Goo00<007ooOol027oo00<007ooOol01goo00<007oo00001goo00<007oo00001goo00@007oo
Ool000Uoo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo0007Ool00`00Ool00007Ool00`00
Ool00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Ool00007Ool00`00Ool00007Ool01000
Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo00@007ooOol000Moo`03001oo`0000Moo`03
001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oo`0000Moo`03001oo`0000Moo`04
001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool100000003001oogoo02Aoo`03001oogoo
009oo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo009oo`03001oogoo
02eoo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo
00=oo`03001oogoo02eoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo
00Uoo`40000000<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol00Woo0@0000000`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0A
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`0AOol00`00Oomoo`02Ool100000003001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`05001o
ogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00D007ooOomo
o`0000moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00ioo`03001oogoo00eoo`05001oogooOol0000<Ool100000004001oogoo000GOol00`00Oomo
o`0JOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomo
o`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomo
o`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0KOol100000003
001oogoo00]oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo015oo`03001oo`0001Aoo`03
001oogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo015oo`03
001oo`0001Aoo`03001oogoo00Moo`03001oogoo019oo`03001oo`0001=oo`03001oogoo00Qoo`03
001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo019oo`03001oo`0001=oo`03
001oogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo00Moo`40
000000<007ooOol07goo00<007ooOol037oo00<007ooOol097oo00<007ooOol02goo00<007ooOol0
97oo00<007ooOol037oo00<007ooOol097oo00<007ooOol02goo00<007ooOol097oo00<007ooOol0
37oo00<007ooOol097oo00<007ooOol02goo00<007ooOol097oo00<007ooOol037oo00<007ooOol0
97oo00<007ooOol02goo00<007ooOol01Goo0@0000000`00Oomoo`05Ool00`00Oomoo`0;Ool00`00
Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00
Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00
Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0GOol10001
Ool100000003001oogoo00Ioo`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qo
o`03001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo019oo`8001Aoo`03001o
ogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo019oo`8001Ao
o`03001oogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03001oogoo019o
o`8001Aoo`03001oogoo00Qoo`03001oogoo015oo`03001oo`0000eoo`40000000<007ooOol06goo
00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06goo00<007ooOol05Goo
00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo
00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06goo00<007ooOol05Goo
00<007ooOol00@0000000`00Oomoo`0:Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<007oo
Ool03Goo00D007ooOomoo`00011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000?
Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007oo
Ool03Woo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000@
Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<007oo
Ool03Goo00D007ooOomoo`00011oo`03001oogoo00eoo`03001oogoo00Aoo`40000000<007ooOol0
8Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Goo00<007ooOol0:Woo00<007ooOol0
1Woo00<007ooOol0:Woo00<007ooOol01Goo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0
:Woo00<007ooOol01Goo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol0
1Goo00<007ooOol027oo0@0000001000Oomoogoo0P004goo00<007ooOol07Woo00<007ooOol04Goo
0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo
00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007Woo0@000000
0`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol0
0`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`03Ool0
0`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol0
0`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool0
0`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`08Ool100000003001oogoo01eoo`03001oogoo
011oo`03001oogoo021oo`03001oogoo00moo`03001oogoo021oo`03001oogoo011oo`03001oogoo
021oo`03001oogoo00moo`03001oogoo021oo`03001oogoo011oo`03001oogoo021oo`03001oogoo
00moo`03001oogoo021oo`03001oogoo011oo`03001oogoo021oo`03001oogoo00moo`03001oogoo
00=oo`40000000<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol04goo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol04goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol04goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol04goo00@007ooOomoo`40000000<007ooOol09Goo
00@007ooOol0039oo`03001oo`00039oo`04001oogoo000bOol00`00Ool0000bOol01000Oomoo`00
<Woo00<007oo0000<Woo00@007ooOol0039oo`03001oo`0000eoo`40000000<007oo000017oo00<0
07ooOol037oo00<007ooOol00goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<0
07ooOol067oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol067oo00<007ooOol00goo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00goo00<007ooOol067oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol06Woo0@0000000`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0A
Ool00`00Oomoo`0BOol00`00Oomoo`09Ool2000COol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00
Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0AOol2000;Ool00`00Oomoo`06
Ool100000003001oo`0001Qoo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001o
ogoo01Ioo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001o
ogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Yoo`03001o
ogoo01Ioo`03001oogoo01Yoo`40000000<007ooOol017oo00<007ooOol03Goo00<007ooOol03Woo
00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomo
o`0=Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo00D007oo
Oomoo`00011oo`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0
011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000<Ool100000003001oogoo00Mo
o`03001oogoo00Moo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Io
o`03001oogoo02Yoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Yo
o`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Yoo`03001oogoo00Io
o`03001oogoo029oo`40000000<007ooOol077oo0P004Woo00<007oo00007Woo00<007oo00004Goo
00<007oo00007goo0P004Woo00<007oo00007Woo00<007oo00004Goo00<007oo00007Woo00<007oo
00004Woo00<007oo00007Woo00<007oo00004Goo00<007oo00007Woo00<007oo00004Woo0P007goo
00<007oo00004Goo00<007oo00000goo0@0000000`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomo
o`0/Ool00`00Oomoo`03Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool00`00Oomo
o`03Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool00`00Oomoo`03Ool00`00Oomo
o`0]Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool00`00Oomoo`03Ool00`00Oomoo`0TOol100000003
001oogoo009oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03
001oogoo011oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo011oo`03
001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo011oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo011oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00Uoo`40000000D007ooOomoo`0001Eoo`03001o
ogoo01aoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo01aoo`03001o
ogoo01=oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo01=oo`03001o
ogoo01eoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo01=oo`03001oogoo01aoo`400000
00<007ooOol08Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Goo
00<007ooOol01Woo00<007ooOol0:Goo00<007ooOol01goo00<007ooOol0:Goo00<007ooOol01Woo
00<007ooOol0:Goo00<007ooOol01goo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol0:Goo
00<007ooOol01Woo00<007ooOol027oo0@0000000`00Oomoo`0:Ool01@00Oomoogoo00003goo00<0
07ooOol03Woo00<007ooOol03Woo00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`05
001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00<007oo
Ool03Goo00<007ooOol03Woo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05
001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo00<007oo
Ool03Woo00<007ooOol03Goo00D007ooOomoo`00011oo`03001oogoo00eoo`03001oogoo00Aoo`40
000000<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol0
6Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol0
5Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol0
6Woo00<007ooOol05Goo00<007ooOol00@0000000`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`0AOol2000COol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool0
0`00Oomoo`0AOol2000COol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomo
o`09Ool00`00Oomoo`0AOol2000COol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Oomoo`0AOol2000COol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomo
o`0<Ool100000003001oogoo00Eoo`03001oogoo00Yoo`03001oogoo02Ioo`03001oogoo00Yoo`03
001oogoo02Eoo`03001oogoo00Yoo`03001oogoo02Ioo`03001oogoo00Yoo`03001oogoo02Eoo`03
001oogoo00Yoo`03001oogoo02Ioo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00Yoo`03
001oogoo02Ioo`03001oogoo00Yoo`03001oogoo021oo`40000000<007ooOol06Woo00<007ooOol0
0Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol067oo00<007ooOol00goo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol06Goo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
6Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0
0goo00<007ooOol02goo00<007ooOol00goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
0goo0@000Goo0@0000000`00Oomoo`0;Ool00`00Ool0000bOol00`00Ool0000cOol00`00Ool0000b
Ool00`00Ool0000cOol00`00Ool0000bOol00`00Ool0000cOol00`00Ool0000bOol00`00Ool0000X
Ool100000003001oogoo025oo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Moo`03001o
ogoo02Qoo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Moo`03001oogoo02Qoo`03001o
ogoo00Qoo`03001oogoo02Qoo`03001oogoo00Moo`03001oogoo02Qoo`03001oogoo00Qoo`03001o
ogoo02Qoo`03001oogoo00Moo`03001oogoo00Moo`40000000@007ooOol0009oo`03001oogoo00mo
o`03001oo`0001ioo`03001oo`00015oo`04001oogoo000MOol01000Oomoo`004Goo00<007oo0000
7Woo00<007oo00004Goo00@007ooOol001eoo`04001oogoo000AOol00`00Ool0000NOol00`00Ool0
000AOol01000Oomoo`007Goo00@007ooOol0015oo`03001oo`0001ioo`03001oo`00015oo`04001o
ogoo000MOol100000003001oogoo02Aoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo00=o
o`03001oogoo02eoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo02eo
o`03001oogoo009oo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo02eoo`03001oogoo009o
o`03001oogoo02eoo`03001oogoo00=oo`03001oogoo00Uoo`40000000<007ooOol027oo00<007oo
Ool01Goo00<007ooOol02Goo0P004goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo0P004goo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool04Goo0P0037oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol00Woo
0@0000000`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomo
o`0[Ool00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`0[Ool00`00Oomo
o`05Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`0[Ool00`00Oomoo`05Ool00`00Oomo
o`0ZOol00`00Oomoo`05Ool00`00Oomoo`0SOol100000003001oogoo00=oo`03001oogoo00ioo`03
001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`05
001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<007oo
Ool03Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00D007oo
Oomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03
001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000<Ool100000004001oogoo000GOol00`00
Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00
Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00
Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0KOol10000
0003001oogoo025oo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Qoo`03001oogoo02Mo
o`03001oogoo00Qoo`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo02Moo`03001oogoo00Qo
o`03001oogoo02Moo`03001oogoo00Uoo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo02Mo
o`03001oogoo00Qoo`03001oogoo00Moo`40000000<007ooOol02goo00<007oo00004Goo00<007oo
Ool037oo00<007ooOol047oo0P004Woo00<007ooOol02goo00<007ooOol047oo00<007oo00004Goo
00<007ooOol037oo00<007ooOol03goo00<007oo00004Woo00<007ooOol02goo00<007ooOol047oo
00<007oo00004Goo00<007ooOol037oo00<007ooOol03goo00<007oo00004Woo00<007ooOol02goo
00<007ooOol047oo00<007oo00004Goo00<007ooOol037oo00<007ooOol03goo00<007oo00004Woo
00<007ooOol02goo00<007ooOol01Goo0@0000000`00Oomoo`0IOol00`00Oomoo`0HOol00`00Oomo
o`0HOol00`00Oomoo`0GOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomo
o`0GOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0GOol00`00Oomo
o`0HOol00`00Oomoo`0HOol00`00Oomoo`0HOol00`00Oomoo`0GOol10001Ool100000003001oogoo
00Eoo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo
00]oo`03001oogoo02Aoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo
02Aoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo
00]oo`03001oogoo021oo`40000000<007ooOol01Woo00<007ooOol027oo00<007ooOol04Woo0P00
57oo00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<007ooOol0
4Woo0P0057oo00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<0
07ooOol04Woo0P0057oo00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol0
27oo00<007ooOol04Woo0P0057oo00<007ooOol027oo00<007ooOol04Goo00<007oo00003Goo0@00
00000`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0K
Ool00`00Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0D
Ool00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0DOol00`00Oomoo`0K
Ool00`00Oomoo`0EOol00`00Oomoo`0100000003001oogoo01ioo`03001oogoo00ioo`03001oogoo
029oo`03001oogoo00ioo`03001oogoo025oo`03001oogoo00ioo`03001oogoo029oo`03001oogoo
00eoo`03001oogoo029oo`03001oogoo00ioo`03001oogoo029oo`03001oogoo00eoo`03001oogoo
029oo`03001oogoo00ioo`03001oogoo025oo`03001oogoo00ioo`03001oogoo00Aoo`40000000<0
07ooOol02Woo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo015oo`05001oogooOol0
000DOol00`00Oomoo`05Ool00`00Oomoo`0BOol01@00Oomoogoo00004goo00<007ooOol01Woo00<0
07ooOol04Goo00D007ooOomoo`0001Aoo`03001oogoo00Eoo`03001oogoo019oo`05001oogooOol0
000COol00`00Oomoo`06Ool00`00Oomoo`0AOol01@00Oomoogoo000057oo00<007ooOol01Goo00<0
07ooOol04Woo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo015oo`05001oogooOol0
000DOol00`00Oomoo`05Ool00`00Oomoo`08Ool100000005001oogooOol0000DOol00`00Oomoo`0N
Ool00`00Oomoo`0BOol00`00Oomoo`0MOol00`00Oomoo`0BOol00`00Oomoo`0NOol00`00Oomoo`0B
Ool00`00Oomoo`0MOol00`00Oomoo`0BOol00`00Oomoo`0NOol00`00Oomoo`0BOol00`00Oomoo`0M
Ool00`00Oomoo`0BOol00`00Oomoo`0NOol00`00Oomoo`0BOol00`00Oomoo`0LOol100000003001o
ogoo009oo`03001oogoo015oo`03001oogoo01ioo`03001oogoo015oo`03001oogoo01moo`03001o
ogoo015oo`03001oogoo01ioo`03001oogoo015oo`03001oogoo01moo`03001oogoo015oo`03001o
ogoo01ioo`03001oogoo015oo`03001oogoo01moo`03001oogoo015oo`03001oogoo01ioo`03001o
ogoo015oo`03001oogoo01eoo`40000000<007ooOol02Goo00<007ooOol00goo00<007ooOol04Goo
00<007ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Woo
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo
00<007ooOol04Woo00<007ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Goo
00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol017oo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol027oo
0@0000000`00Oomoo`0NOol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomo
o`0POol00`00Oomoo`0@Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomo
o`0@Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0@Ool00`00Oomo
o`0POol00`00Oomoo`0?Ool00`00Oomoo`03Ool100000003001oogoo01]oo`03001oogoo01Aoo`03
001oogoo01aoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo01Aoo`03001oogoo01aoo`03
001oogoo01=oo`03001oogoo01aoo`03001oogoo01Aoo`03001oogoo01aoo`03001oogoo01=oo`03
001oogoo01aoo`03001oogoo01Aoo`03001oogoo01aoo`03001oogoo01=oo`04001oogooOol10000
0003001oogoo00Moo`03001oogoo00Moo`03001oogoo015oo`04001oogoo000COol00`00Oomoo`07
Ool00`00Oomoo`0BOol00`00Ool0000DOol00`00Oomoo`07Ool00`00Oomoo`0AOol01000Oomoo`00
4goo00<007ooOol01goo00<007ooOol04Woo00<007oo000057oo00<007ooOol01goo00<007ooOol0
4Goo00@007ooOol001=oo`03001oogoo00Moo`03001oogoo019oo`03001oo`0001Aoo`03001oogoo
00Moo`03001oogoo015oo`04001oogoo000COol00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Ool0
000=Ool100000003001oogoo00Aoo`03001oogoo00aoo`03001oogoo02Aoo`03001oogoo00aoo`03
001oogoo02=oo`03001oogoo00aoo`03001oogoo02Aoo`03001oogoo00aoo`03001oogoo02=oo`03
001oogoo00aoo`03001oogoo02Aoo`03001oogoo00aoo`03001oogoo02=oo`03001oogoo00aoo`03
001oogoo02Aoo`03001oogoo00aoo`03001oogoo01moo`40000000<007oo000037oo00<007ooOol0
2Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo0P002goo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol01Woo0@0000000`00Oomoo`0POol00`00Oomoo`0:
Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0V
Ool00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`09
Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`06
Ool100000003001oo`0001Qoo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001o
ogoo01Ioo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001o
ogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Yoo`03001o
ogoo01Ioo`03001oogoo01Yoo`40000000<007ooOol017oo00<007ooOol03Goo00<007ooOol08Woo
00<007ooOol03Goo00<007ooOol08goo00<007ooOol03Goo00<007ooOol08Woo00<007ooOol03Goo
00<007ooOol08goo00<007ooOol03Goo00<007ooOol08Woo00<007ooOol03Goo00<007ooOol08goo
00<007ooOol03Goo00<007ooOol08Woo00<007ooOol03Goo00<007ooOol07goo0@0000000`00Oomo
o`07Ool00`00Oomoo`06Ool00`00Oomoo`0BOol01000Oomoo`0057oo00<007ooOol01Woo00<007oo
Ool04Goo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo019oo`04001oogoo000DOol0
0`00Oomoo`06Ool00`00Oomoo`0AOol01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol0
4Woo00@007ooOol001Aoo`03001oogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00
Oomoo`06Ool00`00Oomoo`0BOol01000Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D0
07ooOomoo`0000aoo`40000000<007ooOol077oo00<007ooOol04goo00<007ooOol077oo00<007oo
Ool04goo00<007ooOol07Goo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol04goo00<007oo
Ool07Goo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol04goo00<007ooOol077oo00<007oo
Ool04goo00<007ooOol07Goo00<007ooOol04goo00@007ooOomoo`40000000<007ooOol07Goo00<0
07ooOol047oo00<007ooOol087oo00<007ooOol03goo00<007ooOol087oo00<007ooOol047oo00<0
07ooOol087oo00<007ooOol03goo00<007ooOol087oo00<007ooOol047oo00<007ooOol087oo00<0
07ooOol03goo00<007ooOol087oo00<007ooOol047oo00<007ooOol07goo00<007ooOol047oo00<0
07ooOol00goo0@0000000`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0B
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0A
Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0A
Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`09Ool100000003001o
ogoo009oo`03001oogoo011oo`03001oogoo021oo`03001oogoo011oo`03001oogoo01moo`03001o
ogoo011oo`03001oogoo021oo`03001oogoo011oo`03001oogoo01moo`03001oogoo011oo`03001o
ogoo021oo`03001oogoo011oo`03001oogoo01moo`03001oogoo011oo`03001oogoo021oo`03001o
ogoo011oo`03001oogoo01eoo`40000000D007ooOomoo`0001Eoo`03001oogoo01aoo`03001oogoo
01=oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo01=oo`03001oogoo
01eoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo
01=oo`03001oogoo01aoo`03001oogoo01=oo`03001oogoo01aoo`40000000<007ooOol02Woo00D0
07ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo019oo`04001oogoo000COol00`00Oomoo`07
Ool00`00Oomoo`0AOol01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@007oo
Ool001=oo`03001oogoo00Moo`03001oogoo015oo`04001oogoo000DOol00`00Oomoo`06Ool00`00
Oomoo`0BOol01000Oomoo`004goo00<007ooOol01goo00<007ooOol04Goo00@007ooOol001Aoo`03
001oogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`07Ool00`00Oomoo`07
Ool100000003001oogoo01moo`03001oogoo00eoo`03001oogoo029oo`03001oogoo00eoo`03001o
ogoo029oo`03001oogoo00ioo`03001oogoo029oo`03001oogoo00eoo`03001oogoo029oo`03001o
ogoo00ioo`03001oogoo029oo`03001oogoo00eoo`03001oogoo029oo`03001oogoo00ioo`03001o
ogoo029oo`03001oogoo00eoo`03001oogoo00Aoo`40000000<007ooOol06Woo00<007ooOol05Woo
00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo
00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo
00<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol00@00
00000`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0W
Ool00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomoo`09
Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomoo`09Ool00`00Oomoo`0V
Ool00`00Oomoo`09Ool00`00Oomoo`0QOol100000003001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo015oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yo
o`03001oogoo015oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo00Yoo`03001oogoo015oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo015o
o`03001oogoo00Yoo`03001oogoo015oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`03001o
ogoo00aoo`40000000<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Goo00<007ooOol05goo
00<007ooOol06Goo00<007ooOol05Woo00<007ooOol06Goo00<007ooOol05goo00<007ooOol06Goo
00<007ooOol05Woo00<007ooOol06Goo00<007ooOol05goo00<007ooOol06Goo00<007ooOol05Woo
00<007ooOol06Goo00<007ooOol05goo0@000Goo0@0000000`00Oomoo`0OOol00`00Oomoo`0<Ool0
0`00Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`0SOol0
0`00Oomoo`0=Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomoo`0=Ool0
0`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`05Ool1
00000003001oogoo00]oo`03001oo`00039oo`04001oogoo000bOol00`00Ool0000bOol00`00Ool0
000cOol00`00Ool0000bOol00`00Ool0000cOol00`00Ool0000bOol00`00Ool0000XOol100000004
001oogoo000FOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol0
0`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool100000003001oogoo00=oo`03001oogoo00moo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo
00=oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo
00moo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo
00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo
00Uoo`40000000<007ooOol027oo00<007ooOol017oo00<007ooOol02goo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<0
07ooOol047oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol00Woo0@0000000`00Oomoo`0L
Ool00`00Oomoo`0BOol00`00Oomoo`0NOol00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`0B
Ool00`00Oomoo`0NOol00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`0BOol00`00Oomoo`0N
Ool00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`0BOol00`00Oomoo`0NOol00`00Oomoo`0A
Ool00`00Oomoo`02Ool100000003001oogoo00Qoo`03001oogoo00Eoo`03001oogoo02Yoo`03001o
ogoo00Eoo`03001oogoo02]oo`03001oogoo00Eoo`03001oogoo02Yoo`03001oogoo00Eoo`03001o
ogoo02]oo`03001oogoo00Eoo`03001oogoo02Yoo`03001oogoo00Eoo`03001oogoo02]oo`03001o
ogoo00Eoo`03001oogoo02Yoo`03001oogoo00Eoo`03001oogoo02=oo`40000000<007ooOol097oo
00<007ooOol00Woo00<007ooOol0;Woo00D007ooOomoo`00031oo`03001oogoo009oo`03001oogoo
02ioo`05001oogooOol0000`Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool01@00Oomoogoo0000<7oo
00<007ooOol00Woo00<007ooOol0;Woo00D007ooOomoo`0000aoo`40000000@007ooOol0009oo`03
001oogoo00ioo`05001oogooOol0000LOol01@00Oomoogoo000047oo00@007ooOol001eoo`04001o
ogoo000@Ool01@00Oomoogoo000077oo00D007ooOomoo`00011oo`04001oogoo000MOol01000Oomo
o`0047oo00D007ooOomoo`0001aoo`05001oogooOol0000@Ool01000Oomoo`007Goo00@007ooOol0
011oo`05001oogooOol0000LOol01@00Oomoogoo000047oo00@007ooOol001eoo`40000000<007oo
Ool08Goo00<007ooOol027oo00<007ooOol09goo00<007ooOol02Goo00<007ooOol09goo00<007oo
Ool027oo00<007ooOol09goo00<007ooOol02Goo00<007ooOol09goo00<007ooOol027oo00<007oo
Ool09goo00<007ooOol02Goo00<007ooOol09goo00<007ooOol027oo00<007ooOol09goo00<007oo
Ool02Goo00<007ooOol01Woo0@0000000`00Oomoo`0;Ool00`00Ool0000cOol2000cOol00`00Ool0
000cOol2000cOol2000dOol2000cOol2000cOol00`00Ool0000XOol100000003001oogoo01Uoo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo01Qoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo01Qoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03
001oogoo00aoo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00=oo`40005oo`40000000<007ooOol01Goo00<007ooOol02goo00<007ooOol097oo00<0
07ooOol02goo00<007ooOol09Goo00<007ooOol02goo00<007ooOol097oo00<007ooOol02goo00<0
07ooOol09Goo00<007ooOol02goo00<007ooOol097oo00<007ooOol02goo00<007ooOol09Goo00<0
07ooOol02goo00<007ooOol097oo00<007ooOol02goo00<007ooOol087oo0@0000000`00Oomoo`0V
Ool2000cOol00`00Ool0000cOol2000cOol00`00Ool0000cOol2000cOol00`00Ool0000cOol2000c
Ool00`00Ool0000=Ool100000003001oogoo00Ioo`03001oogoo00Qoo`03001oogoo02Qoo`03001o
ogoo00Qoo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Qoo`03001o
ogoo02Moo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Qoo`03001oogoo02Moo`03001o
ogoo00Qoo`03001oogoo02Qoo`03001oogoo00Qoo`03001oogoo025oo`40000000<007ooOol06goo
00@007ooOol0011oo`04001oogoo000MOol01@00Oomoogoo000047oo00@007ooOol001eoo`04001o
ogoo000@Ool01000Oomoo`007Goo00D007ooOomoo`00011oo`04001oogoo000MOol01000Oomoo`00
47oo00@007ooOol001eoo`04001oogoo000@Ool01@00Oomoogoo00007Goo00@007ooOol0011oo`04
001oogoo000MOol01000Oomoo`0047oo00D007ooOomoo`00009oo`40000000<007ooOol02Woo00D0
07ooOomoo`00031oo`05001oogooOol0000aOol01@00Oomoogoo0000<7oo00D007ooOomoo`00035o
o`05001oogooOol0000`Ool01@00Oomoogoo0000<Goo00D007ooOomoo`00031oo`05001oogooOol0
000WOol100000003001oogoo029oo`03001oogoo00Ioo`03001oogoo02Yoo`03001oogoo00Eoo`03
001oogoo02Yoo`03001oogoo00Ioo`03001oogoo02Yoo`03001oogoo00Eoo`03001oogoo02Yoo`03
001oogoo00Ioo`03001oogoo02Yoo`03001oogoo00Eoo`03001oogoo02Yoo`03001oogoo00Ioo`03
001oogoo02Yoo`03001oogoo00Eoo`03001oogoo00Qoo`40000000D007ooOomoo`0001Aoo`03001o
ogoo01ioo`03001oogoo019oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo01ioo`03001o
ogoo019oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo01ioo`03001oogoo019oo`03001o
ogoo01eoo`03001oogoo019oo`03001oogoo01ioo`03001oogoo019oo`03001oogoo01aoo`400000
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol02Woo00<007ooOol01Goo00<007ooOol027oo0@0000000`00Oomoo`09Ool00`00Oomo
o`02Ool00`00Oomoo`0^Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomo
o`0^Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomo
o`02Ool00`00Oomoo`0]Ool00`00Oomoo`02Ool00`00Oomoo`0^Ool00`00Oomoo`02Ool00`00Oomo
o`0TOol100000003001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo000AOol0
0`00Ool00009Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Ool0000AOol00`00Ool0000:Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`004Goo00<007oo00002Goo00<007ooOol01goo
00<007ooOol027oo00<007oo00004Goo00<007oo00002Woo00<007ooOol01goo00<007ooOol01goo
00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Ool0000A
Ool00`00Ool0000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Ool0000AOol01000Oomoo`00
2Goo00<007ooOol01goo00<007ooOol027oo00<007oo00004Goo00<007oo00000goo0@0000000`00
Oomoo`0UOol01000Oomoo`00<Woo00<007oo0000<Woo00@007ooOol0039oo`03001oo`00039oo`04
001oogoo000bOol00`00Ool0000bOol01000Oomoo`00<Woo00<007oo00003Goo0@0000000`00Oomo
o`04Ool00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomo
o`0<Ool00`00Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomo
o`0TOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomo
o`0<Ool00`00Oomoo`0OOol100000003001oo`0001Uoo`03001oogoo01Qoo`03001oogoo01Moo`03
001oogoo01Uoo`03001oogoo01Moo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Uoo`03
001oogoo01Moo`03001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Uoo`03001oogoo01Moo`03
001oogoo01Qoo`03001oogoo01Moo`03001oogoo01Yoo`40000000<007ooOol037oo00<007ooOol0
4Goo00<007ooOol02Woo00<007ooOol04Goo0P004Woo00<007ooOol02goo00<007ooOol04Goo00<0
07ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo0P004Woo00<007ooOol02goo00<007ooOol0
47oo0P004goo00<007ooOol02Woo00<007ooOol04Goo0P004Woo00<007ooOol02goo00<007ooOol0
47oo0P004goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol02goo00<0
07ooOol01Goo0@0000000`00Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09
Ool00`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0V
Ool00`00Oomoo`0:Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`0:
Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`06Ool100000003001oo`0001Qoo`03001o
ogoo01Yoo`03001oogoo01Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Yoo`03001o
ogoo01Ioo`03001oogoo01Uoo`03001oogoo01Ioo`03001oogoo01Yoo`03001oogoo01Ioo`03001o
ogoo01Uoo`03001oogoo01Ioo`03001oogoo01Yoo`03001oogoo01Ioo`03001oogoo01Yoo`400000
00<007ooOol017oo00<007ooOol03Goo00<007ooOol08Woo00<007ooOol03Goo00<007ooOol08goo
00<007ooOol03Goo00<007ooOol08Woo00<007ooOol03Goo00<007ooOol08goo00<007ooOol03Goo
00<007ooOol08Woo00<007ooOol03Goo00<007ooOol08goo00<007ooOol03Goo00<007ooOol08Woo
00<007ooOol03Goo00<007ooOol07goo0@0000000`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomo
o`0BOol01000Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0001=oo`03
001oogoo00Ioo`03001oogoo019oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`0AOol0
1@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001Aoo`03001oogoo
00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00Oomoo`0BOol01000
Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0000aoo`40000000<007oo
Ool077oo00<007ooOol04Woo00<007ooOol07Goo00<007ooOol04goo00<007ooOol07Goo00<007oo
Ool04Woo00<007ooOol07Goo00<007ooOol04goo00<007ooOol07Goo00<007ooOol04Woo00<007oo
Ool07Goo00<007ooOol04goo00<007ooOol07Goo00<007ooOol04Woo00<007ooOol07Goo00<007oo
Ool04goo00@007ooOomoo`40000000<007ooOol07Goo00<007ooOol047oo00<007ooOol087oo00<0
07ooOol047oo00<007ooOol07goo00<007ooOol047oo00<007ooOol087oo00<007ooOol047oo00<0
07ooOol07goo00<007ooOol047oo00<007ooOol07goo00<007ooOol047oo00<007ooOol087oo00<0
07ooOol047oo00<007ooOol07goo00<007ooOol047oo00<007ooOol00goo0@0000000`00Oomoo`09
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0A
Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0A
Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03
Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0B
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool100000003001oogoo009oo`03001oogoo011oo`03001o
ogoo021oo`03001oogoo011oo`03001oogoo01moo`03001oogoo011oo`03001oogoo021oo`03001o
ogoo011oo`03001oogoo01moo`03001oogoo011oo`03001oogoo021oo`03001oogoo011oo`03001o
ogoo01moo`03001oogoo011oo`03001oogoo021oo`03001oogoo011oo`03001oogoo01eoo`400000
00D007ooOomoo`0001Eoo`03001oogoo01aoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo
01=oo`03001oogoo01aoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo
01aoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo01aoo`03001oogoo
01=oo`03001oogoo01aoo`40000000<007ooOol02Woo00@007ooOol001Aoo`03001oogoo00Ioo`03
001oogoo019oo`04001oogoo000COol00`00Oomoo`07Ool00`00Oomoo`0AOol01000Oomoo`0057oo
00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001=oo`03001oogoo00Moo`03001oogoo015o
o`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`0BOol01000Oomoo`004goo00<007ooOol0
1goo00<007ooOol04Goo00@007ooOol001Aoo`03001oogoo00Ioo`03001oogoo019oo`04001oogoo
000COol00`00Oomoo`07Ool00`00Oomoo`07Ool100000003001oogoo01moo`03001oogoo00eoo`03
001oogoo029oo`03001oogoo00eoo`03001oogoo02=oo`03001oogoo00eoo`03001oogoo029oo`03
001oogoo00eoo`03001oogoo02=oo`03001oogoo00aoo`03001oogoo02=oo`03001oogoo00eoo`03
001oogoo029oo`03001oogoo00eoo`03001oogoo02=oo`03001oogoo00eoo`03001oogoo00Aoo`40
000000<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol0
6Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol0
5Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol0
6Woo00<007ooOol05Goo00<007ooOol00@0000000`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`0VOol00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomo
o`09Ool00`00Oomoo`0WOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomo
o`0WOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0QOol100000003
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo015oo`8001=oo`03001oogoo00Yoo`03001oogoo
015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`8001=oo`03001oogoo00Yoo`03
001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`8001=oo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`8001=oo`03
001oogoo00Yoo`03001oogoo015oo`03001oogoo00aoo`40000000<007ooOol06Woo00<007ooOol0
0Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol0
3Goo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0
6Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0
0Woo0@000Goo0@0000000`00Oomoo`0;Ool00`00Ool0000COol00`00Oomoo`08Ool00`00Oomoo`0A
Ool01000Oomoo`004goo00<007ooOol01goo00<007ooOol04Woo00<007oo00004goo00<007ooOol0
27oo00<007ooOol04Goo00@007ooOol001=oo`03001oogoo00Moo`03001oogoo019oo`03001oo`00
01=oo`03001oogoo00Qoo`03001oogoo015oo`03001oo`0001Aoo`03001oogoo00Moo`03001oogoo
015oo`04001oogoo000COol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Ool0000DOol00`00Oomo
o`07Ool00`00Oomoo`07Ool100000004001oogoo000FOol00`00Oomoo`0LOol00`00Oomoo`0DOol0
0`00Oomoo`0KOol00`00Oomoo`0DOol00`00Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`0KOol0
0`00Oomoo`0DOol00`00Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`0KOol00`00Oomoo`0DOol0
0`00Oomoo`0LOol00`00Oomoo`0DOol00`00Oomoo`0KOol100000003001oogoo00=oo`03001oogoo
00moo`03001oogoo021oo`03001oogoo00moo`03001oogoo025oo`03001oogoo00moo`03001oogoo
021oo`03001oogoo00moo`03001oogoo025oo`03001oogoo00moo`03001oogoo021oo`03001oogoo
00moo`03001oogoo025oo`03001oogoo00moo`03001oogoo021oo`03001oogoo00moo`03001oogoo
01ioo`40000000<007ooOol027oo00<007ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<0
07ooOol04Woo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<0
07ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol017oo00<0
07ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Woo00<0
07ooOol00Woo00<007ooOol04Woo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<0
07ooOol04Goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00<0
07ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol02Goo0@0000000`00Oomoo`0M
Ool00`00Oomoo`0@Ool00`00Oomoo`0OOol00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`0@
Ool00`00Oomoo`0OOol00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`0@Ool00`00Oomoo`0O
Ool00`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`0@Ool00`00Oomoo`0OOol00`00Oomoo`0A
Ool00`00Oomoo`02Ool100000003001oogoo01aoo`03001oogoo019oo`03001oogoo01ioo`03001o
ogoo019oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo01ioo`03001oogoo019oo`03001o
ogoo01eoo`03001oogoo019oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo01ioo`03001o
ogoo019oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo009oo`40000000<007ooOol027oo
00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo
00<007ooOol04Woo00D007ooOomoo`0001Aoo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo
009oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo019oo`05001oogooOol0000DOol00`00
Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00
Oomoo`0BOol01@00Oomoogoo000057oo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo
00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Woo00D007ooOomoo`0000aoo`40000000<0
07ooOol00goo00<007ooOol03Woo00<007ooOol08Woo00<007ooOol03Woo00<007ooOol08Goo00<0
07ooOol03Woo00<007ooOol08Woo00<007ooOol03Woo00<007ooOol08Goo00<007ooOol03Woo00<0
07ooOol08Woo00<007ooOol03Woo00<007ooOol08Goo00<007ooOol03Woo00<007ooOol08Woo00<0
07ooOol03Woo00<007ooOol07Woo0@0000001000Oomoo`005goo00<007ooOol06Woo00<007ooOol0
5Goo00<007ooOol06goo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol0
6goo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06goo00<007ooOol0
5Goo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06goo0@0000000`00Oomoo`0;Ool2000D
Ool00`00Oomoo`08Ool00`00Oomoo`0BOol2000COol00`00Oomoo`09Ool00`00Oomoo`0AOol2000D
Ool00`00Oomoo`08Ool00`00Oomoo`0BOol2000COol00`00Oomoo`09Ool00`00Oomoo`0AOol2000D
Ool00`00Oomoo`08Ool00`00Oomoo`0BOol2000COol00`00Oomoo`09Ool00`00Oomoo`0AOol2000D
Ool00`00Oomoo`08Ool00`00Oomoo`0BOol2000COol00`00Oomoo`09Ool00`00Oomoo`06Ool10000
0003001oogoo021oo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo00]oo`03001oogoo02Eo
o`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo00]o
o`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo00]oo`03001oogoo02Eo
o`03001oogoo00]oo`03001oogoo00Eoo`40000000<007ooOol06Goo00<007ooOol067oo00<007oo
Ool067oo00<007ooOol05goo00<007ooOol067oo00<007ooOol067oo00<007ooOol067oo00<007oo
Ool05goo00<007ooOol067oo00<007ooOol067oo00<007ooOol067oo00<007ooOol05goo00<007oo
Ool067oo00<007ooOol067oo00<007ooOol067oo00<007ooOol06Goo0@0000000`00Oomoo`05Ool0
0`00Oomoo`0;Ool00`00Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Ool0
000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool0
0`00Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool00`00Oomo
o`0@Ool00`00Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool0
0`00Oomoo`0@Ool00`00Ool0000=Ool100000003001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
02Qoo`03001oogoo00Qoo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo
00Qoo`03001oogoo02Moo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Qoo`03001oogoo
02Moo`03001oogoo00Qoo`03001oogoo02Qoo`03001oogoo00Qoo`03001oogoo025oo`40000000<0
07ooOol06goo00<007ooOol057oo00<007ooOol06goo00<007ooOol05Goo00<007ooOol06goo00<0
07ooOol057oo00<007ooOol06goo00<007ooOol05Goo00<007ooOol06goo00<007ooOol057oo00<0
07ooOol06goo00<007ooOol05Goo00<007ooOol06goo00<007ooOol057oo00<007ooOol06goo00<0
07ooOol05Goo00<007ooOol00@0000000`00Oomoo`0:Ool01@00Oomoogoo00003goo00<007ooOol0
3Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol03goo00<007ooOol0
3Goo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo00moo`03001oogoo00eoo`05001oogooOol0000?Ool00`00Oomoo`0>Ool0
0`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol03goo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00D007ooOomoo`0000moo`03001o
ogoo00moo`03001oogoo00=oo`40000000<007ooOol08Woo00<007ooOol01Woo00<007ooOol0:Woo
00<007ooOol01Goo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Goo
00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Goo00<007ooOol0:Woo
00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Goo00<007ooOol027oo0@0000001000Oomo
ogoo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<0
07ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<0
07ooOol07Woo00<007ooOol04Goo0P007Woo0@0000000`00Oomoo`09Ool00`00Oomoo`02Ool00`00
Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00
Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00
Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00
Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00
Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00
Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00
Oomoo`08Ool100000003001oogoo01]oo`04001oogoo000@Ool01000Oomoo`007Woo00<007oo0000
4Goo00@007ooOol001eoo`04001oogoo000@Ool01000Oomoo`007Woo00<007oo00004Goo00@007oo
Ool001eoo`04001oogoo000@Ool01000Oomoo`007Goo00@007ooOol0015oo`03001oo`0001ioo`04
001oogoo000@Ool01000Oomoo`007Goo00@007ooOol0015oo`03001oo`0000=oo`40000000<007oo
Ool01goo00<007ooOol01goo00<007ooOol0:7oo00<007ooOol01goo00<007ooOol0:Goo00<007oo
Ool01goo00<007ooOol0:7oo00<007ooOol01goo00<007ooOol0:Goo00<007ooOol01goo00<007oo
Ool0:7oo00<007ooOol01goo00<007ooOol0:Goo00<007ooOol01goo00<007ooOol0:7oo00<007oo
Ool01goo00<007ooOol08Woo0@0000000`00Oomoo`0UOol01000Oomoo`00<Woo00<007oo0000<Woo
00@007ooOol0039oo`03001oo`00039oo`04001oogoo000bOol00`00Ool0000bOol01000Oomoo`00
<Woo00<007oo00003Goo0@0000000`00Ool00004Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00
Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00
Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00
Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00
Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0JOol100000003001oogoo021o
o`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo00Yo
o`03001oogoo02Eoo`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo00Yoo`03001oogoo02Eo
o`03001oogoo00]oo`03001oogoo02Eoo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo00]o
o`03001oogoo00Eoo`40000000<007ooOol037oo00<007ooOol04Woo00<007ooOol02Goo00<007oo
Ool04Goo0P004goo00<007ooOol02Goo00<007ooOol04Goo0P0057oo00<007ooOol02Goo00<007oo
Ool04Goo0P004goo00<007ooOol02Goo00<007ooOol04Goo0P004goo00<007ooOol02Woo00<007oo
Ool04Goo0P004goo00<007ooOol02Goo00<007ooOol04Goo0P004goo00<007ooOol02Goo00<007oo
Ool04Woo0P004goo00<007ooOol02Goo00<007ooOol01Woo0@0000000`00Ool0000HOol00`00Oomo
o`0JOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomo
o`0FOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomo
o`0IOol00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`0JOol100000003
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0
011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`00011o
o`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool01@00Oomoogoo000037oo0@0000000`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0ZOol0
0`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool0
0`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0YOol0
0`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0ROol100000003001oogoo
01aoo`03001oogoo019oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo
019oo`03001oogoo01eoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo
01eoo`03001oogoo01=oo`03001oogoo01eoo`03001oogoo019oo`03001oogoo01eoo`03001oogoo
01=oo`04001oogooOol100000003001oogoo00Uoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo011oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo015oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo015oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo011oo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo009oo`400000
00<007ooOol08goo00<007ooOol017oo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol0;7oo
00<007ooOol017oo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol017oo
00<007ooOol0;7oo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol017oo00<007ooOol0;7oo
00<007ooOol00goo00<007ooOol02Goo0@0000001000Oomoogoo0P004Woo00<007oo00007Woo00<0
07oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<0
07oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P00
7Woo0@0000000`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00
Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`0YOol00`00
Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00
Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`07Ool100000003001oogoo00Yoo`04001oogoo000A
Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol0
3Woo00@007ooOol0015oo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000@Ool00`00Oomo
o`0=Ool00`00Oomoo`0>Ool01000Oomoo`004Goo00<007ooOol037oo00<007ooOol03goo00@007oo
Ool0011oo`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000AOol00`00Oomoo`0<Ool00`00
Oomoo`0?Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol017oo0@0000000`00Oomoo`0J
Ool00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0F
Ool00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`0I
Ool00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0F
Ool00`00Oomoo`0100000003001oogoo00Ioo`03001oogoo00Uoo`03001oogoo015oo`8001=oo`03
001oogoo00Uoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo015oo`80
01=oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo
015oo`8001=oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo019oo`03001oogoo00Uoo`03
001oogoo015oo`8001=oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00aoo`40000000<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol03Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02Woo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol03Goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol037oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo0@000Goo0@0000000`00Oomoo`0;Ool00`00
Ool0000bOol01000Oomoo`00<Goo00@007ooOol0039oo`04001oogoo000aOol01000Oomoo`00<Woo
00@007ooOol0035oo`04001oogoo000bOol01000Oomoo`009goo0@0000001000Oomoo`005Woo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol057oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol057oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo0@0000000`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0?
Ool00`00Oomoo`0QOol00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0Q
Ool00`00Oomoo`0?Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0QOol00`00Oomoo`0?
Ool00`00Oomoo`0POol00`00Oomoo`0?Ool00`00Oomoo`0NOol100000003001oogoo00Qoo`03001o
ogoo00Aoo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo00Aoo`03001o
ogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo019oo`03001o
ogoo009oo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001o
ogoo015oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001o
ogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001o
ogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo015oo`03001o
ogoo00=oo`03001oogoo00Uoo`40000000<007ooOol077oo0P004Woo0P007goo0P004goo0P007goo
0P004Woo0P007goo0P004goo0P007goo0P004Woo0P007goo0P004goo0P007goo0P004Woo0P007goo
0P004goo0P000goo0@0000000`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomo
o`06Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomo
o`0ZOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Oomo
o`06Ool00`00Oomoo`0ZOol00`00Oomoo`05Ool00`00Oomoo`0SOol100000003001oogoo00=oo`03
001oogoo00ioo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00ioo`03
001oogoo00eoo`05001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007oo
Ool03Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo00<007oo
Ool03Goo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo00eoo`03001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000<Ool100000004001o
ogoo000GOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00
Oomoo`0JOol00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00
Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0EOol00`00Oomoo`0JOol00`00Oomoo`0EOol00`00
Oomoo`0KOol100000003001oogoo00]oo`8001Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=o
o`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=o
o`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=o
o`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=o
o`03001oogoo00Uoo`03001oogoo00Ioo`40000000<007oo00006Goo00<007ooOol017oo00<007oo
Ool02goo00<007ooOol00goo00<007ooOol067oo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool017oo00<007ooOol05goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool067oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol067oo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol067oo00<007ooOol00goo00<007oo
Ool02goo00<007ooOol00goo00<007ooOol067oo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool017oo00<007ooOol05goo00<007ooOol017oo00<007ooOol02goo00<007ooOol01Goo0@000000
0`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`0TOol00`00Oomoo`0;Ool00`00Oomoo`0UOol0
0`00Oomoo`0;Ool00`00Oomoo`0TOol00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool0
0`00Oomoo`0TOol00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool00`00Oomoo`0TOol0
0`00Oomoo`0;Ool00`00Oomoo`0POol100000003001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
019oo`8001Aoo`03001oogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03001oogoo00Qoo`03
001oogoo019oo`8001Aoo`03001oogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03001oogoo
00Qoo`03001oogoo019oo`8001Aoo`03001oogoo00Qoo`03001oogoo015oo`03001oo`0001=oo`03
001oogoo00Qoo`03001oogoo019oo`8001Aoo`03001oogoo00Qoo`03001oogoo015oo`03001oo`00
00eoo`40000000<007ooOol06goo00<007ooOol057oo00<007ooOol06goo00<007ooOol05Goo00<0
07ooOol06goo00<007ooOol057oo00<007ooOol06goo00<007ooOol05Goo00<007ooOol06goo00<0
07ooOol057oo00<007ooOol06goo00<007ooOol05Goo00<007ooOol06goo00<007ooOol057oo00<0
07ooOol06goo00<007ooOol05Goo00<007ooOol00@0000000`00Oomoo`0:Ool01@00Oomoogoo0000
3goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
3goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol03goo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0
37oo00<007ooOol03goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0
3Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol03goo00<007ooOol0
0goo0@0000001@00Oomoogoo000057oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol027oo0@0000000`00Oomoo`02Ool00`00Oomo
o`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`08Ool100000003001oogoo00Uoo`03001oogoo009oo`03001oogoo02ioo`03
001oogoo009oo`03001oogoo02eoo`03001oogoo009oo`03001oogoo02ioo`03001oogoo009oo`03
001oogoo02eoo`03001oogoo009oo`03001oogoo02ioo`03001oogoo009oo`03001oogoo02eoo`03
001oogoo009oo`03001oogoo02ioo`03001oogoo009oo`03001oogoo02Aoo`40000000<007ooOol0
6goo00@007ooOol0011oo`04001oogoo000NOol00`00Ool0000AOol01000Oomoo`007Goo00@007oo
Ool0011oo`04001oogoo000MOol01000Oomoo`004Goo00@007ooOol001eoo`04001oogoo000@Ool0
1000Oomoo`007Goo00@007ooOol0015oo`04001oogoo000MOol01000Oomoo`0047oo00@007ooOol0
01eoo`04001oogoo000AOol00`00Ool00003Ool100000003001oo`0000Aoo`04001oogoo0009Ool0
0`00Ool00005Ool00`00Oomoo`09Ool01000Oomoo`002goo00<007ooOol00goo00<007oo00002Woo
00<007oo000017oo00<007ooOol02Woo00<007oo000037oo00<007ooOol00Woo00@007ooOol000Uo
o`03001oo`0000Eoo`03001oogoo00Uoo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Ool00009
Ool01000Oomoo`0017oo00<007ooOol02Woo00<007oo000037oo00<007ooOol00Woo00@007ooOol0
00Uoo`03001oo`0000Eoo`03001oogoo00Uoo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Ool0
0009Ool01000Oomoo`0017oo00<007ooOol02Woo00<007oo000037oo00<007ooOol00Woo00@007oo
Ool000Uoo`03001oo`0000Eoo`03001oogoo00Uoo`04001oogoo000;Ool00`00Oomoo`03Ool00`00
Ool00009Ool01000Oomoo`0017oo00<007ooOol02Woo00<007oo00003Goo0@0000000`00Oomoo`0P
Ool00`00Oomoo`0:Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0:
Ool00`00Oomoo`0UOol00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0U
Ool00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`0:Ool00`00Oomoo`0UOol00`00Oomoo`0;
Ool00`00Oomoo`05Ool100000003001oogoo00]oo`8001Aoo`03001oogoo00Uoo`03001oogoo015o
o`8001=oo`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qoo`03001oogoo019o
o`8001=oo`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qoo`03001oogoo019o
o`8001=oo`03001oogoo00Uoo`03001oogoo015oo`8001Aoo`03001oogoo00Qoo`03001oogoo019o
o`8001=oo`03001oogoo00Uoo`03001oogoo00Ioo`40000000@007ooOol000=oo`03001oogoo00eo
o`05001oogooOol0000LOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol06Woo00D0
07ooOomoo`0000moo`05001oogooOol0000LOol01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol06Goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0001aoo`05001oogooOol0
000?Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomo
ogoo000077oo00D007ooOomoo`0000moo`05001oogooOol0000MOol100000003001oogoo00Moo`03
001oogoo00Ioo`03001oogoo019oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`0AOol0
1@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001Aoo`03001oogoo
00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00Oomoo`0BOol01000
Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0001=oo`03001oogoo00Io
o`03001oogoo019oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`0AOol01@00Oomoogoo
000037oo0@0000000`00Oomoo`0LOol2000BOol2000OOol2000COol2000OOol2000BOol2000OOol2
000COol2000OOol2000BOol2000OOol2000COol2000OOol2000BOol2000OOol2000COol20003Ool1
00000003001oogoo00Uoo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo
015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo
00Aoo`03001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo
015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo
00Aoo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo
015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo
00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo00Uoo`40000000@007ooOomoo`80019o
o`03001oo`0001ioo`03001oo`00019oo`8001moo`80019oo`03001oo`0001ioo`03001oo`00019o
o`8001moo`80019oo`03001oo`0001ioo`03001oo`00019oo`8001moo`80019oo`03001oo`0001io
o`03001oo`00019oo`8001ioo`40000000<007ooOol02Woo00@007ooOol001Aoo`03001oogoo00Io
o`03001oogoo019oo`04001oogoo000COol00`00Oomoo`07Ool00`00Oomoo`0AOol01000Oomoo`00
57oo00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001=oo`03001oogoo00Moo`03001oogoo
015oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`0BOol01000Oomoo`004goo00<007oo
Ool01goo00<007ooOol04Goo00@007ooOol001Aoo`03001oogoo00Ioo`03001oogoo019oo`04001o
ogoo000COol00`00Oomoo`07Ool00`00Oomoo`07Ool100000003001oogoo01Yoo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Yoo`05001oogooOol0000?Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomo
o`0IOol00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomo
o`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomo
o`0=Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomo
o`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00000Woo0@00
00000`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0AOol2000COol00`00Oomoo`0:Ool00`00
Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0AOol2000COol00`00Oomoo`09
Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0AOol2000COol00`00
Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0AOol2000C
Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0<Ool100000003001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo01Moo`40005oo`40000000<007ooOol02Woo00@007ooOol0015oo`03001oogoo00aoo`03001o
ogoo00moo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`004Goo00<0
07ooOol037oo00<007ooOol03goo00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`04
001oogoo000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool01000Oomoo`0047oo00<007ooOol03Goo
00<007ooOol03Woo00@007ooOol0015oo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000@
Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool100000005001oogooOol0000EOol00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool1
00000003001oogoo00=oo`03001oogoo00moo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo
00moo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo
00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
00moo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Uoo`40000000<007ooOol027oo00<0
07ooOol017oo00<007ooOol02goo00<007ooOol047oo00<007ooOol02goo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<0
07ooOol047oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol047oo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol02goo00<007ooOol047oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol04Goo00<007ooOol00Woo0@0000000`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol02Goo00<007ooOol01Woo00<007oo
Ool027oo00<007ooOol01Woo00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`05001oogooOol00008Ool00`00Oomoo`08
Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01@00Oomoogoo
000027oo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Woo00D007ooOomoo`0000Qoo`04001oogooOol100000004001oogoo0002Ool00`00Oomoo`0>
Ool01@00Oomoogoo000077oo00D007ooOomoo`00011oo`04001oogoo000MOol01000Oomoo`0047oo
00D007ooOomoo`0001aoo`05001oogooOol0000@Ool01000Oomoo`007Goo00@007ooOol0011oo`05
001oogooOol0000LOol01@00Oomoogoo000047oo00@007ooOol001eoo`04001oogoo000@Ool01@00
Oomoogoo000077oo00D007ooOomoo`00011oo`04001oogoo000MOol100000003001oogoo00]oo`80
01Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=oo`03001oogoo00Uoo`03001oogoo015oo`80
01Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=oo`03001oogoo00Uoo`03001oogoo015oo`80
01Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=oo`03001oogoo00Uoo`03001oogoo015oo`80
01Aoo`03001oogoo00Qoo`03001oogoo019oo`8001=oo`03001oogoo00Uoo`03001oogoo00Ioo`40
000000<007oo00001Goo0P002Woo00<007oo00001Goo00<007ooOol017oo00<007ooOol00goo0P00
1Goo00<007ooOol017oo00<007ooOol00goo00<007oo00002Woo00<007oo00001Goo00<007ooOol0
0goo00<007ooOol00goo00<007oo00001Goo00<007ooOol017oo00<007ooOol00goo0P002Woo00<0
07oo00001Goo00<007ooOol017oo00<007ooOol00goo0P001Goo00<007ooOol017oo00<007ooOol0
0goo00<007oo00002Woo0P001Goo00<007ooOol017oo00<007ooOol00goo00<007oo00001Goo00<0
07ooOol017oo00<007ooOol00goo0P002Woo00<007oo00001Goo00<007ooOol017oo00<007ooOol0
0goo0P001Goo00<007ooOol017oo00<007ooOol00goo00<007oo00002Woo0P001Goo00<007ooOol0
17oo00<007ooOol00goo00<007oo00001Goo00<007ooOol017oo00<007ooOol00goo0P002Woo00<0
07oo00001Goo00<007ooOol017oo00<007ooOol00goo0P001Goo00<007ooOol017oo00<007ooOol0
0goo00<007oo00002Woo0P001Goo00<007ooOol017oo00<007ooOol00goo00<007oo00001Goo00<0
07ooOol01Goo0@0000000`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`00
47oo00@007ooOol000aoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000AOol01000Oomo
o`002goo00<007ooOol00Woo00<007ooOol02Woo00@007ooOol0011oo`04001oogoo000<Ool00`00
Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`004Goo00@007ooOol000]oo`03001oogoo009oo`03
001oogoo00Yoo`04001oogoo000@Ool01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol02Goo
00@007ooOol0015oo`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`00
47oo00@007ooOol000aoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000AOol01000Oomo
o`000Woo0@0000000`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`08Ool100000003001oogoo
009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Qoo`40000000<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`08Ool0
0`00Oomoo`06Ool01000Oomoo`004Goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Mo
o`04001oogoo000@Ool01000Oomoo`002Goo00<007ooOol027oo00<007ooOol01Woo00@007ooOol0
015oo`04001oogoo0008Ool00`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoo`0047oo00@007oo
Ool000Uoo`03001oogoo00Qoo`03001oogoo00Ioo`04001oogoo000AOol01000Oomoo`0027oo00<0
07ooOol027oo00<007ooOol01goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool01000Oomoo`004Goo00@007ooOol0009oo`40000000<007ooOol017oo00<007oo
Ool037oo00<007ooOol047oo00<007oo00004Goo00<007ooOol037oo00<007ooOol03goo00<007oo
00004Goo00<007ooOol037oo00<007ooOol03goo00@007ooOol0015oo`03001oogoo00aoo`03001o
ogoo00moo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000AOol00`00
Oomoo`0<Ool00`00Oomoo`0?Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool01000
Oomoo`004Goo00<007ooOol037oo00<007ooOol03goo00<007oo00003Goo0@0000000`00Ool0000;
Ool2000<Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool2000;
Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool2000<Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool2000;Ool00`00Oomoo`04
Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool2000<Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool2000;Ool00`00Oomoo`04Ool00`00Oomoo`0;
Ool00`00Oomoo`04Ool00`00Oomoo`09Ool2000<Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool2000;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`05
Ool100000004001oogoo0003Ool00`00Oomoo`0=Ool01@00Oomoogoo000027oo00<007ooOol027oo
00<007ooOol01Woo00D007ooOomoo`00011oo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Qoo`03001oogoo00Qoo`03001oogoo
00Ioo`05001oogooOol0000?Ool01@00Oomoogoo000027oo00<007ooOol02Goo00<007ooOol01Woo
00D007ooOomoo`0000moo`05001oogooOol00008Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01@00
Oomoogoo00003goo00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Ioo`05001oogoo
Ool0000?Ool01@00Oomoogoo000027oo00<007ooOol027oo00<007ooOol01Woo00D007ooOomoo`00
00moo`05001oogooOol00008Ool00`00Oomoo`09Ool00`00Oomoo`06Ool100000003001oogoo00Mo
o`03001oogoo00Ioo`03001oogoo00Uoo`8000Moo`04001oogoo0007Ool2000;Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool20007Ool01@00Oomoogoo00001goo0P002Woo00<007ooOol01Woo00<007oo
Ool02Goo0P001goo00@007ooOol000Moo`8000]oo`03001oogoo00Ioo`03001oogoo00Qoo`8000Mo
o`05001oogooOol00007Ool2000:Ool00`00Oomoo`06Ool00`00Oomoo`09Ool20007Ool01000Oomo
o`001goo0P002goo00<007ooOol01Woo00<007ooOol027oo0P001goo00D007ooOomoo`0000Moo`80
00Yoo`03001oogoo00Ioo`03001oogoo00Uoo`8000Moo`04001oogoo0007Ool2000;Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool20007Ool01@00Oomoogoo00001goo0P000goo0@0000000`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`09Ool100000005001oogooOol00008Ool0
1000Oomoo`002Goo00<007ooOol01Goo00@007ooOol000Qoo`04001oogoo0007Ool00`00Oomoo`07
Ool01000Oomoo`0027oo00<007ooOol01Goo00@007ooOol000Uoo`04001oogoo0007Ool00`00Oomo
o`06Ool01000Oomoo`002Goo00<007ooOol01Goo00@007ooOol000Qoo`04001oogoo0007Ool00`00
Oomoo`07Ool01000Oomoo`0027oo00<007ooOol01Goo00@007ooOol000Uoo`04001oogoo0007Ool0
0`00Oomoo`06Ool01000Oomoo`002Goo00<007ooOol01Goo00@007ooOol000Qoo`04001oogoo0007
Ool00`00Oomoo`07Ool01000Oomoo`0027oo00<007ooOol01Goo00@007ooOol000Uoo`04001oogoo
0007Ool00`00Oomoo`06Ool01000Oomoo`002Goo00<007ooOol01Goo00@007ooOol000Qoo`04001o
ogoo0007Ool00`00Oomoo`07Ool01000Oomoo`0027oo00<007ooOol01Goo00@007ooOol000Uoo`04
001oogoo0006Ool100000003001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Uoo`8000]oo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`80
00]oo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`8000]oo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Yoo`40
005oo`40000000<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Eoo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol01Goo00<007ooOol00Woo
00<007ooOol037oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000Ao
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
0Woo00@007ooOol000Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool10001Ool100000007001oogooOol007oo000017oo
00<007ooOol017oo00<007ooOol00goo00<007oo00002Woo00<007oo000017oo00<007oo00002Woo
00<007oo00001Goo00<007ooOol017oo00<007ooOol00Woo00@007ooOol000Uoo`03001oo`0000Eo
o`03001oo`0000Yoo`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Yo
o`03001oo`0000Aoo`03001oo`0000Yoo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0009Ool00`00Ool00005Ool00`00Ool0000:Ool00`00Ool00004Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Ool0000:Ool00`00Ool00004Ool00`00Ool0000:Ool00`00Ool00005
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool0000:Ool00`00Ool00005Ool00`00Ool00009
Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol00goo00<007oo00002Woo00<007oo0000
17oo00<007oo00002Woo00<007oo00001Goo00<007ooOol017oo00<007ooOol00Woo00<007oo0000
2Woo00<007oo00001Goo00<007oo00002Goo0@0000000`00Oomoo`04Ool01000Oomoo`0027oo00D0
07ooOomoo`0000Moo`8000Moo`05001oogooOol00006Ool20007Ool01@00Oomoogoo000027oo00D0
07ooOomoo`0000Ioo`8000Moo`05001oogooOol00007Ool20006Ool01@00Oomoogoo000027oo00D0
07ooOomoo`0000Moo`8000Moo`05001oogooOol00006Ool20007Ool01@00Oomoogoo000027oo00D0
07ooOomoo`0000Ioo`8000Moo`05001oogooOol00007Ool20006Ool01@00Oomoogoo000027oo00D0
07ooOomoo`0000Moo`8000Moo`04001oogoo0007Ool20007Ool01@00Oomoogoo000027oo00D007oo
Oomoo`0000Ioo`8000Moo`05001oogooOol00007Ool20006Ool01@00Oomoogoo000027oo00D007oo
Oomoo`0000Moo`8000Ioo`05001oogooOol00007Ool20007Ool01@00Oomoogoo000027oo00D007oo
Oomoo`0000Ioo`8000Moo`05001oogooOol00007Ool20003Ool100000004001oo`00000:Ool2000;
Ool20006Ool2000:Ool20006Ool2000;Ool2000:Ool20006Ool2000;Ool20006Ool2000:Ool2000;
Ool20006Ool2000:Ool20006Ool2000;Ool2000:Ool20006Ool2000;Ool20006Ool2000:Ool2000;
Ool20006Ool2000:Ool20006Ool2000;Ool2000:Ool20006Ool2000;Ool20006Ool2000:Ool2000;
Ool20006Ool2000:Ool20006Ool2000;Ool2000:Ool20006Ool2000;Ool20007Ool100000003001o
ogoo00Eoo`80009oo`03001oogoo009oo`06001oogoo001oo`001goo00@007ooOol000Aoo`08001o
ogoo001oo`00Ool000Aoo`04001oogoo0007Ool00`00Ool00002Ool00`00Oomoo`02Ool01P00Oomo
o`00Ool000Ioo`04001oogoo0004Ool01P00Oomoo`00Ool0009oo`03001oogoo009oo`04001oogoo
0007Ool20002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000Moo`04001oogoo0004Ool00`00Oomo
o`020002Ool00`00Oomoo`02Ool01000Oomoo`001goo00<007oo00000Woo00<007ooOol00Woo00H0
07ooOol007oo0006Ool01000Oomoo`0017oo00H007ooOol007oo0002Ool00`00Oomoo`02Ool01000
Oomoo`001Woo00<007oo00000Woo00<007ooOol00Woo00H007ooOol007oo0007Ool01000Oomoo`00
17oo00<007ooOol00P000Woo00<007ooOol00Woo00@007ooOol000Moo`03001oo`00009oo`03001o
ogoo009oo`06001oogoo001oo`001Woo00@007ooOol000Aoo`06001oogoo001oo`000Woo00<007oo
Ool00Woo00@007ooOol000Ioo`03001oo`00009oo`03001oogoo009oo`06001oogoo001oo`001goo
00@007ooOol000Aoo`03001oogoo0080009oo`03001oogoo009oo`04001oogoo0007Ool00`00Ool0
0002Ool00`00Oomoo`02Ool00`00Oomoo`020007Ool01000Oomoo`0017oo00H007ooOol007oo0002
Ool00`00Oomoo`02Ool01000Oomoo`000Woo0@0000000`00Oomoo`02Ool01@00Oomoogoo00000Woo
00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`04001oogoo0004Ool02000Oomoo`00
Ool007oo0004Ool01000Oomoo`0017oo00<007ooOol00Woo00@007ooOol000Aoo`04001oogoo0003
Ool20003Ool01000Oomoo`0017oo00H007ooOol007oo0002Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00D007ooOomoo`00009oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool01000
Oomoo`0017oo00P007ooOol007oo001oo`0017oo00@007ooOol000Aoo`03001oogoo009oo`04001o
ogoo0004Ool01000Oomoo`000goo0P000goo00@007ooOol000Aoo`06001oogoo001oo`000Woo00<0
07ooOol00Woo00@007ooOol000Aoo`05001oogooOol00002Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo0080009oo`03001oogoo009oo`04001o
ogoo0004Ool00`00Oomoo`02Ool01000Oomoo`0017oo00@007ooOol000=oo`03001oogoo009oo`04
001oogoo0004Ool01P00Oomoo`00Ool0009oo`03001oogoo009oo`04001oogoo0003Ool20003Ool0
1000Oomoo`0017oo00@007ooOol000Aoo`03001oogoo009oo`04001oogoo0004Ool01@00Ool007oo
00000Woo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo009oo`04001oogoo0004Ool01000
Oomoo`000goo00<007ooOol00Woo00@007ooOol000Aoo`06001oogoo001oo`000Woo00<007ooOol0
0Woo00@007ooOol0009oo`40000000<007oo00000P0000Eoo`00000007oo00800003Ool000000080
0004Ool00000Ool400000goo00000002000017oo000007oo100000Aoo`00001oo`<00003Ool00000
00800004Ool00000Ool400000goo00000002000017oo000007oo100000Aoo`00001oo`P00004Ool0
0000Ool400001Woo000007oo001oo`800003Ool0000000800004Ool00000Ool400001Goo00000000
Ool00P0000=oo`0000000P0000Aoo`00001oo`@00003Ool0000000800004Ool00000Ool4000017oo
000007oo0`0000=oo`0000000P0000Aoo`00001oo`@00003Ool0000000800004Ool00000Ool40000
17oo000007oo200000Aoo`00001oo`@00006Ool00000Ool007oo0P0000=oo`0000000P0000Aoo`00
001oo`@00005Ool00000001oo`0200000goo00000002000017oo000007oo100000=oo`0000000P00
00Aoo`00001oo`@00005Ool00000001oo`0200000goo00000002000017oo000007oo100000=oo`00
00000P0000Aoo`00001oo`@00004Ool00000Ool300000goo00000002000017oo000007oo100000Io
o`00001oo`00Ool200000goo00000002000017oo000007oo200000Aoo`00001oo`@00004Ool00000
Ool400000goo00000002000017oo000007oo100000Eoo`00000007oo00800003Ool0000000800004
Ool00000Ool400000goo00000002000017oo000007oo100000Aoo`00001oo`<00003Ool000000080
0004Ool00000Ool400001Woo000007oo001oo`800003Ool0000000800006Ool00000Ool007oo0@00
00000`00Oomoo`3oOon]Ool100000?l00;400000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 431}, {265.875, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000000P0200000000000000000lZ/o/o?oc
fKJ=HSXK1P077CeUT;WLm?olj/fWO58]4@813RQ<MJ37i_[omn2oUfa38@X011He
FhJ`e>ono_3E/8ML=AL400XQ@V^F_n3foo[Wb:5fC2P>0@8A;55lY/cZnoodg;ZA
IShM20066SYQS;KIl_omk=2[P5H`4`<032E8LIc4i?Won>?3Vg1790/00a@aEh:/
dNgmo_7H]8YP>1T500PN?fNB^mgeoo_YbjEjD2/@0P4?:TihX/WXn_ofgkfEJT4P
2@0563IMR;;Fl?kmk]>^Q5Xc5P@02R95KIS1hOOonNG6WgA:9`d10Q8^E7jXc^_l
oo?K^8iS?1`700LL?6>>^=_cooc[cZQnE2hB0P4=9dYdWlKUnOoghL6HKDDR2P04
5S=JQ:kCk_gnl=JbR5df60D02B11JYFmgoKon^S9XWQ>:Pl10Q0[D7ZUbnWkooGM
^i9W?ah800DI>62:]=Sao_g]dJb2Ec4D0`0;94M`Vl?Sn?oii<BLLDPU30034c1F
P:_@k?gol]VfS64j6PH021dnIY6jg?Conn[<YWaA;1420@hXC7JQb>OjooKP_iI[
@R4:00@G=Eb7/=G`o_k_e;26FcDF100:8D=/UkoPmooji/NPMD`X3P424BeBO:O=
j_com=biT6Dm7@L01Q/jHXfffO?oo>c?ZWmE<1<300`VBG:MaNCiooSR`YY_AR<;
00<E<UR3[M;^oOkaek>:GcPI1@087d1XTkcNmOokjLZTNDl[40413bY?N:?:j?_o
mMjmU6U07`T01APgGXVceo7noNkC[X=I<aD400/SAFjI`N;gooWUaIicBBH=008C
;eAoZLo/o?ocf[N>Hc/K1P0773aTSkSKm?oljljXOE<^4P813RM;MIo7i_[omn70
V6e48PX011HdFXF_e>omo_3E/HMM=QL500TP@VZE_]ofoo[WbJ9gCBT?0@8A;55k
YLcYnooegKZBIchN20066SUPRkGHl_kmkM6[PELa50<032A7LIc3hoSon>?3W757
90`00a@aEh6[dNgmo_;H]H]P>AX600PN?VNB^]geoo_Yc:EkDB`A0P4?:DegX/WW
n_ofgkjEJT8P2@055cIMQk7El?kmkmB_QEXd5P@02R94KIS0hOOon^K7WgE;9`h1
0Q8^DgfXc^_looCK^8mT?1`700HK>f>>]m[cooc/cjUoE2lC0P0=9TUcW/GUnOog
h/6IKTDS2`045C=IPjkCk_gnlMNcREhg60D02Am0JIBmg_GonnS:XgQ?:Pl10A0[
CgVTb^WkooGN_9=X@1l800DI>5n:/mOao_g^dZf3F38E0`0;8dI_V/;Rn?oii<FM
LTTV30034c1EOj[?k?colmVfSF8j6`H01admII2ig?Coo>[=YgaB;A420@hXC7FP
anKjooOP_iM/@b4:00@F=E^6/=C_o_k`eK27G3DG100:8D9[U[oPm_ojilRQMT`X
3P424BaAO:K<j__om=bjTFHn7@P01QXjHHbffO;ooNc@Zh1F<1<300`UB76La>Ci
ooSS`i]`Ab@;00<D<EN2[=7]oOkaf;B:H3PI1@087SmWT[_MmOokjL^UNU0[4081
3bY>N:;9j?[om]nmUFY180T01APfGHRbe_3noNkC[XAJ<aH400XRAFfH`N7gooWU
aYmdBRL=0@8B;UAnZ<k[o?ocfkR>Hc`L1`0773aSS[SKlooljljXOU@^4P813BM:
M9o6iOWomn71V6e58PX011HcFXB^dnkmo_3F/XQM=QP500TP@FZE_Mofoo[XbJ9h
CRX?0@8@:e1jYL_YnooegK^BIclN20056CQPR[CHlOkmkM6/PULa50<02bA7L9_3
hoSonNC4W7589@`00a<`EX2[d>cmoo;I]XaQ>QX600PM?VJA^]cdoo_Zc:IlDB`A
0P4>:4afXLSWn_ofh;nFJd8Q2P045cELQk3El?knkmB`QU/e5P@02R53K9Noh?Oo
n^K7X7E<:0h10Q4]DWbWcN[looCL^I1U?Ad700HK>V:=]]Wcooc/cjYoEC0C0`0<
9TUbWLGTnOohh/:JKdHS2`035C9HPjgBk_gnlMNcRUlh6@D021m0J9>lg_GonnW:
Y7U?:a010@lZCgRSb^SkooGN_IAY@1l900DH=ej9/mOao_g^djj3FC<E100;8dE^
VL7RmooiiLFNLdTV3@024bmDOjW?k?colmZgSV<k6`H01a`lI8nhfoCoo>_>Z7eC
;Q820@hWBgFOanKjooOQ`9Q]A28:00@F=5Z5[mC_oOk`eK67GCHG1@09849ZUKkO
m_ojilVRMddY3`424BaANjG<jO_omMfjTVLn7PP01QXiH8^ef?;noNgAZh5G<A@3
00`TAg6L`n?hooSS`iaaAb@<00<D<EN1Zm7]oOkbf;F;H3TJ1P087SiWT[[MmOok
jLbUNe4/4@813bU=Mj;9io[om]nnUFY280T01ALfGHNaeO3noNoD[hEJ=1H400XR
A6fH`>7goo[VaimeBbL>0@8B;U=mZ<k[o?odfkR?I3`L1`066c]SS[OJloolk<nY
Oe@_4`803BI9Lik5iOWomn;1VFi58`/011DcFH>^dnkmo_7G/hUN=aP500TO@6VD
_Mkeoo_XbZ=hCbX?0@4@:dmiY<[Ynooeg[bCJ40O20056CQOR[?GlOkmk]:]PePb
5@<02b=6Ki[2h_SonNC5WG999P`00a<`EGnZcncloo?I]XeR>Q/600LM?FF@^Mcd
oocZcJMlDRdA0P4>:4aeX<OVn_ogh;nGK4<Q2P045SEKQ[3Dkoknl=F`Qe`e5`@0
2R52JiJoh?Kon^O8XGI<:0h10Q4/DGbVc>[kooCL^Y5V?Qd800HJ>V6<]]Wboog/
d:^0ES0C0`0<9DQaW<CTnOohhl>KL4LT2`03535GPZcAkOgnlMRdRV0h6@D021ho
Ii:kgOGonnW;YGY@:a020@lZCWRRbNSjooKO_IEZ@B0900DH=Uf8/]K`o_g^djj4
FS<F100:8TE]V<7QmooiiLJOM4XW3@424RiDOZS>jocolm^hSV<l70L01a`lHhjh
fo?oo>_>Z7iD;Q820@dWBWBOa^GiooOQ`IQ]AB8:00@F<eZ4[]?^oOk`e[:8GCHH
1@09845ZUKgOm_ojj<VRN4hZ3`4242]@NZG;jO_omMfkTVLo7PP01AThH8Zdf?7n
oNgA[89G<A@300/TAg2K`n?hooWTa9aaB2D<00<C<5J0Zm3/oOobfKJ<HCXJ1P08
7CiVTK[Lm?okj/bVO54/4@813RQ<MZ78io[om^2oUV]28@X011LeG8N`eO3no^oD
/8IK=AH400XQ@fbG_n3goo[Vaj1eC2P>0@8A;E9lYlgZo?odg;V@ICdM1`066cYR
SKKIloolk<nZOeD`4`<032I9LYg5i?Won>;2VVm68`/00aDbF8>]d^kmo_7G/hYO
>1T500PO@6RC_=keoo_YbZAiCb/@0@4?:TmhXl[Xnooeg[fDJD0O2@0563MNRK?G
lOkmk]>^PeTc5@@02b=5KYW1h_OonNG5WW=99Pd00Q<_E7nYcncloo?J]hiS>a/6
00LL?6B?^=_dooc[cZQmDbhB0P4>9d]eWlOVn_oghL2HKD@R2P045SAJQJoDkogn
l=FaQedf5`D02B12JYFngoKon^O9XWM=:@l10Q4/DG^Uc>WkooGM^Y9W?Qh800HJ
>F2;]MSbo_g]dJ^1Ec4D0`0<94MaW<?Sn?ohhl>LLDLT3003535GPJ_AkOgnl]Re
Rf0i6PH021hnIi:jgOGonnW<YG]A;1420@lYCGNRbNOjooKO_YEZ@R0900DG=Uf7
/MG`o_g_e:n5FS@F100:8TA]V<3Qmooji/NOMD/W3P424RiCOJS>jocom=^hSf@l
70L01Q/kHhjgf_?oo>c?ZGmD;a<200dVBG>NaNGiooOR`IU^AB<;00@E<eV3[]?^
oOkaek>9GSLH1@097d1YU;gNmOokj<ZSN4lZ3`4142]?NJC:jO_omMjlTfQ07`P0
1AThGhZceo7noNkB[H=H<QD300/SAVnJ`^;hooWTaIebBBH<00<C<5EoZ/o/o?oc
fKJ=HSXK1P077CeUT;WLm?olj/fWO58]4@813RQ<MJ37i_[omn2oUfa38@X011He
FhJ`e>ono_3E/8ML=AL400XQ@V^F_n3foo[Wb:5fC2P>0@8A;55lY/cZnoodg;ZA
IShM20066SYQS;KIl_omk=2[P5H`4`<032E8LIc4i?Won>?3Vg1790/00a@aEh:/
dNgmo_7H]8YP>1T500PN?fNB^mgeoo_YbjEjD2/@0P4?:TihX/WXn_ofgkfEJT4P
2@0563IMR;;Fl?kmk]>^Q5Xc5P@02R95KIS1hOOonNG6WgA:9`d10Q8^E7jXc^_l
oo?K^8iS?1`700LL?6>>^=_cooc[cZQnE2hB0P4=9dYdWlKUnOoghL6HKDDR2P04
5S=JQ:kCk_gnl=JbR5df60D02B11JYFmgoKon^S9XWQ>:Pl10Q0[D7ZUbnWkooGM
^i9W?ah800DI>62:]=Sao_g]dJb2Ec4D0`0;94M`Vl?Sn?oii<BLLDPU30034c1F
P:_@k?gol]VfS64j6PH021dnIY6jg?Conn[<YWaA;1420@hXC7JQb>OjooKP_iI[
@R4:00@G=Eb7/=G`o_k_e;26FcDF100:8D=/UkoPmooji/NPMD`X3P424BeBO:O=
j_com=biT6Dm7@L01Q/jHXfffO?oo>c?ZWmE<1<300`VBG:MaNCiooSR`YY_AR<;
00<E<UR3[M;^oOkaek>:GcPI1@087d1XTkcNmOokjLZTNDl[40413bY?N:?:j?_o
mMjmU6U07`T01APgGXVceo7noNkC[X=I<aD400/SAFjI`N;gooWUaIicBBH=008C
;eAoZLo/o?ocf[N>Hc/K1P0773aTSkSKm?oljljXOE<^4P813RM;MIo7i_[omn70
V6e48PX011HdFXF_e>omo_3E/HMM=QL500TP@VZE_]ofoo[WbJ9gCBT?0@8A;55k
YLcYnooegKZBIchN20066SUPRkGHl_kmkM6[PELa50<032A7LIc3hoSon>?3W757
90`00a@aEh6[dNgmo_;H]H]P>AX600PN?VNB^]geoo_Yc:EkDB`A0P4?:DegX/WW
n_ofgkjEJT8P2@055cIMQk7El?kmkmB_QEXd5P@02R94KIS0hOOon^K7WgE;9`h1
0Q8^DgfXc^_looCK^8mT?1`700HK>f>>]m[cooc/cjUoE2lC0P0=9TUcW/GUnOog
h/6IKTDS2`045C=IPjkCk_gnlMNcREhg60D02Am0JIBmg_GonnS:XgQ?:Pl10A0[
CgVTb^WkooGN_9=X@1l800DI>5n:/mOao_g^dZf3F38E0`0;8dI_V/;Rn?oii<FM
LTTV30034c1EOj[?k?colmVfSF8j6`H01admII2ig?Coo>[=YgaB;A420@hXC7FP
anKjooOP_iM/@b4:00@F=E^6/=C_o_k`eK27G3DG100:8D9[U[oPm_ojilRQMT`X
3P424BaAO:K<j__om=bjTFHn7@P01QXjHHbffO;ooNc@Zh1F<1<300`UB76La>Ci
ooSS`i]`Ab@;00<D<EN2[=7]oOkaf;B:H3PI1@087SmWT[_MmOokjL^UNU0[4081
3bY>N:;9j?[om]nmUFY180T01APfGHRbe_3noNkC[XAJ<aH400XRAFfH`N7gooWU
aYmdBRL=0@8B;UAnZ<k[o?ocfkR>Hc`L1`0773aSS[SKlooljljXOU@^4P813BM:
M9o6iOWomn71V6e58PX011HcFXB^dnkmo_3F/XQM=QP500TP@FZE_Mofoo[XbJ9h
CRX?0@8@:e1jYL_YnooegK^BIclN20056CQPR[CHlOkmkM6/PULa50<02bA7L9_3
hoSonNC4W7589@`00a<`EX2[d>cmoo;I]XaQ>QX600PM?VJA^]cdoo_Zc:IlDB`A
0P4>:4afXLSWn_ofh;nFJd8Q2P045cELQk3El?knkmB`QU/e5P@02R53K9Noh?Oo
n^K7X7E<:0h10Q4]DWbWcN[looCL^I1U?Ad700HK>V:=]]Wcooc/cjYoEC0C0`0<
9TUbWLGTnOohh/:JKdHS2`035C9HPjgBk_gnlMNcRUlh6@D021m0J9>lg_GonnW:
Y7U?:a010@lZCgRSb^SkooGN_IAY@1l900DH=ej9/mOao_g^djj3FC<E100;8dE^
VL7RmooiiLFNLdTV3@024bmDOjW?k?colmZgSV<k6`H01a`lI8nhfoCoo>_>Z7eC
;Q820@hWBgFOanKjooOQ`9Q]A28:00@F=5Z5[mC_oOk`eK67GCHG1@09849ZUKkO
m_ojilVRMddY3`424BaANjG<jO_omMfjTVLn7PP01QXiH8^ef?;noNgAZh5G<A@3
00`TAg6L`n?hooSS`iaaAb@<00<D<EN1Zm7]oOkbf;F;H3TJ1P087SiWT[[MmOok
jLbUNe4/4@813bU=Mj;9io[om]nnUFY280T01ALfGHNaeO3noNoD[hEJ=1H400XR
A6fH`>7goo[VaimeBbL>0@8B;U=mZ<k[o?odfkR?I3`L1`066c]SS[OJloolk<nY
Oe@_4`803BI9Lik5iOWomn;1VFi58`/011DcFH>^dnkmo_7G/hUN=aP500TO@6VD
_Mkeoo_XbZ=hCbX?0@4@:dmiY<[Ynooeg[bCJ40O20056CQOR[?GlOkmk]:]PePb
5@<02b=6Ki[2h_SonNC5WG999P`00a<`EGnZcncloo?I]XeR>Q/600LM?FF@^Mcd
oocZcJMlDRdA0P4>:4aeX<OVn_ogh;nGK4<Q2P045SEKQ[3Dkoknl=F`Qe`e5`@0
2R52JiJoh?Kon^O8XGI<:0h10Q4/DGbVc>[kooCL^Y5V?Qd800HJ>V6<]]Wboog/
d:^0ES0C0`0<9DQaW<CTnOohhl>KL4LT2`03535GPZcAkOgnlMRdRV0h6@D021ho
Ii:kgOGonnW;YGY@:a020@lZCWRRbNSjooKO_IEZ@B0900DH=Uf8/]K`o_g^djj4
FS<F100:8TE]V<7QmooiiLJOM4XW3@424RiDOZS>jocolm^hSV<l70L01a`lHhjh
fo?oo>_>Z7iD;Q820@dWBWBOa^GiooOQ`IQ]AB8:00@F<eZ4[]?^oOk`e[:8GCHH
1@09845ZUKgOm_ojj<VRN4hZ3`4242]@NZG;jO_omMfkTVLo7PP01AThH8Zdf?7n
oNgA[89G<A@300/TAg2K`n?hooWTa9aaB2D<00<C<5J0Zm3/oOobfKJ<HCXJ1P08
7CiVTK[Lm?okj/bVO54/4@813RQ<MZ78io[om^2oUV]28@X011LeG8N`eO3no^oD
/8IK=AH400XQ@fbG_n3goo[Vaj1eC2P>0@8A;E9lYlgZo?odg;V@ICdM1`066cYR
SKKIloolk<nZOeD`4`<032I9LYg5i?Won>;2VVm68`/00aDbF8>]d^kmo_7G/hYO
>1T500PO@6RC_=keoo_YbZAiCb/@0@4?:TmhXl[Xnooeg[fDJD0O2@0563MNRK?G
lOkmk]>^PeTc5@@02b=5KYW1h_OonNG5WW=99Pd00Q<_E7nYcncloo?J]hiS>a/6
00LL?6B?^=_dooc[cZQmDbhB0P4>9d]eWlOVn_oghL2HKD@R2P045SAJQJoDkogn
l=FaQedf5`D02B12JYFngoKon^O9XWM=:@l10Q4/DG^Uc>WkooGM^Y9W?Qh800HJ
>F2;]MSbo_g]dJ^1Ec4D0`0<94MaW<?Sn?ohhl>LLDLT3003535GPJ_AkOgnl]Re
Rf0i6PH021hnIi:jgOGonnW<YG]A;1420@lYCGNRbNOjooKO_YEZ@R0900DG=Uf7
/MG`o_g_e:n5FS@F100:8TA]V<3Qmooji/NOMD/W3P424RiCOJS>jocom=^hSf@l
70L01Q/kHhjgf_?oo>c?ZGmD;a<200dVBG>NaNGiooOR`IU^AB<;00@E<eV3[]?^
oOkaek>9GSLH1@097d1YU;gNmOokj<ZSN4lZ3`4142]?NJC:jO_omMjlTfQ07`P0
1AThGhZceo7noNkB[H=H<QD300/SAVnJ`^;hooWTaIebBBH<00<C<5EoZ/o/o?oc
fKJ=HSXK1P077CeUT;WLm?olj/fWO58]4@813RQ<MJ37i_[omn2oUfa38@X011He
FhJ`e>ono_3E/8ML=AL400XQ@V^F_n3foo[Wb:5fC2P>0@8A;55lY/cZnoodg;ZA
IShM20066SYQS;KIl_omk=2[P5H`4`<032E8LIc4i?Won>?3Vg1790/00a@aEh:/
dNgmo_7H]8YP>1T500PN?fNB^mgeoo_YbjEjD2/@0P4?:TihX/WXn_ofgkfEJT4P
2@0563IMR;;Fl?kmk]>^Q5Xc5P@02R95KIS1hOOonNG6WgA:9`d10Q8^E7jXc^_l
oo?K^8iS?1`700LL?6>>^=_cooc[cZQnE2hB0P4=9dYdWlKUnOoghL6HKDDR2P04
5S=JQ:kCk_gnl=JbR5df60D02B11JYFmgoKon^S9XWQ>:Pl10Q0[D7ZUbnWkooGM
^i9W?ah800DI>62:]=Sao_g]dJb2Ec4D0`0;94M`Vl?Sn?oii<BLLDPU30034c1F
P:_@k?gol]VfS64j6PH021dnIY6jg?Conn[<YWaA;1420@hXC7JQb>OjooKP_iI[
@R4:00@G=Eb7/=G`o_k_e;26FcDF100:8D=/UkoPmooji/NPMD`X3P424BeBO:O=
j_com=biT6Dm7@L01Q/jHXfffO?oo>c?ZWmE<1<300`VBG:MaNCiooSR`YY_AR<;
00<E<UR3[M;^oOkaek>:GcPI1@087d1XTkcNmOokjLZTNDl[40413bY?N:?:j?_o
mMjmU6U07`T01APgGXVceo7noNkC[X=I<aD400/SAFjI`N;gooWUaIicBBH=008C
;eAoZLo/o?ocf[N>Hc/K1P0773aTSkSKm?oljljXOE<^4P813RM;MIo7i_[omn70
V6e48PX011HdFXF_e>omo_3E/HMM=QL500TP@VZE_]ofoo[WbJ9gCBT?0@8A;55k
YLcYnooegKZBIchN20066SUPRkGHl_kmkM6[PELa50<032A7LIc3hoSon>?3W757
90`00a@aEh6[dNgmo_;H]H]P>AX600PN?VNB^]geoo_Yc:EkDB`A0P4?:DegX/WW
n_ofgkjEJT8P2@055cIMQk7El?kmkmB_QEXd5P@02R94KIS0hOOon^K7WgE;9`h1
0Q8^DgfXc^_looCK^8mT?1`700HK>f>>]m[cooc/cjUoE2lC0P0=9TUcW/GUnOog
h/6IKTDS2`045C=IPjkCk_gnlMNcREhg60D02Am0JIBmg_GonnS:XgQ?:Pl10A0[
CgVTb^WkooGN_9=X@1l800DI>5n:/mOao_g^dZf3F38E0`0;8dI_V/;Rn?oii<FM
LTTV30034c1EOj[?k?colmVfSF8j6`H01admII2ig?Coo>[=YgaB;A420@hXC7FP
anKjooOP_iM/@b4:00@F=E^6/=C_o_k`eK27G3DG100:8D9[U[oPm_ojilRQMT`X
3P424BaAO:K<j__om=bjTFHn7@P01QXjHHbffO;ooNc@Zh1F<1<300`UB76La>Ci
ooSS`i]`Ab@;00<D<EN2[=7]oOkaf;B:H3PI1@087SmWT[_MmOokjL^UNU0[4081
3bY>N:;9j?[om]nmUFY180T01APfGHRbe_3noNkC[XAJ<aH400XRAFfH`N7gooWU
aYmdBRL=0@8B;UAnZ<k[o?ocfkR>Hc`L1`0773aSS[SKlooljljXOU@^4P813BM:
M9o6iOWomn71V6e58PX011HcFXB^dnkmo_3F/XQM=QP500TP@FZE_Mofoo[XbJ9h
CRX?0@8@:e1jYL_YnooegK^BIclN20056CQPR[CHlOkmkM6/PULa50<02bA7L9_3
hoSonNC4W7589@`00a<`EX2[d>cmoo;I]XaQ>QX600PM?VJA^]cdoo_Zc:IlDB`A
0P4>:4afXLSWn_ofh;nFJd8Q2P045cELQk3El?knkmB`QU/e5P@02R53K9Noh?Oo
n^K7X7E<:0h10Q4]DWbWcN[looCL^I1U?Ad700HK>V:=]]Wcooc/cjYoEC0C0`0<
9TUbWLGTnOohh/:JKdHS2`035C9HPjgBk_gnlMNcRUlh6@D021m0J9>lg_GonnW:
Y7U?:a010@lZCgRSb^SkooGN_IAY@1l900DH=ej9/mOao_g^djj3FC<E100;8dE^
VL7RmooiiLFNLdTV3@024bmDOjW?k?colmZgSV<k6`H01a`lI8nhfoCoo>_>Z7eC
;Q820@hWBgFOanKjooOQ`9Q]A28:00@F=5Z5[mC_oOk`eK67GCHG1@09849ZUKkO
m_ojilVRMddY3`424BaANjG<jO_omMfjTVLn7PP01QXiH8^ef?;noNgAZh5G<A@3
00`TAg6L`n?hooSS`iaaAb@<00<D<EN1Zm7]oOkbf;F;H3TJ1P087SiWT[[MmOok
jLbUNe4/4@813bU=Mj;9io[om]nnUFY280T01ALfGHNaeO3noNoD[hEJ=1H400XR
A6fH`>7goo[VaimeBbL>0@8B;U=mZ<k[o?odfkR?I3`L1`066c]SS[OJloolk<nY
Oe@_4`803BI9Lik5iOWomn;1VFi58`/011DcFH>^dnkmo_7G/hUN=aP500TO@6VD
_Mkeoo_XbZ=hCbX?0@4@:dmiY<[Ynooeg[bCJ40O20056CQOR[?GlOkmk]:]PePb
5@<02b=6Ki[2h_SonNC5WG999P`00a<`EGl\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " assumes that the  time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " is given in seconds, so this command causes a pure middle A tone to play \
for 1 second. The tone can be repeated by double clicking on the upper corner \
of the inner cell box."
}], "Text"],

Cell["\<\
\tWe can also play other sounds. For example, we can play the sound \
of a triangle wave, which has a distinctive buzzing quality: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T = 1/440; \ 
    a[n_]\  = \ \(-4\)/\((n^2\ Pi^2)\); \(\(f\_approx[t_, 30]\  = \ 
        Sum[a[n]\ Cos[2\ Pi\ n\ t/T], {n, 1, 30, 
            2}];\)\(\[IndentingNewLine]\)\(\[IndentingNewLine]\)
    \(Play[f\_approx[t, 30], {t, 0, 1}, 
      PlayRange \[Rule] {\(-0.6\), 0.6}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.26"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 8192 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oo`00/@0000000`00
Oomoo`3oOon]Ool100000003001oo`000?l00:`0005oo`40000000<007ooOol01Woo00D007ooOomo
o`0000=oo`05001oogooOol00008Ool01000Oomoo`000goo00<007ooOol01Woo00D007ooOomoo`00
00=oo`03001oogoo00Ioo`04001oogoo0004Ool01000Oomoo`0027oo00D007ooOomoo`0000=oo`03
001oogoo00Eoo`03001oogoo009oo`04001oogoo0008Ool01@00Oomoogoo00000goo00@007ooOol0
00Uoo`04001oogoo0003Ool00`00Oomoo`06Ool01@00Oomoogoo00000goo00<007ooOol01Woo00@0
07ooOol000Aoo`04001oogoo0008Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol0
0Woo00@007ooOol000Qoo`05001oogooOol00003Ool01000Oomoo`002Goo00@007ooOol000=oo`03
001oogoo00Ioo`05001oogooOol00003Ool00`00Oomoo`06Ool01000Oomoo`000goo00D007ooOomo
o`0000Qoo`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`0027oo
00D007ooOomoo`0000=oo`04001oogoo0009Ool01000Oomoo`000goo00<007ooOol01Woo00D007oo
Oomoo`00009oo`03001oogoo00Moo`04001oogoo0003Ool01@00Oomoogoo000027oo00D007ooOomo
o`0000=oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0002Ool100000004001oo`00Ool2
000COol00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000COol00`00Oomoo`0NOol00`00Oomo
o`0AOol2000OOol2000COol00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000COol00`00Oomo
o`0NOol00`00Oomoo`0AOol2000NOol100000003001oogoo00Moo`03001oo`0000Eoo`03001oo`00
00Uoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00009Ool01000Oomo
o`0017oo00<007oo00002Woo00<007oo000017oo00<007ooOol01Goo00<007ooOol00Woo00@007oo
Ool000Uoo`03001oo`0000Eoo`03001oo`0000Uoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Ool00009Ool01000Oomoo`0017oo00<007oo00002Woo00<007oo000017oo00<0
07ooOol01Goo00<007ooOol00Woo00@007ooOol000Uoo`03001oo`0000Eoo`03001oo`0000Uoo`04
001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00009Ool01000Oomoo`0017oo
00<007oo00002Woo00<007oo000017oo00<007ooOol01Goo00<007ooOol00Woo00<007oo00002Woo
00<007oo000017oo00@007ooOol000Uoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Ool00009Ool01000Oomoo`0017oo00<007oo00002Woo00<007oo000017oo00<007ooOol0
1Goo00<007ooOol00Woo00<007oo00000goo0@0000000`00Ool00004Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`09Ool01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00Woo00<007ooOol02Woo00<007oo000037oo00<007ooOol00Woo00<007ooOol037oo00<0
07ooOol00goo00<007ooOol02Goo00@007ooOol000]oo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo009oo`03001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03
001oogoo00=oo`03001oogoo00Uoo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Ool0000<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool01000Oomoo`002goo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol02Woo00<007oo00003Goo0@0000000`00Oomoo`0<Ool00`00Oomo
o`0AOol2000;Ool00`00Oomoo`0AOol2000COol00`00Oomoo`09Ool2000COol00`00Oomoo`0AOol2
000;Ool00`00Oomoo`0AOol2000COol00`00Oomoo`09Ool2000COol00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`0AOol2000COol00`00Oomoo`09Ool2000COol00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`0AOol2000BOol2000;Ool20007Ool100000003001oo`0000Aoo`04001oogoo
0009Ool01000Oomoo`000goo00D007ooOomoo`0000Qoo`04001oogoo0009Ool01000Oomoo`000goo
00D007ooOomoo`0000Qoo`04001oogoo0004Ool01000Oomoo`0027oo00D007ooOomoo`0000Qoo`04
001oogoo0004Ool01000Oomoo`0027oo00D007ooOomoo`0000=oo`05001oogooOol00008Ool01000
Oomoo`002Goo00@007ooOol000=oo`05001oogooOol00008Ool01000Oomoo`0017oo00@007ooOol0
00Qoo`05001oogooOol00008Ool01000Oomoo`0017oo00@007ooOol000Qoo`05001oogooOol00003
Ool01@00Oomoogoo000027oo00@007ooOol000Uoo`04001oogoo0003Ool01@00Oomoogoo000027oo
00@007ooOol000Aoo`04001oogoo0008Ool01@00Oomoogoo000027oo00@007ooOol000Aoo`04001o
ogoo0008Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Qoo`04001oogoo0008Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Qoo`04001oogoo0004Ool01000Oomoo`0027oo00D007ooOomo
o`0000Qoo`04001oogooOol100000003001oogoo00Uoo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo011oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo011oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo011oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo011oo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo011oo`03001oogoo009oo`40
000000@007ooOomoo`8000Moo`05001oogooOol00006Ool00`00Ool0000:Ool20006Ool2000:Ool0
0`00Ool00007Ool01000Oomoo`001goo0P002goo0P001Goo00<007oo00002Woo0P001goo00D007oo
Oomoo`0000Ioo`03001oo`0000Yoo`8000Ioo`8000Yoo`03001oo`0000Moo`04001oogoo0007Ool2
000:Ool00`00Ool00005Ool00`00Ool0000:Ool20007Ool01@00Oomoogoo00001Woo00<007oo0000
2Woo0P001Woo0P002Woo00<007oo00001goo00@007ooOol000Moo`8000Yoo`03001oo`0000Eoo`03
001oo`0000Yoo`8000Moo`05001oogooOol00006Ool00`00Ool0000:Ool20006Ool2000:Ool00`00
Ool00007Ool01000Oomoo`001goo0P002Woo00<007oo00001Goo00<007oo00002Goo0@0000000`00
Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00
Oomoogoo00001goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomoo`0000moo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00eoo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo
00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00eoo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo
00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00eoo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo
00D007ooOomoo`00009oo`40000000<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol02Goo0P0037oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol0
2Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo0P002goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo0P00
2goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
2Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo0P002goo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo0@00
0Goo0@0000001000Oomoo`002Woo00<007oo00002Goo00<007ooOol01Goo00@007ooOol000Uoo`03
001oo`0000Moo`03001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`05Ool00`00Ool00009Ool0
1000Oomoo`001Woo00<007ooOol027oo00<007oo00002Goo00<007ooOol01Goo00@007ooOol000Uo
o`03001oo`0000Moo`03001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`05Ool00`00Ool00009
Ool01000Oomoo`001Woo00<007ooOol027oo00<007oo00002Goo00<007ooOol01Goo00<007oo0000
2Woo00<007oo00001goo00<007ooOol01goo00@007ooOol000Uoo`03001oogoo00Eoo`03001oo`00
00Uoo`04001oogoo0006Ool00`00Oomoo`08Ool00`00Ool00009Ool00`00Oomoo`05Ool00`00Ool0
000:Ool00`00Ool00007Ool00`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol017oo00@007oo
Ool000Uoo`04001oogoo0006Ool100000003001oogoo00=oo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00ao
o`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00ao
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=o
o`03001oogoo00Uoo`40000000<007ooOol027oo00<007ooOol01Goo00<007ooOol02Goo0P001Woo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol01Goo00D007ooOomoo`0000Moo`8000]oo`03001oogoo00Eoo`03001oogoo00Uoo`80
00Ioo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo
00Uoo`03001oogoo00Eoo`05001oogooOol00007Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo0P002goo00<007ooOol01Goo00<007oo
Ool02Goo0P001Woo00<007ooOol00Woo00<007ooOol017oo0P002goo00<007ooOol01Goo00<007oo
Ool02Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`8000=oo`40000000@007ooOol0009oo`03
001oogoo00Eoo`03001oo`0000Ioo`05001oogooOol00007Ool2000:Ool00`00Ool00006Ool01@00
Oomoogoo00001goo0P001goo00@007ooOol000Moo`03001oo`0000Yoo`8000Moo`04001oogoo0007
Ool00`00Ool00006Ool01@00Oomoogoo00001goo0P002Woo00<007oo00001Woo00D007ooOomoo`00
00Moo`8000Moo`04001oogoo0007Ool2000;Ool20007Ool01000Oomoo`001goo00<007oo00001Woo
00D007ooOomoo`0000Moo`8000Yoo`03001oo`0000Ioo`05001oogooOol00007Ool20007Ool01000
Oomoo`001goo0P002goo0P001goo00@007ooOol000Moo`03001oo`0000Ioo`05001oogooOol00007
Ool2000:Ool00`00Ool00006Ool01@00Oomoogoo00001goo0P001goo00@007ooOol000Moo`8000]o
o`8000Moo`40000000<007oo0000o`00[0000Goo0@0000000`00Oomoo`3oOon]Ool100000?l00;40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40
000000<007ooOol01Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
1Goo00D007ooOomoo`0000Moo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Aoo`40005oo`40000000<007ooOol00goo00<007ooOol027oo00<007oo00001goo00@007oo
Ool000Ioo`03001oo`0000Yoo`03001oogoo00Moo`03001oogoo00Moo`03001oo`0000Moo`04001o
ogoo0007Ool00`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool00007Ool01000
Oomoo`001Woo00<007oo00002Woo00<007ooOol01goo00<007ooOol01goo00<007oo00001goo00@0
07ooOol000Moo`03001oo`0000Yoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oo`0000Moo`04
001oogoo0006Ool00`00Ool0000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Ool00007Ool0
1000Oomoo`001goo00<007oo00002Goo00<007ooOol01goo00<007ooOol027oo00<007oo00001goo
00@007ooOol000Ioo`03001oo`0000Yoo`03001oogoo00Moo`03001oogoo00Moo`03001oo`0000Mo
o`04001oogoo0007Ool00`00Ool00009Ool00`00Oomoo`04Ool100000005001oogooOol0000DOol0
0`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0AOol0
0`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool0
0`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol0
0`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool0
0`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol0
0`00Oomoo`02Ool100000003001oogoo00Qoo`8000]oo`03001oogoo00Ioo`03001oogoo00Qoo`80
01=oo`8000Yoo`03001oogoo00Ioo`03001oogoo00Uoo`80019oo`8000]oo`03001oogoo00Ioo`03
001oogoo00Qoo`8001=oo`8000Yoo`03001oogoo00Ioo`03001oogoo00Uoo`80019oo`8000]oo`03
001oogoo00Ioo`03001oogoo00Qoo`8001=oo`8000Yoo`03001oogoo00Ioo`03001oogoo00Uoo`80
019oo`8000]oo`03001oogoo00Eoo`03001oogoo00Uoo`8001=oo`8000Yoo`03001oogoo00Ioo`03
001oogoo00Uoo`8000Yoo`40000000@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`05
001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00<007oo
Ool03Goo00<007ooOol03Woo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05
001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo00<007oo
Ool03Woo00<007ooOol03Goo00D007ooOomoo`00011oo`03001oogoo00eoo`03001oogoo00ioo`05
001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01000Oomoogoo0@0000000`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`0FOol00`00Oomoo`05Ool00`00Oomoo`05Ool100000003001oogoo00Eoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Eoo`40000000<007ooOol0
37oo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0
0Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol067oo00<007ooOol00goo00<007ooOol0
2goo00<007ooOol00goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol0
0goo00<007ooOol067oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol0
6Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<007ooOol067oo00<007ooOol0
0goo00<007ooOol02goo00<007ooOol00goo00<007ooOol067oo00<007ooOol00goo00<007ooOol0
37oo00<007ooOol00goo00<007ooOol037oo0@0000000`00Ool0000DOol00`00Oomoo`08Ool00`00
Oomoo`0AOol00`00Ool0000COol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Ool0000DOol00`00
Oomoo`07Ool00`00Oomoo`0BOol00`00Ool0000COol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00
Ool0000DOol00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Ool0000COol00`00Oomoo`08Ool00`00
Oomoo`0AOol00`00Ool0000DOol00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Ool0000COol00`00
Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`0100000003001oogoo00Moo`04001oogoo000<Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`004Goo00@007ooOol000]oo`03001oogoo009o
o`03001oogoo00Yoo`04001oogoo000@Ool01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol0
2Goo00@007ooOol0015oo`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomo
o`0047oo00@007ooOol000aoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000AOol01000
Oomoo`002goo00<007ooOol00Woo00<007ooOol02Woo00@007ooOol0011oo`04001oogoo000<Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`004Goo00<007oo000037oo00<007ooOol00Woo
00<007ooOol02Woo00@007ooOol000Uoo`40000000<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007oo
Ool02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007oo
Ool00goo0@0000000`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol0
0`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`03Ool100000003001oogoo
00Moo`04001oogoo000<Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`004Goo00@007oo
Ool000]oo`03001oogoo009oo`03001oogoo00Yoo`04001oogoo000@Ool01000Oomoo`0037oo00<0
07ooOol00Woo00<007ooOol02Goo00@007ooOol0015oo`04001oogoo000;Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool01000Oomoo`0047oo00@007ooOol000aoo`03001oogoo009oo`03001oogoo00Uo
o`04001oogoo000AOol01000Oomoo`002goo00<007ooOol00Woo00<007ooOol02Woo00@007ooOol0
011oo`04001oogoo000<Ool01@00Oomoogoo000037oo00@007ooOol0015oo`04001oogoo000;Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`002Goo0@0000000`00Ool0000BOol00`00Ool0
000:Ool2000BOol00`00Ool0000AOol00`00Ool0000:Ool00`00Ool0000AOol00`00Ool0000BOol0
0`00Ool0000:Ool2000BOol00`00Ool0000AOol00`00Ool0000:Ool00`00Ool0000AOol00`00Ool0
000BOol00`00Ool0000:Ool2000BOol00`00Ool0000AOol00`00Ool0000:Ool00`00Ool0000AOol0
0`00Ool0000BOol00`00Ool00009Ool00`00Ool0000BOol00`00Ool0000AOol00`00Ool0000:Ool0
0`00Ool0000AOol00`00Oomoo`0100000003001oogoo00Eoo`03001oogoo00Aoo`03001oogoo01Mo
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Ao
o`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00]o
o`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Ao
o`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qo
o`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Ao
o`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00Io
o`40000000<007ooOol017oo00<007ooOol01Woo00<007ooOol02Goo0P002Woo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo0P002goo00<007ooOol01Woo00<007oo
Ool027oo00<007ooOol01Woo00<007ooOol02Goo0P002Woo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol027oo0P002goo00<007ooOol01Woo00<007ooOol027oo00<007oo
Ool01Woo00<007ooOol02Goo0P002Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol02Goo0P002goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007oo
Ool02Goo0P002Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo
0P002goo00<007ooOol01Woo00<007ooOol017oo0@0000001000Oomoo`0047oo00<007ooOol03Goo
00<007ooOol03Woo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05001oogoo
Ool0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo00<007ooOol03Woo
00<007ooOol03Goo00D007ooOomoo`00011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogoo
Ool0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00<007ooOol03Goo
00<007ooOol03Woo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`04001oogoo
Ool100000005001oogooOol00006Ool2000;Ool20006Ool2000:Ool20006Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool2000:Ool20006Ool2000;Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`04Ool2
000;Ool20006Ool00`00Oomoo`09Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2000:Ool2
0006Ool2000;Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`04Ool2000;Ool20006Ool00`00Oomo
o`09Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool2000:Ool20006Ool2000;Ool20005Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool2000;Ool20006Ool00`00Oomoo`09Ool20006Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`09Ool20006Ool2000;Ool20005Ool00`00Oomoo`02Ool1
00000003001oogoo00ioo`03001oo`00015oo`03001oo`0001ioo`03001oo`00019oo`03001oo`00
01ioo`03001oo`00015oo`03001oo`0001ioo`03001oo`00019oo`03001oo`0001ioo`03001oo`00
015oo`03001oo`0001ioo`03001oo`00019oo`03001oo`0001ioo`03001oo`00015oo`03001oo`00
01ioo`03001oo`00019oo`03001oo`00011oo`40000000<007ooOol00goo00@007ooOol0015oo`04
001oogoo000@Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`00
27oo00@007ooOol0015oo`04001oogoo000@Ool01000Oomoo`002Goo00@007ooOol0011oo`04001o
ogoo000AOol00`00Ool00009Ool01000Oomoo`004Goo00@007ooOol0011oo`04001oogoo0009Ool0
1000Oomoo`0047oo00@007ooOol0015oo`03001oo`0000Uoo`04001oogoo000AOol01000Oomoo`00
47oo00@007ooOol000Uoo`04001oogoo000@Ool01000Oomoo`004Goo00<007oo00001Woo0@000000
0`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0FOol0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`04Ool0
0`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool100000003001oogoo01=oo`03001oogoo
00Uoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo
019oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo
015oo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo015oo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo
015oo`03001oogoo00Yoo`03001oogoo015oo`40005oo`40000000<007ooOol01Woo00<007ooOol0
0Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol0
6Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Goo00<007ooOol0
0Woo00<007ooOol03Goo00D007ooOomoo`0001aoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00eoo`05001oogooOol0000LOol0
0`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool0
0`00Oomoo`0=Ool01@00Oomoogoo000077oo00D007ooOomoo`0000Uoo`40000000<007ooOol00goo
00<007ooOol027oo00<007ooOol01goo00@007ooOol000Qoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Ioo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoo`0027oo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol027oo00<007ooOol01Woo00@007ooOol000Uoo`03001oogoo00Qoo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo0008Ool00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol027oo00<007oo
Ool01Woo00<007ooOol027oo00<007ooOol01goo00@007ooOol000Qoo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`08Ool00`00
Oomoo`03Ool100000005001oogooOol0000>Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomo
o`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomo
o`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool100000003001oogoo00Qoo`80
00aoo`03001oogoo00Aoo`03001oogoo00Uoo`8001=oo`8000]oo`03001oogoo00Aoo`03001oogoo
00Yoo`80019oo`8000aoo`03001oogoo00Aoo`03001oogoo00Uoo`8001=oo`8000]oo`03001oogoo
00Aoo`03001oogoo00Yoo`80019oo`8000aoo`03001oogoo00=oo`03001oogoo00Yoo`8001=oo`80
00]oo`03001oogoo00Aoo`03001oogoo00Yoo`80019oo`8000aoo`03001oogoo00=oo`03001oogoo
00Yoo`8001=oo`8000]oo`03001oogoo00Aoo`03001oogoo00Yoo`8000Yoo`40000000@007ooOol0
01Aoo`03001oogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00
Oomoo`0BOol01000Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0001=o
o`03001oogoo00Ioo`03001oogoo019oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomoo`0A
Ool01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0001Aoo`03
001oogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00Oomoo`0A
Ool01000Oomoogoo0@0000000`00Oomoo`04Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo00D0
07ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`05001oogooOol0000@Ool01@00Oomo
ogoo000027oo00<007ooOol027oo00<007ooOol01Woo00D007ooOomoo`0000moo`05001oogooOol0
0008Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomoogoo000047oo00D007ooOomoo`0000Mo
o`03001oogoo00Uoo`03001oogoo00Ioo`05001oogooOol0000?Ool01@00Oomoogoo000027oo00<0
07ooOol02Goo00<007ooOol01Goo00D007ooOomoo`00011oo`05001oogooOol00007Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Qoo`03001oogoo00Uo
o`03001oogoo00Eoo`05001oogooOol0000@Ool01@00Oomoogoo00001goo00<007ooOol01Goo0@00
00000`00Oomoo`05Ool00`00Oomoo`0AOol2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000C
Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000C
Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000C
Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool2000C
Ool00`00Oomoo`05Ool100000003001oo`0000aoo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oo`0000aoo`03001oogoo00=oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oo`0000aoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oo`0000aoo`03001oogoo00=oo`03001oogoo00]oo`03001o
ogoo00=oo`03001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00Uoo`03001oogoo0040000000<007ooOol02Woo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol027oo00<0
07ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol057oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol057oo00<0
07ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol02Woo0@0000000`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02
Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?
Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool100000003001o
ogoo009oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Uoo`8001=oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo015o
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`8001=oo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo00Uoo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo015oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo019oo`03001o
ogoo00Yoo`03001oogoo009oo`40000000<007ooOol00Woo00<007ooOol04Woo00<007ooOol00Woo
00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Goo
00<007ooOol01Goo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo
00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Woo
00D007ooOomoo`0001Aoo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo009oo`03001oogoo
015oo`03001oogoo00Eoo`03001oogoo019oo`05001oogooOol0000DOol00`00Oomoo`05Ool00`00
Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`03Ool100000003001oogoo00Mo
o`04001oogoo000MOol01000Oomoo`004Goo00@007ooOol001eoo`04001oogoo000@Ool01000Oomo
o`007Goo00@007ooOol0015oo`04001oogoo000MOol01000Oomoo`0047oo00@007ooOol001eoo`04
001oogoo000AOol01000Oomoo`007Goo00@007ooOol0011oo`04001oogoo000MOol01000Oomoo`00
4Goo00@007ooOol001eoo`04001oogoo0009Ool100000003001oo`00019oo`03001oo`0000Yoo`80
019oo`03001oo`00015oo`03001oo`0000Yoo`03001oo`00019oo`80019oo`03001oo`0000Yoo`80
019oo`03001oo`00015oo`03001oo`0000Yoo`03001oo`00015oo`03001oo`00019oo`03001oo`00
00Yoo`80019oo`03001oo`00015oo`03001oo`0000Yoo`03001oo`00015oo`03001oo`00019oo`03
001oo`0000Yoo`80019oo`03001oo`00015oo`03001oo`0000Yoo`03001oo`00015oo`03001oogoo
0040000000<007ooOol017oo0P001Woo00<007ooOol02Woo0P002goo00<007ooOol017oo0P002goo
0P001Goo00<007ooOol02Woo0P0037oo00<007ooOol017oo0P002Woo0P001Woo00<007ooOol02Woo
0P002goo00<007ooOol017oo0P002goo0P001Goo00<007ooOol02Woo0P0037oo00<007ooOol00goo
00<007oo00002Woo0P001Woo00<007ooOol02Woo0P002goo00<007ooOol017oo0P002goo0P001Goo
00<007ooOol02Woo0P0037oo00<007ooOol00goo00<007oo00002Woo0P001Woo00<007ooOol02Woo
0P002goo00<007ooOol017oo0P002goo0P001Goo00<007ooOol02Woo0P0037oo00<007ooOol00goo
00<007oo00001Woo0@0000001000Oomoo`0037oo00D007ooOomoo`00011oo`04001oogoo000<Ool0
1@00Oomoogoo000037oo00@007ooOol0011oo`05001oogooOol0000;Ool01@00Oomoogoo000037oo
00D007ooOomoo`00011oo`04001oogoo000<Ool01@00Oomoogoo000037oo00@007ooOol0011oo`05
001oogooOol0000;Ool01@00Oomoogoo000037oo00D007ooOomoo`0000moo`05001oogooOol0000<
Ool01@00Oomoogoo000037oo00@007ooOol0011oo`05001oogooOol0000;Ool01@00Oomoogoo0000
37oo00D007ooOomoo`0000moo`05001oogooOol0000<Ool01@00Oomoogoo000037oo00@007ooOol0
011oo`05001oogooOol0000;Ool01000Oomoogoo0@0000000`00Oomoo`09Ool00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool100000005001oogooOol00006Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool01000Oomoogoo0@000000
0`00Oomoo`0>Ool00`00Ool0000AOol00`00Ool0000NOol01000Oomoo`004Goo00<007oo00007Woo
00<007oo00004Goo00<007oo00007Woo00@007ooOol0015oo`03001oo`0001ioo`03001oo`00015o
o`03001oo`0001ioo`03001oo`00019oo`03001oo`0001ioo`03001oo`00015oo`03001oo`0001io
o`03001oo`00019oo`03001oo`00011oo`40000000<007ooOol00goo00@007ooOol0015oo`04001o
ogoo000@Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo000AOol00`00Ool00009Ool0
1000Oomoo`004Goo00@007ooOol0011oo`04001oogoo0009Ool01000Oomoo`0047oo00@007ooOol0
015oo`03001oo`0000Uoo`04001oogoo000AOol00`00Ool0000AOol01000Oomoo`002Goo00@007oo
Ool0011oo`04001oogoo000AOol00`00Ool00009Ool01000Oomoo`004Goo00<007oo00004Goo00@0
07ooOol000Uoo`04001oogoo000@Ool01000Oomoo`004Goo00<007oo00001Woo0@0000000`00Oomo
o`0;Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomo
o`0GOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool100000003001oo`0000]oo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`8000]oo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`40005oo`40000000<007ooOol01Woo00<007ooOol0
3goo00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000AOol00`00Oomo
o`0<Ool00`00Oomoo`0?Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo00@007oo
Ool0011oo`03001oogoo00eoo`03001oogoo00moo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03goo00@007ooOol0011oo`03
001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`07Ool100000003001oogoo
00=oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo
00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo
01=oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo
00Qoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo
00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
01=oo`03001oogoo00Qoo`03001oogoo00=oo`40000000D007ooOomoo`0000ioo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00]o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00]o
o`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00ao
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo00=o
o`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00]o
o`03001oogoo009oo`40000000<007ooOol027oo0P007goo0P004goo0P007goo0P004Woo0P007goo
0P004goo0P007goo0P004Woo0P007goo0P004Woo00<007oo00007goo0P004Woo0P007goo0P004Woo
00<007oo00007goo0P002Woo0@0000001000Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo
00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001oogoo019oo`04001oogoo000DOol00`00Oomo
o`06Ool00`00Oomoo`0AOol01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@0
07ooOol001Aoo`03001oogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06
Ool00`00Oomoo`0BOol01000Oomoo`0057oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomo
o`0001=oo`03001oogoo00Ioo`03001oogoo015oo`04001oogooOol100000003001oogoo00Aoo`03
001oogoo00Ioo`05001oogooOol0000?Ool01@00Oomoogoo000027oo00<007ooOol02Goo00<007oo
Ool01Goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000Moo`03001oogoo00Uoo`03
001oogoo00Ioo`05001oogooOol0000?Ool01@00Oomoogoo000027oo00<007ooOol02Goo00<007oo
Ool01Goo00D007ooOomoo`00011oo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`05
001oogooOol0000@Ool01@00Oomoogoo00001goo00<007ooOol02Goo00<007ooOol01Woo00D007oo
Oomoo`0000moo`05001oogooOol00008Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomoogoo
000047oo00D007ooOomoo`0000Moo`03001oogoo00Eoo`40000000<007ooOol01Goo00<007ooOol0
4Goo0P004Woo00<007ooOol02goo00<007ooOol047oo0P004goo00<007ooOol02Woo00<007ooOol0
4Goo0P004Woo00<007ooOol02goo00<007ooOol047oo0P004goo00<007ooOol02Woo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol047oo0P004goo00<007ooOol02Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol047oo0P004goo00<007ooOol0
1Goo0@0000001000Oomoo`002goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<0
07ooOol02Woo00<007oo000037oo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00goo00<0
07ooOol02Goo00@007ooOol000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03
001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03
001oogoo00Uoo`03001oo`0000aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03
001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03
001oogoo00Uoo`03001oo`0000aoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03
001oogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03
001oogoo00Uoo`03001oogoo0040000000<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo
00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol057oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol02Woo
0@0000000`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomo
o`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomo
o`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomo
o`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomo
o`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomo
o`0?Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomo
o`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool100000003001oogoo009oo`03
001oogoo00Yoo`03001oogoo00Eoo`05001oogooOol00007Ool2000;Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`09Ool20006Ool00`00
Oomoo`0:Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo0P002goo00<007ooOol01Goo00<007oo
Ool02Goo0P001Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol02Goo0P001Woo00<007oo
Ool02Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo00Yoo`03001oogoo00Eoo`03
001oogoo00Uoo`8000Ioo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`8000Ioo`03
001oogoo00Yoo`03001oogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`0:Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool20006Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`09Ool20004
Ool100000003001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000
Oomoo`004Goo00@007ooOol000Qoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo000@Ool0
1000Oomoo`002Goo00<007ooOol027oo00<007ooOol01Woo00@007ooOol0015oo`04001oogoo0008
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoo`0047oo00@007ooOol000Uoo`03001oogoo
00Qoo`03001oogoo00Ioo`04001oogoo000@Ool01@00Oomoogoo000027oo00<007ooOol027oo00<0
07ooOol01goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
1000Oomoo`0047oo00D007ooOomoo`0000Qoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo
0009Ool100000003001oo`00019oo`03001oogoo00]oo`03001oogoo011oo`03001oo`00019oo`03
001oogoo00]oo`03001oogoo011oo`80019oo`03001oogoo00]oo`03001oogoo011oo`03001oo`00
015oo`03001oogoo00aoo`03001oogoo011oo`80019oo`03001oogoo00]oo`03001oogoo011oo`03
001oo`00015oo`03001oogoo00aoo`03001oogoo011oo`80019oo`03001oogoo00]oo`03001oogoo
011oo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo0040000000<007oo
Ool01Goo00<007ooOol017oo00<007ooOol02Woo0P002goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02Woo0P0037oo00<007ooOol00goo00<007ooOol02goo00<007oo
Ool017oo00<007ooOol02Woo0P002goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo
00<007ooOol02Woo0P0037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Woo0P002goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol02Woo
0P0037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Goo00<007oo
00002goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007ooOol02Woo0P0037oo
00<007ooOol00goo00<007ooOol01Woo0@0000000`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomo
o`04Ool100000005001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo
00003goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol03Goo00<007oo
Ool03Woo00<007ooOol03Goo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05
001oogooOol0000@Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007oo
Ool03Woo00<007ooOol03Goo00D007ooOomoo`00011oo`03001oogoo00ioo`03001oogoo00eoo`05
001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01000Oomoogoo0@0000000`00Oomo
o`08Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000COol00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool2000BOol2000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000COol0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool2000BOol2000;Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool2000COol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`0AOol2000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000COol00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`09Ool100000005001oogooOol0000DOol00`00Oomoo`04
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0B
Ool00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03
Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0B
Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0A
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol01000Oomoogoo
0@0000000`00Oomoo`0>Ool00`00Ool0000AOol01000Oomoo`007Goo00@007ooOol0015oo`03001o
o`0001ioo`03001oo`00015oo`03001oo`0001ioo`04001oogoo000AOol00`00Ool0000NOol00`00
Ool0000AOol00`00Ool0000NOol01000Oomoo`004Goo00<007oo00007Woo00<007oo00004Goo00<0
07oo00007Woo00<007oo00004Woo00<007oo000047oo0@0000000`00Oomoo`03Ool01000Oomoo`00
4Goo00<007oo00004Goo00@007ooOol000Uoo`04001oogoo000@Ool01000Oomoo`004Goo00<007oo
00002Goo00@007ooOol0015oo`03001oo`00015oo`04001oogoo0009Ool01000Oomoo`0047oo00@0
07ooOol0015oo`03001oo`0000Uoo`04001oogoo000AOol00`00Ool0000AOol01000Oomoo`002Goo
00<007oo00004Goo00@007ooOol0015oo`03001oo`0000Uoo`04001oogoo000AOol00`00Ool0000A
Ool01000Oomoo`002Goo00<007oo00004Goo00@007ooOol0015oo`03001oo`0000Ioo`40000000<0
07ooOol02goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol05goo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol05goo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<0
07ooOol05goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol05Woo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol05goo00<007ooOol017oo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol02goo0@0000000`00Ool0000;Ool00`00Oomoo`05
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`06
Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`05Ool00`00Oomoo`09Ool10001Ool100000003001oogoo00Ioo`03001oogoo00moo`04001o
ogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol03Goo00<0
07ooOol03goo00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool0
0`00Oomoo`0=Ool00`00Oomoo`0?Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo
00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomo
o`0=Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol01goo0@0000000`00Oomoo`03Ool0
0`00Oomoo`08Ool00`00Ool0000BOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`08Ool2000BOol0
0`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool0000BOol2000:Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool2000BOol00`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Ool0000BOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`08Ool2000BOol00`00Ool0000:Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool0000AOol00`00Ool0000:Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool2000BOol00`00Ool0000:Ool00`00Oomoo`03Ool100000003001oogoo009oo`03
001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03
001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03
001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03
001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03
001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03
001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03
001oogoo015oo`03001oogoo009oo`40000000<007ooOol027oo0P007goo0P004Woo00<007oo0000
7goo0P004Woo0P007goo0P004Woo00<007oo00007goo0P004Woo0P007goo0P004Woo00<007oo0000
7Woo00<007oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<007oo00002Woo0@0000001000
Oomoo`0047oo00D007ooOomoo`0000Qoo`04001oogoo000@Ool01@00Oomoogoo000047oo00@007oo
Ool000Qoo`05001oogooOol0000@Ool01000Oomoo`0047oo00D007ooOomoo`0000Qoo`04001oogoo
000@Ool01@00Oomoogoo000047oo00@007ooOol000Qoo`05001oogooOol0000@Ool01000Oomoo`00
47oo00D007ooOomoo`0000Qoo`04001oogoo000@Ool01@00Oomoogoo000047oo00@007ooOol000Qo
o`05001oogooOol0000@Ool01000Oomoo`0047oo00D007ooOomoo`0000Qoo`04001oogoo000@Ool0
1@00Oomoogoo00003goo00D007ooOomoo`0000Qoo`05001oogooOol0000@Ool00`00Oomoo`010000
0003001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Io
o`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo01Io
o`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Io
o`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Uo
o`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eo
o`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Eoo`40000000<007ooOol01Goo00<007oo
Ool017oo00<007ooOol02Woo0P002goo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo
00<007ooOol02Goo0P0037oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Goo0P0037oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Goo
0P0037oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo0P0037oo
00<007ooOol017oo00<007ooOol01Goo0@0000001000Oomoo`002Goo00<007ooOol01Goo00<007oo
00002Goo00@007ooOol000Ioo`03001oogoo00Qoo`03001oo`0000Uoo`03001oogoo00Eoo`04001o
ogoo0009Ool00`00Ool00007Ool00`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol01Goo00<0
07oo00002Goo00@007ooOol000Ioo`03001oogoo00Qoo`03001oo`0000Uoo`03001oogoo00Eoo`03
001oo`0000Yoo`03001oo`0000Moo`03001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`05Ool0
0`00Ool00009Ool01000Oomoo`001Woo00<007ooOol027oo00<007oo00002Goo00<007ooOol01Goo
00<007oo00002Woo00<007oo00001goo00<007ooOol01goo00@007ooOol000Uoo`03001oogoo00Eo
o`03001oo`0000Uoo`04001oogoo0006Ool00`00Oomoo`08Ool00`00Ool00009Ool00`00Oomoo`05
Ool00`00Ool0000:Ool00`00Ool00007Ool00`00Oomoo`07Ool00`00Oomoo`0100000003001oogoo
009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo
00aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo
009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo009oo`40000000<007ooOol03goo00<0
07ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<0
07ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo00<0
07ooOol07Woo0P004goo00<007ooOol03goo0@0000000`00Oomoo`03Ool00`00Oomoo`0AOol01@00
Oomoogoo000057oo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Goo
00<007ooOol01Goo00<007ooOol04Woo00D007ooOomoo`0001Aoo`03001oogoo00Eoo`03001oogoo
015oo`03001oogoo009oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo019oo`05001oogoo
Ool0000DOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00
Oomoo`05Ool00`00Oomoo`0BOol01@00Oomoogoo000057oo00<007ooOol01Goo00<007ooOol04Goo
00<007ooOol00Woo00<007ooOol04Goo00<007ooOol00goo0@0000000`00Oomoo`07Ool01000Oomo
o`002Goo00<007ooOol027oo00<007ooOol01Woo00@007ooOol0011oo`05001oogooOol00008Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoo`0047oo00@007ooOol000Uoo`03001oogoo00Qo
o`03001oogoo00Ioo`04001oogoo000@Ool01@00Oomoogoo000027oo00<007ooOol027oo00<007oo
Ool01goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000
Oomoo`0047oo00D007ooOomoo`0000Qoo`03001oogoo00Qoo`03001oogoo00Ioo`05001oogooOol0
000@Ool01000Oomoo`002Goo00<007ooOol027oo00<007ooOol01Woo00@007ooOol0011oo`05001o
ogooOol00008Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01@00Oomoogoo00002Goo0@0000000`00
Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Ool0000BOol00`00Oomoo`0;Ool00`00
Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Ool0000BOol00`00Oomoo`0;
Ool00`00Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Ool0000BOol00`00
Oomoo`0;Ool00`00Oomoo`0@Ool2000BOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Ool0000A
Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool10001Ool100000003001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00Yoo`8000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00Yoo`8000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Uo
o`03001oo`0000]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yo
o`8000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Uoo`03001o
o`0000]oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`8000ao
o`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oo`0000]o
o`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`8000aoo`03001o
ogoo00=oo`03001oogoo00Ioo`40000000<007ooOol017oo00<007ooOol01Woo00<007ooOol05Goo
00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo
00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol01goo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol017oo
0@0000001@00Oomoogoo00003goo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo00eo
o`05001oogooOol0000?Ool01@00Oomoogoo000027oo00D007ooOomoo`0000moo`03001oogoo009o
o`03001oogoo00eoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomo
ogoo00003goo00D007ooOomoo`0000Qoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomo
o`0=Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000mo
o`05001oogooOol00008Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`05001oogooOol0
0007Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Qo
o`05001oogooOol0000?Ool01000Oomoogoo0@0000000`00Oomoo`08Ool2000OOol2000COol00`00
Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000COol00`00Oomoo`0NOol00`00Oomoo`0AOol2000O
Ool2000COol00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000COol00`00Oomoo`0NOol00`00
Oomoo`09Ool100000005001oogooOol0000DOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomo
o`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomo
o`0BOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomo
o`04Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomo
o`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomo
o`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomo
o`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol01000Oomoogoo0@0000000`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Ool0000AOol01000Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo00@0
07ooOol0015oo`03001oo`0000Uoo`03001oogoo00Moo`03001oogoo00Qoo`03001oo`00015oo`04
001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`004Goo00<007oo00002Goo
00<007ooOol01goo00<007ooOol027oo00<007oo00004Goo00@007ooOol000Uoo`03001oogoo00Mo
o`03001oogoo00Moo`04001oogoo000AOol00`00Ool00009Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Ool0000AOol00`00Ool0000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`00
4Goo00<007oo00002Goo00<007ooOol017oo0@0000000`00Oomoo`06Ool00`00Oomoo`0?Ool00`00
Ool0000AOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`004Goo00<007ooOol037oo00<0
07ooOol03goo00<007oo00004Goo00<007ooOol037oo00<007ooOol03goo00@007ooOol0015oo`03
001oogoo00aoo`03001oogoo00moo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`04
001oogoo000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Ool0000AOol00`00Oomoo`0<Ool0
0`00Oomoo`0?Ool01000Oomoo`004Goo00<007ooOol01Woo0@0000000`00Ool0000;Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool0
0`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool10001Ool100000003001oogoo00]oo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03
001oogoo01Ioo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo01Ioo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Ioo`03
001oogoo00Uoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03
001oogoo00]oo`40000000<007ooOol01Woo00<007ooOol03goo00@007ooOol0011oo`03001oogoo
00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@00Oomo
ogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0011oo`03001oogoo00eoo`03
001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`00
47oo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`00011oo`03001oogoo00eoo`03001o
ogoo00ioo`04001oogoo000@Ool00`00Oomoo`07Ool100000003001oogoo00=oo`03001oogoo00Qo
o`03001oo`00019oo`8000Yoo`03001oogoo00Moo`03001oogoo00Qoo`80019oo`03001oo`0000Yo
o`03001oogoo00Ioo`03001oogoo00Qoo`03001oo`00019oo`8000Yoo`03001oogoo00Moo`03001o
ogoo00Qoo`80019oo`03001oo`0000Yoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oo`00019o
o`8000Yoo`03001oogoo00Moo`03001oogoo00Qoo`80019oo`03001oo`0000Yoo`03001oogoo00Io
o`03001oogoo00Qoo`03001oo`00019oo`8000Yoo`03001oogoo00Ioo`03001oogoo00Uoo`80019o
o`03001oo`0000Yoo`03001oogoo00=oo`40000000<007ooOol00Woo00<007ooOol04Goo00<007oo
Ool00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007oo
Ool04Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo00<007oo
Ool00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol017oo00<007oo
Ool04Goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Goo00<007oo
Ool017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007oo
Ool04Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo00<007oo
Ool00Woo0@0000000`00Oomoo`08Ool2000OOol2000BOol00`00Ool0000OOol2000BOol2000OOol2
000BOol00`00Ool0000NOol00`00Ool0000BOol2000OOol2000BOol00`00Ool0000NOol00`00Ool0
000BOol2000OOol2000BOol00`00Ool0000NOol00`00Ool0000:Ool100000004001oogoo0004Ool0
0`00Oomoo`05Ool01@00Oomoogoo00000goo00<007ooOol01Woo00@007ooOol000Aoo`03001oogoo
00Eoo`05001oogooOol00003Ool01@00Oomoogoo00001goo00<007ooOol00Woo00@007ooOol000Qo
o`05001oogooOol00003Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo
Ool01Woo00D007ooOomoo`0000=oo`03001oogoo00Ioo`04001oogoo0004Ool00`00Oomoo`05Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Moo`03001oogoo009oo`04001oogoo0008Ool01@00
Oomoogoo00000goo00<007ooOol01Goo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00Io
o`05001oogooOol00003Ool00`00Oomoo`06Ool01000Oomoo`0017oo00<007ooOol01Goo00D007oo
Oomoo`0000=oo`05001oogooOol00007Ool00`00Oomoo`02Ool01000Oomoo`0027oo00D007ooOomo
o`0000=oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0003Ool00`00Oomoo`06Ool01@00
Oomoogoo00000Woo00<007ooOol01goo00@007ooOol000=oo`03001oogoo00Ioo`05001oogooOol0
0003Ool01@00Oomoogoo00001goo00<007ooOol00Woo00@007ooOol000Qoo`05001oogooOol00003
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0100000003001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo
00Aoo`03001oogoo00Uoo`8000aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03
001oogoo00Uoo`8000aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Uoo`8000aoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`80
00]oo`03001oogoo00Eoo`03001oogoo00Eoo`40000000@007ooOol0015oo`03001oogoo00aoo`03
001oogoo00moo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000AOol0
0`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool0
1000Oomoo`004Goo00<007ooOol037oo00<007ooOol03goo00<007oo00004Goo00<007ooOol037oo
00<007ooOol03goo00@007ooOol0015oo`03001oogoo00aoo`03001oogoo00moo`03001oo`00015o
o`03001oogoo00aoo`03001oogoo00moo`03001oogoo0040000000<007ooOol01goo00@007ooOol0
00Uoo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo000AOol00`00Ool0000:Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Ool0000AOol01000Oomoo`002Goo00<007ooOol01goo00<007oo
Ool01goo00@007ooOol0015oo`03001oo`0000Yoo`03001oogoo00Moo`03001oogoo00Moo`03001o
o`00015oo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`004Goo00<0
07oo00002Goo00<007ooOol027oo00<007ooOol01goo00<007oo00004Goo00@007ooOol000Uoo`03
001oogoo00Moo`03001oogoo00Moo`04001oogoo000AOol00`00Ool00009Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Ool0000:Ool100000003001oogoo009oo`03001oogoo019oo`03001oogoo
009oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo009oo`03001oogoo
019oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo
00Eoo`03001oogoo015oo`03001oogoo009oo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo
015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo
009oo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo
015oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo
009oo`40000000<007ooOol03goo00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<0
07ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<0
07ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<007ooOol03goo0@0000000`00Oomoo`03
Ool01@00Oomoogoo00003goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Eoo`05
001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo000027oo00D007oo
Oomoo`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000Qoo`05001oogooOol0000?
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00eoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0=
Ool01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000moo`03
001oogoo009oo`03001oogoo00eoo`05001oogooOol00005Ool100000003001oogoo00Yoo`03001o
ogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001o
ogoo01Eoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo01Eoo`03001o
ogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001o
ogoo00Ioo`03001oogoo00]oo`40000000<007oo000037oo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Goo00<007oo00004Woo00<007ooOol02goo00<007ooOol047oo
0P004Woo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Goo00<007oo00002goo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol047oo0P0037oo00<007ooOol00goo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02Woo00<007oo00004Woo00<007ooOol02goo00<007ooOol00goo
00<007ooOol02Woo0P004Woo00<007ooOol02goo00<007ooOol047oo00<007oo00002goo00<007oo
Ool017oo00<007ooOol02goo00<007ooOol047oo0@000Goo0@0000000`00Oomoo`05Ool00`00Oomo
o`0@Ool00`00Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool2000<Ool0
0`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Ool0000BOol0
0`00Oomoo`0;Ool00`00Oomoo`0@Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`0@Ool00`00Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool2000BOol0
0`00Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`04Ool0
0`00Oomoo`0;Ool00`00Oomoo`0@Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`06Ool100000003
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Uoo`03
001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo01Eoo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03
001oogoo00Qoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo01Aoo`03001oogoo00Moo`03001oogoo00Aoo`40000000D007ooOomoo`0000moo`05001o
ogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00eoo`05001o
ogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol0
0Woo00<007ooOol01Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00eoo`05001o
ogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00D007ooOomo
o`0000Qoo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo0000
1goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000moo`05001oogooOol00008Ool0
1@00Oomoogoo00003goo00@007ooOomoo`40000000<007ooOol027oo0P007goo0P004goo00<007oo
Ool07Woo00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo
0P004goo00<007ooOol07Woo00<007ooOol04Goo0P007goo0P004goo00<007ooOol07Woo00<007oo
Ool02Goo0@0000001@00Oomoogoo000057oo00<007ooOol017oo00<007ooOol04Goo00<007ooOol0
0goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol0
4Woo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol0
17oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol0
4Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol0
0Woo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0
4Goo00<007ooOol017oo00<007ooOol04Woo00@007ooOomoo`40000000<007ooOol017oo00<007oo
Ool01goo00<007oo00004Goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Moo`04001o
ogoo000AOol00`00Ool00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Ool0000AOol01000
Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo00@007ooOol0015oo`03001oo`0000Uoo`03
001oogoo00Qoo`03001oogoo00Moo`03001oo`00015oo`04001oogoo0009Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool01000Oomoo`004Goo00<007oo00002Goo00<007ooOol01goo00<007ooOol027oo
00<007oo00004Goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo000A
Ool00`00Ool00009Ool00`00Oomoo`04Ool100000003001oogoo00Ioo`03001oogoo00moo`03001o
o`00015oo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000AOol00`00Oomoo`0<Ool00`00
Oomoo`0?Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool01000Oomoo`004Goo00<0
07ooOol037oo00<007ooOol03goo00<007oo00004Goo00<007ooOol037oo00<007ooOol03goo00@0
07ooOol0015oo`03001oogoo00aoo`03001oogoo00moo`03001oo`00015oo`03001oogoo00aoo`03
001oogoo00moo`04001oogoo000AOol00`00Oomoo`06Ool100000003001oo`0000]oo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`8000]oo`03001oogoo00Eoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`8000]oo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`8000]oo`03001oogoo00Eoo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00Yoo`40005oo`40000000<007ooOol02goo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Woo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol05Woo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol02goo0@0000000`00Oomoo`03Ool01000Oomoo`001goo00<007oo00001Woo00D007ooOomo
o`0000Moo`8000Moo`04001oogoo0009Ool01000Oomoo`001goo0P001goo00@007ooOol000Moo`03
001oo`0000Ioo`05001oogooOol00008Ool01000Oomoo`001goo00<007oo00001Woo00D007ooOomo
o`0000Moo`8000Moo`04001oogoo0008Ool01@00Oomoogoo00001goo0P001goo00@007ooOol000Mo
o`03001oo`0000Ioo`05001oogooOol00008Ool01000Oomoo`001goo00<007oo00001Woo00D007oo
Oomoo`0000Moo`8000Moo`04001oogoo0008Ool01@00Oomoogoo00001goo0P001goo00@007ooOol0
00Moo`03001oo`0000Ioo`05001oogooOol00008Ool01000Oomoo`001goo00<007oo00001Woo00D0
07ooOomoo`0000Moo`8000Moo`04001oogoo0008Ool01@00Oomoogoo00001goo0P001goo00@007oo
Ool000Moo`8000Moo`05001oogooOol00005Ool100000003001oogoo009oo`03001oogoo015oo`03
001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03
001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03
001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03
001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03
001oogoo00Aoo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03
001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03
001oogoo009oo`40000000<007ooOol027oo0P002goo00<007ooOol01Woo00<007ooOol027oo0P00
4Woo00<007oo00002Woo00<007ooOol01Woo00<007ooOol027oo00<007oo00004Woo0P002goo00<0
07ooOol01Woo00<007ooOol027oo0P004Woo00<007oo00002Woo00<007ooOol01Woo00<007ooOol0
27oo00<007oo00004Woo0P002Woo00<007ooOol01goo00<007ooOol027oo0P004Woo00<007oo0000
2Woo00<007ooOol01Woo00<007ooOol027oo00<007oo00004Woo0P002Woo00<007ooOol01goo00<0
07ooOol027oo0P004Woo00<007oo00002Woo00<007ooOol01Woo00<007ooOol027oo00<007oo0000
2Woo0@0000001000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`00011o
o`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0011oo`03001o
ogoo00eoo`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool0
1000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`00011oo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo0040000000<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007oo
Ool01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007oo
Ool02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Woo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007oo
Ool01Goo0@0000000`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000<Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool0
0`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomo
o`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`05Ool1
00000004001oogoo000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Ool0000AOol00`00Oomo
o`0<Ool00`00Oomoo`0?Ool01000Oomoo`004Goo00<007ooOol037oo00<007ooOol03goo00<007oo
00004Goo00<007ooOol037oo00<007ooOol03goo00@007ooOol0015oo`03001oogoo00aoo`03001o
ogoo00moo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00moo`04001oogoo000AOol00`00
Oomoo`0<Ool00`00Oomoo`0?Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00
Oomoo`0100000003001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Ool0000AOol00`00Ool0000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Ool0000AOol0
1000Oomoo`002Goo00<007ooOol01goo00<007ooOol027oo00<007oo00004Goo00<007oo00002Woo
00<007ooOol01goo00<007ooOol01goo00<007oo00004Goo00@007ooOol000Uoo`03001oogoo00Mo
o`03001oogoo00Moo`04001oogoo000AOol00`00Ool0000:Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Ool0000AOol01000Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo00@007ooOol0
015oo`03001oo`0000Yoo`03001oogoo00Moo`03001oogoo00Moo`03001oo`0000Yoo`40000000<0
07ooOol00Woo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol01Goo00<0
07ooOol04Goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol017oo00<007ooOol04Goo00<0
07ooOol00goo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<0
07ooOol04Woo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<0
07ooOol017oo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol017oo00<0
07ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Woo00<0
07ooOol00Woo00<007ooOol04Woo00<007ooOol00Woo0@0000000`00Oomoo`0?Ool00`00Oomoo`0A
Ool2000OOol2000COol00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000COol00`00Oomoo`0N
Ool00`00Oomoo`0AOol2000OOol2000COol00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000C
Ool00`00Oomoo`0?Ool100000003001oogoo00=oo`05001oogooOol0000?Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`00011oo`05001oogooOol0000?Ool0
1@00Oomoogoo000027oo00D007ooOomoo`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool01@00Oomoogoo000047oo00D007ooOomoo`0000moo`05001oogooOol00008Ool0
1@00Oomoogoo00003goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Eoo`05001o
ogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01@00Oomoogoo000027oo00D007ooOomo
o`0000moo`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo0000
3goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0000Eoo`40000000<007ooOol02Woo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo
00<007ooOol027oo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo
00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo
00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol027oo
00<007ooOol01Woo00<007ooOol02goo0@0000000`00Ool0000<Ool00`00Oomoo`03Ool00`00Oomo
o`0;Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`04Ool00`00Oomo
o`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool0
0`00Oomoo`04Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool0
0`00Oomoo`03Ool00`00Oomoo`0:Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomo
o`04Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomo
o`03Ool00`00Oomoo`0:Ool2000<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`04Ool0
0`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool0
0`00Oomoo`0:Ool10001Ool100000003001oogoo00Ioo`03001oogoo00moo`03001oo`00019oo`03
001oogoo00]oo`03001oogoo011oo`80019oo`03001oogoo00aoo`03001oogoo00moo`03001oo`00
019oo`03001oogoo00]oo`03001oogoo011oo`80019oo`03001oogoo00]oo`03001oogoo011oo`03
001oo`00019oo`03001oogoo00]oo`03001oogoo011oo`80019oo`03001oogoo00]oo`03001oogoo
011oo`03001oo`00019oo`03001oogoo00]oo`03001oogoo011oo`80019oo`03001oogoo00Ioo`40
000000<007ooOol017oo00<007ooOol01Woo00D007ooOomoo`00011oo`04001oogoo0008Ool00`00
Oomoo`08Ool00`00Oomoo`07Ool01000Oomoo`0047oo00D007ooOomoo`0000Qoo`03001oogoo00Qo
o`03001oogoo00Ioo`05001oogooOol0000@Ool01000Oomoo`0027oo00<007ooOol027oo00<007oo
Ool01goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01@00
Oomoogoo000047oo00@007ooOol000Qoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo000@
Ool01000Oomoo`002Goo00<007ooOol027oo00<007ooOol01Woo00D007ooOomoo`00011oo`04001o
ogoo0008Ool00`00Oomoo`08Ool00`00Oomoo`07Ool01000Oomoo`0047oo00@007ooOol000Uoo`03
001oogoo00Aoo`40000000D007ooOomoo`0001=oo`03001oogoo00Eoo`03001oogoo019oo`05001o
ogooOol0000DOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`05Ool00`00Oomoo`0BOol01@00Oomoogoo000057oo00<007ooOol01Goo00<007ooOol0
4Goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol04Woo00D007ooOomo
o`0001Aoo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo009oo`03001oogoo015oo`03001o
ogoo00Eoo`03001oogoo019oo`05001oogooOol0000DOol00`00Oomoo`05Ool00`00Oomoo`0AOol0
1000Oomoogoo0@0000000`00Oomoo`08Ool2000POol00`00Oomoo`0AOol00`00Oomoo`0NOol00`00
Oomoo`0AOol2000POol00`00Oomoo`0AOol00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000C
Ool00`00Oomoo`0NOol00`00Oomoo`0AOol2000OOol2000COol00`00Oomoo`0NOol00`00Oomoo`09
Ool100000005001oogooOol0000>Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool01000Oomoogoo0@0000000`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool100000003001oo`0000Ioo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo009oo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001o
o`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`8000Ioo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo009oo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20006Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo0P00
1Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo00<007oo00001Goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol0
17oo00<007ooOol00Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00Aoo`40005oo`40000000<007ooOol02goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
1Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
5Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol0
1Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
1Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol0
5Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02goo0@0000000`00
Oomoo`03Ool01@00Oomoogoo00003goo00D007ooOomoo`00011oo`04001oogoo0008Ool01@00Oomo
ogoo000047oo00@007ooOol0011oo`05001oogooOol00008Ool01@00Oomoogoo00003goo00D007oo
Oomoo`00011oo`04001oogoo0008Ool01@00Oomoogoo000047oo00@007ooOol0011oo`05001oogoo
Ool00008Ool01000Oomoo`0047oo00D007ooOomoo`00011oo`04001oogoo0008Ool01@00Oomoogoo
000047oo00@007ooOol0011oo`05001oogooOol00008Ool01000Oomoo`0047oo00D007ooOomoo`00
011oo`04001oogoo0008Ool01@00Oomoogoo000047oo00@007ooOol0011oo`05001oogooOol00005
Ool100000003001oogoo00ioo`03001oo`00019oo`8001moo`80019oo`03001oo`0001ioo`03001o
o`00019oo`8001moo`80019oo`03001oo`0001ioo`03001oo`00019oo`8001moo`80019oo`8001mo
o`03001oo`00019oo`8001moo`80019oo`80015oo`40000000<007ooOol00Woo00<007ooOol04Goo
00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo
00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00goo
00<007ooOol04Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol04Goo
00<007ooOol00Woo0@0000000`00Oomoo`08Ool2000:Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Ool0000AOol00`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool0000BOol2
000:Ool00`00Oomoo`07Ool00`00Oomoo`08Ool2000BOol00`00Ool0000:Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Ool0000BOol2000:Ool00`00Oomoo`07Ool00`00Oomoo`08Ool2000BOol0
0`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Ool0000BOol2000:Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool2000BOol00`00Ool0000:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Ool0000:Ool100000004001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01@00Oomo
ogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0011oo`03001oogoo00eoo`03
001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`00
47oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0015oo`03001oogoo00eoo`03001oogoo
00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`004Goo00<007oo
Ool03Goo00<007ooOol03Woo00<007ooOol00@0000000`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09
Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool2000;
Ool00`00Oomoo`05Ool00`00Oomoo`05Ool100000003001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001o
ogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001o
ogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001o
ogoo00Eoo`40000000@007ooOol0015oo`03001oo`0000Uoo`04001oogoo000AOol00`00Ool0000A
Ool01000Oomoo`002Goo00<007oo00004Goo00@007ooOol0015oo`03001oo`0000Uoo`04001oogoo
000AOol00`00Ool0000AOol01000Oomoo`002Goo00<007oo00004Goo00@007ooOol0015oo`03001o
o`0000Uoo`04001oogoo000AOol00`00Ool0000AOol01000Oomoo`002Goo00<007oo00004Goo00@0
07ooOol0011oo`04001oogoo0009Ool01000Oomoo`004Goo00<007oo00004Goo00@007ooOol000Uo
o`03001oo`00015oo`03001oogoo0040000000<007ooOol027oo00<007oo00007Woo00<007oo0000
4Goo00<007oo00007Woo00<007oo00004Woo00<007oo00007Woo00<007oo00004Goo00<007oo0000
7Woo00<007oo00004Goo00@007ooOol001ioo`03001oo`00015oo`03001oo`0001ioo`03001oo`00
015oo`04001oogoo000NOol00`00Ool0000AOol00`00Ool0000NOol00`00Ool0000:Ool100000003
001oogoo009oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03
001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo015oo`03
001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo009oo`03
001oogoo019oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03
001oogoo00Aoo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo00Aoo`03
001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo019oo`03
001oogoo009oo`03001oogoo019oo`03001oogoo009oo`40000000<007ooOol00goo00<007ooOol0
2Goo00<007ooOol04Goo0P002goo00<007ooOol01Goo00<007ooOol02Goo0P004goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol04Goo0P002goo00<007ooOol01Goo00<0
07ooOol02Goo0P004goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
4Goo0P002goo00<007ooOol01Goo00<007ooOol02Goo0P004Woo0P002goo00<007ooOol01Woo00<0
07ooOol02Goo00<007ooOol04Goo0P002goo00<007ooOol01Goo00<007ooOol02Goo0P004Woo0P00
2goo00<007ooOol00goo0@0000000`00Oomoo`07Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo
00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo
00eoo`05001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo
00<007ooOol03Woo00<007ooOol03Goo00D007ooOomoo`0000moo`03001oogoo00ioo`03001oogoo
00ioo`05001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo
00<007ooOol03Woo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01goo
0@0000000`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool100000003001oo`0000aoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oo`0000]oo`03
001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`8000aoo`03001oogoo
00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo
00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`8000aoo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00Aoo`03001oogoo00Uoo`8000aoo`03001oogoo00Aoo`03001oogoo
00]oo`03001oogoo00=oo`03001oogoo00Yoo`8000aoo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00Aoo`03001oogoo00Uoo`8000aoo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo
00=oo`03001oogoo00Yoo`40005oo`40000000<007ooOol01Woo00<007ooOol03goo00<007oo0000
4Woo00<007ooOol02goo00<007ooOol047oo00<007oo00004Goo00<007ooOol037oo00<007ooOol0
3goo00<007oo00004Woo00<007ooOol02goo00<007ooOol047oo0P004Woo00<007ooOol037oo00<0
07ooOol03goo00<007oo00004Woo00<007ooOol02goo00<007ooOol047oo0P004Woo00<007ooOol0
37oo00<007ooOol03goo00<007oo00004Woo00<007ooOol02goo00<007ooOol047oo0P004Woo00<0
07ooOol01Woo0@0000000`00Oomoo`04Ool00`00Oomoo`06Ool01@00Oomoogoo000047oo00@007oo
Ool000Qoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo000@Ool01000Oomoo`002Goo00<0
07ooOol027oo00<007ooOol01Woo00D007ooOomoo`00011oo`04001oogoo0008Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool01000Oomoo`0047oo00@007ooOol000Uoo`03001oogoo00Qoo`03001oogoo
00Ioo`05001oogooOol0000@Ool01000Oomoo`0027oo00<007ooOol027oo00<007ooOol01goo00@0
07ooOol0011oo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06Ool01000Oomoo`004Goo
00@007ooOol000Qoo`03001oogoo00Qoo`03001oogoo00Moo`04001oogoo000@Ool01000Oomoo`00
2Goo00<007ooOol017oo0@0000001@00Oomoogoo00004goo00<007ooOol01Goo00<007ooOol04Woo
00D007ooOomoo`0001Aoo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo009oo`03001oogoo
015oo`03001oogoo00Eoo`03001oogoo019oo`05001oogooOol0000DOol00`00Oomoo`05Ool00`00
Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0BOol01@00
Oomoogoo000057oo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Goo
00<007ooOol01Goo00<007ooOol04Woo00D007ooOomoo`0001Aoo`03001oogoo00Eoo`03001oogoo
015oo`04001oogooOol100000005001oogooOol00007Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20006Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20006Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool2
0006Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool20006Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`05Ool01000Oomoogoo0@0000000`00Oomoo`04
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool100000003001oogoo00Ioo`03001oogoo009oo`03001o
ogoo00Yoo`03001oo`0000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001o
ogoo00Yoo`03001oo`0000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00Yoo`03001oo`0000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00Yoo`03001oo`0000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oo`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo00Uoo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Oomoo`06Ool100000003001oo`0001=o
o`03001oogoo00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015o
o`80019oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001o
ogoo015oo`80019oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yo
o`03001oogoo015oo`80019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yo
o`03001oogoo015oo`40005oo`40000000<007ooOol01goo00D007ooOomoo`0000Moo`03001oogoo
00Uoo`03001oogoo00Ioo`05001oogooOol0000?Ool01@00Oomoogoo000027oo00<007ooOol02Goo
00<007ooOol01Goo00D007ooOomoo`00011oo`05001oogooOol00007Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool01@00Oomoogoo00003goo00D007ooOomoo`0000Qoo`03001oogoo00Uoo`03001oogoo
00Eoo`05001oogooOol0000@Ool01@00Oomoogoo00001goo00<007ooOol02Goo00<007ooOol01Woo
00D007ooOomoo`0000moo`05001oogooOol00008Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00
Oomoogoo000047oo00D007ooOomoo`0000Moo`03001oogoo00Uoo`03001oogoo00Ioo`05001oogoo
Ool0000?Ool01@00Oomoogoo000027oo00<007ooOol02Goo00<007ooOol01Goo00D007ooOomoo`00
00Uoo`40000000<007ooOol00goo00<007ooOol04Goo00D007ooOomoo`0001=oo`03001oogoo00Io
o`03001oogoo019oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00Oomoo`0AOol01@00Oomo
ogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001Aoo`03001oogoo00Ioo`03
001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00Oomoo`0BOol01000Oomoo`00
57oo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`0001=oo`03001oogoo00Ioo`03001o
ogoo019oo`04001oogoo000DOol00`00Oomoo`03Ool100000003001oogoo00ioo`03001oo`00019o
o`8001moo`80019oo`8001moo`03001oo`00019oo`8001moo`80019oo`8001moo`03001oo`00019o
o`8001moo`80019oo`8001moo`8001=oo`8001moo`80019oo`80015oo`40000000<007ooOol00Woo
00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo
00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo
00<007ooOol037oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol037oo
00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol02goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol00goo
00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00goo
00<007ooOol02goo00<007ooOol00goo00<007ooOol00Woo0@0000000`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomo
o`0COol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomo
o`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomo
o`07Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool00`00Oomoo`0:Ool100000004001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool0
1000Oomoo`004Goo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0011oo`03001oogoo00eo
o`03001oogoo00ioo`04001oogoo000AOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`00
47oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0015oo`03001oogoo00aoo`03001oogoo
00moo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`004Goo00<007oo
Ool037oo00<007ooOol03goo00<007ooOol00@0000000`00Oomoo`05Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`05Ool100000003001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo01Moo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001o
ogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001o
ogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Aoo`03001o
ogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo01Ioo`03001o
ogoo00Eoo`03001oogoo00Eoo`40000000@007ooOol0015oo`03001oo`0000Uoo`04001oogoo000A
Ool00`00Ool0000AOol01000Oomoo`002Goo00<007oo00004Goo00@007ooOol0011oo`04001oogoo
0009Ool01000Oomoo`004Goo00<007oo00004Goo00@007ooOol000Uoo`03001oo`00015oo`04001o
ogoo000@Ool01000Oomoo`002Goo00@007ooOol0015oo`03001oo`00015oo`04001oogoo0009Ool0
0`00Ool0000AOol01000Oomoo`0047oo00@007ooOol000Uoo`04001oogoo000@Ool01000Oomoo`00
4Goo00@007ooOol000Uoo`03001oo`00015oo`03001oogoo0040000000<007ooOol027oo00<007oo
00007Woo00<007oo00004Goo00<007oo00007Woo00<007oo00004Woo00<007oo00007Woo00<007oo
00004Goo00<007oo00007Woo00<007oo00004Woo00<007oo00007Woo00<007oo00004Goo00<007oo
00007Woo00<007oo00004Goo00@007ooOol001ioo`03001oo`00015oo`03001oo`0001ioo`03001o
o`0000Yoo`40000000<007ooOol00Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00goo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol02goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol02goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol00goo00<007ooOol017oo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol00Woo
0@0000000`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`03Ool100000003001oogoo00Moo`05
001oogooOol0000;Ool01@00Oomoogoo000037oo00D007ooOomoo`0000moo`05001oogooOol0000<
Ool01@00Oomoogoo00002goo00D007ooOomoo`00011oo`04001oogoo000<Ool01@00Oomoogoo0000
37oo00D007ooOomoo`0000moo`05001oogooOol0000<Ool01@00Oomoogoo00002goo00D007ooOomo
o`00011oo`04001oogoo000<Ool01@00Oomoogoo000037oo00D007ooOomoo`0000moo`05001oogoo
Ool0000<Ool01@00Oomoogoo00002goo00D007ooOomoo`00011oo`04001oogoo000<Ool01@00Oomo
ogoo000037oo00@007ooOol0011oo`05001oogooOol0000<Ool01@00Oomoogoo00002goo00D007oo
Oomoo`0000Uoo`40000000<007oo00004goo00<007ooOol02Goo00<007ooOol04Goo00<007oo0000
4goo00<007ooOol027oo00<007ooOol04Woo0P004goo00<007ooOol02Goo00<007ooOol04Goo0P00
57oo00<007ooOol027oo00<007ooOol04Woo0P004goo00<007ooOol02Goo00<007ooOol04Goo0P00
57oo00<007ooOol027oo00<007ooOol04Woo0P004goo00<007ooOol02Goo00<007ooOol04Goo0P00
57oo00<007ooOol027oo00<007ooOol04Woo0@000Goo0@0000000`00Oomoo`04Ool00`00Ool00005
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Ool00009Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool0000:Ool00`00Ool00005Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool2000:Ool00`00
Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Ool0000:Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool2000:Ool00`00Ool00005Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool20006Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool0000:Ool00`00
Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool2000:Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20005Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00006Ool100000003001oogoo00eoo`05001oogooOol0
000@Ool01000Oomoo`007Goo00@007ooOol0011oo`04001oogoo000MOol01000Oomoo`004Goo00@0
07ooOol001eoo`04001oogoo000@Ool01000Oomoo`007Goo00@007ooOol0015oo`04001oogoo000M
Ool01000Oomoo`0047oo00@007ooOol001eoo`04001oogoo000AOol01000Oomoo`007Goo00@007oo
Ool0011oo`04001oogoo000@Ool100000005001oogooOol0000COol00`00Oomoo`05Ool00`00Oomo
o`0BOol01@00Oomoogoo000057oo00<007ooOol01Goo00<007ooOol04Goo00<007ooOol00Woo00<0
07ooOol04Goo00<007ooOol01Goo00<007ooOol04Woo00D007ooOomoo`0001Aoo`03001oogoo00Eo
o`03001oogoo015oo`03001oogoo009oo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo019o
o`05001oogooOol0000DOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomo
o`0AOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomo
o`05Ool00`00Oomoo`0AOol01000Oomoogoo0@0000000`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol2000;Ool00`00Oomoo`05Ool00`00Oomoo`0:
Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool100000005001oogooOol0000>Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool0
0`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool00`00Oomoo`0=Ool01000Oomoogoo0@0000000`00Oomoo`04Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`04Ool100000003001oogoo00Ioo`03001oogoo00=oo`03001oogoo00Uoo`03001o
o`0000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`03001o
o`0000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03001o
o`0000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`03001o
o`0000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03001o
o`0000aoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo00Yoo`03001o
o`0000]oo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03001o
o`0000aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Yoo`03001o
o`0000]oo`03001oogoo00=oo`03001oogoo00Ioo`40000000<007oo00004Woo00<007ooOol02goo
00<007ooOol04Goo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo0P004Woo00<007oo
Ool02goo00<007ooOol047oo0P004goo00<007ooOol02Woo00<007ooOol04Goo0P004Woo00<007oo
Ool02goo00<007ooOol047oo0P004goo00<007ooOol02Woo00<007ooOol04Goo0P004Woo00<007oo
Ool02goo00<007ooOol047oo0P004goo00<007ooOol02Woo00<007ooOol04Goo0@000Goo0@000000
0`00Oomoo`07Ool01@00Oomoogoo00001goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomo
o`0000moo`05001oogooOol00008Ool00`00Oomoo`09Ool00`00Oomoo`05Ool01@00Oomoogoo0000
47oo00D007ooOomoo`0000Moo`03001oogoo00Uoo`03001oogoo00Ioo`05001oogooOol0000?Ool0
1@00Oomoogoo000027oo00<007ooOol02Goo00<007ooOol01Goo00D007ooOomoo`00011oo`05001o
ogooOol00007Ool00`00Oomoo`09Ool00`00Oomoo`06Ool01@00Oomoogoo00003goo00D007ooOomo
o`0000Qoo`03001oogoo00Uoo`03001oogoo00Eoo`05001oogooOol0000@Ool01@00Oomoogoo0000
1goo00<007ooOol02Goo00<007ooOol01Woo00D007ooOomoo`0000moo`05001oogooOol00008Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool01@00Oomoogoo00002Goo0@0000000`00Oomoo`03Ool00`00
Oomoo`0AOol01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00D007ooOomoo`00
01=oo`03001oogoo00Ioo`03001oogoo015oo`05001oogooOol0000COol00`00Oomoo`06Ool00`00
Oomoo`0BOol01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Goo00D007ooOomoo`00
01=oo`03001oogoo00Ioo`03001oogoo019oo`04001oogoo000DOol00`00Oomoo`06Ool00`00Oomo
o`0AOol01@00Oomoogoo00004goo00<007ooOol01Woo00<007ooOol04Woo00@007ooOol001Aoo`03
001oogoo00=oo`40000000<007ooOol00Woo00<007ooOol02Goo00<007oo00004Woo0P0037oo00<0
07ooOol00goo00<007ooOol02Woo0P004Woo0P0037oo00<007ooOol017oo00<007ooOol02Goo0P00
4goo0P0037oo00<007ooOol00goo00<007ooOol02Woo0P004Woo0P0037oo00<007ooOol017oo00<0
07ooOol02Goo0P004goo0P0037oo00<007ooOol00goo00<007ooOol02Woo0P004Woo0P0037oo00<0
07ooOol017oo00<007ooOol02Goo0P004goo0P002goo00<007ooOol017oo00<007ooOol02Woo0P00
4Woo0P0037oo00<007ooOol00Woo0@0000000`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`03
Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;
Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0?
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;
Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03
Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0<
Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`08
Ool100000004001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool01000Oomoo`002Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol027oo00<0
07ooOol01goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Ioo`04001oogoo0009Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01Woo00@007ooOol000Uoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Qo
o`03001oogoo00Moo`04001oogoo0008Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`06Ool01000Oomoo`002Goo00<007ooOol027oo00<007ooOol01Woo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol00@0000000`00Oomoo`0=Ool01@00Oomoogoo00003goo00<0
07ooOol00Woo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomoo`0001ao
o`05001oogooOol0000?Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomo
o`0<Ool00`00Oomoo`02Ool00`00Oomoo`0JOol01@00Oomoogoo00003goo00<007ooOol00Woo00<0
07ooOol06Goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol06Woo00D0
07ooOomoo`0000moo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo00eoo`40000000<007ooOol01Goo00<007ooOol04Goo00<007oo
Ool04Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007oo
Ool04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo00<007oo
Ool02Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007oo
Ool04Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007oo
Ool04Woo00<007ooOol04Goo00<007ooOol01Goo0@0000000`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0FOol0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool0
0`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0GOol0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool0
0`00Oomoo`05Ool100000004001oogoo000@Ool01000Oomoo`002Goo00@007ooOol0015oo`03001o
o`00015oo`04001oogoo0009Ool00`00Ool0000AOol01000Oomoo`0047oo00@007ooOol000Uoo`04
001oogoo000@Ool01000Oomoo`004Goo00@007ooOol000Uoo`03001oo`00015oo`04001oogoo000@
Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`002Goo00<007oo
00004Goo00@007ooOol0011oo`04001oogoo0009Ool01000Oomoo`0047oo00@007ooOol0015oo`04
001oogoo0008Ool01000Oomoo`004Goo00<007ooOol00@0000000`00Oomoo`08Ool00`00Ool0000N
Ool00`00Ool0000AOol00`00Ool0000NOol00`00Ool0000BOol00`00Ool0000NOol00`00Ool0000A
Ool00`00Ool0000NOol00`00Ool0000BOol00`00Ool0000NOol00`00Ool0000AOol00`00Ool0000N
Ool00`00Ool0000BOol00`00Ool0000NOol00`00Ool0000AOol00`00Ool0000NOol00`00Ool0000:
Ool100000003001oogoo009oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001o
ogoo00Aoo`03001oogoo019oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001o
ogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo019oo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001o
ogoo015oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001o
ogoo00Aoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001o
ogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo009oo`40000000<007ooOol00goo
00D007ooOomoo`0000Moo`03001oogoo00Eoo`05001oogooOol00007Ool20007Ool01@00Oomoogoo
00001goo00D007ooOomoo`0000Moo`8000Moo`05001oogooOol00006Ool20007Ool01@00Oomoogoo
000027oo00D007ooOomoo`0000Moo`03001oogoo00Eoo`05001oogooOol00007Ool20007Ool01@00
Oomoogoo00001goo00D007ooOomoo`0000Moo`8000Moo`05001oogooOol00006Ool20007Ool01@00
Oomoogoo000027oo00D007ooOomoo`0000Ioo`8000Moo`05001oogooOol00007Ool20007Ool01@00
Oomoogoo00001goo00D007ooOomoo`0000Moo`8000Moo`05001oogooOol00006Ool20007Ool01@00
Oomoogoo000027oo00D007ooOomoo`0000Ioo`8000Moo`05001oogooOol00007Ool20007Ool01@00
Oomoogoo00001goo00D007ooOomoo`0000Moo`8000Moo`05001oogooOol00006Ool20007Ool01@00
Oomoogoo00001Goo0@0000000`00Ool0000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomo
o`06Ool00`00Oomoo`08Ool2000;Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool0
0`00Oomoo`09Ool2000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomo
o`08Ool2000;Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool2
000;Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool2000;Ool0
0`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool2000:Ool00`00Oomo
o`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool2000;Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool10001Ool100000003001oogoo00aoo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo01Qoo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo00Aoo`03001oogoo01Moo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo00Aoo`03001oogoo00aoo`40000000<007ooOol017oo00<007oo00004Goo00<007oo0000
4Woo00<007oo00002Goo00<007oo00004Woo00<007oo00004Goo00<007oo00002Woo00<007oo0000
4Goo00<007oo00004Woo00<007oo00002Goo00<007oo00004Woo00<007oo00004Goo00<007oo0000
2Woo00<007oo00004Goo00<007oo00004Woo0P002Woo00<007oo00004Woo00<007oo00004Goo00<0
07oo00002Woo00<007oo00004Goo00<007oo00004Woo0P002Woo00<007oo00004Woo00<007oo0000
4Goo00<007oo00001Woo0@0000001@00Oomoogoo00002goo00@007ooOol0015oo`04001oogoo000<
Ool01@00Oomoogoo000037oo00@007ooOol0011oo`04001oogoo000<Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool01000Oomoo`004Goo00@007ooOol000]oo`03001oogoo009oo`03001oogoo00Yoo`04
001oogoo000@Ool01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol02Goo00@007ooOol0015o
o`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`0047oo00@007ooOol0
00aoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000AOol01000Oomoo`002goo00<007oo
Ool00Woo00<007ooOol02Woo00@007ooOol0011oo`04001oogoo000<Ool01000Oomoogoo0@000000
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol0
0`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool0
0`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool0
0`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool100000003001oogoo00Uoo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo
019oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo
00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo00Uoo`40000000D007ooOomoo`0000aoo`03001oo`00015oo`04001oogoo000;
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`0047oo00@007ooOol000aoo`03001oogoo
009oo`03001oogoo00Yoo`03001oo`00015oo`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool01000Oomoo`0047oo00@007ooOol000aoo`03001oogoo009oo`03001oogoo00Uoo`04001o
ogoo000AOol01000Oomoo`002goo00<007ooOol00Woo00<007ooOol02Woo00@007ooOol0011oo`04
001oogoo000<Ool00`00Oomoo`02Ool00`00Oomoo`09Ool01000Oomoo`004Goo00@007ooOol000]o
o`03001oogoo009oo`03001oogoo00Yoo`04001oogoo000@Ool01000Oomoo`0037oo00@007ooOomo
o`40000000<007ooOol017oo00<007ooOol04Goo00<007oo000057oo00<007ooOol01goo00<007oo
Ool04Woo00<007oo00004goo00<007ooOol027oo00<007ooOol04Goo00<007oo000057oo00<007oo
Ool01goo00<007ooOol04Woo00<007oo00004goo00<007ooOol027oo00<007ooOol04Goo00<007oo
000057oo00<007ooOol01goo00<007ooOol04Woo00<007oo00004goo00<007ooOol027oo00<007oo
Ool04Goo00<007oo000057oo00<007ooOol01goo00<007ooOol04Woo00<007oo00004goo00<007oo
Ool017oo0@0000000`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool0
0`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0<Ool0
0`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool0
0`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
0`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool0
0`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`03Ool00`00Oomoo`0;Ool0
0`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`06Ool100000003001oo`00
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`80
019oo`03001oogoo00]oo`03001oogoo011oo`8001=oo`03001oogoo00Yoo`03001oogoo015oo`40
005oo`40000000<007ooOol02goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<0
07ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<0
07ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<0
07ooOol027oo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<0
07ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02goo0@0000000`00Oomoo`07
Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00D007oo
Oomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000@Ool00`00Oomoo`0=
Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<007ooOol03Goo00D007oo
Oomoo`00011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`0>
Ool00`00Oomoo`0=Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00D007oo
Oomoo`0000moo`03001oogoo00Moo`40000000<007ooOol00goo00<007ooOol027oo0P004goo0P00
2goo00<007ooOol01Goo00<007ooOol02Goo0P004Woo0P002goo00<007ooOol01Woo00<007ooOol0
27oo0P004goo0P002goo00<007ooOol01Goo00<007ooOol02Goo0P004Woo0P002goo00<007ooOol0
1Woo00<007ooOol027oo0P004goo0P002Woo00<007ooOol01Woo00<007ooOol02Goo0P004Woo0P00
2goo00<007ooOol01Woo00<007ooOol027oo0P004goo0P002Woo00<007ooOol01Woo00<007ooOol0
2Goo0P004Woo0P002goo00<007ooOol00goo0@0000000`00Oomoo`02Ool00`00Oomoo`0AOol00`00
Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00
Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0BOol00`00
Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00
Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00
Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00
Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00
Oomoo`02Ool100000004001oogoo0007Ool00`00Ool00009Ool00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Ool00006Ool01000Oomoo`001goo00<007oo00002Woo00<007ooOol01goo00<007ooOol0
1goo00<007oo00001goo00@007ooOol000Moo`03001oo`0000Uoo`03001oogoo00Moo`03001oogoo
00Qoo`03001oo`0000Ioo`04001oogoo0007Ool00`00Ool0000:Ool00`00Oomoo`07Ool00`00Oomo
o`07Ool00`00Ool00007Ool01000Oomoo`001goo00<007oo00002Goo00<007ooOol01goo00<007oo
Ool027oo00<007oo00001Woo00@007ooOol000Moo`03001oo`0000Yoo`03001oogoo00Ioo`03001o
ogoo00Qoo`03001oo`0000Moo`04001oogoo0007Ool00`00Ool00009Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Ool00006Ool01000Oomoo`001goo00<007oo00002Woo00<007ooOol01Woo00<0
07ooOol027oo00<007oo00001goo00<007ooOol00@0000000`00Oomoo`05Ool00`00Oomoo`05Ool0
1@00Oomoogoo00001goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
0Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Yoo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Eoo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Eoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo
[Goo0@00003o002a00000001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 431}, {265.875, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000000P0200000000000000000l;4=JL8NN
]LcSf/>]UWmXDCXS7SA;HWV@YkkEj=6kY8efGdPa6RHmE6^2VK37gN39/Y^4KEHo
:1P_AUedRj:icnOG`:VBNfA>=b0Q>4mVOIBZ`MSVc[NPRG=LABhG:T5HKXFL/l[Q
g<F_V85ZDc`U6c99H7N>YKcCjMBmYXmhHDXc72@kDVV0Ujk5g>;;]9f6KeQ1:QH]
A5]bRJ2fcNGI`Z^DOFM@>B8O=TeTNY6X_mKXd;VSS7ENAc0I9cmEK8>J/LSOg/Ra
VX=/EChW6C17GWF<Xk[Aj=JoZ95jHd`e7b8iD6MnUJc2f^C=]Yn8LEY3;AH[@UU`
Qijdbn;Ka:fFOfUB>b@M=4]QN8nV_MCYd[bUSWMPBC8K9CeCJX6H[lKMh<ZcW8E^
Ed0Y5bi5G7>:XKS?i]S1ZY=lIDhg8B0gCVElTj[0f>K?^:6:Lea6;aLY@5M^QI^b
bN3MaZnHPV]D?BHJ<TUOMXfT^m;YeKjWT7URBc@M8cYAJ7nF[LCKhlbeWXM`FD8[
5Ra3FW68WkK=i=[3[9EnIe0j8aheC6=jTJNneNSA^Z><MUm8<ATW?UE[PYV`amkO
b;6KQ6eF?bPH<4IMM8^R^M3Wel2YTW]TCCHO8SQ?IWfDZl;IiLjgX8UbFd@^5bY1
F6n6WKC;hMc5[YN0JE8l9A`cBV5hSjFldnWC_:F?N65:<a`U?59YP9N^aMcQbkBM
QVmH@BXG;TAKLXVP]lkUfL:[U7eVCcPR7cI=I7^BZL3Gim2iXX]dGDH`62PoEVf4
Vk78gmk7/9V2JeDn9aTaB5mfS:>jdNSE_ZNANV=<=AhS>U1WOYF/`m[TcKJOR75J
@b`F:d9IL8NN]LcSflB]UWmXDCXS7CA;HWV@YkkEjM:kY8efGdTb6RHmE6^2V:o6
gN39/Y^5KUM0:AL_AUacRZ6hcnKH`:ZCO6E>=b0Q=diUO9>Z`MSVckRQRW=LABhG
:D1GKXFL/l[PgLJ_V85ZDcdU6c99H7N>YKcBjMBmYXmhHD/d7B@kDVUoUZg4fn;;
]9j7L5U2:aH]@eYaR9nfcNCJ`ZbEOVM@>B8O=DaSNY6X_mKXdKZSS7ENAc0I9ciE
K8>J/LSNglRaVX=/EClW6C17GWF<XkW@j=JoZ95jI4df7b8iD6MmU:_2fNG=]Z29
LU]4;AHZ@EQ_QYfdbn;LaJjGP6UB>b@L<dYQN8nV_MCYdkbUSWMPBC8K9CaCJX6H
[lGLhLZcW8E^F44Z5bi5G7>9X;O>i]S1ZYAmITlh8B0gCVAkTZW0enO?^J:;M5e6
;aPX?eI]Q9^bbN3Mak2IPV]D?BHJ<DQOMXfT^m7XeKjWT7URBc@N8cYAJ7nF[L?J
hlbeWXM`FT</5Ra3FW27W[G<hm[3[IIoJ54j8ahdBf9iT:NneNSA^jB=MUm8<AXV
?EA[PYV`amgPbK:KQ6eF?bPH;dIMM8^R^LoWel2YTW]TCSLP8CQ?IWfDZ/7Hi/jg
X8UcG4D^5bY1F6j5W;?:hMc5[iR1JU<l9A/bBF1gSZFldnWD_JJ?N65:<a`T>e9Y
P9N^aMcRbkBMQVmH@BXF;DAKLXVP]/gUfL:[U7eWD3TR7cI=I7ZAZ;oFj=2iXhae
GTL`6BLoEFb3V[78gmk8/IZ3K5Dn9aT`AeieS:>jdNSF_jRANV=<=AlR>E1WOYF/
`][TcKJOR75J@bdF:d9IL8NN]<_RflB]UX1YDS/T7CA;HGR?Y[gDjM:lYHigH4Tb
6bDmDfZ1V:o6gN3:/ib5KUM0:AL^AEacRZ6hcnKH`JZCO6E>=b4P=diUO9>Z`=SV
ckRQRW=LARlG:D1GKXFK//WPgLJ_V89[E3dV6S99GgJ=Y;_BjMFnYi1iHT/d7B<j
DFQoUZg4fn?<]Ij7L5U2:aH/@eYaR9nfcNCJ`jbEOVM@>R<N=DaSNY6W_]GXdKZS
S7IOB34I9ciEJh:I/<ONglRaVhA]ESlX6316GGB;X[W@imO0ZI9kI4df7b8hCfIm
U:_2fNG>]j29LU]4;QLZ@EQ_QYfdbn7LaJjGP6UB?2DL<dYQN8nU_=?YdkbUSgQQ
BS<L9CaBJH2G[/GLhL^dWHI_F44Z5bi4Fg:9X;O>iMW2ZiAmITlh8QlfCFAkTZW0
enO@^J:;M5e6<1PX?eI]Q9^ab=oNak2IPV]E?RLI<DQOMXbS^]7XeKjWTGYSC3DN
8cY@IgjE[<?Ji<ffWhQaFT</5R]2FG27W[G<hm_4[IIoJ54j8addBf9iT:NneNWB
^jB=MUm9<QXV?EA[PYR_a]gPbK:KQFiG@2TG;dILLhZQ^<oVf<2ZTgaUCSLP8CM>
IGbCZ/7Hi/nhXHYcG4D^5bU0Efj5W;?:h=g6[iR1JU<m9A/bBF1gSZFld^WD_JJ?
N65;=1dT>e9YP9J]a=_RbkBNQg1I@R/F;D=JLHRO]/gTf/:/UGiWD3TR7cE<HgZA
Z;oFj=6jXhaeGTL`6BLnEFb3V[78g]o8/IZ3K5Do9aT`AeieS:>id>SF_jRANVA=
=QlR>E1WOIB[`]WUcKJPRG9KA2dF:T5HKhJM]<_Rg<F^Uh1YDS/T73=:HGR?Y[gD
jM>lYHigH4Tb6bDlDfZ1V:o5g>7:/ib5KUQ1:QL^AEacRJ2gc^KH`JZDOFI?>24P
=diTNi:Y`=OWckVRRgAMARlH:3mFKHBK//WPgLN`VH9[E3dV6S58GgJ=Y;_Aj=Fn
Yi1iHT/d7R<jDFQoUZg3f^?<]Ij7L5Y3;1H/@eY`Qijec>?J`jfFOfQA>R<N=4]R
NI2W_]GXdK^TSGIOB34J9SeDJh:I/<OMh<VbVhA]ESlX62m6GGB;X[W?imO0ZI9k
I4hg824hCfImU:[1f>K>]j29Lea5;QLZ@EQ^QIbcb^7LaJnHPFYC?2DK<TUPMhjU
_=?Ye;fVSgQQBS<L93]BJH2G[/GLh/^dWHI_F44Z5Re4Fg:9X;K=iMW2ZiAmIe0i
8QlfCFAjTJRoe^S@^J><MEi7<1TW?eE/PiZab=oNb;6JPfaE?RLI<4MNMHbS^]7X
e[nXTGYSC3DO8SU@IgjE[<;Ji<ffWhQaFT<]5R]2FG27W[C;h]_4[IJ0JE8k91dd
Bf5hSjJme>WB_:F>Mf19<Q/U?E=ZPIR_a]gPb[>LQFiG@2TG;TELLhZQ^<oVf<6Z
TgaUCSLQ83M>IGbCZ/3Hi/nhXHYcG4H_5bU0Efj5Vk;9h=g6[iR2Je@m9QXbBEmf
SJBkd^WE_ZN@NF9;=1dS>U5XOiJ]a=_Sc;FNQg1I@R/F;4=JLHRO]/gTf/>/UGiW
D3XS7SE<HgZAYkkEj=6jXhafGdPa6BLnEF^2VK37g]o8/I^4KEHo:1P`AUedRj:i
d>OG`:VBNfA==QlR>4mVOIB[`]WUc[NPRG9KA2hG:T5HKhJM]<_Qg<F^Uh1YDS`U
73=:HGR?YKcCjM>lYHmhHDXc72DlDVV0Ujk5g>7;]9f6KeQ1:QL^A5]bRJ2gc^GI
`Z^DOFI?>28O=TeTNi:Y`=OWd;VRRgAMAS0H:3mFKHBK/LSOg/N`VH9[EChW6C58
GgJ<Xk[Aj=FnYi5jHd`e7R<jD6MnUJc3f^C=]Yn8LEY3;1H[@UU`Qijec>?Ka:fF
OfQA>R<M=4]RNI2W_]GYd[^TSGIOBC8J9SeDJh:H[lKMh<VbVhE^Ed0Y5bm6G7>:
XKS?i]S0ZY=lIDhg824gCVElTj[1f>K?^:6:Lea5;QLY@5M^QIbcb^3MaZnHPFYC
?BDK<TUPMhjU_=;Ye;fVSgQQBc@M93]BJGnF[LCKh/^dWXM`FD8[5Re3FW68WkK=
i=[2[9EnIe0i8QleC6=jTJRoe^SA^Z><MEi7<1TW?UE/PiZab=kOb;6JPfaE?bLI
<4MNMHbS^M3Xe[nXTGYTCCHO8SU@IgfDZl;IiLffX8UbFd@]5RY1F6n6WKC;h]c5
[YN0JE8k91`cBV5hSjJme>WC_:F>Mf19<Q/U?5=ZPIR_aMcQb[>LQFiH@BXG;TEL
LhVP]lkVf<6ZU7eVCcPQ83M>I7^BZL3GilniXX]dGDH_62PoEVf4Vk;9h=g7/9V2
Je@m9QXaB5mfSJBkdNSE_ZN@NF9;=1hS>U5XOiJ]`m[Sc;FNQg1J@b`F;4=JL8NN
]LcSf/>]UWmXDCXS7SA;HWV@YkkEj=6kY8efGdPa6RHmE6^2VK37gN39/Y^4KEHo
:1P_AUedRj:icnOG`:VBNfA>=b0Q>4mVOIBZ`MSVc[NPRG=LABhG:T5HKXFL/l[Q
g<F_V85ZDc`U6c99H7N>YKcCjMBmYXmhHDXc72@kDVV0Ujk5g>;;]9f6KeQ1:QH]
A5]bRJ2fcNGI`Z^DOFM@>B8O=TeTNY6X_mKXd;VSS7ENAc0I9cmEK8>J/LSOg/Ra
VX=/EChW6C17GWF<Xk[Aj=JoZ95jHd`e7b8iD6MnUJc2f^C=]Yn8LEY3;AH[@UU`
Qijdbn;Ka:fFOfUB>b@M=4]QN8nV_MCYd[bUSWMPBC8K9CeCJX6H[lKMh<ZcW8E^
Ed0Y5bi5G7>:XKS?i]S1ZY=lIDhg8B0gCVElTj[0f>K?^:6:Lea6;aLY@5M^QI^b
bN3MaZnHPV]D?BHJ<TUOMXfT^m;YeKjWT7URBc@M8cYAJ7nF[LCKhlbeWXM`FD8[
5Ra3FW68WkK=i=[3[9EnIe0j8aheC6=jTJNneNSA^Z><MUm8<ATW?UE[PYV`amkO
b;6KQ6eF?bPH<4IMM8^R^M3Wel2YTW]TCCHO8SQ?IWfDZl;IiLjgX8UbFd@^5bY1
F6n6WKC;hMc5[YN0JE8l9A`cBV5hSjFldnWC_:F?N65:<a`U?59YP9N^aMcQbkBM
QVmH@BXG;TAKLXVP]lkUfL:[U7eVCcPR7cI=I7^BZL3Gim2iXX]dGDH`62PoEVf4
Vk78gmk7/9V2JeDn9aTaB5mfS:>jdNSE_ZNANV=<=AhS>U1WOYF/`m[TcKJOR75J
@b`F:d9IL8NN]LcSflB]UWmXDCXS7CA;HWV@YkkEjM:kY8efGdTb6RHmE6^2V:o6
gN39/Y^5KUM0:AL_AUacRZ6hcnKH`:ZCO6E>=b0Q=diUO9>Z`MSVckRQRW=LABhG
:D1GKXFL/l[PgLJ_V85ZDcdU6c99H7N>YKcBjMBmYXmhHD/d7B@kDVV0UZg4fn;;
]9j7L5U2:aH]@eYaR9nfcNCJ`ZbEOVM@>B8O=DaSNY6X_mKXdKZSS7ENAc0I9ciE
K8>J/LSNglRaVX=/EClW6C17GWF<XkW@j=JoZ95jI4df7b8iD6MmU:_2fNG=]Z29
LU]4;AHZ@EQ_QYfdbn;LaJjGP6UB>b@L<dYQN8nV_MCYdkbUSWMPBC8K9CaCJX6H
[lGLhLZcW8E^F44Z5bi5G7>9X;O>i]S1ZYAmITlh8B0gCVAkTZW0enO?^J:;M5e6
;aPX?eI]Q9^bbN3Mak2IPV]D?BHJ<DQOMXfT^m7XeKjWT7URBc@N8cYAJ7nF[L?J
hlbeWXM`FT</5Ra3FW27W[G<hm[3[IIoJ54j8ahdBf9iT:NneNSA^jB=MUm8<AXV
?EA[PYV`amgPbK:KQ6eF?bPH;dIMM8^R^LoWel2YTW]TCSLP8CQ?IWfDZ/7Hi/jg
X8UcG4D^5bY1F6j5W;?:hMc5[iR1JU<l9A/bBF1gSZFldnWD_JJ?N65:<a`T>e9Y
P9N^aMcRbkBMQVmH@BXF;DAKLXVP]/gUfL:[U7eWD3TR7cI=I7ZAZ;oFj=2iXhae
GTL`6BLoEFb3V[78gmk8/IZ3K5Dn9aT`AeieS:>jdNSF_jRANV=<=AlR>E1WOYF/
`][TcKJOR75J@bdF:d9IL8NN]<_RflB]UWmYDS/T7CA;HGR?Y[gDjM:lYHigH4Tb
6bDmDfZ1V:o6gN3:/ib5KUM0:AL^AEacRZ6hcnKH`JZCO6E>=b4P=diUO9>Z`=SV
ckRQRW=LARlG:D1GKXFK//WPgLJ_V89[E3dV6S99GgJ=Y;_BjMFnYi1iHT/d7B<j
DFQoUZg4fn?<]Ij7L5U2:aH/@eYaR9nfcNCJ`jbEOVM@>R<N=DaSNY6W_]GXdKZS
S7IOB34I9ciEJh:I/<ONglRaVhA]ESlX6316GGB;X[W@imO0ZI9kI4df7b8hCfIm
U:_2fNG>]j29LU]4;QLZ@EQ_QYfdbn7LaJjGP6UB?2DL<dYQN8nU_=?YdkbUSgQQ
BS<L9CaBJH2G[/GLhL^dWHI_F44Z5bi4Fg:9X;O>iMW2ZiAmITlh8QlfCFAkTZW0
enO@^J:;M5e6<1PX?eI]Q9^ab=oNak2IPV]E?RLI<DQOMXbS^]7XeKjWTGYSC3DN
8cY@IgjE[<?Ji<ffWhQaFT</5R]2FG27W[G<hm_4[IIoJ54j8addBf9iT:NneNWB
^jB=MUm9<QXV?EA[PYR_a]gPbK:KQFiG@2TG;dILLhZQ^<oVf<2ZTgaUCSLP8CM>
IGbCZ/7Hi/nhXHYcG4D^5bU0Efj5W;?:h=g6[iR1JU<m9A/bBF1gSZFld^WD_JJ?
N65;=1dT>e9YOiJ]a=_RbkBNQg1I@R/F;D=JLHRO]/gTf/:/UGiWD3TR7cE<HgZA
Z;oFj=6jXhaeGTL`6BLnEFb3V[78g]o8/IZ3K5Do9aT`AeieS:>id>SF_jRANVA=
=QlR>E1WOIB[`]WUcKJPRG9KA2dF:T5HKhJM]<_Rg<F^Uh1YDS/T73=:HGR?Y[gD
jM>lYHigH4Tb6bDlDfZ1V:o5g>7:/ib5KUQ1:QL^AEacRJ2gc^KH`JZDOFI?>24P
=diTNi:Y`=OWckVRRgAMARlH:3mFKHBK//WPgLN`VH9[E3dV6S58GgJ=Y;_Aj=Fn
Yi1iHT/d7R<jDFQoUZg3f^?<]Ij7L5Y3;1H/@eY`Qijec>?J`jfFOfQA>R<N=4]R
NI2W_]GXdK^TSGIOB34J9SeDJh:I/<OMh<VbVhA]ESlX62m6GGB;X[W?imO0ZI9k
I4hg824hCfImU:[1f>K>]j29Lea5;QLZ@EQ^QIbcb^7LaJnHPFYC?2DK<TUPMhjU
_=?Ye;fVSgQQBS<L93]BJH2G[/GLh/^dWHI_F44Z5Re4Fg:9X;K=iMW2ZiAmIe0i
8QlfCFAjTJRoe^S@^J><MEi7<1TW?eE/PiZab=oNb;6JPfaE?RLI<4MNMHbS^]7X
e[nXTGYSC3DO8SU@IgjE[<;Ji<ffWhQaFT<]5R]2FG27W[C;h]_4[IJ0JE8k91dd
Bf5hSjJme>WB_:F>Mf19<Q/U?E=ZPIR_a]gPb[>LQFiG@2TG;TELLhZQ^<oVf<6Z
TgaUCSLQ83M>IGbCZ/3Hi/nhXHYcG4H_5bU0Efj5Vk;9h=g6[iR2Je@m9QXbBEmf
SJBkd^WE_ZN@NF9;=1dS>U5XOiJ]a=_Sc;FNQg1I@R/F;4=JLHRO]/gTf/>/UGiW
D3XS7SE<HgZAYkkEj=6jXhafGdPa6BLnEF^2VK37g]o8/I^4KEHo:1P`AUedRj:i
d>OG`:VBNfA==QlR>4mVOIB[`]WUc[NPRG9KA2hG:T5HKhJM]<_Qg<F^Uh1YDS`U
73=:HGR?YKcCjM>lYHmhHDXc72DlDVV0Ujk5g>7;]9f6KeQ1:QL^A5]bRJ2gc^GI
`Z^DOFI?>28O=TeTNi:Y`=OWd;VRRgAMAS0H:3mFKHBK/LSOg/N`VH9[EChW6C58
GgJ<Xk[Aj=FnYi5jHd`e7R<jD6MnUJc3f^C=]Yn8LEY3;1H[@UU`Qijec>?Ka:fF
OfQA>R<M=4]RNI2W_]GYd[^TSGIOBC8J9SeDJh:H[lKMh<VbVhE^Ed0Y5bm6G7>:
XKS?i]S0ZY=lIDhg824gCVElTj[1f>K?^:6:Lea5;QLY@5M^QIbcb^3MaZnHPFYC
?BDK<TUPMhjU_=;Ye;fVSgQQBc@M93]BJGnF[LCKh/^dWXM`FD8[5Re3FW68WkK=
i=[2[9EnIe0i8QleC6=jTJRoe^SA^Z><MEi7<1TW?UE/PiZab=kOb;6JPfaE?bLI
<4MNMHbS^M3Xe[nXTGYTCCHO8SU@IgfDZl;IiLffX8UbFd@]5RY1F6n6WKC;h]c5
[YN0JE8k91`cBV5hSjJme>WC_:F>Mf19<Q/U?5=ZPIR_aMcQb[>LQFiH@BXG;TEL
LhVP]lkVf<6ZU7eVCcPQ83M>I7^BZL3GilniXX]dGDH_62PoEVf4Vk;9h=g7/9V2
Je@m9QXaB5mfSJBkdNSE_ZN@NF9;=1hS>U5XOiJ]`m[Sc;FNQg1J@b`F;4=JL8NN
]LcSf/>]UWmXDCXS7SA;HWV@YkkEj=6kY8efGdPa6RHmE6^2VK37gN39/Y^4KEHo
:1P_AUedRj:icnOG`:VBNfA>=b0Q>4mVOIBZ`MSVc[NPRG=LABhG:T5HKXFL/l[Q
g<F_V85ZDc`U6c99H7N>YKcCjMBmYXmhHDXc72@kDVV0Ujk5g>;;]9f6KeQ1:QH]
A5]bRJ2fcNGI`Z^DOFM@>B8O=TeTNY6X_mKXd;VSS7ENAc0I9cmEK8>J/LSOg/Ra
VX=/EChW6C17GWF<Xk[Aj=JoZ95jHd`e7b8iD6MnUJc2f^C=]Yn8LEY3;AH[@UU`
Qijdbn;Ka:fFP6UB>b@M=4]QN8nV_MCYd[bUSWMPBC8K9CeCJX6H[lKMh<ZcW8E^
Ed0Y5bi5G7>:XKS?i]S1ZY=lIDhg8B0gCVElTj[0f>K?^:6:Lea6;aLY@5M^QI^b
bN3MaZnHPV]D?BHJ<TUOMXfT^m;YeKjWT7URBc@M8cYAJ7nF[LCKhlbeWXM`FD8[
5Ra3FW68WkK=i=[3[9EnIe0j8aheC6=jTJNneNSA^Z><MUm8<ATW?UE[PYV`amkO
b;6KQ6eF?bPH<4IMM8^R^M3Wel2YTW]TCCHO8SQ?IWfDZl;IiLjgX8UbFd@^5bY1
F6n6WKC;hMc5[YN0JE8l9A`cBV5hSjFldnWC_:F?N65:<a`U?59YP9N^aMcQbkBM
QVmH@BXG;TAKLXVP]lkUfL:[U7eVCcPR7cI=I7^BZL3Gim2iXX]dGDH`62PoEVf4
Vk78gmk7/9V2JeDn9aTaB5mfS:>jdNSE_ZNANV=<=AhS>U1WOYF/`m[TcKJOR75J
@b`F:d9IL8NN]LcSflB]UWmXDCXS7CA;HWV@YkkEjM:kY8efGdTb6RHmE6^2V:o6
gN39/Y^5KUM0:AL_AUacRZ6hcnKH`:ZCO6E>=b0Q=diUO9>Z`MSVckRQRW=LABhG
:D1GKXFL/l[PgLJ_V85ZDcdU6c99H7N>YKcBjMBmYXmhHD/d7B@kDVV0UZg4fn;;
]9j7L5U2:aH]@eYaR9nfcNCJ`ZbEOVM@>B8O=DaSNY6X_mKXdKZSS7ENAc0I9ciE
K8>J/LSNglRaVX=/EClW6C17GWF<XkW@j=JoZ95jI4df7b8iD6MmU:_2fNG=]Z29
LU]4;AHZ@EQ_QYfdbn;LaJjGP6UB>b@L<dYQN8nV_MCYdkbUSWMPBC8K9CaCJX6H
[lGLhLZcW8E^F44Z5bi5G7>9X;O>i]S1ZYAmITlh8B0gCVAkTZW0enO?^J:;M5e6
;aPX?eI]Q9^bbN3Mak2IPV]D?BHJ<DQOMXfT^m7XeKjWT7URBc@N8cYAJ7nF[L?J
hlbeWXM`FT</5Ra3FW27W[G<hm[3[IIoJ54j8ahdBf9iT:NneNSA^jB=MUm8<AXV
?EA[PYV`amgPbK:KQ6eF?bPH;dIMM8^R^LoWel2YTW]TCSLP8CQ?IWfDZ/7Hi/jg
X8UcG4D^5bY1F6j5W;?:hMc5[iR1JU<l9A/bBF1gSZFldnWD_JJ?N65:<a`T>e9Y
P9N^aMcRbkBMQVmH@BXF;DAKLXVP]/gUfL:[U7eWD3TR7cI=I7ZAZ;oFj=2iXhae
GTL`6BLoEFb3V[78gmk8/IZ3K5Dn9aT`AeieS:>jdNSF_jRANV=<=AlR>E1WOYF/
`][TcKJOR75J@bdF:d9IL8NN]<_RflB]UWmYDS/T7CA;HGR?Y[gDjM:lYHigH4Tb
6bDmDfZ1V:o6gN3:/ib5KUM0:AL^AEacRZ6hcnKH`JZCO6E>=b4P=diUO9>Z`=SV
ckRQRW=LARlG:D1GKXFK//WPgLJ_V89[E3dV6S99GgJ=Y;_BjMFnYi1iHT/d7B<j
DFQoUZg4fn?<]Ij7L5U2:aH/@eYaR9nfcNCJ`jbEOVM@>R<N=DaSNY6W_]GXdKZS
S7IOB34I9ciEJh:I/<ONglRaVhA]ESlX6316GGB;X[W@imO0ZI9kI4df7b8hCfIm
U:_2fNG>]j29LU]4;QLZ@EQ_QYfdbn7LaJjGP6UB?2DL<dYQN8nU_=?YdkbUSgQQ
BS<L9CaBJH2G[/GLhL^dWHI_F44Z5bi4Fg:9X;O>iMW2ZiAmITlh8QlfCFAkTZW0
enO@^J:;M5e6<1PX?eI]Q9^ab=oNak2IPV]E?RLI<DQOMXbS^]7XeKjWTGYSC3DN
8cY@IgjE[<?Ji<ffWhQaFT</5R]2FG27W[G<hm_4[IIoJ54j8addBf9iT:NneNWB
^jB=MUm9<QXV?EA[PYR_a]gPbK:KQFiG@2TG;dILLhZQ^<oVf<2ZTgaUCSLP8CM>
IGbCZ/7Hi/nhXHYcG4D^5bU0Efj5W;?:h=g6[iR1JU<m9A/bBF1gSZFld^WD_JJ?
N65;=1dT>e9YP9J]a=_RbkBNQg1I@R/F;D=JLHRO]/gTf/:/UGiWD3TR7cE<HgZA
Z;oFj=6jXhaeGTL`6BLnEFb3V[78g]o8/IZ3K5Do9aT`AeieS:>id>SF_jRANVA=
=QlR>E1WOIB[`]WUcKJPRG9KA2dF:T5HKhJM]<_Rg<F^Uh1YDS/T73=:HGR?Y[gD
jM>lYHigH4Tb6bDlDfZ1V:o5g>7:/ib5KUQ1:QL^AEacRJ2gc^KH`JZDOFI?>24P
=diTNi:Y`=OWckVRRgAMARlH:3mFKHBK//WPgLN`VH9[E3dV6S58GgJ=Y;_Aj=Fn
Yi1iHT/d7R<jDFQoUZg3f^?<]Ij7L5Y3;1H\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here we have used the Fourier series for a triangle wave, with \
coefficients as listed in Eq. ",
  ButtonBox["(2.1.11)",
    ButtonData:>"(2.1.11)",
    ButtonStyle->"Hyperlink"],
  ", keeping 30 coefficients, and neglecting the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["n",
            "TraditionalForm"], "=", "0"}], TraditionalForm]]],
  " term (since it merely produces a constant offset, of no importance to the \
sound).We have also added an option ",
  StyleBox["PlayRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is analogous to ",
  StyleBox["PlotRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for a plot,  setting the range of amplitude levels to be included; it can \
be used to adjust the volume of the sound."
}], "Text"],

Cell["\<\
\tThe harsh buzzing sound of the triangle wave compared to a pure \
sine wave is caused by the high harmonics of the fundamental middle A tone \
that are kept in this series.  \
\>", "Text"],

Cell[TextData[{
  "\tLet's now consider the following question: what happens to the sound of \
the triangle wave if we randomize the phases of the different Fourier modes \
with respect to one another? That is, let's replace ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ n\ t/T)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`cos[2\ \[Pi]\ \((n\ t/T + \[Phi]\_n)\)]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_n\)]],
  " is a random number between 0 and 2\[Pi]. The resulting series can be \
written in terms of a sine and cosine series by using the trigonometric \
identity "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`cos {2\ \[Pi]\ \((n\ t/T + \[Phi]\_n)\)} = 
        cos\ \(\[Phi]\_n\) cos[2\ \[Pi]\ n\ t/T] - 
          sin\ \(\[Phi]\_n\) sin[2\ \[Pi]\ n\ t/T]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tIf we plot the series, it certainly no-longer looks like a triangle \
wave, although it remains periodic with period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", as shown in Cell ",
  ButtonBox["2.27",
    ButtonData:>"Cell 2.27",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(T = 1/440; \ 
    a[n_]\  = \ \(-4\)/\((n^2\ Pi^2)\);\[IndentingNewLine]\), "\n", 
    \(\(\(f\_approx[t_, 30]\  = \ 
        Sum[a[n]\ Cos[2\ Pi\ \((n\ t/T\  + \ Random[])\)], {n, 1, 30, 
            2}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Plot[f\_approx[t, 30], {t, 0, 3  T}]\ ;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.27"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 139.683 0.309015 0.790673 [
[.16349 .29652 -15 -9 ]
[.16349 .29652 15 0 ]
[.30317 .29652 -15 -9 ]
[.30317 .29652 15 0 ]
[.44286 .29652 -15 -9 ]
[.44286 .29652 15 0 ]
[.58254 .29652 -15 -9 ]
[.58254 .29652 15 0 ]
[.72222 .29652 -15 -9 ]
[.72222 .29652 15 0 ]
[.8619 .29652 -15 -9 ]
[.8619 .29652 15 0 ]
[.01131 .07181 -24 -4.5 ]
[.01131 .07181 0 4.5 ]
[.01131 .15088 -24 -4.5 ]
[.01131 .15088 0 4.5 ]
[.01131 .22995 -24 -4.5 ]
[.01131 .22995 0 4.5 ]
[.01131 .38808 -18 -4.5 ]
[.01131 .38808 0 4.5 ]
[.01131 .46715 -18 -4.5 ]
[.01131 .46715 0 4.5 ]
[.01131 .54622 -18 -4.5 ]
[.01131 .54622 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16349 .30902 m
.16349 .31527 L
s
[(0.001)] .16349 .29652 0 1 Mshowa
.30317 .30902 m
.30317 .31527 L
s
[(0.002)] .30317 .29652 0 1 Mshowa
.44286 .30902 m
.44286 .31527 L
s
[(0.003)] .44286 .29652 0 1 Mshowa
.58254 .30902 m
.58254 .31527 L
s
[(0.004)] .58254 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(0.005)] .72222 .29652 0 1 Mshowa
.8619 .30902 m
.8619 .31527 L
s
[(0.006)] .8619 .29652 0 1 Mshowa
.125 Mabswid
.05175 .30902 m
.05175 .31277 L
s
.07968 .30902 m
.07968 .31277 L
s
.10762 .30902 m
.10762 .31277 L
s
.13556 .30902 m
.13556 .31277 L
s
.19143 .30902 m
.19143 .31277 L
s
.21937 .30902 m
.21937 .31277 L
s
.2473 .30902 m
.2473 .31277 L
s
.27524 .30902 m
.27524 .31277 L
s
.33111 .30902 m
.33111 .31277 L
s
.35905 .30902 m
.35905 .31277 L
s
.38698 .30902 m
.38698 .31277 L
s
.41492 .30902 m
.41492 .31277 L
s
.47079 .30902 m
.47079 .31277 L
s
.49873 .30902 m
.49873 .31277 L
s
.52667 .30902 m
.52667 .31277 L
s
.5546 .30902 m
.5546 .31277 L
s
.61048 .30902 m
.61048 .31277 L
s
.63841 .30902 m
.63841 .31277 L
s
.66635 .30902 m
.66635 .31277 L
s
.69429 .30902 m
.69429 .31277 L
s
.75016 .30902 m
.75016 .31277 L
s
.7781 .30902 m
.7781 .31277 L
s
.80603 .30902 m
.80603 .31277 L
s
.83397 .30902 m
.83397 .31277 L
s
.88984 .30902 m
.88984 .31277 L
s
.91778 .30902 m
.91778 .31277 L
s
.94571 .30902 m
.94571 .31277 L
s
.97365 .30902 m
.97365 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 .07181 m
.03006 .07181 L
s
[(-0.3)] .01131 .07181 1 0 Mshowa
.02381 .15088 m
.03006 .15088 L
s
[(-0.2)] .01131 .15088 1 0 Mshowa
.02381 .22995 m
.03006 .22995 L
s
[(-0.1)] .01131 .22995 1 0 Mshowa
.02381 .38808 m
.03006 .38808 L
s
[(0.1)] .01131 .38808 1 0 Mshowa
.02381 .46715 m
.03006 .46715 L
s
[(0.2)] .01131 .46715 1 0 Mshowa
.02381 .54622 m
.03006 .54622 L
s
[(0.3)] .01131 .54622 1 0 Mshowa
.125 Mabswid
.02381 .08763 m
.02756 .08763 L
s
.02381 .10344 m
.02756 .10344 L
s
.02381 .11925 m
.02756 .11925 L
s
.02381 .13507 m
.02756 .13507 L
s
.02381 .16669 m
.02756 .16669 L
s
.02381 .18251 m
.02756 .18251 L
s
.02381 .19832 m
.02756 .19832 L
s
.02381 .21413 m
.02756 .21413 L
s
.02381 .24576 m
.02756 .24576 L
s
.02381 .26157 m
.02756 .26157 L
s
.02381 .27739 m
.02756 .27739 L
s
.02381 .2932 m
.02756 .2932 L
s
.02381 .32483 m
.02756 .32483 L
s
.02381 .34064 m
.02756 .34064 L
s
.02381 .35646 m
.02756 .35646 L
s
.02381 .37227 m
.02756 .37227 L
s
.02381 .4039 m
.02756 .4039 L
s
.02381 .41971 m
.02756 .41971 L
s
.02381 .43552 m
.02756 .43552 L
s
.02381 .45134 m
.02756 .45134 L
s
.02381 .48296 m
.02756 .48296 L
s
.02381 .49878 m
.02756 .49878 L
s
.02381 .51459 m
.02756 .51459 L
s
.02381 .5304 m
.02756 .5304 L
s
.02381 .056 m
.02756 .056 L
s
.02381 .04019 m
.02756 .04019 L
s
.02381 .02437 m
.02756 .02437 L
s
.02381 .00856 m
.02756 .00856 L
s
.02381 .56203 m
.02756 .56203 L
s
.02381 .57784 m
.02756 .57784 L
s
.02381 .59366 m
.02756 .59366 L
s
.02381 .60947 m
.02756 .60947 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .55642 m
.06244 .31887 L
.07216 .23664 L
.08255 .14106 L
.08562 .11578 L
.08852 .09844 L
.09135 .08504 L
.09396 .07338 L
.09643 .06398 L
.09768 .06047 L
.09905 .05769 L
.09977 .05662 L
.10043 .05583 L
.10191 .05447 L
.10458 .05258 L
.1251 .03462 L
.13432 .02535 L
.14415 .01833 L
.14535 .01785 L
.14661 .01717 L
.148 .0162 L
.14928 .01532 L
.15047 .01479 L
.15158 .01477 L
.1528 .01542 L
.15411 .01684 L
.15527 .01846 L
.15653 .02022 L
.15773 .02147 L
.15883 .02206 L
.15982 .02207 L
.16092 .02158 L
.16206 .02071 L
.16314 .01981 L
.16435 .019 L
.16503 .01872 L
.16567 .01862 L
.16696 .01892 L
.16768 .01937 L
.16834 .01996 L
.16952 .0214 L
.17079 .02347 L
.17311 .02849 L
.17583 .0364 L
.1787 .04638 L
.18386 .06804 L
.1887 .0995 L
.19109 .11589 L
.1933 .128 L
.19452 .13312 L
Mistroke
.19583 .13755 L
.19859 .14565 L
.20343 .16542 L
.20581 .17864 L
.20839 .19423 L
.21305 .22663 L
.22175 .30403 L
.23121 .38422 L
.24133 .47742 L
.24432 .50203 L
.24715 .51905 L
.2499 .53217 L
.25244 .5436 L
.25481 .55288 L
.25615 .55691 L
.25741 .55969 L
.25867 .56163 L
.25938 .56244 L
.26003 .56306 L
.2628 .56512 L
.2833 .58188 L
.28558 .58799 L
.28686 .59054 L
.28804 .59205 L
.28908 .59273 L
.29021 .59293 L
.2914 .5928 L
.29251 .59267 L
.29381 .59284 L
.295 .59346 L
.29565 .594 L
.29637 .59469 L
.29767 .59611 L
.29884 .59734 L
.30009 .59838 L
.30116 .59901 L
.30234 .59951 L
.30705 .60206 L
.30833 .6029 L
.30898 .60318 L
.30969 .60332 L
.31095 .60301 L
.31212 .60205 L
.31331 .60055 L
.31444 .59893 L
.31547 .59756 L
.31656 .59648 L
.31774 .59593 L
.31883 .59604 L
.32001 .5967 L
Mistroke
.3213 .59775 L
.32197 .5983 L
.32269 .59881 L
.324 .59937 L
.32527 .59928 L
.32646 .59862 L
.32718 .59795 L
.32787 .59714 L
.32914 .59523 L
.33052 .59261 L
.332 .58912 L
.33722 .57242 L
.34202 .55289 L
.36086 .45902 L
.36602 .43058 L
.37155 .39316 L
.38153 .30529 L
.39171 .21798 L
.39708 .16907 L
.40002 .14099 L
.40278 .11794 L
.40518 .10273 L
.40775 .0899 L
.41043 .07773 L
.41188 .07142 L
.41324 .06618 L
.4145 .06214 L
.41565 .05931 L
.41692 .05704 L
.41762 .05612 L
.41828 .05541 L
.4205 .05362 L
.42291 .05205 L
.44241 .03506 L
.45275 .02512 L
.45547 .02294 L
.45691 .02136 L
.4577 .02057 L
.45844 .01993 L
.45915 .01943 L
.45991 .01901 L
.46125 .01846 L
.46385 .01731 L
.46524 .01636 L
.46655 .01544 L
.4672 .01506 L
.46791 .01479 L
.46869 .01472 L
.4694 .01489 L
.47065 .01578 L
Mistroke
.47136 .01658 L
.47202 .01744 L
.4733 .01928 L
.47449 .02081 L
.47558 .02175 L
.47674 .02213 L
.47803 .02178 L
.47921 .02097 L
.48044 .01994 L
.48109 .01944 L
.48178 .01901 L
.48304 .01862 L
.48422 .01882 L
.48551 .01968 L
.48669 .02101 L
.48799 .023 L
.48936 .02567 L
.49167 .03146 L
.49421 .03948 L
.50327 .07937 L
.50806 .11278 L
.50938 .12089 L
.51077 .12808 L
.51328 .13752 L
.51564 .1444 L
.51817 .15297 L
.52057 .16377 L
.52277 .17571 L
.52797 .20805 L
.53371 .25418 L
.54368 .34057 L
.55282 .42126 L
.55785 .46857 L
.56032 .49079 L
.5626 .50752 L
.56529 .52246 L
.56821 .53605 L
.57064 .54673 L
.57193 .55172 L
.57332 .55612 L
.57462 .55922 L
.57582 .56122 L
.57702 .56262 L
.57816 .56362 L
.58062 .56535 L
.5813 .56578 L
.58201 .56618 L
.58329 .56669 L
.58451 .56683 L
.58521 .56673 L
Mistroke
.58585 .56654 L
.58655 .56624 L
.58719 .5659 L
.58862 .56513 L
.58985 .56465 L
.59055 .56454 L
.59119 .56457 L
.59238 .56502 L
.59363 .56606 L
.59474 .56747 L
.59593 .56948 L
.59808 .57434 L
.60063 .5815 L
.603 .5879 L
.60423 .59039 L
.60555 .59209 L
.6063 .59262 L
.60701 .59287 L
.60764 .59293 L
.60833 .59288 L
.60901 .59277 L
.60975 .59268 L
.61053 .59268 L
.61126 .59284 L
.61255 .59353 L
.61328 .59415 L
.61395 .59482 L
.61641 .59744 L
.61709 .59803 L
.61781 .59855 L
.6191 .59923 L
.62147 .60015 L
.62267 .60078 L
.62398 .60167 L
.6252 .60254 L
.6265 .6032 L
.62773 .60327 L
.62885 .60272 L
.62996 .60162 L
.63115 .60001 L
.63228 .59841 L
.63333 .59711 L
.63454 .59615 L
.63518 .59593 L
.63587 .59593 L
.6366 .59617 L
.63728 .59657 L
.63857 .59759 L
.63969 .5985 L
.64089 .5992 L
Mistroke
.6422 .5994 L
.64342 .59897 L
.64465 .59794 L
.64579 .59652 L
.64703 .59447 L
.64835 .5918 L
.65057 .5861 L
.653 .57835 L
.66168 .54064 L
.66649 .50731 L
.67171 .48147 L
.67631 .46731 L
.67863 .45754 L
.6812 .44404 L
.68688 .40871 L
.69214 .36655 L
.70212 .27991 L
.71154 .19686 L
.71669 .14845 L
.71919 .12606 L
.72147 .1096 L
.72398 .09576 L
.72667 .08323 L
.72939 .07121 L
.73083 .06571 L
.73235 .06109 L
.73362 .05829 L
.73435 .0571 L
.73502 .0562 L
.73621 .05498 L
.73748 .05397 L
.73878 .05305 L
.74001 .05226 L
.74112 .05166 L
.74233 .05127 L
.74298 .0512 L
.74366 .05125 L
.74489 .05162 L
.74621 .05229 L
.74697 .05271 L
.74766 .05305 L
.74891 .05345 L
.7496 .05349 L
.75026 .05339 L
.75142 .05281 L
.75268 .05162 L
.7538 .05005 L
.75504 .04781 L
.75755 .04174 L
.75985 .0351 L
Mistroke
.76204 .02942 L
.76335 .02704 L
.76408 .02612 L
.76477 .02556 L
.76597 .02512 L
.76726 .02518 L
.76799 .02529 L
.76878 .02537 L
.76952 .02531 L
.77021 .02512 L
.7715 .02432 L
.77216 .02374 L
.77288 .023 L
.77418 .02157 L
.77541 .02034 L
.77609 .01979 L
.77683 .0193 L
.77813 .01868 L
.77928 .01826 L
.78049 .01775 L
.78181 .01699 L
.78303 .01612 L
.78415 .01535 L
.78534 .0148 L
.78665 .01481 L
.78787 .01555 L
.7891 .01693 L
.79025 .01856 L
.79129 .02 L
.79242 .02128 L
.79368 .02204 L
.79436 .02212 L
.79501 .02199 L
.79616 .02136 L
.79739 .02036 L
.79808 .01979 L
.79884 .01924 L
.79955 .01886 L
.80021 .01866 L
.80146 .01874 L
.80216 .01907 L
.80279 .01952 L
.80411 .02095 L
.8055 .02308 L
.80799 .02838 L
.81067 .03614 L
.81361 .04632 L
.81615 .056 L
.81887 .06853 L
.82145 .08409 L
Mistroke
.82379 .10071 L
.86366 .36219 L
.87244 .44109 L
.87705 .4846 L
.87957 .50427 L
.8819 .51818 L
.88449 .53065 L
.88732 .5434 L
.88866 .54896 L
.88992 .55353 L
.89115 .55711 L
.89228 .55961 L
.89338 .56136 L
.89454 .56268 L
.89571 .56368 L
.89699 .56462 L
.89824 .56546 L
.89894 .56589 L
.89959 .56624 L
.90086 .56672 L
.90202 .56682 L
.90327 .56655 L
.9044 .56604 L
.90562 .56536 L
.90694 .56476 L
.90816 .56453 L
.90929 .56475 L
.91036 .56538 L
.91149 .56652 L
.91273 .5683 L
.91404 .5708 L
.91642 .57668 L
.91922 .58474 L
.92046 .5879 L
.92116 .58941 L
.92181 .59059 L
.92313 .5922 L
.9238 .59265 L
.92453 .59288 L
.92531 .59292 L
.92606 .59284 L
.92674 .59273 L
.92747 .59267 L
.92817 .59271 L
.9288 .59286 L
.93003 .59354 L
.93072 .59413 L
.93146 .59488 L
.93282 .59636 L
.93413 .59768 L
Mistroke
.93535 .59861 L
.93663 .59926 L
.93803 .59978 L
.93922 .60028 L
.94035 .60091 L
.94165 .60182 L
.94283 .60265 L
.94382 .60315 L
.94489 .60331 L
.9459 .60299 L
.94682 .60227 L
.94785 .60108 L
.94897 .5995 L
.95015 .59785 L
.95123 .59668 L
.95238 .596 L
.95347 .59596 L
.95461 .59648 L
.95585 .59744 L
.95694 .59834 L
.95809 .59908 L
.95908 .59939 L
.96016 .5993 L
.96123 .59874 L
.96224 .5978 L
.96316 .59665 L
.96415 .59508 L
.96638 .59048 L
.96844 .58488 L
.97619 .55642 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00
:7oo00<007ooOol0ogooQWoo000XOol3003oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<0
07ooOol0<7oo0P00O7oo0`00O7oo0`00EGoo000XOol00`00Oomoo`0]Ool30002Ool00`00Oomoo`1g
Ool300000goo0000001iOol300000goo001oo`1DOol002Qoo`03001oogoo02aoo`03001oogoo00Ao
o`03001oo`00008007=oo`8000Aoo`H007=oo`8000Aoo`03001oogoo00<004moo`00:7oo00<007oo
Ool0:goo00<007ooOol01Goo0P000goo00<007ooOol0Kgoo0P001Woo0P000goo00<007ooOol0Kgoo
00<007ooOol01Goo0P000goo00<007ooOol0C7oo000XOol3000ZOol00`00Oomoo`0;Ool00`00Oomo
o`1^Ool00`00Oomoo`0;Ool00`00Oomoo`1/Ool3000=Ool00`00Oomoo`1<Ool002Qoo`03001oogoo
02Uoo`03001oogoo00eoo`03001oogoo06aoo`03001oogoo00aoo`03001oogoo06]oo`03001oogoo
00moo`03001oogoo04]oo`00:7oo00<007ooOol0:7oo00<007ooOol03Woo00<007ooOol0Jgoo00<0
07ooOol03Woo00<007ooOol0JGoo00<007ooOol047oo00<007ooOol0Bgoo000XOol00`00Oomoo`0W
Ool00`00Oomoo`0?Ool00`00Oomoo`1ZOol00`00Oomoo`0?Ool00`00Oomoo`1YOol00`00Oomoo`0@
Ool00`00Oomoo`1;Ool002Qoo`03001oogoo02Eoo`8001=oo`03001oogoo06Moo`80019oo`03001o
ogoo06Uoo`03001oogoo015oo`03001oogoo04Yoo`00:7oo00<007ooOol097oo00<007ooOol04goo
00<007ooOol0IWoo00<007ooOol04goo00<007ooOol0J7oo00<007ooOol04Goo00<007ooOol0BWoo
000XOol3000SOol00`00Oomoo`0DOol00`00Oomoo`1UOol00`00Oomoo`0DOol00`00Oomoo`1WOol0
0`00Oomoo`0BOol00`00Oomoo`1:Ool002Qoo`03001oogoo029oo`03001oogoo01Eoo`03001oogoo
06Aoo`03001oogoo01Eoo`03001oogoo06Moo`03001oogoo019oo`03001oogoo04Yoo`00:7oo00<0
07ooOol08Goo00<007ooOol05goo00<007ooOol0HWoo00<007ooOol05Woo00<007ooOol0Igoo00<0
07ooOol04goo00<007ooOol0BGoo000XOol00`00Oomoo`0POol00`00Oomoo`0HOol00`00Oomoo`1Q
Ool00`00Oomoo`0HOol00`00Oomoo`1UOol00`00Oomoo`0DOol00`00Oomoo`19Ool002Qoo`03001o
ogoo01moo`03001oogoo01Uoo`03001oogoo061oo`03001oogoo01Uoo`03001oogoo06Aoo`03001o
ogoo01Eoo`03001oogoo04Uoo`00:7oo00<007ooOol07Woo00<007ooOol06Woo00<007ooOol0Ggoo
00<007ooOol06Woo00<007ooOol0GWoo1`0067oo00<007ooOol0B7oo000XOol3000LOol2000NOol0
0`00Oomoo`1LOol2000MOol00`00Oomoo`1MOol2000NOol00`00Oomoo`18Ool002Qoo`03001oogoo
01aoo`03001oogoo01eoo`03001oogoo05aoo`03001oogoo01eoo`03001oogoo05]oo`8001moo`03
001oogoo04Qoo`00:7oo00<007ooOol06goo00<007ooOol07Woo00<007ooOol0Fgoo00<007ooOol0
7Woo00<007ooOol0Fgoo00<007ooOol07Woo00<007ooOol0B7oo000XOol00`00Oomoo`0KOol00`00
Oomoo`0NOol00`00Oomoo`1KOol00`00Oomoo`0NOol00`00Oomoo`1KOol00`00Oomoo`0OOol00`00
Oomoo`17Ool000aoo`8000Moo`<000Eoo`@000Moo`03001oogoo01]oo`03001oogoo01moo`03001o
ogoo05Yoo`03001oogoo01ioo`03001oogoo05Yoo`03001oogoo021oo`03001oogoo04Moo`002goo
00@007ooOol000Ioo`<000Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo01]oo`03001o
ogoo01moo`03001oogoo05Uoo`03001oogoo021oo`03001oogoo05Uoo`03001oogoo021oo`03001o
ogoo04Moo`002Woo00<007ooOol00Woo00<007ooOol00goo0`002Goo00<007ooOol017oo00<007oo
Ool06Woo00<007ooOol087oo00<007ooOol0FGoo00<007ooOol087oo00<007ooOol0F7oo00<007oo
Ool08Goo00<007ooOol0Agoo00000goo000000050002Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`04Ool4000IOol00`00Oomoo`0POol00`00Oomoo`1IOol00`00Oomoo`0POol00`00Oomo
o`1HOol00`00Oomoo`0QOol00`00Oomoo`17Ool000Yoo`03001oogoo009oo`03001oogoo00aoo`<0
00Moo`03001oogoo01Yoo`03001oogoo021oo`03001oogoo05Uoo`03001oogoo021oo`03001oogoo
05Qoo`03001oogoo025oo`03001oogoo04Moo`002Woo00<007ooOol00Woo00<007ooOol03goo00<0
07ooOol017oo00<007ooOol06Goo00<007ooOol08Woo00<007ooOol0Egoo00<007ooOol08Woo00<0
07ooOol0Egoo00<007ooOol08Woo00<007ooOol0AWoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`0ROol00`00Oomoo`1GOol00`00Oomoo`0R
Ool00`00Oomoo`1FOol00`00Oomoo`0SOol00`00Oomoo`16Ool000]oo`04001oogoo000=Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0IOol00`00Oomoo`0ROol00`00Oomoo`1GOol00`00
Oomoo`0ROol00`00Oomoo`1FOol00`00Oomoo`0SOol00`00Oomoo`16Ool000aoo`8000moo`@000Mo
o`03001oogoo01Qoo`03001oogoo02=oo`03001oogoo05Ioo`03001oogoo02=oo`03001oogoo05Io
o`03001oogoo02=oo`03001oogoo04Ioo`00:7oo0`0067oo00<007ooOol08goo00<007ooOol0EWoo
00<007ooOol08goo00<007ooOol0EWoo00<007ooOol08goo00<007ooOol0AWoo000XOol00`00Oomo
o`0HOol00`00Oomoo`0SOol00`00Oomoo`1FOol00`00Oomoo`0TOol00`00Oomoo`1DOol00`00Oomo
o`0TOol00`00Oomoo`16Ool002Qoo`03001oogoo01Moo`03001oogoo02Aoo`03001oogoo05Ioo`03
001oogoo02Aoo`03001oogoo05Aoo`03001oogoo02Aoo`03001oogoo04Ioo`00:7oo00<007ooOol0
5goo00<007ooOol09Goo00<007ooOol0EGoo00<007ooOol097oo00<007ooOol0E7oo00<007ooOol0
9Goo00<007ooOol0AGoo000XOol00`00Oomoo`0GOol00`00Oomoo`0UOol00`00Oomoo`1DOol00`00
Oomoo`0UOol00`00Oomoo`1DOol00`00Oomoo`0UOol00`00Oomoo`15Ool002Qoo`03001oogoo01Mo
o`03001oogoo02Eoo`03001oogoo05Aoo`03001oogoo02Eoo`03001oogoo05Aoo`03001oogoo02Eo
o`03001oogoo04Eoo`00:7oo0`005goo00<007ooOol09Goo00<007ooOol0E7oo00<007ooOol09Goo
00<007ooOol0E7oo00<007ooOol09Goo00<007ooOol0AGoo000XOol00`00Oomoo`0GOol00`00Oomo
o`0UOol00`00Oomoo`1DOol00`00Oomoo`0UOol00`00Oomoo`1COol00`00Oomoo`0VOol00`00Oomo
o`15Ool002Qoo`03001oogoo01Ioo`03001oogoo02Ioo`03001oogoo05Aoo`03001oogoo02Ioo`03
001oogoo059oo`03001oogoo02Ioo`03001oogoo04Eoo`00:7oo00<007ooOol05Woo00<007ooOol0
9goo00<007ooOol0Dgoo00<007ooOol09Woo00<007ooOol0DWoo00<007ooOol09goo00<007ooOol0
A7oo000XOol00`00Oomoo`0FOol00`00Oomoo`0WOol00`00Oomoo`1BOol00`00Oomoo`0WOol00`00
Oomoo`1BOol00`00Oomoo`0WOol00`00Oomoo`14Ool002Qoo`03001oogoo01Ioo`03001oogoo02Mo
o`03001oogoo059oo`03001oogoo02Moo`03001oogoo059oo`03001oogoo02Moo`03001oogoo04Ao
o`00:7oo00<007ooOol05Woo00<007ooOol09goo00<007ooOol0DWoo00<007ooOol09goo00<007oo
Ool0DWoo00<007ooOol09goo00<007ooOol0A7oo000XOol3000FOol00`00Oomoo`0WOol00`00Oomo
o`1BOol00`00Oomoo`0WOol00`00Oomoo`1AOol00`00Oomoo`0XOol00`00Oomoo`14Ool002Qoo`03
001oogoo01Ioo`03001oogoo02Qoo`03001oogoo055oo`03001oogoo02Moo`03001oogoo055oo`03
001oogoo02Qoo`03001oogoo04Aoo`00:7oo00<007ooOol05Woo00<007ooOol0:7oo00<007ooOol0
DGoo00<007ooOol0:7oo00<007ooOol0D7oo00<007ooOol0:7oo00<007ooOol0A7oo000XOol00`00
Oomoo`0FOol00`00Oomoo`0XOol00`00Oomoo`1AOol00`00Oomoo`0XOol00`00Oomoo`1@Ool00`00
Oomoo`0YOol00`00Oomoo`13Ool002Qoo`03001oogoo01Eoo`03001oogoo02Uoo`03001oogoo051o
o`03001oogoo02Uoo`03001oogoo051oo`03001oogoo02Uoo`03001oogoo04=oo`00:7oo00<007oo
Ool05Goo00<007ooOol0:Woo00<007ooOol0Cgoo00<007ooOol0:Goo00<007ooOol0D7oo00<007oo
Ool0:Goo00<007ooOol0@goo000XOol3000EOol00`00Oomoo`0ZOol00`00Oomoo`1?Ool00`00Oomo
o`0ZOol00`00Oomoo`1?Ool00`00Oomoo`0YOol00`00Oomoo`13Ool002Qoo`03001oogoo01Eoo`03
001oogoo02Yoo`03001oogoo04moo`03001oogoo02Yoo`03001oogoo04ioo`03001oogoo02Yoo`03
001oogoo04=oo`00:7oo00<007ooOol05Goo00<007ooOol0:Woo00<007ooOol0Cgoo00<007ooOol0
:Woo00<007ooOol0CWoo00<007ooOol0:Woo00<007ooOol0@goo000XOol00`00Oomoo`0EOol00`00
Oomoo`0[Ool00`00Oomoo`1>Ool00`00Oomoo`0[Ool00`00Oomoo`1=Ool00`00Oomoo`0[Ool00`00
Oomoo`12Ool000aoo`8000Moo`<000Aoo`H000Ioo`03001oogoo01Eoo`03001oogoo02]oo`03001o
ogoo04ioo`03001oogoo02]oo`03001oogoo04eoo`03001oogoo02]oo`03001oogoo049oo`002goo
00@007ooOol000Ioo`<000Eoo`05001oogooOol00006Ool00`00Oomoo`0EOol00`00Oomoo`0[Ool0
0`00Oomoo`1>Ool00`00Oomoo`0[Ool00`00Oomoo`1=Ool00`00Oomoo`0[Ool00`00Oomoo`12Ool0
00Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Moo`@001Aoo`03001oogoo
02]oo`03001oogoo04ioo`03001oogoo02aoo`03001oogoo04aoo`03001oogoo02]oo`03001oogoo
049oo`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo00<0
07ooOol05Goo00<007ooOol0;7oo00<007ooOol0CGoo00<007ooOol0;7oo00<007ooOol0C7oo00<0
07ooOol0:goo00<007ooOol0@Woo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`05
Ool00`00Oomoo`0DOol00`00Oomoo`0]Ool00`00Oomoo`1=Ool00`00Oomoo`0/Ool00`00Oomoo`1<
Ool00`00Oomoo`0[Ool00`00Oomoo`12Ool000Yoo`03001oogoo009oo`03001oogoo00moo`03001o
ogoo00Aoo`03001oogoo01Aoo`03001oogoo02eoo`03001oogoo04aoo`03001oogoo02eoo`03001o
ogoo04aoo`03001oogoo02]oo`03001oogoo049oo`002Woo00<007ooOol00Woo00<007ooOol03goo
00<007ooOol017oo00<007ooOol057oo00<007ooOol0;Goo00<007ooOol0C7oo00<007ooOol0;Woo
00<007ooOol0Bgoo00<007ooOol0;7oo00<007ooOol0@Goo000;Ool01000Oomoo`003Goo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol057oo00<007ooOol0;Woo00<007ooOol0Bgoo00<007oo
Ool0;Woo00<007ooOol0BWoo00<007ooOol0;Goo00<007ooOol0@Goo000<Ool2000?Ool40007Ool0
0`00Oomoo`0DOol00`00Oomoo`0^Ool00`00Oomoo`1;Ool00`00Oomoo`0^Ool00`00Oomoo`1:Ool0
0`00Oomoo`0]Ool00`00Oomoo`11Ool002Qoo`<001Aoo`03001oogoo02ioo`03001oogoo04]oo`03
001oogoo02ioo`03001oogoo04Yoo`03001oogoo02eoo`03001oogoo045oo`00:7oo00<007ooOol0
57oo00<007ooOol0;Woo00<007ooOol0Bgoo00<007ooOol0;Woo00<007ooOol0BWoo00<007ooOol0
;Goo00<007ooOol0@Goo000XOol00`00Oomoo`0DOol00`00Oomoo`0_Ool00`00Oomoo`1:Ool00`00
Oomoo`0_Ool00`00Oomoo`19Ool00`00Oomoo`0]Ool00`00Oomoo`11Ool002Qoo`03001oogoo01Ao
o`03001oogoo02moo`03001oogoo04Yoo`03001oogoo02moo`03001oogoo04Uoo`03001oogoo02eo
o`03001oogoo045oo`00:7oo00<007ooOol057oo00<007ooOol0;goo00<007ooOol0BWoo00<007oo
Ool0;goo00<007ooOol0BGoo00<007ooOol0;Woo00<007ooOol0@7oo000XOol00`00Oomoo`0COol0
0`00Oomoo`0`Ool00`00Oomoo`19Ool00`00Oomoo`0`Ool00`00Oomoo`19Ool00`00Oomoo`0^Ool0
0`00Oomoo`10Ool002Qoo`<001=oo`03001oogoo031oo`03001oogoo04Uoo`03001oogoo031oo`03
001oogoo04Uoo`03001oogoo02ioo`03001oogoo041oo`00:7oo00<007ooOol04goo00<007ooOol0
<7oo00<007ooOol0BGoo00<007ooOol0<Goo00<007ooOol0B7oo00<007ooOol0;Woo00<007ooOol0
@7oo000XOol00`00Oomoo`0COol00`00Oomoo`0aOol00`00Oomoo`18Ool00`00Oomoo`0aOol00`00
Oomoo`17Ool00`00Oomoo`0_Ool00`00Oomoo`10Ool002Qoo`03001oogoo01=oo`03001oogoo035o
o`03001oogoo04Qoo`03001oogoo035oo`03001oogoo04Moo`03001oogoo02moo`03001oogoo041o
o`00:7oo00<007ooOol04goo00<007ooOol0<Goo00<007ooOol0B7oo00<007ooOol0<Goo00<007oo
Ool0Agoo00<007ooOol0<7oo00<007ooOol0?goo000XOol00`00Oomoo`0COol00`00Oomoo`0aOol0
0`00Oomoo`17Ool00`00Oomoo`0bOol00`00Oomoo`17Ool00`00Oomoo`0`Ool00`00Oomoo`0oOol0
02Qoo`<001=oo`03001oogoo035oo`03001oogoo04Moo`03001oogoo039oo`03001oogoo04Moo`03
001oogoo031oo`03001oogoo03moo`00:7oo00<007ooOol04goo00<007ooOol0<Goo00<007ooOol0
Agoo00<007ooOol0<Woo00<007ooOol0Agoo00<007ooOol0<7oo00<007ooOol0?goo000XOol00`00
Oomoo`0BOol00`00Oomoo`0bOol00`00Oomoo`17Ool00`00Oomoo`0cOol00`00Oomoo`16Ool00`00
Oomoo`0`Ool00`00Oomoo`0oOol002Qoo`03001oogoo019oo`03001oogoo03=oo`03001oogoo04Io
o`03001oogoo03=oo`03001oogoo04Ioo`03001oogoo031oo`03001oogoo03moo`00:7oo00<007oo
Ool04Woo00<007ooOol0<goo00<007ooOol0AWoo00<007ooOol0<goo00<007ooOol0AWoo00<007oo
Ool0<7oo00<007ooOol0?goo000XOol00`00Oomoo`0BOol00`00Oomoo`0cOol00`00Oomoo`16Ool0
0`00Oomoo`0cOol00`00Oomoo`15Ool00`00Oomoo`0bOol00`00Oomoo`0nOol002Qoo`03001oogoo
019oo`03001oogoo03=oo`03001oogoo04Eoo`03001oogoo03Aoo`03001oogoo04Eoo`03001oogoo
039oo`03001oogoo03ioo`00:7oo0`004Woo00<007ooOol0<goo00<007ooOol0AGoo00<007ooOol0
=7oo00<007ooOol0AGoo00<007ooOol0<Woo00<007ooOol0?Woo000XOol00`00Oomoo`0BOol00`00
Oomoo`0cOol00`00Oomoo`15Ool00`00Oomoo`0dOol00`00Oomoo`15Ool00`00Oomoo`0bOol00`00
Oomoo`0nOol002Qoo`03001oogoo019oo`03001oogoo03=oo`03001oogoo04Eoo`03001oogoo03Ao
o`03001oogoo04Eoo`03001oogoo039oo`03001oogoo03ioo`0037oo0P001goo0`001Goo1@001Woo
00<007ooOol04Woo00<007ooOol0=7oo00<007ooOol0A7oo00<007ooOol0=Goo00<007ooOol0A7oo
00<007ooOol0<Woo00<007ooOol0?Woo000;Ool01000Oomoo`001Woo0`001goo00<007ooOol01Woo
00<007ooOol04Woo00<007ooOol0=7oo00<007ooOol0A7oo00<007ooOol0=Goo00<007ooOol0A7oo
00<007ooOol0<goo00<007ooOol0?Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30007Ool0
0`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0eOol00`00Oomoo`14Ool00`00Oomoo`0eOol0
0`00Oomoo`14Ool00`00Oomoo`0cOol00`00Oomoo`0mOol00003Ool0000000D0009oo`03001oogoo
009oo`03001oogoo00eoo`03001oogoo00Ioo`@0011oo`03001oogoo03Eoo`03001oogoo04=oo`03
001oogoo03Ioo`03001oogoo04=oo`03001oogoo03Aoo`03001oogoo03eoo`002Woo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol0=Goo00<007ooOol0
@goo00<007ooOol0=Woo00<007ooOol0@goo00<007ooOol0=7oo00<007ooOol0?Goo000:Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0eOol00`00
Oomoo`13Ool00`00Oomoo`0fOol00`00Oomoo`13Ool00`00Oomoo`0dOol00`00Oomoo`0mOol000Yo
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo03Eo
o`03001oogoo04=oo`03001oogoo03Ioo`03001oogoo04=oo`03001oogoo03Aoo`03001oogoo03eo
o`002goo00@007ooOol000ioo`<000Qoo`03001oogoo015oo`03001oogoo03Ioo`03001oogoo049o
o`03001oogoo03Ioo`03001oogoo04=oo`03001oogoo03Aoo`03001oogoo03eoo`0037oo0P0047oo
0P0027oo00<007ooOol04Goo00<007ooOol0=Woo00<007ooOol0@Woo00<007ooOol0=Woo00<007oo
Ool0@goo00<007ooOol0=Goo00<007ooOol0?7oo000XOol3000AOol00`00Oomoo`0fOol00`00Oomo
o`12Ool00`00Oomoo`0gOol00`00Oomoo`12Ool00`00Oomoo`0eOol00`00Oomoo`0lOol002Qoo`03
001oogoo015oo`03001oogoo03Ioo`03001oogoo049oo`03001oogoo03Moo`03001oogoo049oo`03
001oogoo03Eoo`03001oogoo03aoo`00:7oo00<007ooOol047oo00<007ooOol0=goo00<007ooOol0
@Woo00<007ooOol0=goo00<007ooOol0@Woo00<007ooOol0=Goo00<007ooOol0?7oo000XOol00`00
Oomoo`0@Ool00`00Oomoo`0gOol00`00Oomoo`11Ool00`00Oomoo`0hOol00`00Oomoo`11Ool00`00
Oomoo`0fOol00`00Oomoo`0lOol002Qoo`03001oogoo011oo`03001oogoo03Moo`03001oogoo045o
o`03001oogoo03Qoo`03001oogoo045oo`03001oogoo03Ioo`03001oogoo03aoo`00:7oo00<007oo
Ool047oo00<007ooOol0=goo00<007ooOol0@Goo00<007ooOol0>7oo00<007ooOol0@Goo00<007oo
Ool0=goo00<007ooOol0>goo000XOol00`00Oomoo`0@Ool00`00Oomoo`0hOol00`00Oomoo`10Ool0
0`00Oomoo`0hOol00`00Oomoo`11Ool00`00Oomoo`0gOol00`00Oomoo`0kOol002Qoo`<0011oo`03
001oogoo03Qoo`03001oogoo041oo`03001oogoo03Qoo`03001oogoo045oo`03001oogoo03Moo`03
001oogoo03]oo`00:7oo00<007ooOol047oo00<007ooOol0>7oo00<007ooOol0@7oo00<007ooOol0
>7oo00<007ooOol0@Goo00<007ooOol0=goo00<007ooOol0>goo000XOol00`00Oomoo`0@Ool00`00
Oomoo`0hOol00`00Oomoo`10Ool00`00Oomoo`0iOol00`00Oomoo`10Ool00`00Oomoo`0gOol00`00
Oomoo`0kOol002Qoo`03001oogoo00moo`03001oogoo03Uoo`03001oogoo041oo`03001oogoo03Uo
o`03001oogoo041oo`03001oogoo03Moo`03001oogoo03]oo`00:7oo00<007ooOol03goo00<007oo
Ool047oo0P001goo0`001Woo0P001goo0P001Woo1@0000=oo`00Ool03Goo0P001goo0`001Woo0P00
1goo0P001Goo1P0037oo00<007ooOol00P001goo0`001Woo0P001goo0P001Woo10004Goo0P001goo
0`001Woo0P001goo0P0027oo0`0047oo0P001goo0`001Woo0P001goo0P001Woo10004Goo0P001goo
0`000Woo00@007ooOomoo`8000Moo`8000Ioo`@002Eoo`00:7oo00<007ooOol03goo00<007ooOol0
3goo00@007ooOol000Ioo`<000Eoo`04001oogoo0005Ool01000Oomoo`001goo00D007ooOomoo`00
00eoo`04001oogoo0006Ool30005Ool01000Oomoo`001Goo00@007ooOol000Eoo`05001oogooOol0
000;Ool01000Oomoo`000Woo00<007ooOol017oo0`001Goo00@007ooOol000Eoo`04001oogoo0004
Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01000Ool000001Woo0`001Goo00@007ooOol000Eoo`04
001oogoo0008Ool00`00Oomoo`0>Ool01000Oomoo`001Woo0`001Goo00@007ooOol000Eoo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool01000Oomoo`001Woo0`000goo00<007oo0000
0Woo00<007ooOol00goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo029oo`00:7oo0`00
3goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol00goo0`0017oo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00=oo`<000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`03Ool0
0`00Oomoo`0<Ool00`00Ool00004Ool00`00Oomoo`03Ool30004Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol01Woo00<007ooOol037oo00H007ooOol007oo0005Ool30004Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00@007ooOomoo`H000ioo`03001oogoo009oo`03001oogoo
00=oo`<000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0<
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30003Ool20004Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0000Aoo`03001oogoo029oo`00:7oo00<007ooOol03goo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001o
ogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Ool00004Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol037oo00H007ooOol0
07oo000<Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000=oo`03001oogoo
00eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`09Ool20004
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo029oo`00:7oo00<007ooOol0
3goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Ool00004Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol0
0goo0`003goo00H007ooOol007oo000<Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool00Woo00@007ooOol000moo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001o
ogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol037oo00<007ooOol0
0Woo00<007ooOol02Goo0P0017oo00D007ooOomoo`0000Aoo`04001oogooOol20003Ool00`00Oomo
o`0ROol002Qoo`03001oogoo00moo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Yoo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`09
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007oo
Ool01Woo00<007ooOol02Goo00<007oo000017oo00<007ooOol02Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00Ioo`03001oogoo00aoo`06001oogoo001oo`0037oo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oo`0000moo`03001oogoo009oo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00004Ool01000Oomoogoo1@00
3goo00<007ooOol00Woo00<007ooOol02Goo0P0017oo00D007ooOomoo`0000Aoo`06001oogooOol0
07oo0`009Goo000XOol00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool02Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`03001oogoo00Uoo`03001oo`0000Aoo`03001oogoo00Yoo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool01P00Oomoo`00Ool000aoo`03001o
ogoo009oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Ool0000?Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomo
o`0001=oo`03001oogoo009oo`03001oogoo00Uoo`8000Aoo`05001oogooOol00004Ool00`00Oomo
o`02Ool00`00Oomoo`0VOol002Qoo`03001oogoo00ioo`03001oogoo011oo`04001oogoo000>Ool0
1000Oomoo`001Goo00@007ooOol000Eoo`<000Aoo`03001oogoo00Yoo`04001oogoo000>Ool01000
Oomoo`001Goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00Uoo`04001oogoo0002Ool0
0`00Oomoo`0<Ool01000Oomoo`001Goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo00eo
o`04001oogoo000>Ool01000Oomoo`001Goo00@007ooOol000Moo`80011oo`04001oogoo0008Ool0
0`00Oomoo`03Ool01000Oomoo`001Goo00@007ooOol000Aoo`03001oogoo019oo`04001oogoo000=
Ool20002Ool00`00Oomoo`03Ool01000Oomoo`001Goo0P009goo000XOol3000>Ool00`00Oomoo`0A
Ool2000@Ool20007Ool20007Ool20004Ool00`00Oomoo`0;Ool2000@Ool20007Ool20006Ool4000<
Ool01000Oomoogoo0P0047oo0P001goo0P001Woo10004Goo0`003goo0P001goo0P002Goo00<007oo
Ool03goo0P002Goo00<007ooOol017oo0P001goo0P001Goo1@004Goo0P003Woo00@007oo000000Mo
o`8000Qoo`<002Aoo`00:7oo00<007ooOol03Woo00<007ooOol0>goo00<007ooOol0?Woo00<007oo
Ool0>goo00<007ooOol0?Woo00<007ooOol0>Woo00<007ooOol0>Goo000XOol00`00Oomoo`0>Ool0
0`00Oomoo`0lOol00`00Oomoo`0lOol00`00Oomoo`0lOol00`00Oomoo`0mOol00`00Oomoo`0kOol0
0`00Oomoo`0iOol002Qoo`03001oogoo00ioo`03001oogoo03aoo`03001oogoo03aoo`03001oogoo
03aoo`03001oogoo03eoo`03001oogoo03]oo`03001oogoo03Uoo`00:7oo00<007ooOol03Woo00<0
07ooOol0?7oo00<007ooOol0?7oo00<007ooOol0?7oo00<007ooOol0?Goo00<007ooOol0>goo00<0
07ooOol0>Goo000XOol00`00Oomoo`0>Ool00`00Oomoo`0lOol00`00Oomoo`0lOol00`00Oomoo`0l
Ool00`00Oomoo`0mOol00`00Oomoo`0kOol00`00Oomoo`0iOol002Qoo`03001oogoo00ioo`03001o
ogoo03aoo`03001oogoo03aoo`03001oogoo03aoo`03001oogoo03eoo`03001oogoo03aoo`03001o
ogoo03Qoo`007gooo`00T@000Goo000XOol00`00Oomoo`09Ool01@00Oomoogoo00001Woo00<007oo
Ool027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol02Goo0P002Goo
00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol027oo00<007ooOol01Woo
00@007ooOol000Yoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oo`0000Yoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Uoo`00:7oo00<007ooOol03Goo00<007oo
Ool09Goo00<007ooOol05Goo00<007ooOol07Goo00<007ooOol077oo00<007ooOol05Woo00<007oo
Ool097oo00<007ooOol03Woo00<007ooOol0:goo00<007ooOol01goo00<007ooOol0<Woo00<007oo
0000>7oo000XOol00`00Oomoo`0=Ool00`00Oomoo`0mOol00`00Oomoo`0kOol00`00Oomoo`0nOol0
0`00Oomoo`0lOol00`00Oomoo`0lOol00`00Oomoo`0hOol002Qoo`03001oogoo00eoo`03001oogoo
03ioo`03001oogoo03Yoo`03001oogoo03ioo`03001oogoo03aoo`03001oogoo03aoo`03001oogoo
03Qoo`00:7oo00<007ooOol03Goo00<007ooOol0?Woo00<007ooOol0>Woo00<007ooOol0?Woo00<0
07ooOol0?7oo00<007ooOol0?7oo00<007ooOol0>7oo000XOol3000=Ool00`00Oomoo`0nOol00`00
Oomoo`0jOol00`00Oomoo`0nOol00`00Oomoo`0kOol00`00Oomoo`0nOol00`00Oomoo`0gOol002Qo
o`03001oogoo00aoo`03001oogoo03moo`03001oogoo03Yoo`03001oogoo03ioo`03001oogoo03]o
o`03001oogoo03ioo`03001oogoo03Moo`00:7oo00<007ooOol037oo00<007ooOol0?goo00<007oo
Ool0>Woo00<007ooOol0?Woo00<007ooOol0>goo00<007ooOol0?Woo00<007ooOol0=goo000XOol0
0`00Oomoo`0<Ool00`00Oomoo`0oOol00`00Oomoo`0jOol00`00Oomoo`0oOol00`00Oomoo`0jOol0
0`00Oomoo`0nOol00`00Oomoo`0gOol002Qoo`03001oogoo00aoo`03001oogoo03moo`03001oogoo
03Yoo`03001oogoo03moo`03001oogoo03Yoo`03001oogoo03ioo`03001oogoo03Moo`00:7oo00<0
07ooOol037oo00<007ooOol0?goo00<007ooOol0>Woo00<007ooOol0?goo00<007ooOol0>Woo00<0
07ooOol0?Woo00<007ooOol0=goo000XOol3000<Ool00`00Oomoo`0oOol00`00Oomoo`0iOol00`00
Oomoo`10Ool00`00Oomoo`0jOol00`00Oomoo`0oOol00`00Oomoo`0fOol002Qoo`03001oogoo00]o
o`03001oogoo041oo`03001oogoo03Uoo`03001oogoo041oo`03001oogoo03Yoo`03001oogoo03mo
o`03001oogoo03Ioo`00:7oo00<007ooOol02goo00<007ooOol0@7oo00<007ooOol0>Goo00<007oo
Ool0@7oo00<007ooOol0>Woo00<007ooOol0?goo00<007ooOol0=Woo000XOol00`00Oomoo`0;Ool0
0`00Oomoo`11Ool00`00Oomoo`0hOol00`00Oomoo`10Ool00`00Oomoo`0jOol00`00Oomoo`0oOol0
0`00Oomoo`0fOol002Qoo`03001oogoo00]oo`03001oogoo045oo`03001oogoo03Qoo`03001oogoo
041oo`03001oogoo03Yoo`03001oogoo03moo`03001oogoo03Ioo`00:7oo00<007ooOol02goo00<0
07ooOol0@Goo00<007ooOol0>7oo00<007ooOol0@Goo00<007ooOol0>Goo00<007ooOol0?goo00<0
07ooOol0=Woo000XOol00`00Oomoo`0;Ool00`00Oomoo`11Ool00`00Oomoo`0hOol00`00Oomoo`11
Ool00`00Oomoo`0hOol00`00Oomoo`10Ool00`00Oomoo`0fOol002Qoo`<000Yoo`03001oogoo049o
o`03001oogoo03Qoo`03001oogoo045oo`03001oogoo03Qoo`03001oogoo045oo`03001oogoo03Eo
o`00:7oo00<007ooOol02Woo00<007ooOol0@Woo00<007ooOol0>7oo00<007ooOol0@Goo00<007oo
Ool0>7oo00<007ooOol0@Goo00<007ooOol0=Goo000XOol00`00Oomoo`0:Ool00`00Oomoo`12Ool0
0`00Oomoo`0gOol00`00Oomoo`12Ool00`00Oomoo`0hOol00`00Oomoo`11Ool00`00Oomoo`0eOol0
02Qoo`03001oogoo00Yoo`03001oogoo049oo`03001oogoo03Moo`03001oogoo049oo`03001oogoo
03Qoo`03001oogoo045oo`03001oogoo03Eoo`00:7oo00<007ooOol02Woo00<007ooOol0@Woo00<0
07ooOol0=goo00<007ooOol0@Woo00<007ooOol0>7oo00<007ooOol0@Goo00<007ooOol0=Goo000X
Ool00`00Oomoo`0:Ool00`00Oomoo`12Ool00`00Oomoo`0gOol00`00Oomoo`12Ool00`00Oomoo`0h
Ool00`00Oomoo`11Ool00`00Oomoo`0eOol002Qoo`<000Uoo`03001oogoo04=oo`03001oogoo03Mo
o`03001oogoo04=oo`03001oogoo03Moo`03001oogoo045oo`03001oogoo03Eoo`00:7oo00<007oo
Ool02Goo00<007ooOol0A7oo00<007ooOol0=Woo00<007ooOol0@goo00<007ooOol0=goo00<007oo
Ool0@Woo00<007ooOol0=7oo000XOol00`00Oomoo`09Ool00`00Oomoo`14Ool00`00Oomoo`0fOol0
0`00Oomoo`13Ool00`00Oomoo`0fOol00`00Oomoo`13Ool00`00Oomoo`0dOol002Qoo`03001oogoo
00Uoo`03001oogoo04Aoo`03001oogoo03Ioo`03001oogoo04=oo`03001oogoo03Ioo`03001oogoo
04=oo`03001oogoo03Aoo`0037oo0P001goo0`001Goo1@001Woo00<007ooOol02Goo00<007ooOol0
A7oo00<007ooOol0=Woo00<007ooOol0@goo00<007ooOol0=Woo00<007ooOol0@goo00<007ooOol0
=7oo000;Ool01000Oomoo`001Woo0`001goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
A7oo00<007ooOol0=Goo00<007ooOol0A7oo00<007ooOol0=Woo00<007ooOol0@goo00<007ooOol0
=7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30007Ool00`00Oomoo`06Ool40007Ool00`00
Oomoo`15Ool00`00Oomoo`0eOol00`00Oomoo`14Ool00`00Oomoo`0fOol00`00Oomoo`13Ool00`00
Oomoo`0dOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo00Qo
o`03001oogoo04Eoo`03001oogoo03Eoo`03001oogoo04Aoo`03001oogoo03Eoo`03001oogoo04Ao
o`03001oogoo03Aoo`002Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo00<007oo
Ool027oo00<007ooOol0AGoo00<007ooOol0=Goo00<007ooOol0AGoo00<007ooOol0=7oo00<007oo
Ool0A7oo00<007ooOol0=7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool0
0`00Oomoo`08Ool00`00Oomoo`15Ool00`00Oomoo`0eOol00`00Oomoo`15Ool00`00Oomoo`0dOol0
0`00Oomoo`15Ool00`00Oomoo`0cOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo
00Ioo`03001oogoo00Qoo`03001oogoo04Eoo`03001oogoo03Eoo`03001oogoo04Eoo`03001oogoo
03Aoo`03001oogoo04Eoo`03001oogoo03=oo`002goo00@007ooOol000ioo`<000Qoo`03001oogoo
00Qoo`03001oogoo04Ioo`03001oogoo03Aoo`03001oogoo04Eoo`03001oogoo03Aoo`03001oogoo
04Eoo`03001oogoo03=oo`0037oo0P0047oo0P0027oo0`001goo00<007ooOol0Agoo00<007ooOol0
=7oo00<007ooOol0AGoo00<007ooOol0<goo00<007ooOol0AWoo00<007ooOol0<goo000XOol00`00
Oomoo`07Ool00`00Oomoo`17Ool00`00Oomoo`0cOol00`00Oomoo`16Ool00`00Oomoo`0cOol00`00
Oomoo`16Ool00`00Oomoo`0cOol002Qoo`03001oogoo00Moo`03001oogoo04Moo`03001oogoo03=o
o`03001oogoo04Ioo`03001oogoo03=oo`03001oogoo04Ioo`03001oogoo03=oo`00:7oo00<007oo
Ool01goo00<007ooOol0Agoo00<007ooOol0<goo00<007ooOol0AWoo00<007ooOol0<goo00<007oo
Ool0AWoo00<007ooOol0<goo000XOol00`00Oomoo`07Ool00`00Oomoo`17Ool00`00Oomoo`0cOol0
0`00Oomoo`17Ool00`00Oomoo`0bOol00`00Oomoo`17Ool00`00Oomoo`0bOol002Qoo`03001oogoo
00Moo`03001oogoo04Moo`03001oogoo03=oo`03001oogoo04Moo`03001oogoo039oo`03001oogoo
04Moo`03001oogoo039oo`00:7oo00<007ooOol01Woo00<007ooOol0B7oo00<007ooOol0<goo00<0
07ooOol0Agoo00<007ooOol0<Woo00<007ooOol0Agoo00<007ooOol0<Woo000XOol30006Ool00`00
Oomoo`18Ool00`00Oomoo`0cOol00`00Oomoo`17Ool00`00Oomoo`0aOol00`00Oomoo`18Ool00`00
Oomoo`0bOol002Qoo`03001oogoo00Ioo`03001oogoo04Uoo`03001oogoo035oo`03001oogoo04Qo
o`03001oogoo035oo`03001oogoo04Qoo`03001oogoo039oo`00:7oo00<007ooOol01Woo00<007oo
Ool0BGoo00<007ooOol0<Goo00<007ooOol0B7oo00<007ooOol0<Goo00<007ooOol0B7oo00<007oo
Ool0<Woo000XOol00`00Oomoo`06Ool00`00Oomoo`19Ool00`00Oomoo`0aOol00`00Oomoo`18Ool0
0`00Oomoo`0aOol00`00Oomoo`18Ool00`00Oomoo`0bOol002Qoo`03001oogoo00Ioo`03001oogoo
04Uoo`03001oogoo035oo`03001oogoo04Qoo`03001oogoo035oo`03001oogoo04Qoo`03001oogoo
039oo`00:7oo00<007ooOol01Goo00<007ooOol0BWoo00<007ooOol0<Goo00<007ooOol0B7oo00<0
07ooOol0<Goo00<007ooOol0BGoo00<007ooOol0<Goo000XOol30005Ool00`00Oomoo`1:Ool00`00
Oomoo`0aOol00`00Oomoo`19Ool00`00Oomoo`0`Ool00`00Oomoo`19Ool00`00Oomoo`0aOol002Qo
o`03001oogoo00Eoo`03001oogoo04Yoo`03001oogoo035oo`03001oogoo04Uoo`03001oogoo02mo
o`03001oogoo04Yoo`03001oogoo035oo`00:7oo00<007ooOol01Goo00<007ooOol0BWoo00<007oo
Ool0<7oo00<007ooOol0BWoo00<007ooOol0;goo00<007ooOol0BWoo00<007ooOol0<Goo000XOol0
0`00Oomoo`05Ool00`00Oomoo`1:Ool00`00Oomoo`0`Ool00`00Oomoo`1:Ool00`00Oomoo`0_Ool0
0`00Oomoo`1:Ool00`00Oomoo`0aOol002Qoo`03001oogoo00Aoo`03001oogoo04aoo`03001oogoo
02moo`03001oogoo04Yoo`03001oogoo02moo`03001oogoo04Yoo`03001oogoo035oo`00:7oo00<0
07ooOol017oo00<007ooOol0C7oo00<007ooOol0;goo00<007ooOol0BWoo00<007ooOol0;goo00<0
07ooOol0BWoo00<007ooOol0<Goo000XOol30004Ool00`00Oomoo`1<Ool00`00Oomoo`0_Ool00`00
Oomoo`1:Ool00`00Oomoo`0_Ool00`00Oomoo`1:Ool00`00Oomoo`0aOol002Qoo`03001oogoo00Ao
o`03001oogoo04aoo`03001oogoo02ioo`03001oogoo04]oo`03001oogoo02ioo`03001oogoo04]o
o`03001oogoo035oo`00:7oo00<007ooOol017oo00<007ooOol0C7oo00<007ooOol0;Woo00<007oo
Ool0Bgoo00<007ooOol0;Woo00<007ooOol0Bgoo00<007ooOol0<Goo000XOol00`00Oomoo`04Ool0
0`00Oomoo`1<Ool00`00Oomoo`0^Ool00`00Oomoo`1<Ool00`00Oomoo`0]Ool00`00Oomoo`1;Ool0
0`00Oomoo`0aOol000aoo`8000Moo`<000Aoo`H000Ioo`03001oogoo00=oo`03001oogoo04eoo`03
001oogoo02ioo`03001oogoo04aoo`03001oogoo02eoo`03001oogoo04]oo`03001oogoo035oo`00
2goo00@007ooOol000Ioo`<000Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`1=
Ool00`00Oomoo`0^Ool00`00Oomoo`1<Ool00`00Oomoo`0]Ool00`00Oomoo`1;Ool00`00Oomoo`0a
Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Moo`03001oogoo00=o
o`03001oogoo04eoo`03001oogoo02ioo`03001oogoo04aoo`03001oogoo02aoo`03001oogoo04eo
o`03001oogoo031oo`002Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo10000Woo
00<007ooOol0CWoo00<007ooOol0;7oo00<007ooOol0CGoo00<007ooOol0;7oo00<007ooOol0CGoo
00<007ooOol0<7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool00`00Oomoo`1>Ool00`00Oomoo`0/Ool00`00Oomoo`1=Ool00`00Oomoo`0/Ool00`00Oomo
o`1=Ool00`00Oomoo`0`Ool000Yoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03
001oogoo00=oo`03001oogoo04ioo`03001oogoo02aoo`03001oogoo04eoo`03001oogoo02]oo`03
001oogoo04ioo`03001oogoo031oo`002Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol0;7oo00<007ooOol0CGoo00<007ooOol0
:goo00<007ooOol0CWoo00<007ooOol0<7oo000;Ool01000Oomoo`003Goo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol0Cgoo00<007ooOol0;7oo00<007ooOol0CGoo00<0
07ooOol0:goo00<007ooOol0CWoo00<007ooOol0<7oo000<Ool2000?Ool40007Ool00`00Oomoo`02
Ool00`00Oomoo`1?Ool00`00Oomoo`0[Ool00`00Oomoo`1?Ool00`00Oomoo`0YOol00`00Oomoo`1?
Ool00`00Oomoo`0`Ool002Qoo`<0009oo`03001oogoo04moo`03001oogoo02]oo`03001oogoo04mo
o`03001oogoo02Uoo`03001oogoo04moo`03001oogoo031oo`00:7oo00<007ooOol00Woo00<007oo
Ool0D7oo00<007ooOol0:Woo00<007ooOol0Cgoo00<007ooOol0:Goo00<007ooOol0Cgoo00<007oo
Ool0<7oo000XOol00`00Oomoo`02Ool00`00Oomoo`1@Ool00`00Oomoo`0ZOol00`00Oomoo`1?Ool0
0`00Oomoo`0YOol00`00Oomoo`1?Ool00`00Oomoo`0`Ool002Qoo`05001oogooOol0001COol00`00
Oomoo`0ZOol00`00Oomoo`1?Ool00`00Oomoo`0XOol00`00Oomoo`1@Ool00`00Oomoo`0`Ool002Qo
o`05001oogooOol0001COol00`00Oomoo`0ZOol00`00Oomoo`1?Ool00`00Oomoo`0XOol00`00Oomo
o`1@Ool00`00Oomoo`0`Ool002Qoo`05001oogooOol0001COol00`00Oomoo`0YOol00`00Oomoo`1@
Ool00`00Oomoo`0XOol00`00Oomoo`1@Ool00`00Oomoo`0`Ool002Qoo`<00003Ool007oo05=oo`03
001oogoo02Qoo`03001oogoo051oo`03001oogoo02Qoo`03001oogoo055oo`03001oogoo02moo`00
:7oo00D007ooOomoo`0005Aoo`03001oogoo02Qoo`03001oogoo055oo`03001oogoo02Moo`03001o
ogoo055oo`03001oogoo02moo`00:7oo00D007ooOomoo`0005Aoo`03001oogoo02Qoo`03001oogoo
055oo`03001oogoo02Ioo`03001oogoo059oo`03001oogoo02moo`00:7oo00@007ooOol005Eoo`03
001oogoo02Qoo`03001oogoo055oo`03001oogoo02Ioo`03001oogoo059oo`03001oogoo02moo`00
:7oo00@007ooOol005Eoo`03001oogoo02Moo`03001oogoo059oo`03001oogoo02Ioo`03001oogoo
059oo`03001oogoo02moo`00:7oo00@007ooOol005Eoo`03001oogoo02Moo`03001oogoo059oo`03
001oogoo02Ioo`03001oogoo059oo`03001oogoo02moo`00:7oo00@007ooOol005Ioo`03001oogoo
02Ioo`03001oogoo059oo`03001oogoo02Ioo`03001oogoo05=oo`03001oogoo02ioo`00:7oo1000
EWoo00<007ooOol09Woo00<007ooOol0DWoo00<007ooOol09Woo00<007ooOol0Dgoo00<007ooOol0
;Woo000XOol01000Oomoo`00EWoo00<007ooOol09Woo00<007ooOol0Dgoo00<007ooOol097oo00<0
07ooOol0E7oo00<007ooOol0;Woo000XOol00`00Ool0001GOol00`00Oomoo`0UOol00`00Oomoo`1D
Ool00`00Oomoo`0TOol00`00Oomoo`1DOol00`00Oomoo`0^Ool002Qoo`03001oo`0005Moo`03001o
ogoo02Eoo`03001oogoo05Aoo`03001oogoo02Aoo`03001oogoo05Aoo`03001oogoo02ioo`00:7oo
00<007oo0000Egoo00<007ooOol09Goo00<007ooOol0E7oo00<007ooOol097oo00<007ooOol0EGoo
00<007ooOol0;Goo000XOol00`00Ool0001HOol00`00Oomoo`0TOol00`00Oomoo`1DOol00`00Oomo
o`0TOol00`00Oomoo`1EOol00`00Oomoo`0]Ool002Qoo`<005Qoo`03001oogoo02Aoo`03001oogoo
05Eoo`03001oogoo02=oo`03001oogoo05Eoo`03001oogoo02eoo`00:7oo00<007oo0000F7oo00<0
07ooOol097oo00<007ooOol0EGoo00<007ooOol08goo00<007ooOol0EGoo00<007ooOol0;Goo000X
Ool2001IOol00`00Oomoo`0SOol00`00Oomoo`1FOol00`00Oomoo`0ROol00`00Oomoo`1FOol00`00
Oomoo`0]Ool002Qoo`8005Uoo`03001oogoo02=oo`03001oogoo05Ioo`03001oogoo029oo`03001o
ogoo05Moo`03001oogoo02aoo`0037oo0P001goo0`001Goo10001goo0P00FWoo00<007ooOol08Woo
00<007ooOol0EWoo00<007ooOol08Woo00<007ooOol0Egoo00<007ooOol0;7oo000;Ool01000Oomo
o`001Woo0`0017oo00<007ooOol00Woo00<007ooOol017oo0P00FWoo00<007ooOol08Woo00<007oo
Ool0Egoo00<007ooOol08Goo00<007ooOol0Egoo00<007ooOol0;7oo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool30009Ool00`00Oomoo`04Ool4001HOol00`00Oomoo`0ROol00`00Oomoo`1GOol0
0`00Oomoo`0QOol00`00Oomoo`1GOol00`00Oomoo`0/Ool000Yoo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Aoo`8005Yoo`03001oogoo025oo`03001oogoo05Qoo`03001oogoo021oo`03
001oogoo05Uoo`03001oogoo02]oo`002Woo00<007ooOol00Woo00<007ooOol037oo0`001goo00<0
07ooOol0FWoo00<007ooOol087oo00<007ooOol0F7oo00<007ooOol087oo00<007ooOol0FGoo00<0
07ooOol0:goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`1J
Ool00`00Oomoo`0POol00`00Oomoo`1HOol00`00Oomoo`0POol00`00Oomoo`1JOol00`00Oomoo`0Z
Ool000Yoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo05Yoo`03001o
ogoo021oo`03001oogoo05Uoo`03001oogoo01moo`03001oogoo05Yoo`03001oogoo01moo`03001o
ogoo00Qoo`002goo00@007ooOol000eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo05Yo
o`03001oogoo021oo`03001oogoo05Uoo`03001oogoo01moo`03001oogoo05Yoo`03001oogoo01mo
o`03001oogoo00Qoo`0037oo0P003goo10001goo00<007ooOol0Fgoo00<007ooOol07Woo00<007oo
Ool0Fgoo00<007ooOol07Goo00<007ooOol0Fgoo0P0087oo00<007ooOol027oo000XOol3001LOol0
0`00Oomoo`0MOol00`00Oomoo`1LOol00`00Oomoo`0LOol00`00Oomoo`1LOol2000NOol00`00Oomo
o`09Ool002Qoo`03001oogoo05eoo`8001eoo`03001oogoo05eoo`H001Qoo`03001oogoo05eoo`80
0003Ool00000008001Qoo`03001oogoo00Uoo`00:7oo00<007ooOol0Ggoo00<007ooOol06Woo00<0
07ooOol0GWoo0P000goo00<007ooOol05Goo00<007ooOol0Ggoo00<007ooOol00Woo00<007ooOol0
5Goo00<007ooOol02Goo000XOol00`00Oomoo`1POol00`00Oomoo`0HOol00`00Oomoo`1TOol00`00
Oomoo`0EOol00`00Oomoo`1TOol00`00Oomoo`0EOol00`00Oomoo`09Ool002Qoo`03001oogoo065o
o`03001oogoo01Moo`03001oogoo06Aoo`03001oogoo01Aoo`03001oogoo06Eoo`03001oogoo01Ao
o`03001oogoo00Yoo`00:7oo00<007ooOol0HWoo00<007ooOol05Woo00<007ooOol0IGoo00<007oo
Ool04goo00<007ooOol0IWoo00<007ooOol04goo00<007ooOol02Woo000XOol3001SOol00`00Oomo
o`0DOol00`00Oomoo`1VOol00`00Oomoo`0COol00`00Oomoo`1VOol00`00Oomoo`0COol00`00Oomo
o`0:Ool002Qoo`03001oogoo06Aoo`03001oogoo01=oo`03001oogoo06Moo`03001oogoo019oo`03
001oogoo06Ioo`03001oogoo01=oo`03001oogoo00Yoo`00:7oo00<007ooOol0IGoo00<007ooOol0
4Woo00<007ooOol0Igoo00<007ooOol04Goo00<007ooOol0J7oo00<007ooOol04Goo00<007ooOol0
2goo000XOol00`00Oomoo`1UOol00`00Oomoo`0AOol00`00Oomoo`1YOol00`00Oomoo`0@Ool00`00
Oomoo`1XOol00`00Oomoo`0AOol00`00Oomoo`0;Ool002Qoo`03001oogoo06Ioo`03001oogoo011o
o`03001oogoo06Uoo`03001oogoo011oo`03001oogoo06Uoo`03001oogoo011oo`03001oogoo00]o
o`00:7oo00<007ooOol0Igoo00<007ooOol03goo00<007ooOol0JGoo00<007ooOol03goo00<007oo
Ool0JWoo00<007ooOol03goo00<007ooOol037oo000XOol3001WOol4000=Ool00`00Oomoo`1[Ool4
000=Ool00`00Oomoo`1[Ool4000=Ool00`00Oomoo`0<Ool002Qoo`03001oogoo06Yoo`8000Ioo`<0
009oo`03001oogoo06moo`03001oogoo00Eoo`<0009oo`03001oogoo06moo`8000Ioo`8000=oo`03
001oogoo00eoo`00:7oo00<007ooOol0Jgoo0P001Goo00<007oo00000`00LWoo0P001Goo00<007oo
00000`00LWoo0P001Goo00<007oo00000P0047oo000XOol00`00Oomoo`1]Ool20002Ool01000Oomo
ogoo0P00M7oo0`000Woo00<007ooOol00Woo00<007ooOol0LWoo0`000Woo00@007ooOomoo`80011o
o`00:7oo00<007ooOol0Kgoo0`00O7oo0P00O7oo0`005Woo000XOol00`00Oomoo`3oOon6Ool002Qo
o`03001oogoo0?moohIoo`00:7oo0`00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001o
ogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
The waveform looks very different than a triangle wave, so there is \
no reason to expect that it would sound the same. However, if we play this \
waveform (using the same playrange as before), \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Play[f\_approx[t, 30], {t, 0, 1}, 
      PlayRange \[Rule] {\(-0.6\), 0.6}]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.28"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 8192 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oo`00/@0000000`00
Oomoo`3oOon]Ool100000003001oo`000?l00:`0005oo`40000000X007oo000007oo001oo`00Ool0
009oo`06001oo`00001oo`000Woo00<007oo00000Woo00H007oo000007oo0002Ool00`00Ool00002
Ool02@00Oomoo`00Ool007oo001oo`0200001Woo001oogoo001oo`800007Ool007ooOol007oo0000
0Woo00H007oo000007oo0002Ool01P00Ool007oo001oo`800007Ool007ooOol007oo00000Woo00H0
07ooOol007oo0002Ool01P00Ool00000Ool0009oo`03001oo`0000<00004Ool007oo0002Ool01P00
Ool00000Ool0009oo`03001oo`00009oo`06001oo`00001oo`000Woo00<007oo00000Woo00<007oo
00000Woo00@007oo001oo`800006Ool007ooOol007oo0P0000Moo`00Oomoo`00Ool00002Ool01P00
Ool00000Ool0009oo`06001oo`00Ool007oo0P0000Moo`00Oomoo`00Ool00002Ool01P00Oomoo`00
Ool0009oo`06001oo`00001oo`000Woo00<007oo00000`0000Aoo`00Ool0009oo`06001oo`00001o
o`000Woo00<007oo00000Woo00H007oo000007oo0002Ool00`00Ool00002Ool01@00Ool007oo0000
0Woo00H007oo000007oo0002Ool01P00Ool00000Ool0009oo`03001oo`00009oo`06001oo`00001o
o`000Woo00H007oo001oo`00Ool200001goo001oogoo001oo`00009oo`06001oogoo001oo`000Woo
00H007oo000007oo0002Ool00`00Ool00003000017oo001oo`000Woo00H007oo000007oo0002Ool0
0`00Ool00002Ool01P00Ool00000Ool0009oo`04001oo`00Ool2000017oo001oo`000Woo00H007oo
000007oo0002Ool01P00Ool00000Ool0009oo`03001oo`00009oo`08001oo`00001oo`00Ool0009o
o`04001oo`00Ool200001goo001oogoo001oo`00009oo`06001oogoo001oo`000Woo00H007oo0000
07oo0002Ool00`00Oomoo`0100000003001oo`0000=oo`04001oo`000002Ool01000Ool0000017oo
00<007oo00000Woo00H007oo000007oo0002Ool00`00Ool00005Ool20002Ool01000Ool0000017oo
00<007oo000017oo0P0000Ioo`00Oomoo`00Ool20004Ool00`00Ool00002Ool300001goo001oogoo
001oo`0000Eoo`03001oo`00009oo`04001oo`000004Ool00`00Ool00003Ool01000Ool000000Woo
00@007oo000000Aoo`03001oo`00009oo`06001oo`00001oo`000Woo00<007oo00001Goo0P000Woo
00@007oo000000Aoo`03001oo`0000Aoo`800006Ool007ooOol007oo0P0017oo0P000goo0`0000Mo
o`00Oomoo`00Ool00005Ool00`00Ool00002Ool01000Ool0000017oo00<007oo00000goo0P0000Io
o`00Oomoo`00Ool20004Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`03001oo`0000Eoo`80
009oo`04001oo`000004Ool00`00Ool00004Ool200001Woo001oogoo001oo`8000Aoo`80009oo`06
001oo`00001oo`000Woo00<007oo00001Goo00<007oo00000Woo00@007oo000000Aoo`03001oo`00
00=oo`800006Ool007ooOol007oo0P0017oo00<007oo00000Woo00H007oo000007oo0002Ool00`00
Ool00005Ool20002Ool01000Ool0000017oo00<007oo000017oo0P0000Ioo`00Oomoo`00Ool20004
Ool20002Ool01P00Ool00000Ool0009oo`03001oo`0000Eoo`03001oo`00009oo`04001oo`000004
Ool00`00Oomoo`0100000003001oo`000?l00:/0009oo`40000000<007ooOol00goo0P0017oo0P00
00=oo`00Ool00goo0P000goo0P0000=oo`00Ool00goo0P0000Aoo`00Oomoo`8000Eoo`03001oo`00
009oo`04001oo`000004Ool00`00Ool00004Ool200000goo001oo`02Ool00`00Ool00002Ool40004
Ool200001goo001oogoo001oo`0000Eoo`03001oo`00009oo`04001oo`000004Ool20004Ool20000
0goo001oo`03Ool20003Ool200000goo001oo`03Ool2000017oo001oogoo0P001Goo00<007oo0000
0Woo00@007oo000000Aoo`03001oo`0000Aoo`800003Ool007oo009oo`03001oo`00009oo`@000Ao
o`800007Ool007ooOol007oo00001Goo00<007oo00000Woo00@007oo000000Aoo`8000Aoo`800003
Ool007oo00=oo`8000=oo`800003Ool007oo00=oo`<0009oo`03001oo`0000Eoo`03001oo`00009o
o`04001oo`000004Ool00`00Ool00004Ool200000goo001oo`02Ool00`00Ool00002Ool200000goo
001oo`03Ool200001goo001oogoo001oo`0000Eoo`03001oo`00009oo`800003Ool007oo00=oo`80
00Aoo`800003Ool007oo00=oo`8000=oo`800003Ool007oo00=oo`<0009oo`03001oo`0000Eoo`03
001oo`00009oo`04001oo`000004Ool00`00Ool00004Ool200000goo001oo`02Ool00`00Ool00002
Ool200000goo001oo`03Ool200001goo001oogoo001oo`0000Eoo`03001oo`00009oo`800003Ool0
07oo0040000000D007ooOomoo`0000Aoo`03001oo`00009oo`06001oo`00001oo`000Woo00<007oo
000017oo0P0000Moo`00Oomoo`00Ool00002Ool00`00Ool00002Ool01000Ool007oo0P0000Ioo`00
Oomoo`00Ool20003Ool200001Woo001oogoo001oo`800004Ool007oo0002Ool01000Oomoogoo0P00
00Ioo`00Oomoo`00Ool200000goo001oo`0200001Woo000007oo001oo`800004Ool007oo0002Ool0
0`00Oomoo`02Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`03001oo`0000Aoo`800007Ool0
07ooOol007oo00000Woo00<007oo00000Woo00@007oo001oo`800006Ool007ooOol007oo0P000goo
0P0000Ioo`00Oomoo`00Ool2000017oo001oo`000Woo00@007ooOomoo`800006Ool007ooOol007oo
0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool2000017oo001oo`000Woo00@007ooOomoo`800006
Ool007ooOol007oo0P0000Moo`00Oomoo`00Ool00004Ool2000017oo001oo`000Woo00L007ooOol0
07oo001oo`0200000goo001oo`0200001Woo001oogoo001oo`8000=oo`800007Ool007ooOol007oo
00000Woo00<007oo00000Woo00@007ooOomoo`800006Ool007ooOol007oo0P0000=oo`00Ool00P00
00Ioo`00001oo`00Ool2000017oo001oo`000Woo00@007ooOomoo`800006Ool007ooOol007oo0P00
00Moo`00Oomoo`00Ool00004Ool2000017oo001oo`000Woo00L007ooOol007oo001oo`0200000goo
001oo`0200001Woo001oogoo001oo`8000=oo`800007Ool007ooOol007oo00000Woo00<007oo0000
0Woo00@007ooOomoo`800006Ool007ooOol007oo0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool2
00001Goo001oo`00Ool00@0000000`00Ool0000900000goo0000000I00000goo00000002000017oo
000007oo600000=oo`000000A`0000=oo`0000000P0000=oo`0000006@0000=oo`0000001@0000=o
o`000000?`0000=oo`0000000P0000=oo`0000006@0000=oo`0000001@0000=oo`0000005P0000=o
o`0000009P0000=oo`0000007P0000=oo`0000007P0000Aoo`00001oo`40000000<007oo0000o`00
[0000Goo0@0000000`00Ool0003o002/0001Ool100000003001oo`0001L00003Ool0000001h00003
Ool0000001h00003Ool0000000D00003Ool0000001h00004Ool00000OolM00000goo0000000N0000
0goo0000000N00000goo0000000500000goo0000000N00000goo0000000N00000goo0000000N0000
0goo0000000500000goo0000000N000017oo000007oo7@0000=oo`0000003P000Goo0@0000001@00
Ool00000Ool00P0000=oo`00Ool00P0000=oo`00Ool00P0000Aoo`000000009oo`07001oogoo001o
o`00Ool00P000goo0P0000Ioo`00001oo`00Ool200000goo001oo`0200000goo00000003Ool01`00
Oomoo`00Ool007oo00800003Ool007oo00800006Ool00000Ool007oo0P0000Ioo`00Oomoo`00Ool2
0003Ool2000017oo001oo`000Woo00@007oo001oo`800003Ool0000000=oo`800006Ool00000Ool0
07oo0P0000=oo`00Ool00P0000Aoo`00Ool0009oo`07001oogoo001oo`00Ool00P000goo0P0000Io
o`00001oo`00Ool200000goo001oo`0200000goo00000003Ool01`00Oomoo`00Ool007oo00800003
Ool007oo00800006Ool00000Ool007oo0P0000Ioo`00Oomoo`00Ool20003Ool01P00Oomoo`00Ool0
009oo`04001oo`00Ool200000goo00000003Ool200001Woo000007oo001oo`800003Ool007oo0080
0004Ool007oo0002Ool01`00Oomoo`00Ool007oo008000=oo`800006Ool00000Ool007oo0P0000=o
o`00Ool00P0000=oo`0000000goo00L007ooOol007oo001oo`0200000goo001oo`0200001Woo0000
07oo001oo`800006Ool007ooOol007oo0P000goo00L007ooOol007oo001oo`0200000goo001oo`02
00000goo00000003Ool200001Woo000007oo001oo`800003Ool007oo00800004Ool007oo0002Ool0
0`00Ool00002Ool01000Ool000000goo0P0000Ioo`00001oo`00Ool200000goo001oo`0200000goo
001oo`03Ool01`00Oomoo`00Ool007oo00800003Ool007oo00800006Ool00000Ool007oo0P0000Io
o`00Oomoo`00Ool20003Ool01`00Oomoo`00Ool007oo00800003Ool007oo00800003Ool0000000Ao
o`40000000D007ooOomoo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00<00005
Ool007oo001oo`020002Ool00`00Ool00002Ool01P00Oomoo`00Ool0009oo`06001oo`00001oo`00
0Woo00D007oo001oo`00009oo`<0009oo`03001oo`00009oo`06001oogoo001oo`000Woo00H007oo
000007oo0002Ool00`00Ool00002Ool00`00Ool000020002Ool01P00Ool00000Ool0009oo`03001o
o`00009oo`06001oogoo001oo`000Woo00<007oo00000Woo00<007ooOol00P000Woo00H007oo0000
07oo0002Ool00`00Ool00002Ool01P00Oomoo`00Ool0009oo`06001oo`00001oo`000Woo0P000Woo
00<007ooOol00`000Woo00<007oo00000Woo00H007ooOol007oo0002Ool01P00Ool00000Ool0009o
o`04001oo`00Ool2000017oo000000000Woo00H007oo000007oo0002Ool00`00Ool00002Ool01P00
Oomoo`00Ool0009oo`03001oo`00009oo`03001oogoo0080009oo`06001oo`00001oo`000Woo00<0
07oo00000Woo00H007ooOol007oo0002Ool01P00Ool00000Ool0009oo`80009oo`03001oogoo00<0
009oo`03001oo`00009oo`06001oogoo001oo`000Woo00H007oo000007oo0002Ool01@00Ool007oo
00000Woo0`000Woo00H007oo000007oo0002Ool00`00Ool00002Ool01P00Oomoo`00Ool0009oo`03
001oo`00009oo`03001oo`000080009oo`06001oo`00001oo`000Woo00<007oo00000Woo00H007oo
Ool007oo0002Ool01P00Ool00000Ool0009oo`80009oo`06001oogoo001oo`000Woo00<007oo0000
0Woo00H007ooOol007oo0002Ool01P00Ool00000Ool0009oo`<00004Ool007ooOol30002Ool01P00
Ool00000Ool0009oo`04001oo`00Ool100000003001oo`0001l00003Ool0000001T00003Ool00000
00X00003Ool0000000X00003Ool0000002D00003Ool0000000X00003Ool0000002H00003Ool00000
00X00003Ool0000002D00003Ool0000000X00003Ool0000002H00003Ool0000000X00003Ool007oo
02D00003Ool0000000X00003Ool0000002H00003Ool0000000`00003Ool000000100005oo`400000
00@007ooOol0009oo`03001oo`0000Eoo`03001oo`00009oo`04001oo`000004Ool20004Ool20000
1Woo001oogoo001oo`8000Aoo`03001oo`00009oo`06001oo`00001oo`000Woo0P001Goo00<007oo
00000Woo00@007oo000000Aoo`03001oo`0000Aoo`800004Ool007ooOol200000goo001oo`02Ool0
0`00Ool00002Ool01P00Ool00000Ool0009oo`03001oo`0000Eoo`03001oo`00009oo`04001oo`00
0003Ool00`00Ool00004Ool200001Woo001oogoo001oo`8000Aoo`03001oo`00009oo`06001oo`00
001oo`000Woo0P001Goo00<007oo00000Woo00@007oo000000Aoo`03001oo`0000Aoo`800004Ool0
07ooOol200000goo001oo`02Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`03001oo`0000Eo
o`03001oo`00009oo`04001oo`000003Ool00`00Ool00004Ool200001Woo001oogoo001oo`8000Ao
o`03001oo`00009oo`03001oo`00008000=oo`8000Eoo`03001oo`00009oo`04001oo`000004Ool0
0`00Ool00004Ool2000017oo001oogoo0P0000=oo`00Ool00Woo00<007oo00000Woo00H007oo0000
07oo0002Ool00`00Ool00005Ool00`00Ool00002Ool200000goo001oo`02Ool00`00Ool00004Ool2
00001Woo001oogoo001oo`8000Aoo`03001oo`00009oo`03001oo`000080009oo`03001oo`0000Eo
o`03001oo`00009oo`04001oo`000004Ool00`00Ool00004Ool2000017oo001oogoo0`0017oo00<0
07oo00000Woo00D007oo000007oo0040000000<007ooOol00P0000=oo`00Ool00P0000=oo`00Ool0
0P0000Ioo`00001oo`00Ool400000goo001oo`0200000goo001oo`0200001Woo000007oo001oo`80
0003Ool0000000800006Ool00000Ool007oo0P0000Aoo`000000009oo`04001oo`00Ool200001Woo
000007oo001oo`800006Ool007ooOol007oo0P0000=oo`00Ool00P0000Qoo`00001oo`00Ool007oo
100000Ioo`00001oo`00Ool200001Woo000007oo001oo`800003Ool007oo00800006Ool00000Ool0
07oo100000=oo`00Ool00P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200000goo000000020000
1Woo000007oo001oo`800005Ool00000001oo`0200000goo001oo`0200001Woo000007oo001oo`80
0006Ool007ooOol007oo0P0000=oo`00Ool00P0000Qoo`00001oo`00Ool007oo100000Ioo`00001o
o`00Ool200001Woo000007oo001oo`800003Ool007oo00800008Ool00000Ool007oo001oo`800003
Ool007oo00800003Ool007oo00800006Ool00000Ool007oo0P0000=oo`0000000P0000Ioo`00001o
o`00Ool200001Goo001oo`00Ool00P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200001Woo001o
ogoo001oo`800003Ool007oo00800004Ool000000002Ool00`00Ool0000300001Woo000007oo001o
o`800006Ool00000Ool007oo0P0000=oo`00Ool00P0000Uoo`00001oo`00Ool007oo00000Woo00L0
07oo000007oo001oo`0200001Woo000007oo001oo`800003Ool0000000800006Ool00000Ool007oo
0P0000Eoo`00Ool007oo00800003Ool007oo00800006Ool00000Ool007oo0P0000Ioo`00Oomoo`00
Ool200000goo001oo`0200001Goo00000000Ool00P0000=oo`0000000P0000Ioo`00001oo`00Ool2
0001Ool100000003001oo`000?l00:`0005oo`40000000<007ooOol0ogoo[Goo0@00003o002a0000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007oo0000ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000@007ooOol0009oo`03001oo`00009oo`03001oogoo0080009o
o`03001oogoo009oo`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool00`00Oomoo`02Ool0
2000Oomoo`00Ool007oo0004Ool01P00Oomoo`00Ool0009oo`06001oogoo001oo`000Woo00<007oo
Ool00Woo00P007ooOol007oo001oo`000Woo00<007oo00000Woo00<007ooOol00Woo00H007ooOol0
07oo0002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`05001oo`00Ool00002Ool00`00Oomo
o`02Ool01P00Oomoo`00Ool0009oo`06001oogoo001oo`000Woo00<007ooOol00Woo00<007ooOol0
0P000Woo00<007ooOol00Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009oo`03001oogoo
009oo`08001oogoo001oo`00Ool0009oo`03001oo`00009oo`03001oogoo009oo`06001oogoo001o
o`000Woo00<007ooOol00Woo00H007ooOol007oo0002Ool01@00Ool007oo00000Woo00<007ooOol0
0Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009oo`03001oogoo009oo`03001oogoo0080
009oo`03001oogoo009oo`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool00`00Oomoo`02
Ool02000Oomoo`00Ool007oo0002Ool00`00Ool00002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0
009oo`03001oogoo009oo`08001oogoo001oo`00Ool0009oo`03001oo`00009oo`03001oogoo009o
o`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool00`00Oomoo`02Ool01@00Ool007oo0000
0Woo00<007ooOol00Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009oo`03001oogoo009o
o`03001oogoo0080009oo`06001oogoo001oo`000Woo00<007ooOol00Woo00H007ooOol007oo0002
Ool00`00Oomoo`02Ool100000003001oo`0000<00003Ool0000000<00003Ool0000000<00003Ool0
000000<00003Ool007oo00D00003Ool007oo00@00003Ool0000000<00003Ool007oo00@00003Ool0
000000@00003Ool0000000<00003Ool007oo00@00003Ool0000000<00003Ool007oo00H00003Ool0
000000800003Ool0000000<00003Ool007oo00D00003Ool0000000@00003Ool0000000T00003Ool0
000000<00003Ool007oo00D00003Ool007oo00@00003Ool0000000<00004Ool00000Ool300000goo
0000000400000goo0000000300000goo001oo`0400000goo0000000300000goo001oo`03000017oo
000007oo100000=oo`0000000`0000=oo`00Ool01@0000=oo`000000100000=oo`0000002@0000=o
o`0000000`0000=oo`00Ool01@0000=oo`00Ool0100000=oo`0000000`0000=oo`000000100000=o
o`000000100000=oo`0000000`0000=oo`00Ool0100000=oo`0000000`0000=oo`00Ool0100000=o
o`00Ool0100000=oo`0000000`0000=oo`00Ool01@0000=oo`000000100000=oo`000000100000=o
o`0000000P0000=oo`0000000`0000=oo`00Ool01@0000=oo`00Ool0100000=oo`0000002P0000=o
o`000000100000=oo`0000000`0000=oo`00Ool0100000=oo`0000000`0000Aoo`00001oo`<00003
Ool007oo00@00003Ool0000000<00003Ool007oo00D00004Ool00000Ool100000004001oo`00Ool4
00001Woo000007oo001oo`H0009oo`04001oo`00Ool200001Woo000007oo001oo`800003Ool00000
0080009oo`04001oo`00Ool400000goo001oo`0200000goo0000000200001Woo000007oo001oo`80
0003Ool000000080009oo`04001oo`00Ool200001Goo00000000Ool00P0000=oo`0000000P000Woo
00@007oo001oo`800006Ool00000Ool007oo0P0000=oo`0000000P0000=oo`0000000P0000=oo`00
Ool010000Woo00@007oo001oo`800006Ool00000Ool007oo0P0000=oo`0000000P000Woo00@007oo
001oo`@00003Ool007oo00800003Ool0000000800006Ool00000Ool007oo0P0000=oo`0000000P00
0Woo00@007oo001oo`<00004Ool00000Ool200000goo000000020002Ool01000Ool007oo0P0000Io
o`00001oo`00Ool200000goo0000000200000goo0000000200000goo001oo`040002Ool01000Ool0
07oo0P0000Ioo`00001oo`00Ool200000goo000000020002Ool01000Ool007oo100000=oo`00Ool0
0P0000=oo`0000000P0000Ioo`00001oo`00Ool200000goo000000020002Ool01000Ool007oo1000
00=oo`00Ool00P0000=oo`0000000P000Woo00@007oo001oo`800006Ool00000Ool007oo0P0000=o
o`0000000P0000Eoo`00000007oo00800003Ool000000080009oo`04001oo`00Ool200001Woo0000
07oo001oo`800003Ool000000080009oo`<00003Ool007oo00800003Ool007oo00800003Ool00000
00800006Ool00000Ool007oo0P0000=oo`0000000P000Woo00@007oo001oo`@00003Ool007oo0080
0003Ool000000080009oo`04001oo`00Ool2000027oo000007oo001oo`00Ool100000005001oogoo
001oo`02000017oo000007oo0`0000Ioo`00001oo`00Ool200000goo001oo`0200001Woo000007oo
001oo`800003Ool007oo00800006Ool00000Ool007oo0`0000Aoo`00001oo`800003Ool007oo0080
0006Ool00000Ool007oo0P0000Ioo`00001oo`00Ool200000goo001oo`0200001Goo00000000Ool0
0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200001Woo000007oo001oo`800003Ool007oo0080
0004Ool00000Ool300001Woo000007oo001oo`800003Ool007oo00800006Ool00000Ool007oo0P00
00=oo`00Ool00P0000Aoo`00001oo`<00003Ool007oo00800006Ool00000Ool007oo0P0000Ioo`00
001oo`00Ool200001Woo000007oo001oo`800003Ool007oo00<00004Ool00000Ool200000goo001o
o`0200001Woo000007oo001oo`800006Ool00000Ool007oo0P0000=oo`00Ool00P0000Eoo`000000
07oo00800006Ool00000Ool007oo0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200000goo001o
o`02000017oo000007oo0`0000Ioo`00001oo`00Ool200000goo001oo`0200001Woo000007oo001o
o`800006Ool00000Ool007oo0P0000=oo`00Ool00`0000Aoo`00001oo`800003Ool007oo00800006
Ool00000Ool007oo0P0000Ioo`00001oo`00Ool200000goo001oo`0200001Goo00000000Ool00P00
00Ioo`00001oo`00Ool200000goo001oo`0200001Woo000007oo001oo`800003Ool007oo00800004
Ool00000Ool300001Woo000007oo001oo`800003Ool007oo00800006Ool00000Ool007oo0P0000Io
o`00001oo`00Ool200001goo00000000Ool007oo00800006Ool00000Ool007oo0P0000Ioo`00001o
o`00Ool200001Woo000007oo001oo`80005oo`40000000D007ooOomoo`0000Eoo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Ao
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Eo
o`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oo`0000Eoo`03001oogoo00=oo`40000000<007oo00002Goo00<007oo000017oo00@007oo
Ool000Uoo`04001oogoo000;Ool00`00Oomoo`02Ool01000Oomoo`002Goo00@007ooOol000Aoo`04
001oogoo0009Ool00`00Ool0000<Ool00`00Oomoo`02Ool01000Oomoo`002Goo00<007oo000017oo
00@007ooOol000Uoo`04001oogoo000;Ool00`00Oomoo`02Ool01000Oomoo`002Goo00@007ooOol0
00Aoo`04001oogoo0009Ool00`00Ool0000<Ool00`00Oomoo`02Ool01000Oomoo`002Goo00<007oo
000017oo00@007ooOol000Uoo`04001oogoo000;Ool00`00Oomoo`02Ool01000Oomoo`002Goo00@0
07ooOol000Aoo`04001oogoo0008Ool01000Oomoo`0037oo00<007ooOol00Woo00@007ooOol000Uo
o`03001oo`0000Aoo`04001oogoo0009Ool01000Oomoo`002goo00<007ooOol00Woo00@007ooOol0
00Uoo`04001oogoo0004Ool01000Oomoo`0027oo00@007ooOol000aoo`03001oogoo009oo`04001o
ogooOol100000003001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Uoo`03
001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03
001oogoo00Eoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Aoo`8000]oo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Aoo`8000]oo`03001oogoo00Eoo`03
001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo00Eoo`03
001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Aoo`8000]oo`03001oogoo00Eoo`03001oogoo
00Ioo`40000000<007oo000027oo00D007ooOomoo`00011oo`04001oogoo0009Ool00`00Oomoo`04
Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`05Ool01000Oomo
o`0027oo00D007ooOomoo`00011oo`04001oogoo0009Ool00`00Oomoo`04Ool01000Oomoo`002Goo
00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`05Ool01000Oomoo`0027oo00@007ooOol0
015oo`04001oogoo0008Ool00`00Oomoo`05Ool01000Oomoo`002Goo00@007ooOol0011oo`04001o
ogoo0009Ool00`00Oomoo`05Ool01000Oomoo`0027oo00@007ooOol0015oo`04001oogoo0008Ool0
0`00Oomoo`05Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`05
Ool01000Oomoogoo0@0000001@00Oomoogoo00001Goo00<007ooOol00goo00<007ooOol00goo00<0
07oo00001Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007oo00001Goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol00goo00<007oo00001Goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007oo00001Goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol00goo00<007oo00001Goo00<007ooOol017oo00<007ooOol00goo00<0
07ooOol00goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<0
07oo00001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007oo00001Goo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol00goo00<007oo00001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<0
07ooOol017oo0@0000000`00Oomoo`06Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007oo
Ool00Woo00D007ooOomoo`0000=oo`03001oogoo00Ioo`04001oogoo0007Ool00`00Oomoo`06Ool0
1@00Oomoogoo00001Woo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Ioo`05001o
ogooOol00007Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol00Woo00D007ooOomo
o`0000=oo`03001oogoo00Ioo`04001oogoo0007Ool00`00Oomoo`06Ool01@00Oomoogoo00001Woo
00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Ioo`05001oogooOol00006Ool00`00
Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo
00Eoo`05001oogooOol00007Ool00`00Oomoo`06Ool01@00Oomoogoo00001Woo00<007ooOol00Woo
00D007ooOomoo`0000=oo`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`06Ool01@00
Oomoogoo00001goo00<007ooOol00Woo00D007ooOomoo`0000=oo`03001oogoo00Eoo`05001oogoo
Ool00007Ool00`00Oomoo`06Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00D007ooOomoo`00
00=oo`03001oogoo00Ioo`06001oogooOol007oo0@0000001000Ool007oo100000=oo`0000001000
00=oo`0000000P000Woo1P0000=oo`0000000`0000=oo`00Ool010000Woo1@0000=oo`0000000`00
00=oo`00Ool010000Woo1P0000=oo`0000000P000Woo1@0000=oo`0000000`0000=oo`00Ool01000
0Woo1P0000=oo`0000000`0000=oo`00Ool0100000=oo`000000100000=oo`0000000P000Woo1P00
00=oo`0000000`0000=oo`00Ool010000Woo1@0000=oo`0000000`0000=oo`00Ool010000Woo1P00
00=oo`0000000P000Woo1@0000=oo`0000000`0000=oo`00Ool010000Woo1P0000=oo`0000000`00
00=oo`00Ool0100000=oo`000000100000=oo`0000000P000Woo1P0000=oo`0000000`0000=oo`00
Ool0100000=oo`000000100000=oo`0000000`0000=oo`00Ool010000Woo1P0000=oo`0000000P00
0Woo1@0000=oo`0000000`0000=oo`00Ool010000Woo1P0000=oo`0000000`0000=oo`00Ool00`00
0Woo1P0000=oo`0000000P000Woo1P0000=oo`0000000`0000=oo`00Ool0100000=oo`0000001000
00=oo`0000000`0000=oo`00Ool010000Woo1P0000=oo`0000000P000Woo1@0000=oo`0000000`00
00=oo`00Ool010000Woo1P0000=oo`0000000`000Woo0@0000001000Oomoo`000Woo00D007oo001o
o`00009oo`03001oo`00009oo`06001oo`00001oo`000Woo00<007oo00000Woo00H007oo000007oo
0002Ool00`00Ool000020002Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`07001oo`00001o
o`00Ool00P0000Ioo`00Oomoo`00Ool200001Woo001oo`00Ool0009oo`06001oogoo001oo`000Woo
00H007oo000007oo0002Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`05001oo`00Ool00002
Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`03001oo`00009oo`06001oo`00001oo`000Woo
00<007oo00000P000Woo00<007oo00000Woo00H007oo000007oo0002Ool01`00Ool00000Ool007oo
00800006Ool007ooOol007oo0P0000Ioo`00Ool007oo0002Ool01P00Oomoo`00Ool0009oo`06001o
o`00001oo`000Woo00<007oo00000Woo00H007oo000007oo0002Ool300001goo001oogoo001oo`00
009oo`06001oo`00001oo`000Woo00<007oo00000Woo00H007oo000007oo0002Ool01@00Ool007oo
00000Woo00<007oo00000Woo00H007oo000007oo0002Ool01`00Ool00000Ool007oo00800006Ool0
07ooOol007oo0`000Woo00<007oo00000Woo00H007oo000007oo0002Ool01P00Ool00000Ool0009o
o`03001oo`00009oo`09001oo`00001oo`00Ool007oo00800007Ool007ooOol007oo00000Woo00H0
07oo000007oo0002Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`05001oo`00Ool00002Ool0
0`00Ool00002Ool01P00Ool00000Ool0009oo`07001oo`00001oo`00Ool00P0000Ioo`00Oomoo`00
Ool30002Ool00`00Ool00002Ool01P00Ool00000Ool0009oo`06001oo`00001oo`000Woo00<007oo
00000Woo00D007oo000007oo0040000000<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol017oo
0P002goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007oo
Ool02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol017oo0P002goo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol017oo0P002goo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol017oo0P002goo00<007ooOol01Goo
00<007ooOol01Goo0@0000001000Oomoo`0027oo00D007ooOomoo`00011oo`04001oogoo000@Ool0
1000Oomoo`002Goo00@007ooOol0011oo`04001oogoo000AOol01000Oomoo`0027oo00D007ooOomo
o`00011oo`04001oogoo000@Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo000AOol0
1000Oomoo`0027oo00@007ooOol0015oo`04001oogoo000@Ool01000Oomoo`002Goo00@007ooOol0
011oo`04001oogoo000AOol01000Oomoo`0027oo00@007ooOol0015oo`04001oogoo000@Ool01000
Oomoo`002Goo00@007ooOol0011oo`04001oogoo000AOol00`00Oomoo`0100000003001oogoo009o
o`03001oogoo00moo`03001oo`00019oo`8000aoo`03001oogoo011oo`80019oo`03001oo`0000ao
o`03001oogoo00moo`03001oo`00019oo`8000aoo`03001oogoo011oo`80019oo`03001oo`0000ao
o`03001oogoo00moo`03001oo`00019oo`8000aoo`03001oogoo011oo`80019oo`03001oo`0000]o
o`03001oogoo011oo`03001oo`00019oo`8000aoo`03001oogoo011oo`80019oo`03001oo`0000Yo
o`40000000<007ooOol027oo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo00<007ooOol00goo00<007oo
Ool02Woo00<007ooOol00goo0@0000000`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`09Ool0
0`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`08Ool0
0`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`02Ool100000003001oo`0000=oo`03001oogoo
00eoo`03001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<007ooOol03Goo00D007ooOomoo`00
011oo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000?Ool00`00Oomoo`0>Ool00`00
Oomoo`0=Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomoo`00
00moo`03001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000?Ool00`00Oomoo`0>Ool00`00
Oomoo`0?Ool100000003001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uo
o`03001oogoo019oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`8001=oo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Uoo`8001=oo`03001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uo
o`03001oogoo019oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`8001=oo`03001o
ogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00Uoo`03001o
ogoo00Eoo`03001oogoo00Uoo`8000Qoo`40000000<007ooOol017oo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol07Woo00<007ooOol017oo00<007ooOol02Woo00<007ooOol07Woo00<007oo
Ool01Goo00<007ooOol02Woo00<007ooOol07Woo00<007ooOol017oo00<007ooOol02Woo00<007oo
Ool07Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol07Woo00<007ooOol017oo00<007oo
Ool02Woo00<007ooOol07Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol07Woo00<007oo
Ool017oo00<007ooOol02Woo00<007ooOol06goo0@0000000`00Oomoo`0@Ool00`00Oomoo`0<Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool00`00Ool0000BOol00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`09Ool0
0`00Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Ool0000AOol0
0`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Ool0000BOol00`00Oomoo`0;Ool0
0`00Oomoo`03Ool00`00Oomoo`0:Ool00`00Ool0000AOol00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Ool0000BOol00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool0
1000Ool007oo0@0000000`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08
Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool100000005001o
ogooOol00004Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`02Ool0
0`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol0
0`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`03Ool0
0`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool0
0`00Oomoo`0BOol00`00Oomoo`09Ool100000003001oogoo00eoo`03001oogoo00Yoo`03001oogoo
00Eoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo
015oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo
00Yoo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo
00Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
00Aoo`40000000<007ooOol03Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Woo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<0
07ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<0
07ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<0
07ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol017oo0@0000001@00Oomoogoo
00000goo00<007ooOol07goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol07Woo00<007oo
Ool03Goo00D007ooOomoo`00021oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo01ioo`03
001oogoo00eoo`05001oogooOol0000POol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0N
Ool00`00Oomoo`0=Ool01@00Oomoogoo000087oo00<007ooOol03Goo00<007ooOol00Woo00<007oo
Ool07Woo00<007ooOol037oo0@0000000`00Oomoo`0BOol01000Oomoo`0057oo00<007ooOol06goo
00@007ooOol001=oo`03001oogoo01]oo`04001oogoo000DOol00`00Oomoo`0KOol01000Oomoo`00
4goo00<007ooOol06goo00@007ooOol001Aoo`03001oogoo01]oo`04001oogoo000COol00`00Oomo
o`0KOol01000Oomoo`0057oo00<007ooOol06Woo00D007ooOomoo`0001=oo`03001oogoo00Uoo`40
000000<007ooOol02Goo00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<007ooOol0
4Woo0P0057oo00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<0
07ooOol04Woo0P0057oo00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol0
27oo00<007ooOol04Woo0P0057oo00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<0
07ooOol027oo00<007ooOol04Goo00<007oo000057oo0@000Goo0@0000000`00Oomoo`0:Ool00`00
Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00
Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00
Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00
Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00
Oomoo`03Ool01000Oomoogoo0@0000000`00Oomoo`03Ool20007Ool00`00Oomoo`08Ool20007Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`08Ool20007Ool00`00Oomoo`08Ool00`00Ool0
0007Ool01@00Oomoogoo00001goo00<007ooOol027oo00<007oo00001goo00<007ooOol027oo0P00
1goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol027oo0P001goo00<007ooOol027oo00<0
07oo00001Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol027oo00<007oo00001goo00<0
07ooOol027oo0P001goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol027oo0P001goo00<0
07ooOol027oo00<007oo00001Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol027oo00<0
07oo00001goo00<007ooOol027oo0P001goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
27oo0P001goo00<007ooOol027oo00<007oo00001Woo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol01Woo0@0000000`00Ool0000?Ool01@00Oomoogoo000047oo00D007ooOomoo`0000]oo`03
001oogoo00ioo`05001oogooOol0000?Ool01@00Oomoogoo000037oo00<007ooOol03Goo00D007oo
Oomoo`00011oo`05001oogooOol0000;Ool00`00Oomoo`0>Ool01@00Oomoogoo00003goo00D007oo
Oomoo`0000aoo`03001oogoo00eoo`05001oogooOol0000@Ool01@00Oomoogoo00002goo00<007oo
Ool03Woo00D007ooOomoo`0000moo`05001oogooOol0000<Ool00`00Oomoo`0=Ool01@00Oomoogoo
00003goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol03Woo00D007ooOomoo`0000moo`05
001oogooOol0000=Ool100000003001oogoo00Moo`03001oogoo015oo`03001oogoo019oo`03001o
ogoo00Uoo`03001oogoo019oo`03001oogoo015oo`8000]oo`03001oogoo015oo`03001oogoo019o
o`03001oogoo00Uoo`03001oogoo019oo`03001oogoo015oo`8000]oo`03001oogoo015oo`03001o
ogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo015oo`8000]oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo015oo`8000Aoo`400000
00<007ooOol00Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol017oo
00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol027oo0@0000000`00Oomo
o`07Ool01000Oomoo`001Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool01goo00<007oo00001goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00@007ooOol000Ioo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Qoo`03001oo`0000Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Moo`03001o
ogoo00Moo`04001oogoo0006Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`08Ool00`00Ool00007Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00
Oomoo`07Ool01000Oomoo`001Woo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007oo00001goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<0
07ooOol00@0000000`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`0AOol00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0BOol0
0`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool0
0`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`09Ool0
0`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol0
0`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool100000004001oogoo
000<Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomo
o`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomo
o`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`05Ool100000004001oogoo000COol00`00Oomoo`0:Ool00`00Oomoo`05Ool0
0`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool0
0`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool0
0`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool100000003001oogoo
00Qoo`05001oogooOol0000?Ool00`00Oomoo`0>Ool01@00Oomoogoo00002goo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol03Woo00@007ooOol000aoo`05001oogooOol0000?Ool00`00Oomo
o`0>Ool01@00Oomoogoo00002goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo00@0
07ooOol000aoo`05001oogooOol0000?Ool00`00Oomoo`0>Ool01@00Oomoogoo00002goo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol000aoo`05001oogooOol0000?Ool0
0`00Oomoo`0>Ool01000Oomoo`0037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo
00@007ooOol000Aoo`40000000<007ooOol047oo00<007ooOol01Woo00<007ooOol027oo00<007oo
Ool07Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol07Woo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol07Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol07Woo00<007oo
Ool01goo00<007ooOol027oo00<007ooOol07Woo00<007ooOol01Woo00<007ooOol027oo00<007oo
Ool07Woo00<007ooOol01goo00<007ooOol027oo00<007ooOol07Woo00<007ooOol01Woo00<007oo
Ool027oo00<007ooOol03goo0@0000000`00Oomoo`03Ool2000BOol00`00Oomoo`0BOol00`00Oomo
o`09Ool00`00Ool0000BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool2000BOol00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Ool0000BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool2000BOol00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Ool0000BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool2000BOol0
0`00Oomoo`0BOol00`00Oomoo`09Ool00`00Ool0000BOol00`00Oomoo`0AOol00`00Oomoo`07Ool1
00000003001oogoo00]oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo
019oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo
01Qoo`03001oogoo019oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo01Qoo`03001oogoo019oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo
015oo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo
00eoo`40000000<007ooOol04Goo0P007goo00<007oo00004Woo0P007goo0P004Woo0P007goo0P00
4goo0P007goo0P004Woo0P007goo0P004goo0P007goo0P004Woo0P007goo0P004Woo00<007oo0000
7goo0P000Goo0@0000000`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0A
Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0EOol00`00Oomoo`06
Ool00`00Oomoo`0AOol00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`0E
Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0B
Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0EOol00`00Oomoo`06
Ool00`00Oomoo`0<Ool100000003001oogoo00Uoo`03001oogoo00ioo`03001oogoo019oo`03001o
ogoo00eoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo00eoo`03001oogoo00ioo`03001o
ogoo019oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo015oo`03001oogoo00eoo`03001o
ogoo00ioo`03001oogoo019oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo015oo`03001o
ogoo00eoo`03001oogoo00ioo`03001oogoo019oo`03001oogoo00eoo`03001oogoo00ioo`03001o
ogoo015oo`03001oogoo00Aoo`40000000<007ooOol03Woo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo
00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01Goo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo
00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo
00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo
0@0000001000Oomoogoo0P004Woo00<007ooOol07Woo0P004goo00<007ooOol07Woo00<007ooOol0
4Goo00<007ooOol07Woo0P004goo00<007ooOol07Woo00<007ooOol04Goo00<007ooOol07Woo0P00
4goo00<007ooOol07Woo00<007ooOol04Goo00<007ooOol07Woo0P004goo00<007ooOol07Goo0@00
00000`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0G
Ool00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0A
Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`04
Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0F
Ool00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`09
Ool100000003001oogoo00ioo`03001oogoo00aoo`03001oogoo019oo`03001oogoo00moo`03001o
ogoo00aoo`03001oogoo015oo`03001oogoo00moo`03001oogoo00aoo`03001oogoo019oo`03001o
ogoo00moo`03001oogoo00aoo`03001oogoo015oo`03001oogoo00moo`03001oogoo00aoo`03001o
ogoo019oo`03001oogoo00moo`03001oogoo00aoo`03001oogoo015oo`03001oogoo00moo`03001o
ogoo00aoo`03001oogoo015oo`03001oogoo011oo`03001oogoo00aoo`03001oogoo015oo`04001o
ogooOol100000003001oogoo00Aoo`03001oo`0000Yoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`08Ool00`00Oomoo`07Ool00`00Ool00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool00`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol027oo00<007ooOol01goo00<007oo00002Goo00<007ooOol027oo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool100000003001oogoo01=oo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo00=oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001o
ogoo01Qoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Uoo`03001o
ogoo009oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo009oo`03001o
ogoo00Ioo`40000000<007oo000037oo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Goo
00<007ooOol02Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04goo
0@0000000`00Ool0000COol00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`09Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomo
o`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0COol100000003
001oogoo00]oo`03001oogoo01Yoo`05001oogooOol0000DOol00`00Oomoo`0IOol00`00Oomoo`02
Ool00`00Oomoo`0AOol00`00Oomoo`0JOol01@00Oomoogoo000057oo00<007ooOol06Goo00<007oo
Ool00Woo00<007ooOol04Goo00<007ooOol06Woo00D007ooOomoo`0001Aoo`03001oogoo01Uoo`03
001oogoo009oo`03001oogoo015oo`03001oogoo01Yoo`05001oogooOol0000DOol00`00Oomoo`0I
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool100000003001oogoo00Moo`03001oogoo00ioo`04001o
ogoo000POol00`00Oomoo`0>Ool01@00Oomoogoo000087oo00<007ooOol03Woo00@007ooOol0021o
o`03001oogoo00ioo`05001oogooOol0000POol00`00Oomoo`0>Ool01000Oomoo`0087oo00<007oo
Ool03Woo00D007ooOomoo`00021oo`03001oogoo00ioo`04001oogoo000POol00`00Oomoo`0>Ool0
1@00Oomoogoo00006Goo0@0000000`00Oomoo`03Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00
Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00
Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00
Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`03Ool100000003001oogoo00mo
o`80019oo`03001oo`0001ioo`03001oo`00015oo`03001oo`0001moo`80019oo`8001moo`03001o
o`00015oo`03001oo`0001moo`80019oo`8001moo`03001oo`00015oo`03001oo`0001ioo`03001o
o`00019oo`8001moo`80019oo`03001oo`00011oo`40000000<007ooOol00Woo00<007ooOol0;7oo
00<007ooOol00goo00<007ooOol0;Goo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol00goo
00<007ooOol0;Goo00<007ooOol00goo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol0;Goo
00<007ooOol00goo00<007ooOol0;7oo00<007ooOol00goo00<007ooOol0;Goo00@007ooOomoo`40
000000<007ooOol05Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol07Woo00<007ooOol0
0goo00<007ooOol02goo00<007ooOol07Woo00<007ooOol017oo00<007ooOol02goo00<007ooOol0
7Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol07Woo00<007ooOol017oo00<007ooOol0
2goo00<007ooOol07Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol07Woo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol07Woo00<007ooOol00goo00<007ooOol02goo00<007ooOol0
27oo0@0000000`00Oomoo`08Ool00`00Ool0000NOol00`00Oomoo`0BOol2000OOol00`00Oomoo`0A
Ool00`00Ool0000NOol00`00Oomoo`0BOol2000OOol00`00Oomoo`0AOol00`00Ool0000NOol00`00
Oomoo`0BOol2000OOol00`00Oomoo`0AOol00`00Ool0000NOol00`00Oomoo`0BOol2000OOol00`00
Oomoo`09Ool100000003001oogoo01Eoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Mo
o`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Moo`03001oogoo02Uo
o`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Moo`03001oogoo02Uoo`03001oogoo00Io
o`03001oogoo02Uoo`03001oogoo00Moo`03001oogoo01Aoo`40000000D007ooOomoo`00011oo`03
001oogoo01ioo`04001oogoo000@Ool00`00Oomoo`0NOol01@00Oomoogoo00003goo00<007ooOol0
7goo00@007ooOol0011oo`03001oogoo01ioo`04001oogoo000@Ool00`00Oomoo`0OOol01000Oomo
o`0047oo00<007ooOol07Woo00@007ooOol0011oo`03001oogoo01ioo`05001oogooOol0000@Ool0
0`00Oomoo`0NOol00`00Oomoo`0100000003001oogoo00eoo`03001oogoo019oo`05001oogooOol0
000LOol00`00Oomoo`0AOol01@00Oomoogoo000077oo00<007ooOol04Woo00D007ooOomoo`0001ao
o`03001oogoo015oo`05001oogooOol0000LOol00`00Oomoo`0BOol01@00Oomoogoo000077oo00<0
07ooOol04Goo00D007ooOomoo`0001aoo`03001oogoo019oo`05001oogooOol0000LOol00`00Oomo
o`0AOol01@00Oomoogoo00003goo0@0000000`00Oomoo`05Ool00`00Oomoo`0VOol00`00Oomoo`09
Ool00`00Oomoo`0WOol00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0W
Ool00`00Oomoo`09Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomoo`09
Ool00`00Oomoo`0VOol00`00Oomoo`09Ool00`00Oomoo`0WOol00`00Oomoo`04Ool100000003001o
ogoo01Uoo`8001=oo`03001oogoo01ioo`03001oogoo015oo`03001oogoo01ioo`8001=oo`03001o
ogoo01ioo`03001oogoo015oo`03001oogoo01ioo`8001=oo`03001oogoo01ioo`03001oogoo015o
o`03001oogoo01ioo`8001=oo`03001oogoo01ioo`03001oogoo015oo`03001oogoo00Eoo`400000
00<007ooOol01Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol017oo
00<007ooOol05goo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol04Woo
00<007ooOol017oo00<007ooOol05goo00<007ooOol04Goo00<007ooOol01Goo00<007ooOol05Woo
00<007ooOol04Woo00<007ooOol017oo00<007ooOol05goo00<007ooOol04Goo00<007ooOol01Goo
00<007ooOol05Woo00<007ooOol04Woo00<007ooOol017oo00<007ooOol05goo00<007ooOol037oo
0@0000000`00Oomoo`0BOol00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomo
o`0SOol00`00Oomoo`0<Ool00`00Oomoo`0SOol00`00Oomoo`0=Ool00`00Oomoo`0SOol00`00Oomo
o`0<Ool00`00Oomoo`0SOol00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomo
o`0SOol00`00Oomoo`0<Ool00`00Oomoo`0BOol100000004001oogoo000bOol00`00Ool0000cOol0
0`00Ool0000bOol00`00Ool0000cOol00`00Ool0000bOol00`00Ool0000cOol00`00Ool0000bOol0
0`00Ool0000bOol00`00Oomoo`0100000003001oogoo00Qoo`03001oo`0000Uoo`03001oogoo00Qo
o`03001oogoo00Moo`03001oo`00015oo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07
Ool01000Oomoo`004Goo00<007oo00002Goo00<007ooOol027oo00<007ooOol01goo00<007oo0000
4Goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Moo`04001oogoo000AOol00`00Ool0
0009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Ool0000AOol01000Oomoo`002Goo00<007oo
Ool01goo00<007ooOol01goo00@007ooOol0015oo`03001oo`0000Uoo`03001oogoo00Qoo`03001o
ogoo00Moo`03001oo`00015oo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool01000
Oomoo`002Goo0@0000000`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0I
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`0BOol00`00Oomoo`02
Ool00`00Oomoo`0IOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`0B
Ool00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0H
Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomoo`0AOol00`00Oomoo`03
Ool00`00Oomoo`0FOol100000003001oogoo011oo`03001oogoo015oo`03001oogoo00Yoo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo015oo`03001o
ogoo00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo019oo`03001o
ogoo011oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001o
ogoo015oo`03001oogoo015oo`03001oogoo00]oo`03001oogoo015oo`03001oogoo015oo`03001o
ogoo00Yoo`03001oogoo009oo`40000000<007ooOol03goo00<007ooOol04Woo00<007ooOol02Goo
00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo
00<007ooOol02Woo00<007ooOol00Woo0@0000000`00Oomoo`03Ool00`00Oomoo`0FOol00`00Oomo
o`0IOol00`00Oomoo`0FOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomo
o`0FOol00`00Oomoo`0JOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomo
o`0JOol00`00Oomoo`0FOol00`00Oomoo`0IOol00`00Oomoo`0FOol00`00Oomoo`0GOol100000003
001oogoo00Moo`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=
Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00<007ooOol03Goo00<007ooOol03Woo00D007ooOomo
o`00011oo`03001oogoo00eoo`03001oogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool01@00Oomoogoo000047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0011o
o`03001oogoo00eoo`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomo
o`0>Ool01000Oomoo`002Goo0@0000000`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0YOol0
0`00Oomoo`06Ool00`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`06Ool0
0`00Oomoo`0ZOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0ZOol0
0`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0OOol100000004001oogoo
000NOol00`00Ool0000COol00`00Oomoo`0MOol2000DOol00`00Oomoo`0LOol00`00Ool0000COol0
0`00Oomoo`0MOol2000COol00`00Oomoo`0MOol00`00Ool0000COol00`00Oomoo`0MOol2000COol0
0`00Oomoo`0MOol00`00Ool0000COol00`00Oomoo`0MOol2000DOol100000003001oogoo00aoo`03
001oogoo00Aoo`03001oogoo01ioo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01ioo`03
001oogoo00]oo`03001oogoo00=oo`03001oogoo01moo`03001oogoo00]oo`03001oogoo00=oo`03
001oogoo01ioo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01moo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo01ioo`03001oogoo00]oo`03001oogoo00=oo`03001oogoo01ioo`03
001oogoo00aoo`03001oogoo00=oo`03001oogoo01ioo`40005oo`40000000<007ooOol06Goo00<0
07ooOol02goo00<007ooOol00goo00<007ooOol07Woo00<007ooOol02goo00<007ooOol017oo00<0
07ooOol07Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol07Woo00<007ooOol02goo00<0
07ooOol017oo00<007ooOol07Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol07Woo00<0
07ooOol02goo00<007ooOol017oo00<007ooOol07Woo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol07Woo00<007ooOol02goo00<007ooOol017oo00<007ooOol01Goo0@0000000`00Oomoo`04
Ool00`00Ool0000COol00`00Oomoo`0MOol2000DOol00`00Oomoo`0LOol00`00Ool0000COol00`00
Oomoo`0MOol2000DOol00`00Oomoo`0LOol00`00Ool0000COol00`00Oomoo`0MOol2000DOol00`00
Oomoo`0LOol00`00Ool0000COol00`00Oomoo`0MOol2000DOol00`00Oomoo`0HOol100000003001o
ogoo02Eoo`03001oogoo00Moo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001o
ogoo00Moo`03001oogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Moo`03001o
ogoo02Uoo`03001oogoo00Ioo`03001oogoo02Uoo`03001oogoo00Moo`03001oogoo02Uoo`03001o
ogoo00Ioo`03001oogoo00Aoo`40000000<007ooOol03Woo00@007ooOol0011oo`03001oogoo00eo
o`03001oogoo00ioo`05001oogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomo
o`0047oo00<007ooOol03Goo00<007ooOol03Woo00@007ooOol0015oo`03001oogoo00eoo`03001o
ogoo00ioo`04001oogoo000@Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`0047oo00<0
07ooOol03Woo00<007ooOol03Woo00@007ooOol0011oo`03001oogoo00eoo`03001oogoo00ioo`04
001oogoo000@Ool00`00Oomoo`0=Ool01000Oomoogoo0@0000001@00Oomoogoo000077oo00<007oo
Ool05Goo00<007ooOol06Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007oo
Ool06Woo00<007ooOol05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007oo
Ool05Woo00<007ooOol06Woo00<007ooOol05Goo00<007ooOol06Woo00<007ooOol05Goo0@000000
0`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool0
0`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomoo`0BOol0
0`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0BOol0
0`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`0BOol00`00Oomoo`09Ool0
0`00Oomoo`0BOol00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`09Ool1
00000003001oogoo00Uoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo
00Yoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo
015oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo
015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo015oo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo
00Qoo`40000000D007ooOomoo`0001]oo`03001oogoo019oo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo015oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo019oo`03001oogoo009o
o`03001oogoo01Uoo`03001oogoo015oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo019o
o`03001oogoo009oo`03001oogoo01Uoo`03001oogoo015oo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo019oo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo015oo`04001oogooOol1
00000003001oogoo015oo`03001oogoo00moo`03001oogoo021oo`03001oogoo00moo`03001oogoo
025oo`03001oogoo00moo`03001oogoo021oo`03001oogoo00moo`03001oogoo025oo`03001oogoo
00ioo`03001oogoo025oo`03001oogoo00moo`03001oogoo021oo`03001oogoo00moo`03001oogoo
025oo`03001oogoo00moo`03001oogoo011oo`40000000<007ooOol017oo00<007ooOol01goo00<0
07ooOol01goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`04001oogoo0009Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Ool00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`07Ool01000Oomoo`002Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01goo00<007oo00002Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00@007ooOol000Uoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00=oo`40000000<007oo
Ool01Woo00<007ooOol097oo00<007ooOol037oo00<007ooOol08goo00<007ooOol037oo00<007oo
Ool097oo00<007ooOol037oo00<007ooOol08goo00<007ooOol037oo00<007ooOol097oo00<007oo
Ool037oo00<007ooOol08goo00<007ooOol037oo00<007ooOol097oo00<007ooOol037oo00<007oo
Ool08goo00<007ooOol01Woo0@0000000`00Oomoo`0<Ool00`00Oomoo`0AOol00`00Oomoo`04Ool0
0`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0AOol0
0`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0GOol0
0`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`04Ool0
0`00Oomoo`0GOol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0BOol0
0`00Oomoo`04Ool00`00Oomoo`0;Ool100000003001oo`0001=oo`03001oogoo01ioo`80019oo`03
001oogoo01moo`03001oogoo015oo`03001oogoo01ioo`80019oo`03001oogoo01ioo`8001=oo`03
001oogoo01ioo`03001oogoo015oo`03001oogoo01ioo`8001=oo`03001oogoo01ioo`03001oogoo
015oo`03001oogoo021oo`40000000<007ooOol04goo00<007ooOol02Woo00<007ooOol09Woo00<0
07ooOol02Goo00<007ooOol09Woo00<007ooOol02Woo00<007ooOol09Woo00<007ooOol02Goo00<0
07ooOol09Woo00<007ooOol02Woo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol09Woo00<0
07ooOol02Woo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol04goo0@0000000`00Oomoo`07
Ool01@00Oomoogoo000077oo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol06Goo00<007oo
Ool04Woo00D007ooOomoo`0001aoo`03001oogoo015oo`03001oogoo009oo`03001oogoo01Uoo`03
001oogoo019oo`05001oogooOol0000LOol00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0I
Ool00`00Oomoo`0BOol01@00Oomoogoo000077oo00<007ooOol04Goo00<007ooOol00Woo00<007oo
Ool06Goo00<007ooOol02goo0@0000000`00Oomoo`0HOol01000Oomoo`0047oo00<007ooOol07Woo
00D007ooOomoo`00011oo`03001oogoo01ioo`04001oogoo000@Ool00`00Oomoo`0NOol01@00Oomo
ogoo000047oo00<007ooOol07Woo00@007ooOol0011oo`03001oogoo01ioo`05001oogooOol0000@
Ool00`00Oomoo`0NOol01000Oomoo`0047oo00<007ooOol07Woo00D007ooOomoo`00011oo`03001o
ogoo00Ioo`40000000<007ooOol00goo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Goo
00<007ooOol01Woo00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Goo00<007ooOol01Woo
00<007ooOol0:Woo00<007ooOol01Woo00<007ooOol0:Goo00<007ooOol01Woo00<007ooOol0:Woo
00<007ooOol01Woo00<007ooOol0:Goo00<007ooOol00goo0@0000000`00Oomoo`0?Ool00`00Oomo
o`0AOol2000OOol00`00Oomoo`0BOol2000OOol00`00Oomoo`0AOol2000OOol00`00Oomoo`0BOol2
000OOol00`00Oomoo`0AOol2000OOol00`00Oomoo`0AOol00`00Ool0000OOol00`00Oomoo`0AOol2
000OOol00`00Oomoo`0AOol00`00Ool0000@Ool100000003001oogoo009oo`03001oogoo00]oo`03
001oogoo01ioo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo01ioo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo01ioo`03
001oogoo00=oo`03001oogoo00]oo`03001oogoo01ioo`03001oogoo00=oo`03001oogoo00]oo`03
001oogoo01moo`03001oogoo00=oo`03001oogoo00]oo`03001oogoo01ioo`03001oogoo00=oo`03
001oogoo00]oo`03001oogoo01moo`04001oogooOol100000003001oogoo01Ioo`03001oogoo00Ao
o`03001oogoo02aoo`03001oogoo00=oo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo02ao
o`03001oogoo00=oo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo00=o
o`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo00=oo`03001oogoo01Io
o`40000000<007ooOol027oo00<007oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<007oo
00007Woo00<007oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P007goo
0P004Woo00<007oo00007Woo00<007oo00004Woo0P007goo0P002Woo0@0000000`00Oomoo`0EOol0
0`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomoo`06Ool0
0`00Oomoo`0YOol00`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0YOol0
0`00Oomoo`07Ool00`00Oomoo`0YOol00`00Oomoo`06Ool00`00Oomoo`0YOol00`00Oomoo`07Ool0
0`00Oomoo`0DOol100000004001oogoo000QOol00`00Oomoo`0>Ool01000Oomoo`0087oo00<007oo
Ool03Woo00@007ooOol0025oo`03001oogoo00ioo`04001oogoo000POol00`00Oomoo`0>Ool01000
Oomoo`0087oo00<007ooOol03goo00@007ooOol0021oo`03001oogoo00ioo`04001oogoo000POol0
0`00Oomoo`0?Ool01000Oomoo`0087oo00<007ooOol03Woo00<007ooOol00@0000000`00Oomoo`0=
Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0JOol01@00Oomoogoo00004goo00<007oo
Ool06Woo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol06Woo00D007ooOomoo`0001=oo`03
001oogoo01Yoo`03001oogoo009oo`03001oogoo015oo`03001oogoo01Yoo`05001oogooOol0000C
Ool00`00Oomoo`0JOol01@00Oomoogoo000057oo00<007ooOol06Woo00D007ooOomoo`0001=oo`03
001oogoo00eoo`40000000<007ooOol01Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol0
2Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol0
4Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol0
4Woo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Woo00<007ooOol0
2Goo00<007ooOol04Woo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol0
4Woo00<007ooOol017oo0@0000000`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00
Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00
Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`0AOol00`00
Oomoo`0:Ool00`00Oomoo`0<Ool100000003001oogoo00eoo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo00=o
o`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009o
o`03001oogoo01Uoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Uo
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo009oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo0040
000000<007ooOol07goo00<007oo0000<Woo00@007ooOol0039oo`03001oo`00039oo`04001oogoo
000bOol00`00Ool0000bOol01000Oomoo`00<Woo00<007oo0000<Woo00@007ooOol001=oo`400000
00H007ooOol007oo0007Ool00`00Oomoo`07Ool01000Oomoo`004Goo00<007oo00002Woo00<007oo
00001goo00<007ooOol01goo00<007oo00004Goo00@007ooOol000Uoo`03001oo`0000Moo`03001o
ogoo00Moo`04001oogoo000AOol00`00Ool0000:Ool00`00Ool00007Ool00`00Oomoo`07Ool00`00
Ool0000AOol01000Oomoo`002Goo00<007oo00001goo00<007ooOol01goo00@007ooOol0015oo`03
001oo`0000Uoo`04001oogoo0007Ool00`00Oomoo`07Ool00`00Ool0000AOol01000Oomoo`002Goo
00<007oo00001goo00<007ooOol01goo00@007ooOol0015oo`03001oo`0000Uoo`04001oogoo0007
Ool00`00Oomoo`07Ool00`00Ool0000AOol01000Oomoo`002Goo0@0000000`00Oomoo`08Ool00`00
Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`05Ool00`00Oomoo`0AOol00`00
Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`05Ool00`00
Oomoo`0AOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0GOol00`00
Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00
Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool100000003001oogoo01ao
o`03001oogoo015oo`03001oogoo01ioo`8001=oo`03001oogoo01ioo`03001oogoo015oo`03001o
ogoo01ioo`8001=oo`03001oogoo01ioo`03001oogoo015oo`03001oogoo01ioo`8001=oo`03001o
ogoo01ioo`03001oogoo015oo`03001oogoo01ioo`8001=oo`03001oogoo009oo`40000000<007oo
Ool01goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007oo
Ool01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Woo00<007oo
Ool05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol05Woo00<007oo
Ool01Goo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007oo
Ool02Goo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol02Goo00<007oo
Ool01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Goo00<007oo
Ool05Woo00<007ooOol01Goo00<007ooOol00Woo0@0000000`00Ool0000DOol00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol0
0`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool00`00Oomoo`0=Ool0
0`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol00`00Oomoo`0=Ool0
0`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0AOol0
0`00Oomoo`0=Ool00`00Oomoo`0?Ool100000003001oogoo00=oo`03001oogoo00Ioo`03001oogoo
019oo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo01Eoo`03001oogoo
00Ioo`03001oogoo019oo`03001oogoo01Aoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo
01Eoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo01Eoo`03001oogoo00Moo`03001oogoo
015oo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo01Eoo`03001oogoo
00Moo`03001oogoo015oo`03001oogoo019oo`40000000<007ooOol05goo00<007oo00004Woo0P00
7goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<0
07oo00004Woo0P007goo0P004Woo00<007oo00007Woo00<007oo00004Woo0P007goo0P004Woo00<0
07oo00001goo0@0000000`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0B
Ool00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0G
Ool00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`0AOol00`00Oomoo`04
Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`0A
Ool00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`03Ool00`00Oomoo`0H
Ool00`00Oomoo`0=Ool100000003001oogoo015oo`03001oogoo00Yoo`80019oo`03001oogoo015o
o`03001oogoo00Yoo`03001oo`00019oo`03001oogoo015oo`03001oogoo00Yoo`80019oo`03001o
ogoo015oo`03001oogoo00Yoo`03001oo`00019oo`03001oogoo015oo`03001oogoo00Yoo`80019o
o`03001oogoo015oo`03001oogoo00Yoo`03001oo`00015oo`03001oogoo019oo`03001oogoo00Yo
o`80019oo`03001oogoo015oo`03001oogoo00Yoo`03001oo`00015oo`04001oogooOol100000003
001oogoo00Uoo`03001oogoo01ioo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo01ioo`03
001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo01ioo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo00Moo`03
001oogoo00Qoo`03001oogoo01ioo`03001oogoo00Ioo`03001oogoo00Qoo`03001oogoo01ioo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo01ioo`03001oogoo00Ioo`40005oo`40000000D0
07ooOomoo`00015oo`04001oogoo000;Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>
Ool01000Oomoo`0037oo00D007ooOomoo`0000moo`03001oogoo00moo`04001oogoo000;Ool00`00
Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`0037oo00D007ooOomoo`0000mo
o`03001oogoo00ioo`05001oogooOol0000;Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomo
o`0>Ool01000Oomoo`0037oo00D007ooOomoo`0000moo`03001oogoo00ioo`05001oogooOol0000;
Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool01000Oomoo`0037oo00D007ooOomo
o`0000ioo`40000000<007ooOol01Woo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol02Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Goo00<007ooOol01Woo
00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Woo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol00goo0@0000000`00Oomo
o`06Ool00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomo
o`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomo
o`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomo
o`0BOol00`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool100000003001oogoo00]oo`03001oogoo019oo`03
001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00aoo`03
001oogoo009oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo00aoo`03001oogoo009oo`03
001oogoo00Yoo`03001oogoo015oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03
001oogoo015oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo015oo`03
001oogoo00aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00eoo`03
001oogoo009oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00aoo`03001oogoo00Aoo`40
000000<007ooOol00goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007oo0000
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo0000
1goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007oo0000
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo0000
1goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007oo0000
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo0000
1goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007oo0000
1goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo0000
1goo00<007ooOol01Woo0@0000001@00Oomoogoo00001Woo00<007ooOol01Goo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol02Woo
00<007ooOol02Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01Goo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol00Woo
0@0000001000Oomoo`0057oo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo0P002goo
00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol04Goo
0P002goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo00<007oo
Ool04Goo0P002goo00<007ooOol04Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol04Goo0P002goo00<007ooOol04Goo0@0000000`00Oomoo`09Ool01@00Oomoogoo0000
37oo00<007ooOol03Goo00D007ooOomoo`0000moo`03001oogoo009oo`03001oogoo00Uoo`03001o
ogoo00eoo`03001oogoo009oo`03001oogoo00eoo`05001oogooOol0000<Ool00`00Oomoo`0=Ool0
1@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol03Goo00<007ooOol0
0Woo00<007ooOol03Goo00D007ooOomoo`0000aoo`03001oogoo00eoo`05001oogooOol0000?Ool0
1@00Oomoogoo000037oo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol03Goo00D007ooOomo
o`0000aoo`03001oogoo00eoo`05001oogooOol0000?Ool01@00Oomoogoo000037oo00<007ooOol0
3Goo00<007ooOol00Woo00<007ooOol017oo0@0000000`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00
Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00
Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00
Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00
Oomoo`09Ool00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00
Oomoo`0<Ool100000003001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eo
o`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`8000aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`8000ao
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00Aoo`8000aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`8000aoo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`8000aoo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001o
ogoo00=oo`8000aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo00Aoo`8000aoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`80009oo`40000000<007oo
Ool00Woo00<007oo00004goo00<007ooOol027oo00<007ooOol04Woo0P0057oo00<007ooOol027oo
00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<007ooOol04Woo0P0057oo00<007oo
Ool027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<007ooOol04Woo0P0057oo
00<007ooOol027oo00<007ooOol04Goo00<007oo00004goo00<007ooOol027oo00<007ooOol04Woo
0P0057oo00<007ooOol027oo00<007ooOol03goo0@0000000`00Oomoo`0?Ool00`00Oomoo`0KOol0
1000Oomoo`004goo00<007ooOol06goo00D007ooOomoo`0001=oo`03001oogoo01]oo`04001oogoo
000COol00`00Oomoo`0KOol01@00Oomoogoo00004goo00<007ooOol06goo00@007ooOol001=oo`03
001oogoo01]oo`04001oogoo000DOol00`00Oomoo`0KOol01000Oomoo`004goo00<007ooOol06goo
00@007ooOol000Eoo`40000000<007ooOol037oo00<007ooOol03Goo00D007ooOomoo`00021oo`03
001oogoo00eoo`03001oogoo009oo`03001oogoo01ioo`03001oogoo00eoo`05001oogooOol0000P
Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`0=Ool01@00Oomoogoo
000087oo00<007ooOol03Goo00<007ooOol00Woo00<007ooOol07Woo00<007ooOol03Goo00D007oo
Oomoo`00021oo`03001oogoo00eoo`03001oogoo009oo`03001oogoo019oo`40000000<007oo0000
1goo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol0
4Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
4Woo00<007ooOol02Woo0@0000000`00Ool00007Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00
Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00
Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00
Oomoo`0:Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool100000003001oogoo00mo
o`03001oogoo00Uoo`03001oogoo00=oo`03001oogoo00aoo`03001oogoo015oo`03001oogoo00Yo
o`03001oogoo009oo`03001oogoo00aoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00ao
o`03001oogoo019oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo015o
o`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo019oo`03001oogoo00Uo
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo009o
o`03001oogoo00aoo`03001oogoo00=oo`40000000<007ooOol00Woo00<007ooOol01goo00<007oo
Ool057oo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol057oo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007oo
Ool027oo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007oo
Ool057oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol057oo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol05Goo00<007ooOol01goo00<007oo
Ool01Goo0@0000000`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`09Ool01000Oomoo`004Goo
00<007ooOol037oo00<007ooOol00Woo00<007ooOol02Woo00<007oo00004Goo00<007ooOol037oo
00<007ooOol00goo00<007ooOol02Goo00@007ooOol0015oo`03001oogoo00aoo`03001oogoo009o
o`03001oogoo00Yoo`03001oo`00015oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Uo
o`04001oogoo000AOol00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Ool0000A
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`09Ool01000Oomoo`004Goo00<007ooOol0
37oo00<007ooOol00Woo00<007ooOol02Woo00<007oo00004Goo00<007ooOol027oo0@0000000`00
Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00
Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00
Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00
Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0100000003
001oogoo00Eoo`03001oogoo00Uoo`8001=oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Uoo`8001Aoo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00Uoo`8001=oo`03001oogoo
00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`8001=oo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo00Uoo`8001=oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Uoo`8001=oo`03
001oogoo00Uoo`03001oogoo00Ioo`03001oogoo00Uoo`8001=oo`03001oogoo00Uoo`03001oogoo
00Eoo`03001oogoo00Uoo`8001=oo`03001oogoo00Uoo`04001oogooOol100000003001oogoo00Uo
o`03001oogoo00eoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00ioo`03001oogoo00eo
o`05001oogooOol0000?Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomo
o`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol03Woo00<0
07ooOol03Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00D0
07ooOomoo`0000moo`03001oogoo00ioo`03001oogoo00eoo`05001oogooOol0000@Ool00`00Oomo
o`0>Ool00`00Oomoo`0=Ool01@00Oomoogoo00003goo00<007ooOol01Goo0@0000001000Oomoo`00
37oo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol01Woo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol027oo0@0000001@00
Oomoogoo00001Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02goo
00<007ooOol017oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol017oo00<007ooOol02goo
00<007ooOol00goo00<007ooOol02Woo00<007ooOol02goo00<007ooOol00goo00<007ooOol02Woo
0@0000000`00Oomoo`0>Ool00`00Ool0000;Ool00`00Oomoo`0@Ool00`00Ool0000AOol00`00Ool0
000<Ool00`00Oomoo`0@Ool2000BOol00`00Ool0000;Ool00`00Oomoo`0@Ool00`00Ool0000AOol0
0`00Ool0000<Ool00`00Oomoo`0@Ool2000BOol00`00Ool0000;Ool00`00Oomoo`0@Ool00`00Ool0
000AOol00`00Ool0000<Ool00`00Oomoo`0?Ool00`00Ool0000BOol00`00Ool0000;Ool00`00Oomo
o`0@Ool00`00Ool0000AOol00`00Ool0000<Ool00`00Oomoo`0?Ool00`00Ool00004Ool100000003
001oogoo00=oo`04001oogoo000@Ool01@00Oomoogoo000027oo00@007ooOol0015oo`04001oogoo
000@Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo000@Ool01@00Oomoogoo000027oo
00@007ooOol0011oo`05001oogooOol0000@Ool01000Oomoo`002Goo00@007ooOol0011oo`04001o
ogoo000@Ool01@00Oomoogoo000027oo00@007ooOol0011oo`05001oogooOol0000@Ool01000Oomo
o`002Goo00@007ooOol0011oo`04001oogoo000@Ool01@00Oomoogoo000027oo00@007ooOol0011o
o`05001oogooOol0000@Ool01000Oomoo`0027oo00D007ooOomoo`0000eoo`40000000<007ooOol0
2goo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol01Goo0@000Goo0@00
00000`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol0
0goo00<007oo000017oo00<007ooOol00Woo00@007ooOol000]oo`03001oogoo00=oo`03001oo`00
00Aoo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Ool0
000<Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol00Woo00@007oo
Ool000Aoo`03001oogoo009oo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Ool00004Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007ooOol00goo00<007oo000037oo00<0
07ooOol00Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0004Ool0
0`00Oomoo`02Ool01000Oomoo`002goo00<007ooOol00goo00<007oo000017oo00<007ooOol01Goo
00<007ooOol00Woo00@007ooOol000=oo`03001oogoo00=oo`03001oo`0000aoo`03001oogoo009o
o`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomoo`0017oo00<007ooOol0
0Woo00@007ooOol000]oo`03001oogoo009oo`04001oogoo0004Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool01000Oomoo`000goo00<007ooOol00goo00<007oo00001Woo0@0000000`00Ool0003o002/
0001Ool100000003001oo`0000Aoo`05001oogooOol00003Ool00`00Oomoo`06Ool01@00Oomoogoo
00001Woo00<007ooOol01Woo00D007ooOomoo`0000Moo`03001oogoo009oo`05001oogooOol00002
Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol01Woo00@007ooOol000Moo`03001o
ogoo009oo`05001oogooOol00003Ool00`00Oomoo`06Ool01000Oomoo`001goo00<007ooOol01Woo
00D007ooOomoo`0000Moo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`06Ool01@00
Oomoogoo00001goo00<007ooOol01Woo00@007ooOol000Moo`03001oogoo009oo`05001oogooOol0
0003Ool00`00Oomoo`06Ool01000Oomoo`001goo00<007ooOol01Woo00D007ooOomoo`0000Moo`03
001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007oo
Ool01Woo00@007ooOol000Moo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`06Ool0
1000Oomoo`001goo00<007ooOol01Woo00D007ooOomoo`0000Moo`05001oogooOol00004Ool01000
Oomoo`0027oo00D007ooOomoo`0000Moo`03001oogoo00Ioo`04001oogoo0008Ool100000004001o
ogoo0006Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20005
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Ool00005Ool100000003001oogoo009oo`04001oogoo0009Ool00`00
Oomoo`05Ool01000Oomoo`0027oo00@007ooOol0015oo`04001oogoo0008Ool00`00Oomoo`05Ool0
1000Oomoo`002Goo00@007ooOol0011oo`04001oogoo0009Ool00`00Oomoo`05Ool01000Oomoo`00
27oo00@007ooOol0015oo`04001oogoo0008Ool00`00Oomoo`05Ool01000Oomoo`002Goo00@007oo
Ool0011oo`04001oogoo0009Ool00`00Oomoo`05Ool01000Oomoo`0027oo00@007ooOol0015oo`04
001oogoo0008Ool00`00Oomoo`05Ool01000Oomoo`002Goo00@007ooOol0011oo`04001oogoo0009
Ool00`00Oomoo`04Ool01@00Oomoogoo000027oo00@007ooOol0015oo`04001oogoo0008Ool00`00
Oomoo`05Ool01000Oomoo`002Goo00@007ooOol000ioo`40000000<007ooOol02Woo00<007ooOol0
1Goo00<007ooOol02Goo0P002goo00<007ooOol01Goo00<007ooOol02Goo0P001Woo00<007ooOol0
2Woo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol0
2Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo0P001Woo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo0P001Woo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol0
2Woo00<007ooOol01Goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol02Woo00<007ooOol0
2Goo00<007ooOol01Goo00<007ooOol00@0000000`00Oomoo`02Ool01000Oomoo`0037oo00<007oo
Ool00Woo00@007ooOol000Qoo`04001oogoo0004Ool01000Oomoo`002Goo00@007ooOol000]oo`03
001oogoo009oo`04001oogoo0009Ool01000Oomoo`0017oo00<007oo00002Goo00@007ooOol000ao
o`03001oogoo009oo`03001oo`0000Uoo`04001oogoo0004Ool01000Oomoo`002Goo00@007ooOol0
00]oo`03001oogoo009oo`04001oogoo0009Ool01000Oomoo`0017oo00<007oo00002Goo00@007oo
Ool000aoo`03001oogoo009oo`03001oo`0000Uoo`04001oogoo0004Ool01000Oomoo`002Goo00@0
07ooOol000]oo`03001oogoo009oo`04001oogoo0009Ool01000Oomoo`0017oo00<007oo00002Goo
00@007ooOol000aoo`03001oogoo009oo`03001oo`0000Uoo`04001oogoo0004Ool01000Oomoo`00
2Goo00<007oo000037oo00<007ooOol00Woo00@007ooOol000Uoo`04001oogoo0004Ool00`00Ool0
0007Ool100000004001oogoo0006Ool00`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Ool00005Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool0
0`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool00005Ool0
0`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool1
00000006001oo`00Ool007oo0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200001Woo000007oo
001oo`<00004Ool00000Ool200000goo001oo`0200001Woo000007oo001oo`800003Ool007oo0080
0006Ool00000Ool007oo0P0000Eoo`00000007oo00@00004Ool00000Ool200000goo001oo`020000
0goo001oo`0200001Woo000007oo001oo`800004Ool00000Ool5000017oo000007oo0P0000=oo`00
Ool00P0000=oo`00Ool00P0000Ioo`00001oo`00Ool200001Woo000007oo001oo`<00004Ool00000
Ool200000goo001oo`0200001Woo000007oo001oo`800003Ool007oo00800006Ool00000Ool007oo
0P0000Eoo`00000007oo00800003Ool007oo00800006Ool00000Ool007oo0P0000=oo`00Ool00P00
00Ioo`00001oo`00Ool2000017oo000007oo1@0000Aoo`00001oo`800003Ool007oo00800003Ool0
07oo00800006Ool00000Ool007oo0P0000Ioo`00001oo`00Ool3000017oo000007oo0P0000=oo`00
Ool00P0000Ioo`00001oo`00Ool200000goo001oo`0200001Woo000007oo001oo`<00004Ool00000
Ool200000goo001oo`0200001Woo000007oo001oo`800003Ool007oo00800006Ool00000Ool007oo
0P0000Eoo`00000007oo00@00004Ool00000Ool200000goo001oo`0200000goo001oo`0200001Woo
000007oo001oo`800004Ool00000Ool300000goo001oo`0200001Woo000007oo001oo`800006Ool0
0000Ool007oo0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool3000017oo000007oo0P0000=oo`00
Ool00P0000Ioo`00001oo`00Ool200000goo001oo`0200001Woo000007oo001oo`800005Ool00000
001oo`0200000goo001oo`0200000goo001oo`0100000007001oo`00001oo`00Ool00P0000=oo`00
00000P000Woo00@007oo001oo`800006Ool00000Ool007oo0`0000Aoo`00001oo`800003Ool007oo
00800003Ool000000080009oo`04001oo`00Ool200001Woo000007oo001oo`800003Ool000000080
0005Ool007oo001oo`0200001Woo000007oo001oo`800003Ool0000000800006Ool00000Ool007oo
0P0000=oo`0000000P000Woo0P0000Aoo`00001oo`800003Ool007oo00800003Ool000000080009o
o`04001oo`00Ool200001Woo000007oo001oo`<00004Ool00000Ool200000goo001oo`0200000goo
000000020002Ool01000Ool007oo0P0000Ioo`00001oo`00Ool2000017oo000000000Woo00@007oo
001oo`800006Ool00000Ool007oo0P0000=oo`0000000P0000Ioo`00001oo`00Ool200000goo0000
000200001Goo001oo`00Ool00P0000Ioo`00001oo`00Ool200000goo000000020002Ool01000Ool0
07oo0P0000Ioo`00001oo`00Ool600001Woo000007oo001oo`800003Ool000000080009oo`04001o
o`00Ool200001Woo000007oo001oo`<00003Ool00000009oo`04001oo`00Ool200001Woo000007oo
001oo`800003Ool0000000800006Ool00000Ool007oo0P0000=oo`0000000P0000Eoo`00Ool007oo
00800006Ool00000Ool007oo0P0000=oo`0000000P000Woo00@007oo001oo`800006Ool00000Ool0
07oo1P0000Ioo`00001oo`00Ool200000goo000000020002Ool01000Ool007oo0P0000Ioo`00001o
o`00Ool300000goo00000002Ool01000Ool007oo0P0000Ioo`00001oo`00Ool200000goo00000002
00001Woo000007oo001oo`800004Ool000000002Ool01000Ool007oo0P000Woo0@0000000`00Ool0
000200000goo001oo`0400000goo0000000300000goo001oo`0500000goo0000000300000goo0000
000300000goo001oo`0400000goo0000000300000goo001oo`0500000goo001oo`0900000goo001o
o`0500000goo0000000400000goo0000000300000goo001oo`0400001Goo00000000Ool00P0000=o
o`0000000`0000=oo`00Ool0100000=oo`0000000`0000=oo`00Ool01@0000=oo`0000000`0000=o
o`0000000`0000=oo`00Ool0100000=oo`0000000`0000=oo`00Ool01@0000=oo`00Ool02@0000=o
o`00Ool01@0000=oo`000000100000=oo`0000000`0000=oo`00Ool0100000=oo`0000000P0000=o
o`00Ool01@0000=oo`00Ool0100000=oo`0000000`0000=oo`00Ool01@0000Aoo`00001oo`800003
Ool0000000<00003Ool007oo00@00003Ool0000000<00003Ool007oo00D00003Ool007oo00<00003
Ool0000000<00003Ool007oo00D00003Ool0000000@00003Ool0000000<00003Ool007oo00T00003
Ool007oo00D00003Ool007oo00@00003Ool0000000<00003Ool007oo00D00004Ool00000Ool20000
0goo0000000300000goo001oo`0400000goo0000000300000goo001oo`0500000goo001oo`030000
0goo0000000300000goo001oo`0500000goo0000000400000goo0000000300000goo001oo`090000
0goo001oo`020001Ool100000005001oogooOol00002Ool00`00Ool00002Ool00`00Oomoo`02Ool0
1P00Oomoo`00Ool0009oo`03001oogoo009oo`05001oo`00Ool00002Ool01P00Oomoo`00Ool0009o
o`03001oogoo009oo`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool01@00Oomoogoo0000
0Woo00<007oo00000Woo00<007ooOol00Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009o
o`05001oogooOol00002Ool00`00Ool00002Ool01P00Oomoo`00Ool0009oo`03001oogoo009oo`06
001oogoo001oo`000Woo00<007ooOol00Woo00D007oo001oo`00009oo`06001oogoo001oo`000Woo
00<007ooOol00Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009oo`05001oogooOol00002
Ool00`00Ool00002Ool00`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`06001oogoo001oo`000Woo
00D007ooOomoo`00009oo`03001oo`00009oo`06001oogoo001oo`000Woo00<007ooOol00Woo00H0
07ooOol007oo0002Ool01@00Oomoogoo00000Woo00<007oo00000Woo00H007ooOol007oo0002Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`08001oogoo001oo`00Ool000Aoo`06001oogoo001o
o`000Woo00<007ooOol00Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009oo`05001oogoo
Ool00002Ool00`00Ool00002Ool01P00Oomoo`00Ool0009oo`03001oogoo009oo`06001oogoo001o
o`000Woo00D007ooOomoo`00009oo`03001oo`00009oo`06001oogoo001oo`000Woo00<007ooOol0
0Woo00H007ooOol007oo0002Ool02000Oomoo`00Ool007oo0004Ool01P00Oomoo`00Ool0009oo`03
001oogoo009oo`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool01@00Oomoogoo00000Woo
00@007oo001oo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000?l00;40
0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 431}, {265.875, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000000P0200000000000000000lZheU@SXe
<C8gD6J=]/G6cLk<]j9nEC`k<c0a?UIeWKk5blk=ajjGKdLj>38a=4YOQ:g4aLc?
c[nXQelo>S<a<SYBJi>iaLS=cLZcWWQ?>cXc<392FG^S`LG<c/k4[95YA3Xf<C8f
CV>9/lC6c<o=^ZF1FCdk<c0a?5AaVKc5b/k=b;2JLdXk>C8a<dMLPJW3a<c?c/6Z
Rf=1>S@a<SQAJ8ngaLO=c/^fXGaC?3Xc<350EgNO_lG<c/g6[IE]ASXg<S8eC626
[lC5c<o=_JN5GChj<c4a>e=]UK[5bLk=bK6MMTdk>S<`<TAJOJG2a<c>c/>[SfM3
>SDa<SM?IHbea<K<c/biXgmG?3/c<34nEG>K_/G;c/g7[iQ`B3Xh<S4cBEj3[<?5
c<o>`:V9HD0j=34b>E9ZT[S5b<g=bkBONU0k>S<`<T5HNJ70aLc>c/F]TfY5>SHa
<SE=HXRba<G<clflYX=K?C/c<C4lDfnH_<G:c/g9/9]dBc/i<c4cAU]oZ<?4c<o>
`ZZ=I48j=C4b>51VS[K5alg>c;NROE@l>S<`<CmFMYfoaL_>cLJ^UVi7>SPb<SA;
GhF^a<G<cljnZ8IN?cXc<C4jDVbD^/G8cLg:/YihCS/j<c0b@eUlY<75c<k>a:b@
J4@j=S4b=TiTR[?4a/c>cKZTP5Pm>c<`<CeDLYZmaL[>cLR_VG99>STb<C=8GH6Z
`lC<clk1ZHYR@CXd<C8hDFR@^<G7cLk;]J1kDS/j<c0a@5MhX<35c<k=aJfDK4Hj
=c8b=DaQQk34aLc?cKfVQ5`n>S<a<C]CKYJkaLW>cLVaW7I<>cTc<395FWjV`/C<
clk3ZhiV@cXe<C8gCfF<]LC6cLk<^:=nES`k<c0a?UEdW;k5blk=ajjGL4Pj>38a
=4UNPjc3aLc?c[nXR610>S<a<SUBJY:iaLS=cLZcWgU@>cXc<392F7ZR`LG<c/k4
[99ZACXf<C8fCV:9//C5c<o=^jF2FSdk<c4a?5A`V;c5b/k=b;2JLdXk>C<a<dIL
P:S3a<c?c/6ZS6A1>S@a<SQ@IhngaLO=c/bfXGaC?3Xc<34oEWJN_lG;c/g6[IE]
AcXg<S8dBf25[lC5c<o=_ZN6GSlj<c4a>U9/UK[5bLk=b[:MMddk>S<`<T=IO:C2
a<c>c/>/T6M3>SDa<SI?I8^da<K<c/biY81G?3/c<34mEG:K_LG:c/g7[iUaBCXh
<S4cB5f2Zl?5c<o>`:V9HT0j=34b>E5YTKS5alg=bkBPNU4k>S<`<D5GNJ70aLc>
c/F]Tf]5>SLb<SE=HHNaa<G<clflYX=K?SXc<C4kDfnG^lG9c/g9/I]eC3/i<c4b
AE]oYl;4c<o>`Z^=ID8j=C4b=e1VSKK5a/g>c;NROUDl>c<`<CiFMIfnaL_>cLN^
Ufm7>SPb<CA:GhB]a<G<cljoZ8MO?cXc<C8jDV^C^LG8cLg:/iihCc/j<c0b@UUk
Xl75c<k>a:bAJD@j=S4b=TiSRK?4a/c?cKZUPETm>c<`<CaDLIVlaL[>cLR`VW=:
>cTb<C=7G86Y`lC<clk1ZX]S@CXd<C8hDFR?]lG7cLk;]Z5lDc`j<c0a@5MgWko5
c<k=aZfEKDHj=c8b=DaPQZo4aLc?cKfWQEdn>S<a<C]CKIFjaLW>cLVaWGI=>cXc
<394FWfU`/C<c/k3ZhmW@cXe<C8gCfF<]LC6c<k<^J=oEc`k<c0a?UEcVkk5blk=
ajnHL4Pj>38a<dUNPjc3aLc?c/2YRF50>S@a<SUBJY:haLS=cL^dWgY@>cXc<391
F7VQ`<G<c/k5[I=ZACXf<C8eCF:8//C5c<o=_:J3Fcdk<c4a?5=_V;c5b/k=bK2K
M4/k>C<a<dIKOjS3a<c?c/:ZSFA2>SDa<SQ@IXjfaLO=c/bgXWeD?3Xc<34oEWJM
_lG;c/g6[YI^AcXh<S8dBen5[/C5c<o>_ZR6GSlj<c4a>U9/U;[5b<g=b[:NN4hk
>S<`<T=IO:C1aLc>c/B/T6Q4>SHa<SI>I8Zca<K<c/fjY81H?C/c<34mE7:J_LG:
c/g8[iUbBCXi<S4cB5f1Z/?4c<o>`JV:HT4j=34b>55XT;S5alg>bkFPNe8k>S<`
<D1GN:30aLc>cLF]U6a6>SLb<SE<HHN`a<G<clfmYXAL?SXc<C4kDfjF^lG9c/g9
/IafC3/i<c0bAEYnY/;4c<o>`j^>IT<j=C4b=dmUS;G4a/g>c;RSOUHl>c<`<CiE
M9bnaL_>cLN^Ug18>SPb<CA9GX>/`lG<cljoZ8QP@3Xc<C8iDVZB^LG8cLg:/imi
D3/j<c0b@UQjX/75c<k>a:bBJTDj=S4b=TiRRK;4aLc?cK^UPUXm>c<a<CaDL9Rl
aL[>cLR`VW=:>cTc<C=6G82X`lC<clk1ZXaT@CXd<C8hD6N?]lG7cLk<]Z5lDc`j
<c0a?eIfW[o5blk=aZfEKDLj=c8b=4]PQJo4aLc?cKjWQUho>S<a<CYBK9FjaLW>
cLZbWGM=>cXc<393FGbT`/C<c/k3[91W@cXe<C8fCfB;]<C6c<k<^JB0Ec`k<c0a
?EEbVkg5b/k=ajnILDTj>38a<dQMPZ_3aLc?c/2YRF90>S@a<SUAJI6haLO=cL^d
X7YA>cXc<351EgVQ`<G<c/k5[I=[ACXg<S8eCF67/LC5c<o=_:J3Fchj<c4a>e=_
Uk_5bLk=bK6KMD`k>C<a<TEKOjO2a<c?c/:[SFE2>SDa<SM@IXffaLK=c/bgXWiE
?3/c<34nEWFM_/G;c/g7[YM_AcXh<S4dBUn4[LC5c<o>_jR7Gclj<c4b>U9[TkW5
b<g=b[>NN4lk>S<`<T9INj?1aLc>c/B/TFU4>SHa<SI>HhVca<K<clfjYH5I?C/c
<34lE76I_<G:c/g8/9YcBS/i<S4cAeb1ZL?4c<o>`JZ;Hd4j=34b>55XSkO5alg>
bkJQO5<l>S<`<D1GMinoaLc>cLJ]UFe6>SLb<SE<H8J_a<G<clfmYhEM?SXc<C4k
DffE^/G9c/g9/IefCC/j<c0bA5YmYL;4c<k>`j^?Id<j=C4b=dmUS;G4a/c>c;VS
OeLl>c<`<CiELi^naL_>cLN_V718>SPb<C=9GX>/`lG<clk0ZHUQ@3Xd<C8iDVZB
^<G8cLg;]9mjD3/j<c0b@EQiXL35c<k>aJfCJTDj=S4b=DeRR;;4aLc?cKbVPe/m
>c<a<CaCKiRlaL[>cLV`VgA;>cTc<C=6FgnX`lC<clk2ZXeT@SXe<C8hD6J>]/G7
cLk<]j9mE3`j<c0a?eIfWKo5blk=aZjFKTLj>38b=4]OQJk4aLc?c[jXQUho>S<a
<CYBK9BjaLS=cLZbWWQ>>cXc<393FGbT`LG<c/k4[91XA3Xf<C8fCVB:/lC6c<k=
^ZB0F3dk<c0a?EAbV[g5b/k=b:nILTTj>C8a<dQMPJ[3a<c?c/6YRV91>S@a<SQA
J92haLO=c/^eX7]B>cXc<350EgRP`<G<c/g5[IA/ASXg<S8eC667/<C5c<o=_JJ4
G3hj<c4a>e=^U[_5bLk=bK6LMT`k>C<`<TEJOZK2a<c?c/>[SVI3>SDa<SM?IHbe
a<K=c/bhXgiF?3/c<34nEGBL_/G;c/g7[YM`B3Xh<S4dBEj3[<?5c<o>_jR8H40j
<c4b>E9ZT[W5b<g=b[>ONE0k>S<`<T9HNZ;1aLc>c/B/TVY5>SHa<SI>HXVba<G<
clfkYH9J?C/c<C4lE72H_<G:c/g8/9YcBS/i<c4cAUb0Z<?4c<o>`JZ<I44j=34b
>51WSkO5alg>c;JQO5<l>S<`<CmFMYjoaL_>cLJ]UFe7>SLb<SA;H8F_a<G<clfn
YhIN?cXc<C4jDVbE^/G9c/g:/YegCC/j<c0b@eUlY<;4c<k>`jb@Id<j=C4b=TmT
RkC4a/c>c;VTP5Ll>c<`<CeELY^maL[>cLN_VG59>SPb<C=8GH:[`lG<clk0ZHUR
@3Xd<C8iDFVA^<G7cLg;]:1jDC/j<c0a@EMiXL35c<k>aJfCJdDj=c8b=DeQQk74
aLc?cKbVPe/n>S<a<C]CKiNkaLW>cLVaVgE<>cTc<C95FgnW`/C<clk2ZheU@SXe
<C8gD6J=]/G6cLk<]j9nEC`k<c0a?UIeWKk5blk=ajjGKdLj>38a=4YOQ:g4aLc?
c[nXQelo>S<a<SYBJi>iaLS=cLZcWWQ?>cXc<392FG^S`LG<c/k4[95YA3Xf<C8f
CV>9/lC6c<o=^ZF1FCdk<c0a?5AaVKc5b/k=b;2JLdXk>C8a<dMLPJW3a<c?c/6Z
Rf=1>S@a<SQAJ8ngaLO=c/^fXGaC?3Xc<350EgNO_lG<c/g6[IE]ASXg<S8eC626
[lC5c<o=_JN5GChj<c4a>e=]UK[5bLk=bK6MMTdk>S<`<TAJOJG2a<c>c/>[SfM3
>SDa<SM?IHbea<K<c/biXgmG?3/c<34nEG>K_/G;c/g7[iQ`B3Xh<S4cBEj3[<?5
c<o>`:V9HD0j=34b>E9ZT[S5b<g=bkBONU0k>S<`<T5HNJ70aLc>c/F]TfY5>SHa
<SE=HXRba<G<clflYX=K?C/c<C4lDfnH_<G:c/g9/9]dBc/i<c4cAU]oZ<?4c<o>
`ZZ=I48j=C4b>51VS[K5alg>c;NROE@l>S<`<CmFMYfoaL_>cLJ^UVi7>SPb<SA;
GhF^a<G<cljnZ8IN?cXc<C4jDVbD^/G8cLg:/YihCS/j<c0b@eUlY<75c<k>a:b@
J4@j=S4b=TiTR[?4a/c>cKZTP5Pm>c<`<CeDLYZmaL[>cLR_VG99>STb<C=8GH6Z
`lC<clk1ZHYR@CXd<C8hDFR@^<G7cLk;]J1kDS/j<c0a@5MhX<35c<k=aJfDK4Hj
=c8b=DaQQk34aLc?cKfVQ5`n>S<a<C]CKYJkaLW>cLVaW7I<>cTc<395FWjV`/C<
clk3ZhiV@cXe<C8gCfF<]LC6cLk<^:=nES`k<c0a?UEdW;k5blk=ajjGL4Pj>38a
=4UNPjc3aLc?c[nXR610>S<a<SUBJY:iaLS=cLZcWgU@>cXc<392F7ZR`LG<c/k4
[99ZACXf<C8fCV:9//C5c<o=^jF2FSdk<c4a?5A`V;c5b/k=b;2JLdXk>C<a<dIL
P:S3a<c?c/6ZS6A1>S@a<SQ@IhngaLO=c/bfXGaC?3Xc<34oEWJN_lG;c/g6[IE]
AcXg<S8dBf25[lC5c<o=_ZN6GSlj<c4a>U9/UK[5bLk=b[:MMddk>S<`<T=IO:C2
a<c>c/>/T6M3>SDa<SI?I8^da<K<c/biY81G?3/c<34mEG:K_LG:c/g7[iUaBCXh
<S4cB5f2Zl?5c<o>`:V9HT0j=34b>E5YTKS5alg=bkBPNU4k>S<`<D5GNJ70aLc>
c/F]Tf]5>SLb<SE=HHNaa<G<clflYX=K?SXc<C4kDfnG^lG9c/g9/I]eC3/i<c4b
AE]oYl;4c<o>`Z^=ID8j=C4b=e1VSKK5a/g>c;NROUDl>c<`<CiFMIfnaL_>cLN^
Ufm7>SPb<CA:GhB]a<G<cljoZ8MO?cXc<C8jDV^C^LG8cLg:/iihCc/j<c0b@UUk
Xl75c<k>a:bAJD@j=S4b=TiSRK?4a/c?cKZUPETm>c<`<CaDLIVlaL[>cLR`VW=:
>cTb<C=7G86Y`lC<clk1ZX]S@CXd<C8hDFR?]lG7cLk;]Z5lDc`j<c0a@5MgWko5
c<k=aZfEKDHj=c8b=DaPQZo4aLc?cKfWQEdn>S<a<C]CKIFjaLW>cLVaWGI=>cXc
<394FWfU`/C<c/k3ZhmW@cXe<C8gCfF<]LC6c<k<^J=oEc`k<c0a?UEcVkk5blk=
ajnHL4Pj>38a<dUNPjc3aLc?c/2YRF50>S@a<SUBJY:haLS=cL^dWgY@>cXc<391
F7VQ`<G<c/k5[I=ZACXf<C8eCF:8//C5c<o=_:J3Fcdk<c4a?5=_V;c5b/k=bK2K
M4/k>C<a<dIKOjS3a<c?c/:ZSFA2>SDa<SQ@IXjfaLO=c/bgXWeD?3Xc<34oEWJM
_lG;c/g6[YI^AcXh<S8dBen5[/C5c<o>_ZR6GSlj<c4a>U9/U;[5b<g=b[:NN4hk
>S<`<T=IO:C1aLc>c/B/T6Q4>SHa<SI>I8Zca<K<c/fjY81H?C/c<34mE7:J_LG:
c/g8[iUbBCXi<S4cB5f1Z/?4c<o>`JV:HT4j=34b>55XT;S5alg>bkFPNe8k>S<`
<D1GN:30aLc>cLF]U6a6>SLb<SE<HHN`a<G<clfmYXAL?SXc<C4kDfjF^lG9c/g9
/IafC3/i<c0bAEYnY/;4c<o>`j^>IT<j=C4b=dmUS;G4a/g>c;RSOUHl>c<`<CiE
M9bnaL_>cLN^Ug18>SPb<CA9GX>/`lG<cljoZ8QP@3Xc<C8iDVZB^LG8cLg:/imi
D3/j<c0b@UQjX/75c<k>a:bBJTDj=S4b=TiRRK;4aLc?cK^UPUXm>c<a<CaDL9Rl
aL[>cLR`VW=:>cTc<C=6G82X`lC<clk1ZXaT@CXd<C8hD6N?]lG7cLk<]Z5lDc`j
<c0a?eIfW[o5blk=aZfEKDLj=c8b=4]PQJo4aLc?cKjWQUho>S<a<CYBK9FjaLW>
cLZbWGM=>cXc<393FGbT`/C<c/k3[91W@cXe<C8fCfB;]<C6c<k<^JB0Ec`k<c0a
?EEbVkg5b/k=ajnILDTj>38a<dQMPZ_3aLc?c/2YRF90>S@a<SUAJI6haLO=cL^d
X7YA>cXc<351EgVQ`<G<c/k5[I=[ACXg<S8eCF67/LC5c<o=_:J3Fchj<c4a>e=_
Uk_5bLk=bK6KMD`k>C<a<TEKOjO2a<c?c/:[SFE2>SDa<SM@IXffaLK=c/bgXWiE
?3/c<34nEWFM_/G;c/g7[YM_AcXh<S4dBUn4[LC5c<o>_jR7Gclj<c4b>U9[TkW5
b<g=b[>NN4lk>S<`<T9INj?1aLc>c/B/TFU4>SHa<SI>HhVca<K<clfjYH5I?C/c
<34lE76I_<G:c/g8/9YcBS/i<S4cAeb1ZL?4c<o>`JZ;Hd4j=34b>55XSkO5alg>
bkJQO5<l>S<`<D1GMinoaLc>cLJ]UFe6>SLb<SE<H8J_a<G<clfmYhEM?SXc<C4k
DffE^/G9c/g9/IefCC/j<c0bA5YmYL;4c<k>`j^?Id<j=C4b=dmUS;G4a/c>c;VS
OeLl>c<`<CiELi^naL_>cLN_V718>SPb<C=9GX>/`lG<clk0ZHUQ@3Xd<C8iDVZB
^<G8cLg;]9mjD3/j<c0b@EQiXL35c<k>aJfCJTDj=S4b=DeRR;;4aLc?cKbVPe/m
>c<a<CaCKiRlaL[>cLV`VgA;>cTc<C=6FgnX`lC<clk2ZXeT@SXe<C8hD6J>]/G7
cLk<]j9mE3`j<c0a?eIfWKo5blk=aZjFKTLj>38b=4]OQJk4aLc?c[jXQUho>S<a
<CYBK9BjaLS=cLZbWWQ>>cXc<393FGbT`LG<c/k4[91XA3Xf<C8fCVB:/lC6c<k=
^ZB0F3dk<c0a?EAbV[g5b/k=b:nILTTj>C8a<dQMPJ[3a<c?c/6YRV91>S@a<SQA
J92haLO=c/^eX7]B>cXc<350EgRP`<G<c/g5[IA/ASXg<S8eC667/<C5c<o=_JJ4
G3hj<c4a>e=^U[_5bLk=bK6LMT`k>C<`<TEJOZK2a<c?c/>[SVI3>SDa<SM?IHbe
a<K=c/bhXgiF?3/c<34nEGBL_/G;c/g7[YM`B3Xh<S4dBEj3[<?5c<o>_jR8H40j
<c4b>E9ZT[W5b<g=b[>ONE0k>S<`<T9HNZ;1aLc>c/B/TVY5>SHa<SI>HXVba<G<
clfkYH9J?C/c<C4lE72H_<G:c/g8/9YcBS/i<c4cAUb0Z<?4c<o>`JZ<I44j=34b
>51WSkO5alg>c;JQO5<l>S<`<CmFMYjoaL_>cLJ]UFe7>SLb<SA;H8F_a<G<clfn
YhIN?cXc<C4jDVbE^/G9c/g:/YegCC/j<c0b@eUlY<;4c<k>`jb@Id<j=C4b=TmT
RkC4a/c>c;VTP5Ll>c<`<CeELY^maL[>cLN_VG59>SPb<C=8GH:[`lG<clk0ZHUR
@3Xd<C8iDFVA^<G7cLg;]:1jDC/j<c0a@EMiXL35c<k>aJfCJdDj=c8b=DeQQk74
aLc?cKbVPe/n>S<a<C]CKiNkaLW>cLVaVgE<>cTc<C95FgnW`/C<clk2ZheU@SXe
<C8gD6J=]/G6cLk<]j9nEC`k<c0a?UIeWKk5blk=ajjGKdLj>38a=4YOQ:g4aLc?
c[nXQelo>S<a<SYBJi>iaLS=cLZcWWQ?>cXc<392FG^S`LG<c/k4[95YA3Xf<C8f
CV>9/lC6c<o=^ZF1FCdk<c0a?5AaVKc5b/k=b;2JLdXk>C8a<dMLPJW3a<c?c/6Z
Rf=1>S@a<SQAJ8ngaLO=c/^fXGaC?3Xc<350EgNO_lG<c/g6[IE]ASXg<S8eC626
[lC5c<o=_JN5GChj<c4a>e=]UK[5bLk=bK6MMTdk>S<`<TAJOJG2a<c>c/>[SfM3
>SDa<SM?IHbea<K<c/biXgmG?3/c<34nEG>K_/G;c/g7[iQ`B3Xh<S4cBEj3[<?5
c<o>`:V9HD0j=34b>E9ZT[S5b<g=bkBONU0k>S<`<T5HNJ70aLc>c/F]TfY5>SHa
<SE=HXRba<G<clflYX=K?C/c<C4lDfnH_<G:c/g9/9]dBc/i<c4cAU]oZ<?4c<o>
`ZZ=I48j=C4b>51VS[K5alg>c;NROE@l>S<`<CmFMYfoaL_>cLJ^UVi7>SPb<SA;
GhF^a<G<cljnZ8IN?cXc<C4jDVbD^/G8cLg:/YihCS/j<c0b@eUlY<75c<k>a:b@
J4@j=S4b=TiTR[?4a/c>cKZTP5Pm>c<`<CeDLYZmaL[>cLR_VG99>STb<C=8GH6Z
`lC<clk1ZHYR@CXd<C8hDFR@^<G7cLk;]J1kDS/j<c0a@5MhX<35c<k=aJfDK4Hj
=c8b=DaQQk34aLc?cKfVQ5`n>S<a<C]CKYJkaLW>cLVaW7I<>cTc<395FWjV`/C<
clk3ZhiV@cXe<C8gCfF<]LC6cLk<^:=nES`k<c0a?UEdW;k5blk=ajjGL4Pj>38a
=4UNPjc3aLc?c[nXR610>S<a<SUBJY:iaLS=cLZcWgU@>cXc<392F7ZR`LG<c/k4
[99ZACXf<C8fCV:9//C5c<o=^jF2FSdk<c4a?5A`V;c5b/k=b;2JLdXk>C<a<dIL
P:S3a<c?c/6ZS6A1>S@a<SQ@IhngaLO=c/bfXGaC?3Xc<34oEWJN_lG;c/g6[IE]
AcXg<S8dBf25[lC5c<o=_ZN6GSlj<c4a>U9/UK[5bLk=b[:MMddk>S<`<T=IO:C2
a<c>c/>/T6M3>SDa<SI?I8^da<K<c/biY81G?3/c<34mEG:K_LG:c/g7[iUaBCXh
<S4cB5f2Zl?5c<o>`:V9HT0j=34b>E5YTKS5alg=bkBPNU4k>S<`<D5GNJ70aLc>
c/F]Tf]5>SLb<SE=HHNaa<G<clflYX=K?SXc<C4kDfnG^lG9c/g9/I]eC3/i<c4b
AE]oYl;4c<o>`Z^=ID8j=C4b=e1VSKK5a/g>c;NROUDl>c<`<CiFMIfnaL_>cLN^
Ufm7>SPb<CA:GhB]a<G<cljoZ8MO?cXc<C8jDV^C^LG8cLg:/iihCc/j<c0b@UUk
Xl75c<k>a:bAJD@j=S4b=TiSRK?4a/c?cKZUPETm>c<`<CaDLIVlaL[>cLR`VW=:
>cTb<C=7G86Y`lC<clk1ZX]S@CXd<C8hDFR?]lG7cLk;]Z5lDc`j<c0a@5MgWko5
c<k=aZfEKDHj=c8b=DaPQZo4aLc?cKfWQEdn>S<a<C]CKIFjaLW>cLVaWGI=>cXc
<394FWfU`/C<c/k3ZhmW@cXe<C8gCfF<]LC6c<k<^J=oEc`k<c0a?UEcVkk5blk=
ajnHL4Pj>38a<dUNPjc3aLc?c/2YRF50>S@a<SUBJY:haLS=cL^dWgY@>cXc<391
F7VQ`<G<c/k5[I=ZACXf<C8eCF:8//C5c<o=_:J3Fcdk<c4a?5=_V;c5b/k=bK2K
M4/k>C<a<dIKOjS3a<c?c/:ZSFA2>SDa<SQ@IXjfaLO=c/bgXWeD?3Xc<34oEWJM
_lG;c/g6[YI^AcXh<S8dBen5[/C5c<o>_ZR6GSlj<c4a>U9/U;[5b<g=b[:NN4hk
>S<`<T=IO:C1aLc>c/B/T6Q4>SHa<SI>I8Zca<K<c/fjY81H?C/c<34mE7:J_LG:
c/g8[iUbBCXi<S4cB5f1Z/?4c<o>`JV:HT4j=34b>55XT;S5alg>bkFPNe8k>S<`
<D1GN:30aLc>cLF]U6a6>SLb<SE<HHN`a<G<clfmYXAL?SXc<C4kDfjF^lG9c/g9
/IafC3/i<c0bAEYnY/;4c<o>`j^>IT<j=C4b=dmUS;G4a/g>c;RSOUHl>c<`<CiE
M9bnaL_>cLN^Ug18>SPb<CA9GX>/`lG<cljoZ8QP@3Xc<C8iDVZB^LG8cLg:/imi
D3/j<c0b@UQjX/75c<k>a:bBJTDj=S4b=TiRRK;4aLc?cK^UPUXm>c<a<CaDL9Rl
aL[>cLR`VW=:>cTc<C=6G82X`lC<clk1ZXaT@CXd<C8hD6N?]lG7cLk<]Z5lDc`j
<c0a?eIfW[o5blk=aZfEKDLj=c8b=4]PQJo4aLc?cKjWQUho>S<a<CYBK9FjaLW>
cLZbWGM=>cXc<393FGbT`/C<c/k3[91W@cXe<C8fCfB;]<C6c<k<^JB0Ec`k<c0a
?EEbVkg5b/k=ajnILDTj>38a<dQMPZ_3aLc?c/2YRF90>S@a<SUAJI6haLO=cL^d
X7YA>cXc<351EgVQ`<G<c/k5[I=[ACXg<S8eCF67/LC5c<o=_:J3Fchj<c4a>e=_
Uk_5bLk=bK6KMD`k>C<a<TEKOjO2a<c?c/8\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "the sound is ",
  StyleBox["indistinguishable",
    FontSlant->"Italic"],
  " from the triangle wave. This is surprising, given the difference between \
the shapes of these two waveforms. One can verify that this is not an \
accident. By re-evaluating the random phase waveform one gets a different \
shape each time; but in each case the sound is identical. (",
  "Try it!",
  ")"
}], "Text"],

Cell[TextData[{
  "\tWhy do differently-shaped waveforms make the same sound? The reason has \
to do with how we perceive sound. Sound is perceived by the brain through the \
electrical signals sent by nerve cells that line the inner ear. Each nerve \
cell is attached to a hair that is sandwiched between two membranes - the \
basilar membrane and the tectorial membrane (see Fig. ",
  ButtonBox["2.2",
    ButtonData:>"Fig. 2.2",
    ButtonStyle->"Hyperlink"],
  "). As sound waves move through the fluid in the inner ear, these \
membranes, immersed in the fluid,  move relative to one another in response. \
The basilar membrane is thicker and stiffer in some places than in others, so \
different parts of the membrane are resonant to different frequencies of \
sound. Therefore, a given sound frequency excites motion only in certain \
places on the membrane. (This correspondence between frequency and location \
is called a ",
  StyleBox["tonotopic map",
    FontSlant->"Italic"],
  ".)  The motion excites the hairs at these locations, which in turn cause \
their respective neurons to fire at a rate that depends on the amplitude of \
the motion, sending signals to the brain that are interpreted as a sound of a \
given frequency and loudness."
}], "Text",
  CellTags->"i:94"],

Cell[TextData[{
  "\tIf you think this system sounds complicated, you're right. After all, it \
is the product of millions of years of evolutionary trial and error. But one \
can think of it very roughly as just a system of oscillators having a range \
of  resonant frequencies. Crudely speaking, the ear is doing a Fourier \
analysis of the incoming sound: the different frequency components of the \
sound resonantly excite different  hairs, which through the tonotopic map are \
perceived as different frequencies. The ",
  StyleBox["amplitude",
    FontSlant->"Italic"],
  " of a hair's motion is translated into the amplitude of the sound at that \
frequency. The ",
  StyleBox["phase",
    FontSlant->"Italic"],
  " of the motion of the hairs relative to one another is apparently not \
important  in what we perceive as the ",
  StyleBox["quality ",
    FontSlant->"Italic"],
  "of the sound (as we have seen, the \"sound\" of the sound is unchanged by \
phase modulation of different frequency components). "
}], "Text",
  CellTags->"i:26"],

Cell[TextData[{
  "\tHowever, as always seems to be the case in biological systems, things \
are really more complicated than this crude picture. The phase of the motion \
of the hairs is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " completely ignored by the auditory system, at least for sounds with \
frequencies less than around 1-1.4 kHz. For this range, neurons are thought \
to be able to \"phase lock\" their firing to the phase of the sound - for \
instance, the neuron might fire only at the peak of the sine wave. (At higher \
frequencies, the neuron's firing rate apparently cannot keep up with the \
sound oscillation.)  Experiments have shown that this phase information is \
used by the brain's auditory system to help locate the",
  StyleBox[" source",
    FontSlant->"Italic"],
  " of the sound, by comparing the phase in the right ear with that in the \
left. (See the exercises.)"
}], "Text"],

Cell[TextData[{
  "\tAlso, the auditory system is not passive. It has recently been shown \
that the resonant response of the hairs to a sound impulse is actually ",
  StyleBox["amplified",
    FontSlant->"Italic"],
  " by molecular motors in the membranes of the hair cells. This \
amplification allows the response of the system to be considerably more \
sharply peaked about the resonant frequency than would be the case for a \
purely passive system with the same damping rate. In fact, the molecular \
motors cause the hairs to vibrate continuously at a low level, and the sound \
this motion creates can be picked up by sensitive microphones ",
  StyleBox["outside",
    FontSlant->"Italic"],
  " the ear. The ear is not just a passive receiver: it also transmits \
(albeit at a level below our conscious perception)."
}], "Text"],

Cell[TextData[{
  "\tIn summary, two periodic waveforms will ",
  StyleBox["look",
    FontSlant->"Italic"],
  " different if their Fourier components have different relative ",
  StyleBox["phases, ",
    FontSlant->"Italic"],
  "but they will still ",
  StyleBox["sound ",
    FontSlant->"Italic"],
  "alike",
  " if their Fourier ",
  StyleBox["amplitudes",
    FontSlant->"Italic"],
  " are the same."
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .6751 
%%ImageSize: 988 667 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.000963948 0.0160738 0.000963948 [
[ 0 0 0 0 ]
[ 1 .6751 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .6751 L
0 .6751 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01607 translate
.95238 .64296 scale
2964 string
988 667 8 [988 0 0 667 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFF000000000000FFFFFF000000000000000000000000000000FFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFF000000000000FFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFF000000000000FFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
FFFFFF000000000000000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979797979797979
797979797979797979797979797979797979797979797979797979797979000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000FFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000D8D8D8000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFD8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFD8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000000000000000000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292FFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000000000000000000000000000000000
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292FFFFFF
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFF929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
FFFFFFFFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFF929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292FFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292FFFFFF929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292FFFFFF929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292FFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292FFFFFF929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292FFFFFFFFFFFF929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292FFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF
FFFFFF929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000000000
000000000000000000D8D8D8D8D8D8000000000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
000000000000000000000000000000000000000000D8D8D8000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8000000000000D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000D8D8D8D8D8D8000000000000D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8FFFFFF000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000D8D8D8D8D8D8D8D8D8000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8000000D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
D8D8D8000000000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000000000000000000000
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8FFFFFF000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000
000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8000000000000000000000000000000000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8000000000000D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
000000000000D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8
D8D8D8D8D8D8D8D8D8D8D8D8D8D8D8FFFFFF000000000000000000000000000000000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292000000000000929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292000000000000929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
000000000000929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292000000000000929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292929292
929292929292929292929292929292929292929292929292929292929292929292000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFF000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF000000
000000FFFFFF000000000000000000000000000000FFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000000000000000000000000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000000000000000000000000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{243.688, 164.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000;K0001kB000`400?l00000o`00003ooooooooo
ooooomgooooo003ooooooooooooogOooool00?oooooooooooooMooooo`00ooooooooooooomgooooo
003ooooooooooooogOooool00?oooooooooooooMooooo`00ooooooooooooomgooooo003ooooooooo
oooogOooool00?oooooooooooooMooooo`00ooooooooooooomgooooo003ooooooooooooogOooool0
0?oooooooooooooMooooo`00ooooooooooooomgooooo000Aooooool0ooooo`3oooni0?oooa?ooooo
000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aoooo
ool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0oooo
o`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni
0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?o
oooo000Aooooool0oooo>03oool00`30`<00oooo0?ooo`060?ooo`030820P03oool0oooo00L0oooo
00<0`<300820P020P8001@20P8020?ooo`L0P8200P3oool70820P0D0oooo00<0`<300820P020P800
0P20P8020?ooo`030<30`020P800oooo00T0oooo00<0`<300820P020P8000P20P8000`30`<00oooo
0?ooo`0;0?ooo`030<30`03oool0oooo00H0oooo00<0P8200?ooo`3oool0o`3ooolM0?oooa?ooooo
000Aooooool0oooo>03oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00T0oooo1000
00050?ooo`@0000000<0P8200?ooo`3oool00P3oool4000000030820P03oool0oooo00<0oooo1`00
00000`3oool0P82000000002000000L0oooo0`0000030?ooo`030820P0000000oooo00/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`3o0?oooad0oooo4oooool0017oooooo`3ooolg
0?ooo`8000001`3oool00`20P80000000820P00;0?ooo`80000000<0P8200?ooo`3oool0103oool3
000000H0oooo0`0000050?ooo`030820P0000000000000H0000000<0P8200000000000000P000000
0`20P800oooo0?ooo`020?ooo`80000000<0P8200?ooo`3oool00`3oool2000000X0oooo0P000007
0?ooo`80000000<0P8200?ooo`3oool0o`3ooolL0?oooa?ooooo000Aooooool0oooo=P3oool01030
`<00000000000020P8060?ooo`030410@0000000@41000/0oooo0P0000000`20P800oooo0?ooo`04
0?ooo`<000001P3oool3000000D0oooo0`0000020820P0<0oooo00D0P82000000000000000000820
P0040?ooo`040820P000000000000820P0L0oooo00<0@41000000020P8001`3oool01030`<000000
00000020P8050?ooo`040<30`000000000000410@1h0oooo00<0P8200000000000000P0000020820
P080oooo00<0P8200000000000000P0000001@10@400P8200?ooo`3oool0P82000@0000000<0@410
0820P03oool00`3oool00`20P800@41000000003000000030410@020P800oooo00@0oooo00<0`<30
0820P00000000`0000001@20P800`<300?ooo`3oool0P82000@000000P20P8020?ooo`030820P000
000000000080000000<0@4100820P03oool0103oool00`30`<00P82000000004000000030410@020
P800oooo00@0oooo00<0`<300820P00000000`0000000`20P800`<300?ooo`040?ooo`060820P000
0000000000000010@400P8200`3oool01@10@40000000410@020P800oooo0080P820100000001@20
P800oooo0?ooo`30`<00P82000@0000000<0P8200<30`03oool00`3oool00`20P800000000000003
000000030820P030`<00oooo06l0oooo4oooool0017oooooo`3ooolf0?ooo`040820P00000000000
000000H0oooo0`00000;0?ooo`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`000004
0?ooo`<0000000<0P8200?ooo`3oool0103oool01020P800000000000020P8040?ooo`<00000203o
ool00`20P8000000000000070?ooo`040820P00000000000000000D0oooo00@0P820000000000000
0000803oool2000000030820P03oool0oooo00@0oooo0`0000060?ooo`<000001@3oool00`20P800
000000000006000000030820P03oool0oooo00D0oooo0P0000000`20P800oooo0?ooo`040?ooo`80
000000<0P8200?ooo`3oool0103oool3000000H0oooo100000040?ooo`030820P0000000000000L0
oooo0P0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000@0000000<0P8200?ooo`00
0000100000001020P800oooo0?ooo`20P802000000H0oooo00@0P820000000000000P8201@3oool9
00000700oooo4oooool0017oooooo`3ooolf0?ooo`050410@000000000000?ooo`000000103oool0
1@20P800000000000030`<00000000X0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3o
ool3000000<0oooo00D0P82000000000000000000<30`0060?ooo`040820P000000000000820P0<0
oooo00@0P820000000000000P8202@3oool2000000030820P03oool0oooo00@0oooo00D0@4100000
00000000oooo000000040?ooo`050410@000000000000<30`00000007`3oool2000000030820P03o
ool0oooo00@0oooo0`0000060?ooo`<000001@3oool4000000070820P03oool0oooo0?ooo`20P800
@4100820P0060?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00@0
oooo0`0000060?ooo`<000001P3oool00`20P8000000000000060?ooo`80000000<0P8200?ooo`3o
ool0103oool3000000050410@03oool0oooo0?ooo`20P800100000020?ooo`040<30`03oool0oooo
0820P08000001P3oool01020P800000000000020P8040?ooo`@0000000<0@4100?ooo`3oool00P3o
ool00`20P80000000<30`01^0?oooa?ooooo000Aooooool0oooo=P3oool2000000030820P03oool0
000000@0oooo0`0000000`3oool000000?ooo`090?ooo`80000000<0P8200?ooo`3oool0103oool3
000000H0oooo0`0000030?ooo`@000001`3oool01020P800000000000020P8030?ooo`<0000000<0
P8200?ooo`3oool01`3oool3000000H0oooo0P0000000`20P800oooo000000040?ooo`<0000000<0
oooo0000003oool07P3oool2000000030820P03oool0oooo00@0oooo0`0000060?ooo`<00000103o
ool4000000L0oooo0P0000050?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820P03o
ool0oooo00@0oooo0`0000060?ooo`<00000203oool2000000D0oooo0P0000000`20P800oooo0?oo
o`040?ooo`<000001P3oool3000000D0oooo00<0P8200000000000001P3oool01020P80000000000
0020P8030?ooo`030820P00000000000008000001`3oool00`000000oooo0?ooo`1/0?oooa?ooooo
000Aoooooj@0oooo00H0`<3000000000000000000820P030`<040?ooo`030<30`020P80000000080
000000D0P8200?ooo`3oool000000410@0020820P0H0oooo00<0P8200410@0000000100000000`20
P800`<300?ooo`070?ooo`030820P0000000000000<000000P20P81K0?ooo`040820P00000000000
0820P080oooo00<0P8200?ooo`3oool00`0000001020P800oooo0?ooo`20P8090?ooo`80000000<0
P8200?ooo`3oool0103oool3000000H0oooo0`0000030?ooo`<00000203oool01020P80000000000
0020P8030?ooo`<000002P3oool3000000D0oooo00@0P820000000000000P8200P3oool00`20P800
oooo0?ooo`03000000040820P03oool0oooo0820P1h0oooo0P0000000`20P800oooo0?ooo`040?oo
o`<000001P3oool3000000@0oooo0`0000000`30`<00oooo0?ooo`060?ooo`030820P030`<00oooo
00<0oooo0P0000000`20P800oooo0?ooo`040?ooo`80000000<0P8200?ooo`3oool0103oool30000
00H0oooo0`0000080?ooo`030410@0000000P82000@0oooo0P0000000`20P800oooo0?ooo`040?oo
o`<000001P3oool3000000D0oooo00<0P8200000000000001P3oool01020P800000000000020P803
0?ooo`040820P000000000000410@0P0oooo00<0`<300820P03oool0K03ooolCooooo`004OoooonT
0?ooo`030820P0000000000000<00000103oool7000000030?ooo`000000000000<000000`3oool0
0`20P800000000000002000000@0oooo0P0000070?ooo`T0000000<0P8200?ooo`3oool0F03oool3
000000<0oooo00<0P8200?ooo`3oool00`0000030?ooo`030820P03oool0oooo00L0oooo0P000000
0`20P800oooo0?ooo`040?ooo`<000001P3oool3000000<0oooo0`0000080?ooo`040820P0000000
00000820P0<0oooo0`00000:0?ooo`<000001@3oool3000000<0oooo00<0P8200?ooo`3oool00`00
00030?ooo`030820P03oool0oooo01`0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3o
ool3000000<0oooo00@0P82000000000000000003`3oool2000000030820P03oool0oooo00@0oooo
0P0000000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000P0oooo00<0P82000000020P800
103oool2000000030820P03oool0oooo00@0oooo00<0P8200000000000001P3oool3000000D0oooo
00<0P8200000000000001P3oool01020P800000000000020P8030?ooo`<0000000<0P8200?ooo`3o
ool0M@3ooolCooooo`004OoooonT0?ooo`<0000000<0P8200?ooo`20P800103oool3000000<0oooo
00<000000820P00000000P0000050?ooo`040820P000000000000820P0H0oooo0P0000000`20P800
oooo0?ooo`020?ooo`030820P000000000000080000000@0P8200?ooo`3oool0oooo0P00001J0?oo
o`<000000`3oool00`20P800oooo0820P003000000<0oooo00<0P8200?ooo`3oool01`3oool20000
00030820P03oool0oooo00@0oooo0`0000060?ooo`<000000`3oool3000000P0oooo00@0P8200000
00000000P8200`3oool3000000X0oooo0`0000050?ooo`<000000`3oool00`20P800oooo0820P003
000000<0oooo00<0P8200?ooo`3oool0703oool2000000030820P03oool0oooo00@0oooo0`000006
0?ooo`<000000`3oool01020P800000000000000000?0?ooo`80000000<0P8200?ooo`3oool0103o
ool2000000030820P03oool0oooo00@0oooo0`0000060?ooo`<00000203oool00`20P80000000000
00040?ooo`80000000<0P8200?ooo`3oool01@3oool2000000030820P03oool0oooo00<0oooo0`00
00050?ooo`030820P0000000000000H0oooo00@0P820000000000000P8200`3oool3000000030820
P03oool0oooo07D0oooo4oooool0017oooooY03oool3000000<0oooo00<0P8200?ooo`3oool00`00
00000`30`<00oooo0?ooo`020?ooo`040<30`00000000000000000D0oooo00@0P820000000000000
P8201P3oool00`30`<0000000410@0040?ooo`050410@0000000000000000020P8001@3oool00`30
`<0000000<30`01G0?ooo`030820P0000000000000@0oooo00<0`<300820P020P8000P0000001P20
P800oooo0?ooo`3oool0`<300820P0P0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3o
ool3000000<0oooo00<0P820000000000000203oool01020P800000000000020P8030?ooo`<00000
2@3oool01030`<0000000000000000040?ooo`<00000103oool00`30`<00P8200820P002000000@0
oooo00<0`<300820P03oool0703oool2000000030820P03oool0oooo00@0oooo0`0000060?ooo`<0
00000`3oool00`20P80000000000000@0?ooo`80000000<0P8200?ooo`3oool0103oool200000003
0820P03oool0oooo00@0oooo0`0000060?ooo`<00000203oool00`20P8000000000000040?ooo`80
000000<0P8200?ooo`3oool01P3oool00`20P80000000820P0040?ooo`<000001@3oool00`20P800
0000000000060?ooo`040820P000000000000820P0<0oooo0`00001h0?oooa?ooooo000Aoooooj@0
oooo0`0000060?ooo`<000001P3oool3000000D0oooo00@0P820000000000000P8201`3oool30000
00<0oooo0`0000090?ooo`030820P03oool0oooo05D0oooo00<0P8200000000000001@3oool40000
00D0oooo00<000000?ooo`3oool01P3oool2000000030820P03oool0oooo00@0oooo0`0000060?oo
o`<00000103oool2000000P0oooo00@0P820000000000000P8200`3oool00`20P800000000000009
0?ooo`040820P000000000000820P0@0oooo0`0000050?ooo`<0000000<0P8200?ooo`3oool00`3o
ool00`000000oooo0?ooo`0K0?ooo`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`00
00030?ooo`030820P000000000000100oooo0P0000000`20P800oooo0?ooo`040?ooo`80000000<0
P8200?ooo`3oool0103oool3000000H0oooo0`0000080?ooo`030820P0000000000000@0oooo0P00
00000`20P800oooo0?ooo`090?ooo`040000003oool0oooo0?ooo`<000001@3oool00`20P8000000
000000060?ooo`040820P000000000000820P0<0oooo0`00001h0?oooa?ooooo000Aoooooj@0oooo
0`0000060?ooo`<000001P3oool3000000D0oooo00@0P820000000000000P820203oool200000080
oooo00@0P820000000000000P8202@3oool00`30`<00oooo0?ooo`1E0?ooo`80000000<0P8200?oo
o`3oool0103oool3000000H0oooo00<000000?ooo`3oool01@3oool2000000030820P03oool0oooo
00@0oooo0`0000060?ooo`<00000103oool00`20P80000000820P0070?ooo`040820P00000000000
0820P0<0oooo00@0`<30000000000000`<30203oool01010@400000000000020P8030?ooo`040820
P000000000000820P0H0oooo0P0000000`20P800oooo0?ooo`040?ooo`030820P03oool0oooo01X0
oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000<0oooo00<0P82000000000
00002`20P8050?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00@0
oooo0`0000060?ooo`<00000203oool00`10@4000000000000040?ooo`80000000<0P8200?ooo`3o
ool02P3oool30820P0<000001@3oool00`20P8000000000000060?ooo`040820P000000000000820
P0<0oooo0`00000:0820P6h0oooo4oooool0017oooooY03oool3000000H0oooo0`0000060?ooo`<0
00001@3oool01020P800000000000020P8080?ooo`<0000000D0oooo00000000000000000820P01P
0?ooo`<0000000<0P8200?ooo`3oool00`3oool3000000L0oooo00<000000820P03oool01@3oool2
000000030820P03oool0oooo00@0oooo100000040?ooo`@000001@3oool00`20P80000000?ooo`06
0?ooo`040820P000000000000820P0@0oooo0P0000000`20P800oooo0?ooo`060?ooo`<00000103o
ool3000000030820P03oool0oooo00<0oooo0`0000070?ooo`030000003oool0oooo01X0oooo0P00
00000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000@0oooo0P0000080?ooo`<000001@3o
ool2000000030820P03oool0oooo00@0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3o
ool3000000P0oooo0`0000040?ooo`80000000<0P8200?ooo`3oool03@3oool3000000D0oooo00<0
P8200000000000001P3oool01020P800000000000020P8030?ooo`030820P0000000000000L0oooo
00<0P820000000000000KP3ooolCooooo`004OoooonT0?ooo`<000001P3oool3000000H0oooo0`00
00050?ooo`040820P000000000000820P0P0oooo0`000000103oool0000000000000001Q0?ooo`<0
00001@3oool01030`<0000000000000000080?ooo`050820P03oool0oooo0?ooo`30`<000P20P802
000000030820P03oool0oooo0080oooo0P20P803000000050<30`0000000P8200820P010@4000`00
00060?ooo`030<30`0000000@41000D0oooo00D0P82000000000000000000820P0050?ooo`030820
P0000000P82000D0oooo00@0`<30000000000000P8201@3oool3000000D0oooo00@0`<3000000000
000000001`3oool00`20P800oooo0?ooo`0J0?ooo`80000000<0P8200?ooo`3oool0103oool30000
00H0oooo0`0000040?ooo`030820P0000000P82000L0oooo0P0000000`20P800oooo0?ooo`030?oo
o`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00@0oooo0`0000060?oo
o`<000001`3oool01020P800000000000020P8040?ooo`80000000<0P8200?ooo`3oool0103oool0
1030`<00000000000030`<050?ooo`<000001@3oool00`20P8000000000000060?ooo`040820P000
000000000820P0<0oooo00@0`<30000000000000`<301P3oool00`20P80000000410@01^0?oooa?o
oooo000Aoooooj@0oooo0`0000060?ooo`<000001P3oool3000000D0oooo00@0P820000000000000
P820203oool3000000040?ooo`000000000000000600oooo100000000`20P800oooo0?ooo`020?oo
o`030820P00000000000008000001P3oool2000000D0oooo0`0000000`20P800oooo0?ooo`030?oo
o`@000000P3oool5000000030820P03oool0oooo00H0oooo00<0P8200000003oool00P3oool00`20
P800000000000002000000030820P03oool0oooo00@0oooo00<0P82000000020P8000`3oool30000
00H0oooo100000000`20P800oooo0?ooo`020?ooo`050820P0000000000000000020P8001P3oool2
000001/0oooo0`0000050?ooo`<0000000<0oooo0000003oool00`3oool4000000D0oooo0P000006
0?ooo`<000001P3oool3000000D0oooo0`0000000`20P80000000?ooo`030?ooo`@000001P3oool3
000000030820P03oool0oooo00<0oooo100000000`20P800oooo0?ooo`020?ooo`<000001P3oool0
1020P800000000000020P8050?ooo`<000001@3oool01@20P8000000000000000000P82000@0oooo
0`0000000`20P800oooo0?ooo`020?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820
P03oool0oooo06`0oooo4oooool0017oooooY03oool3000000H0oooo0`0000060?ooo`<000001@3o
ool01020P800000000000020P8080?ooo`<0000000@0oooo0000000000000000G`3oool00`20P800
00000000000400000080oooo1`0000040?ooo`@000001P3oool00`000000P8200?ooo`060?ooo`80
00000`3oool4000000/0oooo100000001@3oool0P820000000000000P82000P0oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`040?ooo`030820P0000000000000@000000P3oool70000
00@0oooo1000000J0?ooo`80000000<0P8200000000000000P3oool01`20P8000000000000000000
oooo0820P00000000P3oool01020P80000000000000000060?ooo`030820P0000000P82000@0oooo
00<0P8200000000000001`3oool2000000030820P0000000P8200080oooo00D0P820000000000000
00000?ooo`0200000080oooo00@0P82000000000000000001`3oool5000000<0oooo00<0P8200000
000000000P0000040?ooo`@00000103oool00`000000oooo0820P002000000030820P03oool0oooo
00<0oooo0P0000060?ooo`050820P000000000000?ooo`0000000`3oool4000000H0oooo0P000005
0?ooo`<00000K`3ooolCooooo`004OoooonT0?ooo`<000001P3oool3000000H0oooo0`0000050?oo
o`040820P000000000000820P0L0oooo10000000103oool0P8200000000000080820P080000000<0
P8200?ooo`3oool0TP3oool01020P800000000000020P8140?ooo`070820P0000000000000000020
P800oooo0820P005000000040820P03oool0oooo0820P0D0000000<0@4100?ooo`3oool01@3oool0
0`20P8000000000000030820P080000000<0P8200?ooo`3oool00P3oool00`30`<00P82000000002
000000030820P03oool0@41000D0000000@0P8200?ooo`3oool0P8201@0000000`10@400oooo0?oo
o`050?ooo`<0000000<0`<300000000000001@0000001P10@400oooo0?ooo`3oool0`<300820P0<0
00000P20P8000`10@400000000000002000000040?ooo`20P80000000410@0<0oooo00@0`<300000
00000000@410103oool20820P0<0000000<0oooo0<30`00000001@0000000`20P800oooo0?ooo`05
0?ooo`030410@0000000@4100080P8200P0000000`10@400P8200?ooo`1^0?oooa?ooooo000Aoooo
oj@0oooo0`0000060?ooo`<000001P3oool3000000D0oooo00@0P820000000000000P8201`3oool3
000000<0oooo0P0000080?ooo`80000000<0P8200?ooo`3oool0TP3oool01020P800000000000020
P8170?ooo`0300000020P800oooo0080oooo0`0000000`20P800oooo0?ooo`030?ooo`@000002P3o
ool4000000030820P03oool0oooo00P0oooo00<000000820P03oool00P3oool3000000030820P03o
ool0oooo00<0oooo100000080?ooo`<000000`3oool4000000T0oooo00@000000820P03oool0oooo
0`0000050?ooo`D000002P3oool00`000000oooo0?ooo`020?ooo`<000002`3oool400000780oooo
4oooool0017oooooY03oool3000000H0oooo0`0000060?ooo`<000001@3oool01020P80000000000
0010@4060?ooo`040410@00000000000000000<0oooo00<0P82000000020P8001P3oool00`20P800
00000000002E0?ooo`040820P000000000000820P8`0oooo0`00002d0?oooa?ooooo000Aoooooj@0
oooo0`0000060?ooo`<000001P3oool3000000D0oooo00<0P8200000000000000P0000001020P800
oooo0?ooo`3oool4000000D0oooo0P0000050?ooo`<00000UP3oool01020P800000000000020P82<
0?ooo`<00000]03ooolCooooo`004OoooonT0?ooo`<000001@3oool01020P8000000000000000005
0?ooo`040<30`00000000000000000D0oooo00<0P8200000000000000P20P807000000030<30`03o
ool0oooo00@0oooo00<0@4100000000000000P20P8001010@400000000000020P81c0?ooo`030<30
`020P800oooo0200oooo00@0P820000000000000P820S03oool300000;@0oooo4oooool0017ooooo
XP3oool8000000030?ooo`000000000000<00000103oool5000000D0oooo00@0P820000000000000
P8200P3oool4000000030820P03oool0oooo00P0oooo1000001f0?ooo`80000000<0P8200?ooo`3o
ool0703oool00`20P800000000000002000000030820P03oool0oooo08X0oooo0`00002d0?oooa?o
oooo000Aoooooj<0oooo1000000G0?ooo`040820P000000000000820P8/0oooo0P0000000`20P800
oooo0?ooo`0N0?ooo`<0000000<0P8200?ooo`3oool0RP3oool300000;@0oooo4oooool0017ooooo
Y03oool00`10@40000000000000G0?ooo`040820P000000000000820P8/0oooo00<0`<300820P03o
ool08P3oool00`20P800`<300?ooo`290?ooo`80P8200`00002d0?oooa?ooooo000AooooojD0oooo
0P00000G0?ooo`040820P000000000000820P?l0oooo?P3oool01020P800000000000000002d0?oo
oa?ooooo000AooooojD0oooo00<0P8200000003oool05P3oool01020P800000000000020P83o0?oo
od00oooo00<0`<300820P03oool0/`3ooolCooooo`004Ooooonn0?ooo`040820P000000000000820
P?l0oooomP3ooolCooooo`004Ooooonn0?ooo`040820P000000000000820P?l0oooomP3ooolCoooo
o`004Ooooonl0?ooo`030<30`020P80000000080000000<0P8200?ooo`3oool0o`3ooood0?oooa?o
oooo000Aoooool00oooo00<000000820P03oool0o`3ooooe0?oooa?ooooo000Aooooool0ooooo`3o
ooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oo
oa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo
000Aooooool0oooo<@3oool00`30`<00P82000000003000000030820P030`<00oooo00P0oooo00<0
P82000000010@4001020P8000`30`<00oooo0?ooo`070?ooo`050820P0000000000000000020P800
0P3oool01020P80000000820P020P8030?ooo`030820P00000000000008000000P20P8020?ooo`03
0820P000000000000080000000<0@4100820P03oool00`3oool00`20P800@4100000000300000004
0820P03oool0P82000000080P820o`3ooolh0?oooa?ooooo000Aooooool0oooo=03oool200000003
0820P03oool0oooo00L0oooo00<0P8200000000000001P3oool2000000L0oooo1`0000000`3oool0
P82000000003000000@0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001@3oool00`20P800
000000000006000000030820P000000000000080000000<0P8200?ooo`3oool0o`3ooold0?oooa?o
oooo000Aooooool0oooo=03oool2000000030820P03oool0oooo00H0oooo00@0P820000000000000
`<301P3oool00`30`<0000000410@0050?ooo`050820P0000000000000000030`<000P3oool20820
P0030410@0000000000000H0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001@3oool30000
00030820P030`<00oooo0080oooo00D0P82000000000000000000820P00k0?ooo`030820P010@400
000000@0000000<0P8200<30`03oool01@3oool00`30`<00000000000002000000050820P03oool0
oooo0?ooo`20P8000P0000000`20P800oooo0?ooo`030820P00600000020P800P8200820P010@400
P820103oool00`20P800@41000000003000000050820P03oool0oooo0?ooo`20P800100000000`10
@400P8200?ooo`030?ooo`060820P0000000000000000010@400P8200P3oool01P30`<0000000000
0010@400P8200?ooo`80P820100000000`20P800oooo0?ooo`2U0?oooa?ooooo000Aooooool0oooo
=03oool2000000030820P03oool0oooo00H0oooo0`0000080?ooo`8000001@3oool3000000H0oooo
00<0P8200000000000001P3oool2000000030820P03oool0oooo00@0oooo0`0000040?ooo`<00000
00<0P8200?ooo`3oool0103oool01020P800000000000020P80j0?ooo`@00000103oool2000000H0
oooo1`0000000`3oool0P82000000004000000040?ooo`20P80000000820P0D0oooo0P0000050?oo
o`<000001`3oool3000000D0oooo00<0P820000000000000100000000`20P800oooo000000040000
00040820P03oool0oooo0820P0800000Z@3ooolCooooo`004Ooooooo0?oooc@0oooo0P0000000`20
P800oooo0?ooo`050?ooo`<000002P3oool2000000@0oooo0`0000060?ooo`030820P00000000000
00H0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000000`3oool01@20P8000000000000000000
`<3000H0oooo00@0P820000000000000P820>P3oool2000000030820P03oool0oooo00@0oooo00<0
@4100000000000000`3oool4000000030<30`03oool0oooo0080P8200`0000020?ooo`040820P03o
ool0P820000000L0oooo00<000000820P03oool00`3oool3000000L0oooo0`0000050?ooo`<00000
00D0P8200?ooo`3oool0oooo0820P00400000080oooo00@0`<300?ooo`3oool0P8200P00002Y0?oo
oa?ooooo000Aooooool0oooo=03oool2000000030820P03oool0oooo00@0oooo00@0P82000000000
000000002P3oool3000000<0oooo0`0000060?ooo`030820P0000000000000H0oooo0P0000000`20
P800oooo0?ooo`040?ooo`<000000`3oool4000000L0oooo00@0P820000000000000P820>P3oool2
000000030820P03oool0oooo00D0oooo0P0000000`20P800oooo0?ooo`03000000H0oooo00<0P820
000000000000103oool00`20P800oooo0?ooo`060?ooo`800000103oool3000000L0oooo0`000005
0?ooo`80000000<0P8200?ooo`3oool0103oool3000000D0oooo00<0P820000000000000Z@3ooolC
ooooo`004Ooooomc0?oooa<0000000<0P8200?ooo`3oool0103oool2000000060820P03oool0oooo
0?ooo`000000P8201@3oool00`000000oooo0?ooo`05000000T0oooo0`0000050?ooo`040820P000
00000000000000D0oooo0P0000080?ooo`@000001P3oool700000080oooo00<0P820000000000000
100000000`20P800oooo00000006000000D0oooo0`0000050?ooo`8000000`3oool700000080oooo
1`00000X0?ooo`80000000<0P8200?ooo`3oool0103oool01020P800000000000020P80:0?ooo`<0
00000`3oool3000000H0oooo00<0P8200000000000001P3oool2000000030820P03oool0oooo00@0
oooo0`0000030?ooo`<00000203oool01020P800000000000020P80j0?ooo`80000000<0P8200?oo
o`3oool01@3oool300000080oooo0`0000060?ooo`030820P0000000000000@0oooo00<0P8200?oo
o`3oool01@3oool3000000@0oooo0`0000070?ooo`<000001@3oool2000000030820P03oool0oooo
00@0oooo0`0000050?ooo`030820P000000000000:T0oooo4oooool0017oooooM03oool00`20P800
@41000000002000000T0P820100000001@20P800oooo0?ooo`3oool0`<3000H0000000<0`<300?oo
o`0000000P0000001010@400P8200?ooo`3oool2000000030820P030`<00oooo0080oooo00<0P820
0410@020P8001P3oool5000000040820P03oool0oooo0820P0D0000000<0P8200?ooo`30`<001000
00001@20P800oooo0?ooo`3oool0`<3000L0000000<0P8200?ooo`3oool00`3oool01@30`<000000
000000000000P82000D0oooo00@0@410000000000000P820103oool01@20P8000000000000000000
`<3000@0oooo00<0`<30000000000000100000000`30`<00oooo0410@004000000030<30`03oool0
`<3000<0000000<0P8200?ooo`3oool00`3oool01010@400000000000020P80Y0?ooo`80000000<0
P8200?ooo`3oool0103oool01020P800000000000020P80:0?ooo`<000000`3oool3000000H0oooo
00<0P8200000000000001P3oool2000000030820P03oool0oooo00@0oooo0`0000030?ooo`<00000
203oool01020P800000000000020P80j0?ooo`80000000<0P8200?ooo`3oool01P3oool200000080
oooo00<0P8200000000000001P3oool00`20P8000000000000040?ooo`030<30`03oool0oooo00@0
oooo00@0@4100000000000000000103oool3000000L0oooo0`0000050?ooo`030410@0000000P820
00H0oooo0`0000050?ooo`030820P000000000000:T0oooo4oooool0017oooooM@3oool00`20P800
00000000000<0?ooo`<000000`3oool01020P80000000000000000030?ooo`030000003oool00000
00800000103oool00`000000P8200?ooo`050?ooo`030820P0000000oooo00@0oooo00@0P8200000
0000000000000P3oool00`000000oooo00000003000000030820P03oool0oooo00D000000P3oool0
0`000000oooo0?ooo`05000000<0oooo00<0P8200000000000001@3oool3000000H0oooo00<0P820
0000000000001P3oool3000000D0oooo100000030?ooo`@0000000@0P8200?ooo`3oool0P8200P3o
ool3000000H0oooo00<0P820000000000000:P3oool2000000030820P03oool0oooo00@0oooo00@0
P820000000000000P8202P3oool3000000<0oooo0`0000060?ooo`030820P0000000000000H0oooo
0P0000000`20P800oooo0?ooo`040?ooo`<000000`3oool3000000P0oooo00@0P820000000000000
P820>P3oool2000000030820P03oool0oooo00H0oooo0`0000020?ooo`030820P0000000000000D0
oooo00<0P8200000000000002@3oool5000000D0oooo0`0000070?ooo`<000001P3oool2000000H0
oooo0`0000050?ooo`030820P000000000000:T0oooo4oooool0017oooooM@3oool00`20P8000000
0000000=0?ooo`030820P0000000oooo0080oooo0`0000000`30`<00oooo0?ooo`020?ooo`040820
P00000000000000000@0oooo00<000000<30`03oool01@3oool00`20P80000000820P0040?ooo`03
0820P0000000000000@0oooo00D0`<3000000000000000000820P0050?ooo`030410@00000000000
00@0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`030?ooo`030820P010@400oooo
00<0oooo0`0000060?ooo`030820P0000000000000H0oooo0`0000050?ooo`80000000<0@4100?oo
o`3oool00`3oool01020P800000000000020P8050?ooo`<000001P3oool00`20P80000000000000Z
0?ooo`80000000<0P8200?ooo`3oool0103oool01020P800000000000020P8090?ooo`040820P000
00000000000000<0oooo0`0000060?ooo`030820P0000000000000H0oooo0P0000000`20P800oooo
0?ooo`040?ooo`<000000`3oool00`20P8000000000000080?ooo`040820P000000000000820P3X0
oooo0P0000000`20P800oooo0?ooo`060?ooo`<000000`3oool00`20P80000000410@0040?ooo`03
0820P0000000000000H0oooo00<0`<300820P0000000100000000`30`<00oooo0?ooo`030?ooo`<0
00001`3oool3000000L0oooo00<0@41000000020P800103oool3000000D0oooo00<0P82000000000
0000Z@3ooolCooooo`004Ooooome0?ooo`030820P0000000000000h0oooo0P0000020?ooo`<00000
1P3oool3000000@0oooo00<000000?ooo`3oool01@3oool2000000030820P03oool0oooo0080oooo
00<0P8200000000000001@3oool3000000H0oooo00<0P820000000000000103oool01020P8000000
0000000000080?ooo`030820P03oool0oooo0080oooo0`0000060?ooo`030820P0000000000000H0
oooo0`0000050?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00<0
oooo0`0000060?ooo`030820P0000000000002X0oooo0P0000000`20P800oooo0?ooo`050?ooo`80
000000<0P8200?ooo`3oool01`3oool3000000@0oooo0`0000060?ooo`030820P0000000000000H0
oooo0P0000000`20P800oooo0?ooo`040?ooo`<00000103oool2000000P0oooo00@0P82000000000
0000P820>P3oool2000000030820P03oool0oooo00H0oooo0`0000060?ooo`0500000020P800oooo
0?ooo`20P8000P0000060?ooo`D0000000<0P8200?ooo`3oool01@3oool3000000L0oooo0`00000:
0?ooo`040000003oool0oooo0?ooo`<000001@3oool00`20P80000000000002Y0?oooa?ooooo000A
ooooogD0oooo00<0P8200000000000003P3oool01020P80000000?ooo`3oool3000000H0oooo0`00
00040?ooo`030000003oool0oooo00@0oooo0`0000000`20P800oooo0?ooo`020?ooo`030820P000
0000000000D0oooo0`0000060?ooo`030820P0000000000000@0oooo0`00000:0?ooo`040000003o
ool0oooo0?ooo`<000001P3oool00`20P8000000000000060?ooo`<000001@3oool2000000030820
P03oool0oooo00@0oooo0P0000000`20P800oooo0?ooo`030?ooo`<000001P3oool00`20P8000000
0000000Z0?ooo`80000000<0P8200?ooo`3oool01@3oool2000000030820P03oool0oooo00L0oooo
0`0000040?ooo`<000001P3oool00`20P8000000000000060?ooo`80000000<0P8200?ooo`3oool0
103oool3000000@0oooo0P0000080?ooo`040820P000000000000820P3X0oooo0P0000000`20P800
oooo0?ooo`060?ooo`<000001`3oool01020P800000000000020P802000000D0oooo1@0000090?oo
o`<000001`3oool3000000/0oooo0P000000103oool000000000000000050?ooo`030820P0000000
00000:T0oooo4oooool0017oooooM@3oool00`20P80000000000000B0?ooo`<000001P3oool30000
00T0oooo00<0P8200410@00000000P0000000`30`<00oooo0?ooo`020?ooo`030820P00000000000
00H0oooo00<0P82000000020P8001@3oool00`20P8000000000000040?ooo`80000000<0@4100?oo
o`3oool0303oool3000000H0oooo00<0P8200000000000001P3oool3000000D0oooo00<0`<300000
0010@4001P3oool2000000030820P03oool0oooo00<0oooo0`0000060?ooo`030820P00000000000
02X0oooo0P0000000`10@400oooo0?ooo`060?ooo`800000203oool01020P800000000000020P804
0?ooo`<000001P3oool00`20P8000000000000060?ooo`80000000<0@4100820P03oool00`3oool0
1020P80000000000000000050?ooo`030410@0000000oooo00H0oooo00@0P820000000000000P820
>P3oool2000000030820P03oool0oooo00D0oooo1000000:0?ooo`030410@0000000000000@0oooo
00D0`<3000000000000000000820P0040?ooo`030<30`03oool0oooo00<0oooo0`0000070?ooo`<0
00003@3oool01020P80000000000000000050?ooo`030820P000000000000:T0oooo4oooool0017o
ooooM@3oool00`20P80000000000000B0?ooo`<000001P3oool3000000L0oooo00<0P82000000000
00000`0000060?ooo`030820P0000000000000L0oooo00<0P82000000020P800103oool00`20P800
0000000000040?ooo`80000000<0P8200?ooo`3oool0303oool3000000H0oooo00<0P82000000000
00001P3oool3000000L0oooo0P0000050?ooo`80000000<0P8200?ooo`3oool00`3oool3000000H0
oooo00<0P820000000000000:@3oool4000000@0oooo00<000000?ooo`3oool00P3oool2000000L0
oooo0P0000000`20P800oooo0?ooo`030?ooo`<000001P3oool00`20P8000000000000060?ooo`80
000000<0P8200000000000000P3oool01020P80000000000000000060?ooo`030820P0000000P820
00H0oooo0`0000000`20P800oooo0?ooo`0h0?ooo`80000000<0P8200?ooo`3oool01@3oool30000
00<0oooo00<0P8200000003oool01@3oool00`20P8000000000000040?ooo`030820P00000000000
00H0oooo00<0P8200?ooo`3oool00`3oool3000000L0oooo0`0000060?ooo`0300000020P800oooo
00D0oooo0`0000050?ooo`030820P000000000000:T0oooo4oooool0017oooooM@3oool00`20P800
00000000000;0?ooo`030<30`03oool0oooo00@0oooo0`0000060?ooo`<000001@3oool00`30`<00
000000000003000000030820P030`<00oooo00D0oooo00<0P820000000000000203oool30820P004
0<30`03oool0oooo0820P0800000103oool2000000030820P03oool0oooo00`0oooo0`0000060?oo
o`030820P0000000000000H0oooo0`0000070?ooo`040<30`020P800P8200820P0<0oooo0P000000
0`20P800oooo0?ooo`030?ooo`<000001P3oool00`20P80000000000000W0?ooo`030<30`020P800
0000008000000P20P8000`10@400000000000002000000<0oooo00<0`<3000000010@400103oool0
1020P80000000410@020P8050?ooo`040<30`00000000000000000H0oooo00<0@410000000000000
103oool01`20P8000000000000000000P8200?ooo`20P8001@0000000`10@400oooo0?ooo`050?oo
o`030820P010@400P82000<0oooo00<0`<300000000000000P0000000`20P800oooo0?ooo`0h0?oo
o`80000000<0@4100?ooo`3oool0103oool01010@40000000000000000030?ooo`<000001@3oool0
0`20P8000000000000040?ooo`030820P0000000P82000H0oooo00<0@4100?ooo`3oool00`3oool3
000000L0oooo0`0000050?ooo`030820P0000000000000H0oooo0`0000050?ooo`040820P0000000
00000820P:P0oooo4oooool0017oooooM@3oool00`20P80000000000000;0?ooo`030820P03oool0
oooo00@0oooo0`0000060?ooo`<000001@3oool5000000T0oooo00<0P8200000000000002`3oool0
1020P800000000000020P802000000@0oooo0P0000000`20P800oooo0?ooo`0<0?ooo`<000001P3o
ool00`20P8000000000000060?ooo`<000002`3oool2000000040?ooo`00000000000820P0D0oooo
0`0000060?ooo`030820P0000000000002/0oooo00@000000820P03oool0oooo0`0000070?ooo`D0
00001`3oool5000000@0oooo1@0000070?ooo`0300000020P800oooo0080oooo1000000;0?ooo`@0
000000D0oooo0820P000000000000820P00j0?ooo`D000000`3oool4000000040820P03oool0oooo
0?ooo`<000001@3oool00`20P80000000820P0050?ooo`0300000020P800oooo00D0oooo00<00000
0?ooo`3oool00`3oool3000000L0oooo0`0000050?ooo`030820P0000000000000H0oooo0P000006
0?ooo`@000000`3oool00`20P80000000?ooo`2R0?oooa?ooooo000AooooogD0oooo00<0P8200000
000000002@3oool00`30`<0000000820P0060?ooo`<000001P3oool3000000@0oooo00D0P8200000
00000000@4100820P0040?ooo`030820P03oool0oooo00<0oooo00<0P8200000000000003P3oool0
0`10@4000000000000040?ooo`030820P0000000P82000h0oooo0`0000060?ooo`030820P0000000
000000H0oooo0`00000=0?ooo`040820P000000000000820P0D0oooo0`0000060?ooo`030820P000
0000000007<0oooo00@0P820000000000000P820>P3oool200000080P8201`0000000`20P800oooo
0?ooo`020?ooo`040<30`000000000000<30`0<0oooo00@0P820000000000000`<301@3oool00`20
P80000000820P0030?ooo`030820P0000000000000<0oooo00<0P8200410@00000000P0000070?oo
o`<000001P3oool00`20P80000000820P0030?ooo`040<30`000000000000820P0@0oooo0P20P803
000000030?ooo`10@400P82000<0000000<0P8200?ooo`3oool0X03ooolCooooo`004Ooooome0?oo
o`030820P0000000000000/0000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000040?oo
o`<000001P3oool00`000000oooo0?ooo`030?ooo`030820P0000000000000L0oooo00<000000?oo
o`3oool0103oool00`20P8000000000000040?ooo`030820P0000000P82000L0oooo0P0000000`20
P800oooo0?ooo`020?ooo`<000001P3oool00`20P8000000000000060?ooo`<000001P3oool00`00
0000P8200?ooo`050?ooo`80000000<0P8200?ooo`3oool00`3oool3000000H0oooo00<0P8200000
00000000L`3oool01020P800000000000020P80j0?ooo`80000000@0P8200?ooo`3oool0P8200`00
00000`20P800oooo0?ooo`070?ooo`030820P000000000000080000000<0P8200?ooo`3oool01`3o
ool4000000030820P03oool0P82000H0oooo00<0P8200000003oool01P3oool3000000T0oooo1@00
000:0?ooo`040000003oool0oooo0?ooo`<00000X`3ooolCooooo`004Ooooome0?ooo`030820P000
0000000000/0000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000040?ooo`8000001`3o
ool00`000000oooo0?ooo`030?ooo`030820P0000000000000H0oooo0`0000050?ooo`030820P000
0000000000D0oooo0P0000070?ooo`<00000103oool3000000H0oooo00<0P8200000000000001P3o
ool3000000D0oooo00<0P8200000000000001P3oool2000000030820P03oool0oooo00<0oooo0`00
00060?ooo`030820P0000000000007<0oooo00@0P820000000000000P820>P3oool2000000030820
P03oool0oooo03<0oooo0`0000320?oooa?ooooo000AooooogD0oooo00<0P8200000000000002@3o
ool00`30`<0000000820P0060?ooo`<000001P3oool3000000@0oooo00<0P8200000003oool01@3o
ool00`20P80000000?ooo`040?ooo`030820P0000000000000H0oooo0`0000050?ooo`030820P000
0000@41000H0oooo00<000000820P03oool0103oool01020P80000000000000000040?ooo`<00000
00<0P8200410@03oool00P3oool01020P800000000000010@4060?ooo`<000001@3oool00`20P800
0000000000060?ooo`80000000<0`<300?ooo`3oool00`3oool3000000030820P010@400oooo0080
oooo00@0P820000000000000@410L`3oool01020P800000000000020P80j0?ooo`80000000<0P820
0?ooo`3oool0<`3oool300000<80oooo4oooool0017oooooM@3oool00`20P80000000000000;0?oo
o`030820P03oool0oooo00@0oooo0`0000060?ooo`<000001@3oool2000000D0oooo0P0000050?oo
o`030820P0000000000000L0oooo0P0000050?ooo`80000000<0P8200?ooo`3oool0103oool00`20
P8000000000000040?ooo`040820P000000000000820P0@0oooo0`0000000`3oool0P82000000005
000000030820P03oool0oooo0080oooo1@0000060?ooo`8000001@3oool3000000@0oooo1@000000
0`3oool0P82000000005000000030820P03oool0oooo0740oooo00@0P820000000000000P820>P3o
ool2000000030820P03oool0oooo03<0oooo0`0000320?oooa?ooooo000AooooogD0oooo00<0P820
0000000000002`3oool00`30`<00oooo0?ooo`020?ooo`030820P0000000000000800000103oool0
0`20P800000000000002000000D0oooo00<0`<300820P010@4000P20P8001010@400P8200820P000
00030?ooo`030<30`020P800@410008000001020P8030?ooo`030<30`020P800P82000<0P82000<0
00000410@020P8002@3oool50820P00300000020P800P82000D0oooo0`0000020?ooo`80P8200`00
00000`20P800oooo0?ooo`040?ooo`80P8200P0000070?ooo`D0P82000<0@41000000020P8001P3o
ool01030`<00P8200410@00000020?ooo`030820P010@40000000080000000<0P8200?ooo`3oool0
B03oool20820P2H0oooo00<0`<300820P010@4000P0000000`20P800oooo0?ooo`0h0?ooo`800000
00<0P8200?ooo`3oool0<`3oool300000<80oooo4oooool0017oooooM@3oool00`20P80000000000
000a0?ooo`<000009P3oool3000007d0oooo00<000000?ooo`3oool09`3oool3000000030820P03o
ool0oooo03P0oooo0P0000000`20P800oooo0?ooo`0c0?ooo`<00000`P3ooolCooooo`004Ooooome
0?ooo`030820P000000000000340oooo00<0`<300000000000009P3oool3000007`0oooo0P20P80[
0?ooo`030820P030`<00oooo03L0oooo0P20P802000000030820P03oool0oooo02T0oooo00<0P820
00000020P8001@3oool20820P0<00000`P3ooolCooooo`004Ooooome0?ooo`030820P00000000000
03<0oooo00<000000?ooo`3oool0903oool3000007/0oooo0P00001W0?ooo`<0000000<0P8200?oo
o`3oool0:@3oool3000000H0oooo100000320?oooa?ooooo000AooooogD0oooo00<0P82000000000
00003@3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo02@0oooo0`00001k0?ooo`03
0000003oool0oooo06P0oooo00<000000820P03oool0:`3oool00`000000oooo0?ooo`070?ooo`03
0820P0000000oooo0<40oooo4oooool0017oooooM@3oool00`20P80000000000000<0?ooo`800000
9@3oool00`30`<00oooo0?ooo`0T0?ooo`<00000NP3oool20820P8T0oooo00<0P8200<30`03oool0
fP3ooolCooooo`004Ooooome0?ooo`<000002`3oool3000004`0oooo0`00000?0?ooo`030820P000
0000oooo06P0oooo00<000000?ooo`3oool0Q`3oool00`20P80000000820P03K0?oooa?ooooo000A
ooooog<0oooo00<0P8200000000000004000000n0?ooo`030820P03oool0oooo00T0oooo00<0P820
0410@00000000P00000?0?ooo`<00000I`3oool00`000000`<300?ooo`280?ooo`030820P0000000
oooo0=/0oooo4oooool0017oooooa03oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00d0oooo00<0P8200000003oool0IP3oool00`20P80000000?ooo`290?ooo`800000g03ooolCoooo
o`004Oooooo30?ooo`030820P0000000P82008L0oooo00<000000?ooo`3oool0R@3oool00`000000
oooo0?ooo`3K0?oooa?ooooo000Aoooool<0oooo00<0P820000000000000QP3oool00`000000P820
0?ooo`290?ooo`800000g@3ooolCooooo`004Oooooo30?ooo`<00000QP3oool00`000000oooo0?oo
o`290?ooo`0300000020P800oooo0=`0oooo4oooool0017ooooo``3oool3000000030<30`03oool0
oooo0840oooo00<0`<3000000020P800RP3oool00`20P80000000820P03M0?oooa?ooooo000Aoooo
ol80oooo100000000`20P800oooo0?ooo`210?ooo`030820P03oool0oooo08X0oooo0P00003N0?oo
oa?ooooo000Aoooool80oooo100000000`10@400oooo0?ooo`210?ooo`030410@03oool0oooo08T0
oooo00<0`<30000000000000gP3ooolCooooo`004Oooooo10?ooo`030820P0000000000000<00000
PP3oool00`000000P8200?ooo`2:0?ooo`030820P0000000oooo0=h0oooo4oooool0017ooooo`@3o
ool00`20P80000000000000300000840oooo00<0P8200000003oool0R`3oool00`20P80000000?oo
o`3N0?oooa?ooooo000Aoooool40oooo00<0@410000000000000100000200?ooo`030410@03oool0
oooo08/0oooo00<000000820P03oool0gP3ooolCooooo`004Oooooo10?ooo`L00000P03oool00`20
P800oooo0?ooo`2;0?ooo`030000003oool0oooo0=h0oooo4oooool0017oooooD@3ooom>0820P240
oooo00<0P8200000000000001@0000000`30`<00oooo0?ooo`0M0?ooo`80P8201@00001H0820P003
00000010@400P82008/0P8200P0000140820P9`0oooo4oooool0017oooooCP3ooomD000001h0oooo
200000000`20P800oooo0?ooo`0J0?ooool00000>@00002J0?oooa?ooooo000AooooodX0oooo0P20
P81H00000080P8206@3oool00`20P800000000000006000000030410@03oool0oooo01P0oooo00<0
P8200410@0000000o`00000k00000080P820U@3ooolCooooo`004Ooooom80?ooo`T0000000<0BDU9
09:BTP2BTY80B`2BTY88000001P0oooo2P00000I0?ooo`030820P0000000000000@00000G02BTY80
0`000000BDU909:BTP2<09:BTP0304U9B@000000TY:B04<0TY:B2@00002D0?oooa?ooooo000Aoooo
odL0oooo200000000`19BDT0TY:B09:BTP1?09:BTPL000005`3oool:000001P0oooo1P00001M09:B
TP800000SP2BTY800`19BDT0000009:BTP1509:BTPT00000TP3ooolCooooo`004Ooooom40?ooo`03
0820P010@400000000<0000000@09BDU04U9B@19BDT0KVi^E@2BTY800`19BDT09BDU000000030000
00030410@020P800oooo0180oooo00<0`<300000000000002@00000F0?ooo`050410@00000000000
00000019BDT0GP2BTY800`1^KVh0000009:BTP2>09:BTP030000002BTY80TY:B04P0TY:B00<0BDU9
02DU9@0000000`0000000`10@400P8200?ooo`2?0?oooa?ooooo000Aoooood<0oooo1P00001L09:B
TPH0000000<0P8200?ooo`3oool0403oool00`20P800000000000009000001@0oooo100000000`19
BDT0TY:B09:BTP1N09:BTP030000002BTY80TY:B08h0TY:B00<0000009:BTP2BTY80B`2BTY860000
08l0oooo4oooool0017ooooo@@3oool00`20P8000000000000030000000304U9B@1^KVh0TY:B05d0
TY:B00<0KVi^0000000000000P00000B0?ooo`030410@0000000000000T0000000<0`<300?ooo`3o
ool03`3oool00`20P800@410000000020000000304U9B@2BTY80TY:B05h0TY:B00<0BDU902DU9@2B
TY80SP2BTY800`000000BDU909:BTP1=09:BTP0304U9B@000000000000<0000000<0P8200?ooo`3o
ool0R`3ooolCooooo`004Ooooom00?ooo`D0000000<0BDU909:BTP2BTY80H@2BTY8400000140oooo
300000000`20P800oooo0?ooo`0?0?ooo`@00000HP2BTY800`000000TY:B09:BTP2>09:BTP030000
0019BDT0TY:B04l0TY:B00<0BDU90000000000000`00002<0?oooa?ooooo000Aoooooch0oooo00<0
P8200000000000000P0000000`0U9BD0TY:B09:BTP1S09:BTP0306i^KP19BDT00000008000003`3o
ool00`20P80000000000000:000000030410@03oool0oooo00h0oooo00D0@4100000000000000000
04U9B@1Q09:BTP0302DU9@19BDT0TY:B08h0TY:B00<0BDU90000001^KVh0DP2BTY800`1^KVh00000
00000002000000030820P03oool0oooo08P0oooo4oooool0017ooooo?@3oool6000006P0TY:B00@0
BDU9000000000000P8203P3oool>00000100oooo0`00001S09:BTP030000002BTY80TY:B08h0TY:B
00<0BDU90000002BTY80E02BTY85000008T0oooo4oooool0017ooooo?@3oool5000006T0TY:B00@0
BDU900000000000000003P3oool>000000l0oooo0`0000000`19BDT0TY:B09:BTP1P09:BTP030000
0019BDT0TY:B08l0TY:B0P00001F09:BTP@00000R@3ooolCooooo`004Oooooll0?ooo`050410@000
0000000000000019BDT0J`2BTY801@19BDT00000000000000000P82000/0oooo00<0P82000000000
00003@00000=0?ooo`040<30`0000000000000000680TY:B00<0KVi^0000002BTY80T02BTY800`00
0000TY:B09:BTP1F09:BTP0404U9B@00000000000410@8P0oooo4oooool0017ooooo?03oool20000
000304U9B@2BTY80TY:B06d0TY:B0`00000;0?ooo`030820P0000000000000d000003@3oool00`20
P80000000000001S09:BTP030000002BTY80TY:B08l0TY:B0P00001I09:BTP0404U9B@0000000000
000008L0oooo4oooool0017ooooo>P3oool01@30`<000000000000000000KVi^06l0TY:B00@09BDU
000000000000P8202P3oool00`10@40000000000000=000000030820P03oool0oooo00X0oooo0P00
00000`0U9BD0TY:B09:BTP1P09:BTP0304U9B@0U9BD0TY:B0900TY:B00<0000004U9B@2BTY80F@2B
TY801019BDT0000000000010@4260?oooa?ooooo000AooooocX0oooo0`00001a09:BTP0404U9B@00
00000000000000X0oooo4@00000;0?ooo`<00000H`2BTY800`000000TY:B09:BTP2?09:BTP800000
00<0BDU909:BTP2BTY80F@2BTY801019BDT000000000000000250?oooa?ooooo000AooooocT0oooo
0`0000000`19BDT0TY:B09:BTP1`09:BTP<000002`3oool>000000d0oooo0`00001R09:BTP800000
T@2BTY82000005`0TY:B00<0BDU90000000000000P0000240?oooa?ooooo000AooooocT0oooo0`00
00000`1^KVh0TY:B09:BTP1`09:BTP@000002`3oool01030`<00P8200820P010@402000000<0P820
403oool01020P800000000000000001Q09:BTP80BDU9T@2BTY800`1^KVh000000000001M09:BTP05
04U9B@000000000000000030`<00P`3ooolCooooo`004Ooooolh0?ooo`<00000M@2BTY83000000h0
oooo0`00000C0?ooo`<00000HP2BTY800`000000TY:B09:BTP2@09:BTP0304U9B@000000TY:B05h0
TY:B0`0000000`20P800oooo0?ooo`210?oooa?ooooo000AooooocL0oooo00@0P820000000000000
9BDUM@2BTY83000000030<30`03oool0oooo00/0oooo0P0000000`20P800oooo0?ooo`0@0?ooo`04
0<30`0000000000000000640TY:B00<0000004U9B@2BTY80T@2BTY800`0U9BD0000009:BTP1N09:B
TP0404U9B@0000000000000008<0oooo4oooool0017ooooo=`3oool3000007H0TY:B00@0BDU90000
00000000P8203@3oool2000000030820P03oool0oooo0100oooo00@0P820000000000000BDU9H02B
TY800`19BDT0000009:BTP2B09:BTP030000002BTY80TY:B05l0TY:B100000220?oooa?ooooo000A
ooooocH0oooo00@0P820000000000000BDU9MP2BTY801019BDT0000000000020P80<0?ooo`<00000
00<0`<300?ooo`3oool0403oool30000000304U9B@2BTY80TY:B05h0TY:B00<09BDU09:BTP2BTY80
T@2BTY800`19BDT0000009:BTP1P09:BTP0504U9B@000000000000000030`<00P@3ooolCooooo`00
4Ooooolf0?ooo`<00000M`2BTY801019BDT0000000000020P80<0?ooo`<000004`3oool300000003
04U9B@2BTY80TY:B05d0TY:B00<0000004U9B@2BTY80TP2BTY800`000000BDU909:BTP1Q09:BTP<0
000000<0P8200?ooo`3oool0O`3ooolCooooo`004Ooooole0?ooo`030820P0000000000007P0TY:B
00@0BDU900000000000000002`3oool4000001<0oooo0`0000000`19BDT0TY:B09:BTP1M09:BTP03
00000019BDT0TY:B0980TY:B00<0000004U9B@2BTY80HP2BTY8300000840oooo4oooool0017ooooo
=@3oool00`10@40000000000001i09:BTP<000002`3oool3000001@0oooo0`00001O09:BTP030000
0019BDT0TY:B0980TY:B00<0BDU90000001^KVh0H`2BTY80100U9BD0000000000020P8200?oooa?o
oooo000AooooocD0oooo0P0000000`19BDT0TY:B09:BTP1g09:BTP<000002`3oool3000001@0oooo
0`00001N09:BTP0304U9B@000000TY:B09<0TY:B00<0BDU90000002BTY80I02BTY8300000800oooo
4oooool0017ooooo=@3oool20000000306i^KP2BTY80TY:B07L0TY:B0`00000:0?ooo`040820P000
000000000410@1@0oooo0`00001N09:BTP030000002BTY80TY:B09<0TY:B00<0000004U9B@2BTY80
I02BTY83000000030820P03oool0oooo07d0oooo4oooool0017ooooo=03oool3000007X0TY:B0`00
000:0?ooo`040820P000000000000820P1@0oooo0`00001M09:BTP0300000019BDT0TY:B09@0TY:B
00<0000009:BTP2BTY80I@2BTY83000007l0oooo4oooool0017ooooo=03oool20000000304U9B@2B
TY80TY:B07L0TY:B00@0KVi^000000000000@4102P3oool3000000030820P03oool0oooo0180oooo
0`0000000`19BDT0TY:B09:BTP1I09:BTP0306i^KP000000TY:B09@0TY:B00<0000002DU9@2BTY80
IP2BTY83000007l0oooo4oooool0017ooooo<`3oool3000007X0TY:B00@0BDU9000000000000P820
2P3oool3000001D0oooo0`0000000`19BDT0TY:B09:BTP1I09:BTP030000002BTY80TY:B09@0TY:B
00<0000004U9B@2BTY80IP2BTY83000000030820P03oool0oooo07`0oooo4oooool0017ooooo<`3o
ool20000000304U9B@2BTY80TY:B07P0TY:B00@0BDU9000000000000P8202@3oool4000001D0oooo
0`0000000`19BDT0TY:B09:BTP1I09:BTP030000002BTY80TY:B09<0TY:B0P0000000`19BDT0TY:B
09:BTP1U09:BTP0404U9B@00000000000820P7h0oooo4oooool0017ooooo<P3oool01020P8000000
00000000001j09:BTP0402DU9@00000000000820P0P0oooo00@0`<3000000000000000005P3oool0
1020P800000000000000001J09:BTP030000001^KVh0TY:B09@0TY:B0P00001X09:BTP0404U9B@00
000000000820P7h0oooo4oooool0017ooooo<P3oool01020P800000000000000001j09:BTP<00000
2@3oool01020P800000000000000000G0?ooo`<00000F@2BTY800`19BDT0000009:BTP2D09:BTP03
04U9B@000000000006P0TY:B00@0BDU9000000000000P820OP3ooolCooooo`004Ooooolb0?ooo`04
0820P00000000000000007T0TY:B00@0BDU900000000000000002@3oool00`10@40000000000000H
0?ooo`<0000000<0BDU909:BTP2BTY80EP2BTY800`000000TY:B09:BTP2D09:BTP0304U9B@000000
TY:B06P0TY:B00@0BDU9000000000000P820OP3ooolCooooo`004Ooooolb0?ooo`040820P0000000
0000000007T0TY:B0`00000:0?ooo`80000000<0P8200?ooo`3oool05`3oool3000005L0TY:B00<0
000004U9B@2BTY80U@2BTY82000006X0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`000000
0`19BDT0TY:B09:BTP1f09:BTP0406i^KP0000000000000000T0oooo0`0000000`30`<00oooo0?oo
o`0G0?ooo`040820P0000000000006i^KUD0TY:B0P00002G09:BTP030000002BTY80TY:B06T0TY:B
0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP1f09:BTP@00000203o
ool01020P800000000000000000K0?ooo`<00000E02BTY800`19BDT0000009:BTP2G09:BTP030000
002BTY80TY:B06T0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:B
TP1f09:BTP<000002@3oool01020P800000000000000000K0?ooo`030820P0000000000005@0TY:B
00<0BDU90000002BTY80UP2BTY800`000000BDU909:BTP1Z09:BTP<00000OP3ooolCooooo`004Ooo
oolb0?ooo`<0000000<0BDU909:BTP2BTY80M02BTY801@19BDT00000000000000000P82000T0oooo
0`00000L0?ooo`040<30`0000000000000000580TY:B00<0BDU902DU9@2BTY80U`2BTY800`000000
BDU909:BTP1Z09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80
M02BTY84000000T0oooo0`0000000`20P800oooo0?ooo`0K0?ooo`<0000000<0BDU909:BTP2BTY80
C`2BTY800`000000BDU909:BTP2F09:BTP0304U9B@000000TY:B06/0TY:B0`00001n0?oooa?ooooo
000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP1c09:BTP0402DU9@00000000000410@0T0oooo
100000000`30`<00oooo0?ooo`0K0?ooo`050820P0000000000000000019BDT0C`2BTY800`19BDT0
000009:BTP2G09:BTP0304U9B@000000TY:B06/0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo
0`0000000`19BDT0TY:B09:BTP1b09:BTP@0000000<0P8200?ooo`3oool01P3oool01020P8000000
00000000000P0?ooo`030820P0000000000000800000CP2BTY800`000000TY:B09:BTP2G09:BTP03
0000002BTY80TY:B06/0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B
09:BTP1a09:BTP0304U9B@0000000000008000002@3oool01020P800000000000000000P0?ooo`03
0820P0000000000000800000C@2BTY800`000000BDU909:BTP2H09:BTP030000002BTY80TY:B06/0
TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP1_09:BTP0306i^
KP19BDT000000080000000<0P8200?ooo`3oool0203oool3000000030820P03oool0oooo01l0oooo
00<0P8200000000000000P0000000`19BDT0TY:B09:BTP1809:BTP0306i^KP000000KVi^09P0TY:B
00<0BDU902DU9@2BTY80K02BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2B
TY80TY:B06l0TY:B100000000`20P800oooo0?ooo`080?ooo`@00000903oool40000000304U9B@2B
TY80TY:B04L0TY:B00<0BDU909:BTP2BTY80V02BTY800`000000BDU909:BTP1/09:BTP<00000OP3o
oolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80K02BTY800`1^KVh0BDU900000002
000000030410@020P800oooo00T0oooo00D0P82000000000000000000820P00V0?ooo`050410@000
0000000000000019BDT0AP2BTY800`19BDT09BDU09:BTP2H09:BTP0306i^KP000000KVi^06d0TY:B
0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP1[09:BTPH00000303o
ool3000002T0oooo1P00001409:BTP0300000019BDT0TY:B09P0TY:B00<0BDU90000002BTY80K@2B
TY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B06L0TY:B0P19BDT6
000000030410@03oool0oooo00T0oooo00D0`<3000000000000000000820P00Z0?ooo`030<30`000
0000000000@000000P19BDTn09:BTP0306i^KP000000BDU909X0TY:B00<09BDU04U9B@2BTY80K@2B
TY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B0540TY:B7@00000=
0?ooo`@00000;@3oool00`20P80000000000003k0000000304U9B@2BTY80TY:B0540TY:B0`00001n
0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP1=09:BTQl0000000<0P8200?oo
o`3oool02`3oool4000002l0ooooo`00000200000500TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo0`0000000`19BDT0TY:B09:BTP1909:BTP80BDU97@0000020820P0h0oooo00<0@41000000000
00000P0000000`30`<00oooo0?ooo`0`0?ooo`80P820o`00000204U9BD/0TY:B0`00001n0?oooa?o
oooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP1609:BTQd00000503oool5000003X0oooo
00<0P8200000000000002`0000000`19BDT0TY:B09:BTP0M09:BTP@000001`3Hf=P00`1/K6`00000
0=SHf02K0=SHf0030000001/K6`0f=SH01D0f=SH00<0K6a/0000000000003@00001909:BTP<00000
OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80A02BTY800`0U9BD000000000
0004000000030410@020P800P8200280oooo0`20P80600000080P820AP3oool30000000304U9B@2B
TY80TY:B01d0TY:B100000070=SHf00303Hf=P1/K6`0f=SH09X0f=SH0P0000000`2RXZ80f=SH0=SH
f00L0=SHf0030:b/[01/K6`0@41000L0000000<0BDU906i^KP2BTY80A02BTY83000007h0oooo4ooo
ool0017ooooo<P3oool30000000304U9B@2BTY80TY:B0480TY:B00<0BDU900000000000010000000
0`20P800oooo0?ooo`0T0?ooo`P0000000<0P8200?ooo`3oool0AP3oool30000000304U9B@2BTY80
TY:B01d0TY:B100000070=SHf0030000003Hf=P0f=SH09X0f=SH0P00000S0=SHf0030>c/k0000000
000000D00000A@2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B
03l0TY:B00<0KVi^04U9B@0000000`0000000`20P800oooo0?ooo`0Y0?ooo`80000000@0@4100820
P020P800P820BP3oool30000000304U9B@2BTY80TY:B01d0TY:B100000050=SHf00306a/K0000000
XZ:R09/0f=SH00<0K6a/0000001/K6`09P3Hf=P00`3/k>`0oooo0820P0040000000304U9B@2BTY80
TY:B0400TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0o09:B
TPD00000O@3oool30000000304U9B@2BTY80TY:B01d0TY:B100000050=SHf0800000W03Hf=P00`1/
K6`000000=SHf00Y0=SHf0030?ooo`000000000000<00000@@2BTY83000007h0oooo4oooool0017o
oooo<P3oool30000000304U9B@2BTY80TY:B03d0TY:B00<0BDU90000000000000P0000000`20P800
oooo0?ooo`1l0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY84000000@0f=SH00<0K6a/0000003H
f=P0W03Hf=P2000002/0f=SH00<0k>c/0000000000000`00001009:BTP<00000OP3ooolCooooo`00
4Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80?02BTY801@19BDT00000000000000000P8200800
oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@00000103Hf=P00`0f=SH0K6a/0=SHf02L0=SHf003
0000003Hf=P0f=SH02`0f=SH00<0K6a/0000000000000P0000000`19BDT0TY:B09:BTP0l09:BTP<0
0000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80>`2BTY84000000030820
P03oool0oooo07l0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@000000`3Hf=P00`000000K6a/
0=SHf02L0=SHf0800000;`3Hf=P00`3/k>`0000000000003000003d0TY:B0`00001n0?oooa?ooooo
000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0j09:BTP<0000000<0@4100820P03oool0P@3o
ool30000000304U9B@2BTY80TY:B01d0TY:B100000020=SHf0030::RXP000000XZ:R09d0f=SH00<0
000006a/K03Hf=P0;`3Hf=P00`3/k>`0=SHf00000003000003`0TY:B0`00001n0?oooa?ooooo000A
oooooc80oooo0`0000000`19BDT0TY:B09:BTP0i09:BTP@00000Q03oool30000000304U9B@2BTY80
TY:B01d0TY:B100000020=SHf00306a/K0000000f=SH09`0f=SH00<0K6a/0000001/K6`0<P3Hf=P0
1@3oool00000000000000000BDU903/0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`000000
0`19BDT0TY:B09:BTP0h09:BTP0404U9B@0000000000000008D0oooo0`0000000`19BDT0TY:B09:B
TP0M09:BTP@000000P3Hf=P00`000000f=SH0=SHf02L0=SHf00306a/K0000000f=SH03<0f=SH00@0
oooo0000000000000000>`2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2B
TY80TY:B03L0TY:B00D0BDU900000000000000000820P0250?ooo`<0000000<0BDU909:BTP2BTY80
7@2BTY84000000030=SHf0000000K6a/09h0f=SH00<0=SHf0000003Hf=P0=03Hf=P0102f][H00000
00000000000j09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80
=P2BTY800`19BDT0000000000002000008H0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@00000
00<0K6a/0000003Hf=P0WP3Hf=P00`000000f=SH0=SHf00e0=SHf0<0000000<0BDU909:BTP2BTY80
=`2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B03D0TY:B00D0
BDU900000000000000000820P0270?ooo`<0000000<0BDU909:BTP2BTY807@2BTY850000000306a/
K03Hf=P0f=SH09`0f=SH00<0K6a/0000003Hf=P0=`3Hf=P01010@400000000000019BDTh09:BTP<0
0000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80=@2BTY84000008P0oooo
0`0000000`19BDT0TY:B09:BTP0M09:BTP@0000000<0K6a/0=SHf03Hf=P0W@3Hf=P00`000000K6a/
0=SHf00g0=SHf0030>c/k0000000000000800000=`2BTY83000007h0oooo4oooool0017ooooo<P3o
ool30000000304U9B@2BTY80TY:B03@0TY:B100000000`30`<00oooo0?ooo`260?ooo`<0000000<0
BDU909:BTP2BTY807@2BTY84000000030::RXP3Hf=P0f=SH09`0f=SH00<0XZ:R0000001/K6`0>@3H
f=P01@1/K6`00000000000000000BDU903H0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`00
00000`19BDT0TY:B09:BTP0c09:BTP0404U9B@0000000000000008X0oooo0`0000000`19BDT0TY:B
09:BTP0M09:BTP@00000W`3Hf=P00`1/K6`000000=SHf00j0=SHf00406a/K00000000000000003H0
TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0c09:BTP0404U9
B@0000000000000008X0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@00000W`3Hf=P00`1/K6`0
00000=SHf00j0=SHf00406a/K00000000000000003H0TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo0`0000000`19BDT0TY:B09:BTP0b09:BTP0504U9B@000000000000000020P800RP3oool30000
000304U9B@2BTY80TY:B01d0TY:B1000002O0=SHf00303Hf=P1/K6`0f=SH03/0f=SH00@0P8200000
000000000000=@2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B
0380TY:B1000002;0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY84000009l0f=SH00<000000=SH
f03Hf=P0?03Hf=P30000000304U9B@2BTY80TY:B0380TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo0`0000000`19BDT0TY:B09:BTP0a09:BTP0404U9B@0000000000000008`0oooo0`0000000`19
BDT0TY:B09:BTP0L09:BTP0304U9B@000000000000800000WP3Hf=P00`1/K6`0=SHf0=SHf00m0=SH
f0040>c/k0000000000004U9BC@0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19
BDT0TY:B09:BTP0a09:BTP0304U9B@000000000008d0oooo0`0000000`19BDT0TY:B09:BTP0L09:B
TPD00000WP3Hf=P00`000000K6a/0=SHf00n0=SHf0030820P0000000000003@0TY:B0`00001n0?oo
oa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0a09:BTP80000000<0@4100?ooo`3o
ool0R`3oool30000000304U9B@2BTY80TY:B01/0TY:B00<0BDU902DU9@0000000`00002M0=SHf003
06a/K0000000XZ:R03l0f=SH00@0[:b/0000000000000000<`2BTY83000007h0oooo4oooool0017o
oooo<P3oool30000000304U9B@2BTY80TY:B0340TY:B0P0000000`20P800oooo0?ooo`2;0?ooo`<0
000000<0BDU909:BTP2BTY806P2BTY800`19BDT0000009:BTP04000009d0f=SH0P0000110=SHf0<0
0000<`2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B0340TY:B
0P0000000`20P800oooo0?ooo`2;0?ooo`<0000000<0BDU909:BTP2BTY806P2BTY800`19BDT00000
09:BTP04000009d0f=SH0P0000110=SHf0<0000000<0BDU909:BTP2BTY80<02BTY83000007h0oooo
4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B0300TY:B0`0000000`30`<00oooo0?oo
o`2;0?ooo`<0000000<0BDU909:BTP2BTY806P2BTY800`000000TY:B09:BTP04000009`0f=SH00<0
K6a/0000003Hf=P0@@3Hf=P0103/k>`0000000000019BDTb09:BTP<00000OP3ooolCooooo`004Ooo
oolb0?ooo`<0000000<0BDU909:BTP2BTY80<02BTY83000008h0oooo0`0000000`19BDT0TY:B09:B
TP0I09:BTP0400000019BDT0TY:B09:BTP@00000W03Hf=P00`1/K6`000000=SHf0120=SHf0800000
00<0BDU909:BTP2BTY80<02BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2B
TY80TY:B02l0TY:B00@0BDU9000000000000P8205P3oool50820P0P0oooo0`20P8000`30`<00oooo
0?ooo`020?ooo`030<30`020P800`<3000<0oooo1`20P81F0?ooo`<0000000<0BDU909:BTP2BTY80
602BTY82000000<0TY:B1000002L0=SHf0030000003Hf=P0f=SH0480f=SH00<0@410000000000000
<P2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B00<0
BDU90000000000005@3oool8000000H0oooo00<0P8200000000000000`0000030?ooo`@000000`3o
ool00`20P800000000000002000005L0oooo0`0000000`19BDT0TY:B09:BTP0G09:BTP0304U9B@00
0000TY:B00<0TY:B1000002L0=SHf0030000003Hf=P0f=SH0480f=SH00<0K6a/000000000000<P2B
TY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B00<0BDU9
000000000000503oool00`10@400000000000002000000<0P82000<0@41000000030`<000`3oool0
1020P80000000000000000030820P00300000020P8000000008000000P20P80010000000oooo0?oo
o`3oool3000005P0oooo0`0000000`19BDT0TY:B09:BTP0G09:BTP0300000019BDT0TY:B00<0TY:B
1000002K0=SHf0030000001/K6`0f=SH04<0f=SH00<0K6a/000000000000<P2BTY83000007h0oooo
4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B00<0BDU9000000000000503o
ool4000000H0oooo00@000000?ooo`3oool0oooo0`0000000`20P800oooo0?ooo`020?ooo`040820
P00000000000000000H0oooo0`00001H0?ooobL00000V`3Hf=P00`000000K6a/0=SHf0130=SHf003
06a/K000000000000380TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B
09:BTP0_09:BTP0304U9B@000000000001<0oooo100000000`20P800oooo0?ooo`040?ooo`040820
P0000000oooo0?ooo`<000001P3oool3000000H0oooo0`00001H0?ooobL00000VP3Hf=P00`1/K6`0
00000=SHf0140=SHf00406a/K0000000000000000340TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0@4100?ooo`3oool04@3oool300000003
0820P03oool0oooo00H0oooo00<0P8200<30`03oool00`0000060?ooo`<000001P3oool3000005P0
oooo9`00002J0=SHf00306a/K0000000f=SH04@0f=SH00@0XZ:R0000000000000000<@2BTY830000
07h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800
oooo0?ooo`0@0?ooo`040820P00000000000000000d0oooo0P0000060?ooo`<000001P3oool30000
06`0oooo00<0P8200000000000000`0000000`3Hf=P000000=SHf02T0=SHf0030000003Hf=P0f=SH
04D0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2B
TY80;`2BTY82000000030820P03oool0oooo0100oooo00@0P820000000000000P8203@3oool00`30
`<0000000410@0050?ooo`<000001P3oool3000006/0oooo00T0P820000000000000000006a/K02R
XZ80f=SH0000001/K6`0Y@3Hf=P00`000000f=SH0=SHf0150=SHf0<00000<@2BTY83000000`0oooo
00<0P8200410@00000000`0000001@20P800oooo0?ooo`20P800@41000@0000000D0P8200?ooo`3o
ool0oooo0820P00300000080P8200P3oool00`30`<000000000000020820P0030?ooo`20P800@410
00@0000000H0P8200?ooo`3oool0oooo0820P010@403000000030410@020P800oooo0100oooo00<0
P8200000000000000P0000000`10@400P8200?ooo`060?ooo`030<30`020P800000000@0000000<0
P8200<30`03oool00`3oool20820P0@0000000H0P8200?ooo`3oool0oooo0820P010@40400000004
0820P03oool0oooo0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80
000000<0P8200?ooo`3oool0403oool00`20P80000000000000@0?ooo`800000103oool3000000H0
oooo0`00001Z0?ooo`@0000000<0K6a/0=SHf03Hf=P00P00000h0=SHf0<00000JP3Hf=P00`000000
K6a/0=SHf0160=SHf0<00000<@2BTY83000000h0oooo0`0000060?ooo`<00000103oool700000003
0820P03oool0000000@0000000<0P8200?ooo`3oool00`0000070?ooo`<000004P3oool800000003
0820P03oool0oooo00@0oooo2@0000060?ooo`030820P0000000000000L0oooo0`0000050?oooa?o
oooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0
403oool00`20P80000000000000B0?ooo`040000003oool0oooo0?ooo`<000001P3oool3000006T0
oooo00<0P8200000000000000P0000020=SHf00306a/K0000000000003D0f=SH1P00001Z0=SHf003
0000001/K6`0f=SH04H0f=SH0`00000a09:BTP<000003P3oool3000000H0oooo0`0000030?ooo`03
0820P00000000000008000000`3oool4000000040820P03oool0oooo0820P080oooo0`0000070?oo
o`<000004@3oool5000000<0oooo0P0000050?ooo`D00000103oool2000000D0oooo00<0P8200000
000000001`3oool3000000D0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0
TY:B0P0000000`20P800oooo0?ooo`0@0?ooo`030820P0000000000000/0P820203oool30820P0<0
00001P3oool3000006P0oooo00D0P820000000000000000003Hf=P030=SHf00303Hf=P1/K6`0f=SH
0340f=SH0P1/K6`80000000306a/K03Hf=P0f=SH06H0f=SH00<0XZ:R0000002RXZ80A`3Hf=P30000
0340TY:B0`00000>0?ooo`<000001P3oool3000000<0oooo00@0P820000000000000@4101@3oool0
1020P800000000000020P8050?ooo`<000001`3oool300000100oooo00D0P8200000000000000000
0820P0050?ooo`030<30`0000000P8200080oooo00<0`<300000000000000P0000000`30`<00oooo
0?ooo`030?ooo`030820P010@400oooo00<0oooo00<0P8200000000000001`3oool3000000D0oooo
4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?oo
o`0A0?ooo`800000203oool3000000/0oooo0`0000060?ooo`<00000J03oool4000000@0f=SH00<0
00000=SHf03Hf=P0;P3Hf=P=0000000306a/K03Hf=P0f=SH06H0f=SH00<0K6a/0000003Hf=P0A`3H
f=P300000340TY:B0`00000>0?ooo`<000001P3oool3000000<0oooo00@0P820000000000000P820
1P3oool2000000030820P03oool0oooo00<0oooo0`0000070?ooo`<00000403oool3000000030820
P03oool0oooo00H0oooo00@000000?ooo`3oool0P8200`0000080?ooo`030820P03oool0oooo0080
oooo00<0P8200000000000001`3oool3000000D0oooo4oooool0017ooooo<P3oool30000000304U9
B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`0A0?ooo`030820P0000000P82000L0oooo
0P0000001`20P800oooo0?ooo`3oool0@41000000030`<001@3oool3000000H0oooo0`00001W0?oo
o`040820P00000000000000000<0f=SH00<0XZ:R0000002RXZ80;03Hf=P206a/K1000000J03Hf=P0
0`0f=SH0K6a/0=SHf0170=SHf0<00000<@2BTY83000000h0oooo0`0000060?ooo`<000000`3oool0
1030`<00000000000020P8060?ooo`80000000<0P8200?ooo`3oool00`3oool3000000L0oooo0`00
000?0?ooo`040820P00000000000000000X0oooo00<0`<300?ooo`10@4000P00000:0?ooo`050820
P03oool0oooo0?ooo`20P8000P0000070?ooo`<000001@3ooolCooooo`004Ooooolb0?ooo`<00000
00<0BDU909:BTP2BTY80;`2BTY82000000030820P03oool0oooo0180oooo0P0000060?ooo`030820
P0000000000000@0oooo0P0000000`20P800oooo0?ooo`030?ooo`<000001P3oool4000006H0oooo
00<0P820000000000000103Hf=P00`1/K6`000000=SHf00Y0=SHf1D00000J03Hf=P00`000000f=SH
0=SHf0170=SHf0<00000<@2BTY83000000h0oooo0`0000060?ooo`<000001@3oool2000000H0oooo
0P0000000`20P800oooo0?ooo`030?ooo`<000001`3oool3000000l0oooo00<0P820000000000000
3@3oool3000000h0oooo00<0P8200000000000001`3oool3000000D0oooo4oooool0017ooooo<P3o
ool30000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`0B0?ooo`040<30`000
000000000820P0<0oooo00@0P820000000000000P820103oool00`10@40000000820P0040?ooo`03
0<30`0000000000000D0oooo00<0P8200410@00000000P0000020820P0050?ooo`20P80000000000
0030`<00G`3oool01020P80000000000001/K6`30=SHf00306a/K0000000f=SH02H0f=SH0P1/K6`G
000006L0f=SH00<0K6a/03Hf=P3Hf=P0B03Hf=P300000340TY:B0`00000>0?ooo`<000001P3oool3
000000H0oooo00<0@41000000030`<00103oool2000000030820P03oool0oooo00<0oooo0`000007
0?ooo`<000003`3oool00`20P80000000000000=0?ooo`80000000<0P8200?ooo`3oool0303oool0
0`20P8000000000000070?ooo`<000001@3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:B
TP2BTY80;`2BTY82000000030820P03oool0oooo01@0oooo1`0000070?ooo`800000103oool20000
00030820P03oool0oooo00@0oooo00H0P82000000000000000000?ooo`20P804000000030820P03o
ool0oooo05d0oooo0`0000040=SHf0030000001/K6`0f=SH02<0f=SH;@00001F0=SHf0030000001/
K6`0f=SH04P0f=SH0`00000a09:BTP<000003P3oool3000000H0oooo0`0000080?ooo`030820P000
0000oooo0080oooo0P0000000`20P800oooo0?ooo`030?ooo`<000001`3oool3000000l0oooo00<0
P8200000000000003@3oool2000000030820P03oool0oooo00`0oooo00<0P8200000000000001`3o
ool3000000D0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P000000
0`20P800oooo0?ooo`0E0?ooo`030820P00000000000008000002P3oool5000000/0oooo00@00000
0?ooo`3oool0oooo0`00001O0?ooo`040820P00000000000000000<0f=SH00<0K6a/0000003Hf=P0
8P3Hf=Q=000003P0f=SH00<0000006a/K03Hf=P0B03Hf=P300000340TY:B0`00000>0?ooo`<00000
1P3oool3000000X0oooo0P000000103oool0000000000020P8050?ooo`<000001`3oool3000000l0
oooo00<0P8200000000000003@3oool2000000030820P03oool0oooo00`0oooo00<0P82000000000
00001`3oool3000000D0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B
0P0000000`20P800oooo0?ooo`2J0?ooo`040820P0000000000006a/K0<0f=SH00<0=SHf06a/K03H
f=P09@3Hf=P00`2RXZ80K6a/03Hf=P1E000000H0K6a/8`3Hf=P2000004X0f=SH0`00000a09:BTP<0
00003P3oool3000000H0oooo0`00000<0?ooo`040820P000000000000820P0D0oooo0`0000070?oo
o`<00000403oool2000000d0oooo00<0@41000000010@4001`20P8000`10@4000000000000040?oo
o`030820P0000000000000L0oooo0`0000050?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0
TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool00`20P8000000000000030=SHf080
0000:@3Hf=P00`1/K6`000000000001O000001d0f=SH0P00001:0=SHf0<00000<@2BTY83000000h0
oooo0`0000060?ooo`<000001@3oool00`000000P8200?ooo`050?ooo`80000000<0P8200?ooo`3o
ool00`3oool3000000L0oooo0`00000@0?ooo`800000203oool2000000<0oooo00<0P82000000020
P8001`3oool00`20P8000000000000040?ooo`030820P0000000000000L0oooo0`0000050?oooa?o
oooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0
VP3oool300000080f=SH00<0K6a/0000002RXZ80;P3Hf=P206a/K1800000:@3Hf=P:06a/K1/00000
1P1/K6`A0=SHf00306a/K0000000K6a/04X0f=SH0`00000a09:BTP<000003P3oool3000000030820
P030`<00oooo0080oooo00@0`<300000000000000000103oool3000000H0oooo0P0000000`20P800
oooo0?ooo`030?ooo`<000001`3oool3000000030<30`03oool0oooo00h0oooo00<0@4100000003o
ool01@3oool01020P80000000000000000030?ooo`8000001`3oool00`10@40000000820P0040?oo
o`030820P0000000000000L0oooo0`0000050?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0
TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool20000000306a/K03Hf=P0f=SH0080
0000=03Hf=P>0000000306a/K03Hf=P0f=SH03/0f=SH700000000`1/K6`0f=SH0=SHf0090=SHf003
06a/K0000000f=SH04X0f=SH0`00000a09:BTP<000003P3oool3000000030?ooo`000000oooo0080
oooo0`0000000`20P800oooo0?ooo`020?ooo`<000001P3oool2000000H0oooo0`0000060?ooo`05
0820P0000000000000000020P8000`3oool00`000000P8200?ooo`0:0?ooo`030820P0000000P820
00D0oooo100000040?ooo`8000001@3oool3000000D0oooo00<0P8200000000000001`3oool30000
00D0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800
oooo0?ooo`2J0?ooo`80000000@0K6a/0=SHf02RXZ800000=`3Hf=P306a/K0T0000000<0K6a/0=SH
f03Hf=P0@P3Hf=P706a/K1<000001@1/K6`20=SHf0030000001/K6`0f=SH04X0f=SH0`00000a09:B
TP<000003P3oool3000000030?ooo`30`<00000000D0000000<0`<300?ooo`3oool00`3oool00`20
P80000000820P0030?ooo`040<30`000000000000820P0@0oooo00<0P8200410@00000000P000005
0?ooo`030820P010@40000000080000000<0`<3000000020P8000`00000<0?ooo`030820P010@400
P82000<0oooo00@0`<30000000000000P8201@3oool01030`<00000000000010@4020820P0800000
00<0@4100820P03oool0103oool00`20P8000000000000070?ooo`<000001@3ooolCooooo`004Ooo
oolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03oool0oooo09X0oooo0P00
00000`1/K6`0f=SH0=SHf00m0=SHf0L00000D`3Hf=PE000004/0f=SH0`00000a09:BTP<000003P3o
ool3000000<0oooo00@0P82000000000000000002P3oool5000000T0oooo00<0P8200000003oool0
1`3oool00`20P80000000?ooo`020?ooo`80000000<0P8200?ooo`3oool03@3oool5000000X0oooo
100000080?ooo`030820P0000000000000L0oooo0`0000050?oooa?ooooo000Aoooooc80oooo0`00
00000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool20000000306a/K03H
f=P0f=SH0400f=SH1000001J0=SHf1400000B03Hf=P300000340TY:B0`00000>0?ooo`<00000F`3o
ool00`20P8000000000000070?ooo`<000001@3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU9
09:BTP2BTY80;`2BTY82000000030820P03oool0oooo09X0oooo0P0000000`1/K6`0f=SH0=SHf012
0=SHf080K6a/GP3Hf=P506a/K0/000000`1/K6a20=SHf0<00000<@2BTY83000000h0oooo0`00001K
0?ooo`030820P0000000000000L0oooo0`0000050?oooa?ooooo000Aoooooc80oooo0`0000000`19
BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool20000000306a/K03Hf=P0f=SH
0:T0f=SH00<0000006a/K00000003000000o0=SHf0<00000<@2BTY83000000h0oooo0`00001K0?oo
o`030820P0000000000000L0oooo0`0000050?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0
TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool20000000306a/K03Hf=P0f=SH0:P0
f=SH00<0K6a/0000003Hf=P00`3Hf=P306a/K00303Hf=P000000000000L000000P1/K6`00`2RXZ80
f=SH0=SHf00g0=SHf0<00000<@2BTY83000000h0oooo0`00001K0?ooo`030820P0000000000000L0
oooo0`0000050?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP800000
00<0P8200?ooo`3oool0VP3oool20000000306a/K03Hf=P0f=SH0:P0f=SH00<0K6a/0000003Hf=P0
2@3Hf=P00`1/K6`0000000000009000003L0f=SH0`00000a09:BTP<000003P3oool3000005/0oooo
00<0P8200000000000001`3oool3000000D0oooo4oooool0017ooooo<P3oool30000000304U9B@2B
TY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`2J0?ooo`80000000<0K6a/0=SHf03Hf=P0Z03H
f=P00`000000f=SH0=SHf00<0=SHf0`00000=03Hf=P300000340TY:B0`00000>0?ooo`<000007`3o
ool00`000000oooo0?ooo`0i0?ooo`030820P0000000000000L0oooo0`0000050?oooa?ooooo000A
oooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool2
0000000303Hf=P3Hf=P0f=SH0:P0f=SH00<000000=SHf03Hf=P03`3Hf=P306a/K0L0000000<0=SHf
06a/K01/K6`0<03Hf=P300000340TY:B0`00000<0?ooo`030820P010@4000000008000007P3oool3
000003P0oooo0P20P803000000D0oooo00<0P8200410@00000000P0000050?oooa?ooooo000Aoooo
oc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0VP3oool00`20
P80000000000002Y0=SHf0030000001/K6`0f=SH01D0f=SH00<0K6a/0000000000001P00000_0=SH
f0<00000<@2BTY83000000l0oooo00<0P8200000003oool07P3oool00`000000oooo0?ooo`0k0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool00`3ooolCooooo`004Ooooolb0?ooo`<0
000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03oool0oooo09X0oooo00<0P82000000000
0000Z@3Hf=P00`000000K6a/0=SHf00H0=SHf00306a/K0000000000000@0000000<0=SHf06a/K02R
XZ80:`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B
09:BTP0_09:BTP80000000<0P8200?ooo`3oool0V`3oool300000:L0f=SH0P00000M0=SHf0P00000
:P3Hf=P300000340TY:B0`00000L0?ooo`<00000G`3ooolCooooo`004Ooooolb0?ooo`<0000000<0
BDU909:BTP2BTY80;`2BTY82000000030820P03oool0oooo09/0oooo00<0P820000000000000Y`3H
f=P2000001l0f=SH00<0K6a/000000000000100000000`0f=SH0K6a/0=SHf00V0=SHf0<00000<@2B
TY83000001H0oooo00@0`<300820P020P800@4100P0000030820P5l0oooo4oooool0017ooooo<P3o
ool30000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`2L0?ooo`800000YP3H
f=P00`1/K6`000000=SHf00R0=SHf0L000009P3Hf=P300000340TY:B0`00000D0?ooo`D0000000<0
P8200?ooo`3oool0HP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82
000000030820P03oool0oooo09`0oooo0P0000000`1/K6`0f=SH0=SHf02S0=SHf00306a/K0000000
f=SH02<0f=SH00<0K6a/0000000000001000000U0=SHf0<00000<@2BTY8300000100oooo1P000000
0`20P800oooo0?ooo`1U0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:B
TP80000000<0P8200?ooo`3oool0403oool00`30`<00P82000000003000000050820P030`<00oooo
0?ooo`20P800100000020820P080oooo00<0P8200000000000000P0000001@10@400P8200?ooo`3o
ool0P82000@0000000<0@4100820P03oool0103oool00`30`<00P82000000003000000070820P030
`<00oooo00000010@400P8200<30`0050?ooo`030820P010@400000000<0000000@0P8200?ooo`20
P80000000P20P8030?ooo`030820P010@40000000080000000<0@4100820P03oool0103oool00`30
`<00P82000000004000000030820P030`<00oooo02d0oooo00@0P820000000000000K6a/Y03Hf=P0
0`0f=SH0K6a/0=SHf00U0=SHf00306a/K00f=SH0000000<000000P1/K6`R0=SHf0<00000<@2BTY83
000000X0oooo00@0`<300820P020P800@4100`0000030820P6X0oooo4oooool0017ooooo<P3oool3
0000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`0B0?ooo`040820P0000000
00000820P0H0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000L0oooo2000
00000`3oool0000000000003000000<0oooo00<0P8200000000000001P0000000`20P80000000000
0002000000040820P03oool0oooo0?ooo`<000001`3oool9000002h0oooo00<0P820000000000000
0P00002S0=SHf0030000003Hf=P0f=SH02P0f=SH1@00000R0=SHf0<00000<@2BTY83000000P0oooo
1@0000000`20P800oooo0?ooo`1^0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:B
TP0_09:BTP80000000<0P8200?ooo`3oool04P3oool01020P800000000000020P8060?ooo`800000
00<0P8200?ooo`3oool0103oool3000000H0oooo0`0000060?ooo`@0000000D0P8200?ooo`3oool0
oooo0<30`004000000D0oooo0`0000020820P0<0oooo00D0P82000000000000000000820P0050?oo
o`<000001P3oool4000000030410@03oool0oooo0080oooo00<0P82000000030`<00;@3oool01@20
P8000000000000000000K6a/0:40f=SH00<0K6a/03Hf=P3Hf=P0:@3Hf=P00`2RXZ80K6a/00000002
0000000303Hf=P1/K6`0f=SH01l0f=SH0`00000a09:BTP<000000P3oool30820P0<000000P20P800
0`30`<00oooo0?ooo`1a0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:B
TP80000000<0P8200?ooo`3oool04P3oool01020P800000000000020P8060?ooo`80000000<0P820
0?ooo`3oool0103oool3000000H0oooo0`0000050?ooo`040820P00000000000000000L0oooo0`00
00040?ooo`<0000000<0P8200?ooo`3oool0103oool01020P800000000000020P8050?ooo`<00000
1@3oool00`20P800000000000002000000L0oooo00<000000?ooo`3oool0;03oool400000:40f=SH
00<0000006a/K03Hf=P0;03Hf=P40000000306a/K03Hf=P0f=SH01d0f=SH0`00000a09:BTPP00000
N@3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03o
ool0oooo0180oooo00@0P820000000000000P8201P3oool2000000030820P03oool0oooo00@0oooo
0`0000060?ooo`<000001@3oool01010@400000000000020P8070?ooo`<000000`3oool01@30`<00
0000000000000000`<3000H0oooo00@0P820000000000000P8201@3oool3000000D0oooo00@0P820
000000000000P820203oool00`30`<00P8200?ooo`0/0?ooo`030<30`000000000000080000000<0
XZ:R0=SHf03Hf=P0c@3Hf=P01@1/K6`0=SHf000000000000K6a/01h0f=SH0`00000^09:BTP80BDU9
00@09BDU00000000000000000P20P81l0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B
09:BTP0_09:BTP80000000<0P8200?ooo`3oool04P3oool01020P800000000000020P8060?ooo`80
000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000050?ooo`<00000203oool3000000<0
oooo00@0P82000000000000000001`3oool01020P800000000000020P8050?ooo`<000001@3oool3
000003X0oooo1000003A0=SHf0@0000000<0K6a/0=SHf03Hf=P06P3Hf=P3000002X0TY:B1P000000
1019BDT0000000000000001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_
09:BTP80000000<0P8200?ooo`3oool04P3oool01020P800000000000020P8060?ooo`80000000<0
P8200?ooo`3oool0103oool3000000H0oooo0`0000050?ooo`80000000<0P8200?ooo`3oool01P3o
ool3000000<0oooo00<0P820000000000000203oool01020P800000000000020P8050?ooo`<00000
1@3oool3000003X0oooo1P00003@0=SHf0@00000703Hf=P3000002L0TY:B00<0BDU9000000000000
1000000309:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2B
TY82000000030820P03oool0oooo0180oooo00@0P820000000000000P8201P3oool2000000030820
P03oool0oooo00@0oooo0`0000060?ooo`<000001@3oool2000000030820P03oool0oooo00H0oooo
0`0000030?ooo`030820P0000000000000P0oooo00@0P820000000000000P8201@3oool3000000D0
oooo0P0000000`20P800oooo0?ooo`0i0?ooo`80K6a/1@0000000`1/K6`0f=SH0=SHf03;0=SHf003
0::RXP1/K6`000000080000000<0K6a/0=SHf03Hf=P0603Hf=P300000280TY:B0P19BDT0100U9BD0
000000000000000304U9B@H0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0
TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool04P3oool01020P800000000000020P8060?oo
o`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000050?ooo`80000000<0P8200?oo
o`3oool01P3oool3000000<0oooo00<0P820000000000000203oool01020P800000000000020P805
0?ooo`<000001@3oool2000000030820P03oool0oooo02D0oooo9`0000340=SHf0@000006P3Hf=P3
000001l0TY:B1P00000<09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:B
TP2BTY80;`2BTY82000000030820P03oool0oooo0180oooo00@0P820000000000000P8201P3oool2
000000030820P03oool0oooo00@0oooo0`0000060?ooo`<000001@3oool00`10@40000000820P008
0?ooo`<000000`3oool00`30`<000000000000080?ooo`040820P000000000000820P0D0oooo0`00
00050?ooo`80000000<0@4100820P020P8002020P80M0?ooon@00000203Hf=P0100f=SH000000000
0000000I0=SHf0<000006@2BTY800`1^KVh0BDU904U9B@03000000<0BDU900<0KVi^09:BTP2BTY80
302BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P00
00000`20P800oooo0?ooo`0B0?ooo`040820P000000000000820P0H0oooo0P0000000`20P800oooo
0?ooo`040?ooo`<000001P3oool3000000D0oooo00<0P82000000020P800203oool3000000@0oooo
0P0000080?ooo`040820P000000000000820P0D0oooo0`0000050?ooo`030820P0000000P82000L0
oooo00<0P8200000000000007@3ooooT000000P0f=SH00D0K6a/000000000000000006a/K00H0=SH
f0<000005P2BTY800`19BDT0000000000003000001D0TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool04P3oool01020P800
000000000020P8060?ooo`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000050?oo
o`030<30`0000000@41000P0oooo0`0000040?ooo`030820P0000000P82000L0oooo00@0P8200000
00000000P8201@3oool3000000D0oooo00<0`<3000000010@4001`3oool00`20P80000000410@00M
0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY8300000;/0?Cdm0`0000090=SHf00406a/K0000000
0000000001P0f=SH0`00000@09:BTP@0BDU90P000000100U9BD0BDU904U9B@1^KVhG09:BTP<00000
OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03o
ool0oooo0180oooo00@0P82000000000000000001@3oool3000000030820P0000000oooo00<0oooo
100000060?ooo`<000001`3oool00`000000oooo0?ooo`060?ooo`<000001@3oool00`20P8000000
0?ooo`060?ooo`040820P000000000000820P0D0oooo0`0000060?ooo`8000001`3oool200000003
0820P03oool0oooo01/0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP<00000^`1iNGT3000000X0
f=SH00@0K6a/00000000000000005`3Hf=P3000000d0TY:B00<0BDU90000000000001000000M09:B
TP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY8200000003
0820P03oool0oooo0180oooo00H0P820000000000000P82000000020P8020?ooo`050820P0000000
00000000003oool00P0000020?ooo`040820P00000000000000000L0oooo0`0000070?ooo`800000
1P3oool4000000D0oooo00<0P82000000020P8001P3oool3000000030820P03oool0oooo00<0oooo
0`0000070?ooo`8000001@3oool3000001h0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP<00000
^`1iNGT3000000X0f=SH00@0K6a/00000000000000005`3Hf=P3000000X0TY:B00<0BDU900000000
00001000000P09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80
;`2BTY82000000030820P03oool0oooo0100oooo00<0`<300820P00000000P0000000`20P800oooo
0410@005000000040820P03oool0oooo0820P0D0000000<0P8200?ooo`3oool00`3oool00`20P800
000000000002000000L0oooo00@0`<300820P0000000`<300`3oool00`10@4000000000000020000
00H0oooo00<0P8200410@020P8000`3oool00`30`<00000000000002000000030820P03oool0oooo
00<0oooo0`0000070?ooo`040<30`000000000000410@080P8200P0000000`10@400P8200?ooo`0M
0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY8300000;/0NGUi0`00000;0=SHf0@000005P3Hf=P3
000000D0TY:B0`19BDT3000000<0BDU98`2BTY83000007h0oooo4oooool0017ooooo<P3oool30000
000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`0D0?ooo`0300000020P800oooo
0080oooo0`0000000`20P800oooo0?ooo`030?ooo`<0000000<0P8200?ooo`3oool01`3oool00`20
P80000000?ooo`090?ooo`060820P0000000000000000020P800oooo0`0000090?ooo`@0000000D0
oooo0820P000000000000820P0050?ooo`<000002P3oool400000240oooo0`0000000`19BDT0TY:B
09:BTP0M09:BTP<00000^`1iNGT3000000`0f=SH0`00000F0=SHf0<000000P2BTY860000000304U9
B@2BTY80TY:B02H0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:B
TP0_09:BTP80000000<0P8200?ooo`3oool0@@3oool3000000h0oooo00@0P820000000000000P820
1@3oool3000002l0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP<00000^`1iNGT3000000`0f=SH
0`0000000`1/K6`0f=SH0=SHf00B0=SHf0030::RXP000000000000@000000`19BDT[09:BTP<00000
OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03o
ool0oooo0440oooo0`00000>0?ooo`040820P000000000000820P0D0oooo0`00000_0?ooo`<00000
00<0BDU909:BTP2BTY807@2BTY8300000;/0NGUi0`00000<0=SHf00406a/K0000000000006a/K180
f=SH1P00000a09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80
;`2BTY82000000030820P03oool0oooo0440oooo0`00000>0?ooo`040820P000000000000820P0D0
oooo0`00000_0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY8300000;/0NGUi0`00000<0=SHf004
06a/K0000000000006a/K0h0f=SH1P000000101/K6`0000000000000000a09:BTP<00000OP3ooolC
ooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03oool0oooo
0440oooo0`00000>0?ooo`040820P000000000000820P0D0oooo0`00000_0?ooo`<0000000<0BDU9
09:BTP2BTY807@2BTY8300000:/0NGUi2P0m?Cd00`0O7al0000000000006000000`0f=SH00@0XZ:R
0000000000000000203Hf=P0102RXZ80K6a/06a/K00f=SH3000000<0K6a/0`3Hf=P300000340TY:B
0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0
P8200?ooo`3oool0@@3oool3000000h0oooo00@0P820000000000000P8201@3oool3000002l0oooo
0`0000000`19BDT0TY:B09:BTP0M09:BTP<00000Z01iNGTF000001H0f=SH1P0000090=SHf0<00000
<@2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P00
00000`20P800oooo0?ooo`0^0?ooo`030820P0000000P82000h0oooo0P20P803000000`0oooo00<0
`<300820P010@4000P0000001020P800oooo0?ooo`3oool20820P0<00000;`3oool30000000304U9
B@2BTY80TY:B01d0TY:B0`00002K07UiN@L0?Cdm500000040820P0050410@000000000000000001/
K6`03`3Hf=P306a/K0<0000000<0=SHf06a/K01/K6`0303Hf=P300000340TY:B0`00001n0?oooa?o
oooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0
;P3oool3000000l0oooo1000000>0?ooo`<0000000<0P8200?ooo`3oool00P3oool01020P8000000
00000000000_0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY83000009D0NGUi5P0000070?ooo`@0
0000103oool01@20P8000000000000000000K6a/00`0f=SH1P0000000`1/K6`0f=SH0=SHf00?0=SH
f0<00000<@2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0
TY:B0P0000000`20P800oooo0?ooo`0_0?ooo`030820P03oool0oooo0100oooo00<0`<300820P03o
ool03`3oool00`20P800`<300?ooo`050?ooo`030<30`020P800oooo02h0oooo0`0000000`19BDT0
TY:B09:BTP0M09:BTP<00000R01iNGT703dm?AD0000000<0@4100820P00000000P0000000`10@400
oooo0?ooo`070?ooo`040820P00000000000000000<0oooo00D0P820000000000000000003Hf=P07
0=SHf080K6a/00@0=SHf00000000000000000`1/K6`D0=SHf0<00000<@2BTY83000007h0oooo4ooo
ool0017ooooo<P3oool30000000304U9B@2BTY80TY:B02l0TY:B0P0000000`20P800oooo0?ooo`2=
0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY8300000840NGUi00<0?Cdm0000000000005`000000
0`20P800oooo0?ooo`020?ooo`D0000000@0oooo00000000000000002`3oool3000000<0oooo00<0
P8200000000000000P0000030=SHf0L000006P3Hf=P300000340TY:B0`00001n0?oooa?ooooo000A
oooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0S@3oool3
0000000304U9B@2BTY80TY:B01d0TY:B1000001j07UiNAh0000000<0P8200?ooo`3oool01P3oool7
000000/0oooo0`0000001020P800oooo0?ooo`3oool;000001d0f=SH0`00000a09:BTP<00000OP3o
oolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80;`2BTY82000000030820P03oool0
oooo08d0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@00000K@1iNGT00`1KFe/0?Cdm03dm?@04
03dm?AD0000000<0@4100820P020P8000P20P805000000050<30`0000000000000000020P8002@3o
ool00`30`<00000000000004000000030<30`03oool0oooo00L0oooo00@0`<300000000000000000
0`3oool00`20P800000000000003000000<0K6a/803Hf=P300000340TY:B0`00001n0?oooa?ooooo
000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0_09:BTP80000000<0P8200?ooo`3oool0S@3o
ool30000000304U9B@2BTY80TY:B01d0TY:B1000001V07UiN@0303dm?@000000000001P000000P3o
ool4000000030820P03oool0oooo00H0oooo1`00000;0?ooo`L000002@3oool<000002@0f=SH0`00
000a09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`040410@0000000000004U9BC40TY:B0P00
00000`20P800oooo0?ooo`2=0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY84000005X0NGUi1P0m
?CdI000000@0P8201@0000001@30`<000000000000000000P82000T0oooo00<0`<30000000000000
100000000`20P800oooo0?ooo`070?ooo`060<30`000000000000000003oool0@410100000040820
P0030410@000000000000080000000<0@4100?ooo`30`<000P20P8000`30`<000000000000020000
02@0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`040820P0000000000004U9
BC00TY:B0`0000000`20P800oooo0?ooo`2=0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY840000
05<0NGUi00<0?Cdm0000000000006@0000001020P800oooo0?ooo`3oool3000000030820P03oool0
oooo00H0oooo1`00000;0?ooo`L0000000<0P8200?ooo`3oool01P3oool400000080oooo3@000006
0?ooo`@00000903Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo00@0P8200000
00000000BDU9<02BTY83000000030820P03oool0oooo08d0oooo0`0000000`19BDT0TY:B09:BTP0M
09:BTP@00000AP1iNGT703dm?A@0000000<0P8200000000000003@0000001@20P800`<3000000000
0000P82000X0oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`070?ooo`060<30`000
000000000000003oool0@410100000000`10@400P8200820P0020820P0@0000000<0@4100?ooo`3o
ool00`3oool00`20P800000000000006000000030820P03oool0oooo00D0oooo1000000=0=SHf003
06a/K02RXZ80f=SH01@0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`040820
P0000000000000000300TY:B0`00002@0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY8400000400
NGUi7`0000030?ooo`@00000203oool7000000`0oooo1P0000000`20P800oooo0?ooo`060?ooo`@0
00000P3oool=000000L0oooo0`0000020?ooo`040820P000000000000820P0L0oooo0`0000000`1/
K6`0f=SH0=SHf00:0=SHf08000005P3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo00@0P8200000000000000000;`2BTY8400000900oooo0`0000000`19BDT0TY:B09:BTP0M09:B
TP@00000>@1iNGT00`0m?Cd000000000000T00000080oooo0`00000:0?ooo`H00000303oool20000
00030?ooo`000000000000<0000000<0P8200?ooo`3oool00P3oool5000000040820P03oool0oooo
0?ooo`/00000203oool300000080oooo00@0P820000000000000P8201`3oool30000000306a/K03H
f=P0f=SH00T0f=SH00<0K6a/0000000000005P3Hf=P300000340TY:B0`00001n0?oooa?ooooo000A
oooooc<0oooo0`00000_09:BTP<00000T@3oool30000000304U9B@2BTY80TY:B01d0TY:B1000000/
07UiN@L0?Cdm6P0000001020P800oooo0?ooo`3oool4000000P0P820100000001020P80000000000
0000000:0?ooo`030<30`0000000000000@0000000<0`<300?ooo`3oool01P3oool01020P8000000
0000000000020?ooo`030410@0000000000000X0000000<0P8200?ooo`3oool0103oool3000000<0
P8200P0000000`20P800oooo0?ooo`060?ooo`<000000P3oool01020P800000000000020P8060?oo
o`050<30`000000000000000001/K6`02P3Hf=P0101/K6`000000000001/K6`F0=SHf0<00000<@2B
TY83000007h0oooo4oooool0017ooooo<`3oool4000002d0TY:B00@0BDU90000000000000000T@3o
ool30000000304U9B@2BTY80TY:B01d0TY:B1000000V07UiNAX0000000<0oooo0000000000003000
00020?ooo`<000002P3oool7000000/0oooo2@0000040?ooo`H000000`3oool<000000L0oooo0`00
00030?ooo`80000000<0P8200?ooo`3oool01P3oool300000080oooo00@0P820000000000000P820
1P3oool01@20P8000000000000000000K6a/00T0f=SH1000000G0=SHf0<00000<@2BTY83000007h0
oooo4oooool0017ooooo=03oool30000000304U9B@2BTY80TY:B02X0TY:B00@09BDU000000000000
P820T@3oool30000000304U9B@2BTY80TY:B01d0TY:B1000000I07UiN@H0?Cdm00<07alO00000000
00006P0000001@20P800oooo0?ooo`3oool0P82000@000001`20P804000000040820P00000000000
000000/0oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`060?ooo`070820P0000000
000000000010@400oooo0410@00<000000030820P03oool0oooo00@0oooo0`0000030820P0800000
00<0P8200?ooo`3oool01P3oool3000000<0oooo0P0000000`20P800oooo0?ooo`060?ooo`<00000
0P3oool01020P800000000000020P8050?ooo`030820P000000000000080000000<0XZ:R0=SHf03H
f=P01@3Hf=P00`2RXZ800000000000020000000306a/K03Hf=P0f=SH01D0f=SH0`00000a09:BTP<0
0000OP3ooolCooooo`004Ooooole0?ooo`<00000;02BTY83000000030820P03oool0oooo08l0oooo
0`0000000`19BDT0TY:B09:BTP0M09:BTP@000004`1iNGTJ000000<0oooo3P0000020?ooo`030820
P0000000000000X0oooo1`00000;0?ooo`030820P0000000000000D000001P3oool00`20P8000000
00000002000000030820P03oool0oooo00`000001`3oool3000000<0oooo0P0000000`20P800oooo
0?ooo`060?ooo`<000000`3oool2000000030820P03oool0oooo00H0oooo0`0000020?ooo`040820
P000000000000820P0D0oooo1@0000080=SHf0D00000603Hf=P300000340TY:B0`00001n0?oooa?o
oooo000AooooocD0oooo00@0P8200000000000000000:P2BTY84000000030820P03oool0oooo08l0
oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@00000301iNGTN000000D0oooo00<0P82000000000
00003@000000103oool0P82000000000000;0?ooo`H000002`3oool3000000030?ooo`0000000000
00`000001P3oool9000000P0oooo0`0000030?ooo`80000000<0P8200?ooo`3oool01P3oool30000
00<0oooo0P0000000`20P800oooo0?ooo`060?ooo`<000000P3oool01020P800000000000020P803
0?ooo`030820P000000000000080000000<0K6a/0=SHf03Hf=P01P3Hf=P6000001P0f=SH0`00000a
09:BTP<00000OP3ooolCooooo`004Ooooole0?ooo`050<30`0000000000000000019BDT0:02BTY80
1@1^KVh00000000000000000P8200980oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@000001@0m
?CdD000000H0P82000<0`<300820P00000002P0000001020P800`<300?ooo`20P802000000030410
@020P800`<3000H0oooo00<0P8200000000000001@00000;0?ooo`030820P0000000000000<00000
0P20P8060?ooo`030<30`020P80000000080000000<0@4100?ooo`30`<00300000070?ooo`<00000
0`3oool3000000P0oooo0`0000030?ooo`80000000<0P8200?ooo`3oool01P3oool3000000<0oooo
0P0000000`20P800oooo0?ooo`060?ooo`<000000P3oool01P20P800000000000020P800oooo0820
P0D0000000<0K6a/0=SHf03Hf=P01@3Hf=P00`2RXZ800000000000040000000306a/K03Hf=P0f=SH
01H0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooolf0?ooo`@00000:02BTY84000009<0
oooo0`0000000`19BDT0TY:B09:BTP0M09:BTQd000001P3oool00`20P80000000000000;00000003
0820P03oool0P8200080000000<0P8200?ooo`3oool0203oool6000000/0oooo0`0000000`3oool0
000000000003000000@0oooo1P0000050?ooo`030820P0000000000000H00000203oool3000000<0
oooo0`0000080?ooo`<000000`3oool2000000030820P03oool0oooo00H0oooo0`0000030?ooo`80
000000<0P8200?ooo`3oool01P3oool300000080oooo00<0P820000000000000200000070=SHf0P0
000000<0K6a/0=SHf03Hf=P05P3Hf=P300000340TY:B0`00001n0?oooa?ooooo000AooooocL0oooo
0`0000000`0U9BD0TY:B09:BTP0T09:BTP0404U9B@00000000000410@9@0oooo0`0000000`19BDT0
TY:B09:BTP0M09:BTPT000001`20P8001030`<00oooo0?ooo`3oool<000000<0oooo0`0000000`20
P800`<300?ooo`050?ooo`050820P0000000000000000020P8000`0000000`30`<00oooo0?ooo`08
0?ooo`030820P0000000000000<000000P20P8070?ooo`070820P0000000000000000010@400oooo
0820P00<000000030410@03oool0oooo00@0oooo00<0P8200000000000000`20P803000000P0oooo
0`0000030?ooo`<00000203oool3000000<0oooo0P0000000`20P800oooo0?ooo`060?ooo`<00000
0`3oool2000000030820P03oool0oooo00H0oooo0`0000000`30`<00P8200410@0080000000306a/
K02RXZ80f=SH00@0f=SH00<0K6a/03Hf=P0000001`00000I0=SHf0<00000<@2BTY83000007h0oooo
4oooool0017ooooo=`3oool00`20P800000000000002000002@0TY:B00@0BDU90000000000000000
U@3oool30000000304U9B@2BTY80TY:B01d0TY:B100000000`20P800oooo00000005000000L0oooo
3@0000000`20P800oooo0?ooo`02000000030820P03oool0oooo00L0oooo1`0000000`20P800oooo
0?ooo`080?ooo`030820P0000000000000H00000103oool6000000D0oooo00<0P820000000000000
1P0000080?ooo`030820P0000000000000<0oooo0`0000080?ooo`<000000`3oool3000000P0oooo
0`0000030?ooo`80000000<0P8200?ooo`3oool01P3oool3000000<0oooo0P0000000`20P800oooo
0?ooo`040?ooo`030820P0000000000000/0000000<0K6a/0=SHf03Hf=P01@3Hf=P;000001T0f=SH
0`00000a09:BTP<00000OP3ooolCooooo`004Ooooolh0?ooo`050820P000000000000000000U9BD0
8P2BTY801@19BDT00000000000000000P82009D0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTPl0
00000`3oool300000080P82000<0`<300?ooo`3oool00P3oool20820P0<0000000D0P82000000000
000000000<30`00;0?ooo`D0000000<0@4100820P030`<001P3oool00`20P8000000000000020000
00030<30`020P800000000/0000000<0@4100?ooo`3oool0103oool00`20P8000000000000030820
P0<00000203oool00`20P8000000000000030?ooo`<00000203oool3000000<0oooo0`0000080?oo
o`<000000`3oool2000000030820P03oool0oooo00H0oooo0`0000030?ooo`80000000<0@4100820
P020P800400000000`1/K6`0f=SH0=SHf0050=SHf00306a/K00f=SH0000000T000006P3Hf=P30000
0340TY:B0`00001n0?oooa?ooooo000AooooocX0oooo100000000`19BDT0TY:B09:BTP0L09:BTP03
04U9B@00000000000080000000<0P8200?ooo`3oool0U03oool30000000304U9B@2BTY80TY:B01d0
TY:B400000020?ooo`80000000<0P8200?ooo`3oool01`3oool00`20P80000000000000400000003
0820P03oool0oooo00T0oooo200000040?ooo`030820P0000000000000<000001@3oool9000000P0
oooo00<0P8200000000000000`3oool3000000P0oooo00<0P8200000000000000`3oool3000000P0
oooo0`0000030?ooo`<00000203oool3000000<0oooo0P0000000`20P800oooo0?ooo`060?oooaT0
00002@3Hf=P00`1/K6`000000000000:000001X0f=SH0`00000a09:BTP<00000OP3ooolCooooo`00
4Ooooolj0?ooo`030820P00000000000008000007P2BTY85000009L0oooo0`0000000`19BDT0TY:B
09:BTP0M09:BTPH0000000<0P8200?ooo`3oool00P3oool00`20P800000000000002000000050820
P0000000000000000020P8002`3oool5000000030820P03oool0oooo00L0oooo100000000`20P800
00000000000<000000H0oooo00<0P8200000000000001P0000080?ooo`030820P0000000000000<0
oooo0`0000080?ooo`030820P0000000000000<0oooo0`0000080?ooo`<000000`3oool3000000P0
oooo0`0000030?ooo`80000000@0P8200?ooo`3oool0oooo6`00000<0=SHf0`0000000<0K6a/0=SH
f03Hf=P0603Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooooc`0oooo00H0@41000000000
0000000004U9B@1^KVhI09:BTP0302DU9@00000000000080000000<0`<300?ooo`3oool0UP3oool3
0000000304U9B@2BTY80TY:B01d0TY:B100000000`30`<00oooo0?ooo`060?ooo`030820P0000000
000000@0000000<0`<300?ooo`3oool02@3oool600000080P820103oool00`30`<00P8200410@003
000000030820P03oool0oooo0080P8202P0000000`30`<00oooo0?ooo`040?ooo`040820P0000000
00000820P080oooo0`0000080?ooo`030820P0000000000000<0oooo0`0000080?ooo`030820P000
0000000000<0oooo0`0000080?ooo`<000000`3oool3000000P0oooo0`0000030820P1800000201/
K6`00`2RXZ80f=SH0=SHf00>0=SHf00306a/K0000000000000/0000000<0K6a/0=SHf03Hf=P0603H
f=P300000340TY:B0`00001n0?oooa?ooooo000Aoooooch0oooo1@00000F09:BTPD00000V`3oool3
0000000304U9B@2BTY80TY:B01d0TY:B1000000:0?ooo`H0000000<0P8200?ooo`3oool01`3oool0
0`20P800000000000002000000030820P0000000000000/0000000<0P8200?ooo`3oool0103oool9
000000L0oooo00@0P820000000000000P8200P3oool3000000P0oooo00<0P8200000000000000`3o
ool3000000P0oooo00<0P8200000000000000`3oool3000000P0oooo0`0000030?ooo`<00000103o
oolG000001d0f=SH3`00000K0=SHf0<00000<@2BTY83000007h0oooo4oooool0017ooooo?P3oool0
0`30`<00P82000000003000000<0BDU93`2BTY800`19BDT0000000000003000000030820P030`<00
oooo09X0oooo0`0000000`19BDT0TY:B09:BTP0M09:BTP@000002`3oool600000080P82000<0`<30
0?ooo`3oool00P3oool20820P0@000000P3oool20820P0X0000000<0P8200?ooo`3oool01@3oool2
000000040820P03oool0oooo0820P0<000001`3oool01020P800000000000020P8020?ooo`<00000
203oool00`20P8000000000000030?ooo`<00000203oool00`20P8000000000000030?ooo`<00000
203oool3000000<0P8205000000506a/K200f=SH00<0XZ:R0000000000003P00000K0=SHf0<00000
<@2BTY83000007h0oooo4oooool0017ooooo@@3oool8000000X0TY:B200000000`20P800oooo0?oo
o`2K0?ooo`<0000000<0BDU909:BTP2BTY807@2BTY84000000X0oooo100000000`3oool000000000
000;000000030820P03oool0oooo00@0oooo2@0000080?ooo`80000000@0P8200?ooo`3oool0P820
0`0000070?ooo`040820P000000000000820P080oooo0`0000080?ooo`030820P0000000000000<0
oooo0`0000080?ooo`030820P0000000000000<0oooo0`0000040?oooaT00000:P3Hf=P@000001`0
f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooom20?ooo`030820P0000000000001D00000
W`3ooolW000000030410@020P800`<3000@0oooo00<0`<300820P00000000`0000030?ooo``00000
1`3oool3000000030<30`03oool0P82000<00000203oool2000000040820P03oool0oooo0820P0<0
00001`3oool01020P800000000000020P8020?ooo`<00000203oool00`20P8000000000000030?oo
o`<00000203oool00`20P8000000000000030820P0<000000P20P80A000000D0K6a/;`3Hf=P00`2R
XZ8000000000000=000001`0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooom60?oooa00
000000<0P8200000000000000P0000000`20P800oooo0?ooo`2K0?oooc<000001P3oool9000000P0
oooo0`0000020?ooo`040820P00000000000000000P0oooo0P0000001020P800oooo0?ooo`20P803
000000L0oooo00@0P820000000000000P8200P3oool3000000P0oooo00<0P8200000000000000`3o
ool3000000D0oooo6@00000l0=SHf0d0000000<0K6a/0=SHf03Hf=P06P3Hf=P300000340TY:B0`00
001n0?oooa?ooooo000AooooodP0oooo00<0P8200000000000002@0000020?ooo`030820P0000000
000000<00000W@3ooolb000000L0oooo0`0000000`20P800oooo0820P003000000P0oooo0`000002
0?ooo`040820P00000000000000000P0oooo0P0000001020P800oooo0?ooo`20P803000000L0oooo
00@0P820000000000000P8200P3oool3000000P0oooo00<0P8200000000000000`3oool300000080
oooo5P0000000`1/K6`0f=SH0=SHf00o0=SHf0d0000000<0K6a/0=SHf03Hf=P06P3Hf=P300000340
TY:B0`00001n0?oooa?ooooo000AoooooeP0oooo00<0P8200000000000000P0000000`10@400oooo
0?ooo`0U0?ooo`D0P8201`3oool01030`<00oooo0?ooo`30`<040820P0L0oooo00<0`<300?ooo`30
`<001020P8000`30`<00oooo0?ooo`020?ooo`L0P82000<0`<300?ooo`3oool01@3oool40820P0L0
oooo1`20P8070?ooo`D0P8201`3oool00`30`<00oooo0<30`0040820P0030<30`03oool0oooo01l0
oooo00<0P8200410@00000001000000;0=SHf00306a/K0000000000000<0P8202@0000000`20P800
oooo0?ooo`050?ooo`<000000P3oool01020P80000000000000000080?ooo`<000000P3oool01020
P80000000000000000080?ooo`80000000@0P8200?ooo`3oool0P8200`0000070?ooo`040820P000
000000000820P080oooo0`0000080?ooo`030820P0000000000000<0P8204@00000606a/K4D0f=SH
0P1/K6`<000000030::RXP3Hf=P0f=SH01X0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooo
oomK0?ooo`@00000903oool01020P800000000000020P8030?ooo`030000003oool0oooo00@0oooo
00@0P82000000000000000000`3oool00`20P80000000?ooo`050?ooo`<00000103oool00`000000
oooo0?ooo`040?ooo`@00000203oool7000000H0oooo100000070?ooo`P000001P3oool3000000@0
oooo00<000000?ooo`3oool08P3oool5000000X0f=SH00<0K6a/0000000000000`3oool300000003
0820P03oool0oooo00<00000203oool300000080oooo00@0P8200000000000000000203oool30000
0080oooo00@0P8200000000000000000203oool2000000040820P03oool0oooo0820P0<000001`3o
ool01020P800000000000020P8020?ooo`<000001P3ooolD000004l0f=SH00<0K6a/000000000000
3000000M0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooF`3oool00`30`<0000000000
0002000000030410@03oool0oooo01h0oooo00@0`<30000000000000P8201@3oool01030`<000000
00000030`<030?ooo`030820P0000000P82000D0oooo00<0P82000000020P800103oool00`000000
P8200?ooo`040?ooo`030<30`0000000P82000@0oooo00<0P8200000000000001P3oool00`30`<00
P82000000002000000060410@020P800P8200820P0000000@4101P3oool2000000030820P03oool0
oooo00@0oooo00<0@4100000000000000P0000030820P0030410@0000000`<3000@0oooo00<00000
0820P03oool0103oool00`30`<0000000820P00S0?ooo`050820P000000000000000000f=SH02@3H
f=P3000000<0oooo0`0000030?ooo`<00000203oool300000080oooo00@0P8200000000000000000
203oool300000080oooo00@0P8200000000000000000203oool2000000040820P03oool0oooo0820
P0<000001`3oool00`20P8000000000000030820P0<0000000<0P8200000000000003P00000506a/
K540f=SH00<0XZ:R0000000000000P0000000`0f=SH0K6a/0::RXP080000000306a/K03Hf=P0f=SH
01/0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomM0?ooo`D000007`3oool200000003
0820P03oool0oooo00H0oooo0P0000030?ooo`030820P0000000oooo00H0oooo0P0000040?ooo`03
0000003oool0oooo00D0oooo0P0000040?ooo`030820P0000000000000H0oooo00<0P82000000000
00000P0000050?ooo`030820P0000000oooo00@0oooo0P0000000`20P800oooo0?ooo`040?ooo`@0
00001P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00D0oooo0P00000U0?ooo`@0
0000203Hf=P3000000<0oooo0`0000030?ooo`<00000203oool300000080oooo00@0P82000000000
00000000203oool300000080oooo00@0P8200000000000000000203oool2000000040820P03oool0
oooo0820P0<000001@3oool00`20P80000000000000D00000280f=SH00<0K6a/0000003Hf=P0=@3H
f=P60000000506a/K03Hf=P0f=SH0=SHf01/K6`01P00000N0=SHf0<00000<@2BTY83000007h0oooo
4oooool0017oooooGP3oool4000000030820P03oool0oooo01`0oooo0P0000000`20P800oooo0?oo
o`060?ooo`8000000`3oool00`20P800oooo0?ooo`060?ooo`800000103oool00`20P800oooo0?oo
o`050?ooo`800000103oool00`20P8000000000000060?ooo`@000001`3oool00`000000P8200?oo
o`030?ooo`80000000<0P8200?ooo`3oool00`3oool4000000030820P03oool0oooo00@0oooo00<0
P8200000003oool00P3oool00`20P800oooo0?ooo`050?ooo`8000009@3oool00`20P80000000000
0002000000L0f=SH0`0000030?ooo`<000000`3oool3000000P0oooo0`0000020?ooo`040820P000
00000000000000P0oooo0`0000020?ooo`040820P00000000000000000P0oooo0P0000001020P800
oooo0?ooo`20P80K000002L0f=SH00<0000006a/K03Hf=P0<`3Hf=P6000000H0f=SH1P00000N0=SH
f0<00000<@2BTY83000007h0oooo4oooool0017oooooG`3oool01020P800000000000010@40M0?oo
o`<000002P3oool200000080oooo00<0P8200?ooo`3oool0103oool01030`<000000000000000004
0?ooo`030820P03oool0oooo00@0oooo00<0@410000000000000103oool00`20P800000000000005
0?ooo`050820P0000000000000000030`<00203oool00`20P800oooo0?ooo`020?ooo`80000000<0
P8200?ooo`3oool00`3oool3000000030820P03oool0oooo00H0oooo00D0P8200<30`03oool0oooo
0820P0060?ooo`030410@0000000000002H0oooo00D0P820000000000000000003Hf=P060=SHf0<0
00000`3oool3000000<0oooo0`0000080?ooo`<000000P3oool01020P80000000000000000080?oo
o`<000000P3oool01020P80000000000000000080?ooo`80000000<0@4100820P020P8004P000005
06a/K2`0f=SH00<0000006a/K03Hf=P0<03Hf=P00`1/K6`00000000000030000000306a/K02RXZ80
f=SH00P0f=SH00<0XZ:R06a/K00000007`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooo
of00oooo0`00000L0?ooo`@000002P3oool2000000030820P03oool0oooo00H0oooo1000000:0?oo
o`@00000103oool00`20P8000000000000050?ooo`@000003P3oool2000000030820P03oool0oooo
0080oooo00@0P82000000000000000004`3oool4000002L0oooo00<0P8200000000000000P000005
0=SHf0<000000`3oool3000000<0oooo0`0000080?ooo`<000000P3oool01020P800000000000000
00080?ooo`<000000P3oool01020P80000000000000000040?oooaH00000=`3Hf=P00`000000f=SH
0=SHf00]0=SHf0H00000;`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aooooof00oooo00D0
P82000000000000000000<30`00J0?ooo`<000002`3oool2000000030820P03oool0oooo00<0oooo
00<0P8200410@00000000`0000000`30`<00oooo0?ooo`050?ooo`030820P010@400000000<00000
00<0`<300?ooo`3oool00P3oool00`20P8000000000000050?ooo`<000003`3oool2000000030820
P03oool0oooo0080oooo00@0P820000000000000P820403oool00`20P800@4100000000300000003
0<30`03oool0oooo02H0oooo00D0P82000000000000000000::RXP040=SHf0<000000`3oool30000
00<0oooo0`0000080?ooo`<000000P3oool01020P80000000000000000080?ooo`<0000000<0oooo
0820P010@400500000000`0f=SH0K6a/06a/K00206a/K3/0f=SH00<000000=SHf03Hf=P0:P3Hf=P0
0`1/K6`000000000000300000080K6a/<03Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooo
of40oooo0`0000000`20P800oooo0?ooo`0H0?ooo`<000002`3oool2000000030820P03oool0oooo
0080oooo1P0000080?ooo`H000001P3oool00`20P8000000000000050?ooo`<000003`3oool20000
00030820P03oool0oooo0080oooo00<0P820000000000000403oool6000002/0oooo0`0000000`1/
K6`0f=SH0=SHf0020=SHf0<000000`3oool3000000<0oooo0`0000080?ooo`<000000P3oool01020
P80000000000000000060?ooo`030820P0000000000001@00000A@3Hf=P00`1/K6`000000=SHf00X
0=SHf0L00000<`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aooooof80oooo0`00000J0?oo
o`<000002`3oool2000000040820P03oool0oooo0820P0@0000000<0P8200<30`03oool01P3oool0
0`30`<0000000000000200000080P8201`3oool00`20P8000000000000050?ooo`<000003`3oool2
000000030820P03oool0oooo0080oooo00<0P8200000000000003P3oool00`30`<00000000000002
00000080P820;@3oool01010@40000000000003/k>`30=SHf0<000000P20P800103oool000000000
000000030?ooo`<00000203oool300000080P82000D0@41000000000000000000820P00C000000D0
K6a/B@3Hf=P00`1/K6`000000=SHf00T0=SHf080K6a/1P0000000`1/K6`0XZ:R0=SHf00c0=SHf0<0
0000<@2BTY83000007h0oooo4oooool0017oooooHP3oool01020P800000000000000000I0?ooo`<0
00002P3oool3000000030820P03oool0oooo00@0000000<0P8200?ooo`3oool01`3oool01@20P800
0000000000000000P82000T0oooo00<0P8200000000000001P3oool2000000l0oooo0P0000000`20
P800oooo0?ooo`020?ooo`030820P0000000000000/000000`3oool01@20P8000000000000000000
P82002l0oooo00@0P82000000000000000000`3Hf=P00`1/K6`0000000000002000000040820P000
00000000000000<0oooo0`0000040?oooa`00000E03Hf=P200000280f=SH200000000`1/K6`0f=SH
0=SHf00e0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooHP3oool01020P80000000000
0000000J0?ooo`8000002P3oool300000080oooo00@0P82000000000000000001P3oool00`20P800
oooo0?ooo`020?ooo`<000001P3oool00`20P800oooo0?ooo`020?ooo`030820P0000000000000H0
oooo0P00000?0?ooo`80000000<0P8200?ooo`3oool00`3oool2000000P0oooo0`0000030?ooo`<0
00001P3oool00`20P800oooo0?ooo`0Y0?ooo`<0000000@0oooo0=SHf03Hf=P0K6a/200000030?oo
oah00000F@3Hf=P200000200f=SH2@00000i0=SHf0<00000<@2BTY83000007h0oooo4oooool0017o
ooooH`3oool3000000030820P03oool0oooo01L0oooo00<0P82000000020P800203oool01020P800
00000000000000020?ooo`040820P000000000000<30`0H0oooo00<0P8200?ooo`3oool00P3oool2
000000030<30`03oool0oooo00@0oooo00<0P8200?ooo`3oool00P3oool00`20P800000000000006
0?ooo`030410@0000000P82000L0oooo0P0000000`30`<00oooo0?ooo`020?ooo`80000000<0P820
0?ooo`3oool00`3oool00`20P80000000820P0070?ooo`80000000@0P8200?ooo`3oool0oooo0P00
00000`30`<00oooo0?ooo`040?ooo`030820P03oool0oooo02T0oooo00D0P8200000000000000000
0::RXP020=SHf00306a/K0000000000001X000001`1/K6aN0=SHf00306a/K0000000XZ:R01/0f=SH
00<0XZ:R06a/K00000001P00000206a/K3/0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooo
oomT0?ooo`<000006P3oool2000000P0oooo0`0000030?ooo`030820P0000000000000H0oooo00<0
00000820P03oool00`3oool2000000H0oooo00<000000820P03oool00`3oool00`20P80000000000
00070?ooo`8000001P3oool3000000030820P03oool0oooo0080oooo0P0000000`20P800oooo0?oo
o`040?ooo`8000001P3oool00`20P8000000000000040?ooo`8000001P3oool00`000000P8200?oo
o`0[0?ooo`040820P0000000000006a/K0@0f=SH4`00001^0=SHf0030000001/K6`0f=SH01P0f=SH
00<0K6a/0000000000001P00000o0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooI03o
ool3000000030<30`03oool0oooo01L0oooo00<0`<3000000010@4001P3oool01010@40000000000
0030`<040?ooo`80000000<0`<300?ooo`3oool00P3oool00`20P80000000820P0040?ooo`030820
P0000000`<3000@0oooo00<0`<3000000020P8000P3oool20820P0030410@0000000000000L0oooo
00<0P82000000010@4001@3oool3000000030<30`03oool0oooo0080oooo0P0000000`20P800oooo
0?ooo`040?ooo`040<30`000000000000820P0<0oooo00@0P820000000000000P820103oool00`20
P80000000<30`0040?ooo`030<30`0000000P82002`0oooo00@0P820000000000000=SHf1P3Hf=P9
06a/K0030::RXP3Hf=P0f=SH07@0f=SH00<000000=SHf03Hf=P04`3Hf=P206a/K00303Hf=P000000
000000@0000000<0=SHf06a/K02RXZ80@03Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooo
of@0oooo00@0P820000000000000P8206`3oool2000000<0oooo00<0P820000000000000203oool2
000000<0oooo0`0000000`20P800oooo0?ooo`030?ooo`8000000`3oool3000000030820P03oool0
oooo0080oooo0`0000090?ooo`030820P0000000oooo0080oooo0`0000060?ooo`80000000<0P820
0?ooo`3oool01P3oool7000000L0oooo0P0000030?ooo`<0000000<0P8200?ooo`3oool0:`3oool3
000008H0f=SH00<000000=SHf03Hf=P04@3Hf=P9000004D0f=SH0`00000a09:BTP<00000OP3ooolC
ooooo`004OoooomT0?ooo`040820P000000000000820P1d0oooo1@20P80:0?ooo`050<30`020P800
P8200820P030`<000P3oool00`30`<00oooo0?ooo`040?ooo`030<30`020P800P8200080P8200P3o
ool00`30`<00oooo0?ooo`040?ooo`030820P03oool0oooo00T0oooo1@20P8070?ooo`80000000<0
P8200?ooo`3oool01`3oool00`30`<00P8200820P0020820P0T0oooo00<0`<300820P020P8000P20
P8020?ooo`030<30`03oool0oooo02/0oooo0`0000260=SHf00306a/K0000000f=SH00/0f=SH00<0
XZ:R06a/K01/K6`02000000206a/K4L0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomT
0?ooo`040820P0000000000000000600oooo0P0000000`20P800oooo0?ooo`1:0?ooo`@00000Q@3H
f=P00`1/K6`000000=SHf0090=SHf0/00000B`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000A
ooooofD0oooo0`00001P0?ooo`80000000<0P8200?ooo`3oool0B`3oool3000008H0f=SH00<00000
06a/K03Hf=P01@3Hf=P<000004d0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomU0?oo
o`<00000H03oool2000000030820P03oool0oooo04/0oooo0`0000260=SHf0030000000f=SH0K6a/
0080K6a/2@00000306a/K500f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomU0?ooo`<0
0000H03oool2000000030820P03oool0oooo0200oooo5P2BTY800`39bLT0oooo0?ooo`0B0?ooo`<0
0000Q@3Hf=P<0000000306a/K03Hf=P0f=SH05<0f=SH0`00000a09:BTP<00000OP3ooolCooooo`00
4OoooomU0?ooo`<00000A@3oool20<W9b@030820P02UYJD0TY:B01@0TY:B00D0[Zj^0<W9b@000000
000006EUI@0G0?ooo`030<W9b@2BTY80TY:B02P0TY:B00<0[Zj^0<W9b@3Ti>@0203oool300000003
0::RXP3Hf=P0f=SH07/0f=SH00<0XZ:R06a/K01/K6`02`00000206a/K0030::RXP3Hf=P0f=SH05H0
f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomU0?ooo`<000003@3oool00`39bLT0TY:B
09:BTP0J09:BTQH0oooo1P2BTY800`19BDT000000000000E09:BTP@0000000<0BDU909:BTP2BTY80
0P2BTY800`39bLT0oooo0?ooo`0>0?oooc40TY:B1`3oool30000000306a/K03Hf=P0f=SH07P0f=SH
3P00001N0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooI@3oool3000000H0oooo0`39
bLTU09:BTP040:j^[P39bLT0bLW90<W9b@T0oooo00<0bLW90:j^[P2BTY80202BTY800`1^KVh00000
02DU9@0F09:BTP80BDU900<0000004U9B@2BTY801`2BTY800`39bLT0i>CT0?ooo`050?ooo`030>CT
i039bLT0TY:B03H0TY:B00@0[Zj^0?ooo`3oool0oooo0`0000000`1/K6`0f=SH0=SHf01a0=SHf004
0::RXP1/K6`0K6a/06a/K0X000000`1/K6`0102RXZ80f=SH06a/K000001N0=SHf0<00000<@2BTY83
000007h0oooo4oooool0017oooooI@3oool3000000H0oooo;02BTY880?oooc@0TY:B1@3ooolk09:B
TP80oooo0`0000000`1/K6`0f=SH0=SHf01/0=SHf10000002@3Hf=P2000005d0f=SH0`00000a09:B
TP<00000OP3ooolCooooo`004OoooomU0?ooo`<000000`3ooolb09:BTP<0oooo>02BTY820?oooc`0
TY:B00<0bLW90?ooo`0000000P0000000`1/K6`0f=SH0=SHf01W0=SHf140000000<0K6a/0=SHf03H
f=P02P3Hf=P2000005d0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomU0?ooo`<00000
00<0oooo0>CTi02BTY80<P2BTY800`2^[Zh0oooo0?ooo`0h09:BTP80bLW9?@2BTY801@39bLT00000
000000000000K6a/05h0f=SH1@1/K6`00`0f=SH000000000000>000000@0K6a/3`3Hf=P00`1/K6`0
00000::RXP1L0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooI@3oool3000000030?oo
o`2BTY80TY:B06h0TY:B00<0bLW909:BTP2BTY80>`2BTY801@3oool00000000000000000K6a/05P0
f=SH5P0000000`1/K6`0f=SH0=SHf00G0=SHf0030000001/K6`0f=SH05/0f=SH0`00000a09:BTP<0
0000OP3ooolCooooo`004OoooomU0?ooo`<00000L@2BTY800`3Ti>@0TY:B09:BTP0j09:BTP030:j^
[P3oool0000000800000BP3Hf=P706a/K00303Hf=P00000000000100000000<0=SHf06a/K01/K6`0
0`1/K6`O0=SHf00306a/K00f=SH0f=SH05/0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooo
oomU0?ooo`<00000L02BTY830?oooc/0TY:B0P3oool300000480f=SH00<0K6a/0000000000006P00
000[0=SHf0030000003Hf=P0f=SH05X0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomU
0?ooo`<0000000<0oooo09:BTP2BTY80K@2BTY840?ooocP0TY:B00@0bLW90?ooo`3oool0oooo0`00
000k0=SHf1h00000<@3Hf=P00`000000f=SH0=SHf01J0=SHf0<00000<@2BTY83000007h0oooo4ooo
ool0017oooooI03oool01P20P800000000000010@400oooo0<W9bC<0TY:B00D0[Zj^0<W9b@3oool0
oooo0<W9b@0d09:BTP030<W9b@3oool0oooo00D0oooo00<0bLW909:BTP2BTY80<02BTY800`2^[Zh0
bLW90?ooo`040?ooo`<00000703Hf=P^000000P0K6a/>03Hf=P00`1/K6`000000=SHf01J0=SHf0<0
0000<@2BTY83000007h0oooo4oooool0017oooooI03oool01020P800000000000020P8030?oooc80
TY:B1`3oool00`39bLT0TY:B09:BTP0/09:BTQ00oooo:P2BTY800`39bLT0oooo0?ooo`080?ooo`<0
0000703Hf=PW000004L0f=SH00<0K6a/0000003Hf=P0FP3Hf=P300000340TY:B0`00001n0?oooa?o
oooo000Aooooof@0oooo00@0@410000000000000P820103oool20<W9bB`0TY:B00<0bLW90>CTi03o
ool02`3oool50<W9bAh0TY:B1039bLT00`3Ti>@0oooo0?ooo`0F0?ooo`@0bLW900<0[Zj^09:BTP2B
TY805@2BTY850<W9b@h0oooo0`0000000`1/K6`0f=SH0=SHf00J0=SHf1l0K6a/00<0XZ:R0=SHf03H
f=P0C@3Hf=P00`000000K6a/0=SHf01I0=SHf0<00000<@2BTY83000007h0oooo4oooool0017ooooo
I03oool3000000X0oooo9@2BTY800`39bLT0oooo0?ooo`0H0?oooaH0TY:B6@3oool00`20P8000000
0000000d0?ooo`<00000S@3Hf=P00`000000f=SH0=SHf01H0=SHf0<00000<@2BTY83000007h0oooo
4oooool0017oooooH`3oool4000000h0oooo00<0i>CT0<W9b@39bLT00P39bLTD09:BTP@0bLW9C@3o
ool5000000030<30`03oool0oooo02l0oooo00@0`<300000000000000000S@3Hf=P00`000000f=SH
0=SHf01H0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooHP3oool01020P80000000000
0000001i0?ooo`H00000<@3oool01020P800000000000000002=0=SHf00306a/K0000000f=SH05P0
f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomR0?ooo`040820P00000000000000007X0
oooo0P0000001020P800oooo00000000000`0?ooo`<0000000<0K6a/0=SHf03Hf=P0R`3Hf=P00`1/
K6`000000=SHf01H0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooHP3oool00`10@400
00000000001o0?ooo`030<30`0000000P82002l0oooo0`0000000`2RXZ80f=SH0=SHf02;0=SHf003
0::RXP000000XZ:R05P0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomR0?ooo`<00000
P@3oool00`000000oooo0?ooo`0/0?ooo`@00000S`3Hf=P00`000000K6a/0=SHf01G0=SHf0<00000
<@2BTY83000007h0oooo4oooool0017oooooH03oool01@30`<000000000000000000`<300840oooo
00<0P8200<30`03oool0:`3oool01@20P8000000000000000000K6a/08l0f=SH00<0K6a/03Hf=P3H
f=P0E`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aooooof00oooo00@0P820000000000000
0000P`3oool00`20P800oooo0?ooo`0Z0?ooo`@00000T@3Hf=P00`000000f=SH0=SHf01F0=SHf0<0
0000<@2BTY83000007h0oooo4oooool0017oooooG`3oool01020P800000000000010@40I0?ooo`03
0<30`000000000000080000000D0P8200?ooo`3oool0oooo0820P002000000030820P03oool0oooo
00<0oooo00@0P8200410@000000000000P20P8020?ooo`0300000020P800P82000H0oooo00<0P820
0410@00000000P0000001@10@400P8200?ooo`20P80000000080P8200`3oool00`20P80000000000
0002000000030410@020P800oooo00@0oooo00D0`<3000000000000000000820P0070?ooo`030820
P0000000@41000@0P82000<0`<300?ooo`3oool00`3oool00`20P800@41000000003000000030820
P03oool0oooo00X0oooo00<0P8200000003oool0:P3oool30000000303Hf=P3Hf=P0f=SH0900f=SH
00<0=SHf06a/K03Hf=P0EP3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooooeh0oooo1000
00000`20P800oooo0?ooo`0G0?ooo`L0000000<0oooo000000000000100000030?ooo`030820P000
0000000000@0000000<0P8200?ooo`000000100000030?ooo`T0000000<0P8200000000000000P00
00040?ooo`<000001`3oool00`20P800000000000003000000@0oooo0`0000060?ooo`8000001P3o
ool3000000h0oooo0P00000Z0?ooo`@0000000<0K6a/0=SHf03Hf=P0T03Hf=P00`1/K6`000000=SH
f01F0=SHf0<00000<@2BTY83000007h0oooo4oooool0017oooooG@3oool00`20P800000000000002
000000030?ooo`000000P82001H0oooo100000030?ooo`D000000P3oool01@000000oooo0?ooo`3o
ool0P82000<000000`3oool01@000000oooo000000000000P82000@0oooo00<0P820000000000000
0P0000001020P800oooo0?ooo`3oool4000000H0oooo0`0000070?ooo`<000000P3oool01@000000
oooo0?ooo`3oool0P8200080000000<0P8200?ooo`3oool0103oool00`20P80000000820P0050?oo
o`<000003@3oool4000002T0oooo1000002C0=SHf00306a/K0000000f=SH05H0f=SH0`00000a09:B
TP<00000OP3ooolCooooo`004OoooomL0?ooo`050820P0000000000000000010@4000P3oool00`20
P800@4100?ooo`0E0?ooo`<0000000<0`<300?ooo`3oool00P3oool01030`<000000000000000006
0?ooo`80000000<0@4100?ooo`3oool00`3oool01020P800000000000020P8040?ooo`040410@000
000000000410@0H0oooo00<0@4100000000000001P3oool3000000L0oooo0P0000001@20P800oooo
0?ooo`3oool0P8200080oooo0`0000080?ooo`8000001@3oool3000000`0oooo00<0`<3000000000
00000P00000X0?ooo`050410@000000000000000001/K6`0U03Hf=P2000005H0f=SH0`00000a09:B
TP<00000OP3ooolCooooo`004OoooomK0?ooo`030820P0000000000000800000103oool00`000000
oooo0?ooo`0D0?ooo`<000001P3oool3000000H0oooo0P0000000`20P800oooo0?ooo`040?ooo`80
000000<0P8200?ooo`3oool00P3oool3000000030820P03oool0oooo00@0oooo00<0P82000000000
00001P3oool3000000L0oooo0P0000000`20P800oooo0?ooo`030?ooo`<000002P3oool2000000@0
oooo0`00000<0?ooo`060820P000000000000820P03oool0P8209P3oool40000000306a/K03Hf=P0
f=SH03l0f=SH00<0K6a/000000000000100000000`1/K6`0f=SH0=SHf0020=SHf0L000001`3Hf=P0
101/K6`000000000001/K6`30=SHf0030000003Hf=P0f=SH00<0f=SH1`0000070=SHf0@0000000D0
K6a/0=SHf03Hf=P0K6a/0000000F0=SHf0800000EP3Hf=P300000340TY:B0`00001n0?oooa?ooooo
000AoooooeT0oooo0P20P803000000030820P03oool0oooo00<0oooo00<000000?ooo`3oool0503o
ool00`20P8000000000000060?ooo`<000001P3oool2000000030820P03oool0oooo00@0oooo0P00
00001020P800oooo0?ooo`3oool4000000L0oooo00<0P8200000000000001P3oool3000000L0oooo
0P0000000`20P800oooo0?ooo`020?ooo`040<30`00000000000000000X0oooo0P0000001030`<00
oooo0?ooo`3oool3000000`0oooo0`0000000`30`<00oooo0410@00U0?ooo`070410@00000000000
0000001/K6`0XZ:R06a/K0120=SHf00406a/K0000000000003Hf=PL0f=SH00D0K6a/000000000000
00000::RXP060=SHf0030::RXP000000000000@0000000<0XZ:R0=SHf00000000P0000000`0f=SH0
K6a/0=SHf0020=SHf00403Hf=P000000000006a/K0H0f=SH00<0K6a/0000000000001@00000206a/
K0<0000000<0K6a/0=SHf03Hf=P04P3Hf=P00`000000K6a/0=SHf01D0=SHf0<00000<@2BTY830000
07h0oooo4oooool0017oooooE`3oool6000000030820P03oool0oooo00@0oooo00<0P8200000003o
ool05@3oool00`20P80000000820P0050?ooo`<000001P3oool2000000030820P03oool0oooo00@0
oooo0P0000001020P800oooo0?ooo`3oool3000000P0oooo00<0P8200000000000001P3oool30000
00L0oooo0P0000000`20P800oooo0?ooo`020?ooo`030820P0000000000000/0oooo0P0000001020
P800oooo0?ooo`3oool3000000`0oooo0`0000020?ooo`030820P03oool0oooo0280oooo10000002
0=SHf00306a/K0000000K6a/0480f=SH0P0000000`1/K6`0f=SH0=SHf0060=SHf0<000001`3Hf=P0
101/K6`000000000000000030=SHf0030000003Hf=P00000008000001@3Hf=P00`1/K6`000000000
00060=SHf00306a/K000000000000080000000@0K6a/0=SHf03Hf=P0f=SH1000000F0=SHf0030000
001/K6`0f=SH05@0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004OoooomF0?ooo`H00000203o
ool00`20P80000000?ooo`0F0?ooo`8000001@3oool3000000H0oooo0P0000000`20P800oooo0?oo
o`040?ooo`80000000@0P8200?ooo`3oool0oooo0`0000080?ooo`030820P0000000000000H0oooo
0`0000070?ooo`80000000<0P8200?ooo`3oool00P3oool00`20P80000000000000;0?ooo`800000
00@0P8200?ooo`3oool0oooo0`00000;0?ooo`<000000`3oool00`20P800oooo0?ooo`0Q0?ooo`@0
000000H0K6a/0=SHf03Hf=P0f=SH0000001/K6a20=SHf080000000<0K6a/0=SHf03Hf=P01P3Hf=P3
000000L0f=SH0`0000050=SHf0@000001@3Hf=P00`1/K6`00000000000060=SHf00406a/K0000000
0000000000H0f=SH0`00000G0=SHf0030000003Hf=P0f=SH05<0f=SH0`00000a09:BTP<00000OP3o
oolCooooo`004Ooooom:0?ooo`X0P82000<0@4100000000000000`0000000`20P800`<300?ooo`07
0?ooo`030820P0000000oooo01L0oooo0`20P8000`30`<00oooo0?ooo`03000000H0oooo0P000000
0`20P800oooo0?ooo`040?ooo`80000000@0P8200?ooo`3oool0oooo0`0000080?ooo`030820P000
0000000000H0oooo0`0000070?ooo`80000000<0P8200?ooo`3oool00P3oool00`20P80000000000
000;0?ooo`80000000@0P8200?ooo`3oool0oooo0`00000:0?ooo`040<30`00000000000000000@0
oooo00<000000?ooo`3oool07@3oool00`30`<00P820000000030000000306a/K03Hf=P0f=SH0080
f=SH00<0K6a/0000003Hf=P0@@3Hf=P20000000306a/K03Hf=P0f=SH00H0f=SH0`0000070=SHf080
000000<0K6a/0=SHf03Hf=P0103Hf=P3000000D0f=SH00<0K6a/0000000000001P3Hf=P3000000L0
f=SH00<0K6a/0000000000005`3Hf=P00`000000f=SH0=SHf01C0=SHf0<00000<@2BTY83000007h0
oooo4oooool0017oooooA`3ooolD000000030820P03oool0oooo00L0oooo0P00000J0?ooo`030820
P0000000P82000<000001P3oool2000000030820P03oool0oooo00@0oooo0P0000001020P800oooo
0?ooo`3oool3000000P0oooo00<0P8200000000000001P3oool3000000L0oooo0P0000000`20P800
oooo0?ooo`020?ooo`030820P0000000000000/0oooo0P0000001020P800oooo0?ooo`3oool30000
00X0oooo00<0P8200000000000001@3oool00`000000oooo0?ooo`0L0?ooo`H0000000<0K6a/0=SH
f03Hf=P0103Hf=P00`000000f=SH0=SHf0100=SHf080000000<0K6a/0=SHf03Hf=P01P3Hf=P30000
00L0f=SH0P0000000`1/K6`0f=SH0=SHf0040=SHf0<000001@3Hf=P00`1/K6`00000000000050=SH
f0<0000000<0K6a/0=SHf03Hf=P01@3Hf=P00`1/K6`000000000000G0=SHf00306a/K0000000f=SH
05<0f=SH0`00000a09:BTP<00000OP3ooolCooooo`004Ooooom20?ooo`<0P820600000020820P0H0
oooo0P00000L0?ooo`040<30`00000000000000000H0oooo0P0000000`20P800oooo0?ooo`040?oo
o`80000000<0P8200?ooo`3oool00P3oool2000000P0oooo00<0P8200000000000001P3oool30000
00L0oooo0P0000000`20P800oooo0?ooo`020?ooo`030<30`0000000000000X0oooo0`0000001030
`<00oooo0?ooo`3oool3000000X0oooo0P0000000`10@400oooo0?ooo`040?ooo`030000003oool0
oooo00L0oooo4`20P807000000L0K6a/0P00000306a/K3h0f=SH0P0000000`1/K6`0f=SH0=SHf006
0=SHf0<000001`3Hf=P20000000306a/K03Hf=P0f=SH00@0f=SH0`0000050=SHf00306a/K0000000
000000D0f=SH0`0000000`2RXZ80f=SH0=SHf0050=SHf00306a/K0000000000001L0f=SH00<0K6a/
0000003Hf=P0D`3Hf=P300000340TY:B0`00001n0?oooa?ooooo000Aoooood00oooo2P0000000`19
BDT0TY:B09:BTP0;09:BTPP0000000<0P8200?ooo`3oool00P3oool2000001D0oooo00<0P8200000
003oool01@3oool3000000H0oooo0P0000000`20P800oooo0?ooo`040?ooo`80000000<0P8200?oo
o`3oool00P3oool2000000P0oooo00<0P8200000000000001P3oool3000000L0oooo0P0000000`20
P800oooo0?ooo`030?ooo`8000002P3oool3000000@0oooo0`0000090?ooo`<0000000<0P8200?oo
o`3oool0103oool00`000000oooo0?ooo`070?ooobH00000?P3Hf=P20000000306a/K03Hf=P0f=SH
00H0f=SH0`0000070=SHf080000000<0K6a/0=SHf03Hf=P0103Hf=P3000000D0f=SH00<0K6a/0000
000000001@3Hf=P3000000P0f=SH00<0K6a/000000000000603Hf=P00`000000K6a/0=SHf01B0=SH
f0<00000<@2BTY83000007h0oooo4oooool0017ooooo?`3oool00`20P80000000000000400000080
BDU900<0KVi^09:BTP2BTY803`2BTY800`19BDT09BDU00000005000000060820P03oool0oooo0820
P0000000`<30503oool2000000030820P03oool0oooo00<0oooo0`0000060?ooo`80000000<0P820
0?ooo`3oool0103oool2000000030820P03oool0oooo0080oooo00<0`<300000000000001`3oool0
0`20P8000000000000060?ooo`<000001`3oool2000000030820P03oool0oooo00@0oooo0P000008
0?ooo`040820P000000000000820P0@0oooo0`0000000`20P800oooo0?ooo`050?ooo`040<30`000
00000000000000P0oooo00<0P8200?ooo`3oool01P3ooolV000003h0f=SH0P0000000`1/K6`0f=SH
0=SHf0060=SHf0<000001`3Hf=P20000000306a/K03Hf=P0f=SH00@0f=SH0`0000050=SHf00306a/
K0000000000000D0f=SH0`0000080=SHf00306a/K0000000000001P0f=SH00<0K6a/03Hf=P3Hf=P0
D@3Hf=P0102RXZ80000000000000000a09:BTP<00000OP3ooolCooooo`004Oooooln0?ooo`D00000
00<0BDU909:BTP2BTY805`2BTY800`19BDT000000000000400000080oooo00<000000820P03oool0
4`3oool2000000030820P03oool0oooo00<0oooo0P0000000`20P800oooo0?ooo`040?ooo`800000
00<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo00<0oooo0P0000000`20P800oooo
0?ooo`040?ooo`<000001P3oool3000000L0oooo0P0000000`20P800oooo0?ooo`040?ooo`030820
P0000000000000L0oooo0P0000000`20P800oooo0?ooo`020?ooo`030820P0000000000000800000
0`3oool01@000000P8200?ooo`3oool0P820008000002@3oool00`000000oooo0?ooo`060?ooo`80
000000<0BDU909:BTP2BTY807P2BTY83000003h0f=SH0P0000000`1/K6`0f=SH0=SHf0060=SHf0<0
00001`3Hf=P20000000306a/K03Hf=P0f=SH00@0f=SH0`0000050=SHf00306a/K0000000000000D0
f=SH0`0000080=SHf00306a/K0000000000001T0f=SH00<000000=SHf03Hf=P0D03Hf=P0101/K6`0
000000000000000a09:BTP<00000OP3ooolCooooo`004Ooooolm0?ooo`@0000000<0BDU909:BTP2B
TY806`2BTY86000000030?ooo`000000P82001@0oooo00<0P82000000020P800103oool01020P800
000000000020P8060?ooo`80000000<0P8200?ooo`3oool0103oool2000000030820P03oool0oooo
00@0oooo0P0000050?ooo`@00000103oool5000000L0oooo0P0000000`20P800oooo0?ooo`050?oo
o`80000000<0P8200?ooo`3oool00`3oool3000000@0oooo1@0000000`3oool000000?ooo`030000
0080oooo0`0000090?ooo`030820P03oool0oooo00H0oooo0P0000000`19BDT0TY:B09:BTP0N09:B
TP<00000?P3Hf=P20000000306a/K03Hf=P0f=SH00H0f=SH0`0000070=SHf080000000<0K6a/0=SH
f03Hf=P0103Hf=P3000000D0f=SH00<0K6a/0000000000001P3Hf=P2000000P0f=SH00<0K6a/0000
000000006@3Hf=P00`000000f=SH0=SHf01@0=SHf00306a/K000000000000380TY:B0`00001n0?oo
oa?ooooo000Aoooooc/0oooo00<0P8200000000000000P0000000`19BDT0TY:B09:BTP0M09:BTP03
06i^KP0000000000008000000P20P8000`10@400oooo0?ooo`0C0?ooo`H0P82000<000000820P020
P800103oool00`30`<00P82000000002000000030820P03oool0oooo0080oooo00D0P82000000000
000000000820P0070?ooo`030<30`020P800P8200080P82000<000000820P010@4000P0000050?oo
o`80P8200P0000040?ooo`030<30`020P800P8200080000000@0@4100820P020P800P8201@3oool5
0820P0040410@0000000P8200<30`0H0oooo00L0`<300820P010@40000000?ooo`30`<00P8200080
000000<0@4100820P0000000100000000`20P800oooo0?ooo`030?ooo`80P8200P0000000`30`<00
oooo0?ooo`040?ooo`80000000<0BDU909:BTP2BTY807P2BTY83000003h0f=SH0P0000000`1/K6`0
f=SH0=SHf0060=SHf0<000001`3Hf=P20000000306a/K03Hf=P0f=SH00@0f=SH0`0000050=SHf003
06a/K0000000000000H0f=SH0P0000080=SHf00306a/K0000000000001T0f=SH00<0K6a/0000003H
f=P0D03Hf=P00`1/K6`000000000000b09:BTP<00000OP3ooolCooooo`004Ooooolj0?ooo`050820
P0000000000000000019BDT08`2BTY800`19BDT0000000000003000003l0oooo00<0P82000000000
00003`3oool3000000030820P03oool0oooo03H0oooo0P0000000`19BDT0TY:B09:BTP0N09:BTP<0
0000?P3Hf=P20000000306a/K03Hf=P0f=SH00H0f=SH0`0000070=SHf080000000<0K6a/0=SHf03H
f=P0103Hf=P3000000D0f=SH00<0K6a/0000000000001P3Hf=P00`1/K6`0000006a/K0070=SHf003
06a/K0000000000001T0f=SH00<0K6a/0000003Hf=P0D03Hf=P00`1/K6`000000000000b09:BTP<0
0000OP3ooolCooooo`004Ooooolh0?ooo`030820P000000000000080000000<0BDU909:BTP2BTY80
8`2BTY800`19BDT0000000000002000003l0oooo00<0P820000000000000403oool00`10@4000000
0820P00h0?ooo`80000000<0BDU909:BTP2BTY807P2BTY83000003h0f=SH0P0000000`1/K6`0f=SH
0=SHf0060=SHf0<000001`3Hf=P20000000306a/K03Hf=P0f=SH00@0f=SH0`0000050=SHf00306a/
K0000000000000L0f=SH00<0000003Hf=P3Hf=P01P3Hf=P00`0f=SH000000000000J0=SHf0030000
001/K6`0f=SH04l0f=SH00<0@410000000000000<P2BTY83000007h0oooo4oooool0017ooooo=`3o
ool00`20P8000000000000020000000304U9B@2BTY80TY:B02D0TY:B00<0BDU90000000000000P00
000n0?ooo`030820P000000000000140oooo00<000000820P03oool0=`3oool20000000304U9B@2B
TY80TY:B01h0TY:B0`0000000`1/K6`0f=SH0=SHf00k0=SHf080000000<0K6a/0=SHf03Hf=P01P3H
f=P3000000L0f=SH0P0000000`1/K6`0f=SH0=SHf0040=SHf0<000000`3Hf=P5000000P0f=SH0P00
00050=SHf0@000006P3Hf=P00`000000K6a/0=SHf01?0=SHf080000000<0BDU909:BTP2BTY80<02B
TY83000007h0oooo4oooool0017ooooo=`3oool01010@40000000000000U9BDZ09:BTP0504U9B@00
0000000000000010@400?@3oool00`20P80000000000000A0?ooo`80P820>03oool20000000304U9
B@2BTY80TY:B01h0TY:B0`0000000`0f=SH0f=SH0=SHf00h0=SHf0030::RXP1/K6`0K6a/00800000
00<0=SHf06a/K01/K6`01P3Hf=P3000000D0f=SH00D0K6a/000000000000000006a/K0040=SHf003
06a/K00000000000008000001@3Hf=P206a/K0030000003Hf=P0f=SH00L0f=SH1@1/K6`00`000000
K6a/03Hf=P02000001/0f=SH00<000000=SHf03Hf=P0C@3Hf=P01020P800000000000019BDTb09:B
TP<00000OP3ooolCooooo`004Ooooolf0?ooo`@0000000<0BDU909:BTP2BTY80:P2BTY801019BDT0
000000000000000l0?ooo`030820P0000000000004/0oooo0P0000000`19BDT0TY:B09:BTP0N09:B
TP@00000?@3Hf=P20000000306a/K03Hf=P0f=SH00H0f=SH0`00000[0=SHf00306a/K00000000000
01/0f=SH00<000000=SHf03Hf=P0C@3Hf=P30000000304U9B@2BTY80TY:B0300TY:B0`00001n0?oo
oa?ooooo000AooooocD0oooo00<0P8200000000000000P00000]09:BTP0404U9B@00000000000000
03`0oooo00<0P8200000000000001P3oool00`20P80000000?ooo`120?ooo`80000000<0BDU909:B
TP2BTY807P2BTY84000003d0f=SH0P0000000`1/K6`0f=SH0=SHf0060=SHf0<00000:`3Hf=P00`1/
K6`000000000000K0=SHf00306a/K0000000f=SH04`0f=SH00@0k>c/0000000000000000<`2BTY83
000007h0oooo4oooool0017ooooo=@3oool01010@400000000000019BDT_09:BTP<0000000<0@410
0?ooo`3oool0=`3oool20820P0<000001P3oool300000480oooo0P0000000`19BDT0TY:B09:BTP0N
09:BTP<0000000<0=SHf0000003Hf=P0>`3Hf=P20000000306a/K03Hf=P0f=SH00H0f=SH0`00000[
0=SHf00306a/K0000000000001/0f=SH00<0K6a/0000003Hf=P0C03Hf=P0101/K6`0000000000000
000c09:BTP<00000OP3ooolCooooo`004Ooooole0?ooo`<00000<02BTY84000003d0oooo00<00000
0?ooo`3oool0103oool00`20P80000000?ooo`120?ooo`80000000<0BDU909:BTP2BTY807P2BTY83
0000000306a/K0000000K6a/03/0f=SH00<0K6a/0000001/K6`0203Hf=P3000002/0f=SH00<0K6a/
000000000000703Hf=P2000004`0f=SH00<0P820000000000000=02BTY83000007h0oooo4oooool0
017ooooo=03oool01020P80000000000001^KVh`09:BTP0304U9B@000000000000800000R03oool2
0000000304U9B@2BTY80TY:B01h0TY:B0`0000000`3Hf=P0000003Hf=P0k0=SHf00306a/K0000000
K6a/00P0f=SH0`00000[0=SHf00306a/K0000000000001`0f=SH0P00001;0=SHf0040820P0000000
000002DU9C@0TY:B0`00001n0?oooa?ooooo000Aoooooc<0oooo1000000b09:BTP@00000R03oool2
0000000304U9B@2BTY80TY:B01h0TY:B0`0000020=SHf0030000003Hf=P0f=SH03X0f=SH00<00000
06a/K03Hf=P00`3Hf=P0101/K6`000000=SHf03Hf=P3000001T0f=SH00<0000006a/K03Hf=P03`3H
f=P00`1/K6`000000000000M0=SHf0030000001/K6`0f=SH04P0f=SH00@0oooo0000000000000000
=@2BTY83000007h0oooo4oooool0017ooooo<`3oool3000003<0TY:B00D0000009:BTP0000000000
0820P0270?ooo`80000000<0BDU909:BTP2BTY807P2BTY8300000080f=SH00<0000006a/K03Hf=P0
>P3Hf=P00`1/K6`0=SHf0=SHf0020=SHf00406a/K0000000000003Hf=P@00000603Hf=P00`1/K6`0
00000000000>0=SHf080K6a/0`00000M0=SHf0030000001/K6`0f=SH04L0f=SH00D0h^;R00000000
0000000004U9B@0e09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`040820P000000000000000
03<0TY:B00<0000009:BTP19BDT00`0000260?ooo`80000000<0BDU909:BTP2BTY807P2BTY830000
0080f=SH00<0K6a/0000003Hf=P0?03Hf=P5000000@0f=SH0P00000I0=SHf0030000001/K6`0f=SH
0140f=SH00<000000=SHf03Hf=P0703Hf=P00`000000f=SH0=SHf0160=SHf00406a/K00000000000
000003H0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo00@0P820000000000000BDU9<`2BTY80
1019BDT0000009:BTP2BTY82000008H0oooo0P0000000`19BDT0TY:B09:BTP0N09:BTP<000000P3H
f=P00`1/K6`000000000002C0=SHf0030000003Hf=P0f=SH04H0f=SH00@0P820000000000000BDU9
=P2BTY83000007h0oooo4oooool0017ooooo<P3oool01020P800000000000019BDTc09:BTP0304U9
B@000000TY:B00@0000000<0`<300?ooo`3oool0PP3oool20000000304U9B@2BTY80TY:B01h0TY:B
0`0000030=SHf0800000T`3Hf=P00`0f=SH0K6a/0=SHf0150=SHf0050820P0000000000000000019
BDT0=P2BTY83000007h0oooo4oooool0017ooooo<P3oool01020P800000000000019BDTc09:BTP04
04U9B@000000TY:B09:BTP@00000Q03oool20000000304U9B@2BTY80TY:B01h0TY:B0`0000030=SH
f080000000<0K6a/0=SHf03Hf=P0T03Hf=P00`1/K6`000000=SHf0140=SHf00306a/K00000000000
00800000=`2BTY83000007h0oooo4oooool0017ooooo<P3oool01010@400000000000019BDTd09:B
TP0500000019BDT0TY:B09:BTP0U9BD00`0000230?ooo`80000000<0BDU909:BTP2BTY807P2BTY83
000000@0f=SH00<0000003Hf=P3Hf=P0T@3Hf=P00`2RXZ8000000::RXP130=SHf0040>c/k010@400
0000000003T0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`00000e09:BTP0300000019BDT0
TY:B0080TY:B100000220?ooo`80000000<0BDU909:BTP2BTY807P2BTY83000000D0f=SH00<00000
0=SHf03Hf=P0T@3Hf=P00`000000K6a/0=SHf0120=SHf0<0000000<0BDU909:BTP2BTY80=`2BTY83
000007h0oooo4oooool0017ooooo<P3oool3000003D0TY:B00<0000004U9B@2BTY800`2BTY830000
00030820P03oool0oooo07l0oooo0P0000000`19BDT0TY:B09:BTP0N09:BTP<000001@3Hf=P00`00
0000f=SH0=SHf02B0=SHf0030000003Hf=P0f=SH0400f=SH00@0K6a/0000000000000000>P2BTY83
000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B03<0TY:B00<0000009:B
TP2BTY800P2BTY801@0U9BD00000000000000000P8200800oooo0P0000000`19BDT0TY:B09:BTP0N
09:BTP<000001@3Hf=P00`0f=SH000000=SHf02B0=SHf0030000003Hf=P0f=SH03l0f=SH00@0K6a/
0000000000000000>`2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80
TY:B03<0TY:B00<0000009:BTP2BTY800`2BTY84000000030820P03oool0oooo07d0oooo0P000000
0`19BDT0TY:B09:BTP0N09:BTP<000001@3Hf=P00`1/K6`0000006a/K02B0=SHf00306a/K0000000
f=SH03d0f=SH00<0K6a/0000000000000P0000000`19BDT0TY:B09:BTP0i09:BTP<00000OP3ooolC
ooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80<`2BTY800`000000TY:B09:BTP0409:B
TP0304U9B@00000000000080000000<0`<300?ooo`3oool0N`3oool20000000304U9B@2BTY80TY:B
01h0TY:B0`0000060=SHf0030000001/K6`0f=SH0940f=SH00<0K6a/0000003Hf=P0?03Hf=P00`1/
K6`00000000000020000000304U9B@2BTY80TY:B03X0TY:B0`00001n0?oooa?ooooo000Aoooooc80
oooo0`0000000`19BDT0TY:B09:BTP0c09:BTP0304U9B@000000TY:B00D0TY:B00<0BDU900000000
00000P00001m0?ooo`80000000<0BDU909:BTP2BTY807P2BTY83000000H0f=SH0P00002C0=SHf080
0000>`3Hf=P50000000304U9B@2BTY80TY:B03/0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo
0`0000000`19BDT0TY:B09:BTP0c09:BTP0304U9B@000000TY:B00H0TY:B00<0BDU902DU9@000000
0P0000000`20P800`<300?ooo`1i0?ooo`80000000<0BDU909:BTP2BTY807P2BTY83000000L0f=SH
00<0000006a/K03Hf=P0T@3Hf=P2000003P0f=SH00<0h^;R06a/K0000000100000000`19BDT0TY:B
09:BTP0l09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80<`2B
TY800`19BDT0000009:BTP0809:BTPH00000N@3oool20000000304U9B@2BTY80TY:B01h0TY:B0`00
00070=SHf00306a/K0000000f=SH0980f=SH00<0000006a/K03Hf=P0=P3Hf=P00`20P80000000000
00020000000304U9B@2BTY80TY:B03h0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`000000
0`19BDT0TY:B09:BTP0d09:BTP8000002@2BTY85000000030820P03oool0oooo07H0oooo0P000000
0`19BDT0TY:B09:BTP0N09:BTP<000001`3Hf=P00`1/K6`0000006a/K02B0=SHf0030000001/K6`0
f=SH03@0f=SH00<0k>c/0000000000001000001109:BTP<00000OP3ooolCooooo`004Ooooolb0?oo
o`<0000000<0BDU909:BTP2BTY80=02BTY82000000T0TY:B00<0KVi^04U9B@000000100000000`20
P800oooo0?ooo`1d0?ooo`80000000<0BDU909:BTP2BTY807P2BTY83000000P0f=SH00<0000006a/
K03Hf=P0T@3Hf=P00`1/K6`0=SHf0=SHf00b0=SHf0030:b/[020P800000000@0000000<0BDU909:B
TP2BTY80@02BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B03@0
TY:B0P00000<09:BTP0304U9B@000000000000@00000M03oool20000000304U9B@2BTY80TY:B01h0
TY:B0`0000080=SHf0800000T`3Hf=P00`000000f=SH0=SHf00^0=SHf0030>c/k0000000000000H0
0000A02BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B03@0TY:B
00<0BDU90000001^KVh0302BTY800`19BDT09BDU00000005000000030410@020P800P82006l0oooo
0P0000000`19BDT0TY:B09:BTP0N09:BTP<000002@3Hf=P00`000000K6a/0=SHf02A0=SHf00303Hf
=P1/K6`0f=SH02X0f=SH00<0[:b/06a/K01fMWH01`0000000`19BDT0KVi^09:BTP1409:BTP<00000
OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80=@2BTY800`000000BDU909:B
TP0>09:BTPl00000J03oool20000000304U9B@2BTY80TY:B01h0TY:B0`0000090=SHf00306a/K000
0000f=SH0940f=SH00<0K6a/0000003Hf=P08P3Hf=P00`3/k>`000000000000>000004P0TY:B0`00
001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0e09:BTP0300000019BDT0
TY:B0100TY:B0`19BDWo000006L000000P19BDU;09:BTP<00000OP3ooolCooooo`004Ooooolb0?oo
o`<0000000<0BDU909:BTP2BTY80=P2BTY800`000000TY:B09:BTP0D09:BT_l00000H`00001?09:B
TP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80=P2BTY800`000000
TY:B09:BTP0L09:BT_l00000D`00001G09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<00000
00<0BDU909:BTP2BTY80=P2BTY800`000000TY:B09:BTP2e09:BTP0300000019BDT0TY:B0940TY:B
00<0000009:BTP2BTY80N@2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2B
TY80TY:B03H0TY:B00<0BDU90000002BTY80]@2BTY8200000980TY:B00<0000009:BTP2BTY80N@2B
TY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B03H0TY:B00<0BDU9
0000002BTY80]P2BTY800`000000BDU909:BTP2@09:BTP0304U9B@000000TY:B07T0TY:B0`00001n
0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0f09:BTP0304U9B@000000TY:B
0;H0TY:B00<0BDU90000002BTY80T02BTY800`19BDT0000009:BTP1i09:BTP<00000OP3ooolCoooo
o`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80=P2BTY800`19BDT0000009:BTP2f09:BTP03
04U9B@000000BDU90940TY:B00<0000004U9B@2BTY80N02BTY83000007h0oooo4oooool0017ooooo
<P3oool30000000304U9B@2BTY80TY:B03L0TY:B00<0000004U9B@2BTY80]P2BTY800`000000BDU9
09:BTP2@09:BTP0300000019BDT0TY:B07P0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`00
00000`19BDT0TY:B09:BTP0g09:BTP0300000019BDT0TY:B0;H0TY:B0P00002B09:BTP030000002B
TY80TY:B07L0TY:B0`00001n0?oooa?ooooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0g
09:BTP0304U9B@0U9BD0TY:B0;L0TY:B00<0000004U9B@2BTY80T02BTY800`0U9BD0BDU909:BTP1g
09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80>02BTY800`00
0000TY:B09:BTP2f09:BTP0304U9B@000000TY:B0900TY:B00<0BDU90000002BTY80M`2BTY830000
07h0oooo4oooool0017ooooo<P3oool30000000304U9B@2BTY80TY:B03P0TY:B00<0000009:BTP2B
TY80]P2BTY800`19BDT0000004U9B@2@09:BTP0306i^KP000000BDU907L0TY:B0`00001n0?oooa?o
oooo000Aoooooc80oooo0`0000000`19BDT0TY:B09:BTP0h09:BTP0304U9B@000000TY:B0;L0TY:B
0P00002A09:BTP800000M`2BTY83000007h0oooo4oooool0017ooooo<P3oool30000000304U9B@2B
TY80TY:B03P0TY:B00<0BDU90000002BTY80]`2BTY820000000304U9B@2BTY80TY:B08h0TY:B0P00
001g09:BTP<00000OP3ooolCooooo`004Ooooolb0?ooo`<0000000<0BDU909:BTP2BTY80>02BTY80
0`19BDT0000009:BTP2h09:BTP0300000019BDT0TY:B0900TY:B00<0000004U9B@2BTY80M@2BTY83
000007h0oooo4oooool0017ooooo<P3oool01020P800000000000000000j09:BTP0304U9B@000000
TY:B0;P0TY:B0P00002A09:BTP0300000019BDT0TY:B07D0TY:B0`00001n0?oooa?ooooo000Aoooo
oc80oooo00@0P8200000000000000000>`2BTY8200000;T0TY:B00<0000004U9B@2BTY80T02BTY80
0`000000TY:B09:BTP1c09:BTP0404U9B@00000000000820P7h0oooo4oooool0017ooooo<P3oool0
1020P800000000000000000k09:BTP800000^@2BTY800`19BDT0000009:BTP2@09:BTP030000002B
TY80TY:B07<0TY:B00@0BDU9000000000000P820OP3ooolCooooo`004Ooooolb0?ooo`040820P000
00000000000003/0TY:B00<0BDU90000001^KVh0^02BTY800`1^KVh0000004U9B@2@09:BTP0304U9
B@000000TY:B07<0TY:B00@0BDU9000000000000P820OP3ooolCooooo`004Ooooolb0?ooo`040820
P00000000000000003`0TY:B00<0000004U9B@2BTY80^02BTY800`000000BDU909:BTP2?09:BTP03
04U9B@000000TY:B07<0TY:B0`0000000`20P800oooo0?ooo`1l0?oooa?ooooo000Aoooooc<0oooo
0`00000l09:BTP0300000019BDT0TY:B0;P0TY:B0P00002A09:BTP0300000019BDT0TY:B0780TY:B
0`0000000`20P800oooo0?ooo`1l0?oooa?ooooo000Aoooooc@0oooo0`00000k09:BTP0304U9B@0U
9BD0TY:B0;T0TY:B00<0000004U9B@2BTY80S`2BTY800`000000BDU909:BTP1b09:BTP<00000O`3o
oolCooooo`004Ooooold0?ooo`<00000?02BTY800`000000TY:B09:BTP2h09:BTP0304U9B@000000
TY:B0900TY:B00<0000009:BTP2BTY80L02BTY84000007l0oooo4oooool0017ooooo=@3oool20000
000304U9B@2BTY80TY:B03T0TY:B00<0000009:BTP2BTY80^02BTY800`19BDT0000006i^KP2@09:B
TP030000002BTY80TY:B0700TY:B0`0000200?oooa?ooooo000AooooocD0oooo0`00000k09:BTP03
0000002BTY80TY:B0;T0TY:B00<0000004U9B@2BTY80S`2BTY800`19BDT0000009:BTP1_09:BTP04
04U9B@000000000000000800oooo4oooool0017ooooo=@3oool00`20P80000000000000k09:BTP03
04U9B@000000TY:B0;T0TY:B00<0BDU90000002BTY80S`2BTY800`19BDT0000009:BTP1_09:BTP03
04U9B@00000000000840oooo4oooool0017ooooo=@3oool00`20P80000000000000k09:BTP0304U9
B@000000TY:B0;X0TY:B00<0000009:BTP2BTY80S`2BTY800`000000BDU909:BTP1^09:BTP<00000
P@3ooolCooooo`004Ooooolf0?ooo`<00000>P2BTY800`19BDT0000009:BTP2j09:BTP800000T02B
TY800`000000BDU909:BTP1]09:BTP@00000P@3ooolCooooo`004Ooooolf0?ooo`040820P0000000
000004U9BCX0TY:B00<0000004U9B@2BTY80^@2BTY800`19BDT0000004U9B@2?09:BTP0304U9B@0U
9BD0TY:B06`0TY:B00D0BDU900000000000000000<30`0210?oooa?ooooo000AooooocL0oooo0`00
000j09:BTP0300000019BDT0TY:B0;X0TY:B0P00002@09:BTP030000002BTY80TY:B06/0TY:B1000
00220?oooa?ooooo000AooooocL0oooo00@0P820000000000000BDU9>@2BTY800`000000BDU909:B
TP2j09:BTP0304U9B@000000BDU908l0TY:B00<0BDU90000002BTY80JP2BTY801019BDT000000000
000000230?oooa?ooooo000AooooocP0oooo1000000i09:BTP030000002BTY80TY:B0;X0TY:B00<0
000004U9B@2BTY80SP2BTY800`19BDT0000009:BTP1Z09:BTP<0000000<0P8200?ooo`3oool0P@3o
oolCooooo`004Ooooolh0?ooo`@0000000<0BDU909:BTP2BTY80=P2BTY800`000000TY:B09:BTP2j
09:BTP800000T02BTY82000006T0TY:B100000000`20P800oooo0?ooo`210?oooa?ooooo000Aoooo
ocT0oooo00@0P8200000000000009BDU>02BTY800`000000TY:B09:BTP2k09:BTP0300000019BDT0
TY:B08h0TY:B0P00001X09:BTP0504U9B@000000000000000020P800Q03ooolCooooo`004Ooooolj
0?ooo`040820P00000000000000003L0TY:B00<0BDU90000002BTY80^`2BTY800`19BDT0000009:B
TP2?09:BTP0300000019BDT0TY:B06H0TY:B0`0000260?oooa?ooooo000AooooocX0oooo00D0`<30
000000000000000004U9B@0f09:BTP0304U9B@000000TY:B0;/0TY:B00<0BDU90000001^KVh0S`2B
TY800`000000BDU909:BTP1T09:BTP0506i^KP000000000000000020P800QP3ooolCooooo`004Ooo
ooll0?ooo`<00000=P2BTY800`19BDT0000009:BTP2l09:BTP0300000019BDT0TY:B08l0TY:B00<0
000009:BTP2BTY80H`2BTY84000008L0oooo4oooool0017ooooo?03oool01P20P800000000000000
0000BDU906i^KS@0TY:B00<0000004U9B@2BTY80^`2BTY800`19BDT0000009:BTP2?09:BTP030000
002BTY80TY:B0640TY:B0P19BDT2000000030410@03oool0oooo08H0oooo4oooool0017ooooo?@3o
ool5000003@0TY:B00<0000004U9B@2BTY80_02BTY800`000000TY:B09:BTP2>09:BTP0304U9B@00
0000TY:B0600TY:B00<0BDU90000000000000P0000290?oooa?ooooo000Aoooooch0oooo1@00000c
09:BTP0300000019BDT0TY:B0;`0TY:B0P00002?09:BTP0304U9B@000000TY:B0600TY:B1000002:
0?oooa?ooooo000Aooooocl0oooo00<0P8200000000000000P0000000`19BDT0TY:B09:BTP0_09:B
TP0304U9B@0U9BD0TY:B0;`0TY:B00<0BDU90000001^KVh0SP2BTY800`1^KVh0000006i^KP1N09:B
TP0502DU9@000000000000000020P800R`3ooolCooooo`004Ooooom10?ooo`@0000000<0BDU909:B
TP2BTY80;`2BTY800`000000TY:B09:BTP2l09:BTP0300000019BDT0TY:B08h0TY:B00<0000004U9
B@2BTY80F`2BTY800`19BDT0000000000002000008d0oooo4oooool0017ooooo@P3oool00`20P800
0000000000020000000304U9B@2BTY80TY:B02d0TY:B00<0000009:BTP2BTY80_02BTY800`000000
9BDU09:BTP2>09:BTP0304U9B@0U9BD0TY:B05T0TY:B0P19BDT3000000030820P03oool0oooo08`0
oooo4oooool0017ooooo@`3oool6000002h0TY:B00<0BDU90000002BTY80_@2BTY800`000000TY:B
09:BTP2>09:BTP030000002BTY80TY:B05L0TY:B1P00002?0?oooa?ooooo000Aoooood@0oooo0P20
P8040000000302DU9@19BDT0BDU902X0TY:B00<0BDU90000002BTY80_@2BTY800`0U9BD0000009:B
TP2>09:BTP0302DU9@19BDT0TY:B05@0TY:B00<0BDU902DU9@0000000`0000000`10@400P8200?oo
o`2?0?oooa?ooooo000AooooodP0oooo1`0000000`19BDT0TY:B09:BTP0U09:BTP0304U9B@000000
TY:B0;d0TY:B00<0BDU9000000000000SP2BTY800`19BDT0000009:BTP1B09:BTPH00000U03ooolC
ooooo`004Ooooom90?ooo`P0000000<0BDU909:BTP2BTY80902BTY8200000;h0TY:B0P00002>09:B
TP0304U9B@000000TY:B04l0TY:B2000002E0?oooa?ooooo000AooooodX0oooo0P20P80<00000003
02DU9@19BDT0BDU901d0BDU90P00002n04U9B@800000S`19BDT00`0000009BDU04U9B@1704U9B@d0
00000P20P82E0?oooa?ooooo000Aooooodh0ooooo`00003A000009T0oooo4oooool0017oooooD03o
ool80820P?l00000_00000080820P9`0oooo4oooool0017oooooN@3oool00`000000P8200?ooo`2n
0?ooo`030000003oool0oooo08d0oooo00<0P8200000003oool0jP3ooolCooooo`004Ooooomi0?oo
o`0300000020P800oooo0;h0oooo0P00002>0?ooo`030820P0000000oooo0>X0oooo4oooool0017o
ooooN@3oool00`20P800@4100?ooo`2n0?ooo`030820P0000000`<3008d0oooo00<0`<3000000020
P800jP3ooolCooooo`004Ooooomj0?ooo`030000003oool0oooo0;h0oooo00<000000820P03oool0
S@3oool200000>X0oooo4oooool0017oooooNP3oool00`000000oooo0?ooo`2n0?ooo`0300000010
@400oooo08d0oooo00<0P82000000030`<00j@3ooolCooooo`004Ooooomj0?ooo`030000003oool0
oooo0;l0oooo00<000000?ooo`3oool0S@3oool00`000000P8200?ooo`3X0?oooa?ooooo000Aoooo
ogX0oooo00<0P8200000003oool0_`3oool00`10@40000000?ooo`2=0?ooo`030820P010@400oooo
0>P0oooo4oooool0017oooooNP3oool00`20P80000000?ooo`2o0?ooo`030820P0000000000008h0
oooo00<000000?ooo`3oool0i`3ooolCooooo`004Ooooomj0?ooo`030820P0000000oooo0<00oooo
0P00002>0?ooo`030000003oool0oooo0>L0oooo4oooool0017oooooN`3oool00`000000P8200?oo
o`2o0?ooo`80000000<0`<300?ooo`3oool0R`3oool00`20P80000000?ooo`3W0?oooa?ooooo000A
ooooog/0oooo00<000000820P03oool0`03oool00`000000P8200?ooo`3o0?ooogL0oooo4oooool0
017oooooN`3oool00`20P800@4100?ooo`300?ooo`030820P0000000oooo0?l0ooooM`3ooolCoooo
o`004Oooooml0?ooo`030000003oool0oooo0?l0ooooo`3ooolj0?oooa?ooooo000Aooooog`0oooo
00<0P8200?ooo`3oool0o`3ooooo0?ooocX0oooo4oooool0017oooooo`3ooooo0?oookT0oooo4ooo
ool0017oooooo`3ooooo0?oookT0oooo4oooool0017oooooo`3ooooo0?oookT0oooo4oooool0017o
ooooo`3ooooo0?oookT0oooo4oooool0017ooooo>03oool20820P0@0000000<0@4100820P03oool0
1@3oool01P20P8000000000000000000@4100820P0<0oooo00@0@41000000010@400P8200P3oool0
0`20P800@41000000003000000030820P03oool0oooo00h0oooo0P20P804000000040820P030`<00
oooo00000080P8200`3oool00`20P800@41000000003000000030820P03oool0oooo00H0oooo00T0
P82000000000000000000820P030`<00oooo0820P00000000P20P8030?ooo`030820P00000000000
0080000000H0@4100820P03oool0oooo0820P010@404000000050820P03oool0oooo0820P010@400
100000000`20P800oooo0?ooo`1R0?ooo`0300000030`<00oooo00H0oooo00<000000?ooo`3oool0
1`3oool00`20P800@41000000003000000060820P03oool0oooo0?ooo`20P800@4100`0000001P10
@400P8200?ooo`3oool0P8200410@0@0000000<0P8200?ooo`3oool00P3oool00`30`<00P8200000
0003000000040820P030`<00oooo00000080P82000<0`<300?ooo`3oool0103oool00`30`<00P820
000000050820P0`0oooo00<000000<30`03oool01P3oool00`000000oooo0?ooo`0M0?ooo`030<30
`020P800000000<0000000D0P8200<30`03oool0oooo0820P004000000050410@020P800oooo0?oo
o`20P800100000000`10@400P8200?ooo`040?ooo`030820P0000000000000<0000000<0P8200<30
`03oool00`3oool00`30`<00P82000000003000000050820P030`<00oooo0<30`020P80010000002
0820P080oooo00<0P8200000000000000P0000000`10@400P8200?ooo`040?ooo`030<30`020P800
000000@0000000<0@4100820P03oool0103oool00`30`<00P82000000003000000030820P030`<00
oooo00D0oooo00H0@41000000000000000000820P030`<020?ooo`080820P000000000000820P030
`<00oooo0820P010@403000000060410@020P800oooo0?ooo`20P800@410100000000`20P800oooo
0?ooo`020?ooo`030<30`020P800000000@0000000<0P8200?ooo`3oool0S`3ooolCooooo`004Ooo
oolg0?ooo`030820P0000000000000L00000103oool00`20P800000000000005000000030?ooo`00
0000000000@000000`3oool300000140oooo00<0P8200000000000001P0000000`3oool000000000
0003000000<0oooo0`0000090?ooo`L0000000<0oooo0820P00000000`0000001020P800oooo0?oo
o`3oool3000000H0oooo0`0000060?ooo`<00000I@3oool00`20P80000000820P0060?ooo`030820
P0000000000000X0oooo0`0000070?ooo`<000001P3oool3000000H0oooo200000000`3oool00000
00000003000000@0oooo0`0000050?ooo`030820P0000000P82000T0oooo00<0P82000000020P800
1P3oool00`20P80000000820P00Q0?ooo`80000000<0P8200?ooo`3oool0103oool3000000H0oooo
0`0000060?ooo`T000001P3oool01020P800000000000020P8060?ooo`80000000<0P8200?ooo`3o
ool0103oool3000000H0oooo100000040?ooo`030820P0000000P82000H0oooo00@0P82000000000
0000P8201`3oool7000000030?ooo`20P800000000@000000`3oool3000000H0oooo0`0000060?oo
o`T00000T03ooolCooooo`004Ooooolg0?ooo`@0000000@0P8200?ooo`3oool0oooo0P20P8001010
@400oooo0?ooo`3oool3000000060410@03oool0oooo0?ooo`20P800@4100`0000020?ooo`040820
P03oool0oooo0?ooo`<000004@3oool3000000030410@020P800oooo0080oooo00D0`<3000000000
000000000820P0050?ooo`<00000203oool01@30`<000000000000000000P8200080oooo00<0`<30
0820P010@4000P0000000`20P800oooo0?ooo`030?ooo`<000001P3oool3000000H0oooo0`00001U
0?ooo`030410@0000000@41000H0oooo00@0@410000000000000`<302@3oool3000000L0oooo0`00
00060?ooo`<000001@3oool3000000030410@020P800oooo0080oooo00<0`<300000000000000P00
00040?ooo`040<30`000000000000410@0L0oooo00<0P82000000020P800203oool00`10@4000000
0410@0060?ooo`030410@0000000@4100240oooo0P0000000`20P800oooo0?ooo`040?ooo`<00000
1P3oool3000000D0oooo00<0P8200000000000000P0000001`30`<00oooo0?ooo`3oool0P8200000
0020P800103oool01020P800000000000020P8060?ooo`80000000<0P8200?ooo`3oool0103oool3
000000H0oooo0`0000060?ooo`030820P0000000000000D0oooo00@0P820000000000000P8201P3o
ool01@20P8000000000000000000P8200080oooo00<0`<300820P00000000P0000000`20P800oooo
0<30`0030?ooo`<000001P3oool3000000D0oooo100000001`20P800oooo0?ooo`3oool0`<300820
P010@400S`3ooolCooooo`004Ooooolf0?ooo`@0000000<0P8200?ooo`3oool0103oool01020P800
00000?ooo`3oool3000000H0oooo0`0000060?ooo`<00000403oool4000000L0oooo0P0000000`20
P800oooo0?ooo`030?ooo`<00000203oool00`20P8000000000000060?ooo`040820P00000000000
0820P0D0oooo0`0000060?ooo`<000001P3oool3000006D0oooo0`0000060?ooo`<0000000<0P820
0?ooo`3oool01`3oool3000000L0oooo0`0000060?ooo`<00000103oool4000000L0oooo0`000004
0?ooo`040820P000000000000820P0P0oooo0P0000080?ooo`<000001P3oool300000240oooo0P00
00000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000D0oooo100000070?ooo`0300000020
P800oooo0080oooo00@0P820000000000000P8201P3oool2000000030820P03oool0oooo00@0oooo
0`0000060?ooo`<000001`3oool00`20P8000000000000040?ooo`040820P000000000000820P0H0
oooo00<0P8200000000000001P3oool01020P800000000000020P8050?ooo`<000001P3oool30000
00@0oooo100000000`20P800oooo0?ooo`040?ooo`030820P0000000oooo08d0oooo4oooool0017o
oooo=P3oool4000000P0oooo00<000000?ooo`3oool00`0000060?ooo`<000001P3oool300000100
oooo100000070?ooo`80000000<0P8200?ooo`3oool00`3oool3000000P0oooo00<0P82000000000
00001P3oool01020P800000000000020P8050?ooo`<000001P3oool3000000H0oooo0`00001U0?oo
o`80000000<0P8200000003oool0103oool3000000030820P03oool0oooo00L0oooo0`0000070?oo
o`<000001P3oool3000000@0oooo100000070?ooo`<00000103oool3000000T0oooo00<0P8200000
0020P8001`3oool2000000030820P0000000oooo00@0oooo0P0000000`20P80000000?ooo`0O0?oo
o`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000050?ooo`<000002@3oool01@20
P800oooo0?ooo`3oool0P8200080000000<0P8200?ooo`3oool0103oool2000000030820P03oool0
oooo00@0oooo0`0000060?ooo`<000001`3oool01020P800000000000020P8030?ooo`040820P000
000000000820P0H0oooo00<0P8200000000000001P3oool01020P800000000000020P8050?ooo`<0
00001P3oool3000000@0oooo100000080?ooo`030000003oool0oooo08`0oooo4oooool0017ooooo
=@3oool01030`<00000000000000000:0?ooo`030<30`03oool0@410008000001P3oool3000000H0
oooo0`00000?0?ooo`040820P00000000000000000P0oooo0P0000000`20P800oooo0?ooo`030?oo
o`<00000203oool00`20P8000000000000060?ooo`040820P000000000000820P0D0oooo0`000006
0?ooo`<000001P3oool3000006@0oooo0`0000000`30`<0000000?ooo`030?ooo`<0000000<0oooo
0820P03oool0203oool3000000L0oooo0`0000060?ooo`<000000`3oool01020P800000000000000
00080?ooo`<000000`3oool01020P80000000000000000090?ooo`030820P0000000@41000H0oooo
0`0000000`30`<0000000?ooo`030?ooo`<0000000<0oooo0000003oool07`3oool2000000030820
P03oool0oooo00@0oooo0`0000060?ooo`<00000103oool01020P800000000000020P8090?ooo`05
0<30`03oool0oooo0?ooo`20P8000P0000000`20P800oooo0?ooo`040?ooo`80000000<0P8200?oo
o`3oool0103oool3000000H0oooo0`0000080?ooo`80000000D0P8200?ooo`3oool0oooo0820P002
000000030820P03oool0oooo00@0oooo00<0`<300000000000001P3oool01020P800000000000020
P8050?ooo`<000001P3oool3000000<0oooo00@0`<3000000000000000002P3oool00`30`<00oooo
0?ooo`2;0?oooa?ooooo000AooooocD0oooo00@0P82000000000000000003@3oool2000000030820
P03oool0oooo00<0oooo0`0000060?ooo`<000003`3oool00`20P8000000000000090?ooo`800000
00<0P8200?ooo`3oool00`3oool3000000P0oooo00<0P8200000000000001P3oool01020P8000000
00000020P8050?ooo`<000001P3oool3000000H0oooo0`00001T0?ooo`<000000P3oool010000000
oooo0?ooo`20P80300000080oooo00<000000?ooo`3oool01P3oool3000000L0oooo0`0000060?oo
o`<000000`3oool01020P800000000000020P8080?ooo`<000000`3oool3000000X0oooo00<0P820
0000000000001P3oool300000080oooo00@0P8200?ooo`3oool0P8200`0000020?ooo`030000003o
ool0oooo01d0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000@0oooo0`00
00000`20P800oooo0?ooo`0;0?ooo`040820P000000000000820P0H0oooo0P0000000`20P800oooo
0?ooo`040?ooo`<000001P3oool3000000P0oooo0`0000030?ooo`040820P000000000000820P0P0
oooo0P0000050?ooo`040820P000000000000820P0D0oooo0`0000060?ooo`<000000`3oool01020
P800000000000000002H0?oooa?ooooo000AooooocD0oooo00<0P8200000000000003`3oool00`20
P80000000820P0040?ooo`<000001P3oool3000000l0oooo00<0P8200000000000002@3oool20000
00030820P03oool0oooo00<0oooo0`0000080?ooo`030820P0000000000000H0oooo00@0P8200000
00000000P8201@3oool3000000H0oooo0`0000060?ooo`<00000H`3oool3000000070820P03oool0
oooo0820P030`<00oooo0820P002000000<0oooo00<0P8200<30`03oool01P3oool3000000L0oooo
0`0000060?ooo`<000000`3oool01020P800000000000020P8080?ooo`<000000`3oool3000000X0
oooo00<0P8200000000000001@3oool3000000040820P03oool0oooo0820P080oooo00<0P8200000
000000000`3oool00`20P800`<300?ooo`0M0?ooo`80000000<0P8200?ooo`3oool0103oool30000
00H0oooo0`0000040?ooo`<000003P3oool01020P800000000000020P8060?ooo`80000000<0P820
0?ooo`3oool0103oool3000000H0oooo0`0000080?ooo`<000000`3oool01020P800000000000020
P8080?ooo`040<30`000000000000<30`0<0oooo00@0P820000000000000P8201@3oool3000000H0
oooo0`0000030?ooo`040820P000000000000820P9P0oooo4oooool0017ooooo=@3oool00`20P800
00000000000B0?ooo`040000003oool0oooo0?ooo`<000001P3oool3000000l0oooo00<0P8200000
000000002@3oool2000000030820P03oool0oooo00<0oooo0`0000080?ooo`030820P00000000000
00H0oooo00@0P820000000000000P8201@3oool3000000H0oooo0`0000060?ooo`<00000H`3oool3
000000@0oooo00<0P8200?ooo`0000000P0000040?ooo`030820P03oool0oooo00D0oooo0`000007
0?ooo`<000001P3oool3000000<0oooo00@0P820000000000000P820203oool3000000<0oooo0`00
000:0?ooo`030820P0000000000000D0oooo0`0000030?ooo`030820P03oool0oooo00<00000103o
ool00`20P800oooo0?ooo`0L0?ooo`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`00
00040?ooo`<000003P3oool01020P800000000000020P8060?ooo`80000000<0P8200?ooo`3oool0
103oool3000000H0oooo0`0000080?ooo`<000000`3oool01020P800000000000020P80;0?ooo`05
0820P0000000oooo0?ooo`20P8000P0000000`20P800oooo0?ooo`030?ooo`<000001P3oool30000
00<0oooo00@0P820000000000000P820V03ooolCooooo`004Ooooole0?ooo`030820P00000000000
01<0oooo0P0000001020P80000000000000000060?ooo`<000003`3oool00`20P800000000000009
0?ooo`80000000<0P8200?ooo`3oool00`3oool3000000P0oooo00<0P8200000000000001P3oool0
1020P800000000000020P8050?ooo`<000001P3oool3000000H0oooo0`00001R0?ooo`040820P000
000000000820P0@0oooo00D0P8200?ooo`00000000000820P0040?ooo`030820P03oool0oooo00D0
oooo0`0000070?ooo`<000001P3oool3000000<0oooo00@0P820000000000000P820203oool30000
00<0oooo0`00000:0?ooo`030820P0000000000000@0oooo00@0P820000000000000P8200`3oool0
0`20P800oooo0?ooo`02000000030820P03oool0oooo0080oooo00<0P8200?ooo`3oool0703oool2
000000030820P03oool0oooo00@0oooo0`0000060?ooo`<00000103oool3000000h0oooo00@0P820
000000000000P8201P3oool2000000030820P03oool0oooo00@0oooo0`0000060?ooo`<00000203o
ool3000000<0oooo00@0P820000000000000P8203@3oool2000000040820P000000000000820P0D0
oooo0`0000060?ooo`<000000`3oool01020P800000000000020P82H0?oooa?ooooo000AooooocD0
oooo00<0`<300000000000002020P803000000X0oooo00@0`<3000000000000000001P3oool30000
0100oooo0P0000090?ooo`80000000<0P8200?ooo`3oool00`3oool3000000P0oooo00<0P8200000
000000001P3oool01020P800000000000020P8050?ooo`<000001P3oool3000000H0oooo0`00001R
0?ooo`040820P000000000000820P0@0oooo0P20P802000000030<30`03oool0oooo0080oooo00<0
P8200?ooo`3oool01@3oool3000000L0oooo0`0000060?ooo`<00000103oool2000000030820P03o
ool0oooo00H0oooo0`0000030?ooo`030820P0000000000000X0oooo0P0000000`10@400oooo0?oo
o`020?ooo`040820P000000000000820P0@0oooo00D000000820P000000000000<30`0040?ooo`03
0820P03oool0oooo01`0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000@0
oooo00<0P8200000000000001`20P8001010@400000000000020P8030?ooo`040820P00000000000
0820P0H0oooo0P0000000`20P800oooo0?ooo`040?ooo`<000001P3oool3000000L0oooo00@0P820
00000000000000000`3oool01020P800000000000020P80?0?ooo`040410@000000000000820P0D0
oooo0`0000060?ooo`<000000`3oool01030`<00000000000010@4070820P0<00000SP3ooolCoooo
o`004Ooooolf0?ooo`800000203oool3000000<0oooo0P0000060?ooo`<000001P3oool300000100
oooo0P0000090?ooo`80000000<0P8200?ooo`3oool00`3oool3000000P0oooo00<0P82000000000
00001P3oool01020P800000000000020P8050?ooo`<000001P3oool3000000H0oooo0`00001R0?oo
o`<000001P3oool3000000H0oooo00<000000?ooo`3oool0103oool3000000L0oooo0`0000060?oo
o`<00000103oool2000000030820P03oool0oooo00H0oooo0`0000040?ooo`8000002P3oool20000
00030820P03oool0oooo0080oooo0`0000060?ooo`<000001P3oool00`000000oooo0?ooo`0K0?oo
o`80000000<0P8200?ooo`3oool0103oool3000000H0oooo0`0000050?ooo`8000001`3oool01020
P800000000000020P8030?ooo`040820P000000000000820P0H0oooo0P0000000`20P800oooo0?oo
o`040?ooo`<000001P3oool3000000L0oooo00@0P820000000000000P8200`3oool01020P8000000
00000020P8080?ooo`030000003oool0oooo00@0oooo00@0P820000000000000P8201@3oool30000
00H0oooo0`0000040?ooo`80000000<0P8200?ooo`3oool01@3oool3000008h0oooo4oooool0017o
oooo=`3oool2000000H0oooo00<0P8200000000000000`3oool01020P800000000000020P8050?oo
o`<000001P3oool3000000030820P03oool0oooo00h0oooo00<0@4100000003oool01`3oool20000
00030820P03oool0oooo00<0oooo0`0000000`20P800oooo0?ooo`050?ooo`030820P00000000000
00H0oooo00@0P820000000000000P8201@3oool3000000030<30`03oool0oooo0080oooo00<0`<30
0000000000000P20P8001@30`<00oooo0?ooo`3oool0`<3000<00000H@3oool01020P80000000000
000000050?ooo`040<30`000000000000820P0H0oooo00<000000<30`03oool0103oool3000000L0
oooo0`0000000`20P800oooo0?ooo`020?ooo`040<30`00000000000000000D0oooo00<0P8200000
003oool01`3oool3000000@0oooo00<0P820000000000000203oool3000000050<30`03oool0oooo
0?ooo`20P8000`0000050?ooo`040820P000000000000820P0H0oooo00<000000<30`03oool06`3o
ool2000000030410@03oool0oooo00<0oooo00<0P8200000000000000P20P8040?ooo`040820P000
00000000000000D0oooo00<0P82000000020P8001P3oool00`10@4000000000000040?ooo`040820
P000000000000410@0D0oooo00<0P8200000000000000P20P8040?ooo`040820P000000000000000
00H0oooo0`0000000`30`<00oooo0?ooo`030?ooo`050820P0000000000000000020P8000`3oool0
1020P800000000000010@4070?ooo`<000001@3oool01020P800000000000020P8050?ooo`<00000
00<0P8200?ooo`3oool00P3oool01030`<0000000000000000050?ooo`8000001P3oool00`30`<00
00000000002?0?oooa?ooooo000AooooocL0oooo00<0P820000000000000103oool01020P8000000
00000020P8030?ooo`040820P000000000000820P0D0oooo0P0000060?ooo`030820P00000000000
008000000`3oool2000000/0oooo00<0P8200000000000001P3oool3000000030820P03oool0oooo
0080oooo00<0P8200000000000000P0000030?ooo`8000000P3oool00`20P8000000000000060?oo
o`040820P000000000000820P0D0oooo0`0000000`20P80000000?ooo`020?ooo`<000000P3oool0
10000000oooo0?ooo`3oool3000000030820P03oool0oooo05l0oooo0`0000060?ooo`030820P000
0000000000P0oooo00<0P8200?ooo`3oool00`3oool3000000L0oooo0`0000000`20P80000000?oo
o`020?ooo`<0000000<0P8200?ooo`3oool0103oool2000000H0oooo100000050?ooo`80000000<0
P8200?ooo`3oool0103oool00`20P8000000000000050?ooo`<000001P3oool3000000P0oooo00<0
P8200?ooo`3oool06P3oool2000000030820P0000000P8200080oooo00L0P8200000000000000000
0?ooo`20P80000000080oooo00@0P82000000000000000001`3oool2000000D0oooo0`0000050?oo
o`060820P000000000000820P0000000P8200P3oool4000000030?ooo`00000000000080oooo00@0
P82000000000000000001`3oool5000000<0oooo00<0P8200000000000000P0000040?ooo`@00000
103oool00`000000oooo0?ooo`03000000D0oooo00<0P8200000000000001P3oool3000000030820
P0000000oooo0080oooo0`0000070?ooo`8000001@3oool2000000030820P03oool0oooo08d0oooo
4oooool0017ooooo>03oool00`20P8000000000000030820P080000000<0P8200<30`03oool00`3o
ool00`20P80000000410@0040?ooo`030410@0000000@41000D0oooo00<0P8200410@00000000P00
00000`3oool0@4100820P003000000030820P03oool0oooo00T0oooo0P20P8000`10@400oooo0?oo
o`020?ooo`050410@0000000000000000020P8000`3oool00`20P800@41000000002000000030?oo
o`10@400P82000<0000000<0P8200?ooo`10@4000P0000060?ooo`040410@000000000000820P0<0
oooo00<0P8200000000000000P0000000`3oool0P82000000004000000040410@03oool0oooo0<30
`0H0000000<0`<300?ooo`3oool0GP3oool01@30`<000000000000000000P82000D0oooo0`000000
0`20P800oooo0?ooo`040?ooo`030820P010@400oooo0080oooo00<0P8200410@00000000P000005
0?ooo`030820P010@40000000080000000<0oooo0820P00000001@0000000`30`<00oooo0?ooo`04
0?ooo`030<30`020P800@41000@0oooo00<0@4100000000000000P0000060?ooo`030820P0000000
P82000<0oooo0P20P8000`000000P8200<30`0040?ooo`050<30`0000000000000000020P800103o
ool01@20P8000000000000000000P82000H0oooo00<0P8200410@03oool0603oool00`30`<00P820
00000002000000030820P03oool0@41000D0000000@0P8200?ooo`3oool0P8201@0000000`10@400
oooo0?ooo`060?ooo`030410@000000000000080P82000@0@41000000010@400P8200`3oool00`30
`<00P82000000002000000030820P03oool0@41000D0000000@0P8200?ooo`3oool0P8201@000000
0`20P800oooo0?ooo`050?ooo`<0000000<0`<300000000000001@0000001P20P800oooo0?ooo`3o
ool0`<300820P0<000000P20P8000`10@40000000000000200000080oooo00<0@41000000020P800
0`3oool01020P800000000000020P8040?ooo`030820P010@40000000080000000<0oooo0820P000
0000100000000`10@400oooo0?ooo`050?ooo`030<30`0000000000000<0P8200P0000000`20P800
`<300?ooo`2>0?oooa?ooooo000AooooocX0oooo00D0P82000000000000000000820P00:0?ooo`D0
00002P3oool00`20P80000000?ooo`020?ooo`<000003`3oool4000000050820P03oool000000000
0020P8001P3oool00`20P80000000?ooo`020?ooo`<0000000<0P8200000000000000P0000040?oo
o`030820P000000000000080000000<0P8200?ooo`3oool0103oool00`20P80000000?ooo`020?oo
o`040820P00000000000000000D0oooo00@0P8200000000000000000HP3oool600000080oooo1`00
00040?ooo`040820P00000000000000000H0oooo00<000000?ooo`3oool01P3oool00`20P8000000
0?ooo`020?ooo`040820P00000000000000000/0oooo100000000`20P800oooo00000002000000T0
oooo1@0000070?ooo`H000000P3oool7000000@0oooo00@0P8200000000000000000703oool00`00
0000P8200?ooo`020?ooo`<0000000<0P8200?ooo`3oool00`3oool4000000/0oooo1000000:0?oo
o`0300000020P800oooo0080oooo0`0000000`20P800oooo0?ooo`030?ooo`<0000000<0P8200?oo
o`3oool01P3oool3000000<0oooo100000090?ooo`0400000020P800oooo0?ooo`<000001P3oool4
000000030820P03oool0oooo00L0oooo00<0P8200000003oool00P3oool01020P800000000000000
000:0?ooo`030820P0000000000000800000TP3ooolCooooo`004Ooooome0?ooo`80000000<0P820
0?ooo`3oool0e@3oool3000008d0oooo0`00003E0?oooa?ooooo000AooooogD0oooo0P0000000`20
P800oooo0?ooo`3E0?ooo`<00000S@3oool300000=D0oooo4oooool0017oooooM@3oool200000003
0820P03oool0oooo0=D0oooo0`00002=0?ooo`<00000e@3ooolCooooo`004Ooooome0?ooo`800000
00<0P8200?ooo`3oool0e@3oool3000008d0oooo0`00003E0?oooa?ooooo000AooooogD0oooo0P00
00000`20P800oooo0?ooo`3E0?ooo`<00000S@3oool300000=D0oooo4oooool0017oooooL`3oool2
0820P080000000<0P8200?ooo`3oool0/03oool00`20P80000000410@00P0?ooo`80P8200`00002;
0?ooo`80P8200`00003E0?oooa?ooooo000Aooooog@0oooo0`0000000`20P800oooo0?ooo`2`0?oo
o`<000008@3oool4000008`0oooo1000003E0?oooa?ooooo000AooooogH0oooo00<000000820P03o
ool0/P3oool00`000000P8200?ooo`0R0?ooo`800000SP3oool00`20P80000000?ooo`3D0?oooa?o
oooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000A
ooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0
ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3o
ooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oo
oa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo000Aooooool0ooooo`3oooni0?oooa?ooooo
000Aooooool0oooo5@3oool00`20P800000000000002000000030820P03oool0oooo00/0oooo00<0
P8200?ooo`3oool02P3oool3000000030820P03oool0oooo0080oooo00<0P8200000000000000P3o
ool00`20P800000000000004000000030820P03oool0oooo04l0oooo0`0000080?ooo`@0000000<0
P8200?ooo`3oool02@3oool4000000X0oooo0`0000090?ooo`D000001`3oool7000000D0oooo1`00
00050?ooo`<000001@3oool2000000<0oooo1`00002`0?oooa?ooooo000Aooooool0oooo4P3oool0
1@30`<00P82000000010@400P82000<0oooo00<0`<3000000020P8002`3oool00`10@400P8200?oo
o`090?ooo`030410@0000000000000<0000000<0P8200?ooo`20P800100000001020P800oooo0?oo
o`10@402000000030410@03oool0oooo0500oooo00<0P8200000000000000P0000001@20P800oooo
0?ooo`3oool0`<3000P0000000<0P8200?ooo`3oool01@3oool00`10@40000000000000400000003
0410@03oool0oooo00D0oooo1@0000000`20P800oooo0?ooo`020?ooo`040820P010@40000000820
P0@0oooo00<0@4100820P030`<001@3oool01@20P8000000000000000000`<3000L0oooo00D0P820
00000000000000000<30`0040?ooo`030820P0000000000000@0000000<0`<300?ooo`10@4001000
00000`30`<00oooo0<30`003000000030820P03oool0oooo0:l0oooo4oooool0017oooooo`3ooolB
0?ooo`<000001`3oool2000000X0oooo0P0000090?ooo`@000000`3oool500000080oooo00@00000
0?ooo`3oool0P8200P0000000`20P800oooo0?ooo`1@0?ooo`<000000P3oool010000000oooo0?oo
o`3oool5000000<0oooo0P0000000`20P800oooo0?ooo`020?ooo`D00000103oool2000000D0oooo
00@0P82000000000000000000P3oool010000000oooo0?ooo`3oool3000000L0oooo0P0000060?oo
o`<000002@3oool3000000@0oooo00<0P8200000000000000P0000030?ooo`@0000000@0P8200?oo
o`3oool0P8200P3oool300000;80oooo4oooool0017oooooo`3ooolA0?ooo`<00000203oool00`20
P80000000820P0080?ooo`040820P000000000000820P0P0oooo0`0000000`30`<00oooo0?ooo`02
0?ooo`040<30`00000000000000000D0oooo00@0P820000000000000P820DP3oool2000000070820
P03oool0oooo0?ooo`20P800oooo0820P003000000030410@03oool0oooo00@0oooo00D0@4100820
P03oool0oooo0<30`004000000030<30`03oool0oooo00<0oooo00<0P8200410@03oool00`3oool0
0`20P8000000000000040?ooo`030<30`03oool0P8200080000000<0P8200?ooo`3oool01P3oool2
000000D0oooo0`0000090?ooo`<00000103oool01020P800000000000010@4050?ooo`040820P000
000000000820P0D0oooo0`00002b0?oooa?ooooo000Aooooool0oooo403oool00`20P80000000000
000:0?ooo`800000203oool3000000030820P03oool0oooo00H0oooo0`0000060?ooo`<000001@3o
ool01020P800000000000020P81B0?ooo`80000000<0P8200?ooo`3oool00`3oool4000000P0oooo
00@000000?ooo`3oool0P8200`0000080?ooo`030820P03oool0oooo0080oooo00<0P82000000000
00001P3oool3000000T0oooo00<0P820000000000000103oool3000000T0oooo0`0000040?ooo`04
0820P000000000000820P0H0oooo0P0000000`20P800oooo0?ooo`030?ooo`<00000/P3ooolCoooo
o`004Ooooooo0?oooa00oooo00<0@4100000000000002P3oool2000000030820P03oool0oooo00@0
oooo00<0P8200000000000000P20P8080?ooo`030820P0000000000000H0oooo0`0000050?ooo`04
0820P000000000000820P580oooo0P0000000`20P800oooo0?ooo`020?ooo`040<30`00000000000
000000X0oooo00<0`<300?ooo`0000000P0000000`20P800oooo0?ooo`070?ooo`050820P03oool0
oooo0?ooo`20P8000P0000050?ooo`040820P00000000000000000T0oooo00@0P820000000000000
`<300`3oool3000000T0oooo0`0000040?ooo`040<30`000000000000820P0H0oooo0P0000000`20
P800oooo0?ooo`030?ooo`<00000/P3ooolCooooo`004Ooooooo0?oooa00oooo0P0000000`20P800
oooo0?ooo`080?ooo`<000001P3oool300000080oooo00<000000?ooo`3oool01P3oool00`20P800
00000820P0050?ooo`<000001@3oool01020P800000000000020P81B0?ooo`80000000<0P8200?oo
o`3oool00P3oool01020P800000000000000000<0?ooo`<000003P3oool00`20P800000000000005
0?ooo`<000002P3oool01020P800000000000020P8030?ooo`<000002@3oool3000000H0oooo0P00
00060?ooo`80000000<0P8200?ooo`3oool00`3oool300000;80oooo4oooool0017oooooo`3oool@
0?ooo`80000000<0P8200?ooo`3oool0203oool3000000D0oooo00@0P82000000000000000000P3o
ool00`000000oooo0?ooo`070?ooo`8000001@3oool3000000D0oooo00@0P820000000000000P820
DP3oool2000000030820P03oool0oooo0080oooo00<0P8200000000000003@3oool3000000h0oooo
00<0P8200000000000001@3oool3000000X0oooo00@0P820000000000000P8200`3oool3000000T0
oooo0`0000070?ooo`8000001@3oool2000000030820P03oool0oooo00<0oooo0`00002b0?oooa?o
oooo000Aooooool0oooo403oool2000000030820P03oool0oooo00P0oooo0`0000050?ooo`040820
P000000000000820P0<0oooo00<000000?ooo`3oool01`3oool30820P0<0oooo0`0000050?ooo`04
0820P000000000000820P580oooo0P0000000`20P800oooo0?ooo`020?ooo`030820P00000000000
00d0oooo0`00000>0?ooo`030820P0000000000000D0oooo0`00000:0?ooo`040820P00000000000
0820P0<0oooo0`0000090?ooo`<000001`3oool01030`<00P8200820P020P8030?ooo`80000000<0
P8200?ooo`3oool00`3oool300000;80oooo4oooool0017oooooo`3oool@0?ooo`80000000<0P820
0?ooo`3oool0203oool3000000D0oooo0`0000050?ooo`030820P03oool0oooo00T0oooo0P000000
1020P80000000000000000050?ooo`040820P000000000000820P580oooo0P0000000`20P800oooo
0?ooo`020?ooo`030820P0000000000000d0oooo0`00000>0?ooo`030820P0000000000000D0oooo
0`00000:0?ooo`040820P000000000000820P0<0oooo0`0000090?ooo`<000002`3oool200000004
0?ooo`00000000000820P0D0oooo0`00002b0?oooa?ooooo000Aooooool0oooo403oool00`10@400
00000820P0090?ooo`040820P000000000000820P0@0oooo00@0P82000000000000000001@3oool0
0`20P800oooo0?ooo`0;0?ooo`040<30`00000000000000000D0oooo00@0P820000000000000P820
DP3oool2000000030820P03oool0oooo0080oooo00<0`<300000000000002020P80300000080oooo
00<0P8200000000000003P3oool00`20P8000000000000050?ooo`030820P0000000000000X0oooo
0`0000001030`<00oooo0?ooo`3oool3000000T0oooo0`00000=0?ooo`040820P000000000000820
P0D0oooo0`00002b0?oooa?ooooo000Aooooool0oooo403oool00`20P80000000820P0090?ooo`03
0820P0000000000000D0oooo0`0000060?ooo`030820P03oool0oooo00@0oooo00<0P8200000003o
ool01@3oool3000000D0oooo00@0P820000000000000P820DP3oool2000000030820P03oool0oooo
00<0oooo0P0000080?ooo`<000000P3oool00`20P8000000000000070?ooo`030820P0000000P820
00@0oooo00<0P8200000000000001P3oool2000000X0oooo0`0000040?ooo`<000002@3oool30000
00H0oooo00<000000820P03oool01@3oool2000000030820P03oool0oooo00<0oooo0`00002b0?oo
oa?ooooo000Aooooool0oooo4@3oool2000000T0oooo0P0000000`10@400oooo0?ooo`020?ooo`04
0<30`00000000000000000H0oooo00<0`<300820P03oool0103oool2000000030820P03oool0oooo
00<0oooo0`0000050?ooo`040820P000000000000820P580oooo0P0000000`20P800oooo0?ooo`04
0?ooo`8000001P3oool00`20P8000000000000040?ooo`030820P0000000P82000H0oooo00<0@410
000000000000103oool00`20P8000000000000060?ooo`030820P0000000000000P0oooo0`000000
0`20P800oooo0?ooo`020?ooo`<0000000<0`<300?ooo`3oool01P3oool3000000D0oooo0`000006
0?ooo`80000000<0P8200?ooo`3oool00`3oool300000;80oooo4oooool0017oooooo`3ooolB0?oo
o`8000001`3oool3000000D0oooo00<0P820000000000000203oool00`000000oooo0?ooo`030?oo
o`80000000<0P8200?ooo`3oool00`3oool2000000H0oooo00@0P820000000000000P820DP3oool2
000000030820P03oool0oooo00@0oooo00<0P820000000000000103oool01020P800000000000020
P8050?ooo`8000001P3oool3000000@0oooo00<0P8200000000000001`3oool2000000030820P03o
ool0oooo00@0oooo00<0P8200000000000001@3oool4000000060820P03oool0oooo0?ooo`000000
P8200`3oool3000000D0oooo0`0000060?ooo`8000001P3oool300000;80oooo4oooool0017ooooo
o`3ooolB0?ooo`030820P0000000000000D0oooo00<0P8200000000000001P3oool3000000P0oooo
00<000000820P03oool00`3oool00`20P80000000820P0040?ooo`030820P0000000000000H0oooo
00@0P820000000000000P820DP3oool2000000030820P03oool0oooo00D0oooo0`0000030?ooo`<0
000000<0P8200?ooo`3oool0103oool2000000D0oooo0P0000000`20P800oooo0?ooo`020?ooo`03
0820P0000000000000P0oooo0P0000060?ooo`80000000<0P8200?ooo`3oool00P3oool500000003
0820P0000000P82000<0000000<0oooo0000000000000`0000060?ooo`8000001@3oool3000000H0
oooo0`00002b0?oooa?ooooo000Aooooool0oooo4`3oool60820P00300000010@400P82000D0oooo
00<0`<300000000000000P0000020820P0D0oooo00@0P82000000010@400P820103oool60820P003
00000020P800`<3000H0oooo00@0P820000000000000P820C`3oool00`30`<00P8200820P0020000
00040410@020P800P8200820P0D0oooo00<0P8200410@00000000P0000000`10@400P8200?ooo`08
0?ooo`D0P82000<000000410@020P8000`3oool00`30`<00P8200410@002000000@0P8201@3oool5
0820P0030410@0000000P82000L0oooo0P20P802000000030?ooo`20P800@4100080000000<0@410
0?ooo`3oool00P20P802000000L0oooo1@20P8000`10@40000000820P0070?ooo`<00000/P3ooolC
ooooo`004Ooooooo0?oood@0oooo00@0P820000000000000P820D@3oool3000000030820P03oool0
oooo02<0oooo0`00000n0?ooo`<00000/P3ooolCooooo`004Ooooooo0?oood@0oooo00@0P8200000
00000000P820DP3oool00`10@40000000820P00U0?ooo`030<30`0000000000003h0oooo0`00002b
0?oooa?ooooo000Aooooool0ooooA03oool01020P800000000000020P81C0?ooo`0300000020P800
oooo02H0oooo00<000000?ooo`3oool0?03oool300000;80oooo4oooool0017oooooo`3ooom40?oo
o`040820P000000000000820P5<0oooo00<000000820P03oool09P3oool00`000000oooo0?ooo`0l
0?ooo`<00000/P3ooolCooooo`004Ooooooo0?oood@0oooo00@0P820000000000000P820E03oool0
0`30`<00oooo0?ooo`0U0?ooo`030<30`03oool0oooo03`0oooo0`00002b0?oooa?ooooo000Aoooo
ool0ooooA03oool01020P800000000000020P82R0?ooo`030820P0000000oooo01H0oooo0`00002b
0?oooa?ooooo000Aooooool0oooo@P3oool00`30`<00P82000000002000000030820P03oool0oooo
0:00oooo0`00000D0?ooo`030820P010@400000000800000/P3ooolCooooo`004Ooooooo0?ooodH0
oooo00<000000820P03oool0X@3oool00`20P80000000?ooo`0G0?ooo`030820P0000000oooo0;40
oooo4oooool0017oooooo`3ooooo0?oookT0oooo4oooool0017oooooo`3ooooo0?oookT0oooo4ooo
ool00?oooooooooooooMooooo`00ooooooooooooomgooooo003ooooooooooooogOooool00?oooooo
oooooooMooooo`00ooooooooooooomgooooo003ooooooooooooogOooool00?oooooooooooooMoooo
o`00ooooooooooooomgooooo003ooooooooooooogOooool00?oooooooooooooMooooo`00oooooooo
ooooomgooooo0000\
\>"],
  ImageRangeCache->{{{0, 304.188}, {205.188, 0}} -> {-25.0898, -16.6785, \
4.26613, 4.26613}},
  CellTags->{"Fig. 2.2", "i:32"}],

Cell["\<\
Fig. 2.2 Simplified diagram of the middle and  inner ear (not to \
scale).\
\>", "Caption",
  CellTags->"Fig. 2.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 2.1", "Subsubtitle",
  CellTags->"c:12"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Prove that for a periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " of period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", the following is true: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%T\( f(
              t)\) \[DifferentialD]t = \[Integral]\_x\%\(T + x\)\(f(
              t)\) \(\(\[DifferentialD]t\)\(\ \)\)\)]],
  " for any ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Do the following periodic functions meet the conditions of Theorem 2.1? "
}], "Text"],

Cell[TextData[{
  "\t(i) ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \(\(|\)\(t\)\( | \^3\)\(\ \ \)\(on\  - 1/2 < t < 1/2\)\); 
      f(t) = f(t + 1)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(ii)",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = 3  x\ \ on\ 0 < x < 2; \ f(x) = f(x + 2)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(iii) ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = exp(\(-t\))\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(\(f(t + 3)\)\(\ \)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the  Fourier series coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_n\)]],
  " for the periodic functions of part (a). "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Plot the resulting series  for different numbers of coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`1 < M < 10\)]],
  ", and observe the convergence. Compare with the exact functions. Are the \
series converging?"
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Plot the difference between the series and the actual functions as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases, and determine using Eq. ",
  ButtonBox["(2.1.15)",
    ButtonData:>"(2.1.15)",
    ButtonStyle->"Hyperlink"],
  " whether the series are exhibiting uniform convergence."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " For the series of function (ii), evaluate the derivative of the series \
with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", term by term.  Compare it with the derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`3  x\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 2\)]],
  "  by plotting the result for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`M = 50\)]],
  ". Does the derivative of the series give a good representation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\^\[Prime]\)(x)\)\(\ \)\)\)]],
  "?"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)(a)",
    FontWeight->"Bold"],
  " Theorem 2.1 provides sufficient conditions for convergence of a Fourier \
series. There conditions are not necessary, however. Functions that have \
singularities or singular derivatives can sometimes also have well-behaved \
convergent Fourier series. For example, use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to evaluate the Fourier sine-cosine series of the periodic function"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(x) = \(\@x\) \((1 - x)\)\)]],
  "  on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ x\  \[LessEqual] \ \ 1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(x + 1) = f(x)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "and plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 4, 8, 12, 16, 20\)]],
  ". Does this  series appear to be converging to ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " increases?\n",
  StyleBox["[Hint: Don't be afraid of any special functions that ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" might spit out when evaluating  Fourier coefficients. You don't \
need to know what they are (although you can look up their definitions in the \
",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" book if you want). Just use them in the series, stand back, and \
let ",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["Mathematica",
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" plot out the result.]",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "At what value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is the maximum error in the series occurring? Evaluate this maximum error \
for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10, 30, 60, 90\)]],
  ". According to Eq. ",
  ButtonBox["(2.1.15)",
    ButtonData:>"(2.1.15)",
    ButtonStyle->"Hyperlink"],
  ", is this series converging uniformly?"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Repeat Exercise (2)(b) and (c) using exponential Fourier series."
}], "Text"],

Cell[TextData[{
  StyleBox["(5) ",
    FontWeight->"Bold"],
  "A damped harmonic oscillator satisfies the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + x\^\[Prime] + 4  x = f(t)\)]],
  ". The forcing function is given by  ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = t\^2, \ \(-1\) \[LessEqual] \ 
        t \[LessEqual] \ 1; \ f(t + 2) = f(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Find a particular solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  " to the forcing in terms of an exponential Fourier series."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  Find a homogeneous solution to add to your particular solution from part \
a) so as to satisfy the ODE with initial conditions  ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 1, \(x\^\[Prime]\)(0) = 0\)]],
  ". Plot the solution for 0<t<20."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " An undamped harmonic oscillator satisfies the equation ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + \ x = f(t)\)]],
  ". The forcing function is a square wave of period 1/2: ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 1, \ 0 < t < 1/4; \ f(t) = 0, \ 
      1/4 < t < 1/2; \ f(t + 1/2)\  = f(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Find a particular solution to this problem. (Be careful - there is an \
exact resonance!)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  "Find a homogeneous solution to add to the particular solution so as to \
satisfy the ODE with initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 0, \(x\^\[Prime]\)(0) = 0\)]],
  ". Plot the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " An ",
  StyleBox["RC",
    FontSlant->"Italic"],
  " circuit (a resistor and capacitor in series) is driven by a periodic \
sawtooth voltage, with period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", of the form ",
  Cell[BoxData[
      \(TraditionalForm\`V(t) = V\_0\ Mod[t/T, 1]\)]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`V(t)\)]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T = 0.002\), ",", " ", 
          RowBox[{
            FormBox[\(V\_0\),
              "TraditionalForm"], "=", "1"}]}], TraditionalForm]]],
  " over a time range ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t < 4  T\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " The charge ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " on the capacitor satisfies the ODE ",
  Cell[BoxData[
      \(TraditionalForm\`R\ Q\^\[Prime] + Q/C\  = \ V(t)\)]],
  ". Find a particular solution for ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " (in the form of an  exponential Fourier series) . Add a homogeneous \
solution to match the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`Q(0)\  = \ 0\)]],
  ".  Plot ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 5, 10, 20\)]],
  " for the case ",
  Cell[BoxData[
      \(TraditionalForm\`R = 500\ \[CapitalOmega]\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(C = 2\ \[Mu]F\)\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(V\_0\),
              "TraditionalForm"], "=", 
            RowBox[{"1", " ", 
              StyleBox["V",
                FontSlant->"Plain"]}]}], ","}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{"0.002", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".  Compare the shape of ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " for a few periods to the original voltage function. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Play the sawtooth sound ",
  Cell[BoxData[
      \(TraditionalForm\`V(t)\)]],
  ", and play the resulting ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " as a sound. Play ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " again, for ",
  Cell[BoxData[
      \(TraditionalForm\`R = 5000\ \[CapitalOmega]\)]],
  ", all else the same. Would you characterize this circuit as one that \
filters out high frequencies or low frequencies? "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)(a) ",
    FontWeight->"Bold"],
  " Rewrite the exponential series of the previous problem for ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  " as a cos-sin series.  For ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20\)]],
  " compare with the exponential series by plotting both, showing they are \
identical."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Randomize the phases of the Fourier modes in part (a) by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\ n\ \[Pi]\ \[CapitalDelta]\[Omega]\ t)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`sin(\ n\ \[Pi]\ \[CapitalDelta]\[Omega]\ t)\)]],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"cos", "(", 
            RowBox[{\(n\ \[Pi]\ \[CapitalDelta]\[Omega]\ t\), "+", " ", 
              FormBox[\(\[Phi]\_n\),
                "TraditionalForm"]}], ")"}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"sin", "(", 
          RowBox[{
            RowBox[{"n", 
              FormBox["\[Pi]",
                "TraditionalForm"], "\[CapitalDelta]\[Omega]", " ", "t"}], 
            "+", 
            FormBox[\(\[Phi]\&_\_n\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\&_\_n\)]],
  " are random phases  in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\((0, 2  \[Pi])\)\)]],
  ", different for each mode, and generated using  ",
  StyleBox["2\[Pi] Random[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " . Listen to the randomized series to see if you can tell the difference. \
Also plot the randomized series for a few periods to verify that the function \
looks completely different than ",
  Cell[BoxData[
      \(TraditionalForm\`Q(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Find a particular solution  to the following set of coupled ODEs using \
exponential Fourier series:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[DoublePrime]\)(t) = \(-\((x - 2  y)\)\) - 
          x\^\[Prime] + \(f\_1\)(t), \[IndentingNewLine]\(y\^\[DoublePrime]\)(
          t) = \(-\((y - x)\)\) + \(f\_2\)(t), \)]]
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_1\)(
          t)\)\(=\)\(\((Mod[t, 1])\)\^2\)\(\ \)\)\)]],
  "and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\_2\)(t) = \(\(2\) \( Mod[t, \@2]\)\(\ \)\)\)]],
  "are two sawtooth oscillations (with  incommensurate periods). Plot the \
particular solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\)]],
  ". Keep as many terms in the series as you feel are necessary to achieve \
good convergence."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " When a signal propagates from a source that is not directly in front of \
an observer, there is a time difference between when the signal arrives at \
the left and right ears. The human auditory systems can use this time delay  \
to help determine the direction from which the sound is coming. A phase \
difference between the left and right ears of even 1-2 degrees is detectable \
as a change in the apparent location of the sound source. This can be tested \
using ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can take as its argument \t",
  StyleBox["two",
    FontSlant->"Italic"],
  " sound waveforms,  for left  and right  channels of a set of stereo \
headphones.  For example, \n",
  StyleBox["Play[{Sin[440 2 \[Pi] t],Sin[440 2 \[Pi] t + \
\[Phi](t)]},{t,0,10}]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", plays a sine tone for 10 seconds in each ear, but with a phase advance \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](t)\)]],
  " in the right ear."
}], "Text",
  CellTags->"i:27"],

Cell[TextData[{
  "\t Using a pair of stereo headphones with the above sound, see if you can \
determine an apparent location of a sound source. Try (a) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](t) = \ 0.2\ t\)]],
  ", (b) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](t)\  = \ \(-0.2\)\ t\)]],
  "; (c) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](t)\  = \ 0\)]],
  ". Can you tell the difference? (See ",
  ButtonBox["Hartmann (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".) ",
  StyleBox["(Warning! The stereo effect in ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Play ",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["may not work on all platforms. Test it out by trying ",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Play[{0,Sin[440 2\[Pi] t]},{t,0,1}]",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["; this should produce a tone only in the right ear. Repeat for \
the left ear. Also, make sure the volume is on a low setting, or else \
crosstalk between your ears may impede the directional effect. )",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.2 Fourier Representation of Functions Defined on a Finite \
Interval\
\>", "Subtitle",
  CellTags->{"Sec. 2.2", "i:15", "c:13"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["2.2.1 Periodic Extension of a Function", "Subsubtitle",
  CellTags->{"i:29", "c:14"}],

Cell[TextData[{
  "\tIn the previous sections,  Fourier series methods were applied to \
represent periodic functions. Here, we will apply Fourier methods to \
functions  ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " defined only on an interval, ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ t \[LessEqual] \ b\)]],
  ". Such functions often appear in boundary-value problems, where the \
solution of the differential equation is needed only between boundary points \
",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFunctions defined only on an interval are not periodic, since they are \
not defined outside the interval in question and therefore do not satisfy Eq. \
",
  ButtonBox["(2.1.1)",
    ButtonData:>"(2.1.1)",
    ButtonStyle->"Hyperlink"],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". However, a Fourier representation can be still be obtained by ",
  StyleBox["replacing",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " with a periodic function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(t)\)]],
  ", defined on the entire real line ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < t < \[Infinity]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t There are several different choices for this periodic function. One \
choice requires  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(t)\)]],
  StyleBox[" ",
    FontWeight->"Bold"],
  "to equal ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ t \[LessEqual] \ b\)]],
  ", and to have period ",
  Cell[BoxData[
      \(TraditionalForm\`T = b - a\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(f\^\((p)\)\)(t)\  = \ f(t), \ \ a < t < 
      b, \[IndentingNewLine]\(f\^\((p)\)\)(
        t + T) = \(\(\(f\^\((p)\)\)(t)\)\(.\)\)\)]]], "NE2",
  CellTags->"(2.2.1)"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(t)\)]],
  " is called a ",
  StyleBox["periodic extension ",
    FontSlant->"Italic"],
  "of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". The type of periodic extension given by Eq. ",
  ButtonBox["(2.2.1)",
    ButtonData:>"(2.2.1)",
    ButtonStyle->"Hyperlink"],
  " is depicted in Fig. ",
  ButtonBox["2.3",
    ButtonData:>"Fig. 2.3",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.579365 0.0793651 0.45222 0.07537 [
[.10317 .43972 -6 -9 ]
[.10317 .43972 6 0 ]
[.2619 .43972 -6 -9 ]
[.2619 .43972 6 0 ]
[.42063 .43972 -6 -9 ]
[.42063 .43972 6 0 ]
[.7381 .43972 -3 -9 ]
[.7381 .43972 3 0 ]
[.89683 .43972 -3 -9 ]
[.89683 .43972 3 0 ]
[1.025 .45222 0 -6 ]
[1.025 .45222 10 6 ]
[.56687 0 -12 -4.5 ]
[.56687 0 0 4.5 ]
[.56687 .15074 -12 -4.5 ]
[.56687 .15074 0 4.5 ]
[.56687 .30148 -12 -4.5 ]
[.56687 .30148 0 4.5 ]
[.56687 .60296 -6 -4.5 ]
[.56687 .60296 0 4.5 ]
[.57937 .64303 -14 0 ]
[.57937 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.10317 .45222 m
.10317 .45847 L
s
[(-6)] .10317 .43972 0 1 Mshowa
.2619 .45222 m
.2619 .45847 L
s
[(-4)] .2619 .43972 0 1 Mshowa
.42063 .45222 m
.42063 .45847 L
s
[(-2)] .42063 .43972 0 1 Mshowa
.7381 .45222 m
.7381 .45847 L
s
[(2)] .7381 .43972 0 1 Mshowa
.89683 .45222 m
.89683 .45847 L
s
[(4)] .89683 .43972 0 1 Mshowa
.125 Mabswid
.14286 .45222 m
.14286 .45597 L
s
.18254 .45222 m
.18254 .45597 L
s
.22222 .45222 m
.22222 .45597 L
s
.30159 .45222 m
.30159 .45597 L
s
.34127 .45222 m
.34127 .45597 L
s
.38095 .45222 m
.38095 .45597 L
s
.46032 .45222 m
.46032 .45597 L
s
.5 .45222 m
.5 .45597 L
s
.53968 .45222 m
.53968 .45597 L
s
.61905 .45222 m
.61905 .45597 L
s
.65873 .45222 m
.65873 .45597 L
s
.69841 .45222 m
.69841 .45597 L
s
.77778 .45222 m
.77778 .45597 L
s
.81746 .45222 m
.81746 .45597 L
s
.85714 .45222 m
.85714 .45597 L
s
.06349 .45222 m
.06349 .45597 L
s
.02381 .45222 m
.02381 .45597 L
s
.93651 .45222 m
.93651 .45597 L
s
.97619 .45222 m
.97619 .45597 L
s
.25 Mabswid
0 .45222 m
1 .45222 L
s
gsave
1.025 .45222 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.57937 0 m
.58562 0 L
s
[(-6)] .56687 0 1 0 Mshowa
.57937 .15074 m
.58562 .15074 L
s
[(-4)] .56687 .15074 1 0 Mshowa
.57937 .30148 m
.58562 .30148 L
s
[(-2)] .56687 .30148 1 0 Mshowa
.57937 .60296 m
.58562 .60296 L
s
[(2)] .56687 .60296 1 0 Mshowa
.125 Mabswid
.57937 .03768 m
.58312 .03768 L
s
.57937 .07537 m
.58312 .07537 L
s
.57937 .11305 m
.58312 .11305 L
s
.57937 .18842 m
.58312 .18842 L
s
.57937 .22611 m
.58312 .22611 L
s
.57937 .26379 m
.58312 .26379 L
s
.57937 .33916 m
.58312 .33916 L
s
.57937 .37685 m
.58312 .37685 L
s
.57937 .41453 m
.58312 .41453 L
s
.57937 .4899 m
.58312 .4899 L
s
.57937 .52759 m
.58312 .52759 L
s
.57937 .56527 m
.58312 .56527 L
s
.25 Mabswid
.57937 0 m
.57937 .61803 L
s
gsave
.57937 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .57523 m
.03347 .57164 L
.044 .5672 L
.0539 .56245 L
.06341 .55729 L
.07354 .55108 L
.08328 .5443 L
.09365 .53612 L
.10363 .52716 L
.11323 .51741 L
.12345 .50565 L
.13329 .49281 L
.14275 .47887 L
.15282 .46208 L
.16251 .44378 L
.17282 .42171 L
.18274 .39756 L
.19229 .3713 L
.20245 .33965 L
.21224 .30512 L
.22263 .26343 L
.23265 .21776 L
.24229 .16802 L
.25254 .10806 L
.2619 .04605 L
s
.2619 .57523 m
.27156 .57164 L
.2821 .5672 L
.29199 .56245 L
.3015 .55729 L
.31163 .55108 L
.32138 .5443 L
.33174 .53612 L
.34172 .52716 L
.35133 .51741 L
.36154 .50565 L
.37138 .49281 L
.38084 .47887 L
.39091 .46208 L
.40061 .44378 L
.41091 .42171 L
.42084 .39756 L
.43039 .3713 L
.44055 .33965 L
.45033 .30512 L
.46073 .26343 L
.47074 .21776 L
.48038 .16802 L
.49063 .10806 L
.5 .04605 L
s
.5 .57523 m
.50966 .57164 L
.52019 .5672 L
.53009 .56245 L
.5396 .55729 L
.54973 .55108 L
.55948 .5443 L
.56984 .53612 L
.57982 .52716 L
.58942 .51741 L
.59964 .50565 L
.60948 .49281 L
.61894 .47887 L
.62901 .46208 L
.6387 .44378 L
.64901 .42171 L
.65893 .39756 L
.66848 .3713 L
.67864 .33965 L
.68843 .30512 L
.69882 .26343 L
.70884 .21776 L
.71848 .16802 L
.72873 .10806 L
.7381 .04605 L
s
.7381 .57523 m
.74775 .57164 L
.75829 .5672 L
.76818 .56245 L
.77769 .55729 L
.78782 .55108 L
.79757 .5443 L
.80793 .53612 L
.81791 .52716 L
.82752 .51741 L
.83773 .50565 L
.84757 .49281 L
.85703 .47887 L
.8671 .46208 L
.8768 .44378 L
.8871 .42171 L
.89703 .39756 L
.90658 .3713 L
.91674 .33965 L
.92652 .30512 L
.93692 .26343 L
.94693 .21776 L
.95657 .16802 L
.96682 .10806 L
.97619 .04605 L
s
.006 w
.5 .57523 m
.50966 .57164 L
.52019 .5672 L
.53009 .56245 L
.5396 .55729 L
.54973 .55108 L
.55948 .5443 L
.56984 .53612 L
.57982 .52716 L
.58942 .51741 L
.59964 .50565 L
.60948 .49281 L
.61894 .47887 L
.62901 .46208 L
.6387 .44378 L
.64901 .42171 L
.65893 .39756 L
.66848 .3713 L
.67864 .33965 L
.68843 .30512 L
.69882 .26343 L
.70884 .21776 L
.71848 .16802 L
.72873 .10806 L
.7381 .04605 L
s
.5 Mabswid
[ .05 .05 ] 0 setdash
.5 0 m
.5 .60296 L
s
.7381 0 m
.7381 .60296 L
s
gsave
.47619 .60296 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.7619 .60296 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?moobUoo`@00?mooaEoo`00
ogoo:7oo00<007ooOol00Woo00<007ooOol0ogoo4Woo003oOolWOol00`00Oomoo`04Ool00`00Oomo
o`3oOolAOol00?moobMoo`03001oogoo00Aoo`03001oogoo0?mooa5oo`00ogoo47oo00<007ooOol0
27oo2@000goo00<007ooOol017oo00<007ooOol01Woo1@00Bgoo00<007ooOol0]goo003oOol@Ool0
0`00Oomoo`08Ool90003Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`1=Ool00`00Oomo
o`2gOol00?mooa1oo`03001oogoo01Aoo`8000Aoo`03001oogoo00Moo`03001oogoo04eoo`03001o
ogoo0;Moo`00ogoo47oo00<007ooOol057oo00<007oo00000`002Woo00<007ooOol0CGoo00<007oo
Ool0]goo003oOol@Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`1=Ool00`00Oomoo`2g
Ool00?mooa1oo`03001oogoo01Eoo`03001oogoo00aoo`03001oogoo04eoo`03001oogoo0;Moo`00
ogoo47oo00<007ooOol05Woo0P0037oo00<007ooOol0CGoo00<007ooOol0]goo003oOol@Ool00`00
Oomoo`0HOol40008Ool00`00Oomoo`1=Ool00`00Oomoo`2gOol00?mooa1oo`03001oogoo02Aoo`03
001oogoo04eoo`03001oogoo0;Moo`00ogoo47oo00<007ooOol097oo00<007ooOol0CGoo00<007oo
Ool0]goo003oOol@Ool00`00Oomoo`0TOol00`00Oomoo`1=Ool00`00Oomoo`2gOol00?mooa1oo`03
001oogoo02Aoo`03001oogoo04eoo`03001oogoo0;Moo`00ogoo47oo00<007ooOol097oo00<007oo
Ool0CGoo00<007ooOol0]goo003oOol@Ool00`00Oomoo`0TOol00`00Oomoo`1=Ool00`00Oomoo`2g
Ool00?mooa1oo`03001oogoo02Aoo`03001oogoo04eoo`03001oogoo0;Moo`00ogoo47oo00<007oo
Ool097oo00<007ooOol0CGoo00<007ooOol0]goo003oOol@Ool00`00Oomoo`0TOol00`00Oomoo`1=
Ool00`00Oomoo`2gOol00?mooa1oo`03001oogoo02Aoo`03001oogoo04eoo`03001oogoo0;Moo`00
ogoo47oo00<007ooOol097oo0`00CGoo00<007ooOol0]goo003oOol@Ool00`00Oomoo`0TOol00`00
Oomoo`1=Ool00`00Oomoo`2gOol00?mooa1oo`03001oogoo02Aoo`03001oogoo04eoo`03001oogoo
0;Moo`00ogoo47oo00<007ooOol097oo00<007ooOol0CGoo00<007ooOol0]goo003oOol@Ool00`00
Oomoo`0TOol00`00Oomoo`1<Ool3002hOol009Qoo`03001oogoo07Aoo`03001oogoo02Aoo`03001o
ogoo04aoo`<007Eoo`03001oogoo041oo`00V7oo00<007ooOol0M7oo00<007ooOol097oo00<007oo
Ool0C7oo0`00MGoo00<007ooOol0@7oo002HOol00`00Oomoo`1dOol00`00Oomoo`0TOol00`00Oomo
o`1<Ool3001eOol00`00Oomoo`10Ool009Qoo`03001oogoo07Aoo`03001oogoo02Aoo`03001oogoo
04]oo`@007Eoo`03001oogoo041oo`00Ugoo00<007ooOol0M7oo00<007ooOol09Goo00<007ooOol0
Bgoo1000M7oo00<007ooOol0@Goo002GOol00`00Oomoo`1dOol00`00Oomoo`0UOol00`00Oomoo`1;
Ool3001eOol00`00Oomoo`11Ool009Moo`03001oogoo07Aoo`03001oogoo02Eoo`03001oogoo04]o
o`<007Eoo`03001oogoo045oo`00Ugoo00<007ooOol0M7oo00<007ooOol09Goo00<007ooOol0Bgoo
0`00MGoo00<007ooOol0@Goo002GOol00`00Oomoo`1dOol00`00Oomoo`0UOol00`00Oomoo`1;Ool3
001eOol00`00Oomoo`11Ool009Moo`03001oogoo07Aoo`03001oogoo02Eoo`03001oogoo04Yoo`@0
07Eoo`03001oogoo045oo`00UWoo00<007ooOol0M7oo00<007ooOol09Woo00<007ooOol0BWoo1000
M7oo00<007ooOol0@Woo002FOol00`00Oomoo`1dOol00`00Oomoo`0VOol00`00Oomoo`1:Ool3001e
Ool00`00Oomoo`12Ool009Ioo`03001oogoo07Aoo`03001oogoo02Ioo`03001oogoo04Yoo`<007Eo
o`03001oogoo049oo`00UWoo00<007ooOol0M7oo00<007ooOol09Woo00<007ooOol0BWoo0`00MGoo
00<007ooOol0@Woo002FOol00`00Oomoo`1dOol00`00Oomoo`0VOol3001:Ool3001eOol00`00Oomo
o`12Ool009Ioo`03001oogoo07Aoo`03001oogoo02Ioo`03001oogoo04Uoo`@007Eoo`03001oogoo
049oo`00UGoo00<007ooOol0M7oo00<007ooOol09goo00<007ooOol0BGoo1000M7oo00<007ooOol0
@goo002EOol00`00Oomoo`1dOol00`00Oomoo`0WOol00`00Oomoo`19Ool3001eOol00`00Oomoo`13
Ool009Eoo`03001oogoo07Aoo`03001oogoo02Moo`03001oogoo04Uoo`<007Eoo`03001oogoo04=o
o`00UGoo00<007ooOol0M7oo00<007ooOol09goo00<007ooOol0BGoo0`00MGoo00<007ooOol0@goo
002EOol00`00Oomoo`1dOol00`00Oomoo`0WOol00`00Oomoo`19Ool3001eOol00`00Oomoo`13Ool0
09Eoo`03001oogoo07Aoo`03001oogoo02Moo`03001oogoo04Uoo`<007Eoo`03001oogoo04=oo`00
UGoo00<007ooOol0M7oo00<007ooOol09goo00<007ooOol0B7oo1000MGoo00<007ooOol0@goo002D
Ool00`00Oomoo`1dOol00`00Oomoo`0XOol00`00Oomoo`18Ool4001dOol00`00Oomoo`14Ool009Ao
o`03001oogoo07Aoo`03001oogoo02Qoo`03001oogoo04Qoo`<007Eoo`03001oogoo04Aoo`00U7oo
00<007ooOol0M7oo00<007ooOol0:7oo00<007ooOol0B7oo0`00MGoo00<007ooOol0A7oo002DOol0
0`00Oomoo`1dOol00`00Oomoo`0XOol00`00Oomoo`18Ool3001eOol00`00Oomoo`14Ool009Aoo`03
001oogoo07Aoo`05001oogooOol0000VOol00`00Oomoo`18Ool30002Ool00`00Oomoo`1`Ool00`00
Oomoo`14Ool009Aoo`03001oogoo07Aoo`05001oogooOol0000VOol00`00Oomoo`17Ool40002Ool0
0`00Oomoo`1`Ool00`00Oomoo`14Ool009=oo`03001oogoo07Aoo`03001oogoo009oo`03001oogoo
02Aoo`03001oogoo04Moo`@0009oo`03001oogoo06moo`03001oogoo04Eoo`00Tgoo00<007ooOol0
M7oo00<007ooOol00Woo00<007ooOol097oo00<007ooOol0Agoo0`000goo00<007ooOol0Kgoo00<0
07ooOol0AGoo002COol00`00Oomoo`1dOol00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomoo`17
Ool30003Ool00`00Oomoo`1_Ool00`00Oomoo`15Ool009=oo`03001oogoo07Aoo`03001oogoo009o
o`03001oogoo02Aoo`03001oogoo04Moo`<000=oo`03001oogoo06moo`03001oogoo04Eoo`00Tgoo
00<007ooOol0M7oo00<007ooOol00Woo00<007ooOol097oo0`00Agoo0`000goo00<007ooOol0Kgoo
00<007ooOol0AGoo002COol00`00Oomoo`1dOol00`00Oomoo`02Ool00`00Oomoo`0TOol00`00Oomo
o`16Ool40003Ool00`00Oomoo`1_Ool00`00Oomoo`15Ool0099oo`03001oogoo07Aoo`03001oogoo
00=oo`03001oogoo02Aoo`03001oogoo04Ioo`@000=oo`03001oogoo06ioo`03001oogoo04Ioo`00
TWoo00<007ooOol0M7oo00<007ooOol00goo00<007ooOol097oo00<007ooOol0AWoo0`0017oo00<0
07ooOol0KWoo00<007ooOol0AWoo002BOol00`00Oomoo`1dOol00`00Oomoo`03Ool00`00Oomoo`0T
Ool00`00Oomoo`16Ool30004Ool00`00Oomoo`1^Ool00`00Oomoo`16Ool0099oo`03001oogoo07Ao
o`03001oogoo00=oo`03001oogoo02Aoo`03001oogoo04Ioo`<000Aoo`03001oogoo06ioo`03001o
ogoo04Ioo`00TWoo00<007ooOol0M7oo00<007ooOol00goo00<007ooOol097oo00<007ooOol0AWoo
0`0017oo00<007ooOol0KWoo00<007ooOol0AWoo002BOol00`00Oomoo`1dOol00`00Oomoo`03Ool0
0`00Oomoo`0TOol00`00Oomoo`15Ool40004Ool00`00Oomoo`1^Ool00`00Oomoo`16Ool0095oo`03
001oogoo07Aoo`03001oogoo00Aoo`03001oogoo02Aoo`03001oogoo04Eoo`@000Aoo`03001oogoo
06eoo`03001oogoo04Moo`00TGoo00<007ooOol0M7oo00<007ooOol017oo00<007ooOol097oo00<0
07ooOol0AGoo0`001Goo00<007ooOol0KGoo00<007ooOol0Agoo002AOol00`00Oomoo`1dOol00`00
Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`15Ool30005Ool00`00Oomoo`1]Ool00`00Oomoo`17
Ool0095oo`03001oogoo07Aoo`03001oogoo00Aoo`03001oogoo02Aoo`03001oogoo04Eoo`<000Eo
o`03001oogoo06eoo`03001oogoo04Moo`00TGoo00<007ooOol0M7oo00<007ooOol017oo00<007oo
Ool097oo00<007ooOol0AGoo0`001Goo00<007ooOol0KGoo00<007ooOol0Agoo002AOol00`00Oomo
o`1dOol00`00Oomoo`04Ool00`00Oomoo`0TOol00`00Oomoo`14Ool40005Ool00`00Oomoo`1]Ool0
0`00Oomoo`17Ool0091oo`03001oogoo07Aoo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo
04Aoo`@000Eoo`03001oogoo06aoo`03001oogoo04Qoo`00T7oo00<007ooOol0M7oo00<007ooOol0
1Goo00<007ooOol067oo1@001goo00<007ooOol0A7oo0`001Woo00<007ooOol0K7oo00<007ooOol0
B7oo002@Ool00`00Oomoo`1dOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`07Ool00`00
Oomoo`14Ool30006Ool00`00Oomoo`1/Ool00`00Oomoo`18Ool0091oo`03001oogoo07Aoo`03001o
ogoo00Eoo`03001oogoo01Yoo`03001oogoo00Moo`03001oogoo04Aoo`<000Ioo`03001oogoo06ao
o`03001oogoo04Qoo`00T7oo00<007ooOol0M7oo00<007ooOol01Goo00<007ooOol057oo2@001goo
00<007ooOol0A7oo0`001Woo00<007ooOol0K7oo00<007ooOol0B7oo002@Ool00`00Oomoo`1dOol0
0`00Oomoo`05Ool00`00Oomoo`08Ool90004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool50011Ool4
0006Ool00`00Oomoo`1/Ool00`00Oomoo`18Ool008moo`03001oogoo07Aoo`03001oogoo015oo`T0
00Aoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo04=oo`@007Aoo`03001oogoo04Uoo`00
Sgoo00<007ooOol0M7oo00<007ooOol07goo00D007ooOomoo`0000Uoo`03001oogoo04=oo`<007Eo
o`03001oogoo04Uoo`00Sgoo00<007ooOol0M7oo00<007ooOol087oo00@007ooOol000Uoo`03001o
ogoo04=oo`<007Eoo`03001oogoo04Uoo`00Sgoo00<007ooOol0M7oo00<007ooOol087oo00@007oo
Ool000Uoo`03001oogoo04=oo`<007Eoo`03001oogoo04Uoo`00Sgoo00<007ooOol0M7oo00<007oo
Ool08Goo00<007oo00002Goo00<007ooOol0@goo0`00MGoo00<007ooOol0BGoo002?Ool00`00Oomo
o`1dOol00`00Oomoo`0ROol20009Ool00`00Oomoo`12Ool4001eOol00`00Oomoo`19Ool008ioo`03
001oogoo07Aoo`03001oogoo02=oo`8000Uoo`03001oogoo049oo`@007Aoo`03001oogoo04Yoo`00
SWoo00<007ooOol0M7oo00<007ooOol0;Woo00<007ooOol0@Woo0`00MGoo00<007ooOol0BWoo002>
Ool00`00Oomoo`1dOol00`00Oomoo`0^Ool00`00Oomoo`12Ool3001eOol00`00Oomoo`1:Ool008io
o`03001oogoo07Aoo`03001oogoo02ioo`03001oogoo049oo`<007Eoo`03001oogoo04Yoo`00SWoo
00<007ooOol0M7oo00<007ooOol0;Woo00<007ooOol0@Goo1000MGoo00<007ooOol0BWoo002=Ool0
0`00Oomoo`1dOol00`00Oomoo`0_Ool00`00Oomoo`11Ool4001dOol00`00Oomoo`1;Ool008eoo`03
001oogoo07Aoo`03001oogoo02moo`03001oogoo045oo`<007Eoo`03001oogoo04]oo`00SGoo00<0
07ooOol0M7oo00<007ooOol0;goo00<007ooOol0@Goo0`00MGoo00<007ooOol0Bgoo002=Ool00`00
Oomoo`1dOol00`00Oomoo`0_Ool00`00Oomoo`11Ool3001eOol00`00Oomoo`1;Ool008eoo`03001o
ogoo07Aoo`03001oogoo02moo`03001oogoo041oo`@007Eoo`03001oogoo04]oo`00S7oo00<007oo
Ool0M7oo00<007ooOol0<7oo00<007ooOol0@7oo1000M7oo00<007ooOol0C7oo002<Ool00`00Oomo
o`1dOol00`00Oomoo`0`Ool00`00Oomoo`10Ool3001eOol00`00Oomoo`1<Ool008aoo`03001oogoo
07Aoo`03001oogoo031oo`<0041oo`<007Eoo`03001oogoo04aoo`00S7oo00<007ooOol0M7oo00<0
07ooOol0<7oo00<007ooOol0@7oo0`00MGoo00<007ooOol0C7oo002<Ool00`00Oomoo`1dOol00`00
Oomoo`0`Ool00`00Oomoo`0oOol4001eOol00`00Oomoo`1<Ool008]oo`03001oogoo07Aoo`03001o
ogoo035oo`03001oogoo03moo`@007Aoo`03001oogoo04eoo`00Rgoo00<007ooOol0M7oo00<007oo
Ool0<Goo00<007ooOol0?goo0`00MGoo00<007ooOol0CGoo002;Ool00`00Oomoo`1dOol00`00Oomo
o`0aOol00`00Oomoo`0oOol3001eOol00`00Oomoo`1=Ool008]oo`03001oogoo07Aoo`03001oogoo
00Yoo`03001oogoo02Aoo`03001oogoo03moo`<000]oo`03001oogoo06Moo`03001oogoo04eoo`00
Rgoo00<007ooOol0M7oo00<007ooOol02Woo00<007ooOol097oo00<007ooOol0?Woo10002goo00<0
07ooOol0Igoo00<007ooOol0CGoo002:Ool00`00Oomoo`1dOol00`00Oomoo`0;Ool00`00Oomoo`0T
Ool00`00Oomoo`0nOol4000;Ool00`00Oomoo`1VOol00`00Oomoo`1>Ool008Yoo`03001oogoo07Ao
o`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo03ioo`<000aoo`03001oogoo06Ioo`03001o
ogoo04ioo`00RWoo00<007ooOol0M7oo00<007ooOol02goo00<007ooOol097oo00<007ooOol0?Woo
0`0037oo00<007ooOol0IWoo00<007ooOol0CWoo002:Ool00`00Oomoo`1dOol00`00Oomoo`0;Ool0
0`00Oomoo`0TOol00`00Oomoo`0nOol3000<Ool00`00Oomoo`1VOol00`00Oomoo`1>Ool008Yoo`03
001oogoo07Aoo`03001oogoo00]oo`03001oogoo02Aoo`03001oogoo03eoo`@000aoo`03001oogoo
06Ioo`03001oogoo04ioo`00RGoo00<007ooOol0M7oo00<007ooOol037oo00<007ooOol097oo00<0
07ooOol0?Goo100037oo00<007ooOol0IGoo00<007ooOol0Cgoo0029Ool00`00Oomoo`1dOol00`00
Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`0mOol3000=Ool00`00Oomoo`1UOol00`00Oomoo`1?
Ool008Uoo`03001oogoo07Aoo`03001oogoo00aoo`03001oogoo02Aoo`03001oogoo03eoo`<000eo
o`03001oogoo06Eoo`03001oogoo04moo`00RGoo00<007ooOol0M7oo00<007ooOol037oo00<007oo
Ool097oo00<007ooOol0?Goo0`003Goo00<007ooOol0IGoo00<007ooOol0Cgoo0029Ool00`00Oomo
o`1dOol00`00Oomoo`0<Ool00`00Oomoo`0TOol00`00Oomoo`0lOol4000=Ool00`00Oomoo`1UOol0
0`00Oomoo`1?Ool008Qoo`03001oogoo07Aoo`03001oogoo00eoo`03001oogoo02Aoo`03001oogoo
03aoo`@000eoo`03001oogoo06Aoo`03001oogoo051oo`00R7oo00<007ooOol0M7oo00<007ooOol0
3Goo00<007ooOol097oo0`00?7oo0`003Woo00<007ooOol0I7oo00<007ooOol0D7oo0028Ool00`00
Oomoo`1dOol00`00Oomoo`0=Ool00`00Oomoo`0TOol00`00Oomoo`0lOol3000>Ool00`00Oomoo`1T
Ool00`00Oomoo`1@Ool008Qoo`03001oogoo07Aoo`03001oogoo00eoo`03001oogoo02Aoo`03001o
ogoo03aoo`<000ioo`03001oogoo06Aoo`03001oogoo051oo`00R7oo00<007ooOol0M7oo00<007oo
Ool03Goo00<007ooOol097oo00<007ooOol0>goo10003Woo00<007ooOol0I7oo00<007ooOol0D7oo
0027Ool00`00Oomoo`1dOol00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`0kOol4000>Ool0
0`00Oomoo`1SOol00`00Oomoo`1AOol008Moo`03001oogoo07Aoo`03001oogoo00ioo`03001oogoo
02Aoo`03001oogoo03]oo`<000moo`03001oogoo06=oo`03001oogoo055oo`00Qgoo00<007ooOol0
M7oo00<007ooOol03Woo00<007ooOol097oo00<007ooOol0>goo0`003goo00<007ooOol0Hgoo00<0
07ooOol0DGoo0027Ool00`00Oomoo`1dOol00`00Oomoo`0>Ool00`00Oomoo`0TOol00`00Oomoo`0j
Ool4000?Ool00`00Oomoo`1SOol00`00Oomoo`1AOol008Ioo`03001oogoo07Aoo`03001oogoo00mo
o`03001oogoo02Aoo`03001oogoo03Yoo`@000moo`03001oogoo069oo`03001oogoo059oo`00QWoo
00<007ooOol0M7oo00<007ooOol03goo00<007ooOol097oo00<007ooOol0>Woo0`0047oo00<007oo
Ool0HWoo00<007ooOol0DWoo0026Ool00`00Oomoo`1dOol00`00Oomoo`0?Ool00`00Oomoo`0TOol0
0`00Oomoo`0jOol3000@Ool00`00Oomoo`1ROol00`00Oomoo`1BOol008Ioo`03001oogoo07Aoo`03
001oogoo00moo`03001oogoo02Aoo`03001oogoo03Uoo`@0011oo`03001oogoo069oo`03001oogoo
059oo`00QGoo00<007ooOol0M7oo00<007ooOol047oo00<007ooOol097oo00<007ooOol0>Goo1000
47oo00<007ooOol0HGoo00<007ooOol0Dgoo0025Ool00`00Oomoo`1dOol00`00Oomoo`0gOol00`00
Oomoo`0iOol3001eOol00`00Oomoo`1COol008Eoo`03001oogoo07Aoo`03001oogoo03Moo`03001o
ogoo03Uoo`<007Eoo`03001oogoo05=oo`00QGoo00<007ooOol0M7oo00<007ooOol0=goo00<007oo
Ool0>Goo0`00MGoo00<007ooOol0Dgoo0025Ool00`00Oomoo`1dOol00`00Oomoo`0gOol00`00Oomo
o`0hOol4001eOol00`00Oomoo`1COol008Aoo`03001oogoo07Aoo`03001oogoo03Qoo`03001oogoo
03Qoo`@007Aoo`03001oogoo05Aoo`00Q7oo00<007ooOol0M7oo00<007ooOol0>7oo00<007ooOol0
>7oo0`00MGoo00<007ooOol0E7oo0024Ool00`00Oomoo`1dOol00`00Oomoo`0hOol3000hOol3001e
Ool00`00Oomoo`1DOol008Aoo`03001oogoo07Aoo`03001oogoo03Qoo`03001oogoo03Moo`@007Eo
o`03001oogoo05Aoo`00Pgoo00<007ooOol0M7oo00<007ooOol0>Goo00<007ooOol0=goo1000M7oo
00<007ooOol0EGoo0023Ool00`00Oomoo`1dOol00`00Oomoo`0iOol00`00Oomoo`0gOol3001eOol0
0`00Oomoo`1EOol008=oo`03001oogoo07Aoo`03001oogoo03Uoo`03001oogoo03Moo`<007Eoo`03
001oogoo05Eoo`00Pgoo00<007ooOol0M7oo00<007ooOol0>Goo00<007ooOol0=Woo1000MGoo00<0
07ooOol0EGoo0022Ool00`00Oomoo`1dOol00`00Oomoo`0jOol00`00Oomoo`0fOol4001dOol00`00
Oomoo`1FOol0089oo`03001oogoo07Aoo`03001oogoo03Yoo`03001oogoo03Ioo`<007Eoo`03001o
ogoo05Ioo`00PWoo00<007ooOol0M7oo00<007ooOol0>Woo00<007ooOol0=Woo0`00MGoo00<007oo
Ool0EWoo0022Ool00`00Oomoo`1dOol00`00Oomoo`0jOol00`00Oomoo`0eOol4001eOol00`00Oomo
o`1FOol0085oo`03001oogoo07Aoo`03001oogoo03]oo`03001oogoo03Eoo`@007Aoo`03001oogoo
05Moo`00PGoo00<007ooOol0M7oo00<007ooOol0>goo00<007ooOol0=Goo0`00MGoo00<007ooOol0
Egoo0021Ool00`00Oomoo`1dOol00`00Oomoo`0kOol00`00Oomoo`0eOol3001eOol00`00Oomoo`1G
Ool0085oo`03001oogoo07Aoo`03001oogoo03]oo`03001oogoo03Eoo`<007Eoo`03001oogoo05Mo
o`00PGoo00<007ooOol0M7oo00<007ooOol0>goo00<007ooOol0=7oo1000MGoo00<007ooOol0Egoo
0020Ool00`00Oomoo`1dOol00`00Oomoo`0/Ool80008Ool00`00Oomoo`0dOol4001dOol00`00Oomo
o`1HOol0081oo`03001oogoo07Aoo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo03Aoo`<007Eoo`03001oogoo05Qoo`00P7oo00<007ooOol0M7oo00<007ooOol0;Woo00<0
07ooOol02goo00<007ooOol0=7oo0`00MGoo00<007ooOol0F7oo0020Ool00`00Oomoo`1dOol00`00
Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`0cOol4000FOol00`00Oomoo`1L
Ool00`00Oomoo`1HOol007moo`03001oogoo07Aoo`03001oogoo01Ioo`03001oogoo00Qoo`T000Mo
o`03001oogoo00Uoo`D0035oo`@001Ioo`03001oogoo05]oo`03001oogoo05Uoo`00Ogoo00<007oo
Ool0M7oo00<007ooOol05Woo00<007ooOol027oo2@0027oo00<007ooOol027oo00<007ooOol0<goo
0`005goo00<007ooOol0Fgoo00<007ooOol0FGoo001oOol00`00Oomoo`1dOol00`00Oomoo`0FOol0
0`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomoo`0cOol3000GOol00`00Oomoo`1KOol00`00Oomo
o`1IOol007moo`03001oogoo07Aoo`03001oogoo01Ioo`03001oogoo01]oo`03001oogoo00Ioo`03
001oogoo039oo`@001Moo`03001oogoo05]oo`03001oogoo05Uoo`00OWoo00<007ooOol0M7oo00<0
07ooOol05goo00<007ooOol06goo00<007ooOol01Woo00<007ooOol0<Woo10005goo00<007ooOol0
FWoo00<007ooOol0FWoo001nOol00`00Oomoo`1dOol00`00Oomoo`0GOol00`00Oomoo`0EOol00`00
Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`0bOol3000HOol00`00Oomoo`1JOol00`00Oomoo`1J
Ool007ioo`03001oogoo07Aoo`03001oogoo01Moo`03001oogoo01Eoo`8000=oo`03001oogoo00Mo
o`03001oogoo035oo`@001Qoo`03001oogoo05Yoo`03001oogoo05Yoo`00OGoo00<007ooOol0M7oo
00<007ooOol067oo00<007ooOol05goo0`002Woo00<007ooOol0<Goo100067oo00<007ooOol0FGoo
00<007ooOol0Fgoo001mOol00`00Oomoo`1dOol00`00Oomoo`0HOol00`00Oomoo`0TOol00`00Oomo
o`0aOol3000IOol00`00Oomoo`1IOol00`00Oomoo`1KOol007eoo`03001oogoo07Aoo`03001oogoo
01Qoo`03001oogoo02Aoo`03001oogoo035oo`<001Uoo`03001oogoo05Uoo`03001oogoo05]oo`00
OGoo00<007ooOol0M7oo00<007ooOol067oo00<007ooOol097oo00<007ooOol0<7oo10006Goo00<0
07ooOol0FGoo00<007ooOol0Fgoo001lOol00`00Oomoo`1dOol00`00Oomoo`0IOol00`00Oomoo`0T
Ool00`00Oomoo`0`Ool4000IOol00`00Oomoo`1HOol00`00Oomoo`1LOol007aoo`03001oogoo07Ao
o`03001oogoo01Uoo`03001oogoo02Aoo`03001oogoo031oo`<001Yoo`03001oogoo05Qoo`03001o
ogoo05aoo`00O7oo00<007ooOol0M7oo00<007ooOol06Goo00<007ooOol097oo00<007ooOol0<7oo
0`006Woo00<007ooOol0F7oo00<007ooOol0G7oo001lOol00`00Oomoo`1dOol00`00Oomoo`0IOol0
0`00Oomoo`0TOol00`00Oomoo`0_Ool4000JOol00`00Oomoo`1HOol00`00Oomoo`1LOol007]oo`03
001oogoo07Aoo`03001oogoo01Yoo`03001oogoo02Aoo`03001oogoo02moo`@001Yoo`03001oogoo
05Moo`03001oogoo05eoo`00Ngoo00<007ooOol0M7oo00<007ooOol06Woo00<007ooOol097oo00<0
07ooOol0;goo0`006goo00<007ooOol0Egoo00<007ooOol0GGoo001kOol00`00Oomoo`1dOol00`00
Oomoo`0JOol00`00Oomoo`0TOol00`00Oomoo`0^Ool4000KOol00`00Oomoo`1GOol00`00Oomoo`1M
Ool007Yoo`03001oogoo07Aoo`03001oogoo01]oo`03001oogoo02Aoo`<002ioo`@001]oo`03001o
ogoo05Ioo`03001oogoo05ioo`00NWoo00<007ooOol0M7oo00<007ooOol06goo00<007ooOol097oo
00<007ooOol0;Woo0`0077oo00<007ooOol0EWoo00<007ooOol0GWoo001jOol00`00Oomoo`1dOol0
0`00Oomoo`0KOol00`00Oomoo`0TOol00`00Oomoo`0]Ool4000LOol00`00Oomoo`1FOol00`00Oomo
o`1NOol007Uoo`03001oogoo07Aoo`03001oogoo01aoo`03001oogoo02Aoo`03001oogoo02eoo`@0
01aoo`03001oogoo05Eoo`03001oogoo05moo`00NGoo00<007ooOol0M7oo00<007ooOol077oo00<0
07ooOol097oo00<007ooOol0;Goo0`007Goo00<007ooOol0EGoo00<007ooOol0Ggoo001iOol00`00
Oomoo`1dOol00`00Oomoo`0LOol00`00Oomoo`0TOol00`00Oomoo`0/Ool4000MOol00`00Oomoo`1E
Ool00`00Oomoo`1OOol007Qoo`03001oogoo07Aoo`03001oogoo01eoo`03001oogoo02Aoo`03001o
ogoo02aoo`@001eoo`03001oogoo05Aoo`03001oogoo061oo`00N7oo00<007ooOol0M7oo00<007oo
Ool0A7oo00<007ooOol0;7oo0`00MGoo00<007ooOol0H7oo001hOol00`00Oomoo`1dOol00`00Oomo
o`14Ool00`00Oomoo`0[Ool4001eOol00`00Oomoo`1POol007Moo`03001oogoo07Aoo`03001oogoo
04Eoo`03001oogoo02]oo`@007Aoo`03001oogoo065oo`00Mgoo00<007ooOol0M7oo00<007ooOol0
AGoo00<007ooOol0:goo0`00MGoo00<007ooOol0HGoo001gOol00`00Oomoo`1dOol00`00Oomoo`15
Ool00`00Oomoo`0ZOol4001eOol00`00Oomoo`1QOol007Ioo`03001oogoo07Aoo`03001oogoo04Io
o`03001oogoo02Yoo`@007Aoo`03001oogoo069oo`00MWoo00<007ooOol0M7oo00<007ooOol0AWoo
00<007ooOol0:Woo0`00MGoo00<007ooOol0HWoo001fOol00`00Oomoo`1dOol00`00Oomoo`16Ool0
0`00Oomoo`0YOol4001eOol00`00Oomoo`1ROol007Eoo`03001oogoo07Aoo`03001oogoo04Moo`03
001oogoo02Uoo`@007Aoo`03001oogoo06=oo`00MGoo00<007ooOol0M7oo00<007ooOol0Agoo00<0
07ooOol0:Goo0`00MGoo00<007ooOol0Hgoo001eOol00`00Oomoo`1dOol00`00Oomoo`17Ool00`00
Oomoo`0XOol4001eOol00`00Oomoo`1SOol007Aoo`03001oogoo07Aoo`03001oogoo04Qoo`03001o
ogoo02Qoo`@007Aoo`03001oogoo06Aoo`00M7oo00<007ooOol0M7oo00<007ooOol0B7oo0`00:7oo
0`00MGoo00<007ooOol0I7oo001dOol00`00Oomoo`1dOol00`00Oomoo`18Ool00`00Oomoo`0WOol4
001eOol00`00Oomoo`1TOol007=oo`03001oogoo07Aoo`03001oogoo04Uoo`03001oogoo02Moo`@0
07Aoo`03001oogoo06Eoo`00Lgoo00<007ooOol0M7oo00<007ooOol0BGoo00<007ooOol09goo0`00
MGoo00<007ooOol0IGoo001cOol00`00Oomoo`1dOol00`00Oomoo`19Ool00`00Oomoo`0VOol4001e
Ool00`00Oomoo`1UOol0079oo`03001oogoo07Aoo`03001oogoo04Yoo`03001oogoo02Ioo`@007Ao
o`03001oogoo06Ioo`00LWoo00<007ooOol0M7oo00<007ooOol0BWoo00<007ooOol09Woo0`00MGoo
00<007ooOol0IWoo001bOol00`00Oomoo`1dOol00`00Oomoo`1:Ool00`00Oomoo`0UOol4001eOol0
0`00Oomoo`1VOol0075oo`03001oogoo07Aoo`03001oogoo04]oo`03001oogoo02Eoo`@007Aoo`03
001oogoo06Moo`00LGoo00<007ooOol0M7oo00<007ooOol0Bgoo00<007ooOol09Goo0`00MGoo00<0
07ooOol0Igoo001aOol00`00Oomoo`1dOol00`00Oomoo`1;Ool00`00Oomoo`0TOol4001eOol00`00
Oomoo`1WOol0071oo`03001oogoo07Aoo`03001oogoo04aoo`03001oogoo02Aoo`@007Aoo`03001o
ogoo06Qoo`00L7oo00<007ooOol0M7oo00<007ooOol09Goo00<007ooOol097oo00<007ooOol08goo
10009Woo00<007ooOol0C7oo00<007ooOol0J7oo001_Ool00`00Oomoo`1dOol00`00Oomoo`0VOol0
0`00Oomoo`0TOol00`00Oomoo`0SOol4000VOol00`00Oomoo`1;Ool00`00Oomoo`1YOol006moo`03
001oogoo07Aoo`03001oogoo02Ioo`03001oogoo02Aoo`03001oogoo02=oo`<002Moo`03001oogoo
04]oo`03001oogoo06Uoo`00Kgoo00<007ooOol0M7oo00<007ooOol09Woo00<007ooOol097oo00<0
07ooOol08Woo10009goo00<007ooOol0Bgoo00<007ooOol0JGoo001^Ool00`00Oomoo`1dOol00`00
Oomoo`0WOol00`00Oomoo`0TOol00`00Oomoo`0ROol4000WOol00`00Oomoo`1:Ool00`00Oomoo`1Z
Ool006ioo`03001oogoo07Aoo`03001oogoo02Moo`03001oogoo02Aoo`03001oogoo025oo`@002Qo
o`03001oogoo04Yoo`03001oogoo06Yoo`00C7oo10007Goo00<007ooOol0;Woo1@00@Goo00<007oo
Ool00Woo20007Woo00<007ooOol097oo00<007ooOol08Goo100097oo2000BGoo00<007oo00001000
IWoo001;Ool00`00Oomoo`02Ool00`00Oomoo`0JOol00`00Oomoo`0`Ool00`00Oomoo`11Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`0LOol00`00Oomoo`0TOol3000POol4000VOol01000
Oomoo`000Woo00<007ooOol0AWoo00<007ooOol00Woo00<007ooOol0IWoo001:Ool00`00Oomoo`04
Ool00`00Oomoo`0HOol00`00Oomoo`0aOol00`00Oomoo`10Ool00`00Oomoo`05Ool00`00Oomoo`0Q
Ool00`00Oomoo`0TOol00`00Oomoo`0POol4000WOol00`00Ool0001;Ool00`00Oomoo`02Ool00`00
Oomoo`1VOol004Yoo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo02]oo`T0041oo`03001o
ogoo00Ioo`03001oogoo021oo`03001oogoo02Aoo`03001oogoo021oo`<002Uoo`8004Yoo`T006Io
o`00?Woo2@000goo00<007ooOol017oo00<007ooOol067oo00<007ooOol07goo2@0017oo00<007oo
Ool00Woo00<007ooOol0>Woo2@001goo00<007ooOol07goo00<007ooOol097oo00<007ooOol07goo
1000:Woo00<007ooOol0B7oo0P0017oo00<007ooOol0IWoo000nOol90003Ool00`00Oomoo`04Ool0
0`00Oomoo`0GOol00`00Oomoo`0POol90004Ool00`00Oomoo`02Ool00`00Oomoo`0jOol90008Ool0
0`00Oomoo`0NOol00`00Oomoo`0TOol00`00Oomoo`0OOol4000ZOol20019Ool20004Ool00`00Oomo
o`1VOol004Yoo`8000Aoo`03001oogoo01Qoo`03001oogoo02ioo`05001oogooOol00011Ool00`00
Oomoo`0:Ool00`00Oomoo`0MOol00`00Oomoo`0TOol00`00Oomoo`0NOol4000[Ool00`00Ool00018
Ool00`00Ool00003Ool00`00Oomoo`1VOol004Yoo`03001oo`0000<001Yoo`03001oogoo031oo`04
001oogoo0010Ool00`00Oomoo`0<Ool00`00Oomoo`0LOol00`00Oomoo`0TOol00`00Oomoo`0NOol4
000[Ool01000Oomoo`00AWoo00D007ooOomoo`00009oo`03001oogoo06Ioo`00Bgoo00<007ooOol0
77oo00<007ooOol0<7oo00@007ooOol0041oo`03001oogoo00aoo`03001oogoo01aoo`03001oogoo
02Aoo`03001oogoo01eoo`@002aoo`04001oogoo0016Ool01@00Oomoogoo00000Woo00<007ooOol0
IWoo001;Ool00`00Oomoo`0KOol00`00Oomoo`0bOol00`00Ool0000oOol00`00Oomoo`07Ool00`00
Oomoo`03Ool00`00Oomoo`0LOol00`00Oomoo`0TOol00`00Oomoo`0MOol4000YOol01000Oomoo`00
0Woo00<007ooOol0@goo00<007ooOol00goo00<007oo0000J7oo001<Ool2000KOol00`00Oomoo`0c
Ool2000oOol00`00Oomoo`07Ool20003Ool00`00Oomoo`0MOol00`00Oomoo`0TOol00`00Oomoo`0L
Ool4000ZOol2000017oo001oo`00AWoo00<007ooOol017oo0P00J7oo001>Ool4000FOol00`00Oomo
o`0dOol2000nOol00`00Oomoo`0:Ool3000POol00`00Oomoo`0TOol00`00Oomoo`0LOol4000/Ool3
0016Ool00`00Oomoo`05Ool2001XOol006Qoo`03001oogoo07Aoo`03001oogoo02eoo`03001oogoo
02Aoo`03001oogoo01aoo`<002ioo`03001oogoo04Aoo`03001oogoo071oo`00J7oo00<007ooOol0
M7oo00<007ooOol0;Goo00<007ooOol097oo00<007ooOol06goo1000;Woo00<007ooOol0A7oo00<0
07ooOol0L7oo001WOol00`00Oomoo`1dOol00`00Oomoo`0^Ool00`00Oomoo`0TOol00`00Oomoo`0K
Ool4000^Ool00`00Oomoo`13Ool00`00Oomoo`1aOol006Moo`03001oogoo07Aoo`03001oogoo02io
o`03001oogoo02Aoo`03001oogoo01Yoo`@002moo`03001oogoo04=oo`03001oogoo04moo`D001eo
o`00IWoo00<007ooOol0M7oo00<007ooOol0;goo00<007ooOol097oo00<007ooOol06Woo1000;goo
00<007ooOol0@Woo00<007ooOol0Cgoo00<007ooOol00goo0P006goo001VOol00`00Oomoo`1dOol0
0`00Oomoo`0_Ool00`00Oomoo`0TOol00`00Oomoo`0IOol4000`Ool00`00Oomoo`12Ool00`00Oomo
o`1?Ool00`00Oomoo`0POol006Eoo`03001oogoo07Aoo`03001oogoo031oo`03001oogoo02Aoo`03
001oogoo01Uoo`@0031oo`03001oogoo045oo`03001oogoo051oo`03001oogoo021oo`00IGoo00<0
07ooOol0M7oo00<007ooOol0<7oo00<007ooOol097oo00<007ooOol067oo1000<Goo00<007ooOol0
@Goo00<007ooOol0D7oo00<007ooOol087oo000DOooo003g000COol00`00Oomoo`0POol0021oo`03
001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo00Yoo`03
001oogoo015oo`03001oogoo015oo`03001oogoo011oo`03001oogoo015oo`03001oogoo015oo`03
001oogoo00Aoo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03
001oogoo011oo`03001oogoo015oo`03001oogoo00=oo`@000Yoo`03001oogoo015oo`03001oogoo
015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo
00Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo01eoo`03001oogoo021oo`0087oo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol017oo00<007ooOol02Woo00<0
07ooOol04Goo00<007ooOol04Goo00<007ooOol047oo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol017oo00<007ooOol02Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Goo00<0
07ooOol047oo00<007ooOol04Goo00<007ooOol00Woo10002goo00<007ooOol04Goo00<007ooOol0
4Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol0
2Woo00<007ooOol04Goo00<007ooOol04Goo00<007ooOol06goo20007Goo0018Ool00`00Oomoo`0G
Ool00`00Oomoo`0cOol00`00Oomoo`0nOol00`00Oomoo`0;Ool00`00Oomoo`1<Ool00`00Oomoo`0F
Ool4000cOol00`00Oomoo`0nOol00`00Oomoo`0;Ool00`00Oomoo`15Ool00`00Oomoo`0POol0069o
o`03001oogoo07Aoo`03001oogoo05Yoo`03001oogoo01Eoo`@007Eoo`03001oogoo05=oo`03001o
ogoo021oo`00HGoo00<007ooOol0M7oo00<007ooOol0Fgoo00<007ooOol05Goo1000M7oo00<007oo
Ool0E7oo00<007ooOol087oo001QOol00`00Oomoo`1dOol00`00Oomoo`1KOol00`00Oomoo`0DOol4
001eOol00`00Oomoo`1gOol0061oo`03001oogoo07Aoo`03001oogoo05aoo`03001oogoo01=oo`D0
07Aoo`03001oogoo07Qoo`00Ggoo00<007ooOol0M7oo00<007ooOol0GGoo00<007ooOol04goo1000
M7oo00<007ooOol0NGoo001OOol00`00Oomoo`1dOol00`00Oomoo`1MOol00`00Oomoo`0BOol4001e
Ool00`00Oomoo`1iOol005ioo`03001oogoo07Aoo`03001oogoo05ioo`03001oogoo019oo`@007Ao
o`03001oogoo07Yoo`00GWoo00<007ooOol0M7oo00<007ooOol0GWoo00<007ooOol04Goo1000MGoo
00<007ooOol0NWoo001MOol00`00Oomoo`1dOol00`00Oomoo`1OOol00`00Oomoo`0@Ool5001dOol0
0`00Oomoo`1kOol005aoo`03001oogoo07Aoo`03001oogoo061oo`03001oogoo011oo`@007Aoo`03
001oogoo07aoo`00G7oo00<007ooOol0M7oo00<007ooOol0H7oo00<007ooOol03goo1000MGoo00<0
07ooOol0O7oo001KOol00`00Oomoo`1dOol00`00Oomoo`1QOol00`00Oomoo`0?Ool4001dOol00`00
Oomoo`1mOol005Yoo`03001oogoo07Aoo`03001oogoo069oo`03001oogoo00ioo`@007Eoo`03001o
ogoo07eoo`00FGoo00<007ooOol0M7oo00<007ooOol0Hgoo00<007ooOol03Goo1@00M7oo00<007oo
Ool0OWoo001IOol00`00Oomoo`1dOol00`00Oomoo`1SOol00`00Oomoo`0=Ool4001dOol00`00Oomo
o`1oOol005Qoo`03001oogoo07Aoo`03001oogoo06Aoo`<000aoo`@007Eoo`03001oogoo07moo`00
Egoo00<007ooOol0M7oo00<007ooOol0IGoo00<007ooOol037oo1000M7oo00<007ooOol0P7oo001G
Ool00`00Oomoo`1dOol00`00Oomoo`1UOol00`00Oomoo`0;Ool4001eOol00`00Oomoo`20Ool005Io
o`03001oogoo07Aoo`03001oogoo06Ioo`03001oogoo00Yoo`D007Aoo`03001oogoo085oo`00EGoo
00<007ooOol0M7oo00<007ooOol0Igoo00<007ooOol02Goo1@00M7oo00<007ooOol0PWoo001DOol0
0`00Oomoo`1dOol00`00Oomoo`11Ool00`00Oomoo`0TOol00`00Oomoo`09Ool40010Ool00`00Oomo
o`0aOol00`00Oomoo`23Ool005Aoo`03001oogoo07Aoo`03001oogoo045oo`03001oogoo02Aoo`03
001oogoo00Qoo`@0045oo`03001oogoo035oo`03001oogoo08=oo`00Dgoo00<007ooOol0M7oo00<0
07ooOol0@Woo00<007ooOol097oo00<007ooOol01goo1@00@Goo00<007ooOol0<7oo00<007ooOol0
Q7oo001BOol00`00Oomoo`1dOol00`00Oomoo`13Ool00`00Oomoo`0TOol00`00Oomoo`07Ool40012
Ool00`00Oomoo`0_Ool00`00Oomoo`25Ool0059oo`03001oogoo07Aoo`03001oogoo04=oo`03001o
ogoo02Aoo`03001oogoo00Ioo`@004=oo`03001oogoo02moo`03001oogoo08Eoo`00DGoo00<007oo
Ool0M7oo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol01Goo1@00@goo00<007ooOol0;Woo
00<007ooOol0QWoo001@Ool00`00Oomoo`1dOol00`00Oomoo`15Ool00`00Oomoo`0TOol00`00Oomo
o`04Ool50014Ool00`00Oomoo`0]Ool00`00Oomoo`27Ool004moo`03001oogoo07Aoo`03001oogoo
04Ioo`03001oogoo02Aoo`03001oogoo00=oo`D004Eoo`03001oogoo02aoo`03001oogoo08Qoo`00
CWoo00<007ooOol0M7oo00<007ooOol0Agoo00<007ooOol097oo00@007ooOomoo`H004Ioo`03001o
ogoo02]oo`03001oogoo08Uoo`00C7oo0P00MWoo00<007ooOol0B7oo00<007ooOol097oo00<007oo
Ool01P00Agoo00<007ooOol0:Goo0P00S7oo001;Ool00`00Oomoo`1eOol00`00Oomoo`19Ool00`00
Oomoo`0TOol00`00Ool000050018Ool00`00Oomoo`0XOol00`00Oomoo`2<Ool004Yoo`03001oogoo
07Eoo`03001oogoo04Yoo`03001oogoo02Aoo`H004Yoo`03001oogoo02Moo`03001oogoo08eoo`00
BGoo00<007ooOol0MGoo00<007ooOol0Bgoo00<007ooOol097oo1@00Bgoo00<007ooOol09Woo00<0
07ooOol0SWoo0018Ool00`00Oomoo`1eOol00`00Oomoo`1<Ool00`00Oomoo`0SOol5001<Ool00`00
Oomoo`0UOol00`00Oomoo`2?Ool004Moo`03001oogoo07Eoo`03001oogoo04eoo`03001oogoo029o
o`D004eoo`03001oogoo02Aoo`03001oogoo091oo`00AWoo00<007ooOol0MGoo00<007ooOol0CWoo
00<007ooOol08Goo1@00CWoo00<007ooOol08goo00<007ooOol0TGoo0015Ool00`00Oomoo`1eOol0
0`00Oomoo`1?Ool00`00Oomoo`0POol5001?Ool00`00Oomoo`0ROol00`00Oomoo`2BOol004Aoo`03
001oogoo07Eoo`03001oogoo051oo`03001oogoo01ioo`L004moo`03001oogoo025oo`03001oogoo
09=oo`00@Woo0P00MWoo0P00Dgoo00<007ooOol07Goo1P0000=oo`00Ool0CWoo00<007ooOol07goo
0P00UWoo0011Ool00`00Oomoo`1eOol00`00Oomoo`1COol00`00Oomoo`0LOol60002Ool00`00Oomo
o`1=Ool00`00Oomoo`0NOol00`00Oomoo`2FOol0041oo`03001oogoo07Aoo`8005Ioo`03001oogoo
01]oo`D000Aoo`03001oogoo04eoo`03001oogoo01eoo`03001oogoo09Moo`00?goo00<007ooOol0
M7oo00<007ooOol0EWoo00<007ooOol06Goo1P001Goo00<007ooOol0CGoo00<007ooOol077oo00<0
07ooOol0V7oo000mOol2001eOol2001IOol00`00Oomoo`0GOol70006Ool00`00Oomoo`1=Ool00`00
Oomoo`0JOol2002KOol003]oo`8007Eoo`8005]oo`03001oogoo01Ioo`L000Moo`03001oogoo04eo
o`03001oogoo01Qoo`8009eoo`00>Woo00<007ooOol0M7oo00<007ooOol0Fgoo00<007ooOol057oo
1`002Goo00<007ooOol0CGoo00<007ooOol05goo00<007ooOol0WGoo000hOol2001eOol2001NOol0
0`00Oomoo`0COol6000;Ool00`00Oomoo`1=Ool00`00Oomoo`0EOol2002POol003Moo`03001oogoo
07Aoo`03001oogoo07=oo`H000aoo`03001oogoo06Aoo`03001oogoo0:1oo`00=Woo00<007ooOol0
M7oo00<007ooOol0Lgoo1@003Woo00<007ooOol0Hgoo00<007ooOol0XGoo000eOol00`00Oomoo`1d
Ool00`00Oomoo`1bOol6000?Ool00`00Oomoo`1ROol00`00Oomoo`2ROol003=oo`8007Eoo`80079o
o`P0011oo`03001oogoo061oo`800:Eoo`00<7oo0`00MGoo0P00LWoo2@004Goo00<007ooOol0GGoo
0`00Ygoo000^Ool2001fOol2001bOol9000COol00`00Oomoo`1KOol2002ZOol002aoo`8007Ioo`80
07=oo`L001Ioo`03001oogoo05Uoo`800:aoo`00:goo00<007ooOol0MGoo00<007ooOol0LGoo1`00
67oo0`00F7oo00<007ooOol0[7oo000YOol2001fOol2001aOol8000JOol00`00Oomoo`1FOol2002_
Ool002Ioo`<007Eoo`<0075oo`T001]oo`03001oogoo05=oo`<00;5oo`0097oo0P00MGoo0`00LGoo
2P007Goo00<007ooOol0DGoo0P00]7oo000QOol3001eOol2001cOol8000POol00`00Oomoo`1>Ool3
002fOol0021oo`03001oogoo07Eoo`03001oogoo07=oo`H0029oo`03001oogoo04eoo`03001oogoo
0;Moo`00ogoo3goo0`009Goo00<007ooOol0ogoo27oo003oOolgOol00`00Oomoo`3oOol8Ool00?mo
ocMoo`03001oogoo0?moo`Qoo`00ogoo=goo00<007ooOol0ogoo27oo003oOolgOol00`00Oomoo`3o
Ool8Ool00?moocMoo`03001oogoo0?moo`Qoo`00ogoo=goo00<007ooOol0ogoo27oo003oOol1Ool4
000017oo00000000;Woo00<007ooOol0E7oo0P000Woo0`00[7oo003oOol00`00Oomoo`02Ool2000P
Ool80008Ool00`00Oomoo`1EOol30003Ool2002ZOol00?ioo`03001oogoo00Aoo`03001oogoo01mo
o`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo05Eoo`8000Eoo`03001oogoo0:Qoo`00oWoo
00<007ooOol017oo00<007ooOol087oo00<007ooOol02goo00<007ooOol0EGoo00<007ooOol01Goo
00<007ooOol0Ygoo003oOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomo
o`0:Ool00`00Oomoo`1=Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`2WOol00?moo`5o
o`H000Uoo`03001oogoo01Qoo`03001oogoo00Uoo`D004]oo`03001oogoo00Eoo`03001oogoo00Eo
o`03001oogoo0:Moo`00ogoo1Woo00<007ooOol08goo00<007ooOol027oo00<007ooOol0EGoo0P00
1Goo00<007ooOol0Z7oo003oOol00`00Oomoo`02Ool2000VOol00`00Oomoo`07Ool00`00Oomoo`1E
Ool30003Ool2002ZOol00?moo`5oo`D002Qoo`03001oogoo00Ioo`03001oogoo05Eoo`03001oogoo
00<00:aoo`00ogoo;Woo00<007ooOol01Woo00<007ooOol0EGoo00<007ooOol0[goo003oOolXOol0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`1EOol00`00Oomoo`2_Ool00?moobQoo`8000=o
o`03001oogoo00Moo`03001oogoo05Eoo`03001oogoo0:moo`00ogoo:Woo0`002Woo00<007ooOol0
E7oo0P00/Goo003oOolgOol00`00Oomoo`3oOol8Ool00?mooomood9oo`00ogooogoo@Woo003oOooo
Oom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo
003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogoo
ogoo@Woo003oOoldOol00`00Oomoo`0>Ool00`00Oomoo`3iOol00?mooc=oo`03001oogoo011oo`03
001oogoo0?Qoo`00ogoo<goo00<007ooOol047oo00<007ooOol0n7oo003oOolbOol00`00Oomoo`0B
Ool00`00Oomoo`3gOol00?moob5oo`L000Yoo`03001oogoo00Ioo`D000Moo`03001oogoo0?Moo`00
ogoo8goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol00goo0P001Woo00<007ooOol0mWoo
003oOolSOol00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3fOol00?mo
ob=oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?Ioo`00ogoo8goo
00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0mWoo003oOolSOol00`00
Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3fOol00?moob=oo`03001oogoo
00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?Ioo`00ogoo8goo00<007ooOol02goo
00<007ooOol017oo200027oo00<007ooOol0mWoo003oOolQOol7000:Ool00`00Oomoo`05Ool00`00
Oomoo`0:Ool00`00Oomoo`3gOol00?moob=oo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
00Yoo`03001oogoo0?Moo`00ogoo8goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol02Goo
00<007ooOol0n7oo003oOolSOol2000>Ool00`00Oomoo`0@Ool00`00Oomoo`3hOol00?moobAoo`D0
00]oo`03001oogoo00ioo`03001oogoo0?Uoo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9o
o`00ogooogoo@Woo003oOoooOom2Ool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-7, -6, 0, 0}}],

Cell[TextData[{
  "Fig. 2.3 Periodic extension of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " defined on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ t \[LessEqual] \ b\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(-1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b = 2\)]],
  "."
}], "Caption",
  CellTags->"Fig. 2.3"],

Cell[TextData[{
  "\tSince ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\((p)\)\)]],
  " is periodic with period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", it can be represented by a Fourier series,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(
          t) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] c\_n\ \
\[ExponentialE]\^\(\(\ \)\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ \
t\)\)\)]],
  ","
}], "NE2",
  CellTags->"(2.2.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] = 2  \[Pi]/T\)]],
  ".  The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  " can be found using Eq. ",
  ButtonBox["( 2.1.33 )",
    ButtonData:>"(2.1.33)",
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\_n\  = \ \(1\/T\) \(\[Integral]\_a\%b\( f(
                t)\)\ \ \(\[ExponentialE]\^\(\(\ \ \)\(\[ImaginaryI]\ n\ \
\[CapitalDelta]\[Omega]\ t\)\)\) \[DifferentialD]t\)\)]],
  "."
}], "NE2",
  CellTags->"(2.2.3)"],

Cell["\<\
The function could also be represented by a Fourier sine-cosine \
series,\
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\^\((p)\)\)(
          t) = \[Sum]\+\(n = 0\)\%\[Infinity] a\_n\ \(cos(\ 
                n\ \[CapitalDelta]\[Omega]\ \ t)\) + \[Sum]\+\(n = 1\)\%\
\[Infinity] b\_n\ \(sin(\ n\ \[CapitalDelta]\[Omega]\ \ t)\)\)\(,\)\)\)]]
}], "Text"],

Cell["\<\
but usually the exponential form of the series is more \
convenient.\
\>", "Text"],

Cell[TextData[{
  "\tFor example, say that ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ t\^2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 1\)]],
  ". The Fourier coefficients are then "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[n_]\  = \ 
      Simplify[Integrate[t^2\ Exp[\ I\ 2\ Pi\ n\ t], {t, 0, 1}], 
        n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.29"],

Cell[BoxData[
    \(\(1 - \[ImaginaryI]\ n\ \[Pi]\)\/\(2\ n\^2\ \[Pi]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(c[0]\  = \ Integrate[t^2, {t, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.30"],

Cell[BoxData[
    \(1\/3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "-term approximant to the Fourier series for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " can then be constructed and plotted as in Cell ",
  ButtonBox["2.31",
    ButtonData:>"Cell 2.31",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f\_approx[x_, M_] := \ 
        Sum[c[n]\ Exp[\(-I\)\ 2\ Pi\ n\ t], {n, \(-M\), 
            M}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(func\  = \ f\_approx[t, 50];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Plot[func, {t, \(-2\), 2}, PlotRange \[Rule] {\(-0.2\), 1.2}, 
        PlotLabel \[Rule] \*"\"\<\!\(f\^\((p)\)\)(t) for f(t)=\!\(t\^2\) on \
0<t<1\>\""];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.31"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0882906 0.441453 [
[.02381 .07579 -6 -9 ]
[.02381 .07579 6 0 ]
[.2619 .07579 -6 -9 ]
[.2619 .07579 6 0 ]
[.7381 .07579 -3 -9 ]
[.7381 .07579 3 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .17658 -18 -4.5 ]
[.4875 .17658 0 4.5 ]
[.4875 .26487 -18 -4.5 ]
[.4875 .26487 0 4.5 ]
[.4875 .35316 -18 -4.5 ]
[.4875 .35316 0 4.5 ]
[.4875 .44145 -18 -4.5 ]
[.4875 .44145 0 4.5 ]
[.4875 .52974 -6 -4.5 ]
[.4875 .52974 0 4.5 ]
[.5 .63053 -83.4375 0 ]
[.5 .63053 83.4375 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .08829 m
.02381 .09454 L
s
[(-2)] .02381 .07579 0 1 Mshowa
.2619 .08829 m
.2619 .09454 L
s
[(-1)] .2619 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.5 0 m
.50625 0 L
s
[(-0.2)] .4875 0 1 0 Mshowa
.5 .17658 m
.50625 .17658 L
s
[(0.2)] .4875 .17658 1 0 Mshowa
.5 .26487 m
.50625 .26487 L
s
[(0.4)] .4875 .26487 1 0 Mshowa
.5 .35316 m
.50625 .35316 L
s
[(0.6)] .4875 .35316 1 0 Mshowa
.5 .44145 m
.50625 .44145 L
s
[(0.8)] .4875 .44145 1 0 Mshowa
.5 .52974 m
.50625 .52974 L
s
[(1)] .4875 .52974 1 0 Mshowa
.125 Mabswid
.5 .02207 m
.50375 .02207 L
s
.5 .04415 m
.50375 .04415 L
s
.5 .06622 m
.50375 .06622 L
s
.5 .11036 m
.50375 .11036 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .19865 m
.50375 .19865 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .2428 m
.50375 .2428 L
s
.5 .28694 m
.50375 .28694 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33109 m
.50375 .33109 L
s
.5 .37523 m
.50375 .37523 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .41938 m
.50375 .41938 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .50767 m
.50375 .50767 L
s
.5 .55182 m
.50375 .55182 L
s
.5 .57389 m
.50375 .57389 L
s
.5 .59596 m
.50375 .59596 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -144.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 9.438 moveto
(H) show
73.188 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.375 9.438 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
82.625 13.438 moveto
(H) show
88.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
94.625 13.438 moveto
(L) show
106.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
130.625 13.438 moveto
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
136.625 13.438 moveto
(H) show
142.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
148.625 13.438 moveto
(L) show
154.625 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
160.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
166.625 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
177.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(on) show
195.875 13.438 moveto
(0) show
201.875 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
207.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
213.875 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
219.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
225.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30812 m
.02499 .11705 L
.02605 .04947 L
.02729 .0807 L
.02846 .10978 L
.02954 .09476 L
.03053 .07571 L
.03163 .08041 L
.03279 .0979 L
.03395 .09577 L
.0352 .08167 L
.03638 .08488 L
.03746 .09559 L
.03873 .094 L
.03944 .08781 L
.04011 .0842 L
.04132 .08905 L
.04262 .09666 L
.04327 .09522 L
.04396 .0909 L
.04519 .08694 L
.04588 .08986 L
.04652 .09404 L
.04722 .09698 L
.04797 .09608 L
.04862 .0929 L
.04933 .08986 L
.05061 .09216 L
.05175 .09777 L
.05302 .0963 L
.05424 .09212 L
.05539 .09487 L
.0566 .09983 L
.05791 .09776 L
.05907 .09491 L
.06028 .09829 L
.06131 .10203 L
.06244 .10095 L
.06315 .09882 L
.06381 .09801 L
.06453 .09938 L
.06529 .10242 L
.06657 .10491 L
.06729 .1035 L
.06797 .10182 L
.06924 .1027 L
.0704 .10693 L
.07103 .10803 L
.07173 .10742 L
.073 .10505 L
Mistroke
.07376 .10582 L
.07448 .10822 L
.07514 .11047 L
.07583 .11152 L
.07659 .11076 L
.07728 .10942 L
.07803 .10906 L
.07885 .11088 L
.07954 .11335 L
.0802 .11504 L
.08096 .11521 L
.08166 .11414 L
.08291 .11355 L
.08362 .11534 L
.08427 .1176 L
.08544 .11961 L
.08669 .11812 L
.08787 .11866 L
.08896 .12208 L
.09016 .12421 L
.09148 .1229 L
.09214 .12288 L
.09285 .1243 L
.09413 .12827 L
.09483 .12917 L
.09548 .12883 L
.09618 .1281 L
.09695 .12826 L
.09824 .13179 L
.09895 .13379 L
.09961 .1345 L
.10085 .13365 L
.10153 .13371 L
.10218 .13494 L
.10333 .1386 L
.10458 .14018 L
.10581 .13944 L
.10694 .14104 L
.10802 .1445 L
.10916 .14626 L
.11422 .15263 L
.12446 .16636 L
.14288 .19866 L
.18095 .27982 L
.22148 .39503 L
.24019 .45687 L
.25005 .49576 L
.25128 .49083 L
.25245 .48429 L
.25309 .49024 L
Mistroke
.25379 .50356 L
.25502 .51878 L
.25573 .51152 L
.25649 .49679 L
.2572 .49098 L
.25785 .50213 L
.2585 .52778 L
.25921 .55529 L
.26049 .52152 L
.26119 .43402 L
.26183 .32111 L
.2626 .1843 L
.2633 .09289 L
.26404 .05106 L
.26474 .05645 L
.26547 .08419 L
.26627 .10732 L
.26691 .10839 L
.26761 .09526 L
.26829 .08022 L
.26903 .07411 L
.27035 .09087 L
.27158 .09951 L
.27283 .08597 L
.27353 .08066 L
.27419 .08235 L
.27488 .08919 L
.27551 .09525 L
.27624 .09712 L
.27692 .09318 L
.27814 .08434 L
.27927 .08789 L
.28051 .09627 L
.28182 .0925 L
.28307 .08677 L
.28421 .09139 L
.28552 .09716 L
.28677 .09259 L
.28793 .08945 L
.28899 .09376 L
.29016 .09831 L
.29141 .09499 L
.29208 .09255 L
.29278 .09235 L
.29356 .09521 L
.29426 .09857 L
.29555 .09931 L
.29627 .0968 L
.29695 .09505 L
.29822 .09758 L
Mistroke
.29937 .10196 L
.30001 .10214 L
.3007 .10046 L
.30196 .09803 L
.30319 .10159 L
.30431 .10491 L
.3056 .10293 L
.30683 .10155 L
.30796 .10504 L
.30901 .10795 L
.31016 .10668 L
.31139 .10508 L
.3121 .10649 L
.31274 .10883 L
.31345 .11098 L
.3142 .11144 L
.31546 .1093 L
.31618 .10911 L
.31684 .11056 L
.31807 .11459 L
.31923 .11501 L
.31987 .11393 L
.32057 .11324 L
.32179 .1156 L
.32309 .11934 L
.3243 .11882 L
.32496 .11795 L
.32564 .11807 L
.32639 .11984 L
.32708 .12217 L
.32775 .12383 L
.32847 .12414 L
.32977 .12277 L
.33056 .12335 L
.33131 .12545 L
.33198 .12763 L
.33271 .12905 L
.33393 .12842 L
.33523 .12855 L
.33643 .13211 L
.33756 .13445 L
.33824 .13429 L
.33888 .13369 L
.34009 .13448 L
.34139 .1385 L
.34213 .14 L
.34281 .14013 L
.3441 .13947 L
.34475 .14033 L
.34547 .14239 L
Mistroke
.34673 .14586 L
.3479 .14599 L
.34862 .14567 L
.34929 .14627 L
.35056 .14998 L
.35127 .15191 L
.35192 .15265 L
.35264 .15246 L
.3534 .15225 L
.35458 .15434 L
.35585 .15832 L
.35705 .15942 L
.35814 .15918 L
.35936 .16154 L
.36005 .16387 L
.36069 .16565 L
.36198 .16651 L
.36271 .16638 L
.36337 .16704 L
.36453 .17045 L
.36576 .17369 L
.36681 .174 L
.36797 .17448 L
.36921 .17803 L
.36989 .18025 L
.37054 .18155 L
.3718 .18184 L
.37295 .18299 L
.37404 .18648 L
.37519 .18961 L
.37618 .1901 L
.37727 .19057 L
.37844 .19376 L
.3797 .19773 L
.38089 .19866 L
.38198 .19921 L
.38326 .20286 L
.38446 .20664 L
.38554 .20757 L
.38671 .20822 L
.38799 .212 L
.38868 .21453 L
.38934 .21613 L
.39049 .21685 L
.39177 .21826 L
.39294 .22237 L
.39406 .22568 L
.39506 .22644 L
.39615 .22724 L
.39734 .23091 L
Mistroke
.3986 .23523 L
.3998 .23639 L
.40088 .23726 L
.40217 .24151 L
.40288 .24423 L
.40354 .24592 L
.40471 .24675 L
.40599 .2486 L
.40671 .25124 L
.40739 .25404 L
.40867 .25705 L
.41153 .26249 L
.42156 .28785 L
.4599 .39632 L
.47968 .45939 L
.48449 .47553 L
.4858 .47121 L
.48701 .48306 L
.48828 .49624 L
.48895 .49451 L
.48967 .488 L
.49047 .48413 L
.49122 .49082 L
.4919 .50384 L
.49263 .51637 L
.49332 .51793 L
.49405 .50731 L
.49535 .49127 L
.49667 .53083 L
.4979 .55896 L
.4986 .52063 L
.49924 .44025 L
.49994 .31942 L
.50069 .18564 L
.50198 .05509 L
.5032 .06946 L
.50429 .106 L
.50547 .10055 L
.50677 .07534 L
.50747 .07605 L
.50813 .08551 L
.50931 .09987 L
.51057 .09047 L
.51175 .08048 L
.51303 .08978 L
.51424 .09727 L
.51536 .09018 L
.51636 .08408 L
.51747 .08874 L
.51863 .09636 L
Mistroke
.51972 .09375 L
.521 .08693 L
.52172 .088 L
.52239 .09199 L
.52362 .09716 L
.52493 .09225 L
.52622 .0898 L
.52744 .09569 L
.52853 .09825 L
.52971 .09412 L
.531 .09263 L
.53174 .09566 L
.53243 .09883 L
.53315 .10008 L
.53382 .09878 L
.53459 .09605 L
.53531 .09492 L
.53657 .09876 L
.53723 .10138 L
.53795 .10228 L
.53917 .09931 L
.54046 .09862 L
.54167 .10317 L
.5428 .10487 L
.54404 .10206 L
.54474 .10139 L
.54537 .10251 L
.54664 .10709 L
.54736 .10805 L
.54803 .10721 L
.54925 .10503 L
.55054 .10771 L
.55164 .11115 L
.55281 .1107 L
.55393 .10898 L
.55494 .11057 L
.55613 .11451 L
.55743 .11486 L
.55865 .11324 L
.55979 .11528 L
.5611 .11922 L
.56184 .11951 L
.56252 .11864 L
.56377 .11811 L
.56508 .12187 L
.56627 .1242 L
.56737 .12322 L
.56858 .12322 L
.56988 .12706 L
.5706 .12882 L
Mistroke
.57127 .12914 L
.572 .12846 L
.57277 .12798 L
.57408 .1306 L
.57482 .13302 L
.57551 .13434 L
.57678 .13386 L
.57745 .13355 L
.57816 .13441 L
.57934 .13805 L
.58064 .14021 L
.60191 .16809 L
.62123 .20239 L
.6603 .29002 L
.68112 .34199 L
.70031 .39784 L
.71901 .45644 L
.72844 .48409 L
.72977 .49909 L
.73102 .51855 L
.73172 .51479 L
.73247 .50067 L
.73316 .49111 L
.7338 .49591 L
.73507 .54395 L
.73622 .55218 L
.73686 .50383 L
.73755 .40578 L
.7388 .18302 L
.74005 .05607 L
.74119 .06531 L
.7425 .10787 L
.74374 .09662 L
.74481 .07575 L
.74595 .08099 L
.7472 .09889 L
.74835 .09449 L
.74958 .08115 L
.75028 .08171 L
.75091 .08747 L
.75215 .09722 L
.75332 .09137 L
.75398 .08599 L
.75468 .08405 L
.75594 .09179 L
.75671 .09631 L
.75744 .09573 L
.75809 .09191 L
.7588 .08777 L
.76012 .08959 L
Mistroke
.76135 .0966 L
.76205 .09674 L
.76269 .09404 L
.76344 .09038 L
.76414 .08948 L
.76481 .09172 L
.76553 .09567 L
.76624 .0982 L
.76704 .0973 L
.76772 .09448 L
.76845 .0922 L
.76915 .09275 L
.76978 .09538 L
.771 .09998 L
.77213 .09801 L
.77337 .09491 L
.77407 .09624 L
.7747 .09892 L
.77598 .10231 L
.7767 .10103 L
.77737 .09901 L
.77859 .09871 L
.77989 .10358 L
.7811 .10461 L
.78241 .10158 L
.78366 .10315 L
.78481 .10729 L
.78596 .10753 L
.787 .10534 L
.78819 .10621 L
.78932 .11016 L
.79055 .11127 L
.79186 .10907 L
.79297 .11037 L
.79419 .11443 L
.79551 .11488 L
.79624 .11365 L
.79692 .11328 L
.79822 .11644 L
.79946 .11953 L
.80051 .1188 L
.80167 .11791 L
.80288 .12084 L
.80402 .12394 L
.80508 .12374 L
.80605 .12274 L
.80711 .12423 L
.80823 .12782 L
.80938 .12914 L
.81059 .12802 L
Mistroke
.81174 .1293 L
.81279 .13264 L
.81402 .13451 L
.81471 .13402 L
.81535 .13355 L
.81653 .13511 L
.81777 .139 L
.81898 .14014 L
.81967 .13962 L
.82031 .13948 L
.82147 .14179 L
.82271 .14551 L
.82382 .14617 L
.82486 .14567 L
.826 .14751 L
.82723 .15139 L
.82846 .15264 L
.82916 .15229 L
.8298 .15237 L
.83112 .15547 L
.83179 .15767 L
.83252 .15917 L
.83383 .15918 L
.83506 .16018 L
.83627 .16396 L
.83738 .1664 L
.8557 .1973 L
.89507 .27974 L
.93292 .38272 L
.95234 .4415 L
.95793 .46072 L
.96325 .48369 L
.96444 .49614 L
.96556 .49092 L
.96685 .48475 L
.96802 .50231 L
.96931 .51877 L
.97004 .51104 L
.97072 .49781 L
.97194 .49687 L
.97322 .54621 L
.97396 .56049 L
.97476 .52361 L
.97551 .42873 L
.97619 .30814 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo002jOol20007Ool30004Ool6003POol00;Uoo`04001oogoo0006Ool3
0005Ool01@00Oomoogoo0000h7oo002hOol00`00Oomoo`02Ool00`00Oomoo`03Ool30006Ool00`00
Oomoo`08Ool3003FOol00:moo`L0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Mo
o`03001oogoo0=Ioo`00^7oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol01Woo00<007oo
Ool0eWoo002hOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`3FOol0
0;Qoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo0=Ioo`00^Goo00@0
07ooOol000eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo0=Ioo`00^Woo0P003goo1000
27oo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo0P00egoo
003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00
Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol0
0=Moo`800=Moo`00egoo00<007ooOol0eWoo000ROol6001FOol5001DOol00`00Oomoo`1EOol5001E
Ool6000QOol0029oo`8000=oo`03001oogoo05=oo`04001oogoo001FOol00`00Oomoo`1GOol00`00
Oomoo`1FOol01@00Oomoogoo00008Goo000ROol00`00Ool0001HOol01000Oomoo`00EWoo0P00F7oo
00<007ooOol0Egoo00<007ooOol08Woo000IOol70002Ool01000Oomoo`00CWoo1`000Woo00@007oo
Ool005Ioo`8005Qoo`03001oo`0005Qoo`03001oogoo025oo`008Woo00D007ooOomoo`0005Ioo`04
001oogoo001FOol2001HOol00`00Ool0001IOol00`00Oomoo`0POol0029oo`03001oogoo009oo`03
001oogoo05=oo`04001oogoo001FOol2001HOol00`00Ool0001JOol00`00Oomoo`0OOol0029oo`03
001oogoo009oo`03001oogoo05=oo`04001oogoo001FOol2001HOol00`00Ool0001JOol00`00Oomo
o`0OOol0029oo`8000=oo`03001oogoo05=oo`@005Ioo`8005Ioo`<00003Ool007oo05Aoo`03001o
ogoo009oo`03001oogoo01moo`008Woo1@00EWoo00@007oo000005Ioo`8005Moo`800003Ool007oo
05Eoo`@0029oo`008Woo0P00FGoo0P00F7oo0P00FWoo00<007ooOol0NWoo000ROol3001HOol3001G
Ool200000goo001oo`1GOol2001kOol0029oo`<005Qoo`<005Moo`800003Ool007oo05Moo`8007]o
o`008Woo0`00F7oo0`0000=oo`00Ool0E7oo0P0000=oo`000000Egoo1000NGoo000ROol3000017oo
001oo`00E7oo0`0000=oo`00Ool0E7oo0P0000Eoo`00001oo`0005Eoo`@00003Ool007oo07Ioo`00
8Woo0`0000Aoo`00Ool005Aoo`H00003Ool007oo055oo`800005Ool00000Ool0001EOol400000goo
001oo`1fOol001Qoool0080001Uoo`008Goo2`0027oo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol03goo2`001goo00<007ooOol047oo00<007ooOol03goo00<007ooOol0
3goo00<007ooOol03goo2`001goo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03goo2`001goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol0
47oo00<007ooOol087oo000QOol500000goo001oo`05001>Ool=001>Ool300000goo00000007001>
Ool=001>Ool00`00Oomoo`0POol0029oo`@00003Ool007oo00D00003Ool007oo04aoo`800003Ool0
000000800003Ool007oo00@004aoo`<00006Ool00000Ool007oo1@00CWoo1@0000=oo`00Ool01P00
Kgoo000ROol40006Ool00`00Ool00003001;Ool200000goo001oo`05Ool00`00Ool00002001;Ool3
00000goo001oo`05Ool5001<Ool30007Ool5001^Ool0029oo`<000]oo`<004Yoo`8000]oo`@004Uo
o`<000Yoo`<00003Ool007oo04Uoo`8000Uoo`06001oo`00001oo`00K7oo000ROol2000>Ool30018
Ool2000=Ool40017Ool3000=Ool200000goo001oo`17Ool00`00Oomoo`0<Ool2001/Ool0029oo`80
00moo`8004Qoo`8000moo`8004Moo`<000moo`8004Qoo`03001oogoo00ioo`8006Yoo`008Woo0P00
3goo00@007oo000004Ioo`8000moo`04001oo`000015Ool2000@Ool200000goo001oo`15Ool00`00
Oomoo`0?Ool3001XOol0029oo`03001oogoo011oo`8004Ioo`03001oogoo011oo`8004Eoo`80019o
o`8004Ioo`03001oogoo011oo`8006Qoo`008Woo00<007ooOol04Woo0P00A7oo00<007ooOol04Woo
0P00@goo0P004goo0`00A7oo00<007ooOol04Goo0P00Igoo000ROol00`00Oomoo`0COol20013Ool0
0`00Oomoo`0COol30011Ool2000EOol20013Ool00`00Oomoo`0COol2001UOol0029oo`03001oogoo
01Aoo`80049oo`03001oogoo01Aoo`80045oo`8001Eoo`8004=oo`03001oogoo01=oo`<006Aoo`00
8Woo00<007ooOol05Goo0P00@Goo00<007ooOol05Goo0P00@7oo00<007ooOol05Woo0P00@7oo00<0
07ooOol05Woo0P00Hgoo000ROol00`00Oomoo`0FOol20010Ool00`00Oomoo`0EOol3000oOol00`00
Oomoo`0FOol20010Ool00`00Oomoo`0FOol2001SOol0029oo`03001oogoo01Moo`8003moo`03001o
ogoo01Moo`8003ioo`03001oogoo01Qoo`8003ioo`03001oogoo01Qoo`03001oogoo061oo`008Woo
00<007ooOol05goo0P00?goo00<007ooOol05goo0P00?Woo00<007ooOol067oo0P00?Woo00<007oo
Ool067oo0P00HGoo000ROol00`00Oomoo`0IOol2000mOol00`00Oomoo`0IOol2000lOol2000KOol2
000lOol00`00Oomoo`0IOol2001POol0029oo`03001oogoo01Uoo`8003eoo`03001oogoo01Uoo`80
03aoo`03001oogoo01Yoo`8003aoo`03001oogoo01Yoo`8005moo`008Woo00<007ooOol06goo00<0
07ooOol0>Woo00<007ooOol06goo00<007ooOol0>Goo00<007ooOol06goo00<007ooOol0>Woo00<0
07ooOol06goo00<007ooOol0GGoo000ROol00`00Oomoo`0KOol2000jOol00`00Oomoo`0LOol2000j
Ool00`00Oomoo`0LOol00`00Oomoo`0iOol00`00Oomoo`0LOol2001MOol0029oo`03001oogoo01eo
o`03001oogoo03Moo`03001oogoo01eoo`03001oogoo03Qoo`03001oogoo01aoo`03001oogoo03Uo
o`03001oogoo01eoo`03001oogoo05]oo`008Woo00<007ooOol07Goo00<007ooOol0=goo00<007oo
Ool07Woo0P00>7oo00<007ooOol07Goo00<007ooOol0>7oo00<007ooOol07Goo0P00G7oo000ROol0
0`00Oomoo`0MOol00`00Oomoo`0gOol00`00Oomoo`0OOol00`00Oomoo`0fOol00`00Oomoo`0NOol0
0`00Oomoo`0gOol00`00Oomoo`0NOol00`00Oomoo`1JOol0029oo`03001oogoo01ioo`03001oogoo
03Ioo`03001oogoo01moo`8003Moo`03001oogoo01moo`03001oogoo03Ioo`03001oogoo01moo`80
05Yoo`008Woo00<007ooOol07goo00<007ooOol0=Goo00<007ooOol087oo0P00=Woo0P008Goo00<0
07ooOol0=Goo00<007ooOol07goo0P00FWoo000ROol00`00Oomoo`0OOol00`00Oomoo`0eOol00`00
Oomoo`0QOol00`00Oomoo`0dOol00`00Oomoo`0POol00`00Oomoo`0eOol00`00Oomoo`0POol00`00
Oomoo`1HOol0029oo`03001oogoo021oo`03001oogoo03Aoo`03001oogoo025oo`8003Eoo`03001o
ogoo025oo`03001oogoo03Aoo`03001oogoo025oo`8005Qoo`008Woo00<007ooOol08Goo00<007oo
Ool0<goo00<007ooOol08Woo00<007ooOol0<goo00<007ooOol08Woo00<007ooOol0<goo00<007oo
Ool08Woo00<007ooOol0EWoo000ROol00`00Oomoo`0ROol00`00Oomoo`0bOol00`00Oomoo`0SOol0
0`00Oomoo`0bOol00`00Oomoo`0SOol00`00Oomoo`0bOol00`00Oomoo`0ROol00`00Oomoo`1FOol0
029oo`03001oogoo02=oo`03001oogoo035oo`03001oogoo02=oo`8003=oo`03001oogoo02Aoo`03
001oogoo035oo`03001oogoo02=oo`03001oogoo05Eoo`008Woo00<007ooOol08goo00<007ooOol0
<Goo00<007ooOol097oo00<007ooOol057oo0P001goo0`0017oo1P001goo00<007ooOol097oo00<0
07ooOol0<Goo00<007ooOol08goo00<007ooOol0EGoo000ROol00`00Oomoo`0TOol00`00Oomoo`0`
Ool00`00Oomoo`0TOol00`00Oomoo`0COol01000Oomoo`001Woo0`001Goo00D007ooOomoo`0000Mo
o`03001oogoo02Eoo`03001oogoo031oo`03001oogoo02Aoo`03001oogoo05Aoo`008Woo00<007oo
Ool097oo00<007ooOol0<7oo00<007ooOol09Goo0P004Woo00<007ooOol00Woo00<007ooOol00goo
0`001Woo00<007ooOol027oo00<007ooOol09Goo00<007ooOol0<7oo00<007ooOol097oo00<007oo
Ool0E7oo000ROol00`00Oomoo`0UOol00`00Oomoo`0_Ool00`00Oomoo`0VOol00`00Oomoo`0@Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool3000VOol00`00Oomoo`0_Ool00`00Oomo
o`0UOol00`00Oomoo`1COol0029oo`03001oogoo02Ioo`03001oogoo02ioo`03001oogoo02Ioo`03
001oogoo011oo`03001oogoo009oo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo02Ioo`03
001oogoo02moo`03001oogoo02Ioo`03001oogoo059oo`008Woo00<007ooOol09Woo00<007ooOol0
;Woo00<007ooOol09goo0P0047oo00<007ooOol00Woo00<007ooOol03goo00<007ooOol01Goo00<0
07ooOol09goo00<007ooOol0;Woo00<007ooOol09Woo00<007ooOol0DWoo000ROol00`00Oomoo`0W
Ool00`00Oomoo`0]Ool00`00Oomoo`0XOol00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`05Ool00`00Oomoo`0WOol00`00Oomoo`0^Ool00`00Oomoo`0WOol00`00Oomoo`1A
Ool0029oo`03001oogoo02Moo`03001oogoo02eoo`03001oogoo02Qoo`03001oogoo00moo`04001o
ogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`0]Ool00`00
Oomoo`0WOol00`00Oomoo`1AOol0029oo`03001oogoo02Qoo`03001oogoo02aoo`03001oogoo02Qo
o`80015oo`8000moo`@000Qoo`03001oogoo02Qoo`03001oogoo02eoo`03001oogoo02Qoo`03001o
ogoo051oo`008Woo00<007ooOol0:Goo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0:goo
00<007ooOol0:Goo00<007ooOol0;7oo00<007ooOol0:Goo00<007ooOol0Cgoo000ROol00`00Oomo
o`0YOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0YOol00`00Oomo
o`0/Ool00`00Oomoo`0YOol00`00Oomoo`1?Ool0029oo`03001oogoo02Yoo`03001oogoo02Yoo`03
001oogoo02Yoo`8002aoo`8002]oo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo04ioo`00
8Woo00<007ooOol0:Woo00<007ooOol0:Woo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0
:Woo00<007ooOol0:goo00<007ooOol0:Woo00<007ooOol0CWoo000ROol00`00Oomoo`0[Ool00`00
Oomoo`0YOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00Oomoo`0[Ool00`00Oomoo`0ZOol00`00
Oomoo`0[Ool00`00Oomoo`1=Ool0029oo`03001oogoo02]oo`03001oogoo02Uoo`03001oogoo02ao
o`03001oogoo02Uoo`03001oogoo02]oo`03001oogoo02Yoo`03001oogoo02]oo`03001oogoo04eo
o`008Woo00<007ooOol0;7oo00<007ooOol0:7oo00<007ooOol0;7oo0P00:Woo00<007ooOol0;7oo
00<007ooOol0:Goo00<007ooOol0;7oo00<007ooOol0C7oo000ROol00`00Oomoo`0/Ool00`00Oomo
o`0XOol00`00Oomoo`0]Ool00`00Oomoo`0XOol00`00Oomoo`0/Ool00`00Oomoo`0YOol00`00Oomo
o`0/Ool00`00Oomoo`1<Ool0025oo`03001oogoo02eoo`03001oogoo02Qoo`03001oogoo02ioo`03
001oogoo02Moo`03001oogoo02eoo`03001oogoo02Qoo`03001oogoo02eoo`03001oogoo04]oo`00
8Goo00<007ooOol0;Woo00<007ooOol09goo00<007ooOol0;Woo00<007ooOol09goo00<007ooOol0
;Goo00<007ooOol0:7oo00<007ooOol0;Goo00<007ooOol0Bgoo000QOol00`00Oomoo`0^Ool00`00
Oomoo`0WOol00`00Oomoo`0_Ool00`00Oomoo`0VOol00`00Oomoo`0^Ool00`00Oomoo`0WOol00`00
Oomoo`0^Ool00`00Oomoo`1:Ool0025oo`03001oogoo02moo`03001oogoo02Ioo`03001oogoo02mo
o`03001oogoo02Ioo`8002moo`03001oogoo02Moo`03001oogoo02ioo`03001oogoo04Yoo`008Goo
00<007ooOol0;goo00<007ooOol09Woo00<007ooOol0<7oo00<007ooOol09Goo00<007ooOol0;Woo
00<007ooOol09goo00<007ooOol0;goo00<007ooOol0BGoo000QOol00`00Oomoo`0`Ool00`00Oomo
o`0UOol00`00Oomoo`0`Ool00`00Oomoo`0UOol00`00Oomoo`0_Ool00`00Oomoo`0VOol00`00Oomo
o`0_Ool00`00Oomoo`19Ool0025oo`03001oogoo031oo`03001oogoo02Eoo`03001oogoo035oo`03
001oogoo02Aoo`03001oogoo02moo`03001oogoo02Ioo`03001oogoo031oo`03001oogoo04Qoo`00
8Goo00<007ooOol0<Goo00<007ooOol097oo00<007ooOol0<Goo00<007ooOol097oo00<007ooOol0
<7oo00<007ooOol09Goo00<007ooOol0<7oo00<007ooOol0B7oo000QOol00`00Oomoo`0aOol00`00
Oomoo`0TOol00`00Oomoo`0aOol00`00Oomoo`0TOol00`00Oomoo`0`Ool00`00Oomoo`0UOol00`00
Oomoo`0aOol00`00Oomoo`17Ool0025oo`03001oogoo039oo`03001oogoo02=oo`03001oogoo039o
o`03001oogoo02=oo`03001oogoo035oo`03001oogoo02Aoo`03001oogoo035oo`03001oogoo04Mo
o`008Goo00<007ooOol0<Woo00<007ooOol08goo00<007ooOol0<goo00<007ooOol08Woo00<007oo
Ool0<Goo00<007ooOol097oo00<007ooOol0<Woo00<007ooOol0AWoo000QOol00`00Oomoo`0bOol0
0`00Oomoo`0SOol00`00Oomoo`0cOol00`00Oomoo`0ROol2000cOol00`00Oomoo`0SOol00`00Oomo
o`0bOol00`00Oomoo`16Ool0025oo`03001oogoo03=oo`03001oogoo029oo`03001oogoo03=oo`80
02=oo`03001oogoo039oo`03001oogoo02=oo`03001oogoo039oo`03001oogoo04Ioo`008Goo00<0
07ooOol0<goo00<007ooOol08Woo00<007ooOol0=7oo00<007ooOol08Goo00<007ooOol0<goo00<0
07ooOol08Woo00<007ooOol0<goo00<007ooOol0AGoo000QOol00`00Oomoo`0dOol00`00Oomoo`0Q
Ool00`00Oomoo`0dOol00`00Oomoo`0QOol00`00Oomoo`0cOol00`00Oomoo`0ROol00`00Oomoo`0c
Ool00`00Oomoo`15Ool0025oo`03001oogoo03Aoo`03001oogoo025oo`03001oogoo03Eoo`03001o
ogoo021oo`03001oogoo03=oo`03001oogoo029oo`03001oogoo03Aoo`03001oogoo04Aoo`008Goo
00<007ooOol0=Goo00<007ooOol087oo00<007ooOol0=Goo00<007ooOol087oo00<007ooOol0=7oo
00<007ooOol08Goo00<007ooOol0=7oo00<007ooOol0A7oo000QOol00`00Oomoo`0eOol00`00Oomo
o`0POol00`00Oomoo`0eOol00`00Oomoo`03Ool20007Ool30007Ool30007Ool00`00Oomoo`0dOol0
0`00Oomoo`0QOol00`00Oomoo`0eOol00`00Oomoo`13Ool0025oo`03001oogoo03Ioo`03001oogoo
01moo`03001oogoo03Ioo`05001oogooOol00002Ool00`00Oomoo`04Ool30008Ool00`00Oomoo`06
Ool00`00Oomoo`0eOol00`00Oomoo`0POol00`00Oomoo`0eOol00`00Oomoo`13Ool0025oo`03001o
ogoo03Ioo`03001oogoo01moo`03001oogoo03Ioo`04001oogoo0004Ool00`00Oomoo`03Ool30004
Ool60007Ool3000eOol00`00Oomoo`0POol00`00Oomoo`0fOol00`00Oomoo`12Ool0025oo`03001o
ogoo03Moo`03001oogoo01ioo`03001oogoo03Moo`03001oo`0000Aoo`03001oogoo00Yoo`05001o
ogooOol00008Ool00`00Oomoo`0fOol00`00Oomoo`0OOol00`00Oomoo`0fOol00`00Oomoo`12Ool0
025oo`03001oogoo03Moo`03001oogoo01ioo`03001oogoo03Moo`03001oo`0000Aoo`03001oogoo
00]oo`04001oogoo0008Ool00`00Oomoo`0fOol00`00Oomoo`0OOol00`00Oomoo`0gOol00`00Oomo
o`11Ool0025oo`03001oogoo03Moo`03001oogoo01ioo`03001oogoo03Moo`03001oo`0000Aoo`03
001oogoo00aoo`03001oo`0000Qoo`03001oogoo03Moo`03001oogoo01ioo`03001oogoo03Moo`03
001oogoo045oo`008Goo00<007ooOol0>7oo00<007ooOol07Goo00<007ooOol0>7oo0P0017oo00<0
07ooOol037oo00<007oo000027oo00<007ooOol0=goo00<007ooOol07Woo00<007ooOol0>7oo00<0
07ooOol0@7oo000QOol00`00Oomoo`0hOol00`00Oomoo`0MOol00`00Oomoo`0hOol00`00Ool00002
Ool00`00Oomoo`0>Ool20008Ool00`00Oomoo`0hOol00`00Oomoo`0MOol00`00Oomoo`0hOol00`00
Oomoo`10Ool0025oo`03001oogoo03Uoo`03001oogoo01aoo`03001oogoo03Uoo`04001oo`00000B
Ool00`00Oomoo`06Ool00`00Oomoo`0hOol00`00Oomoo`0MOol00`00Oomoo`0iOol00`00Oomoo`0o
Ool0025oo`03001oogoo03Uoo`03001oogoo01aoo`03001oogoo03Uoo`03001oogoo01aoo`03001o
ogoo03Qoo`03001oogoo01eoo`03001oogoo03Uoo`03001oogoo03moo`008Goo00<007ooOol0>Woo
00<007ooOol06goo00<007ooOol0>Goo00<007ooOol077oo00<007ooOol0>Goo00<007ooOol077oo
00<007ooOol0>Woo00<007ooOol0?Woo000QOol00`00Oomoo`0jOol00`00Oomoo`0KOol00`00Oomo
o`0jOol00`00Oomoo`0KOol2000jOol00`00Oomoo`0LOol00`00Oomoo`0jOol00`00Oomoo`0nOol0
025oo`03001oogoo03Yoo`03001oogoo01]oo`03001oogoo03Yoo`03001oogoo01]oo`03001oogoo
03Yoo`03001oogoo01]oo`03001oogoo03Yoo`03001oogoo03ioo`008Goo00<007ooOol0>goo00<0
07ooOol06Woo00<007ooOol0>goo00<007ooOol06Woo00<007ooOol0>Woo00<007ooOol06goo00<0
07ooOol0>goo00<007ooOol0?Goo000QOol00`00Oomoo`0kOol00`00Oomoo`0JOol00`00Oomoo`0k
Ool00`00Oomoo`0JOol00`00Oomoo`0kOol00`00Oomoo`0JOol00`00Oomoo`0kOol00`00Oomoo`0m
Ool0025oo`03001oogoo03]oo`03001oogoo01Yoo`03001oogoo03]oo`03001oogoo01Yoo`03001o
ogoo03]oo`03001oogoo01Yoo`03001oogoo03]oo`03001oogoo03eoo`008Goo00<007ooOol0?7oo
00<007ooOol06Goo00<007ooOol0?7oo00<007ooOol06Goo00<007ooOol0>goo00<007ooOol06Woo
00<007ooOol0?7oo00<007ooOol0?7oo000QOol00`00Oomoo`0lOol00`00Oomoo`0IOol00`00Oomo
o`0lOol00`00Oomoo`0IOol00`00Oomoo`0lOol00`00Oomoo`0IOol00`00Oomoo`0lOol00`00Oomo
o`0lOol0025oo`03001oogoo03aoo`03001oogoo01Uoo`03001oogoo03aoo`03001oogoo01Uoo`03
001oogoo03aoo`03001oogoo01Uoo`03001oogoo03aoo`03001oogoo03aoo`008Goo00<007ooOol0
?Goo00<007ooOol067oo00<007ooOol0?Goo00<007ooOol067oo0P00?Woo00<007ooOol067oo00<0
07ooOol0?Goo00<007ooOol067oo00<007ooOol087oo001QOol00`00Oomoo`0HOol00`00Oomoo`0m
Ool00`00Oomoo`0HOol00`00Oomoo`0mOol00`00Oomoo`0HOol00`00Oomoo`0mOol00`00Oomoo`0H
Ool00`00Oomoo`0POol0069oo`03001oogoo01Moo`03001oogoo03eoo`03001oogoo01Qoo`03001o
ogoo03eoo`03001oogoo01Qoo`03001oogoo03eoo`03001oogoo01Qoo`03001oogoo021oo`00HWoo
00<007ooOol05goo00<007ooOol0?Woo00<007ooOol05goo00<007ooOol0?Woo00<007ooOol05goo
00<007ooOol0?Woo00<007ooOol05goo00<007ooOol087oo001ROol00`00Oomoo`0GOol00`00Oomo
o`0nOol00`00Oomoo`0GOol00`00Oomoo`0nOol00`00Oomoo`0GOol00`00Oomoo`0nOol00`00Oomo
o`0GOol00`00Oomoo`0POol006=oo`03001oogoo01Ioo`03001oogoo03ioo`03001oogoo01Moo`03
001oogoo03moo`03001oogoo01Ioo`03001oogoo03moo`03001oogoo01Ioo`03001oogoo021oo`00
Hgoo00<007ooOol05Woo00<007ooOol0?goo00<007ooOol05Woo00<007ooOol0?goo00<007ooOol0
5Woo00<007ooOol0?goo00<007ooOol05Woo00<007ooOol087oo001SOol00`00Oomoo`0FOol00`00
Oomoo`0oOol00`00Oomoo`0FOol00`00Oomoo`0oOol00`00Oomoo`0FOol00`00Oomoo`0oOol00`00
Oomoo`0FOol00`00Oomoo`0POol006Aoo`03001oogoo01Eoo`03001oogoo041oo`03001oogoo01Eo
o`03001oogoo041oo`03001oogoo01Eoo`03001oogoo041oo`03001oogoo01Eoo`03001oogoo021o
o`00I7oo00<007ooOol05Goo00<007ooOol0@7oo00<007ooOol05Goo0P00@Goo00<007ooOol05Goo
00<007ooOol0@7oo00<007ooOol05Goo00<007ooOol087oo001TOol00`00Oomoo`0EOol00`00Oomo
o`10Ool00`00Oomoo`0EOol00`00Oomoo`11Ool00`00Oomoo`0DOol00`00Oomoo`10Ool00`00Oomo
o`0EOol00`00Oomoo`0POol006Eoo`03001oogoo01Aoo`03001oogoo045oo`03001oogoo01Aoo`03
001oogoo045oo`03001oogoo01Aoo`03001oogoo045oo`03001oogoo01Aoo`03001oogoo021oo`00
IGoo00<007ooOol057oo00<007ooOol0@Goo00<007ooOol057oo00<007ooOol0@Goo00<007ooOol0
57oo00<007ooOol0@Goo00<007ooOol057oo00<007ooOol087oo001VOol00`00Oomoo`0COol00`00
Oomoo`11Ool00`00Oomoo`0DOol00`00Oomoo`12Ool00`00Oomoo`0COol00`00Oomoo`11Ool00`00
Oomoo`0DOol00`00Oomoo`0POol006Ioo`03001oogoo01=oo`03001oogoo049oo`03001oogoo01=o
o`03001oogoo049oo`03001oogoo01=oo`03001oogoo049oo`03001oogoo01=oo`03001oogoo021o
o`00IWoo00<007ooOol04goo00<007ooOol0>goo0P001Goo00<007oo00000P001Goo100027oo00<0
07ooOol0@goo00<007ooOol04Woo00<007ooOol0@Woo00<007ooOol04goo00<007ooOol087oo001W
Ool00`00Oomoo`0BOol00`00Oomoo`0jOol01000Oomoo`0017oo00<007oo00000P0017oo00<007oo
Ool00Woo00<007ooOol01Goo00<007ooOol0@goo00<007ooOol04Woo00<007ooOol0@goo00<007oo
Ool04Woo00<007ooOol087oo001WOol00`00Oomoo`0BOol00`00Oomoo`0iOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool40004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30013Ool00`00Oomoo`0BOol0
0`00Oomoo`13Ool00`00Oomoo`0BOol00`00Oomoo`0POol006Moo`03001oogoo019oo`03001oogoo
03Uoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo
00Eoo`03001oogoo04Aoo`03001oogoo015oo`03001oogoo04=oo`03001oogoo019oo`03001oogoo
021oo`00J7oo00<007ooOol04Goo00<007ooOol0>Goo00<007ooOol00Woo00<007ooOol00Woo00<0
07ooOol01Goo0P000goo00<007ooOol01Goo00<007ooOol0A7oo00<007ooOol04Goo00<007ooOol0
A7oo00<007ooOol04Goo00<007ooOol087oo001XOol00`00Oomoo`0AOol00`00Oomoo`0iOol00`00
Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Ool000020008Ool00`00Oomoo`14Ool0
0`00Oomoo`0AOol00`00Oomoo`14Ool00`00Oomoo`0AOol00`00Oomoo`0POol006Qoo`03001oogoo
015oo`03001oogoo03Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo
00Uoo`03001oogoo04Eoo`03001oogoo011oo`03001oogoo04Aoo`03001oogoo015oo`03001oogoo
021oo`00JGoo00<007ooOol047oo00<007ooOol0>Woo00@007ooOol000Moo`03001oogoo00Aoo`80
00Yoo`03001oogoo04Eoo`03001oogoo011oo`03001oogoo04Eoo`03001oogoo011oo`03001oogoo
021oo`00JGoo00<007ooOol047oo00<007ooOol0>goo0P0027oo00<007ooOol01Woo0`001goo00<0
07ooOol0AGoo00<007ooOol047oo00<007ooOol0AGoo00<007ooOol047oo00<007ooOol087oo001Z
Ool00`00Oomoo`0?Ool00`00Oomoo`15Ool00`00Oomoo`0@Ool00`00Oomoo`16Ool00`00Oomoo`0?
Ool00`00Oomoo`15Ool00`00Oomoo`0?Ool00`00Oomoo`0QOol006Yoo`03001oogoo00moo`03001o
ogoo04Ioo`03001oogoo00moo`8004Moo`03001oogoo00moo`03001oogoo04Ioo`03001oogoo00io
o`03001oogoo025oo`00JWoo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol03goo00<007oo
Ool0AWoo00<007ooOol03goo00<007ooOol0AWoo00<007ooOol03Woo00<007ooOol08Goo001[Ool0
0`00Oomoo`0>Ool00`00Oomoo`16Ool00`00Oomoo`0?Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool0
0`00Oomoo`16Ool00`00Oomoo`0>Ool00`00Oomoo`0QOol006]oo`03001oogoo00ioo`03001oogoo
04Moo`03001oogoo00ioo`03001oogoo04Moo`03001oogoo00ioo`03001oogoo04Moo`03001oogoo
00eoo`03001oogoo025oo`00Jgoo00<007ooOol03Woo00<007ooOol0Agoo00<007ooOol03Woo00<0
07ooOol0Agoo00<007ooOol03Woo00<007ooOol0Agoo00<007ooOol03Goo00<007ooOol08Goo001/
Ool00`00Oomoo`0=Ool00`00Oomoo`17Ool00`00Oomoo`0>Ool00`00Oomoo`18Ool00`00Oomoo`0=
Ool00`00Oomoo`18Ool00`00Oomoo`0<Ool00`00Oomoo`0QOol006aoo`03001oogoo00eoo`03001o
ogoo04Qoo`03001oogoo00eoo`03001oogoo04Qoo`03001oogoo00eoo`03001oogoo04Qoo`03001o
ogoo00aoo`03001oogoo025oo`00K7oo00<007ooOol03Goo00<007ooOol0B7oo00<007ooOol03Goo
00<007ooOol0B7oo00<007ooOol03Goo00<007ooOol0B7oo00<007ooOol037oo00<007ooOol08Goo
001]Ool00`00Oomoo`0<Ool00`00Oomoo`18Ool00`00Oomoo`0=Ool00`00Oomoo`19Ool00`00Oomo
o`0<Ool00`00Oomoo`19Ool00`00Oomoo`0;Ool00`00Oomoo`0QOol006eoo`03001oogoo00aoo`03
001oogoo04Uoo`03001oogoo00aoo`8004Yoo`03001oogoo00aoo`03001oogoo04Uoo`03001oogoo
00]oo`03001oogoo025oo`00KGoo00<007ooOol037oo00<007ooOol0BGoo00<007ooOol037oo00<0
07ooOol0BGoo00<007ooOol037oo00<007ooOol0BGoo00<007ooOol02goo00<007ooOol08Goo001^
Ool00`00Oomoo`0;Ool00`00Oomoo`19Ool00`00Oomoo`0<Ool00`00Oomoo`1:Ool00`00Oomoo`0;
Ool00`00Oomoo`1:Ool00`00Oomoo`0:Ool00`00Oomoo`0QOol006ioo`03001oogoo00]oo`03001o
ogoo04Yoo`03001oogoo00]oo`03001oogoo04Yoo`03001oogoo00]oo`03001oogoo04Yoo`03001o
ogoo00Yoo`03001oogoo025oo`00KWoo00<007ooOol02goo00<007ooOol0BWoo00<007ooOol02goo
00<007ooOol0BWoo00<007ooOol02goo00<007ooOol0BWoo00<007ooOol02Woo00<007ooOol08Goo
001_Ool00`00Oomoo`0:Ool00`00Oomoo`1:Ool00`00Oomoo`0;Ool00`00Oomoo`1;Ool00`00Oomo
o`0:Ool00`00Oomoo`1;Ool00`00Oomoo`09Ool00`00Oomoo`0QOol006moo`03001oogoo00Yoo`03
001oogoo04]oo`03001oogoo00Yoo`03001oogoo04]oo`03001oogoo00Yoo`03001oogoo04]oo`03
001oogoo00Uoo`03001oogoo025oo`00Kgoo00<007ooOol02Woo00<007ooOol0Bgoo00<007ooOol0
2Woo00<007ooOol0Bgoo00<007ooOol02Woo00<007ooOol0Bgoo00<007ooOol02Goo00<007ooOol0
8Goo001_Ool00`00Oomoo`0:Ool00`00Oomoo`1;Ool00`00Oomoo`0:Ool2001=Ool00`00Oomoo`09
Ool00`00Oomoo`1<Ool00`00Oomoo`08Ool00`00Oomoo`0QOol0071oo`03001oogoo00Uoo`03001o
ogoo04]oo`03001oogoo00Yoo`03001oogoo04aoo`03001oogoo00Uoo`03001oogoo04aoo`03001o
ogoo00Qoo`03001oogoo025oo`00L7oo00<007ooOol02Goo00<007ooOol0C7oo00<007ooOol02Goo
00<007ooOol0C7oo00<007ooOol02Goo00<007ooOol0C7oo00<007ooOol027oo00<007ooOol08Goo
001`Ool00`00Oomoo`09Ool00`00Oomoo`1<Ool00`00Oomoo`09Ool00`00Oomoo`1=Ool00`00Oomo
o`08Ool00`00Oomoo`1=Ool00`00Oomoo`07Ool00`00Oomoo`0QOol0075oo`03001oogoo00Qoo`03
001oogoo04aoo`03001oogoo00Uoo`03001oogoo04eoo`03001oogoo00Qoo`03001oogoo04eoo`03
001oogoo00Moo`03001oogoo025oo`00LGoo00<007ooOol027oo00<007ooOol0CGoo00<007ooOol0
27oo00<007ooOol0CWoo00<007ooOol01goo00<007ooOol0CGoo00<007ooOol01goo00<007ooOol0
8Goo001aOol00`00Oomoo`08Ool00`00Oomoo`0kOol20007Ool30005Ool40008Ool00`00Oomoo`1>
Ool00`00Oomoo`07Ool00`00Oomoo`1>Ool00`00Oomoo`06Ool00`00Oomoo`0QOol0079oo`03001o
ogoo00Moo`03001oogoo03Yoo`04001oogoo0006Ool30004Ool00`00Ool00002Ool00`00Oomoo`05
Ool00`00Oomoo`1>Ool00`00Oomoo`07Ool00`00Oomoo`1>Ool00`00Oomoo`06Ool00`00Oomoo`0Q
Ool0079oo`03001oogoo00Moo`03001oogoo03Uoo`03001oogoo009oo`03001oogoo00=oo`<000Ao
o`06001oogoo001oo`001goo00<007ooOol0Cgoo00<007ooOol01Woo00<007ooOol0CWoo00<007oo
Ool01Woo00<007ooOol08Goo001bOol00`00Oomoo`07Ool00`00Oomoo`0iOol00`00Oomoo`02Ool0
0`00Oomoo`0:Ool01P00Oomoo`00Ool000Moo`<004moo`03001oogoo00Ioo`03001oogoo04moo`03
001oogoo00Eoo`03001oogoo025oo`00LWoo00<007ooOol01goo00<007ooOol0>Goo00<007ooOol0
0Woo00<007ooOol02goo100027oo00<007ooOol0Cgoo00<007ooOol01Woo00<007ooOol0Cgoo00<0
07ooOol01Goo00<007ooOol08Goo001cOol00`00Oomoo`06Ool00`00Oomoo`0iOol00`00Oomoo`02
Ool00`00Oomoo`0:Ool01P00Oomoo`00Ool000Moo`03001oogoo051oo`03001oogoo00Eoo`03001o
ogoo04moo`03001oogoo00Eoo`03001oogoo025oo`00Lgoo00<007ooOol01Woo00<007ooOol0>Goo
00<007ooOol00Woo00<007ooOol02Woo00@007ooOomoo`8000Moo`03001oogoo051oo`03001oogoo
00Eoo`03001oogoo051oo`03001oogoo00Aoo`03001oogoo025oo`00Lgoo00<007ooOol01Woo00<0
07ooOol0>Woo00@007ooOol000eoo`04001oogooOol20007Ool00`00Oomoo`1@Ool00`00Oomoo`05
Ool00`00Oomoo`1@Ool00`00Oomoo`04Ool00`00Oomoo`0QOol007Aoo`03001oogoo00Eoo`03001o
ogoo03]oo`8000moo`@000Qoo`03001oogoo055oo`03001oogoo00Aoo`03001oogoo051oo`03001o
ogoo00Aoo`03001oogoo025oo`00M7oo00<007ooOol01Goo00<007ooOol0D7oo00<007ooOol01Goo
00<007ooOol0DGoo00<007ooOol00goo00<007ooOol0DWoo00<007ooOol00goo00<007ooOol08Goo
001dOol00`00Oomoo`05Ool00`00Oomoo`1@Ool00`00Oomoo`05Ool00`00Oomoo`1AOol00`00Oomo
o`03Ool00`00Oomoo`1BOol00`00Oomoo`03Ool00`00Oomoo`0QOol007Aoo`03001oogoo00Eoo`03
001oogoo051oo`03001oogoo00Eoo`8005=oo`03001oogoo009oo`03001oogoo059oo`03001oogoo
00=oo`03001oogoo025oo`00MGoo00<007ooOol017oo00<007ooOol0DGoo00<007ooOol017oo00<0
07ooOol0DWoo00<007ooOol00Woo00<007ooOol0DWoo00<007ooOol00goo00<007ooOol08Goo001e
Ool00`00Oomoo`04Ool00`00Oomoo`1AOol00`00Oomoo`04Ool00`00Oomoo`1BOol00`00Oomoo`02
Ool00`00Oomoo`1COol00`00Oomoo`02Ool00`00Oomoo`0QOol007Eoo`03001oogoo00Aoo`03001o
ogoo055oo`03001oo`0000Aoo`03001oogoo05=oo`05001oogooOol0001EOol00`00Oomoo`02Ool0
0`00Oomoo`0QOol007Ioo`03001oogoo00=oo`03001oogoo059oo`8000Aoo`03001oogoo05=oo`05
001oogooOol0001EOol00`00Oomoo`02Ool00`00Oomoo`0QOol007Ioo`03001oogoo00=oo`03001o
ogoo059oo`8000Aoo`03001oogoo05=oo`05001oogooOol0001EOol00`00Oomoo`02Ool00`00Oomo
o`0QOol007Ioo`03001oogoo00=oo`03001oogoo05=oo`03001oogoo009oo`03001oogoo05=oo`05
001oogooOol0001EOol00`00Oomoo`02Ool00`00Oomoo`0QOol007Ioo`03001oogoo00=oo`03001o
ogoo05=oo`04001oogooOol2001FOol01000Oomoo`00EWoo00D007ooOomoo`0002=oo`00Mgoo00<0
07oo00000Woo00<007ooOol0Dgoo0P000Woo0P00EWoo00@007ooOol005Ioo`80009oo`03001oogoo
025oo`00Mgoo00<007oo00000Woo00<007ooOol0Dgoo0P000Woo0`00EGoo00@007ooOol005Ioo`80
009oo`03001oogoo025oo`00Mgoo0`000Woo00<007ooOol0Dgoo0`0000=oo`000000EWoo00@007oo
Ool005Ioo`80009oo`03001oogoo025oo`00N7oo0`0000=oo`00Ool0EGoo1@00EWoo00@007oo0000
05Ioo`80009oo`03001oogoo025oo`00N7oo0`0000=oo`00Ool0EGoo1@00Egoo0`00EWoo0P000Woo
00<007ooOol08Goo001iOol200000goo001oo`1EOol5001GOol3001FOol200000goo0000000SOol0
07Uoo`@005Moo`@005Moo`<005Moo`04001oo`00000SOol007Uoo`@005Moo`@005Moo`<005Moo`04
001oo`00000SOol007Uoo`@005Moo`@005Moo`<005Moo`@002=oo`00NGoo1000Egoo1@00EWoo0`00
Egoo10008goo001iOol4001GOol4001GOol3001GOol4000SOol007Yoo`<005Moo`@005Moo`<005Qo
o`<002=oo`00NWoo0`00Egoo00@007oo000005Moo`<005Qoo`<002=oo`00NWoo0`00Egoo00@007oo
000005Moo`<005Qoo`<002=oo`00Ngoo0P00FGoo0P00F7oo0P00FGoo0P008goo001kOol2001>Ool5
0006Ool2001IOol00`00Oomoo`1GOol2000SOol007]oo`80051oo`03001oogoo00Ioo`8005Uoo`03
001oogoo05Moo`8002=oo`00Ngoo0P00D7oo00<007ooOol01Woo1000Egoo00<007ooOol0Egoo0P00
8goo001kOol2001@Ool00`00Oomoo`06Ool2001IOol00`00Oomoo`1GOol2000SOol007]oo`80051o
o`03001oogoo00Ioo`8005Uoo`03001oogoo05Moo`8002=oo`00Ngoo0P00D7oo00<007ooOol01Woo
0P00FGoo00<007ooOol0Egoo0P008goo001kOol00`00Oomoo`1?Ool00`00Oomoo`06Ool2001IOol0
0`00Oomoo`1GOol2000SOol007]oo`03001oogoo04eoo`<000Qoo`8005Uoo`03001oogoo05Moo`80
02=oo`00Ngoo00<007ooOol0CWoo0P0027oo0P00FGoo00<007ooOol0Egoo0P008goo001kOol00`00
Oomoo`1HOol2001IOol00`00Oomoo`1GOol2000SOol007]oo`03001oogoo05Qoo`8005Uoo`03001o
ogoo05Moo`8002=oo`00Ngoo00<007ooOol0F7oo0`00F7oo00<007ooOol0Egoo0P008goo001kOol0
0`00Oomoo`1HOol2002dOol00`00Oomoo`0QOol00=Ioo`800;Aoo`03001oogoo025oo`00eWoo0P00
]7oo00<007ooOol08Goo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007oo
Ool0eWoo003GOol00`00Oomoo`3FOol00=Moo`800=Moo`00egoo00<007ooOol0eWoo003GOol00`00
Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol0
0=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`800=Mo
o`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<0
07ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo
003GOol00`00Oomoo`3FOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003o
OonaOol0081oo`03001oogoo00]oo`03001oogoo041oo`03001oogoo00]oo`03001oogoo0<ioo`00
Ogoo00<007ooOol03Goo00<007ooOol0?Woo00<007ooOol03Goo00<007ooOol0cGoo001oOol00`00
Oomoo`0=Ool00`00Oomoo`0nOol00`00Oomoo`0=Ool00`00Oomoo`3=Ool005ioo`H001Yoo`03001o
ogoo00Eoo`@000Ioo`03001oogoo00aoo`H000Eoo`<000Aoo`H000aoo`H000Ioo`03001oogoo00Eo
o`@000Ioo`03001oogoo00ioo`@001Ioo`<000Aoo`<0009oo`<000aoo`8000Yoo`03001oogoo00=o
o`@000Qoo`03001oogoo009oo`D0065oo`00H7oo00<007ooOol06goo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol01Goo00D007ooOomoo`0000Eoo`03
001oogoo00moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00Aoo`H000=oo`03001oogoo009oo`03001oogoo019oo`05001oogooOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`001goo0P001Goo00<007ooOol00Woo00<007ooOol0
0goo0P001goo00<007ooOol0HGoo001POol00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`08
Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0F
Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007ooOol02Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0HGoo001POol0
0`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`04Ool0
0`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`03Ool01@00Oomoogoo0000
17oo00<007ooOol02Goo00<007ooOol00Woo00@007ooOomoo`8000Qoo`03001oogoo00Eoo`8000Yo
o`03001oogoo065oo`00H7oo00<007ooOol027oo1@000goo00<007ooOol027oo00<007ooOol017oo
00<007ooOol027oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo
00<007ooOol03goo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol017oo
1P000goo00<007ooOol05Woo00<007ooOol00goo00D007ooOomoo`0000Aoo`03001oogoo00Uoo`03
001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo065oo`00H7oo00<007ooOol01goo00@007ooOol000Ioo`03001oogoo00Moo`03001oogoo
00Aoo`03001oogoo00Qoo`03001oogoo00ioo`03001oogoo00Eoo`05001oogooOol00005Ool2000@
Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0G
Ool01@00Oomoogoo000017oo0P000goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol017oo
0P001Goo00<007ooOol027oo0P001goo00<007ooOol0HGoo001NOol60005Ool01000Oomoogoo1000
17oo00<007ooOol01goo00@007ooOomoo`L000Eoo`03001oogoo00eoo`H000Eoo`<000Aoo`<00003
Ool00000008000Yoo`H000Moo`04001oogooOol70005Ool00`00Oomoo`0<Ool70003Ool4000?Ool3
0004Ool2000017oo0000000037oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01`0027oo
00<007ooOol017oo00<007ooOol0HGoo001POol00`00Oomoo`06Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00moo`03001oogoo025o
o`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00ioo`03001oogoo00Io
o`03001oogoo02Uoo`04001oogoo000>Ool00`00Oomoo`0?Ool3001SOol0061oo`03001oogoo00Io
o`05001oogooOol00003Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol047oo00<007ooOol08Goo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol01Woo00<0
07ooOol03goo00<007ooOol01goo00<007ooOol0:Goo0P003goo00<007ooOol047oo0P00Hgoo001Q
Ool30005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000moo`03001oogoo01Yoo`<0025oo`<0
00eoo`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo03Yoo`03001oogoo07Eoo`00JGoo00<0
07ooOol01@0017oo00<007ooOol0Q7oo00<007ooOol0/Goo001ZOol00`00Oomoo`07Ool00`00Oomo
o`22Ool01000Oomoo`00/goo001[Ool00`00Oomoo`05Ool00`00Oomoo`24Ool2002dOol00?mook5o
o`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "This ",
  Cell[BoxData[
      \(TraditionalForm\`M = 50\)]],
  " approximation to the complete series exhibits the by now familiar Gibbs \
phenomenon, due to the discontinuity in the periodic extension of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ".  For this reason, the series does not converge to ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " very rapidly; ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_n~\ \(-\[ImaginaryI]\)/\((2\ n\ \[Pi])\)\)\(\ \
\)\)\)]],
  "for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", which implies many terms in the series must be kept to achieve \
reasonable convergence."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2.2 Even Periodic Extension ", "Subsubtitle",
  CellTags->{"i:30", "c:15"}],

Cell[TextData[{
  "The problem of poor convergence can be avoided by using a ",
  "different",
  " periodic extension of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". Consider an ",
  StyleBox["even",
    FontSlant->"Italic"],
  " periodic extension of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((e)\)\)(t)\)]],
  ", with period ",
  Cell[BoxData[
      \(TraditionalForm\`2  T\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". This extension obeys"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[IndentingNewLine]", 
          RowBox[{\(\(f\^\((e)\)\)(t)\), "=", 
            TagBox[
              StyleBox[
                RowBox[{"{", 
                  StyleBox[GridBox[{
                        {\(f(t), \ \ \ \ \ \ \ \ \ \ \ \ a < t < a + T, \)},
                        {\(f(2  a - t), \ a - T < t < a, \)}
                        }],
                    ShowAutoStyles->True]}],
                ShowAutoStyles->False],
              (#&)]}]}], TraditionalForm]]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((e)\)\)(
          t + 2  T) = \(\(\(f\^\((e)\)\)(t)\)\(.\)\)\)]]
}], "NE2",
  CellTags->"(2.2.4)"],

Cell[TextData[{
  "The even periodic extension of a function is depicted in Fig. ",
  ButtonBox["2.4",
    ButtonData:>"Fig. 2.4",
    ButtonStyle->"Hyperlink"],
  " It is an even function of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "  about the point ",
  Cell[BoxData[
      \(TraditionalForm\`t = a\)]],
  ", and for this reason no longer has a discontinuity. Therefore, we expect \
that the series for ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\((e)\)\)]],
  " will converge more rapidly than that for ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\((p)\)\)]],
  ", and will no longer display the Gibbs phenomenon associated with \
nonuniform convergence."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.588235 0.0588235 0.475411 0.0594263 [
[0 .46291 -9 -9 ]
[0 .46291 9 0 ]
[.14706 .46291 -12 -9 ]
[.14706 .46291 12 0 ]
[.29412 .46291 -6 -9 ]
[.29412 .46291 6 0 ]
[.44118 .46291 -12 -9 ]
[.44118 .46291 12 0 ]
[.73529 .46291 -9 -9 ]
[.73529 .46291 9 0 ]
[.88235 .46291 -3 -9 ]
[.88235 .46291 3 0 ]
[1.025 .47541 0 -6 ]
[1.025 .47541 10 6 ]
[.57574 0 -12 -4.5 ]
[.57574 0 0 4.5 ]
[.57574 .11885 -12 -4.5 ]
[.57574 .11885 0 4.5 ]
[.57574 .23771 -12 -4.5 ]
[.57574 .23771 0 4.5 ]
[.57574 .35656 -12 -4.5 ]
[.57574 .35656 0 4.5 ]
[.57574 .59426 -6 -4.5 ]
[.57574 .59426 0 4.5 ]
[.58824 .64303 -14 0 ]
[.58824 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 .47541 m
0 .48166 L
s
[(-10)] 0 .46291 0 1 Mshowa
.14706 .47541 m
.14706 .48166 L
s
[(-7.5)] .14706 .46291 0 1 Mshowa
.29412 .47541 m
.29412 .48166 L
s
[(-5)] .29412 .46291 0 1 Mshowa
.44118 .47541 m
.44118 .48166 L
s
[(-2.5)] .44118 .46291 0 1 Mshowa
.73529 .47541 m
.73529 .48166 L
s
[(2.5)] .73529 .46291 0 1 Mshowa
.88235 .47541 m
.88235 .48166 L
s
[(5)] .88235 .46291 0 1 Mshowa
.125 Mabswid
.02941 .47541 m
.02941 .47916 L
s
.05882 .47541 m
.05882 .47916 L
s
.08824 .47541 m
.08824 .47916 L
s
.11765 .47541 m
.11765 .47916 L
s
.17647 .47541 m
.17647 .47916 L
s
.20588 .47541 m
.20588 .47916 L
s
.23529 .47541 m
.23529 .47916 L
s
.26471 .47541 m
.26471 .47916 L
s
.32353 .47541 m
.32353 .47916 L
s
.35294 .47541 m
.35294 .47916 L
s
.38235 .47541 m
.38235 .47916 L
s
.41176 .47541 m
.41176 .47916 L
s
.47059 .47541 m
.47059 .47916 L
s
.5 .47541 m
.5 .47916 L
s
.52941 .47541 m
.52941 .47916 L
s
.55882 .47541 m
.55882 .47916 L
s
.61765 .47541 m
.61765 .47916 L
s
.64706 .47541 m
.64706 .47916 L
s
.67647 .47541 m
.67647 .47916 L
s
.70588 .47541 m
.70588 .47916 L
s
.76471 .47541 m
.76471 .47916 L
s
.79412 .47541 m
.79412 .47916 L
s
.82353 .47541 m
.82353 .47916 L
s
.85294 .47541 m
.85294 .47916 L
s
.91176 .47541 m
.91176 .47916 L
s
.94118 .47541 m
.94118 .47916 L
s
.97059 .47541 m
.97059 .47916 L
s
.25 Mabswid
0 .47541 m
1 .47541 L
s
gsave
1.025 .47541 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.58824 0 m
.59449 0 L
s
[(-8)] .57574 0 1 0 Mshowa
.58824 .11885 m
.59449 .11885 L
s
[(-6)] .57574 .11885 1 0 Mshowa
.58824 .23771 m
.59449 .23771 L
s
[(-4)] .57574 .23771 1 0 Mshowa
.58824 .35656 m
.59449 .35656 L
s
[(-2)] .57574 .35656 1 0 Mshowa
.58824 .59426 m
.59449 .59426 L
s
[(2)] .57574 .59426 1 0 Mshowa
.125 Mabswid
.58824 .02971 m
.59199 .02971 L
s
.58824 .05943 m
.59199 .05943 L
s
.58824 .08914 m
.59199 .08914 L
s
.58824 .14857 m
.59199 .14857 L
s
.58824 .17828 m
.59199 .17828 L
s
.58824 .20799 m
.59199 .20799 L
s
.58824 .26742 m
.59199 .26742 L
s
.58824 .29713 m
.59199 .29713 L
s
.58824 .32684 m
.59199 .32684 L
s
.58824 .38627 m
.59199 .38627 L
s
.58824 .41598 m
.59199 .41598 L
s
.58824 .4457 m
.59199 .4457 L
s
.58824 .50512 m
.59199 .50512 L
s
.58824 .53484 m
.59199 .53484 L
s
.58824 .56455 m
.59199 .56455 L
s
.25 Mabswid
.58824 0 m
.58824 .61803 L
s
gsave
.58824 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15908 m
.00141 .16552 L
.0033 .1791 L
.01866 .2745 L
.03261 .34203 L
.04767 .39899 L
.06375 .44571 L
.07855 .47875 L
.09219 .50266 L
.10717 .52325 L
.12302 .54002 L
.13701 .5515 L
.15204 .56114 L
.15931 .565 L
.16622 .56824 L
.17242 .57084 L
.17412 .57151 L
.17593 .5722 L
.17764 .57196 L
.17918 .57137 L
.19309 .56526 L
.20777 .55704 L
.22386 .54533 L
.23865 .53135 L
.25274 .51432 L
.26782 .49096 L
.28206 .46268 L
.29502 .43024 L
.30975 .38355 L
.32336 .32868 L
.33926 .24629 L
.34704 .1971 L
.35044 .17344 L
.35237 .15942 L
.35416 .16416 L
.35581 .17606 L
.35731 .18657 L
.36067 .2092 L
.36751 .25149 L
.38188 .32579 L
.39761 .38879 L
.41244 .43458 L
.42689 .46936 L
.44217 .49793 L
.45521 .51708 L
.46954 .53377 L
.48464 .54747 L
.49843 .55724 L
.51433 .56601 L
.5215 .56925 L
Mistroke
.52531 .57082 L
.52731 .57161 L
.5284 .57202 L
.52942 .5724 L
.53125 .57171 L
.53326 .57092 L
.53678 .56948 L
.5437 .56639 L
.55889 .55818 L
.57208 .54911 L
.58619 .53687 L
.60135 .52 L
.61779 .49605 L
.63332 .46637 L
.64765 .43109 L
.662 .38602 L
.67543 .33259 L
.69017 .25809 L
.69839 .20769 L
.70239 .18048 L
.70428 .16698 L
.70601 .15614 L
.70781 .16932 L
.70975 .18312 L
.71327 .207 L
.72101 .25472 L
.73737 .33715 L
.75185 .39328 L
.76715 .43931 L
.78122 .47226 L
.79629 .49983 L
.81051 .52011 L
.82347 .53478 L
.8372 .54716 L
.85178 .5575 L
.86778 .56625 L
.87549 .5697 L
.87887 .57107 L
.88066 .57176 L
.88256 .57232 L
.8844 .57163 L
.88607 .57097 L
.88934 .56964 L
.89647 .56647 L
.91145 .55841 L
.92539 .54882 L
.93855 .53743 L
.95298 .52163 L
.96824 .50012 L
.98128 .47677 L
Mistroke
.9956 .44436 L
Mfstroke
.9956 .44436 m
1 .43159 L
s
.006 w
.52941 .5724 m
.53657 .56957 L
.54438 .56607 L
.55171 .56232 L
.55876 .55826 L
.56627 .55336 L
.57349 .54801 L
.58117 .54156 L
.58857 .5345 L
.59569 .52681 L
.60326 .51754 L
.61055 .50742 L
.61756 .49642 L
.62503 .48319 L
.63221 .46876 L
.63985 .45135 L
.64721 .43231 L
.65429 .41161 L
.66182 .38666 L
.66907 .35942 L
.67677 .32656 L
.6842 .29055 L
.69134 .25133 L
.69894 .20405 L
.70588 .15516 L
s
.5 Mabswid
[ .05 .05 ] 0 setdash
.52941 .11885 m
.52941 .59426 L
s
.70588 .11885 m
.70588 .59426 L
s
gsave
.51176 .59426 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.72353 .59426 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?moocMoo`@00?moo`Moo`00
ogoo=Woo00<007ooOol00Woo00<007ooOol0ogoo17oo003oOoleOol00`00Oomoo`04Ool00`00Oomo
o`3oOol3Ool00?moocEoo`03001oogoo00Aoo`03001oogoo0?moo`=oo`00ogoo:Goo2@000goo00<0
07ooOol017oo00<007ooOol01Woo1000n7oo003oOolYOol90004Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`3iOol00?moocIoo`H000Uoo`03001oogoo0?Uoo`00ogoo=Woo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol0nGoo003oOoleOol00`00Oomoo`04Ool00`00Oomoo`06Ool0
0`00Oomoo`3iOol00?moocEoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0?Uoo`00ogoo
=Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0nGoo003oOolgOol4000:Ool00`00Oomo
o`3iOol00?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomo
o`3iOol00?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomo
o`3iOol00?moodEoo`<00?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol0
0?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol0
0?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol0
0?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol0
0?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol0
0?moodEoo`<00?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEo
o`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEo
o`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEo
o`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEo
o`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEo
o`<00?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEoo`03001o
ogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEoo`03001o
ogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3iOol00?moodEoo`03001o
ogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOolgOol4000:Ool00`00Oomoo`3iOol00?moocIo
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?Uoo`00ogoo=Goo00<007ooOol017oo00<0
07ooOol01Woo00<007ooOol0nGoo003oOoleOol00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`3iOol00?moobMoo`03001oo`0000P000=oo`03001oogoo00Aoo`03001oogoo00Ioo`@003Moo`03
001oogoo0;ioo`00ogoo9goo00<007oo000020000goo00<007ooOol017oo00<007ooOol01Woo00<0
07ooOol0>7oo00<007ooOol0_Woo003oOolWOol00`00Oomoo`0;Ool20004Ool00`00Oomoo`07Ool0
0`00Oomoo`0hOol00`00Oomoo`2nOol00?moobMoo`03001oogoo00]oo`03001oo`0000<000Yoo`03
001oogoo03Qoo`03001oogoo0;ioo`00ogoo9goo00<007ooOol037oo00<007ooOol037oo00<007oo
Ool0>7oo00<007ooOol0_Woo003oOolWOol00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0h
Ool00`00Oomoo`2nOol00?moobMoo`03001oogoo00eoo`8000aoo`03001oogoo03Qoo`03001oogoo
0;ioo`00ogoo9goo00<007ooOol03goo100027oo00<007ooOol0>7oo00<007ooOol0_Woo003oOolW
Ool00`00Oomoo`0KOol00`00Oomoo`0hOol00`00Oomoo`2nOol00?moobMoo`03001oogoo01]oo`03
001oogoo03Qoo`03001oogoo0;ioo`00ogoo9goo00<007ooOol06goo00<007ooOol0>7oo00<007oo
Ool0_Woo003oOolWOol00`00Oomoo`0KOol00`00Oomoo`0hOol00`00Oomoo`2nOol00?moobMoo`03
001oogoo01]oo`03001oogoo03Qoo`03001oogoo0;ioo`00ogoo9goo00<007ooOol06goo00<007oo
Ool0>7oo00<007ooOol0_Woo003oOolWOol00`00Oomoo`0KOol00`00Oomoo`0hOol00`00Oomoo`2n
Ool00?moobMoo`03001oogoo01]oo`<003Qoo`03001oogoo0;ioo`00ogoo9goo00<007ooOol06goo
00<007ooOol0>7oo00<007ooOol0_Woo003oOolWOol00`00Oomoo`0KOol00`00Oomoo`0gOol3002o
Ool00?moobMoo`03001oogoo01]oo`03001oogoo03Moo`<00;moo`00ogoo9goo00<007ooOol06goo
00<007ooOol0=goo0`00_goo000MOol00`00Oomoo`2^Ool00`00Oomoo`1EOol00`00Oomoo`0KOol0
0`00Oomoo`0gOol3002oOol001eoo`03001oogoo0:ioo`03001oogoo05Eoo`03001oogoo01]oo`03
001oogoo03Ioo`@00;moo`007Woo00<007ooOol0[Goo0P00EWoo00<007ooOol06goo00<007ooOol0
=Woo1000_goo000NOol00`00Oomoo`2]Ool2001FOol00`00Oomoo`0KOol00`00Oomoo`0fOol4002o
Ool001ioo`03001oogoo0:aoo`03001oo`0005Ioo`03001oogoo01]oo`03001oogoo03Ioo`@00;mo
o`007Woo00<007ooOol0[7oo00<007oo0000EWoo00<007ooOol06goo00<007ooOol0=Woo1000_goo
000NOol00`00Oomoo`2/Ool00`00Ool0001dOol00`00Oomoo`0fOol4002oOol001moo`03001oogoo
0:]oo`04001oogoo001cOol00`00Oomoo`0eOol5002oOol001moo`03001oogoo0:]oo`04001oogoo
001cOol00`00Oomoo`0eOol5002oOol001moo`03001oogoo0:]oo`04001oogoo001cOol00`00Oomo
o`0eOol30002Ool00`00Oomoo`2lOol001moo`03001oogoo0:]oo`04001oogoo001cOol3000eOol3
0002Ool00`00Oomoo`2lOol001moo`03001oogoo0:Yoo`05001oogooOol0001cOol00`00Oomoo`0e
Ool30002Ool00`00Oomoo`2lOol001moo`03001oogoo0:Yoo`05001oogooOol0001cOol00`00Oomo
o`0eOol30002Ool00`00Oomoo`2lOol001moo`03001oogoo0:Yoo`05001oogooOol0001cOol00`00
Oomoo`0eOol30002Ool00`00Oomoo`2lOol0021oo`03001oogoo0:Uoo`05001oogooOol0001cOol0
0`00Oomoo`0dOol40002Ool00`00Oomoo`2lOol0021oo`03001oogoo0:Uoo`05001oogooOol0001c
Ool00`00Oomoo`0dOol40002Ool00`00Oomoo`2lOol0021oo`03001oogoo0:Uoo`05001oogooOol0
001cOol00`00Oomoo`0dOol30003Ool00`00Oomoo`2lOol0021oo`03001oogoo0:Qoo`03001oogoo
009oo`03001oogoo075oo`03001oogoo03Aoo`<000=oo`03001oogoo0;aoo`0087oo00<007ooOol0
Z7oo00<007ooOol00goo00<007ooOol0L7oo00<007ooOol0=7oo0`000goo00<007ooOol0_7oo000P
Ool00`00Oomoo`2XOol00`00Oomoo`03Ool00`00Oomoo`1`Ool00`00Oomoo`0dOol30004Ool00`00
Oomoo`2kOol0025oo`03001oogoo0:Moo`03001oogoo00=oo`03001oogoo071oo`03001oogoo03=o
o`@000Aoo`03001oogoo0;]oo`008Goo00<007ooOol0Ygoo00<007ooOol00goo00<007ooOol0L7oo
00<007ooOol0<goo100017oo00<007ooOol0^goo000QOol00`00Oomoo`2WOol00`00Oomoo`03Ool0
0`00Oomoo`1`Ool00`00Oomoo`0cOol30005Ool00`00Oomoo`2kOol0025oo`03001oogoo0:Ioo`03
001oogoo00Eoo`03001oogoo06moo`03001oogoo03=oo`<000Eoo`03001oogoo0;]oo`008Goo00<0
07ooOol0YWoo00<007ooOol01Goo00<007ooOol0Kgoo00<007ooOol0<goo0`001Goo00<007ooOol0
^goo000QOol00`00Oomoo`2VOol00`00Oomoo`05Ool00`00Oomoo`1_Ool3000cOol30005Ool00`00
Oomoo`2kOol0029oo`03001oogoo0:Eoo`03001oogoo00Eoo`03001oogoo06moo`03001oogoo03=o
o`<000Eoo`03001oogoo0;]oo`008Woo00<007ooOol0YGoo00<007ooOol01Goo00<007ooOol0Kgoo
00<007ooOol0<Woo10001Goo00<007ooOol0^goo000ROol00`00Oomoo`2UOol00`00Oomoo`05Ool0
0`00Oomoo`1_Ool00`00Oomoo`0bOol40006Ool00`00Oomoo`2jOol0029oo`03001oogoo0:Aoo`03
001oogoo00Ioo`03001oogoo06moo`03001oogoo039oo`<000Moo`03001oogoo0;Yoo`008Woo00<0
07ooOol0Y7oo00<007ooOol01goo00<007ooOol0D7oo00<007ooOol06goo00<007ooOol0<Woo0`00
0goo00D007ooOomoo`000;aoo`008Woo00<007ooOol0Y7oo00<007ooOol01goo00<007ooOol0D7oo
00<007ooOol06goo00<007ooOol0<Woo0`000goo00D007ooOomoo`000;aoo`008goo00<007ooOol0
Xgoo00<007ooOol01goo00<007ooOol0D7oo00<007ooOol06goo00<007ooOol0<Woo0`000goo00D0
07ooOomoo`000;aoo`008goo00<007ooOol0Xgoo00<007ooOol01goo00<007ooOol0D7oo00<007oo
Ool06goo00<007ooOol0<Woo0`000goo00D007ooOomoo`000;aoo`008goo00<007ooOol0Xgoo00<0
07ooOol01goo00<007ooOol0D7oo00<007ooOol06goo00<007ooOol0<Goo10000goo00<007ooOol0
0Woo00<007ooOol0^Goo000SOol00`00Oomoo`2SOol00`00Oomoo`07Ool00`00Oomoo`1@Ool00`00
Oomoo`0KOol00`00Oomoo`0aOol40003Ool00`00Oomoo`02Ool00`00Oomoo`2iOol002=oo`03001o
ogoo0:9oo`03001oogoo00Qoo`03001oogoo051oo`03001oogoo00moo`D000Moo`03001oogoo035o
o`<000Aoo`03001oogoo009oo`03001oogoo0;Uoo`008goo00<007ooOol0XWoo00<007ooOol02Goo
00<007ooOol0Cgoo00<007ooOol04Goo00<007ooOol01goo00<007ooOol0<Goo0`0017oo00<007oo
Ool00Woo00<007ooOol0^Goo000TOol00`00Oomoo`2QOol00`00Oomoo`09Ool00`00Oomoo`1?Ool0
0`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`0aOol30004Ool00`00Oomoo`02Ool00`00Oomo
o`2iOol002Aoo`03001oogoo0:5oo`03001oogoo00Uoo`03001oogoo04moo`03001oogoo00]oo`T0
00Moo`03001oogoo035oo`<000Aoo`03001oogoo009oo`03001oogoo0;Uoo`0097oo00<007ooOol0
XGoo00<007ooOol02Goo00<007ooOol0Cgoo00<007oo0000200017oo00<007ooOol00Woo00<007oo
Ool01goo1000<7oo0`0017oo00<007ooOol00goo00<007ooOol0^7oo000TOol00`00Oomoo`2QOol0
0`00Oomoo`09Ool00`00Oomoo`1?Ool00`00Ool000080004Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`0aOol30004Ool00`00Oomoo`03Ool00`00Oomoo`2hOol002Aoo`03001oogoo0:1o
o`03001oogoo00Yoo`03001oogoo04moo`03001oogoo00eoo`05001oogooOol00009Ool00`00Oomo
o`0`Ool40004Ool00`00Oomoo`03Ool00`00Oomoo`2hOol002Aoo`03001oogoo0:1oo`03001oogoo
00Yoo`03001oogoo04moo`03001oogoo00ioo`04001oogoo0009Ool00`00Oomoo`0`Ool40004Ool0
0`00Oomoo`03Ool00`00Oomoo`2hOol002Eoo`03001oogoo09moo`03001oogoo00]oo`03001oogoo
04ioo`03001oogoo00ioo`04001oogoo0009Ool00`00Oomoo`0`Ool30005Ool00`00Oomoo`03Ool0
0`00Oomoo`2hOol002Eoo`03001oogoo09moo`03001oogoo00]oo`03001oogoo04ioo`03001oogoo
00moo`03001oo`0000Uoo`03001oogoo031oo`<000Eoo`03001oogoo00=oo`03001oogoo0;Qoo`00
9Goo00<007ooOol0Wgoo00<007ooOol02goo00<007ooOol0CWoo00<007ooOol047oo0P002Goo00<0
07ooOol0<7oo0`001Goo00<007ooOol017oo00<007ooOol0]goo000UOol00`00Oomoo`2OOol00`00
Oomoo`0;Ool00`00Oomoo`1>Ool00`00Oomoo`0@Ool20009Ool00`00Oomoo`0`Ool30005Ool00`00
Oomoo`04Ool00`00Oomoo`2gOol002Eoo`03001oogoo09ioo`03001oogoo00aoo`03001oogoo04io
o`03001oogoo01]oo`03001oogoo02moo`@000Eoo`03001oogoo00Aoo`03001oogoo0;Moo`009Goo
00<007ooOol0WWoo00<007ooOol037oo00<007ooOol0CWoo00<007ooOol06goo00<007ooOol0;goo
10001Goo00<007ooOol017oo00<007ooOol0]goo000VOol00`00Oomoo`2MOol00`00Oomoo`0=Ool0
0`00Oomoo`1=Ool00`00Oomoo`0KOol00`00Oomoo`0_Ool30006Ool00`00Oomoo`04Ool00`00Oomo
o`2gOol002Ioo`03001oogoo09eoo`03001oogoo00eoo`03001oogoo04eoo`03001oogoo01]oo`03
001oogoo02moo`<000Ioo`03001oogoo00Eoo`03001oogoo0;Ioo`009Woo00<007ooOol0WGoo00<0
07ooOol03Goo00<007ooOol0CGoo00<007ooOol06goo00<007ooOol0;goo0`001Woo00<007ooOol0
1Goo00<007ooOol0]Woo000VOol00`00Oomoo`2LOol00`00Oomoo`0>Ool00`00Oomoo`1=Ool00`00
Oomoo`0KOol00`00Oomoo`0^Ool40006Ool00`00Oomoo`05Ool00`00Oomoo`2fOol002Ioo`03001o
ogoo09aoo`03001oogoo00ioo`03001oogoo04eoo`03001oogoo01]oo`<002ioo`@000Ioo`03001o
ogoo00Eoo`03001oogoo0;Ioo`009Woo00<007ooOol0W7oo00<007ooOol03goo00<007ooOol0C7oo
00<007ooOol06goo00<007ooOol0;Woo0`001goo00<007ooOol01Goo00<007ooOol0]Woo000WOol0
0`00Oomoo`2KOol00`00Oomoo`0?Ool00`00Oomoo`1ZOol00`00Oomoo`0^Ool3000@Ool00`00Oomo
o`2eOol002Moo`03001oogoo09]oo`03001oogoo00moo`03001oogoo06Yoo`03001oogoo02ioo`<0
011oo`03001oogoo0;Eoo`009goo00<007ooOol0VWoo00<007ooOol047oo00<007ooOol0JWoo00<0
07ooOol0;Goo100047oo00<007ooOol0]Goo000WOol00`00Oomoo`2JOol00`00Oomoo`0@Ool00`00
Oomoo`1ZOol00`00Oomoo`0]Ool4000@Ool00`00Oomoo`2eOol002Moo`03001oogoo09Yoo`03001o
ogoo015oo`03001oogoo06Uoo`03001oogoo02eoo`<0019oo`03001oogoo0;Aoo`00:7oo00<007oo
Ool0VGoo00<007ooOol04Goo00<007ooOol0JGoo00<007ooOol0;Goo0`004Woo00<007ooOol0]7oo
000XOol00`00Oomoo`2IOol00`00Oomoo`0AOol00`00Oomoo`1YOol00`00Oomoo`0]Ool3000BOol0
0`00Oomoo`2dOol002Qoo`03001oogoo09Qoo`03001oogoo019oo`03001oogoo06Uoo`03001oogoo
02aoo`@0019oo`03001oogoo0;Aoo`00:7oo00<007ooOol0V7oo00<007ooOol04goo00<007ooOol0
J7oo00<007ooOol0;7oo10004Woo00<007ooOol0]7oo000XOol00`00Oomoo`2HOol00`00Oomoo`0C
Ool00`00Oomoo`1XOol00`00Oomoo`0/Ool3000DOol00`00Oomoo`2cOol002Uoo`03001oogoo09Mo
o`03001oogoo01=oo`03001oogoo06Qoo`03001oogoo02aoo`<001Aoo`03001oogoo0;=oo`00:Goo
00<007ooOol0Ugoo00<007ooOol04goo00<007ooOol0J7oo00<007ooOol0;7oo0`0057oo00<007oo
Ool0/goo000YOol00`00Oomoo`2FOol00`00Oomoo`0DOol00`00Oomoo`1XOol00`00Oomoo`0[Ool4
000DOol00`00Oomoo`2cOol002Uoo`03001oogoo09Ioo`03001oogoo01Eoo`03001oogoo06Moo`<0
02]oo`@001Eoo`03001oogoo0;9oo`00:Goo00<007ooOol0UWoo00<007ooOol05Goo00<007ooOol0
Igoo00<007ooOol0:goo0`005Woo00<007ooOol0/Woo000ZOol00`00Oomoo`2EOol00`00Oomoo`0E
Ool00`00Oomoo`1WOol00`00Oomoo`0[Ool3000FOol00`00Oomoo`2bOol002Yoo`03001oogoo09Eo
o`03001oogoo01Eoo`03001oogoo06Moo`03001oogoo02]oo`<001Ioo`03001oogoo0;9oo`00:Woo
00<007ooOol0U7oo00<007ooOol05goo00<007ooOol0IWoo00<007ooOol0:Woo10005Woo00<007oo
Ool0/Woo000ZOol00`00Oomoo`2DOol00`00Oomoo`0GOol00`00Oomoo`1VOol00`00Oomoo`0ZOol4
000GOol00`00Oomoo`2aOol002Yoo`03001oogoo09Aoo`03001oogoo01Moo`03001oogoo06Ioo`03
001oogoo02Yoo`<001Qoo`03001oogoo0;5oo`00:goo00<007ooOol0Tgoo00<007ooOol05goo00<0
07ooOol0IWoo00<007ooOol0:Woo0`0067oo00<007ooOol0/Goo000[Ool00`00Oomoo`2COol00`00
Oomoo`0GOol00`00Oomoo`1VOol00`00Oomoo`0YOol4000HOol00`00Oomoo`2aOol002]oo`03001o
ogoo099oo`03001oogoo01Uoo`03001oogoo06Eoo`03001oogoo02Uoo`@001Qoo`03001oogoo0;5o
o`00:goo00<007ooOol0TWoo00<007ooOol06Goo00<007ooOol0IGoo00<007ooOol0:Goo0`006Woo
00<007ooOol0/7oo000[Ool00`00Oomoo`2BOol00`00Oomoo`0IOol00`00Oomoo`17Ool00`00Oomo
o`0KOol00`00Oomoo`0YOol3000<Ool00`00Oomoo`0;Ool00`00Oomoo`2`Ool002aoo`03001oogoo
095oo`03001oogoo01Uoo`03001oogoo04Moo`03001oogoo01]oo`03001oogoo02Uoo`<000aoo`03
001oogoo00]oo`03001oogoo0;1oo`00;7oo00<007ooOol0TGoo00<007ooOol06Goo00<007ooOol0
Agoo00<007ooOol06goo00<007ooOol0:7oo100037oo00<007ooOol02goo00<007ooOol0/7oo000/
Ool00`00Oomoo`2@Ool00`00Oomoo`0KOol00`00Oomoo`16Ool00`00Oomoo`0KOol00`00Oomoo`0X
Ool4000<Ool00`00Oomoo`0<Ool00`00Oomoo`2_Ool002aoo`03001oogoo091oo`03001oogoo01]o
o`03001oogoo04Ioo`03001oogoo01]oo`<002Qoo`<000eoo`03001oogoo00aoo`03001oogoo0:mo
o`00;7oo00<007ooOol0T7oo00<007ooOol06goo00<007ooOol0AWoo00<007ooOol06goo00<007oo
Ool0:7oo0`003Goo00<007ooOol037oo00<007ooOol0[goo000]Ool00`00Oomoo`2?Ool00`00Oomo
o`0KOol00`00Oomoo`16Ool00`00Oomoo`0KOol00`00Oomoo`0WOol4000=Ool00`00Oomoo`0<Ool0
0`00Oomoo`2_Ool002eoo`03001oogoo08moo`03001oogoo01aoo`03001oogoo04Eoo`03001oogoo
01]oo`03001oogoo02Moo`@000eoo`03001oogoo00aoo`03001oogoo0:moo`00;Goo00<007ooOol0
SWoo00<007ooOol07Goo00<007ooOol0AGoo00<007ooOol06goo00<007ooOol09goo0`003Woo00<0
07ooOol03Goo00<007ooOol0[Woo000]Ool00`00Oomoo`2>Ool00`00Oomoo`0MOol00`00Oomoo`15
Ool00`00Oomoo`0KOol00`00Oomoo`0WOol3000>Ool00`00Oomoo`0=Ool00`00Oomoo`2^Ool002eo
o`03001oogoo08ioo`03001oogoo01eoo`03001oogoo04Eoo`03001oogoo01]oo`03001oogoo02Io
o`@000ioo`03001oogoo00eoo`03001oogoo0:ioo`00;Woo00<007ooOol0SGoo00<007ooOol07Goo
00<007ooOol0AGoo00<007ooOol06goo00<007ooOol09Woo10003Woo00<007ooOol03Goo00<007oo
Ool0[Woo000^Ool00`00Oomoo`2=Ool00`00Oomoo`0NOol00`00Oomoo`14Ool00`00Oomoo`0KOol0
0`00Oomoo`0VOol3000?Ool00`00Oomoo`0>Ool00`00Oomoo`2]Ool002ioo`03001oogoo08aoo`03
001oogoo01moo`03001oogoo04Aoo`03001oogoo01]oo`03001oogoo02Ioo`<000moo`03001oogoo
00ioo`03001oogoo0:eoo`00;Woo00<007ooOol0S7oo00<007ooOol07goo00<007ooOol0A7oo00<0
07ooOol06goo00<007ooOol09Woo0`003goo00<007ooOol03Woo00<007ooOol0[Goo000_Ool00`00
Oomoo`2;Ool00`00Oomoo`0OOol00`00Oomoo`14Ool00`00Oomoo`0;Ool80008Ool00`00Oomoo`0U
Ool4000?Ool00`00Oomoo`0>Ool00`00Oomoo`2]Ool002moo`03001oogoo08]oo`03001oogoo021o
o`03001oogoo04=oo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo02Eo
o`@000moo`03001oogoo00moo`03001oogoo0:aoo`00;goo00<007ooOol0Rgoo00<007ooOol087oo
00<007ooOol0@goo00<007ooOol03Goo00<007ooOol02goo00<007ooOol09Goo0`0047oo00<007oo
Ool03goo00<007ooOol0[7oo000_Ool00`00Oomoo`2:Ool00`00Oomoo`0QOol00`00Oomoo`13Ool0
0`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`0UOol3000@Ool00`00Oomoo`0?Ool00`00Oomo
o`2/Ool0031oo`03001oogoo08Uoo`03001oogoo025oo`03001oogoo04=oo`03001oo`0000P000Mo
o`03001oogoo00Uoo`@002=oo`@0011oo`03001oogoo00moo`03001oogoo0:aoo`00<7oo00<007oo
Ool0RGoo00<007ooOol08Woo00<007ooOol0@Woo00<007oo0000200027oo00<007ooOol027oo00<0
07ooOol097oo100047oo00<007ooOol047oo00<007ooOol0Zgoo000`Ool00`00Oomoo`29Ool00`00
Oomoo`0ROol00`00Oomoo`12Ool00`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`0TOol3000A
Ool00`00Oomoo`0@Ool00`00Oomoo`2[Ool0031oo`03001oogoo08Qoo`03001oogoo02=oo`03001o
ogoo049oo`03001oogoo019oo`03001oogoo00Ioo`03001oogoo02Aoo`<0015oo`03001oogoo011o
o`03001oogoo0:]oo`00<Goo00<007ooOol0Qgoo00<007ooOol08goo00<007ooOol0@Woo00<007oo
Ool04Woo00<007ooOol01Woo00<007ooOol08goo10004Goo00<007ooOol047oo00<007ooOol0Zgoo
000aOol00`00Oomoo`27Ool00`00Oomoo`0SOol00`00Oomoo`12Ool00`00Oomoo`0<Ool00`00Oomo
o`03Ool00`00Oomoo`06Ool00`00Oomoo`0SOol4000AOol00`00Oomoo`0AOol00`00Oomoo`2ZOol0
035oo`03001oogoo08Moo`03001oogoo02Aoo`03001oogoo045oo`03001oogoo00aoo`8000=oo`03
001oogoo00Moo`03001oogoo02=oo`<0019oo`03001oogoo015oo`03001oogoo0:Yoo`00<Goo00<0
07ooOol0Qgoo00<007ooOol097oo00<007ooOol0DWoo0`002Woo00<007ooOol08goo0`009Woo00<0
07ooOol0ZWoo000bOol00`00Oomoo`25Ool00`00Oomoo`0UOol00`00Oomoo`1OOol00`00Oomoo`0R
Ool4000VOol00`00Oomoo`2ZOol0039oo`03001oogoo08Eoo`03001oogoo02Eoo`03001oogoo05mo
o`03001oogoo029oo`@002Moo`03001oogoo0:Uoo`00<Woo00<007ooOol0QGoo00<007ooOol09Woo
00<007ooOol0GWoo00<007ooOol08Woo0`00:7oo00<007ooOol0ZGoo000bOol00`00Oomoo`25Ool0
0`00Oomoo`0VOol00`00Oomoo`1NOol00`00Oomoo`0ROol3000XOol00`00Oomoo`2YOol003=oo`03
001oogoo08Aoo`03001oogoo02Ioo`03001oogoo05ioo`03001oogoo029oo`<002Qoo`03001oogoo
0:Uoo`00<goo00<007ooOol0Pgoo00<007ooOol09goo00<007ooOol0GWoo00<007ooOol08Goo1000
:Goo00<007ooOol0Z7oo000cOol00`00Oomoo`23Ool00`00Oomoo`0WOol00`00Oomoo`1NOol00`00
Oomoo`0QOol4000YOol00`00Oomoo`2XOol003=oo`03001oogoo08=oo`03001oogoo02Qoo`03001o
ogoo05eoo`<0025oo`<002Yoo`03001oogoo0:Qoo`00=7oo00<007ooOol0PGoo00<007ooOol0:Goo
00<007ooOol0GGoo00<007ooOol08Goo0`00:Woo00<007ooOol0Z7oo000dOol00`00Oomoo`21Ool0
0`00Oomoo`0YOol00`00Oomoo`1MOol00`00Oomoo`0POol4000[Ool00`00Oomoo`2WOol003Aoo`03
001oogoo085oo`03001oogoo02Yoo`03001oogoo05aoo`03001oogoo021oo`@002]oo`03001oogoo
0:Moo`00=7oo00<007ooOol0P7oo00<007ooOol0:goo00<007ooOol0G7oo00<007ooOol087oo0`00
;7oo00<007ooOol0Ygoo000eOol00`00Oomoo`1oOol00`00Oomoo`0[Ool00`00Oomoo`1LOol00`00
Oomoo`0OOol4000/Ool00`00Oomoo`2WOol003Eoo`03001oogoo07moo`03001oogoo02aoo`03001o
ogoo05]oo`03001oogoo01moo`@002eoo`03001oogoo0:Ioo`00=Goo00<007ooOol0OWoo00<007oo
Ool0;Goo00<007ooOol0Fgoo00<007ooOol07goo0`00;Woo00<007ooOol0YWoo000fOol00`00Oomo
o`1mOol00`00Oomoo`0]Ool00`00Oomoo`1KOol00`00Oomoo`0NOol4000^Ool00`00Oomoo`2VOol0
03Ioo`03001oogoo07eoo`03001oogoo02ioo`03001oogoo05Yoo`03001oogoo01ioo`@002moo`03
001oogoo0:Eoo`00=Woo00<007ooOol0O7oo00<007ooOol0;goo00<007ooOol0FWoo00<007ooOol0
7Woo0`00<7oo00<007ooOol0YGoo000gOol00`00Oomoo`1kOol00`00Oomoo`0_Ool00`00Oomoo`1J
Ool00`00Oomoo`0MOol4000`Ool00`00Oomoo`2UOol003Moo`03001oogoo07]oo`03001oogoo031o
o`03001oogoo05Uoo`03001oogoo01eoo`@0031oo`03001oogoo0:Eoo`00=goo00<007ooOol0NWoo
00<007ooOol0<Goo00<007ooOol0FGoo00<007ooOol07Goo0`00<Woo00<007ooOol0Y7oo000hOol0
0`00Oomoo`1iOol00`00Oomoo`0aOol00`00Oomoo`1IOol00`00Oomoo`0LOol4000bOol00`00Oomo
o`2TOol003Qoo`03001oogoo07Uoo`03001oogoo039oo`03001oogoo05Qoo`<001aoo`@0039oo`03
001oogoo0:Aoo`00>7oo00<007ooOol0N7oo00<007ooOol0<goo00<007ooOol0>Woo00<007ooOol0
6goo00<007ooOol077oo0`006Goo00<007ooOol067oo00<007ooOol0Xgoo000iOol00`00Oomoo`1g
Ool00`00Oomoo`0cOol00`00Oomoo`0jOol00`00Oomoo`0KOol00`00Oomoo`0KOol4000IOol00`00
Oomoo`0HOol00`00Oomoo`2SOol003Uoo`03001oogoo07Moo`03001oogoo03Aoo`03001oogoo03Uo
o`03001oogoo01]oo`03001oogoo01]oo`@001Uoo`03001oogoo01Qoo`03001oogoo0:=oo`00>Goo
00<007ooOol0MWoo00<007ooOol0=Goo00<007ooOol0>Goo00<007ooOol06goo00<007ooOol06Woo
10006Woo00<007ooOol06Goo00<007ooOol0XWoo000jOol00`00Oomoo`1eOol00`00Oomoo`0eOol0
0`00Oomoo`0iOol00`00Oomoo`0KOol00`00Oomoo`0JOol4000JOol00`00Oomoo`0IOol00`00Oomo
o`2ROol003Yoo`03001oogoo07Eoo`03001oogoo03Ioo`03001oogoo03Qoo`03001oogoo01]oo`03
001oogoo01Yoo`<001]oo`03001oogoo01Uoo`03001oogoo0:9oo`00>Woo00<007ooOol0M7oo00<0
07ooOol0=goo00<007ooOol0>7oo00<007ooOol06goo00<007ooOol06Goo10006goo00<007ooOol0
6Goo00<007ooOol0XWoo000kOol00`00Oomoo`1cOol00`00Oomoo`0gOol00`00Oomoo`0hOol00`00
Oomoo`0KOol00`00Oomoo`0IOol4000KOol00`00Oomoo`0JOol00`00Oomoo`1cOol00`00Oomoo`0[
Ool001Yoo`L000Ioo`@0011oo`03001oogoo025oo`03001oogoo00Uoo`<000Moo`H003Eoo`03001o
ogoo00H003=oo`04001oogooOol80006Ool30007Ool6000HOol00`00Oomoo`0KOol00`00Oomoo`0I
Ool3000KOol80006Ool30007Ool7000fOol6000iOol00`00Oomoo`0[Ool001eoo`03001oogoo00Io
o`03001oogoo009oo`03001oogoo00eoo`03001oogoo029oo`03001oogoo00Qoo`<000Ioo`8000Eo
o`03001oogoo039oo`04001oo`000005Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool30006Ool20005Ool00`00Oomoo`0EOol00`00Oomoo`0KOol00`00Oomoo`0H
Ool4000LOol00`00Oomoo`03Ool00`00Oomoo`04Ool30006Ool20005Ool00`00Oomoo`0cOol20005
Ool00`00Oomoo`0eOol00`00Oomoo`0/Ool001eoo`03001oogoo00Ioo`03001oogoo009oo`03001o
ogoo00ioo`03001oogoo025oo`03001oogoo00Qoo`<000ioo`03001oogoo035oo`03001oogoo00Mo
o`03001oogoo031oo`03001oogoo009oo`03001oogoo00Uoo`<000ioo`03001oogoo01Aoo`03001o
ogoo01]oo`03001oogoo01Qoo`@001aoo`8000]oo`<000ioo`03001oogoo03Yoo`03001oogoo03Ao
o`03001oogoo02aoo`007Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol03Goo00<007oo
Ool08Woo00<007ooOol067oo00<007ooOol0<7oo00<007ooOol027oo00<007ooOol0<7oo00<007oo
Ool00goo00<007ooOol06Goo00<007ooOol057oo00<007ooOol06goo00<007ooOol067oo0`007Goo
00<007oo00006goo00<007ooOol0>Woo00<007ooOol0=7oo00<007ooOol0;7oo000=Ool90007Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`0BOol90007Ool00`00Oomo
o`0HOol00`00Oomoo`0XOol9000:Ool00`00Oomoo`0WOol:0006Ool00`00Oomoo`0HOol00`00Oomo
o`0DOol00`00Oomoo`0KOol00`00Oomoo`0GOol4000MOol01000Oomoo`006Woo00<007ooOol0>Woo
00<007ooOol0<goo00<007ooOol0;Goo000=Ool90007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`0>Ool00`00Oomoo`0AOol90007Ool00`00Oomoo`0HOol00`00Oomoo`0XOol9000:Ool0
0`00Oomoo`0WOol900000goo001oo`05Ool00`00Oomoo`0GOol00`00Oomoo`0DOol00`00Oomoo`0K
Ool00`00Oomoo`0GOol4000MOol01@00Oomoogoo00006Goo0P00>goo00<007ooOol0<goo00<007oo
Ool0;Goo000MOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`0ROol0
0`00Oomoo`0@Ool20004Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool20004Ool00`00Oomoo`0bOol0
0`00Oomoo`05Ool00`00Oomoo`0?Ool20004Ool00`00Oomoo`0EOol00`00Oomoo`0KOol3000GOol3
000NOol00`00Oomoo`02Ool00`00Oomoo`0?Ool20004Ool00`00Ool0000dOol20004Ool00`00Oomo
o`0dOol00`00Oomoo`0]Ool001eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00ioo`03
001oogoo029oo`03001oogoo011oo`H003=oo`03001oogoo009oo`H003Ioo`03001oogoo00Eoo`03
001oogoo00ioo`H001Qoo`03001oogoo01]oo`03001oogoo01Ioo`@001ioo`03001oogoo00=oo`03
001oogoo00ioo`H000=oo`03001oogoo035oo`H003Ioo`03001oogoo02ioo`007Goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol03goo00<007ooOol08Woo00<007ooOol03goo00<007ooOol0
=Goo00<007ooOol00goo00<007ooOol0>Goo00<007ooOol01Goo00<007ooOol03Woo00<007ooOol0
6goo00<007ooOol06goo00<007ooOol05Woo10007Woo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol01Woo00<007ooOol0<Goo00<007ooOol0>Goo00<007ooOol0;Woo000MOol00`00Oomoo`06
Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0ROol00`00Oomoo`0?Ool00`00Oomoo`0e
Ool00`00Oomoo`03Ool00`00Oomoo`0iOol00`00Ool00005Ool00`00Oomoo`0>Ool00`00Oomoo`0K
Ool00`00Oomoo`0KOol00`00Oomoo`0FOol3000OOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`07Ool00`00Oomoo`0`Ool00`00Oomoo`0hOol00`00Oomoo`0_Ool001Yoo`@000Qoo`03001o
ogoo009oo`03001oogoo015oo`03001oogoo01]oo`03001oogoo00Aoo`03001oogoo00ioo`03001o
ogoo03Eoo`03001oogoo00=oo`03001oogoo03Yoo`<000=oo`03001oogoo00moo`03001oogoo01]o
o`03001oogoo01]oo`03001oogoo01Eoo`@001moo`8000=oo`03001oogoo00moo`03001oogoo00Mo
o`03001oogoo031oo`03001oogoo03Qoo`03001oogoo02moo`0077oo0P002Goo100057oo00<007oo
Ool06goo200047oo1`00<7oo00<007ooOol017oo1`00=Woo00<007ooOol00`004Woo1`005goo00<0
07ooOol06goo00<007ooOol05Goo10007goo00<007oo00000P004Woo1`0017oo00<007ooOol0;goo
1`00=7oo00<007ooOol0;goo0010Ool00`00Oomoo`1YOol00`00Oomoo`11Ool00`00Oomoo`0cOol0
0`00Oomoo`0KOol00`00Oomoo`0DOol4000POol00`00Oomoo`0OOol00`00Oomoo`1YOol00`00Oomo
o`0`Ool0041oo`03001oogoo06Uoo`03001oogoo049oo`03001oogoo039oo`03001oogoo01]oo`03
001oogoo01Aoo`@0021oo`03001oogoo021oo`03001oogoo06Qoo`03001oogoo031oo`00@Goo00<0
07ooOol0Igoo00<007ooOol0@goo00<007ooOol0<Woo00<007ooOol06goo00<007ooOol04goo1000
8Goo00<007ooOol087oo00<007ooOol0Igoo00<007ooOol0<Goo0011Ool00`00Oomoo`1WOol00`00
Oomoo`14Ool00`00Oomoo`0aOol00`00Oomoo`0KOol00`00Oomoo`0COol4000QOol00`00Oomoo`0Q
Ool00`00Oomoo`1VOol00`00Oomoo`0aOol0049oo`03001oogoo06Eoo`03001oogoo04Eoo`03001o
ogoo035oo`03001oogoo01]oo`03001oogoo019oo`@0029oo`03001oogoo025oo`03001oogoo06Eo
o`03001oogoo01Uoo`D001Aoo`00@Woo00<007ooOol0IGoo00<007ooOol0AGoo00<007ooOol0<Goo
00<007ooOol06goo00<007ooOol04Woo10008Woo00<007ooOol08Woo00<007ooOol0I7oo00<007oo
Ool067oo00<007ooOol00goo0P004Woo0013Ool00`00Oomoo`1SOol00`00Oomoo`17Ool00`00Oomo
o`1>Ool00`00Oomoo`0AOol40018Ool00`00Oomoo`1TOol00`00Oomoo`0HOol00`00Oomoo`0GOol0
04=oo`03001oogoo06=oo`03001oogoo04Moo`03001oogoo04ioo`03001oogoo015oo`@004Uoo`03
001oogoo069oo`03001oogoo01Uoo`03001oogoo01Moo`00A7oo00<007ooOol0HGoo00<007ooOol0
BGoo00<007ooOol0CGoo00<007ooOol047oo1000BWoo00<007ooOol0HWoo00<007ooOol06Goo00<0
07ooOol05goo000MOooo003g000COol00`00Oomoo`0GOol001eoo`03001oogoo00aoo`03001oogoo
00aoo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo
00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo009oo`03001oogoo
00Moo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo
00Ioo`03001oogoo009oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo
00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00@000Moo`03001oogoo00aoo`03001o
ogoo00aoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo00aoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001o
ogoo00]oo`03001oogoo00=oo`03001oogoo01Yoo`03001oogoo01Moo`007Goo00<007ooOol09Goo
00<007ooOol07goo00<007ooOol0?Goo00<007ooOol01goo00<007ooOol0@Woo00D007ooOomoo`00
04Uoo`03001oogoo00ioo`@003Eoo`03001oogoo01Ioo`03001oogoo02eoo`03001oogoo02ioo`03
001oogoo01Uoo`P001Aoo`007Goo00<007ooOol09Woo00<007ooOol07Woo00<007ooOol0?7oo00<0
07ooOol027oo00<007ooOol0@Woo00D007ooOomoo`0004Uoo`03001oogoo00ioo`@003Eoo`03001o
ogoo01Ioo`03001oogoo02eoo`03001oogoo02ioo`03001oogoo01]oo`03001oogoo01Moo`00AWoo
00<007ooOol0GGoo00<007ooOol0CWoo00<007ooOol0BWoo00<007ooOol03Goo1000D7oo00<007oo
Ool0G7oo00<007ooOol077oo00<007ooOol05goo0017Ool00`00Oomoo`1KOol00`00Oomoo`1?Ool0
0`00Oomoo`1:Ool00`00Oomoo`0=Ool4001@Ool00`00Oomoo`1KOol00`00Oomoo`0MOol00`00Oomo
o`0GOol004Qoo`03001oogoo05Yoo`03001oogoo051oo`03001oogoo04Uoo`03001oogoo00aoo`@0
059oo`03001oogoo05Yoo`03001oogoo03Moo`00B7oo00<007ooOol0FGoo00<007ooOol0DGoo00<0
07ooOol0BGoo00<007ooOol037oo1000DWoo00<007ooOol0FGoo00<007ooOol0>7oo0019Ool00`00
Oomoo`1HOol00`00Oomoo`1BOol00`00Oomoo`18Ool00`00Oomoo`0<Ool3001DOol00`00Oomoo`1H
Ool00`00Oomoo`0hOol004Uoo`03001oogoo05Moo`03001oogoo05Aoo`03001oogoo04Moo`03001o
ogoo00]oo`@005Aoo`03001oogoo05Moo`03001oogoo03Uoo`00BWoo00<007ooOol0EGoo00<007oo
Ool0EGoo00<007ooOol0Agoo00<007ooOol02goo1000EGoo00<007ooOol0EGoo00<007ooOol0>Woo
001;Ool00`00Oomoo`1DOol00`00Oomoo`1FOol00`00Oomoo`16Ool00`00Oomoo`0:Ool4001FOol0
0`00Oomoo`1EOol00`00Oomoo`0jOol004]oo`03001oogoo05=oo`03001oogoo05Moo`03001oogoo
04Ioo`03001oogoo00Uoo`D005Moo`03001oogoo05=oo`03001oogoo03]oo`00C7oo00<007ooOol0
DGoo00<007ooOol0FGoo00<007ooOol0AGoo00<007ooOol02Goo1000F7oo00<007ooOol0Dgoo00<0
07ooOol0>goo001<Ool00`00Oomoo`1AOol00`00Oomoo`1JOol00`00Oomoo`14Ool30008Ool4001J
Ool00`00Oomoo`1AOol00`00Oomoo`0lOol004eoo`03001oogoo04moo`03001oogoo05]oo`03001o
ogoo04Aoo`03001oogoo00Moo`D005]oo`03001oogoo04moo`03001oogoo03eoo`00CWoo00<007oo
Ool0CGoo00<007ooOol0GGoo00<007ooOol0@goo00<007ooOol01goo1000G7oo00<007ooOol0CWoo
00<007ooOol0?Woo001>Ool00`00Oomoo`1=Ool00`00Oomoo`1NOol00`00Oomoo`12Ool00`00Oomo
o`06Ool4001NOol00`00Oomoo`1=Ool00`00Oomoo`0nOol004moo`03001oogoo04]oo`03001oogoo
05moo`03001oogoo049oo`03001oogoo00Eoo`D005moo`03001oogoo04]oo`03001oogoo03moo`00
D7oo00<007ooOol0BGoo00<007ooOol0HGoo00<007ooOol0@Goo00<007ooOol017oo1@00HGoo00<0
07ooOol0BGoo00<007ooOol0@7oo001@Ool00`00Oomoo`19Ool00`00Oomoo`1ROol00`00Oomoo`10
Ool00`00Oomoo`03Ool5001ROol00`00Oomoo`19Ool00`00Oomoo`10Ool0055oo`03001oogoo04Mo
o`03001oogoo06=oo`03001oogoo029oo`03001oogoo01]oo`03001oogoo00=oo`@0035oo`03001o
ogoo031oo`03001oogoo04Moo`03001oogoo045oo`00DGoo00<007ooOol0AWoo00<007ooOol0IGoo
00<007ooOol08Goo00<007ooOol06goo00<007ooOol00Woo1000<Woo00<007ooOol0<Goo00<007oo
Ool0AGoo00<007ooOol0@Woo001BOol00`00Oomoo`14Ool00`00Oomoo`1WOol00`00Oomoo`0POol0
0`00Oomoo`0KOol01000Oomoogoo1@00<Woo00<007ooOol0<Woo00<007ooOol0@goo00<007ooOol0
@goo001COol00`00Oomoo`12Ool00`00Oomoo`1YOol00`00Oomoo`0OOol00`00Oomoo`0KOol00`00
Oomoo`05000cOol00`00Oomoo`0cOol00`00Oomoo`12Ool00`00Oomoo`13Ool005Aoo`03001oogoo
045oo`03001oogoo06Yoo`03001oogoo01ioo`03001oogoo01]oo`03001oo`0000@003Aoo`03001o
ogoo03Aoo`03001oogoo041oo`03001oogoo04Aoo`00EGoo00<007ooOol0?goo00<007ooOol0Jgoo
00<007ooOol07Woo00<007ooOol06goo1P00=Goo00<007ooOol0=Goo00<007ooOol0?Woo00<007oo
Ool0AGoo001FOol00`00Oomoo`0mOol00`00Oomoo`1]Ool00`00Oomoo`0MOol00`00Oomoo`0KOol5
000fOol00`00Oomoo`0fOol00`00Oomoo`0lOol00`00Oomoo`16Ool005Moo`03001oogoo03]oo`03
001oogoo06moo`03001oogoo01aoo`03001oogoo01Yoo`D003Moo`03001oogoo03Moo`03001oogoo
03Yoo`03001oogoo04Moo`00F7oo00<007ooOol0>Goo00<007ooOol0LGoo0P0077oo00<007ooOol0
6Goo1@00>7oo00<007ooOol0>7oo00<007ooOol0>7oo00<007ooOol0B7oo001IOol00`00Oomoo`0g
Ool00`00Oomoo`1dOol00`00Oomoo`0IOol00`00Oomoo`0HOol5000iOol00`00Oomoo`0iOol00`00
Oomoo`0fOol00`00Oomoo`19Ool005Yoo`03001oogoo03Eoo`03001oogoo07Ioo`03001oogoo01Qo
o`03001oogoo01Moo`D003Yoo`03001oogoo03Yoo`03001oogoo03=oo`8004aoo`00Fgoo0P00=7oo
00<007ooOol0N7oo00<007ooOol05goo00<007ooOol05Woo1P00>Woo00<007ooOol0>goo00<007oo
Ool0<Goo00<007ooOol0C7oo001MOol00`00Oomoo`0`Ool00`00Oomoo`1jOol00`00Oomoo`0FOol0
0`00Oomoo`0EOol500000goo001oo`0iOol00`00Oomoo`0lOol00`00Oomoo`0_Ool00`00Oomoo`1=
Ool005ioo`03001oogoo02ioo`03001oogoo07aoo`03001oogoo01Eoo`03001oogoo01Aoo`D0009o
o`03001oogoo03Qoo`03001oogoo03eoo`03001oogoo02eoo`03001oogoo04ioo`00Ggoo00<007oo
Ool0:goo0P00P7oo00<007ooOol057oo00<007ooOol04Woo1P000goo00<007ooOol0>7oo00<007oo
Ool0?Woo00<007ooOol0:goo00<007ooOol0Cgoo001POol00`00Oomoo`0XOol20023Ool2000DOol0
0`00Oomoo`0AOol60004Ool00`00Oomoo`0hOol00`00Oomoo`0oOol2000YOol2001BOol0065oo`03
001oogoo02Eoo`8008Moo`03001oogoo015oo`03001oogoo011oo`H000Eoo`03001oogoo03Qoo`03
001oogoo045oo`03001oogoo02Eoo`03001oogoo059oo`00HWoo0P0097oo00<007ooOol0R7oo0P00
4Goo00<007ooOol03Woo1P001goo00<007ooOol0>7oo00<007ooOol0@Woo0P008goo0P00EGoo001T
Ool00`00Oomoo`0OOol2002=Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool70008Ool00`00Oomoo`0h
Ool00`00Oomoo`14Ool00`00Oomoo`0OOol00`00Oomoo`1EOol006Eoo`8001eoo`80091oo`03001o
ogoo00eoo`03001oogoo00Yoo`P000Uoo`03001oogoo03Qoo`03001oogoo04Eoo`03001oogoo01eo
o`03001oogoo05Ioo`00Igoo0P006Woo00<007ooOol0TGoo0P003Goo00<007ooOol02Goo1`002goo
00<007ooOol0>7oo00<007ooOol0AWoo0P006goo0P00FGoo001YOol00`00Oomoo`0EOol2002FOol2
000;Ool00`00Oomoo`07Ool7000=Ool00`00Oomoo`0hOol00`00Oomoo`18Ool2000GOol2001KOol0
06Yoo`<001=oo`03001oogoo09Qoo`8000Uoo`03001oogoo00Eoo`L000moo`03001oogoo03Qoo`03
001oogoo04Yoo`8001=oo`8005eoo`00KGoo0P0047oo00<007ooOol0Vgoo0P001goo00<007ooOol0
0goo200047oo0`00>7oo00<007ooOol0C7oo0P003goo0P00Ggoo001_Ool2000<Ool2002POol20005
Ool01000Oomoogoo20004Woo00<007ooOol0>7oo00<007ooOol0CWoo0P002goo0P00HGoo001aOol3
0006Ool3002TOol20003Ool:000DOol00`00Oomoo`0hOol00`00Oomoo`1@Ool20008Ool00`00Oomo
o`1QOol007Aoo`04001oogooOol2002YOol;000FOol00`00Oomoo`2=Ool20003Ool3001TOol007Eo
o`<00:eoo`L001Qoo`03001oogoo08moo`<006Moo`00ogoo9Woo10006goo00<007ooOol0nGoo003o
Oom5Ool00`00Oomoo`3iOol00?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003o
Oom5Ool00`00Oomoo`3iOol00?mooaaoo`@00004Ool00000000QOol00`00Oomoo`0lOol20002Ool3
002fOol00?mooa]oo`03001oogoo009oo`8001=oo`P000Qoo`03001oogoo03eoo`<000=oo`800;Ao
o`00ogoo6Woo00<007ooOol017oo00<007ooOol04Woo00<007ooOol00goo00<007ooOol01Woo00<0
07ooOol0?Goo0P001Goo00<007ooOol0/Woo003oOolJOol00`00Oomoo`04Ool00`00Oomoo`0COol0
0`00Oomoo`0;Ool00`00Oomoo`0mOol00`00Oomoo`05Ool00`00Oomoo`2aOol00?mooa]oo`03001o
ogoo00=oo`03001oogoo01Aoo`03001oogoo00Yoo`03001oogoo03eoo`03001oogoo00Eoo`03001o
ogoo0;5oo`00ogoo77oo1P005goo00<007ooOol02Goo1000?7oo00<007ooOol01Goo00<007ooOol0
/Goo003oOolQOol00`00Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`0mOol20005Ool00`00Oomo
o`2bOol00?mooa]oo`03001oogoo009oo`8001Uoo`03001oogoo00Moo`03001oogoo03eoo`<000=o
o`800;Aoo`00ogoo77oo1@006goo00<007ooOol01Woo00<007ooOol0?Goo00<007ooOol00`00]Woo
003oOollOol00`00Oomoo`06Ool00`00Oomoo`0mOol00`00Oomoo`2iOol00?moocIoo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo03eoo`03001oogoo0;Uoo`00ogoo=Woo0P000goo00<007oo
Ool01goo00<007ooOol0?Goo00<007ooOol0^Goo003oOolhOol3000:Ool00`00Oomoo`0lOol2002k
Ool00?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOom5Ool00`00Oomoo`3i
Ool00?moodEoo`03001oogoo0?Uoo`00ogooAGoo00<007ooOol0nGoo003oOoooOom2Ool00?mooomo
od9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool0
0?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOooo
Oom2Ool00?mooomood9oo`00ogoo@Woo00<007ooOol03Woo00<007ooOol0jgoo003oOom1Ool00`00
Oomoo`0@Ool00`00Oomoo`3ZOol00?mood5oo`03001oogoo011oo`03001oogoo0>Yoo`00ogoo@7oo
00<007ooOol04Woo00<007ooOol0jGoo003oOol_Ool7000:Ool00`00Oomoo`06Ool50007Ool00`00
Oomoo`3YOol00?mooc5oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00=oo`8000Ioo`03
001oogoo0>Qoo`00ogoo<Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007oo
Ool0j7oo003oOolaOol00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3X
Ool00?mooc5oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0>Qoo`00
ogoo<Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0j7oo003oOola
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3XOol00?mooc5oo`03
001oogoo00]oo`03001oogoo00Aoo`P000Qoo`03001oogoo0>Qoo`00ogoo;goo1`002Woo00<007oo
Ool01Goo00<007ooOol02Woo00<007ooOol0jGoo003oOolaOol00`00Oomoo`0<Ool00`00Oomoo`05
Ool00`00Oomoo`0:Ool00`00Oomoo`3YOol00?mooc5oo`03001oogoo00eoo`03001oogoo00Aoo`03
001oogoo00Uoo`03001oogoo0>Yoo`00ogoo<Goo0P003Woo00<007ooOol047oo00<007ooOol0jWoo
003oOolbOol5000;Ool00`00Oomoo`0>Ool00`00Oomoo`3[Ool00?mooomood9oo`00ogooogoo@Woo
003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-11, -8, 0, 0}}],

Cell[TextData[{
  "Fig. 2.4 Even periodic extension of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " defined on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < t < 2\)]],
  ". "
}], "Caption",
  CellTags->"Fig. 2.4"],

Cell[TextData[{
  "\tSince the series is of cosine form when time is evaluated with respect \
to an origin at ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((e)\)\)(
          t) = \[Sum]\+\(n = 0\)\%\[Infinity] a\_n\ cos[
              n\ \(\[CapitalDelta]\[Omega](\ t - a)\)/2]\)]],
  "."
}], "NE2",
  CellTags->"(2.2.5)"],

Cell[TextData[{
  "Note that the period is now ",
  Cell[BoxData[
      \(TraditionalForm\`2  T\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", so the fundamental frequency is ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tIn order to determine the Fourier coefficients for ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\((e)\)\)]],
  ", we must now integrate over an interval of ",
  Cell[BoxData[
      \(TraditionalForm\`2  T\)]],
  ". A good choice is the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a - T < t < a + T\)]],
  ", so that the Fourier coefficients have the form"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`a\_n = \(1\/T\) \(\[Integral]\_\(a - T\)\%\(a + \
T\)\(\(f\^\((e)\)\)(t)\)\ \ cos[
              n\ \[CapitalDelta]\[Omega]\ \((\ t - a)\)/
                  2] \[DifferentialD]t\), \ 
    n > 0, \[IndentingNewLine]a\_o = \(1\/\(2  
              T\)\) \(\[Integral]\_\(a - T\)\%\(a + T\)\(\(f\^\((e)\)\)(
              t)\)\ \ \(\(\[DifferentialD]t\)\(.\)\)\)\)]]], "NE2",
  CellTags->"(2.2.6)"],

Cell[TextData[{
  " Let's break the integrals up into two pieces, running from ",
  Cell[BoxData[
      \(TraditionalForm\`a - T\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and from ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(a + T = b\)\)\)]],
  ", and use Eq. ",
  ButtonBox["(2.2.4)",
    ButtonData:>"(2.2.4)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`a\_n = \(1\/T\) \(\[Integral]\_\(a - T\)\%a\( f(
                  2  a - t)\)\ \ cos[
                  n\ \[CapitalDelta]\[Omega]\ \((\ t - a)\)/
                      2] \[DifferentialD]t\) + \[Integral]\_a\%b\( f(
                t)\)\ \ cos[
                n\ \[CapitalDelta]\[Omega]\ \((\ t - a)\)/
                    2] \[DifferentialD]t, \ \ \ n > 0, \)]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(a\_o\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(2  T\)\) \(\[Integral]\_\(a - T\)\%a\( f(
                2  a - t)\)\ \ \[DifferentialD]t\)\  + \(1\/\(2  
                T\)\) \(\[Integral]\_a\%b\( f(
                t)\)\ \ \(\(\[DifferentialD]t\)\(\ \)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(2.2.7)"],

Cell[TextData[{
  "Then, performing a change of variables in the first integral from ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`2  a - t\)]],
  ",  and using the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`cos(\(-t\)) = \(\(cos\)\(\ \)\(t\)\(\ \)\)\)]],
  "for any ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", we obtain "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`a\_n = \(2\/T\) \(\[Integral]\_a\%b\( f(t)\)\ \ cos[
              n\ \[CapitalDelta]\[Omega]\ \((\ t - a)\)/
                  2] \[DifferentialD]t\)\ , \ \ \ n > 
      0, \[IndentingNewLine]a\_o = \(1\/T\) \(\[Integral]\_a\%b\( f(
              t)\)\ \ \(\(\[DifferentialD]t\)\(.\)\)\)\)]]], "NE2",
  CellTags->"(2.2.8)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.2.5)",
    ButtonData:>"(2.2.5)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.2.8)",
    ButtonData:>"(2.2.8)",
    ButtonStyle->"Hyperlink"],
  " allow us to construct an even Fourier series of a function on the \
interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  ", with no discontinuities.  As an example, we will construct ",
  Cell[BoxData[
      \(TraditionalForm\`f\^\((e)\)\)]],
  " for the previous case of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = t\^2\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 1]\)\)]],
  ". "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T\  = \ 1; 
    a[n_]\  = \ 
      2/T\ Simplify[Integrate[t^2\ Cos[2\ Pi\ n\ t/\((2  T)\)], {t, 0, T}], 
          n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.32"],

Cell[BoxData[
    \(\(4\ \((\(-1\))\)\^n\)\/\(n\^2\ \[Pi]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(a[0]\  = \ 1/T\ Integrate[t^2, {t, 0, 1}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.33"],

Cell[BoxData[
    \(1\/3\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Terms in the series are now falling off like ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\^2\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\)]],
  ", so the series converges more rapidly than the previous series did. This \
can be seen directly from the plot in Cell ",
  ButtonBox["2.34",
    ButtonData:>"Cell 2.34",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f\_approx[x_, M_] := \ 
        Sum[a[n]\ Cos[2\ Pi\ n\ t/\((2  T)\)], {n, 0, 
            M}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(func\  = \ f\_approx[t, 10];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Plot[func, {t, \(-2\), 2}, PlotRange \[Rule] {\(-0.2\), 1.2}, 
        PlotLabel \[Rule] \*"\"\<\!\(f\^\((e)\)\)(t) for f(t)=\!\(t\^2\) on \
0<t<1\>\""];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.34"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.238095 0.0882906 0.441453 [
[.02381 .07579 -6 -9 ]
[.02381 .07579 6 0 ]
[.2619 .07579 -6 -9 ]
[.2619 .07579 6 0 ]
[.7381 .07579 -3 -9 ]
[.7381 .07579 3 0 ]
[.97619 .07579 -3 -9 ]
[.97619 .07579 3 0 ]
[.4875 0 -24 -4.5 ]
[.4875 0 0 4.5 ]
[.4875 .17658 -18 -4.5 ]
[.4875 .17658 0 4.5 ]
[.4875 .26487 -18 -4.5 ]
[.4875 .26487 0 4.5 ]
[.4875 .35316 -18 -4.5 ]
[.4875 .35316 0 4.5 ]
[.4875 .44145 -18 -4.5 ]
[.4875 .44145 0 4.5 ]
[.4875 .52974 -6 -4.5 ]
[.4875 .52974 0 4.5 ]
[.5 .63053 -83.4375 0 ]
[.5 .63053 83.4375 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .08829 m
.02381 .09454 L
s
[(-2)] .02381 .07579 0 1 Mshowa
.2619 .08829 m
.2619 .09454 L
s
[(-1)] .2619 .07579 0 1 Mshowa
.7381 .08829 m
.7381 .09454 L
s
[(1)] .7381 .07579 0 1 Mshowa
.97619 .08829 m
.97619 .09454 L
s
[(2)] .97619 .07579 0 1 Mshowa
.125 Mabswid
.07143 .08829 m
.07143 .09204 L
s
.11905 .08829 m
.11905 .09204 L
s
.16667 .08829 m
.16667 .09204 L
s
.21429 .08829 m
.21429 .09204 L
s
.30952 .08829 m
.30952 .09204 L
s
.35714 .08829 m
.35714 .09204 L
s
.40476 .08829 m
.40476 .09204 L
s
.45238 .08829 m
.45238 .09204 L
s
.54762 .08829 m
.54762 .09204 L
s
.59524 .08829 m
.59524 .09204 L
s
.64286 .08829 m
.64286 .09204 L
s
.69048 .08829 m
.69048 .09204 L
s
.78571 .08829 m
.78571 .09204 L
s
.83333 .08829 m
.83333 .09204 L
s
.88095 .08829 m
.88095 .09204 L
s
.92857 .08829 m
.92857 .09204 L
s
.25 Mabswid
0 .08829 m
1 .08829 L
s
.5 0 m
.50625 0 L
s
[(-0.2)] .4875 0 1 0 Mshowa
.5 .17658 m
.50625 .17658 L
s
[(0.2)] .4875 .17658 1 0 Mshowa
.5 .26487 m
.50625 .26487 L
s
[(0.4)] .4875 .26487 1 0 Mshowa
.5 .35316 m
.50625 .35316 L
s
[(0.6)] .4875 .35316 1 0 Mshowa
.5 .44145 m
.50625 .44145 L
s
[(0.8)] .4875 .44145 1 0 Mshowa
.5 .52974 m
.50625 .52974 L
s
[(1)] .4875 .52974 1 0 Mshowa
.125 Mabswid
.5 .02207 m
.50375 .02207 L
s
.5 .04415 m
.50375 .04415 L
s
.5 .06622 m
.50375 .06622 L
s
.5 .11036 m
.50375 .11036 L
s
.5 .13244 m
.50375 .13244 L
s
.5 .15451 m
.50375 .15451 L
s
.5 .19865 m
.50375 .19865 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .2428 m
.50375 .2428 L
s
.5 .28694 m
.50375 .28694 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33109 m
.50375 .33109 L
s
.5 .37523 m
.50375 .37523 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .41938 m
.50375 .41938 L
s
.5 .46353 m
.50375 .46353 L
s
.5 .4856 m
.50375 .4856 L
s
.5 .50767 m
.50375 .50767 L
s
.5 .55182 m
.50375 .55182 L
s
.5 .57389 m
.50375 .57389 L
s
.5 .59596 m
.50375 .59596 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -144.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 9.438 moveto
(H) show
73.188 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.375 9.438 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
82.625 13.438 moveto
(H) show
88.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
94.625 13.438 moveto
(L) show
106.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
130.625 13.438 moveto
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
136.625 13.438 moveto
(H) show
142.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
148.625 13.438 moveto
(L) show
154.625 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
160.625 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
166.625 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
177.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(on) show
195.875 13.438 moveto
(0) show
201.875 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
207.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
213.875 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
219.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
225.875 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0891 m
.02499 .0891 L
.02605 .0891 L
.02729 .0891 L
.02846 .0891 L
.02954 .08911 L
.03053 .08912 L
.03163 .08914 L
.03279 .08917 L
.03395 .08922 L
.0352 .08929 L
.03638 .08938 L
.03746 .08948 L
.03873 .08963 L
.04011 .08984 L
.04262 .09034 L
.04523 .09106 L
.04759 .09189 L
.0529 .09437 L
.06244 .10043 L
.07287 .10776 L
.08414 .11618 L
.09479 .12671 L
.10458 .13932 L
.14407 .20034 L
.18204 .2817 L
.22246 .39301 L
.2411 .45917 L
.24617 .47901 L
.25093 .49516 L
.25352 .50218 L
.25589 .5072 L
.25718 .50928 L
.25853 .51095 L
.25923 .51161 L
.25989 .51208 L
.2606 .51245 L
.26137 .51267 L
.26211 .51271 L
.2628 .51259 L
.26355 .5123 L
.26435 .51179 L
.26504 .5112 L
.26568 .51051 L
.26715 .50849 L
.26968 .5036 L
.2724 .49656 L
.28261 .45957 L
.30273 .3891 L
.34401 .27629 L
Mistroke
.38377 .19251 L
.42202 .13552 L
.43217 .12322 L
.44173 .11451 L
.45274 .10649 L
.46271 .0995 L
.46778 .09619 L
.4725 .09354 L
.47743 .09144 L
.48004 .09063 L
.48149 .09027 L
.48283 .08999 L
.48521 .08961 L
.48647 .08947 L
.4878 .08935 L
.48896 .08927 L
.49004 .08921 L
.49123 .08917 L
.49251 .08913 L
.49358 .08912 L
.49475 .08911 L
.49597 .0891 L
.4971 .0891 L
.49817 .0891 L
.49914 .0891 L
.50026 .0891 L
.50132 .0891 L
.50247 .0891 L
.50372 .0891 L
.50489 .0891 L
.50596 .08911 L
.50721 .08913 L
.50792 .08914 L
.50858 .08916 L
.50978 .0892 L
.51106 .08927 L
.51228 .08935 L
.51359 .08947 L
.51482 .08962 L
.51596 .08978 L
.51859 .09029 L
.52137 .09104 L
.52593 .0928 L
.53018 .09498 L
.53983 .10126 L
.55855 .11473 L
.5691 .1246 L
.57885 .13669 L
.60017 .16661 L
.62031 .20045 L
Mistroke
.65968 .28533 L
.69754 .38986 L
.71859 .4644 L
.72343 .48292 L
.72608 .49195 L
.72858 .4993 L
.73092 .50491 L
.73214 .50731 L
.73344 .50938 L
.73454 .51076 L
.73574 .51185 L
.73683 .51247 L
.73785 .51271 L
.73908 .51257 L
.74025 .512 L
.7413 .51113 L
.74244 .50981 L
.74368 .50795 L
.745 .5055 L
.74736 .49997 L
.75229 .48459 L
.75774 .46383 L
.77664 .39561 L
.81686 .28444 L
.85557 .20107 L
.87523 .16774 L
.89673 .13752 L
.90666 .12507 L
.91727 .11503 L
.93637 .10125 L
.94621 .09487 L
.9489 .09344 L
.95175 .09215 L
.95421 .09124 L
.95686 .09047 L
.95935 .08993 L
.96162 .08959 L
.96271 .08946 L
.9639 .08935 L
.96503 .08928 L
.96607 .08922 L
.96671 .08919 L
.96739 .08917 L
.96864 .08914 L
.96986 .08912 L
.97097 .08911 L
.97218 .0891 L
.97287 .0891 L
.97351 .0891 L
.97481 .0891 L
Mistroke
.97553 .0891 L
.97619 .0891 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo002jOol20007Ool30004Ool6003POol00;Uoo`04001oogoo0006Ool3
0005Ool01@00Oomoogoo0000h7oo002hOol00`00Oomoo`02Ool00`00Oomoo`03Ool30006Ool00`00
Oomoo`08Ool3003FOol00:moo`L0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Mo
o`03001oogoo0=Ioo`00^7oo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol01Woo00<007oo
Ool0eWoo002hOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`3FOol0
0;Qoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo0=Ioo`00^Goo00@0
07ooOol000eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo0=Ioo`00^Woo0P003goo1000
27oo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo0P00egoo
003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00
Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol0
0=Moo`800=Moo`00egoo00<007ooOol0eWoo000ROol6001FOol5001DOol00`00Oomoo`1EOol5001E
Ool6000QOol002=oo`05001oogooOol0001HOol00`00Oomoo`1DOol00`00Oomoo`1GOol00`00Oomo
o`1FOol01@00Oomoogoo00008Goo000TOol00`00Oomoo`1IOol00`00Oomoo`1DOol00`00Oomoo`1G
Ool00`00Oomoo`1GOol00`00Oomoo`0ROol001Uoo`L000Eoo`03001oogoo04aoo`L000Eoo`03001o
ogoo05Aoo`03001oogoo05Moo`03001oogoo05Qoo`03001oogoo025oo`009Woo00<007ooOol0Egoo
00<007ooOol0E7oo00<007ooOol0Egoo00<007ooOol0FGoo00<007ooOol087oo000WOol00`00Oomo
o`1FOol00`00Oomoo`1DOol00`00Oomoo`1GOol00`00Oomoo`1JOol00`00Oomoo`0OOol002Moo`03
001oogoo05Ioo`03001oogoo05Aoo`03001oogoo05Moo`03001oogoo05Yoo`03001oogoo01moo`00
8Woo00<007ooOol00Woo00<007ooOol0E7oo0`00EWoo0P00EWoo0`00Egoo00<007ooOol00Woo00<0
07ooOol07goo000SOol4001HOol2001FOol00`00Oomoo`1FOol2001HOol4000ROol00=Moo`03001o
ogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00
egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol001Qoool0080001Uoo`008Goo00<007ooOol0
0goo1@0027oo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol03goo00<007ooOol01Woo1000
1Goo00<007ooOol00goo100027oo00<007ooOol03goo00<007ooOol03goo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<007ooOol03goo00<0
07ooOol01goo10001Goo00<007ooOol087oo000QOol00`00Oomoo`08Ool2001>Ool00`00Oomoo`1=
Ool20009Ool00`00Oomoo`07Ool2001?Ool00`00Oomoo`1=Ool20009Ool00`00Oomoo`0POol002io
o`03001oogoo09Uoo`8000]oo`03001oogoo00Uoo`8009]oo`8002ioo`00;goo00<007ooOol0UWoo
0P003Goo00<007ooOol02goo00<007ooOol0UWoo0P00<7oo000`Ool2002EOol00`00Oomoo`0=Ool0
0`00Oomoo`0<Ool2002DOol2000bOol0039oo`80099oo`03001oogoo00ioo`03001oogoo00ioo`03
001oogoo091oo`03001oogoo039oo`00=7oo00<007ooOol0SGoo0P004Goo00<007ooOol03goo0P00
SWoo0P00=Goo000eOol00`00Oomoo`2;Ool00`00Oomoo`0AOol2000BOol00`00Oomoo`2:Ool00`00
Oomoo`0eOol003Ioo`03001oogoo08Uoo`03001oogoo019oo`03001oogoo019oo`03001oogoo08Qo
o`03001oogoo03Ioo`00=goo00<007ooOol0QWoo0P005Goo00<007ooOol04goo00<007ooOol0QWoo
00<007ooOol0=goo000hOol00`00Oomoo`24Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomo
o`24Ool00`00Oomoo`0hOol003Uoo`03001oogoo089oo`03001oogoo01Ioo`03001oogoo01Eoo`03
001oogoo089oo`03001oogoo03Uoo`00>Woo00<007ooOol0P7oo00<007ooOol05goo00<007ooOol0
5Woo00<007ooOol0P7oo00<007ooOol0>Woo000kOol00`00Oomoo`1oOol00`00Oomoo`0GOol00`00
Oomoo`0GOol00`00Oomoo`1nOol00`00Oomoo`0kOol003aoo`03001oogoo07eoo`03001oogoo01Qo
o`03001oogoo01Moo`03001oogoo07ioo`03001oogoo03]oo`00?7oo00<007ooOol0O7oo00<007oo
Ool06Goo00<007ooOol067oo00<007ooOol0O7oo00<007ooOol0?7oo000mOol00`00Oomoo`1jOol0
0`00Oomoo`0JOol2000JOol00`00Oomoo`1jOol00`00Oomoo`0mOol003ioo`03001oogoo07Qoo`03
001oogoo01]oo`03001oogoo01Yoo`03001oogoo07Qoo`03001oogoo03ioo`00?goo00<007ooOol0
Mgoo00<007ooOol06goo00<007ooOol06goo00<007ooOol0MWoo00<007ooOol0?goo0010Ool00`00
Oomoo`1eOol00`00Oomoo`0LOol00`00Oomoo`0KOol00`00Oomoo`1fOol00`00Oomoo`0oOol0041o
o`03001oogoo07Aoo`03001oogoo01eoo`03001oogoo01aoo`03001oogoo07Aoo`03001oogoo041o
o`00@Goo00<007ooOol0Lgoo00<007ooOol07Goo00<007ooOol07Goo00<007ooOol0LWoo00<007oo
Ool0@Goo0012Ool00`00Oomoo`1aOol00`00Oomoo`0NOol00`00Oomoo`0NOol00`00Oomoo`1`Ool0
0`00Oomoo`12Ool0049oo`03001oogoo071oo`03001oogoo01moo`03001oogoo01ioo`03001oogoo
071oo`03001oogoo049oo`00@goo00<007ooOol0Kgoo00<007ooOol07goo0P0087oo00<007ooOol0
KWoo00<007ooOol0@goo0014Ool00`00Oomoo`1]Ool00`00Oomoo`0POol00`00Oomoo`0POol00`00
Oomoo`1/Ool00`00Oomoo`14Ool004Aoo`03001oogoo06eoo`03001oogoo021oo`03001oogoo021o
o`03001oogoo06aoo`03001oogoo04Aoo`00AGoo00<007ooOol0Jgoo00<007ooOol08Goo00<007oo
Ool08Goo00<007ooOol0JWoo00<007ooOol0AGoo0016Ool00`00Oomoo`1YOol00`00Oomoo`0ROol0
0`00Oomoo`0ROol00`00Oomoo`1XOol00`00Oomoo`16Ool004Ioo`03001oogoo06Uoo`03001oogoo
029oo`03001oogoo02=oo`03001oogoo06Ioo`03001oogoo04Moo`00Agoo00<007ooOol0Igoo00<0
07ooOol01Woo0P001goo0`0017oo1P001goo00<007ooOol08goo00<007ooOol0IWoo00<007ooOol0
Agoo0018Ool00`00Oomoo`1UOol00`00Oomoo`06Ool01000Oomoo`001Woo0`001Goo00D007ooOomo
o`0000Moo`03001oogoo02Aoo`03001oogoo06Aoo`03001oogoo04Qoo`00B7oo00<007ooOol0IGoo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo0`001Woo00<007ooOol027oo00<007oo
Ool09Goo00<007ooOol0Hgoo00<007ooOol0B7oo0019Ool00`00Oomoo`1SOol00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool3000UOol00`00Oomoo`1ROol00`00Oomo
o`19Ool004Uoo`03001oogoo069oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00ioo`03
001oogoo00Ioo`03001oogoo02Ioo`03001oogoo065oo`03001oogoo04Uoo`00BWoo00<007ooOol0
HGoo00<007ooOol01goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol01Goo00<007ooOol0
9Woo00<007ooOol0H7oo00<007ooOol0BWoo001;Ool00`00Oomoo`1OOol00`00Oomoo`08Ool00`00
Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0WOol00`00Oomoo`1NOol00`00
Oomoo`1;Ool004]oo`03001oogoo05moo`03001oogoo00Uoo`04001oogoo000=Ool00`00Oomoo`02
Ool00`00Oomoo`05Ool00`00Oomoo`0XOol00`00Oomoo`1MOol00`00Oomoo`1;Ool004aoo`03001o
ogoo05eoo`03001oogoo00]oo`8000moo`@000Qoo`03001oogoo02Qoo`03001oogoo05aoo`03001o
ogoo04aoo`00CGoo00<007ooOol0Fgoo00<007ooOol0:Goo00<007ooOol0:Goo00<007ooOol0Fgoo
00<007ooOol0C7oo001=Ool00`00Oomoo`1KOol00`00Oomoo`0YOol00`00Oomoo`0YOol00`00Oomo
o`1JOol00`00Oomoo`1=Ool004ioo`03001oogoo05Uoo`03001oogoo02Yoo`8002]oo`03001oogoo
05Uoo`03001oogoo04eoo`00Cgoo00<007ooOol0F7oo00<007ooOol0:Woo00<007ooOol0:goo00<0
07ooOol0Egoo00<007ooOol0CWoo001?Ool00`00Oomoo`1GOol00`00Oomoo`0[Ool00`00Oomoo`0[
Ool00`00Oomoo`1GOol00`00Oomoo`1>Ool0051oo`03001oogoo05Ioo`03001oogoo02]oo`03001o
ogoo02aoo`03001oogoo05Eoo`03001oogoo04moo`00D7oo00<007ooOol0EGoo00<007ooOol0;7oo
00<007ooOol0;7oo00<007ooOol0EGoo00<007ooOol0Cgoo001AOol00`00Oomoo`1DOol00`00Oomo
o`0/Ool00`00Oomoo`0]Ool00`00Oomoo`1COol00`00Oomoo`1@Ool0055oo`03001oogoo05=oo`03
001oogoo02eoo`03001oogoo02eoo`03001oogoo05=oo`03001oogoo051oo`00DWoo00<007ooOol0
DWoo00<007ooOol0;Goo00<007ooOol0;Woo00<007ooOol0DGoo00<007ooOol0DGoo001BOol00`00
Oomoo`1BOol00`00Oomoo`0]Ool00`00Oomoo`0^Ool00`00Oomoo`1AOol00`00Oomoo`1AOol005=o
o`03001oogoo051oo`03001oogoo02ioo`80031oo`03001oogoo04moo`03001oogoo059oo`00Dgoo
00<007ooOol0D7oo00<007ooOol0;Woo00<007ooOol0;goo00<007ooOol0Cgoo00<007ooOol0DWoo
001DOol00`00Oomoo`1>Ool00`00Oomoo`0_Ool00`00Oomoo`0_Ool00`00Oomoo`1?Ool00`00Oomo
o`1BOol005Aoo`03001oogoo04ioo`03001oogoo02moo`03001oogoo031oo`03001oogoo04eoo`03
001oogoo05=oo`00EGoo00<007ooOol0C7oo00<007ooOol0<7oo00<007ooOol0<7oo00<007ooOol0
CGoo00<007ooOol0Dgoo001EOol00`00Oomoo`1<Ool00`00Oomoo`0`Ool00`00Oomoo`0aOol00`00
Oomoo`1;Ool00`00Oomoo`1DOol005Ioo`03001oogoo04Yoo`03001oogoo035oo`03001oogoo035o
o`03001oogoo04]oo`03001oogoo05Aoo`00EWoo00<007ooOol0BWoo00<007ooOol0<Goo00<007oo
Ool0<Woo00<007ooOol0BGoo00<007ooOol0EGoo001GOol00`00Oomoo`18Ool00`00Oomoo`0bOol2
000cOol00`00Oomoo`19Ool00`00Oomoo`1EOol005Moo`03001oogoo04Qoo`03001oogoo039oo`03
001oogoo03=oo`03001oogoo04Moo`03001oogoo05Ioo`00Egoo00<007ooOol0Agoo00<007ooOol0
<goo00<007ooOol0<goo00<007ooOol0Agoo00<007ooOol0EWoo001HOol00`00Oomoo`16Ool00`00
Oomoo`0cOol00`00Oomoo`0dOol00`00Oomoo`15Ool00`00Oomoo`1GOol005Qoo`03001oogoo04Eo
o`03001oogoo03Aoo`03001oogoo03Aoo`03001oogoo04Eoo`03001oogoo05Moo`00FGoo00<007oo
Ool0A7oo00<007ooOol0=7oo00<007ooOol0=Goo00<007ooOol0@goo00<007ooOol0F7oo001IOol0
0`00Oomoo`14Ool00`00Oomoo`0GOol20007Ool30007Ool30007Ool00`00Oomoo`0eOol00`00Oomo
o`13Ool00`00Oomoo`1HOol005Yoo`03001oogoo049oo`03001oogoo01Moo`04001oogoo0006Ool3
0008Ool00`00Oomoo`06Ool00`00Oomoo`0fOol00`00Oomoo`11Ool00`00Oomoo`1IOol005Yoo`03
001oogoo049oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo00=oo`<000Aoo`H000Moo`<0
03Ioo`03001oogoo045oo`03001oogoo05Uoo`00Fgoo00<007ooOol0@7oo00<007ooOol05goo00<0
07ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000Qoo`03001oogoo03Ioo`03001oogoo045o
o`03001oogoo05Uoo`00Fgoo00<007ooOol0@7oo00<007ooOol05goo00<007ooOol00Woo00<007oo
Ool02goo00@007ooOol000Qoo`03001oogoo03Moo`03001oogoo03moo`03001oogoo05Yoo`00G7oo
00<007ooOol0?Woo00<007ooOol067oo00<007ooOol00Woo00<007ooOol037oo00<007oo000027oo
00<007ooOol0=goo00<007ooOol0?goo00<007ooOol0FWoo001LOol00`00Oomoo`0nOol00`00Oomo
o`0HOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Ool00008Ool00`00Oomoo`0hOol00`00Oomo
o`0mOol00`00Oomoo`1KOol005eoo`03001oogoo03aoo`03001oogoo01Yoo`04001oogoo000@Ool2
0008Ool00`00Oomoo`0hOol00`00Oomoo`0mOol00`00Oomoo`1KOol005eoo`03001oogoo03aoo`03
001oogoo01]oo`80019oo`03001oogoo00Ioo`03001oogoo03Uoo`03001oogoo03]oo`03001oogoo
05aoo`00GWoo00<007ooOol0>Woo00<007ooOol0>Goo00<007ooOol0>Goo00<007ooOol0>goo00<0
07ooOol0G7oo001NOol00`00Oomoo`0jOol00`00Oomoo`0iOol00`00Oomoo`0jOol00`00Oomoo`0i
Ool00`00Oomoo`1MOol005moo`03001oogoo03Uoo`03001oogoo03Uoo`8003]oo`03001oogoo03Uo
o`03001oogoo05eoo`00Ggoo00<007ooOol0>7oo00<007ooOol0>Woo00<007ooOol0>goo00<007oo
Ool0=goo00<007ooOol0GWoo001OOol00`00Oomoo`0hOol00`00Oomoo`0jOol00`00Oomoo`0kOol0
0`00Oomoo`0gOol00`00Oomoo`1NOol0061oo`03001oogoo03Moo`03001oogoo03Yoo`03001oogoo
03]oo`03001oogoo03Moo`03001oogoo05ioo`00H7oo00<007ooOol0=Woo00<007ooOol0>goo00<0
07ooOol0?7oo00<007ooOol0=Goo00<007ooOol0Ggoo001POol00`00Oomoo`0fOol00`00Oomoo`0k
Ool00`00Oomoo`0lOol00`00Oomoo`0eOol00`00Oomoo`1OOol0065oo`03001oogoo03Aoo`03001o
ogoo03aoo`03001oogoo03aoo`03001oogoo03Eoo`03001oogoo05moo`00HGoo00<007ooOol0=7oo
00<007ooOol0?7oo00<007ooOol0?Goo00<007ooOol0<goo00<007ooOol0H7oo001QOol00`00Oomo
o`0dOol00`00Oomoo`0lOol2000nOol00`00Oomoo`0cOol00`00Oomoo`1POol0069oo`03001oogoo
039oo`03001oogoo03eoo`03001oogoo03eoo`03001oogoo03=oo`03001oogoo061oo`00HWoo00<0
07ooOol0<Woo00<007ooOol0?Goo00<007ooOol0?Woo00<007ooOol0<Goo00<007ooOol0HGoo001R
Ool00`00Oomoo`0bOol00`00Oomoo`0mOol00`00Oomoo`0nOol00`00Oomoo`0aOol00`00Oomoo`1Q
Ool006=oo`03001oogoo031oo`03001oogoo03ioo`03001oogoo03ioo`03001oogoo035oo`03001o
ogoo065oo`00Hgoo00<007ooOol0<7oo00<007ooOol0?Woo00<007ooOol0?goo00<007ooOol0;goo
00<007ooOol0HWoo001TOol00`00Oomoo`0^Ool00`00Oomoo`0oOol00`00Oomoo`0oOol00`00Oomo
o`0_Ool00`00Oomoo`1ROol006Aoo`03001oogoo02ioo`03001oogoo03moo`03001oogoo03moo`03
001oogoo02ioo`03001oogoo06=oo`00I7oo00<007ooOol0;Woo00<007ooOol0?goo00<007ooOol0
@7oo00<007ooOol0;Goo00<007ooOol0Hgoo001UOol00`00Oomoo`0/Ool00`00Oomoo`10Ool20011
Ool00`00Oomoo`0]Ool00`00Oomoo`1SOol006Eoo`03001oogoo02aoo`03001oogoo041oo`03001o
ogoo041oo`03001oogoo02aoo`03001oogoo06Aoo`00IGoo00<007ooOol0;7oo00<007ooOol0@7oo
00<007ooOol0@Goo00<007ooOol0:goo00<007ooOol0I7oo001VOol00`00Oomoo`0ZOol00`00Oomo
o`11Ool00`00Oomoo`11Ool00`00Oomoo`0[Ool00`00Oomoo`1TOol006Ioo`03001oogoo02Yoo`03
001oogoo045oo`03001oogoo049oo`03001oogoo02Uoo`03001oogoo06Eoo`00IWoo00<007ooOol0
:Woo00<007ooOol0@Goo00<007ooOol0@Woo00<007ooOol0:Goo00<007ooOol0IGoo001WOol00`00
Oomoo`0XOol00`00Oomoo`0UOol20007Ool30005Ool40008Ool00`00Oomoo`12Ool00`00Oomoo`0Y
Ool00`00Oomoo`1UOol006Moo`03001oogoo02Qoo`03001oogoo02Aoo`04001oogoo0006Ool30004
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`13Ool00`00Oomoo`0WOol00`00Oomoo`1V
Ool006Moo`03001oogoo02Moo`03001oogoo02Aoo`03001oogoo009oo`03001oogoo00=oo`<000Ao
o`03001oogoo009oo`03001oogoo00Eoo`<004=oo`03001oogoo02Moo`03001oogoo06Ioo`00J7oo
00<007ooOol09Woo00<007ooOol097oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol0@goo00<007ooOol09goo00<007ooOol0IWoo001XOol00`00Oomo
o`0VOol00`00Oomoo`0TOol00`00Oomoo`02Ool00`00Oomoo`0:Ool20003Ool00`00Oomoo`05Ool0
0`00Oomoo`14Ool00`00Oomoo`0UOol00`00Oomoo`1WOol006Uoo`03001oogoo02Aoo`03001oogoo
02Eoo`03001oogoo009oo`03001oogoo00Yoo`03001oo`00008000Qoo`03001oogoo04Aoo`03001o
ogoo02Eoo`03001oogoo06Moo`00JGoo00<007ooOol097oo00<007ooOol09Goo00<007ooOol00Woo
00<007ooOol02goo00<007ooOol02Goo00<007ooOol0A7oo00<007ooOol097oo00<007ooOol0J7oo
001YOol00`00Oomoo`0TOol00`00Oomoo`0VOol01000Oomoo`003Woo0P002Woo00<007ooOol0AGoo
00<007ooOol08goo00<007ooOol0J7oo001ZOol00`00Oomoo`0ROol00`00Oomoo`0XOol2000AOol3
0007Ool00`00Oomoo`15Ool00`00Oomoo`0SOol00`00Oomoo`1XOol006Yoo`03001oogoo029oo`03
001oogoo04Eoo`03001oogoo04Eoo`03001oogoo029oo`03001oogoo06Uoo`00JWoo00<007ooOol0
8Goo00<007ooOol0AWoo0P00Agoo00<007ooOol08Goo00<007ooOol0JGoo001[Ool00`00Oomoo`0P
Ool00`00Oomoo`16Ool00`00Oomoo`16Ool00`00Oomoo`0QOol00`00Oomoo`1YOol006]oo`03001o
ogoo021oo`03001oogoo04Ioo`03001oogoo04Ioo`03001oogoo021oo`03001oogoo06Yoo`00Jgoo
00<007ooOol07goo00<007ooOol0Agoo00<007ooOol0Agoo00<007ooOol07goo00<007ooOol0JWoo
001/Ool00`00Oomoo`0NOol00`00Oomoo`17Ool00`00Oomoo`17Ool00`00Oomoo`0OOol00`00Oomo
o`1ZOol006aoo`03001oogoo01ioo`03001oogoo04Moo`03001oogoo04Moo`03001oogoo01ioo`03
001oogoo06]oo`00K7oo00<007ooOol07Goo00<007ooOol0B7oo00<007ooOol0B7oo00<007ooOol0
7Goo00<007ooOol0Jgoo001]Ool00`00Oomoo`0LOol00`00Oomoo`18Ool00`00Oomoo`18Ool00`00
Oomoo`0MOol00`00Oomoo`1[Ool006eoo`03001oogoo01aoo`03001oogoo04Qoo`03001oogoo04Qo
o`03001oogoo01aoo`03001oogoo06aoo`00KGoo00<007ooOol06goo00<007ooOol0BGoo0P00BWoo
00<007ooOol06goo00<007ooOol0K7oo001^Ool00`00Oomoo`0JOol00`00Oomoo`19Ool00`00Oomo
o`19Ool00`00Oomoo`0KOol00`00Oomoo`1/Ool006ioo`03001oogoo01Yoo`03001oogoo04Uoo`03
001oogoo04Uoo`03001oogoo01Yoo`03001oogoo06eoo`00KWoo00<007ooOol06Goo00<007ooOol0
BWoo00<007ooOol0BWoo00<007ooOol06Goo00<007ooOol0KGoo001_Ool00`00Oomoo`0HOol00`00
Oomoo`1:Ool00`00Oomoo`1:Ool00`00Oomoo`0IOol00`00Oomoo`1]Ool006moo`03001oogoo01Qo
o`03001oogoo04Yoo`03001oogoo04Yoo`03001oogoo01Qoo`03001oogoo06ioo`00Kgoo00<007oo
Ool05goo00<007ooOol0Bgoo00<007ooOol0BWoo00<007ooOol067oo00<007ooOol0KWoo001_Ool0
0`00Oomoo`0GOol00`00Oomoo`1;Ool00`00Oomoo`1;Ool00`00Oomoo`0GOol00`00Oomoo`1^Ool0
071oo`03001oogoo01Ioo`03001oogoo04]oo`8004aoo`03001oogoo01Ioo`03001oogoo06moo`00
L7oo00<007ooOol05Woo00<007ooOol0Bgoo00<007ooOol0Bgoo00<007ooOol05Woo00<007ooOol0
Kgoo001`Ool00`00Oomoo`0EOol00`00Oomoo`1<Ool00`00Oomoo`1<Ool00`00Oomoo`0EOol00`00
Oomoo`1_Ool0075oo`03001oogoo01Aoo`03001oogoo04aoo`03001oogoo04aoo`03001oogoo01Ao
o`03001oogoo071oo`00LGoo00<007ooOol057oo00<007ooOol0C7oo00<007ooOol0C7oo00<007oo
Ool057oo00<007ooOol0L7oo001aOol00`00Oomoo`0COol00`00Oomoo`1=Ool00`00Oomoo`1<Ool0
0`00Oomoo`0DOol00`00Oomoo`1`Ool0075oo`03001oogoo01=oo`03001oogoo031oo`8000Moo`<0
00Eoo`@000Qoo`03001oogoo04eoo`03001oogoo01=oo`03001oogoo071oo`00LWoo00<007ooOol0
4Woo00<007ooOol0;goo00@007ooOol000Ioo`<000Aoo`03001oogoo009oo`03001oogoo00Eoo`03
001oogoo04eoo`03001oogoo019oo`03001oogoo075oo`00LWoo00<007ooOol04Woo00<007ooOol0
;Woo00<007ooOol00Woo00<007ooOol00goo0`0017oo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol0CGoo00<007ooOol04Woo00<007ooOol0LGoo001bOol00`00Oomoo`0AOol00`00Oomoo`0_
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3001>Ool00`00
Oomoo`0AOol00`00Oomoo`1aOol0079oo`03001oogoo015oo`03001oogoo02moo`03001oogoo009o
o`03001oogoo00]oo`@000Qoo`03001oogoo04ioo`03001oogoo011oo`03001oogoo079oo`00Lgoo
00<007ooOol047oo00<007ooOol0;goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo
00<007ooOol01Goo00<007ooOol0CWoo00<007ooOol047oo00<007ooOol0LWoo001cOol00`00Oomo
o`0?Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`1>Ool00`00Oomoo`0@Ool00`00Oomoo`1bOol007=oo`03001oogoo00moo`03
001oogoo035oo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1?Ool0
0`00Oomoo`0>Ool00`00Oomoo`1cOol007Aoo`03001oogoo00ioo`03001oogoo039oo`8000moo`@0
00Qoo`03001oogoo04moo`03001oogoo00ioo`03001oogoo07=oo`00M7oo00<007ooOol03Goo00<0
07ooOol0D7oo00<007ooOol0Cgoo00<007ooOol03Woo00<007ooOol0Lgoo001dOol00`00Oomoo`0=
Ool00`00Oomoo`1@Ool00`00Oomoo`1@Ool00`00Oomoo`0<Ool00`00Oomoo`1dOol007Aoo`03001o
ogoo00eoo`03001oogoo051oo`80055oo`03001oogoo00aoo`03001oogoo07Aoo`00MGoo00<007oo
Ool037oo00<007ooOol0D7oo00<007ooOol0D7oo00<007ooOol037oo00<007ooOol0M7oo001eOol0
0`00Oomoo`0;Ool00`00Oomoo`1AOol00`00Oomoo`1@Ool00`00Oomoo`0<Ool00`00Oomoo`1dOol0
07Eoo`03001oogoo00]oo`03001oogoo055oo`03001oogoo055oo`03001oogoo00Yoo`03001oogoo
07Eoo`00MGoo00<007ooOol02goo00<007ooOol0DGoo00<007ooOol0DGoo00<007ooOol02Woo00<0
07ooOol0MGoo001fOol00`00Oomoo`09Ool00`00Oomoo`1BOol00`00Oomoo`1AOol00`00Oomoo`0:
Ool00`00Oomoo`1eOol007Ioo`03001oogoo00Uoo`03001oogoo059oo`03001oogoo055oo`03001o
ogoo00Yoo`03001oogoo07Eoo`00MWoo00<007ooOol02Goo00<007ooOol0DWoo00<007ooOol0DWoo
00<007ooOol027oo00<007ooOol0MWoo001gOol00`00Oomoo`08Ool00`00Oomoo`1BOol00`00Oomo
o`1BOol00`00Oomoo`08Ool00`00Oomoo`1fOol007Moo`03001oogoo00Moo`03001oogoo05=oo`80
05=oo`03001oogoo00Qoo`03001oogoo07Ioo`00Mgoo00<007ooOol01goo00<007ooOol0Dgoo00<0
07ooOol0Dgoo00<007ooOol01Woo00<007ooOol0Mgoo001hOol00`00Oomoo`06Ool00`00Oomoo`1C
Ool00`00Oomoo`1COol00`00Oomoo`06Ool00`00Oomoo`1gOol007Qoo`03001oogoo00Eoo`03001o
ogoo05Aoo`03001oogoo05=oo`03001oogoo00Ioo`03001oogoo07Moo`00N7oo00<007ooOol01Goo
00<007ooOol0E7oo00<007ooOol0E7oo00<007ooOol017oo00<007ooOol0N7oo001iOol00`00Oomo
o`04Ool00`00Oomoo`1DOol00`00Oomoo`1DOol00`00Oomoo`04Ool00`00Oomoo`1hOol007Uoo`03
001oogoo00=oo`03001oogoo05Eoo`03001oogoo05Aoo`03001oogoo00Aoo`03001oogoo07Qoo`00
NGoo00<007ooOol00goo00<007ooOol0EGoo00<007ooOol0EGoo00<007ooOol00Woo00<007ooOol0
NGoo001jOol01@00Oomoogoo0000F7oo0P00Egoo00D007ooOomoo`0007]oo`00NWoo0P0000=oo`00
0000F7oo00<007ooOol0EWoo00@007ooOol007aoo`00Ngoo0`00FGoo00<007ooOol0Egoo0`00O7oo
003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003;Ool50007
Ool00`00Oomoo`3FOol00<eoo`03001oogoo00Moo`03001oogoo0=Ioo`00cGoo00<007ooOol01goo
0`00eWoo003=Ool00`00Oomoo`07Ool00`00Oomoo`3FOol00<eoo`03001oogoo00Moo`03001oogoo
0=Ioo`00cGoo00<007ooOol01goo00<007ooOol0eWoo003=Ool00`00Oomoo`07Ool00`00Oomoo`3F
Ool00<]oo`<000Uoo`03001oogoo0=Ioo`00c7oo0P002Goo00<007ooOol0eWoo003GOol00`00Oomo
o`3FOol00=Moo`03001oogoo0=Ioo`00egoo0P00egoo003GOol00`00Oomoo`3FOol00=Moo`03001o
ogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00
egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`800=Moo`00egoo00<007ooOol0eWoo
003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00
Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol0
0=Moo`800=Moo`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Io
o`00egoo00<007ooOol0eWoo003GOol00`00Oomoo`3FOol00=Moo`03001oogoo0=Ioo`00egoo00<0
07ooOol0eWoo003GOol00`00Oomoo`3FOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol0081oo`03001oogoo00]oo`03001oogoo041oo`03001oogoo00]oo`03001o
ogoo0<ioo`00Ogoo00<007ooOol03Goo00<007ooOol0?Woo00<007ooOol03Goo00<007ooOol0cGoo
001oOol00`00Oomoo`0=Ool00`00Oomoo`0nOol00`00Oomoo`0=Ool00`00Oomoo`3=Ool005ioo`H0
01Yoo`03001oogoo00Eoo`@000Ioo`03001oogoo00aoo`H000Eoo`<000Aoo`H000aoo`H000Ioo`03
001oogoo00Eoo`@000Ioo`03001oogoo00ioo`@001Ioo`<000Aoo`<0009oo`<000aoo`8000Yoo`03
001oogoo00=oo`@000Qoo`03001oogoo009oo`D0065oo`00H7oo00<007ooOol06goo00<007ooOol0
17oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol01Goo00D007ooOomo
o`0000Eoo`03001oogoo00moo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03001o
ogoo00=oo`03001oogoo00Aoo`H000=oo`03001oogoo009oo`03001oogoo019oo`05001oogooOol0
0004Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomoo`001goo0P001Goo00<007ooOol00Woo
00<007ooOol00goo0P001goo00<007ooOol0HGoo001POol00`00Oomoo`0KOol00`00Oomoo`04Ool0
0`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool0
0`00Oomoo`0FOol00`00Oomoo`03Ool01@00Oomoogoo000017oo00<007ooOol02Goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
HGoo001POol00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00
Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`0FOol00`00Oomoo`03Ool01@00
Oomoogoo000017oo00<007ooOol02Goo00<007ooOol00Woo00@007ooOomoo`8000Qoo`03001oogoo
00Eoo`8000Yoo`03001oogoo065oo`00H7oo00<007ooOol027oo00<007ooOol01Goo00<007ooOol0
27oo00<007ooOol017oo00<007ooOol027oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol01goo00<007ooOol017oo00<007ooOol0
27oo00<007ooOol017oo1P000goo00<007ooOol05Woo00<007ooOol00goo00D007ooOomoo`0000Ao
o`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Mo
o`03001oogoo00Moo`03001oogoo065oo`00H7oo00<007ooOol01goo00<007ooOol01goo00<007oo
Ool01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol03Woo00<007ooOol01Goo00D007oo
Oomoo`0000Eoo`80011oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo
00eoo`03001oogoo01Moo`05001oogooOol00004Ool20003Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool20005Ool00`00Oomoo`08Ool20007Ool00`00Oomoo`1QOol005ioo`H000Eo
o`03001oogoo009oo`@000=oo`03001oogoo00Moo`04001oogooOol70005Ool00`00Oomoo`0=Ool6
0005Ool30004Ool300000goo00000002000:Ool60007Ool01000Oomoogoo1`001Goo00<007ooOol0
37oo1`000goo10003goo0`0017oo0P0000Aoo`00000000aoo`03001oogoo009oo`03001oogoo00Io
o`03001oogoo00L000Qoo`03001oogoo00Aoo`03001oogoo065oo`00H7oo00<007ooOol01Woo00D0
07ooOomoo`0000Moo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00mo
o`03001oogoo025oo`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00io
o`03001oogoo00Ioo`03001oogoo02Uoo`04001oogoo000>Ool00`00Oomoo`0?Ool3001SOol0061o
o`03001oogoo00Ioo`04001oogooOol50003Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomoo`09Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`0YOol2000?Ool00`00Oomoo`0@Ool2
001SOol0065oo`<000Eoo`05001oogooOol00003Ool01@00Oomoogoo00003goo00<007ooOol06Woo
0`008Goo0`003Goo00<007ooOol067oo00<007ooOol01goo00<007ooOol0>Woo00<007ooOol0MGoo
001YOol00`00Oomoo`02Ool30004Ool00`00Oomoo`24Ool00`00Oomoo`2aOol006Yoo`03001oogoo
00Moo`03001oogoo089oo`04001oogoo002cOol006]oo`03001oogoo00Eoo`03001oogoo08Aoo`80
0;Aoo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-2, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Note that we have only kept 10 terms in the series, but it still works \
quite well. There is no-longer a Gibb's phenomenon; the series converges \
uniformly and rapidly to ",
  Cell[BoxData[
      \(TraditionalForm\`t\^2\)]],
  " on the interval [0,1]. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2.3 Odd Periodic Extension ", "Subsubtitle",
  CellTags->{"i:31", "c:16"}],

Cell[TextData[{
  "It is also possible to define an odd periodic extension to a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", defined on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([a, b]\)\)]],
  ". This extension, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((o)\)\)(t)\)]],
  ", is odd around the point ",
  Cell[BoxData[
      \(TraditionalForm\`t = a\)]],
  ", and is defined by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\^\((o)\)\)(t)\), "=", 
          TagBox[
            StyleBox[
              RowBox[{"{", 
                StyleBox[GridBox[{
                      {\(\(\ \ \ \ \)\(f(t), \ \ \ \ \ \ \ \ \ \ \ \ a < t < 
                          a + T, \)\)},
                      {\(\(-\(f(2  a - t)\)\), \ a - T < t < a, \)}
                      }],
                  ShowAutoStyles->True]}],
              ShowAutoStyles->False],
            (#&)]}], TraditionalForm]]],
  "\n\n",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((o)\)\)(
          t + 2  T) = \(\(\(f\^\((o)\)\)(t)\)\(.\)\)\)]]
}], "NE2",
  CellTags->"(2.2.9)"],

Cell[TextData[{
  "\tThis type of periodic extension is useful when one considers functions \
",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " for which ",
  Cell[BoxData[
      \(TraditionalForm\`f(a) = \(f(b) = 0\)\)]],
  ". Although  the periodic extension and the even periodic extension of such \
functions are both continuous at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(=\)\(a\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", the odd periodic extension also exhibits a continuous first derivative \
at the boundary points, as can be seen in Fig. ",
  ButtonBox["2.5",
    ButtonData:>"Fig. 2.5",
    ButtonStyle->"Hyperlink"],
  ". This makes the series converge even faster than the other types of \
periodic extension. However, if either ",
  Cell[BoxData[
      \(TraditionalForm\`f(a)\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`f(b)\)]],
  " is unequal to zero, the convergence will be hampered by discontinuities \
in the odd periodic extension. "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0793651 0.309017 0.0245252 [
[.02381 .29652 -6 -9 ]
[.02381 .29652 6 0 ]
[.18254 .29652 -6 -9 ]
[.18254 .29652 6 0 ]
[.34127 .29652 -6 -9 ]
[.34127 .29652 6 0 ]
[.65873 .29652 -3 -9 ]
[.65873 .29652 3 0 ]
[.81746 .29652 -3 -9 ]
[.81746 .29652 3 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.4875 .06377 -18 -4.5 ]
[.4875 .06377 0 4.5 ]
[.4875 .18639 -12 -4.5 ]
[.4875 .18639 0 4.5 ]
[.4875 .43164 -6 -4.5 ]
[.4875 .43164 0 4.5 ]
[.4875 .55427 -12 -4.5 ]
[.4875 .55427 0 4.5 ]
[.5 .64303 -14 0 ]
[.5 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(-6)] .02381 .29652 0 1 Mshowa
.18254 .30902 m
.18254 .31527 L
s
[(-4)] .18254 .29652 0 1 Mshowa
.34127 .30902 m
.34127 .31527 L
s
[(-2)] .34127 .29652 0 1 Mshowa
.65873 .30902 m
.65873 .31527 L
s
[(2)] .65873 .29652 0 1 Mshowa
.81746 .30902 m
.81746 .31527 L
s
[(4)] .81746 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(6)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.06349 .30902 m
.06349 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.38095 .30902 m
.38095 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.57937 .30902 m
.57937 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.77778 .30902 m
.77778 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .06377 m
.50625 .06377 L
s
[(-10)] .4875 .06377 1 0 Mshowa
.5 .18639 m
.50625 .18639 L
s
[(-5)] .4875 .18639 1 0 Mshowa
.5 .43164 m
.50625 .43164 L
s
[(5)] .4875 .43164 1 0 Mshowa
.5 .55427 m
.50625 .55427 L
s
[(10)] .4875 .55427 1 0 Mshowa
.125 Mabswid
.5 .08829 m
.50375 .08829 L
s
.5 .11282 m
.50375 .11282 L
s
.5 .13734 m
.50375 .13734 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .21092 m
.50375 .21092 L
s
.5 .23544 m
.50375 .23544 L
s
.5 .25997 m
.50375 .25997 L
s
.5 .28449 m
.50375 .28449 L
s
.5 .33354 m
.50375 .33354 L
s
.5 .35807 m
.50375 .35807 L
s
.5 .38259 m
.50375 .38259 L
s
.5 .40712 m
.50375 .40712 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .48069 m
.50375 .48069 L
s
.5 .50522 m
.50375 .50522 L
s
.5 .52974 m
.50375 .52974 L
s
.5 .03924 m
.50375 .03924 L
s
.5 .01472 m
.50375 .01472 L
s
.5 .57879 m
.50375 .57879 L
s
.5 .60332 m
.50375 .60332 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .38259 m
.04262 .45084 L
.0522 .48874 L
.05746 .50792 L
.06244 .52347 L
.06506 .53016 L
.06644 .53317 L
.0679 .53593 L
.06912 .53787 L
.07047 .53956 L
.0717 .54068 L
.07286 .54132 L
.07411 .54155 L
.0753 .54129 L
.07636 .54062 L
.07753 .53941 L
.07879 .53749 L
.08013 .53469 L
.08255 .52757 L
.08404 .52174 L
.08541 .51532 L
.0885 .49679 L
.09123 .4753 L
.09411 .44671 L
.0991 .38072 L
.10458 .28232 L
.10982 .20057 L
.1124 .16961 L
.11478 .14576 L
.11924 .11216 L
.12159 .09952 L
.12289 .09385 L
.12409 .08945 L
.12527 .0858 L
.12656 .08256 L
.12785 .08004 L
.12857 .07896 L
.12922 .07815 L
.13042 .07709 L
.13171 .07654 L
.1329 .07654 L
.13403 .07696 L
.13466 .07737 L
.13536 .07795 L
.13677 .07954 L
.13808 .08147 L
.1393 .08364 L
.145 .09771 L
.15541 .13415 L
.16529 .1734 L
Mistroke
.18383 .23936 L
.19344 .2648 L
.19871 .27584 L
.20367 .28441 L
.20832 .29095 L
.21333 .29654 L
.21789 .30045 L
.22207 .30319 L
.22679 .30544 L
.22943 .30638 L
.23183 .30707 L
.23408 .30758 L
.23651 .30802 L
.23881 .30833 L
.24094 .30855 L
.24212 .30864 L
.2434 .30873 L
.24571 .30885 L
.24705 .3089 L
.24845 .30894 L
.24966 .30896 L
.25097 .30898 L
.25169 .30899 L
.25237 .309 L
.25364 .30901 L
.25435 .30901 L
.25501 .30901 L
.25573 .30901 L
.25649 .30901 L
.25775 .30902 L
.25893 .30902 L
.26022 .30902 L
.26095 .30902 L
.26161 .30902 L
.26279 .30902 L
.26389 .30902 L
.2651 .30902 L
.26641 .30902 L
.2677 .30902 L
.26836 .30902 L
.26907 .30902 L
.27033 .30903 L
.27151 .30904 L
.2727 .30905 L
.27383 .30907 L
.27484 .30909 L
.27594 .30911 L
.27713 .30915 L
.2784 .3092 L
.28067 .30932 L
Mistroke
.28196 .30941 L
.28313 .30951 L
.28578 .3098 L
.28822 .31017 L
.29055 .31063 L
.29325 .31131 L
.29575 .31211 L
.29871 .31331 L
.30143 .31468 L
.30651 .31803 L
.312 .32304 L
.31685 .32885 L
.32196 .33658 L
.33084 .35432 L
.34058 .38046 L
.36174 .45746 L
.37176 .49662 L
.37616 .51206 L
.38102 .52647 L
.38326 .53182 L
.38567 .53645 L
.38699 .53843 L
.38821 .53985 L
.38938 .54083 L
.3906 .54142 L
.39185 .54153 L
.39254 .54137 L
.39318 .54107 L
.39441 .54008 L
.39558 .53859 L
.39693 .53616 L
.39819 .5332 L
.40102 .52377 L
.40328 .5132 L
.4054 .50062 L
.40791 .48191 L
.41021 .46093 L
.41491 .40503 L
.41995 .32233 L
.4247 .23745 L
.42917 .17732 L
.43165 .15131 L
.43432 .12842 L
.43655 .1131 L
.43899 .09983 L
.44172 .08889 L
.44321 .0845 L
.4446 .08134 L
.4459 .07914 L
.44709 .07773 L
Mistroke
.44774 .07718 L
.44846 .07677 L
.44975 .07648 L
.45095 .07671 L
.45227 .07748 L
.45293 .07806 L
.45365 .07882 L
.45494 .08053 L
.45744 .085 L
.45973 .09024 L
.46957 .12161 L
.47871 .15725 L
.48937 .19897 L
.49943 .23365 L
.50928 .26099 L
.51446 .27247 L
.51994 .2825 L
.52456 .28936 L
.52963 .29537 L
.53424 .29959 L
.53854 .3026 L
.54354 .30515 L
.54637 .30621 L
.54899 .30699 L
.55127 .30752 L
.55379 .30799 L
.55642 .30835 L
.55889 .30859 L
.56115 .30875 L
.56229 .30881 L
.56354 .30886 L
.56461 .3089 L
.56575 .30893 L
.56683 .30896 L
.56781 .30897 L
.56905 .30899 L
.57019 .309 L
.57144 .30901 L
.57207 .30901 L
.57276 .30901 L
.57393 .30901 L
.57518 .30902 L
.57636 .30902 L
.57744 .30902 L
.57873 .30902 L
.57995 .30902 L
.58104 .30902 L
.58222 .30902 L
.58351 .30902 L
.58416 .30902 L
Mistroke
.58487 .30902 L
.58613 .30902 L
.5873 .30903 L
.58849 .30903 L
.58962 .30904 L
.59063 .30906 L
.59172 .30907 L
.59291 .3091 L
.59418 .30914 L
.59526 .30917 L
.59645 .30923 L
.59776 .3093 L
.59914 .30939 L
.6016 .30961 L
.60426 .30994 L
.60715 .31045 L
.60967 .31103 L
.61235 .31182 L
.61719 .31379 L
.61978 .31519 L
.62253 .31697 L
.62745 .32102 L
.63275 .32682 L
.63856 .33516 L
.64899 .35593 L
.65873 .38258 L
.67733 .45 L
.68715 .48885 L
.69253 .50841 L
.69759 .52409 L
.70032 .53093 L
.70282 .53593 L
.70417 .53805 L
.7056 .53978 L
.70634 .54046 L
.70703 .54095 L
.70779 .54133 L
.7086 .54153 L
.70991 .5414 L
.71066 .54106 L
.71134 .54057 L
.7126 .53921 L
.71324 .53828 L
.71394 .53707 L
.71515 .53447 L
.71645 .53094 L
.71879 .52246 L
.72137 .50975 L
.72418 .49133 L
.72666 .4707 L
Mistroke
.7293 .44368 L
.73428 .37664 L
.73891 .29336 L
.74391 .21179 L
.74919 .1505 L
.75196 .1271 L
.75499 .10733 L
.75775 .09412 L
.76032 .08543 L
.76158 .08234 L
.76294 .07977 L
.76423 .07806 L
.76542 .07704 L
.76649 .07657 L
.76767 .07651 L
.7689 .07694 L
.77006 .07775 L
.77134 .07909 L
.77268 .08096 L
.77508 .08537 L
.7805 .09941 L
.80047 .17441 L
.81861 .23895 L
.8287 .26557 L
.83823 .28384 L
.84346 .29123 L
.84828 .29657 L
.85358 .30101 L
.85645 .30287 L
.85918 .30433 L
.86154 .30537 L
.86411 .30631 L
.86648 .307 L
.86862 .3075 L
.87117 .30797 L
.87388 .30835 L
.87509 .30848 L
.8764 .30859 L
.87762 .30869 L
.87876 .30876 L
.88098 .30886 L
.88215 .3089 L
.88341 .30894 L
.88472 .30896 L
.88597 .30898 L
.88709 .30899 L
.88831 .309 L
.88936 .30901 L
.89052 .30901 L
.89173 .30902 L
Mistroke
.89286 .30902 L
.89392 .30902 L
.89489 .30902 L
.89601 .30902 L
.89707 .30902 L
.89832 .30902 L
.89902 .30902 L
.89966 .30902 L
.90084 .30902 L
.90209 .30902 L
.90322 .30902 L
.90427 .30902 L
.90542 .30903 L
.90665 .30904 L
.90796 .30905 L
.9087 .30907 L
.90939 .30908 L
.91065 .30911 L
.91199 .30915 L
.91318 .30919 L
.9143 .30924 L
.91553 .30932 L
.91686 .30941 L
.91911 .30961 L
.92147 .30991 L
.92366 .31026 L
.9257 .31068 L
.93031 .31199 L
.9329 .31299 L
.93524 .31409 L
.94008 .31703 L
.94521 .32131 L
.94959 .32607 L
.95441 .33263 L
.96515 .35291 L
.9752 .37957 L
.97619 .38259 L
Mfstroke
.006 w
.57937 .30902 m
.57956 .30902 L
.57974 .30902 L
.57995 .30902 L
.58014 .30902 L
.58032 .30902 L
.58049 .30902 L
.58067 .30902 L
.58086 .30902 L
.58106 .30902 L
.58126 .30902 L
.58146 .30902 L
.58164 .30902 L
.58185 .30902 L
.58208 .30902 L
.5823 .30902 L
.5825 .30902 L
.58271 .30902 L
.58293 .30902 L
.58334 .30902 L
.58373 .30902 L
.5841 .30902 L
.58449 .30902 L
.58493 .30902 L
.5858 .30902 L
.58628 .30902 L
.58672 .30902 L
.58756 .30903 L
.58846 .30903 L
.58944 .30904 L
.59029 .30905 L
.5912 .30907 L
.59205 .30908 L
.59283 .3091 L
.59439 .30914 L
.59607 .30921 L
.59756 .30928 L
.59912 .30939 L
.60071 .30952 L
.60241 .3097 L
.60547 .31013 L
.60718 .31045 L
.60903 .31086 L
.61239 .31183 L
.6157 .3131 L
.61921 .31485 L
.62552 .31929 L
.62876 .32231 L
.63224 .3262 L
.63912 .33608 L
Mistroke
.64575 .34864 L
.65212 .36375 L
.65891 .38314 L
.66544 .40482 L
.67238 .43053 L
.67906 .45693 L
.6855 .48248 L
.69234 .50776 L
.69575 .51879 L
.69893 .52762 L
.70199 .53443 L
.70371 .53737 L
.70527 .53942 L
.70607 .54023 L
.70651 .54059 L
.70692 .54088 L
.7073 .54111 L
.70765 .54127 L
.70804 .54141 L
.70824 .54147 L
.70845 .54151 L
.70867 .54154 L
.70887 .54155 L
.70898 .54155 L
.7091 .54155 L
.70931 .54153 L
.70951 .5415 L
.70973 .54145 L
.70991 .5414 L
.71011 .54133 L
.71056 .54112 L
.71104 .54081 L
.71192 .54003 L
.7128 .53895 L
.71361 .53766 L
.71545 .53371 L
.71708 .52893 L
.7188 .52241 L
.72205 .50577 L
.72509 .48424 L
.72845 .45295 L
.73153 .41636 L
.7381 .30902 L
Mfstroke
.5 Mabswid
.02381 .38259 m
.04262 .45084 L
.0522 .48874 L
.05746 .50792 L
.06244 .52347 L
.06506 .53016 L
.06644 .53317 L
.0679 .53593 L
.06912 .53787 L
.07047 .53956 L
.0717 .54068 L
.07286 .54132 L
.07411 .54155 L
.0753 .54129 L
.07636 .54062 L
.07753 .53941 L
.07879 .53749 L
.08013 .53469 L
.08255 .52757 L
.08404 .52174 L
.08541 .51532 L
.0885 .49679 L
.09123 .4753 L
.09411 .44671 L
.0991 .38072 L
.10458 .28232 L
.10982 .20057 L
.1124 .16961 L
.11478 .14576 L
.11924 .11216 L
.12159 .09952 L
.12289 .09385 L
.12409 .08945 L
.12527 .0858 L
.12656 .08256 L
.12785 .08004 L
.12857 .07896 L
.12922 .07815 L
.13042 .07709 L
.13171 .07654 L
.1329 .07654 L
.13403 .07696 L
.13466 .07737 L
.13536 .07795 L
.13677 .07954 L
.13808 .08147 L
.1393 .08364 L
.145 .09771 L
.15541 .13415 L
.16529 .1734 L
Mistroke
.18383 .23936 L
.19344 .2648 L
.19871 .27584 L
.20367 .28441 L
.20832 .29095 L
.21333 .29654 L
.21789 .30045 L
.22207 .30319 L
.22679 .30544 L
.22943 .30638 L
.23183 .30707 L
.23408 .30758 L
.23651 .30802 L
.23881 .30833 L
.24094 .30855 L
.24212 .30864 L
.2434 .30873 L
.24571 .30885 L
.24705 .3089 L
.24845 .30894 L
.24966 .30896 L
.25097 .30898 L
.25169 .30899 L
.25237 .309 L
.25364 .30901 L
.25435 .30901 L
.25501 .30901 L
.25573 .30901 L
.25649 .30901 L
.25775 .30902 L
.25893 .30902 L
.26022 .30902 L
.26095 .30902 L
.26161 .30902 L
.26279 .30902 L
.26389 .30902 L
.2651 .30902 L
.26641 .30902 L
.2677 .30902 L
.26836 .30902 L
.26907 .30902 L
.27033 .30903 L
.27151 .30904 L
.2727 .30905 L
.27383 .30907 L
.27484 .30909 L
.27594 .30911 L
.27713 .30915 L
.2784 .3092 L
.28067 .30932 L
Mistroke
.28196 .30941 L
.28313 .30951 L
.28578 .3098 L
.28822 .31017 L
.29055 .31063 L
.29325 .31131 L
.29575 .31211 L
.29871 .31331 L
.30143 .31468 L
.30651 .31803 L
.312 .32304 L
.31685 .32885 L
.32196 .33658 L
.33084 .35432 L
.34058 .38046 L
.36174 .45746 L
.37176 .49662 L
.37616 .51206 L
.38102 .52647 L
.38326 .53182 L
.38567 .53645 L
.38699 .53843 L
.38821 .53985 L
.38938 .54083 L
.3906 .54142 L
.39185 .54153 L
.39254 .54137 L
.39318 .54107 L
.39441 .54008 L
.39558 .53859 L
.39693 .53616 L
.39819 .5332 L
.40102 .52377 L
.40328 .5132 L
.4054 .50062 L
.40791 .48191 L
.41021 .46093 L
.41491 .40503 L
.41995 .32233 L
.4247 .23745 L
.42917 .17732 L
.43165 .15131 L
.43432 .12842 L
.43655 .1131 L
.43899 .09983 L
.44172 .08889 L
.44321 .0845 L
.4446 .08134 L
.4459 .07914 L
.44709 .07773 L
Mistroke
.44774 .07718 L
.44846 .07677 L
.44975 .07648 L
.45095 .07671 L
.45227 .07748 L
.45293 .07806 L
.45365 .07882 L
.45494 .08053 L
.45744 .085 L
.45973 .09024 L
.46957 .12161 L
.47871 .15725 L
.48937 .19897 L
.49943 .23365 L
.50928 .26099 L
.51446 .27247 L
.51994 .2825 L
.52456 .28936 L
.52963 .29537 L
.53424 .29959 L
.53854 .3026 L
.54354 .30515 L
.54637 .30621 L
.54899 .30699 L
.55127 .30752 L
.55379 .30799 L
.55642 .30835 L
.55889 .30859 L
.56115 .30875 L
.56229 .30881 L
.56354 .30886 L
.56461 .3089 L
.56575 .30893 L
.56683 .30896 L
.56781 .30897 L
.56905 .30899 L
.57019 .309 L
.57144 .30901 L
.57207 .30901 L
.57276 .30901 L
.57393 .30901 L
.57518 .30902 L
.57636 .30902 L
.57744 .30902 L
.57873 .30902 L
.57995 .30902 L
.58104 .30902 L
.58222 .30902 L
.58351 .30902 L
.58416 .30902 L
Mistroke
.58487 .30902 L
.58613 .30902 L
.5873 .30903 L
.58849 .30903 L
.58962 .30904 L
.59063 .30906 L
.59172 .30907 L
.59291 .3091 L
.59418 .30914 L
.59526 .30917 L
.59645 .30923 L
.59776 .3093 L
.59914 .30939 L
.6016 .30961 L
.60426 .30994 L
.60715 .31045 L
.60967 .31103 L
.61235 .31182 L
.61719 .31379 L
.61978 .31519 L
.62253 .31697 L
.62745 .32102 L
.63275 .32682 L
.63856 .33516 L
.64899 .35593 L
.65873 .38258 L
.67733 .45 L
.68715 .48885 L
.69253 .50841 L
.69759 .52409 L
.70032 .53093 L
.70282 .53593 L
.70417 .53805 L
.7056 .53978 L
.70634 .54046 L
.70703 .54095 L
.70779 .54133 L
.7086 .54153 L
.70991 .5414 L
.71066 .54106 L
.71134 .54057 L
.7126 .53921 L
.71324 .53828 L
.71394 .53707 L
.71515 .53447 L
.71645 .53094 L
.71879 .52246 L
.72137 .50975 L
.72418 .49133 L
.72666 .4707 L
Mistroke
.7293 .44368 L
.73428 .37664 L
.73891 .29336 L
.74391 .21179 L
.74919 .1505 L
.75196 .1271 L
.75499 .10733 L
.75775 .09412 L
.76032 .08543 L
.76158 .08234 L
.76294 .07977 L
.76423 .07806 L
.76542 .07704 L
.76649 .07657 L
.76767 .07651 L
.7689 .07694 L
.77006 .07775 L
.77134 .07909 L
.77268 .08096 L
.77508 .08537 L
.7805 .09941 L
.80047 .17441 L
.81861 .23895 L
.8287 .26557 L
.83823 .28384 L
.84346 .29123 L
.84828 .29657 L
.85358 .30101 L
.85645 .30287 L
.85918 .30433 L
.86154 .30537 L
.86411 .30631 L
.86648 .307 L
.86862 .3075 L
.87117 .30797 L
.87388 .30835 L
.87509 .30848 L
.8764 .30859 L
.87762 .30869 L
.87876 .30876 L
.88098 .30886 L
.88215 .3089 L
.88341 .30894 L
.88472 .30896 L
.88597 .30898 L
.88709 .30899 L
.88831 .309 L
.88936 .30901 L
.89052 .30901 L
.89173 .30902 L
Mistroke
.89286 .30902 L
.89392 .30902 L
.89489 .30902 L
.89601 .30902 L
.89707 .30902 L
.89832 .30902 L
.89902 .30902 L
.89966 .30902 L
.90084 .30902 L
.90209 .30902 L
.90322 .30902 L
.90427 .30902 L
.90542 .30903 L
.90665 .30904 L
.90796 .30905 L
.9087 .30907 L
.90939 .30908 L
.91065 .30911 L
.91199 .30915 L
.91318 .30919 L
.9143 .30924 L
.91553 .30932 L
.91686 .30941 L
.91911 .30961 L
.92147 .30991 L
.92366 .31026 L
.9257 .31068 L
.93031 .31199 L
.9329 .31299 L
.93524 .31409 L
.94008 .31703 L
.94521 .32131 L
.94959 .32607 L
.95441 .33263 L
.96515 .35291 L
.9752 .37957 L
.97619 .38259 L
Mfstroke
.006 w
.57937 .30902 m
.57956 .30902 L
.57974 .30902 L
.57995 .30902 L
.58014 .30902 L
.58032 .30902 L
.58049 .30902 L
.58067 .30902 L
.58086 .30902 L
.58106 .30902 L
.58126 .30902 L
.58146 .30902 L
.58164 .30902 L
.58185 .30902 L
.58208 .30902 L
.5823 .30902 L
.5825 .30902 L
.58271 .30902 L
.58293 .30902 L
.58334 .30902 L
.58373 .30902 L
.5841 .30902 L
.58449 .30902 L
.58493 .30902 L
.5858 .30902 L
.58628 .30902 L
.58672 .30902 L
.58756 .30903 L
.58846 .30903 L
.58944 .30904 L
.59029 .30905 L
.5912 .30907 L
.59205 .30908 L
.59283 .3091 L
.59439 .30914 L
.59607 .30921 L
.59756 .30928 L
.59912 .30939 L
.60071 .30952 L
.60241 .3097 L
.60547 .31013 L
.60718 .31045 L
.60903 .31086 L
.61239 .31183 L
.6157 .3131 L
.61921 .31485 L
.62552 .31929 L
.62876 .32231 L
.63224 .3262 L
.63912 .33608 L
Mistroke
.64575 .34864 L
.65212 .36375 L
.65891 .38314 L
.66544 .40482 L
.67238 .43053 L
.67906 .45693 L
.6855 .48248 L
.69234 .50776 L
.69575 .51879 L
.69893 .52762 L
.70199 .53443 L
.70371 .53737 L
.70527 .53942 L
.70607 .54023 L
.70651 .54059 L
.70692 .54088 L
.7073 .54111 L
.70765 .54127 L
.70804 .54141 L
.70824 .54147 L
.70845 .54151 L
.70867 .54154 L
.70887 .54155 L
.70898 .54155 L
.7091 .54155 L
.70931 .54153 L
.70951 .5415 L
.70973 .54145 L
.70991 .5414 L
.71011 .54133 L
.71056 .54112 L
.71104 .54081 L
.71192 .54003 L
.7128 .53895 L
.71361 .53766 L
.71545 .53371 L
.71708 .52893 L
.7188 .52241 L
.72205 .50577 L
.72509 .48424 L
.72845 .45295 L
.73153 .41636 L
.7381 .30902 L
Mfstroke
.5 Mabswid
.02381 .38259 m
.04262 .45084 L
.0522 .48874 L
.05746 .50792 L
.06244 .52347 L
.06506 .53016 L
.06644 .53317 L
.0679 .53593 L
.06912 .53787 L
.07047 .53956 L
.0717 .54068 L
.07286 .54132 L
.07411 .54155 L
.0753 .54129 L
.07636 .54062 L
.07753 .53941 L
.07879 .53749 L
.08013 .53469 L
.08255 .52757 L
.08404 .52174 L
.08541 .51532 L
.0885 .49679 L
.09123 .4753 L
.09411 .44671 L
.0991 .38072 L
.10458 .28232 L
.10982 .20057 L
.1124 .16961 L
.11478 .14576 L
.11924 .11216 L
.12159 .09952 L
.12289 .09385 L
.12409 .08945 L
.12527 .0858 L
.12656 .08256 L
.12785 .08004 L
.12857 .07896 L
.12922 .07815 L
.13042 .07709 L
.13171 .07654 L
.1329 .07654 L
.13403 .07696 L
.13466 .07737 L
.13536 .07795 L
.13677 .07954 L
.13808 .08147 L
.1393 .08364 L
.145 .09771 L
.15541 .13415 L
.16529 .1734 L
Mistroke
.18383 .23936 L
.19344 .2648 L
.19871 .27584 L
.20367 .28441 L
.20832 .29095 L
.21333 .29654 L
.21789 .30045 L
.22207 .30319 L
.22679 .30544 L
.22943 .30638 L
.23183 .30707 L
.23408 .30758 L
.23651 .30802 L
.23881 .30833 L
.24094 .30855 L
.24212 .30864 L
.2434 .30873 L
.24571 .30885 L
.24705 .3089 L
.24845 .30894 L
.24966 .30896 L
.25097 .30898 L
.25169 .30899 L
.25237 .309 L
.25364 .30901 L
.25435 .30901 L
.25501 .30901 L
.25573 .30901 L
.25649 .30901 L
.25775 .30902 L
.25893 .30902 L
.26022 .30902 L
.26095 .30902 L
.26161 .30902 L
.26279 .30902 L
.26389 .30902 L
.2651 .30902 L
.26641 .30902 L
.2677 .30902 L
.26836 .30902 L
.26907 .30902 L
.27033 .30903 L
.27151 .30904 L
.2727 .30905 L
.27383 .30907 L
.27484 .30909 L
.27594 .30911 L
.27713 .30915 L
.2784 .3092 L
.28067 .30932 L
Mistroke
.28196 .30941 L
.28313 .30951 L
.28578 .3098 L
.28822 .31017 L
.29055 .31063 L
.29325 .31131 L
.29575 .31211 L
.29871 .31331 L
.30143 .31468 L
.30651 .31803 L
.312 .32304 L
.31685 .32885 L
.32196 .33658 L
.33084 .35432 L
.34058 .38046 L
.36174 .45746 L
.37176 .49662 L
.37616 .51206 L
.38102 .52647 L
.38326 .53182 L
.38567 .53645 L
.38699 .53843 L
.38821 .53985 L
.38938 .54083 L
.3906 .54142 L
.39185 .54153 L
.39254 .54137 L
.39318 .54107 L
.39441 .54008 L
.39558 .53859 L
.39693 .53616 L
.39819 .5332 L
.40102 .52377 L
.40328 .5132 L
.4054 .50062 L
.40791 .48191 L
.41021 .46093 L
.41491 .40503 L
.41995 .32233 L
.4247 .23745 L
.42917 .17732 L
.43165 .15131 L
.43432 .12842 L
.43655 .1131 L
.43899 .09983 L
.44172 .08889 L
.44321 .0845 L
.4446 .08134 L
.4459 .07914 L
.44709 .07773 L
Mistroke
.44774 .07718 L
.44846 .07677 L
.44975 .07648 L
.45095 .07671 L
.45227 .07748 L
.45293 .07806 L
.45365 .07882 L
.45494 .08053 L
.45744 .085 L
.45973 .09024 L
.46957 .12161 L
.47871 .15725 L
.48937 .19897 L
.49943 .23365 L
.50928 .26099 L
.51446 .27247 L
.51994 .2825 L
.52456 .28936 L
.52963 .29537 L
.53424 .29959 L
.53854 .3026 L
.54354 .30515 L
.54637 .30621 L
.54899 .30699 L
.55127 .30752 L
.55379 .30799 L
.55642 .30835 L
.55889 .30859 L
.56115 .30875 L
.56229 .30881 L
.56354 .30886 L
.56461 .3089 L
.56575 .30893 L
.56683 .30896 L
.56781 .30897 L
.56905 .30899 L
.57019 .309 L
.57144 .30901 L
.57207 .30901 L
.57276 .30901 L
.57393 .30901 L
.57518 .30902 L
.57636 .30902 L
.57744 .30902 L
.57873 .30902 L
.57995 .30902 L
.58104 .30902 L
.58222 .30902 L
.58351 .30902 L
.58416 .30902 L
Mistroke
.58487 .30902 L
.58613 .30902 L
.5873 .30903 L
.58849 .30903 L
.58962 .30904 L
.59063 .30906 L
.59172 .30907 L
.59291 .3091 L
.59418 .30914 L
.59526 .30917 L
.59645 .30923 L
.59776 .3093 L
.59914 .30939 L
.6016 .30961 L
.60426 .30994 L
.60715 .31045 L
.60967 .31103 L
.61235 .31182 L
.61719 .31379 L
.61978 .31519 L
.62253 .31697 L
.62745 .32102 L
.63275 .32682 L
.63856 .33516 L
.64899 .35593 L
.65873 .38258 L
.67733 .45 L
.68715 .48885 L
.69253 .50841 L
.69759 .52409 L
.70032 .53093 L
.70282 .53593 L
.70417 .53805 L
.7056 .53978 L
.70634 .54046 L
.70703 .54095 L
.70779 .54133 L
.7086 .54153 L
.70991 .5414 L
.71066 .54106 L
.71134 .54057 L
.7126 .53921 L
.71324 .53828 L
.71394 .53707 L
.71515 .53447 L
.71645 .53094 L
.71879 .52246 L
.72137 .50975 L
.72418 .49133 L
.72666 .4707 L
Mistroke
.7293 .44368 L
.73428 .37664 L
.73891 .29336 L
.74391 .21179 L
.74919 .1505 L
.75196 .1271 L
.75499 .10733 L
.75775 .09412 L
.76032 .08543 L
.76158 .08234 L
.76294 .07977 L
.76423 .07806 L
.76542 .07704 L
.76649 .07657 L
.76767 .07651 L
.7689 .07694 L
.77006 .07775 L
.77134 .07909 L
.77268 .08096 L
.77508 .08537 L
.7805 .09941 L
.80047 .17441 L
.81861 .23895 L
.8287 .26557 L
.83823 .28384 L
.84346 .29123 L
.84828 .29657 L
.85358 .30101 L
.85645 .30287 L
.85918 .30433 L
.86154 .30537 L
.86411 .30631 L
.86648 .307 L
.86862 .3075 L
.87117 .30797 L
.87388 .30835 L
.87509 .30848 L
.8764 .30859 L
.87762 .30869 L
.87876 .30876 L
.88098 .30886 L
.88215 .3089 L
.88341 .30894 L
.88472 .30896 L
.88597 .30898 L
.88709 .30899 L
.88831 .309 L
.88936 .30901 L
.89052 .30901 L
.89173 .30902 L
Mistroke
.89286 .30902 L
.89392 .30902 L
.89489 .30902 L
.89601 .30902 L
.89707 .30902 L
.89832 .30902 L
.89902 .30902 L
.89966 .30902 L
.90084 .30902 L
.90209 .30902 L
.90322 .30902 L
.90427 .30902 L
.90542 .30903 L
.90665 .30904 L
.90796 .30905 L
.9087 .30907 L
.90939 .30908 L
.91065 .30911 L
.91199 .30915 L
.91318 .30919 L
.9143 .30924 L
.91553 .30932 L
.91686 .30941 L
.91911 .30961 L
.92147 .30991 L
.92366 .31026 L
.9257 .31068 L
.93031 .31199 L
.9329 .31299 L
.93524 .31409 L
.94008 .31703 L
.94521 .32131 L
.94959 .32607 L
.95441 .33263 L
.96515 .35291 L
.9752 .37957 L
.97619 .38259 L
Mfstroke
.006 w
.57937 .30902 m
.57956 .30902 L
.57974 .30902 L
.57995 .30902 L
.58014 .30902 L
.58032 .30902 L
.58049 .30902 L
.58067 .30902 L
.58086 .30902 L
.58106 .30902 L
.58126 .30902 L
.58146 .30902 L
.58164 .30902 L
.58185 .30902 L
.58208 .30902 L
.5823 .30902 L
.5825 .30902 L
.58271 .30902 L
.58293 .30902 L
.58334 .30902 L
.58373 .30902 L
.5841 .30902 L
.58449 .30902 L
.58493 .30902 L
.5858 .30902 L
.58628 .30902 L
.58672 .30902 L
.58756 .30903 L
.58846 .30903 L
.58944 .30904 L
.59029 .30905 L
.5912 .30907 L
.59205 .30908 L
.59283 .3091 L
.59439 .30914 L
.59607 .30921 L
.59756 .30928 L
.59912 .30939 L
.60071 .30952 L
.60241 .3097 L
.60547 .31013 L
.60718 .31045 L
.60903 .31086 L
.61239 .31183 L
.6157 .3131 L
.61921 .31485 L
.62552 .31929 L
.62876 .32231 L
.63224 .3262 L
.63912 .33608 L
Mistroke
.64575 .34864 L
.65212 .36375 L
.65891 .38314 L
.66544 .40482 L
.67238 .43053 L
.67906 .45693 L
.6855 .48248 L
.69234 .50776 L
.69575 .51879 L
.69893 .52762 L
.70199 .53443 L
.70371 .53737 L
.70527 .53942 L
.70607 .54023 L
.70651 .54059 L
.70692 .54088 L
.7073 .54111 L
.70765 .54127 L
.70804 .54141 L
.70824 .54147 L
.70845 .54151 L
.70867 .54154 L
.70887 .54155 L
.70898 .54155 L
.7091 .54155 L
.70931 .54153 L
.70951 .5415 L
.70973 .54145 L
.70991 .5414 L
.71011 .54133 L
.71056 .54112 L
.71104 .54081 L
.71192 .54003 L
.7128 .53895 L
.71361 .53766 L
.71545 .53371 L
.71708 .52893 L
.7188 .52241 L
.72205 .50577 L
.72509 .48424 L
.72845 .45295 L
.73153 .41636 L
.7381 .30902 L
Mfstroke
.5 Mabswid
[ .05 .05 ] 0 setdash
.57937 .11282 m
.57937 .50522 L
s
.7381 .11282 m
.7381 .50522 L
s
.7381 .01472 m
.7381 .60332 L
s
.57937 .01472 m
.57937 .60332 L
s
gsave
.54762 .52974 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.76984 .52974 -66 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogoo47oo00<007oo
Ool0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo
47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?mo
obmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool2000VOol00`00Oomoo`1?Ool00`00Oomo
o`2dOol00?mooa1oo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Aoo`00ogoo47oo00<0
07ooOol09Goo00<007ooOol0Cgoo00<007ooOol0]7oo003oOol@Ool00`00Oomoo`0UOol00`00Oomo
o`1?Ool00`00Oomoo`2dOol00?mooa1oo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Ao
o`00ogoo47oo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol0]7oo003oOol@Ool00`00Oomo
o`0UOol00`00Oomoo`1?Ool00`00Oomoo`2dOol00?mooa1oo`03001oogoo02Eoo`03001oogoo04mo
o`03001oogoo0;Aoo`00ogoo47oo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol0]7oo003o
Ool@Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`2dOol00?mooa1oo`03001oogoo02Eo
o`03001oogoo04moo`03001oogoo0;Aoo`00ogoo47oo00<007ooOol09Goo00<007ooOol0Cgoo00<0
07ooOol0]7oo003oOol@Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`2dOol00?mooa1o
o`8002Ioo`03001oogoo04moo`03001oogoo0;Aoo`00ogoo47oo00<007ooOol09Goo00<007ooOol0
Cgoo00<007ooOol0]7oo003oOol@Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`2dOol0
0?mooa1oo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Aoo`00ogoo47oo00<007ooOol0
9Goo00<007ooOol0Cgoo00<007ooOol0]7oo003oOol@Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool0
0`00Oomoo`2dOol00?mooa1oo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Aoo`00ogoo
47oo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol0]7oo003cOol70006Ool4000;Ool00`00
Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`2dOol00?Ioo`03001oogoo00Ioo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Aoo`00mWoo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol09Goo00<007ooOol0Cgoo00<007oo
Ool0]7oo003fOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`0UOol0
0`00Oomoo`1?Ool00`00Oomoo`2dOol00>Ioo`T000Moo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo00Moo`@002Aoo`03001oogoo04moo`03001oogoo0;Aoo`00iWoo2@001goo00<007ooOol0
1Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol0
]7oo003fOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`3oOol_Ool0
0?Ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo0?moobmoo`00mWoo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol0ogoo;goo003fOol00`00
Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`3oOol_Ool00?=oo`@000Qoo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo0?moobmoo`00D7oo1000X7oo0`002Goo10002goo
00<007ooOol0QGoo0`00YWoo001?Ool20002Ool00`00Oomoo`2MOol00`00Oomoo`02000GOol00`00
Oomoo`25Ool01000Oomoo`00YGoo001?Ool00`00Oomoo`02Ool00`00Oomoo`2KOol00`00Oomoo`02
Ool00`00Oomoo`0EOol00`00Oomoo`24Ool00`00Oomoo`02Ool00`00Oomoo`2ROol004ioo`03001o
ogoo00=oo`03001oogoo09]oo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo08=oo`03001o
ogoo00=oo`03001oogoo0:9oo`00CWoo00<007ooOol017oo00<007ooOol0VGoo00<007ooOol01Goo
00<007ooOol04goo00<007ooOol0Pgoo00<007ooOol017oo00<007ooOol0XGoo001>Ool00`00Oomo
o`04Ool00`00Oomoo`2IOol00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`23Ool00`00Oomo
o`04Ool00`00Oomoo`2QOol004ioo`03001oogoo00Eoo`03001oogoo09Qoo`03001oogoo00Ioo`03
001oogoo019oo`8008Aoo`03001oogoo00Aoo`03001oogoo0:5oo`00CGoo00<007ooOol01Woo00<0
07ooOol0V7oo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol0PWoo00<007ooOol01Woo00<0
07ooOol0X7oo001=Ool00`00Oomoo`07Ool00`00Oomoo`2FOol00`00Oomoo`07Ool00`00Oomoo`0B
Ool00`00Oomoo`22Ool00`00Oomoo`06Ool00`00Oomoo`2POol004eoo`03001oogoo00Moo`03001o
ogoo09Ioo`03001oogoo00Moo`03001oogoo019oo`03001oogoo085oo`03001oogoo00Qoo`03001o
ogoo09moo`00CGoo00<007ooOol01goo00<007ooOol0UWoo00<007ooOol027oo00<007ooOol04Goo
00<007ooOol0PGoo00<007ooOol027oo00<007ooOol0Wgoo001<Ool00`00Oomoo`09Ool00`00Oomo
o`2DOol00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomoo`21Ool00`00Oomoo`08Ool00`00Oomo
o`2OOol004aoo`03001oogoo00Uoo`03001oogoo09Aoo`03001oogoo00Uoo`03001oogoo015oo`03
001oogoo085oo`03001oogoo00Uoo`03001oogoo09ioo`00C7oo00<007ooOol02Goo00<007ooOol0
U7oo00<007ooOol02Woo00<007ooOol047oo00<007ooOol0P7oo00<007ooOol02Woo00<007ooOol0
WWoo001<Ool00`00Oomoo`0:Ool00`00Oomoo`2COol00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00
Oomoo`20Ool00`00Oomoo`0:Ool00`00Oomoo`2NOol004aoo`03001oogoo00Yoo`03001oogoo09=o
o`03001oogoo00Yoo`03001oogoo011oo`03001oogoo081oo`03001oogoo00]oo`03001oogoo09eo
o`00Bgoo00<007ooOol02goo00<007ooOol0TWoo00<007ooOol037oo00<007ooOol03goo00<007oo
Ool0P7oo00<007ooOol02goo00<007ooOol0WGoo001;Ool00`00Oomoo`0;Ool00`00Oomoo`2BOol0
0`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`20Ool00`00Oomoo`0;Ool00`00Oomoo`2MOol0
04]oo`03001oogoo00aoo`03001oogoo095oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo
081oo`03001oogoo00]oo`03001oogoo09eoo`00Bgoo00<007ooOol037oo00<007ooOol0TGoo00<0
07ooOol03Goo00<007ooOol03Woo0P009Woo00<007ooOol0Cgoo00<007ooOol01Goo00<007ooOol0
3Goo00<007ooOol0W7oo001;Ool00`00Oomoo`0<Ool00`00Oomoo`2AOol00`00Oomoo`0=Ool00`00
Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00
Oomoo`2LOol004]oo`03001oogoo00eoo`03001oogoo091oo`03001oogoo00eoo`03001oogoo00io
o`03001oogoo02Eoo`03001oogoo04moo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo09ao
o`00BWoo00<007ooOol03Woo00<007ooOol0T7oo00<007ooOol03Woo00<007ooOol03Goo00<007oo
Ool09Goo00<007ooOol0Cgoo00<007ooOol01Goo00<007ooOol03Woo00<007ooOol0Vgoo001:Ool0
0`00Oomoo`0>Ool00`00Oomoo`2@Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0UOol0
0`00Oomoo`1?Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`2KOol004Yoo`03001oogoo
00ioo`03001oogoo08moo`03001oogoo00moo`03001oogoo00eoo`03001oogoo02Eoo`03001oogoo
04moo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo09]oo`00BWoo00<007ooOol03goo00<0
07ooOol0SWoo00<007ooOol03goo00<007ooOol03Goo00<007ooOol09Goo00<007ooOol0Cgoo00<0
07ooOol017oo00<007ooOol03goo00<007ooOol0Vgoo001:Ool00`00Oomoo`0?Ool00`00Oomoo`2>
Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`04
Ool00`00Oomoo`0@Ool00`00Oomoo`2JOol004Yoo`03001oogoo00moo`03001oogoo08ioo`03001o
ogoo011oo`03001oogoo00aoo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo00Aoo`03001o
ogoo011oo`03001oogoo09Yoo`00BGoo00<007ooOol047oo00<007ooOol0SWoo00<007ooOol047oo
00<007ooOol037oo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol017oo00<007ooOol047oo
00<007ooOol0VWoo0019Ool00`00Oomoo`0AOol00`00Oomoo`2=Ool00`00Oomoo`0@Ool00`00Oomo
o`0<Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomo
o`2JOol004Uoo`03001oogoo015oo`03001oogoo08eoo`03001oogoo015oo`03001oogoo00]oo`03
001oogoo02Eoo`03001oogoo04moo`03001oogoo00Aoo`03001oogoo015oo`03001oogoo09Uoo`00
BGoo00<007ooOol04Goo00<007ooOol0S7oo00<007ooOol04Woo00<007ooOol02goo0P009Woo00<0
07ooOol0Cgoo00<007ooOol017oo00<007ooOol04Goo00<007ooOol0VGoo0019Ool00`00Oomoo`0A
Ool00`00Oomoo`2<Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool00`00Oomoo`0UOol00`00Oomoo`1?
Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`2IOol004Uoo`03001oogoo019oo`03001o
ogoo08]oo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo02Eoo`03001oogoo04moo`03001o
ogoo00=oo`03001oogoo019oo`03001oogoo09Uoo`00B7oo00<007ooOol04goo00<007ooOol0Rgoo
00<007ooOol04goo00<007ooOol02Woo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol00goo
00<007ooOol04goo00<007ooOol0V7oo0018Ool00`00Oomoo`0COol00`00Oomoo`2;Ool00`00Oomo
o`0COol00`00Oomoo`0:Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`03Ool00`00Oomo
o`0COol00`00Oomoo`2HOol004Qoo`03001oogoo01=oo`03001oogoo08Yoo`03001oogoo01Aoo`03
001oogoo00Yoo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo00=oo`03001oogoo01=oo`03
001oogoo09Qoo`00B7oo00<007ooOol057oo00<007ooOol0RGoo00<007ooOol05Goo00<007ooOol0
2Goo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol00goo00<007ooOol04goo00<007ooOol0
V7oo0018Ool00`00Oomoo`0DOol00`00Oomoo`29Ool00`00Oomoo`0EOol00`00Oomoo`09Ool00`00
Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`03Ool00`00Oomoo`0DOol00`00Oomoo`2GOol004Qo
o`03001oogoo01Aoo`03001oogoo08Uoo`03001oogoo01Eoo`03001oogoo00Uoo`03001oogoo02Eo
o`03001oogoo04moo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo09Moo`00B7oo00<007oo
Ool057oo00<007ooOol0RGoo00<007ooOol05Goo00<007ooOol02Goo00<007ooOol09Goo00<007oo
Ool0Cgoo00<007ooOol00goo00<007ooOol057oo00<007ooOol0Ugoo0018Ool00`00Oomoo`0EOol0
0`00Oomoo`28Ool00`00Oomoo`0FOol00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool0
0`00Oomoo`03Ool00`00Oomoo`0EOol00`00Oomoo`2FOol004Qoo`03001oogoo01Eoo`03001oogoo
08Qoo`03001oogoo01Ioo`03001oogoo00Qoo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo
00=oo`03001oogoo01Eoo`03001oogoo09Ioo`00Agoo00<007ooOol05Woo00<007ooOol0R7oo00<0
07ooOol05Woo00<007ooOol027oo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol00goo00<0
07ooOol05Goo00<007ooOol0UWoo0017Ool00`00Oomoo`0FOol00`00Oomoo`28Ool00`00Oomoo`0F
Ool00`00Oomoo`08Ool2000VOol00`00Oomoo`1?Ool00`00Oomoo`02Ool00`00Oomoo`0FOol00`00
Oomoo`2FOol004Moo`03001oogoo01Moo`03001oogoo08Moo`03001oogoo01Moo`03001oogoo00Mo
o`03001oogoo02Eoo`03001oogoo04moo`03001oogoo009oo`03001oogoo01Moo`03001oogoo09Eo
o`00Agoo00<007ooOol05goo00<007ooOol0QWoo00<007ooOol067oo00<007ooOol01goo00<007oo
Ool0O7oo00<007ooOol05goo00<007ooOol0UGoo0017Ool00`00Oomoo`0GOol00`00Oomoo`26Ool0
0`00Oomoo`0HOol00`00Oomoo`07Ool00`00Oomoo`1lOol00`00Oomoo`0GOol00`00Oomoo`2EOol0
04Moo`03001oogoo01Moo`03001oogoo08Ioo`03001oogoo01Qoo`03001oogoo00Moo`03001oogoo
07aoo`03001oogoo01Moo`03001oogoo09Eoo`00Agoo00<007ooOol067oo00<007ooOol0QGoo00<0
07ooOol06Goo00<007ooOol01Woo00<007ooOol0O7oo00<007ooOol067oo00<007ooOol0U7oo0017
Ool00`00Oomoo`0HOol00`00Oomoo`25Ool00`00Oomoo`0IOol00`00Oomoo`06Ool00`00Oomoo`1l
Ool00`00Oomoo`0HOol00`00Oomoo`2DOol004Moo`03001oogoo01Qoo`03001oogoo08Eoo`03001o
ogoo01Uoo`03001oogoo00Ioo`03001oogoo07aoo`03001oogoo01Qoo`03001oogoo09Aoo`00Agoo
00<007ooOol067oo00<007ooOol0QGoo00<007ooOol06Goo00<007ooOol01Woo00<007ooOol0O7oo
00<007ooOol067oo00<007ooOol0U7oo0017Ool00`00Oomoo`0IOol00`00Oomoo`24Ool00`00Oomo
o`0AOol60003Ool00`00Oomoo`05Ool00`00Oomoo`1lOol00`00Oomoo`0IOol00`00Oomoo`2COol0
04Moo`03001oogoo01Uoo`03001oogoo08Aoo`03001oogoo011oo`8000Eoo`04001oogoo0007Ool0
0`00Oomoo`1lOol00`00Oomoo`0IOol00`00Oomoo`2COol004Moo`03001oogoo01Uoo`03001oogoo
08Aoo`03001oogoo01Qoo`03001oo`0000Moo`03001oogoo07]oo`03001oogoo01Yoo`03001oogoo
09=oo`00Agoo00<007ooOol06Woo00<007ooOol0Pgoo00<007ooOol067oo00<007oo00001goo00<0
07ooOol0Ngoo00<007ooOol06goo00<007ooOol0TWoo0016Ool00`00Oomoo`0KOol00`00Oomoo`23
Ool00`00Oomoo`05Ool9000:Ool00`00Ool00007Ool4001jOol00`00Oomoo`0KOol00`00Oomoo`2B
Ool004Ioo`03001oogoo01]oo`03001oogoo08=oo`03001oogoo00Eoo`T000Yoo`04001oogoo0006
Ool00`00Oomoo`1kOol00`00Oomoo`0KOol00`00Oomoo`2BOol004Ioo`03001oogoo01aoo`03001o
ogoo089oo`03001oogoo015oo`8000Aoo`05001oogooOol00006Ool00`00Oomoo`1kOol00`00Oomo
o`0LOol00`00Oomoo`2AOol004Ioo`03001oogoo01aoo`03001oogoo089oo`03001oogoo015oo`H0
00Aoo`03001oogoo00Aoo`03001oogoo07]oo`03001oogoo01aoo`03001oogoo095oo`00AWoo00<0
07ooOol077oo00<007ooOol0PGoo00<007ooOol04Woo00<007ooOol01goo00<007ooOol017oo00<0
07ooOol0Ngoo00<007ooOol077oo00<007ooOol0TGoo0016Ool00`00Oomoo`0LOol00`00Oomoo`21
Ool00`00Oomoo`0BOol00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`1kOol00`00Oomoo`0L
Ool00`00Oomoo`2AOol004Ioo`03001oogoo01eoo`03001oogoo081oo`03001oogoo019oo`03001o
ogoo00Qoo`03001oogoo00=oo`03001oogoo07]oo`03001oogoo01eoo`03001oogoo091oo`00AWoo
00<007ooOol07Goo00<007ooOol0P7oo00<007ooOol04Woo1`0017oo00<007ooOol00goo00<007oo
Ool0Ngoo00<007ooOol07Goo00<007ooOol0T7oo0016Ool00`00Oomoo`0MOol00`00Oomoo`20Ool0
0`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`1kOol00`00Oomoo`0MOol00`00Oomoo`2@Ool0
04Ioo`03001oogoo01ioo`03001oogoo07moo`03001oogoo01ioo`03001oogoo009oo`03001oogoo
07Yoo`03001oogoo01moo`03001oogoo08moo`00AWoo00<007ooOol07Woo00<007ooOol0Ogoo00<0
07ooOol07Woo00<007ooOol00Woo00<007ooOol0NWoo00<007ooOol07goo00<007ooOol0Sgoo0016
Ool00`00Oomoo`0NOol00`00Oomoo`1oOol00`00Oomoo`0NOol00`00Oomoo`02Ool00`00Oomoo`1j
Ool00`00Oomoo`0OOol00`00Oomoo`2?Ool004Ioo`03001oogoo01ioo`03001oogoo07moo`03001o
ogoo01moo`04001oogooOol2001kOol00`00Oomoo`0OOol00`00Oomoo`2?Ool004Ioo`03001oogoo
01moo`03001oogoo07ioo`03001oogoo01moo`05001oogooOol0000WOol00`00Oomoo`1?Ool01000
Oomoo`008Woo00<007ooOol0SWoo0016Ool00`00Oomoo`0OOol00`00Oomoo`1nOol00`00Oomoo`0O
Ool01@00Oomoogoo00009goo00<007ooOol0Cgoo00@007ooOol0029oo`03001oogoo08ioo`00AGoo
00<007ooOol087oo00<007ooOol0OWoo00<007ooOol07goo00D007ooOomoo`0002Moo`03001oogoo
04moo`04001oogoo000ROol00`00Oomoo`2>Ool004Eoo`03001oogoo025oo`03001oogoo07eoo`03
001oogoo021oo`04001oogoo000WOol00`00Oomoo`1?Ool01000Oomoo`008goo00<007ooOol0SGoo
0015Ool00`00Oomoo`0QOol00`00Oomoo`1mOol00`00Oomoo`0POol01000Oomoo`009goo00<007oo
Ool0Cgoo00@007ooOol002=oo`03001oogoo08eoo`00AGoo00<007ooOol08Goo00<007ooOol0OGoo
00<007ooOol087oo00@007ooOol002Moo`03001oogoo04moo`04001oogoo000SOol00`00Oomoo`2=
Ool004Eoo`03001oogoo029oo`03001oogoo07]oo`03001oogoo025oo`04001oogoo000WOol00`00
Oomoo`1?Ool01000Oomoo`0097oo00<007ooOol0S7oo0015Ool00`00Oomoo`0ROol00`00Oomoo`1k
Ool00`00Oomoo`0ROol00`00Ool0000WOol00`00Oomoo`1?Ool01000Oomoo`0097oo00<007ooOol0
S7oo0015Ool00`00Oomoo`0ROol00`00Oomoo`1kOol00`00Oomoo`0ROol00`00Ool0000WOol00`00
Oomoo`1?Ool01000Oomoo`0097oo00<007ooOol0S7oo0015Ool00`00Oomoo`0ROol00`00Oomoo`1k
Ool00`00Oomoo`0ROol00`00Ool0000WOol00`00Oomoo`1?Ool01000Oomoo`0097oo00<007ooOol0
S7oo0015Ool00`00Oomoo`0SOol00`00Oomoo`1jOol00`00Oomoo`0SOol2000WOol00`00Oomoo`1?
Ool01000Oomoo`009Goo00<007ooOol0Rgoo0015Ool00`00Oomoo`0SOol00`00Oomoo`1jOol00`00
Oomoo`0SOol2000WOol00`00Oomoo`1?Ool00`00Ool0000VOol00`00Oomoo`2;Ool004Eoo`03001o
ogoo02=oo`03001oogoo07Yoo`03001oogoo02=oo`<002Ioo`03001oogoo04moo`03001oo`0002Io
o`03001oogoo08]oo`00AGoo00<007ooOol097oo00<007ooOol0NGoo00<007ooOol097oo00<007oo
Ool09Goo00<007ooOol0Cgoo00<007oo00009goo00<007ooOol0RWoo0015Ool00`00Oomoo`0TOol0
0`00Oomoo`1iOol00`00Oomoo`0TOol00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Ool0000WOol0
0`00Oomoo`2:Ool004Eoo`03001oogoo02Aoo`03001oogoo07Uoo`03001oogoo02Aoo`03001oogoo
02Eoo`03001oogoo04moo`03001oo`0002Moo`03001oogoo08Yoo`00A7oo00<007ooOol09Woo00<0
07ooOol0N7oo00<007ooOol097oo0P009Woo00<007ooOol0Cgoo00<007oo0000:7oo00<007ooOol0
RGoo0014Ool00`00Oomoo`0VOol00`00Oomoo`1hOol00`00Oomoo`0TOol2000VOol00`00Oomoo`1?
Ool00`00Ool0000XOol00`00Oomoo`29Ool004Aoo`03001oogoo02Ioo`03001oogoo07Qoo`03001o
ogoo02Aoo`8002Ioo`03001oogoo04moo`03001oo`0002Qoo`03001oogoo08Uoo`00A7oo00<007oo
Ool09goo00<007ooOol0Mgoo00<007ooOol097oo00<007oo00009Goo00<007ooOol0Cgoo00<007oo
0000:Goo00<007ooOol0R7oo0014Ool00`00Oomoo`0WOol00`00Oomoo`1gOol00`00Oomoo`0TOol0
0`00Ool0000UOol00`00Oomoo`1?Ool00`00Ool0000YOol00`00Oomoo`28Ool004Aoo`03001oogoo
02Qoo`03001oogoo07Eoo`03001oogoo02Eoo`03001oo`0002Eoo`03001oogoo04moo`03001oo`00
02Yoo`03001oogoo08Moo`00A7oo00<007ooOol0:7oo00<007ooOol0MGoo00<007ooOol09Goo00@0
07ooOol002Aoo`03001oogoo04moo`03001oo`0002Yoo`03001oogoo08Moo`00A7oo00<007ooOol0
:7oo00<007ooOol0MGoo00<007ooOol09Goo00@007ooOol002Aoo`03001oogoo04moo`03001oo`00
02Yoo`03001oogoo08Moo`00A7oo00<007ooOol0:Goo00<007ooOol0M7oo00<007ooOol09Goo0P00
00=oo`00Ool08goo00<007ooOol0Cgoo00<007oo0000:goo00<007ooOol0QWoo0014Ool00`00Oomo
o`0YOol00`00Oomoo`1dOol00`00Oomoo`0UOol01@00Oomoogoo00008goo00<007ooOol0Cgoo00<0
07oo0000:goo00<007ooOol0QWoo0014Ool00`00Oomoo`0YOol00`00Oomoo`1dOol00`00Oomoo`0U
Ool01@00Oomoogoo00008goo00<007ooOol0Cgoo00<007oo0000:goo00<007ooOol0QWoo0014Ool0
0`00Oomoo`0ZOol00`00Oomoo`1cOol00`00Oomoo`0UOol00`00Oomoo`02Ool00`00Oomoo`0POol0
0`00Oomoo`1?Ool00`00Ool0000/Ool00`00Oomoo`25Ool004Aoo`03001oogoo02Yoo`03001oogoo
07=oo`03001oogoo02Eoo`03001oogoo009oo`03001oogoo07Aoo`03001oogoo02Yoo`03001oogoo
08Eoo`007Woo10008Woo00<007ooOol0:Woo1@00BGoo200087oo00<007ooOol09Goo00<007ooOol0
0goo00<007ooOol0A7oo20009goo00<007ooOol097oo1@000Woo00<007ooOol0AWoo1000>Woo000M
Ool00`00Oomoo`02Ool00`00Oomoo`0NOol00`00Oomoo`0/Ool2001<Ool00`00Oomoo`03Ool00`00
Oomoo`0NOol00`00Oomoo`0UOol00`00Oomoo`03Ool00`00Oomoo`15Ool00`00Oomoo`03Ool00`00
Oomoo`0UOol00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`15Ool00`00Oomoo`02Ool00`00
Oomoo`0gOol001aoo`03001oogoo00Aoo`03001oogoo01eoo`03001oogoo02eoo`03001oogoo04]o
o`03001oogoo02=oo`03001oogoo02Eoo`03001oogoo00Aoo`03001oogoo04Eoo`03001oogoo02Yo
o`03001oogoo02Ioo`03001oogoo00=oo`03001oogoo04=oo`03001oogoo00Aoo`03001oogoo03Io
o`0077oo00<007ooOol017oo00<007ooOol07Goo00<007ooOol09goo2@00C7oo00<007ooOol08Woo
00<007ooOol09Goo00<007ooOol017oo00<007ooOol0AWoo00<007ooOol0:7oo00<007ooOol08Goo
2@000goo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0=Woo000@Ool90003Ool00`00Oomo
o`04Ool00`00Oomoo`0MOol00`00Oomoo`0KOol90004Ool00`00Oomoo`02Ool2000nOol90007Ool0
0`00Oomoo`0QOol00`00Oomoo`0UOol00`00Oomoo`05Ool00`00Oomoo`16Ool00`00Oomoo`0WOol0
0`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`12Ool00`00Oomoo`04Ool0
0`00Oomoo`0fOol0011oo`T000=oo`03001oogoo00Aoo`03001oogoo01eoo`03001oogoo01]oo`T0
00Aoo`03001oogoo009oo`8003ioo`T000Qoo`03001oogoo021oo`03001oogoo02Eoo`03001oogoo
00Ioo`03001oogoo04Ioo`03001oogoo02Ioo`03001oogoo029oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo049oo`03001oogoo00Aoo`03001oogoo03Ioo`0077oo0P0017oo00<007ooOol0
7Woo00<007ooOol0:Goo00L007ooOomoo`00Ool0001?Ool00`00Oomoo`0NOol00`00Oomoo`0VOol0
0`00Oomoo`06Ool00`00Oomoo`17Ool00`00Oomoo`0UOol00`00Oomoo`0SOol01@00Oomoogoo0000
1goo00<007ooOol0@Goo0P0017oo00<007ooOol0=goo000LOol00`00Ool00003000QOol00`00Oomo
o`0ZOol01P00Oomoo`00Ool0051oo`03001oogoo01eoo`03001oogoo02Ioo`03001oogoo00Moo`03
001oogoo04Moo`03001oogoo02Aoo`03001oogoo02Aoo`04001oogoo0007Ool00`00Oomoo`11Ool0
0`00Ool00003000jOol001eoo`03001oogoo02=oo`03001oogoo02Yoo`04001oogoo0002Ool00`00
Oomoo`1=Ool00`00Oomoo`0MOol00`00Oomoo`0VOol20008Ool00`00Oomoo`17Ool00`00Oomoo`0T
Ool00`00Oomoo`0TOol01000Oomoo`0027oo00<007ooOol0@Goo00<007ooOol0?7oo000MOol00`00
Oomoo`0SOol00`00Oomoo`0[Ool00`00Ool00002Ool00`00Oomoo`17Ool00`00Oomoo`03Ool00`00
Oomoo`0MOol00`00Oomoo`0VOol00`00Oomoo`08Ool00`00Oomoo`10Ool00`00Oomoo`03Ool00`00
Oomoo`0TOol00`00Oomoo`0UOol00`00Ool00008Ool00`00Oomoo`11Ool00`00Oomoo`0lOol001io
o`8002=oo`03001oogoo02aoo`8000=oo`03001oogoo04Ioo`8000=oo`03001oogoo01ioo`03001o
ogoo02Ioo`03001oogoo00Qoo`03001oogoo041oo`8000=oo`03001oogoo02Eoo`03001oogoo02Io
o`8000Uoo`03001oogoo045oo`8003aoo`0087oo10007goo00<007ooOol0;7oo0P0017oo00<007oo
Ool0Agoo0`008Goo00<007ooOol09Woo00<007ooOol02Goo00<007ooOol0@Goo0`00:7oo00<007oo
Ool09Woo0P002Woo00<007ooOol0@Woo1000>7oo0013Ool00`00Oomoo`0cOol00`00Oomoo`1ZOol0
0`00Oomoo`0VOol00`00Oomoo`0:Ool00`00Oomoo`1[Ool00`00Oomoo`0cOol00`00Oomoo`1mOol0
04=oo`03001oogoo03Aoo`03001oogoo06Uoo`03001oogoo02Ioo`03001oogoo00]oo`03001oogoo
06Yoo`03001oogoo03Aoo`03001oogoo07aoo`00@goo00<007ooOol0=Goo00<007ooOol0J7oo00<0
07ooOol09Woo00<007ooOol037oo00<007ooOol0JGoo00<007ooOol0=Goo00<007ooOol0Ngoo0013
Ool00`00Oomoo`0fOol00`00Oomoo`1WOol00`00Oomoo`0VOol00`00Oomoo`0=Ool00`00Oomoo`1X
Ool00`00Oomoo`0fOol00`00Oomoo`1jOol0049oo`03001oogoo03Qoo`8006Moo`03001oogoo02Io
o`03001oogoo00ioo`8006Qoo`03001oogoo03Moo`03001oogoo05ioo`D001Ioo`00@Woo00<007oo
Ool0>Woo00<007ooOol0I7oo00<007ooOol09Woo00<007ooOol047oo0P00IWoo00<007ooOol0>7oo
0P00GGoo00<007ooOol00goo0P0057oo0012Ool00`00Oomoo`0kOol2001TOol00`00Oomoo`0VOol0
0`00Oomoo`0BOol00`00Oomoo`1SOol00`00Oomoo`0jOol2001KOol00`00Oomoo`0IOol0049oo`03
001oogoo03eoo`<0065oo`03001oogoo02Ioo`03001oogoo01=oo`<0069oo`03001oogoo03aoo`80
05Uoo`03001oogoo01Uoo`00@Woo00<007ooOol0@7oo1`00FWoo00<007ooOol09Woo00<007ooOol0
5Woo1`001goo4P00@7oo0`00@7oo2000DGoo00<007ooOol06Goo000=Oooo003o0006000COol00`00
Oomoo`0IOol001Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015o
o`03001oogoo019oo`03001oogoo015oo`03001oogoo00eoo`<00003Ool007oo01=oo`03001oogoo
015oo`03001oogoo015oo`8001=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo011ooaL0
01=oo`03001oogoo019oo`03001oogoo011oo`<001=oo`03001oogoo015oo`03001oogoo015oo`03
001oogoo019oo`03001oogoo00ioo`04001oogoo000DOol00`00Oomoo`0MOol00`00Oomoo`0IOol0
01Yoo`03001oogoo015oo`03001oogoo015oo`03001oogoo019oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo015oo`03001oogoo011oo`8001Aoo`03001oogoo015oo`03001oogoo015oo`80
01=oo`03001oogoo019oo`03001oogoo015oo`03001oogoo015oo`03001oogoo00aoo`T0015oo`03
001oogoo019oo`03001oogoo011oo`<001=oo`03001oogoo015oo`03001oogoo015oo`03001oogoo
019oo`03001oogoo00moo`<001Aoo`03001oogoo01]oo`P001Ioo`006Woo00<007ooOol09Goo00<0
07ooOol09Woo00<007ooOol0>Woo0`004Woo00<007ooOol09Goo00<007ooOol09goo00<007ooOol0
9Goo00<007ooOol03goo1`0047oo00<007ooOol09Goo0`009goo00<007ooOol0>goo00<007ooOol0
4Goo00<007ooOol07Goo00<007ooOol06Goo0012Ool00`00Oomoo`1VOol00`00Oomoo`0gOol00`00
Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`0AOol7000fOol3001VOol2000aOol00`00Oomoo`0I
Ool0049oo`03001oogoo06Moo`03001oogoo03Ioo`03001oogoo02Moo`03001oogoo02Eoo`03001o
ogoo01=oo`H003Eoo`<006Qoo`03001oogoo02ioo`03001oogoo01Uoo`00@Woo00<007ooOol0J7oo
00<007ooOol0=Goo00<007ooOol09goo00<007ooOol09Goo00<007ooOol057oo1P00=7oo0`00JGoo
00<007ooOol0BGoo0012Ool00`00Oomoo`1YOol00`00Oomoo`0dOol00`00Oomoo`0WOol00`00Oomo
o`0UOol00`00Oomoo`0FOol5000cOol3001ZOol00`00Oomoo`18Ool0049oo`03001oogoo06Uoo`03
001oogoo03Aoo`03001oogoo02Moo`03001oogoo02Eoo`03001oogoo01Moo`@003=oo`<006]oo`03
001oogoo04Moo`00@Woo00<007ooOol0JWoo00<007ooOol0<goo00<007ooOol09goo00<007ooOol0
9Goo00<007ooOol067oo1000<Goo1000Jgoo00<007ooOol0Agoo0012Ool00`00Oomoo`1[Ool00`00
Oomoo`0bOol00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`0HOol4000aOol4001/Ool00`00
Oomoo`16Ool0049oo`03001oogoo06]oo`03001oogoo039oo`03001oogoo02Moo`03001oogoo02Eo
o`03001oogoo01Uoo`@0031oo`<006eoo`03001oogoo04Ioo`00@Goo00<007ooOol0KGoo00<007oo
Ool0<Goo00<007ooOol09goo0P009Woo00<007ooOol06Goo1000<7oo0`00KWoo00<007ooOol0AGoo
0011Ool00`00Oomoo`1^Ool00`00Oomoo`0`Ool00`00Oomoo`0WOol00`00Oomoo`0UOol00`00Oomo
o`0JOol4000_Ool3001^Ool00`00Oomoo`15Ool0045oo`03001oogoo06moo`03001oogoo02moo`03
001oogoo02Moo`03001oogoo02Eoo`03001oogoo01Yoo`@002moo`<006moo`03001oogoo04Aoo`00
@Goo00<007ooOol0Kgoo00<007ooOol0;goo00<007ooOol09goo00<007ooOol09Goo00<007ooOol0
6goo1000;Woo0`00L7oo00<007ooOol0@goo0011Ool00`00Oomoo`1`Ool00`00Oomoo`0^Ool00`00
Oomoo`0WOol00`00Oomoo`0UOol00`00Oomoo`0KOol5000]Ool3001`Ool00`00Oomoo`13Ool0045o
o`03001oogoo071oo`03001oogoo02ioo`03001oogoo02Moo`03001oogoo02Eoo`03001oogoo01ao
o`@002eoo`<0075oo`03001oogoo049oo`00@Goo00<007ooOol0LGoo00<007ooOol0;7oo00<007oo
Ool0:7oo00<007ooOol09Goo00<007ooOol07Goo1000;7oo0`00LGoo00<007ooOol0@Woo0011Ool0
0`00Oomoo`1bOol00`00Oomoo`0[Ool00`00Oomoo`0XOol00`00Oomoo`0UOol00`00Oomoo`0MOol5
000[Ool3001bOol00`00Oomoo`11Ool0045oo`03001oogoo079oo`03001oogoo02]oo`03001oogoo
02Qoo`03001oogoo02Eoo`03001oogoo01ioo`@002]oo`<007=oo`03001oogoo041oo`00@Goo00<0
07ooOol0Lgoo00<007ooOol0:Woo00<007ooOol0:7oo00<007ooOol09Goo00<007ooOol07goo1000
:Woo0`00Lgoo00<007ooOol0@7oo0011Ool00`00Oomoo`1cOol00`00Oomoo`0ZOol00`00Oomoo`0X
Ool00`00Oomoo`0UOol00`00Oomoo`0OOol4000ZOol3001dOol00`00Oomoo`0oOol0045oo`03001o
ogoo07Aoo`03001oogoo02Uoo`03001oogoo02Qoo`03001oogoo02Eoo`03001oogoo021oo`<002Yo
o`<007Aoo`03001oogoo03moo`00@Goo00<007ooOol0M7oo00<007ooOol0:Goo00<007ooOol0:7oo
00<007ooOol09Goo00<007ooOol087oo1000:Goo0`00MGoo00<007ooOol0?Woo0011Ool00`00Oomo
o`1eOol00`00Oomoo`0XOol00`00Oomoo`0XOol2000VOol00`00Oomoo`0POol4000YOol3001eOol0
0`00Oomoo`0nOol0045oo`03001oogoo07Eoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo
02Eoo`03001oogoo025oo`<002Uoo`<007Eoo`03001oogoo03ioo`00@Goo00<007ooOol0MGoo00<0
07ooOol0:7oo00<007ooOol0:7oo00<007ooOol09Goo00<007ooOol08Goo10009goo1000MWoo00<0
07ooOol0?Goo0011Ool00`00Oomoo`1fOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0U
Ool00`00Oomoo`0QOol4000WOol4001fOol00`00Oomoo`0mOol0041oo`03001oogoo07Moo`03001o
ogoo02Moo`03001oogoo02Qoo`03001oogoo04Yoo`<002Moo`<007Moo`03001oogoo03eoo`00@7oo
00<007ooOol0N7oo00<007ooOol09Woo00<007ooOol0:7oo00<007ooOol0BWoo10009Woo0`00N7oo
00<007ooOol0?7oo0010Ool00`00Oomoo`1hOol00`00Oomoo`0VOol00`00Oomoo`0XOol00`00Oomo
o`1:Ool4000VOol3001hOol00`00Oomoo`0lOol0041oo`03001oogoo07Qoo`03001oogoo02Ioo`03
001oogoo02Qoo`03001oogoo04]oo`<002Ioo`<007Qoo`03001oogoo03aoo`00@7oo00<007ooOol0
NGoo00<007ooOol09Goo00<007ooOol0:7oo00<007ooOol0Bgoo10009Goo0`00NGoo00<007ooOol0
>goo0010Ool00`00Oomoo`1iOol00`00Oomoo`0UOol00`00Oomoo`0XOol00`00Oomoo`1;Ool4000U
Ool3001iOol00`00Oomoo`0kOol0041oo`03001oogoo07Uoo`03001oogoo02Eoo`03001oogoo02Qo
o`03001oogoo04aoo`<002Eoo`<007Uoo`03001oogoo03]oo`00@7oo00<007ooOol0NWoo00<007oo
Ool097oo00<007ooOol0:7oo00<007ooOol0C7oo100097oo0`00NWoo00<007ooOol0>Woo000JOol0
0`00Oomoo`0SOol00`00Oomoo`1jOol00`00Oomoo`0TOol00`00Oomoo`0XOol2001=Ool4000TOol3
001kOol00`00Oomoo`0iOol001Yoo`03001oogoo02=oo`03001oogoo07Yoo`03001oogoo02Aoo`03
001oogoo02Qoo`03001oogoo04eoo`<002Aoo`<00;Moo`006Woo00<007ooOol08goo00<007ooOol0
Ngoo00<007ooOol08Woo00<007ooOol0:Goo00<007ooOol0CGoo10008goo0`00]goo000KOol00`00
Oomoo`0ROol00`00Oomoo`1kOol00`00Oomoo`0ROol00`00Oomoo`0YOol00`00Oomoo`1=Ool4000S
Ool3002gOol001]oo`03001oogoo029oo`03001oogoo07]oo`03001oogoo029oo`03001oogoo02Uo
o`03001oogoo04ioo`<002=oo`<00;Moo`006goo00<007ooOol08Woo00<007ooOol0Ngoo00<007oo
Ool08Woo00<007ooOol0:Goo00<007ooOol0CWoo10008Woo0`00]goo000KOol00`00Oomoo`0ROol0
0`00Oomoo`1lOol00`00Oomoo`0QOol00`00Oomoo`0YOol00`00Oomoo`1>Ool4000ROol3002gOol0
01aoo`03001oogoo025oo`03001oogoo07aoo`03001oogoo025oo`03001oogoo02Uoo`03001oogoo
04moo`<0029oo`<00;Moo`0077oo00<007ooOol08Goo00<007ooOol0O7oo00<007ooOol08Goo00<0
07ooOol0:Goo00<007ooOol0Cgoo10008Goo0`00]goo000LOol00`00Oomoo`0POol00`00Oomoo`1m
Ool00`00Oomoo`0QOol00`00Oomoo`0YOol00`00Oomoo`1?Ool4000POol4002gOol001aoo`03001o
ogoo021oo`03001oogoo07ioo`03001oogoo021oo`03001oogoo02Uoo`03001oogoo051oo`<0021o
o`@00;Moo`007Goo00<007ooOol07goo00<007ooOol0OWoo00<007ooOol087oo00<007ooOol0:Goo
00<007ooOol0D7oo10007goo0`00^7oo000MOol00`00Oomoo`0OOol00`00Oomoo`1nOol00`00Oomo
o`0POol00`00Oomoo`0YOol00`00Oomoo`1@Ool4000OOol3002hOol001eoo`03001oogoo01moo`03
001oogoo07ioo`03001oogoo021oo`03001oogoo02Uoo`80059oo`<001moo`<00;Qoo`007Goo00<0
07ooOol07goo00<007ooOol0Ogoo00<007ooOol07goo00<007ooOol0:Goo00<007ooOol0DGoo1000
7Woo0`00^7oo000NOol00`00Oomoo`0NOol00`00Oomoo`1oOol00`00Oomoo`0OOol00`00Oomoo`0Y
Ool00`00Oomoo`1AOol4000NOol3002hOol001ioo`03001oogoo01ioo`03001oogoo07moo`03001o
ogoo01moo`03001oogoo02Uoo`03001oogoo02Eoo`03001oogoo02Yoo`<001ioo`<00003Ool007oo
0;Eoo`007Woo00<007ooOol07Woo00<007ooOol0Ogoo00<007ooOol07goo00<007ooOol0:Goo00<0
07ooOol09Goo00<007ooOol0:Woo0`007Woo0`0000=oo`00Ool0]Goo000NOol00`00Oomoo`0NOol0
0`00Oomoo`20Ool00`00Oomoo`0MOol00`00Oomoo`0ZOol00`00Oomoo`0UOol00`00Oomoo`0ZOol4
000MOol300000goo001oo`2eOol001moo`03001oogoo01eoo`03001oogoo081oo`03001oogoo01eo
o`03001oogoo02Yoo`03001oogoo02Eoo`03001oogoo02Yoo`@001eoo`<00003Ool007oo0;Eoo`00
7goo00<007ooOol07Goo00<007ooOol0P7oo00<007ooOol07Goo00<007ooOol0:Woo00<007ooOol0
9Goo00<007ooOol0:goo0`007Goo0`0000=oo`00Ool0]Goo000OOol00`00Oomoo`0MOol00`00Oomo
o`20Ool00`00Oomoo`0MOol00`00Oomoo`0ZOol00`00Oomoo`0UOol00`00Oomoo`0[Ool3000MOol3
00000goo001oo`2eOol001moo`03001oogoo01eoo`03001oogoo085oo`03001oogoo01aoo`03001o
ogoo01Uoo`H000]oo`03001oogoo02Eoo`03001oogoo02]oo`<001eoo`<00003Ool007oo0;Eoo`00
87oo00<007ooOol077oo00<007ooOol0PGoo00<007ooOol077oo00<007ooOol067oo0P001Goo00<0
07ooOol027oo00<007ooOol09Goo00<007ooOol0:goo10006goo100000=oo`00Ool0]Goo000POol0
0`00Oomoo`0LOol00`00Oomoo`21Ool00`00Oomoo`0LOol00`00Oomoo`0POol00`00Oomoo`07Ool0
0`00Oomoo`0UOol00`00Oomoo`0[Ool4000KOol400000goo001oo`2eOol0021oo`03001oogoo01ao
o`03001oogoo085oo`03001oogoo01aoo`03001oogoo021oo`03001oogoo00Moo`03001oogoo02Eo
o`03001oogoo02aoo`<001]oo`<0009oo`03001oogoo0;Aoo`0087oo00<007ooOol06goo00<007oo
Ool0Pgoo00<007ooOol06goo00<007ooOol087oo00<007ooOol01goo100097oo00<007ooOol0;7oo
0`006goo0`000Woo00<007ooOol0]7oo000QOol00`00Oomoo`0JOol00`00Oomoo`23Ool00`00Oomo
o`0JOol00`00Oomoo`0QOol00`00Oomoo`07Ool00`00Oomoo`0UOol00`00Oomoo`0/Ool4000JOol3
0002Ool00`00Oomoo`2dOol0025oo`03001oogoo01Yoo`03001oogoo08=oo`03001oogoo01Yoo`03
001oogoo01Yoo`8000Aoo`03001oogoo00Qoo`03001oogoo02Eoo`03001oogoo02aoo`@001Yoo`<0
009oo`03001oogoo0;Aoo`008Goo00<007ooOol06Woo00<007ooOol0Pgoo00<007ooOol06Woo00<0
07ooOol06Woo1P002goo00<007ooOol09Goo00<007ooOol0;Goo0`006Woo0`000Woo00<007ooOol0
]7oo000QOol00`00Oomoo`0JOol00`00Oomoo`24Ool00`00Oomoo`0IOol00`00Oomoo`0JOol00`00
Oomoo`0>Ool00`00Oomoo`0UOol00`00Oomoo`0]Ool4000IOol30002Ool00`00Oomoo`2dOol0029o
o`03001oogoo01Uoo`03001oogoo08Aoo`03001oogoo01Uoo`03001oogoo01Yoo`03001oogoo00io
o`03001oogoo02Eoo`03001oogoo02eoo`@001Uoo`<0009oo`03001oogoo0;Aoo`008Woo00<007oo
Ool06Goo00<007ooOol0Q7oo00<007ooOol06Goo00<007ooOol06Woo00<007ooOol03Woo00<007oo
Ool09Goo00<007ooOol0;Woo0`0067oo10000Woo00<007ooOol0]7oo000ROol00`00Oomoo`0IOol0
0`00Oomoo`24Ool00`00Oomoo`0IOol00`00Oomoo`0JOol7000:Ool00`00Oomoo`0UOol00`00Oomo
o`0^Ool3000HOol40002Ool00`00Oomoo`2dOol0029oo`03001oogoo01Uoo`03001oogoo08Eoo`03
001oogoo01Qoo`03001oogoo02]oo`03001oogoo02Eoo`03001oogoo02ioo`@001Moo`<000=oo`03
001oogoo0;Aoo`008goo00<007ooOol067oo00<007ooOol0QGoo00<007ooOol067oo00<007ooOol0
:goo00<007ooOol09Goo00<007ooOol0;Woo10005goo0`000goo00<007ooOol0]7oo000SOol00`00
Oomoo`0HOol00`00Oomoo`25Ool00`00Oomoo`0HOol00`00Oomoo`0[Ool00`00Oomoo`0UOol00`00
Oomoo`0_Ool3000GOol30003Ool00`00Oomoo`2dOol002=oo`03001oogoo01Qoo`03001oogoo08Eo
o`03001oogoo01Moo`03001oogoo02aoo`03001oogoo02Eoo`03001oogoo02moo`@001Ioo`<000=o
o`03001oogoo0;Aoo`008goo00<007ooOol05goo00<007ooOol0Qgoo00<007ooOol05Woo00<007oo
Ool0;7oo0P009Woo00<007ooOol0;goo10005Woo0`000goo00<007ooOol0]7oo000TOol00`00Oomo
o`0FOol00`00Oomoo`27Ool00`00Oomoo`0FOol00`00Oomoo`0/Ool00`00Oomoo`0UOol00`00Oomo
o`0`Ool3000FOol30003Ool00`00Oomoo`2dOol002Aoo`03001oogoo01Ioo`03001oogoo08Moo`03
001oogoo01Ioo`03001oogoo02aoo`03001oogoo02Eoo`03001oogoo031oo`<001Ioo`<000=oo`03
001oogoo0;Aoo`0097oo00<007ooOol05Woo00<007ooOol0Qgoo00<007ooOol05Woo00<007ooOol0
;7oo00<007ooOol09Goo00<007ooOol0<7oo100057oo10000goo00<007ooOol0]7oo000TOol00`00
Oomoo`0FOol00`00Oomoo`28Ool00`00Oomoo`0EOol00`00Oomoo`0/Ool00`00Oomoo`0UOol00`00
Oomoo`0`Ool4000DOol40003Ool00`00Oomoo`2dOol002Eoo`03001oogoo01Eoo`03001oogoo08Qo
o`03001oogoo01Eoo`03001oogoo02aoo`03001oogoo02Eoo`03001oogoo035oo`<001Aoo`<000Ao
o`03001oogoo0;Aoo`009Goo00<007ooOol05Goo00<007ooOol0R7oo00<007ooOol05Goo00<007oo
Ool0;7oo00<007ooOol0FGoo0`0057oo0`00^goo000UOol00`00Oomoo`0DOol00`00Oomoo`2:Ool0
0`00Oomoo`0DOol00`00Oomoo`0/Ool00`00Oomoo`1IOol4000COol3002kOol002Ioo`03001oogoo
01=oo`03001oogoo08Yoo`03001oogoo01Aoo`03001oogoo02aoo`03001oogoo05Uoo`@001=oo`<0
0;]oo`009Woo00<007ooOol04goo00<007ooOol0RWoo00<007ooOol04goo00<007ooOol0;Goo00<0
07ooOol0FWoo0`004goo0`00^goo000VOol00`00Oomoo`0COol00`00Oomoo`2;Ool00`00Oomoo`0B
Ool00`00Oomoo`0]Ool00`00Oomoo`1JOol3000COol3002kOol002Ioo`03001oogoo01=oo`03001o
ogoo08]oo`03001oogoo019oo`03001oogoo02eoo`03001oogoo05Yoo`<0019oo`@00;]oo`009goo
00<007ooOol04Woo00<007ooOol0Rgoo00<007ooOol04Woo00<007ooOol0;Goo00<007ooOol0FWoo
10004Goo1000^goo000WOol00`00Oomoo`0BOol00`00Oomoo`2;Ool00`00Oomoo`0BOol00`00Oomo
o`0]Ool2001KOol4000AOol3002lOol002Moo`03001oogoo019oo`03001oogoo08aoo`03001oogoo
015oo`03001oogoo02eoo`03001oogoo05]oo`<0015oo`<00;aoo`009goo00<007ooOol04Woo00<0
07ooOol0S7oo00<007ooOol04Goo00<007ooOol0;Goo00<007ooOol0Fgoo0`004Goo0`00_7oo000X
Ool00`00Oomoo`0@Ool00`00Oomoo`2=Ool00`00Oomoo`0AOol00`00Oomoo`0]Ool00`00Oomoo`1K
Ool4000@Ool3002lOol002Qoo`03001oogoo011oo`03001oogoo08ioo`03001oogoo011oo`03001o
ogoo02eoo`03001oogoo05]oo`@0011oo`<00;aoo`00:7oo00<007ooOol047oo00<007ooOol0SWoo
00<007ooOol047oo00<007ooOol0;Goo00<007ooOol0G7oo0`0047oo0`00_7oo000XOol00`00Oomo
o`0@Ool00`00Oomoo`2>Ool00`00Oomoo`0?Ool00`00Oomoo`0^Ool00`00Oomoo`1LOol4000?Ool3
002lOol002Uoo`03001oogoo00moo`03001oogoo08moo`03001oogoo00ioo`03001oogoo02ioo`03
001oogoo05aoo`@000ioo`@00;aoo`00:Goo00<007ooOol03goo00<007ooOol0Sgoo00<007ooOol0
3Woo00<007ooOol0;Woo00<007ooOol0GGoo0`003Woo1000_7oo000YOol00`00Oomoo`0?Ool00`00
Oomoo`2?Ool00`00Oomoo`0>Ool00`00Oomoo`0^Ool00`00Oomoo`1MOol4000=Ool3002mOol002Yo
o`03001oogoo00ioo`03001oogoo08moo`03001oogoo00ioo`03001oogoo02ioo`03001oogoo05eo
o`@000eoo`<00;eoo`00:Woo00<007ooOol03Goo00<007ooOol0TGoo00<007ooOol03Goo00<007oo
Ool0;Woo00<007ooOol0GWoo0`003Goo0`00_Goo000ZOol00`00Oomoo`0=Ool00`00Oomoo`2AOol0
0`00Oomoo`0=Ool00`00Oomoo`0^Ool00`00Oomoo`1NOol4000<Ool3002mOol002]oo`03001oogoo
00aoo`03001oogoo095oo`03001oogoo00eoo`03001oogoo02ioo`8005moo`@000aoo`<00;eoo`00
:goo00<007ooOol037oo00<007ooOol0TGoo00<007ooOol037oo00<007ooOol0;goo00<007ooOol0
Ggoo0`0037oo0`00_Goo000[Ool00`00Oomoo`0<Ool00`00Oomoo`2BOol00`00Oomoo`0;Ool00`00
Oomoo`0_Ool00`00Oomoo`1OOol3000;Ool4002mOol002]oo`03001oogoo00]oo`03001oogoo09=o
o`03001oogoo00]oo`03001oogoo02moo`03001oogoo05moo`<000]oo`@00;eoo`00;7oo00<007oo
Ool02Woo00<007ooOol0Tgoo00<007ooOol02goo00<007ooOol0;goo00<007ooOol0Ggoo10002Woo
0`00_Woo000/Ool00`00Oomoo`0:Ool00`00Oomoo`2COol00`00Oomoo`0;Ool00`00Oomoo`0_Ool0
0`00Oomoo`0UOol00`00Oomoo`0gOol4000:Ool30007Ool00`00Oomoo`2dOol002aoo`03001oogoo
00Yoo`03001oogoo09Aoo`03001oogoo00Yoo`03001oogoo02moo`03001oogoo02Eoo`03001oogoo
03Qoo`<000Uoo`@000Moo`03001oogoo0;Aoo`00;7oo00<007ooOol02Woo00<007ooOol0U7oo00<0
07ooOol02Goo00<007ooOol0<7oo00<007ooOol04Woo100000Aoo`00000000]oo`03001oogoo03Qo
o`<000Uoo`@000Moo`03001oogoo00Qoo`80009oo`<00:Eoo`00;Goo00<007ooOol02Goo00<007oo
Ool0U7oo00<007ooOol02Goo00<007ooOol0<7oo00<007ooOol04Goo00<007ooOol00Woo0P003Goo
00<007ooOol0>7oo100027oo0`0027oo00<007ooOol02Goo0`000goo0P00Xgoo000]Ool00`00Oomo
o`09Ool00`00Oomoo`2DOol00`00Oomoo`09Ool00`00Oomoo`0`Ool00`00Oomoo`0@Ool00`00Oomo
o`04Ool00`00Oomoo`0;Ool00`00Oomoo`0hOol40008Ool30008Ool00`00Oomoo`09Ool20005Ool0
0`00Oomoo`2QOol002eoo`03001oogoo00Qoo`03001oogoo09Ioo`03001oogoo00Qoo`03001oogoo
031oo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo03Uoo`@000Ioo`@0
00Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo0:1oo`00;Woo00<007ooOol01goo00<0
07ooOol0UWoo00<007ooOol01goo00<007ooOol0<Goo00<007ooOol04Goo00<007ooOol00goo00<0
07ooOol02goo00<007ooOol0>Goo10001Woo100027oo00<007ooOol02Goo00<007ooOol01Goo00<0
07ooOol0X7oo000_Ool00`00Oomoo`06Ool00`00Oomoo`2GOol00`00Oomoo`06Ool00`00Oomoo`0a
Ool2000COol6000=Ool00`00Oomoo`0jOol40005Ool30009Ool00`00Oomoo`09Ool00`00Oomoo`05
Ool00`00Oomoo`2POol002moo`03001oogoo00Ioo`03001oogoo09Qoo`03001oogoo00Eoo`03001o
ogoo035oo`03001oogoo01Moo`03001oogoo00]oo`03001oogoo03Yoo`@000Aoo`@000Uoo`03001o
ogoo00Uoo`8000Eoo`03001oogoo0:5oo`00;goo00<007ooOol01Goo00<007ooOol0VGoo00<007oo
Ool017oo00<007ooOol0<Woo00<007ooOol04Goo00<007ooOol00Woo0P003Goo00<007ooOol0>goo
10000goo10002Goo00<007ooOol02Goo0`000goo0P00Xgoo000`Ool00`00Oomoo`04Ool00`00Oomo
o`2JOol00`00Oomoo`03Ool00`00Oomoo`0bOol00`00Oomoo`0BOol5000>Ool00`00Oomoo`0kOol4
0002Ool4000:Ool00`00Oomoo`09Ool00`00Oomoo`03002UOol0035oo`03001oogoo009oo`03001o
ogoo09]oo`03001oogoo00=oo`03001oogoo039oo`03001oogoo02Eoo`03001oogoo03aoo`@00003
Ool00000008000Yoo`03001oogoo00Uoo`03001oogoo0:Qoo`00<Woo00@007ooOol009ioo`8000=o
o`03001oogoo03=oo`03001oogoo02Eoo`03001oogoo03aoo`P000]oo`03001oogoo00Uoo`03001o
ogoo0:Qoo`00<Woo1000X7oo0`00=Woo00<007ooOol09Goo00<007ooOol0?Goo1`002goo00<007oo
Ool02Goo00<007ooOol0Z7oo003oOol@Ool00`00Oomoo`0UOol00`00Oomoo`0nOol5000<Ool00`00
Oomoo`08Ool2002ZOol00?mooa1oo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Aoo`00
lgoo1`001Woo10002goo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol0]7oo003fOol00`00
Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00
Oomoo`2dOol00?Ioo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo02Eo
o`03001oogoo04moo`03001oogoo0;Aoo`00mWoo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01goo00<007ooOol09Goo00<007ooOol0Cgoo00<007ooOol0]7oo003fOol00`00Oomoo`05Ool0
0`00Oomoo`04Ool00`00Oomoo`07Ool4000TOol00`00Oomoo`1?Ool00`00Oomoo`2dOol00?Ioo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo02Eoo`03001oogoo04moo`03
001oogoo0;Aoo`00mWoo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol0
9Goo00<007ooOol0Cgoo00<007ooOol0]7oo003fOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`07Ool00`00Oomoo`0UOol00`00Oomoo`1?Ool00`00Oomoo`2dOol00?Ioo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo02Eoo`03001oogoo04moo`03001oogoo0;Ao
o`00mWoo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol09Goo00<007oo
Ool0Cgoo00<007ooOol0]7oo003cOol40008Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomo
o`3oOol_Ool00?Eoo`8000Uoo`@000]oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo
;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<0
07ooOol0ogoo;goo003oOol@Ool2003oOol`Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo
00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmo
o`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001o
ogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mo
oa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomoo`3o
Ool_Ool00?mooa1oo`800?mooc1oo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@Ool00`00Oomo
o`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo;goo003oOol@
Ool00`00Oomoo`3oOol_Ool00?mooa1oo`03001oogoo0?moobmoo`00ogoo47oo00<007ooOol0ogoo
;goo003oOol@Ool00`00Oomoo`3oOol_Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool0
0?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOooo
Oom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo
003oOol=Ool00`00Oomoo`0>Ool00`00Oomoo`3oOolQOol00?moo`aoo`03001oogoo011oo`03001o
ogoo0?moob1oo`00ogoo37oo00<007ooOol047oo00<007ooOol0ogoo87oo003oOol;Ool00`00Oomo
o`0BOol00`00Oomoo`3oOolOOol00?Uoo`L000Yoo`03001oogoo00Ioo`D000Moo`03001oogoo0?mo
oamoo`00ngoo00<007ooOol02goo00<007ooOol01Woo00<007ooOol00goo0P001Woo00<007ooOol0
ogoo7Woo003kOol00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3oOolN
Ool00?]oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?mooaioo`00
ngoo00<007ooOol02goo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0ogoo7Woo003kOol0
0`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3oOolNOol00?]oo`03001o
ogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?mooaioo`00ngoo00<007ooOol0
2goo00<007ooOol017oo200027oo00<007ooOol0ogoo7Woo003iOol7000:Ool00`00Oomoo`05Ool0
0`00Oomoo`0:Ool00`00Oomoo`3oOolOOol00?]oo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00Yoo`03001oogoo0?mooamoo`00ngoo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0
2Goo00<007ooOol0ogoo87oo003kOol2000>Ool00`00Oomoo`0@Ool00`00Oomoo`3oOolPOol00?ao
o`D000]oo`03001oogoo00ioo`03001oogoo0?moob5oo`00ogooogoo@Woo003oOoooOom2Ool00?mo
oomood9oo`00ogooogoo@Woo003oOoooOom2Ool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-6, -12, 0, 0}}],

Cell[TextData[{
  "Fig. 2.5 Odd periodic extension of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " defined on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`1 < t < 3\)]],
  "."
}], "Caption",
  CellTags->"Fig. 2.5"],

Cell[TextData[{
  "\tLike the even periodic extension, the odd periodic extension also has \
period ",
  Cell[BoxData[
      \(TraditionalForm\`2  T\)]],
  ". However, since it is odd about the point ",
  Cell[BoxData[
      \(TraditionalForm\`t = a\)]],
  ", it can be written as a Fourier sine series with time measured with \
respect to an origin at ",
  Cell[BoxData[
      \(TraditionalForm\`t = a\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((o)\)\)(
          t) = \[Sum]\+\(n = 1\)\%\[Infinity] b\_n\ sin[
              n\ \(\[CapitalDelta]\[Omega](\ t - a)\)/2]\)]],
  "."
}], "NE2",
  CellTags->"(2.2.10)"],

Cell[TextData[{
  "The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`b\_n\)]],
  " can be determined by following an argument analogous to that which led to \
Eq. ",
  ButtonBox["(2.2.8)",
    ButtonData:>"(2.2.8)",
    ButtonStyle->"Hyperlink"],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`b\_n = \(2\/T\) \(\[Integral]\_a\%b\( f(t)\)\ \ sin[
                n\ \[CapitalDelta]\[Omega]\ \((\ t - a)\)/
                    2] \(\(\[DifferentialD]t\)\(\ \)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(2.2.11)"],

Cell[TextData[{
  "As an example, let's construct the odd periodic extension of the function \
",
  Cell[BoxData[
      \(TraditionalForm\`t\ \((1 - t\^2)\)\)]],
  " on the interval [0,1]. This function is zero at both ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ", and so meets the conditions necessary for rapid convergence of the odd \
periodic extension. "
}], "Text"],

Cell["\tThe Fourier coefficients are given by", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T\  = \ 1; 
    b[n_]\  = \ 
      2/T\ Simplify[
          Integrate[t \((1 - t^2)\) Sin[2\ Pi\ n\ t/\((2  T)\)], {t, 0, T}], 
          n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.35"],

Cell[BoxData[
    \(\(-\(\(12\ \((\(-1\))\)\^n\)\/\(n\^3\ \[Pi]\^3\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "These coefficients fall off as ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\^3\)]],
  ", which is faster than either the coefficients of the even periodic \
extension,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T\  = \ 1; 
    a[n_]\  = \ 
      2/T\ Simplify[
          Integrate[t \((1 - t^2)\) Cos[2\ Pi\ n\ t/\((2  T)\)], {t, 0, T}], 
          n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.36"],

Cell[BoxData[
    \(\(2\ \((6\ \((\(-1\) + \((\(-1\))\)\^n)\) - \((1 + 2\ \
\((\(-1\))\)\^n)\)\ n\^2\ \[Pi]\^2)\)\)\/\(n\^4\ \[Pi]\^4\)\)], "Output"]
}, Open  ]],

Cell["or the regular periodic extension,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T\  = \ 1; 
    c[n_]\  = \ 
      1/T\ Simplify[
          Integrate[t \((1 - t^2)\) Exp[I\ 2\ Pi\ n\ t/T], {t, 0, T}], 
          n \[Element] Integers]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.37"],

Cell[BoxData[
    \(\(-\(\(3\ \((\[ImaginaryI] + 
                n\ \[Pi])\)\)\/\(4\ n\^3\ \[Pi]\^3\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "both of which can be seen to fall off as ",
  Cell[BoxData[
      \(TraditionalForm\`1/n\^2\)]],
  " for large ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tA plot (Cell ",
  ButtonBox["2.38",
    ButtonData:>"Cell 2.38",
    ButtonStyle->"Hyperlink"],
  ") of the resulting series for the odd periodic extension, keeping only \
five terms, illustrates the accuracy of the result when compared to the exact \
function."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(f\_approx[x_, M_] := \ 
        Sum[b[n]\ Sin[2\ Pi\ n\ t/\((2  T)\)], {n, 1, 
            M}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(func\  = \ f\_approx[t, 5];\)\), "\n", 
    \(\(p1\  = \ 
        Plot[t \((1 - t^2)\), {t, 0, 1}, 
          PlotStyle \[Rule] {RGBColor[1, 0, 0], Thickness[0.012]}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p2\  = \ 
        Plot[func, {t, \(-1\), 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction, 
        PlotLabel \[Rule] \*"\"\<\!\(f\^\((o)\)\)(t) for f(t)=t(1- \
\!\(t\^2\)) on 0<t<1\>\""];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.38"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.31746 0.308563 0.765798 [
[.02381 .29606 -6 -9 ]
[.02381 .29606 6 0 ]
[.18254 .29606 -12 -9 ]
[.18254 .29606 12 0 ]
[.5 .29606 -9 -9 ]
[.5 .29606 9 0 ]
[.65873 .29606 -3 -9 ]
[.65873 .29606 3 0 ]
[.81746 .29606 -9 -9 ]
[.81746 .29606 9 0 ]
[.97619 .29606 -3 -9 ]
[.97619 .29606 3 0 ]
[.32877 .00224 -24 -4.5 ]
[.32877 .00224 0 4.5 ]
[.32877 .1554 -24 -4.5 ]
[.32877 .1554 0 4.5 ]
[.32877 .46172 -18 -4.5 ]
[.32877 .46172 0 4.5 ]
[.32877 .61488 -18 -4.5 ]
[.32877 .61488 0 4.5 ]
[.5 .63053 -101.438 0 ]
[.5 .63053 101.438 12.4375 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30856 m
.02381 .31481 L
s
[(-1)] .02381 .29606 0 1 Mshowa
.18254 .30856 m
.18254 .31481 L
s
[(-0.5)] .18254 .29606 0 1 Mshowa
.5 .30856 m
.5 .31481 L
s
[(0.5)] .5 .29606 0 1 Mshowa
.65873 .30856 m
.65873 .31481 L
s
[(1)] .65873 .29606 0 1 Mshowa
.81746 .30856 m
.81746 .31481 L
s
[(1.5)] .81746 .29606 0 1 Mshowa
.97619 .30856 m
.97619 .31481 L
s
[(2)] .97619 .29606 0 1 Mshowa
.125 Mabswid
.05556 .30856 m
.05556 .31231 L
s
.0873 .30856 m
.0873 .31231 L
s
.11905 .30856 m
.11905 .31231 L
s
.15079 .30856 m
.15079 .31231 L
s
.21429 .30856 m
.21429 .31231 L
s
.24603 .30856 m
.24603 .31231 L
s
.27778 .30856 m
.27778 .31231 L
s
.30952 .30856 m
.30952 .31231 L
s
.37302 .30856 m
.37302 .31231 L
s
.40476 .30856 m
.40476 .31231 L
s
.43651 .30856 m
.43651 .31231 L
s
.46825 .30856 m
.46825 .31231 L
s
.53175 .30856 m
.53175 .31231 L
s
.56349 .30856 m
.56349 .31231 L
s
.59524 .30856 m
.59524 .31231 L
s
.62698 .30856 m
.62698 .31231 L
s
.69048 .30856 m
.69048 .31231 L
s
.72222 .30856 m
.72222 .31231 L
s
.75397 .30856 m
.75397 .31231 L
s
.78571 .30856 m
.78571 .31231 L
s
.84921 .30856 m
.84921 .31231 L
s
.88095 .30856 m
.88095 .31231 L
s
.9127 .30856 m
.9127 .31231 L
s
.94444 .30856 m
.94444 .31231 L
s
.25 Mabswid
0 .30856 m
1 .30856 L
s
.34127 .00224 m
.34752 .00224 L
s
[(-0.4)] .32877 .00224 1 0 Mshowa
.34127 .1554 m
.34752 .1554 L
s
[(-0.2)] .32877 .1554 1 0 Mshowa
.34127 .46172 m
.34752 .46172 L
s
[(0.2)] .32877 .46172 1 0 Mshowa
.34127 .61488 m
.34752 .61488 L
s
[(0.4)] .32877 .61488 1 0 Mshowa
.125 Mabswid
.34127 .04053 m
.34502 .04053 L
s
.34127 .07882 m
.34502 .07882 L
s
.34127 .11711 m
.34502 .11711 L
s
.34127 .19369 m
.34502 .19369 L
s
.34127 .23198 m
.34502 .23198 L
s
.34127 .27027 m
.34502 .27027 L
s
.34127 .34685 m
.34502 .34685 L
s
.34127 .38514 m
.34502 .38514 L
s
.34127 .42343 m
.34502 .42343 L
s
.34127 .50001 m
.34502 .50001 L
s
.34127 .5383 m
.34502 .5383 L
s
.34127 .57659 m
.34502 .57659 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.5 .63053 -162.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 9.438 moveto
(H) show
73.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
77.375 9.438 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
82.625 13.438 moveto
(H) show
88.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
94.625 13.438 moveto
(L) show
106.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(for) show
130.625 13.438 moveto
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
136.625 13.438 moveto
(H) show
142.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
148.625 13.438 moveto
(L) show
154.625 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
160.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
166.625 13.438 moveto
(H) show
172.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
178.625 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
190.625 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
196.625 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
201.875 13.438 moveto
(L) show
213.875 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(on) show
231.875 13.438 moveto
(0) show
237.875 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
243.875 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
249.875 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(<) show
255.875 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
261.875 13.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.012 w
.34127 .30856 m
.35415 .33958 L
.36819 .37304 L
.38138 .40378 L
.39407 .43241 L
.40757 .46153 L
.42057 .48792 L
.43439 .51386 L
.4477 .53644 L
.4605 .55561 L
.47412 .57291 L
.48724 .58624 L
.49985 .59565 L
.50632 .59909 L
.50995 .60059 L
.51328 .60168 L
.51487 .60211 L
.51656 .60249 L
.51802 .60276 L
.51961 .603 L
.52058 .60311 L
.52147 .60319 L
.52233 .60325 L
.52276 .60328 L
.52323 .6033 L
.52366 .60331 L
.52405 .60332 L
.52427 .60332 L
.5245 .60332 L
.52493 .60332 L
.52533 .60331 L
.52575 .6033 L
.52612 .60329 L
.52652 .60327 L
.5273 .60322 L
.52815 .60315 L
.52988 .60294 L
.53148 .60268 L
.53296 .60237 L
.53633 .60146 L
.53992 .60013 L
.54703 .5964 L
.55375 .59151 L
.56657 .57831 L
.58021 .55843 L
.59335 .53325 L
.60597 .50315 L
.61942 .46444 L
.63236 .42036 L
.64612 .36582 L
Mistroke
.65873 .30856 L
Mfstroke
0 g
.5 Mabswid
.02381 .30856 m
.04262 .22939 L
.06244 .15547 L
.08255 .09707 L
.09396 .07207 L
.10458 .05368 L
.11508 .03963 L
.125 .02959 L
.1339 .02294 L
.13893 .02009 L
.14357 .018 L
.14823 .01642 L
.15085 .01576 L
.15324 .0153 L
.15546 .01499 L
.15672 .01486 L
.15788 .01478 L
.159 .01473 L
.16002 .01472 L
.16119 .01473 L
.1623 .01477 L
.16349 .01484 L
.16481 .01497 L
.16618 .01514 L
.16746 .01534 L
.16975 .01581 L
.17221 .01645 L
.17781 .01847 L
.18292 .021 L
.19284 .02778 L
.20201 .03621 L
.22277 .06221 L
.26204 .13021 L
.29979 .20956 L
.33999 .30541 L
.37868 .3983 L
.41982 .48558 L
.44034 .52362 L
.45944 .55443 L
.47787 .5781 L
.48818 .58808 L
.49755 .59491 L
.5024 .59758 L
.50753 .59976 L
.51191 .60111 L
.5144 .60166 L
.51673 .60204 L
.51802 .60219 L
.5187 .60226 L
.51942 .60231 L
Mistroke
.52012 .60235 L
.52075 .60238 L
.52197 .60241 L
.52316 .6024 L
.52444 .60236 L
.52565 .60228 L
.52676 .60218 L
.52805 .60202 L
.52926 .60184 L
.532 .6013 L
.53467 .6006 L
.53753 .59967 L
.54283 .59742 L
.54773 .59474 L
.55881 .58641 L
.56858 .57618 L
.57894 .56193 L
.58834 .54553 L
.59845 .52375 L
.61675 .47264 L
.65794 .31196 L
.67851 .22548 L
.69762 .15464 L
.71608 .10053 L
.73578 .05962 L
.74605 .04447 L
.75716 .03209 L
.76227 .02764 L
.76766 .02369 L
.77271 .02068 L
.77733 .01848 L
.77965 .01756 L
.78218 .01671 L
.78437 .01609 L
.78679 .01555 L
.78934 .01512 L
.79074 .01495 L
.79206 .01483 L
.79328 .01476 L
.79441 .01472 L
.79564 .01472 L
.79694 .01475 L
.79809 .01482 L
.79913 .0149 L
.80033 .01504 L
.80147 .01519 L
.80349 .01555 L
.80569 .01605 L
.81067 .01764 L
.81527 .01965 L
Mistroke
.82494 .02561 L
.83401 .0333 L
.85464 .05785 L
.89343 .1234 L
.93467 .20948 L
.9744 .30416 L
.97619 .30856 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00IOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0k?ooool006Gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`3]ooooo`00GOooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool00ol0003oooooooooo`3Uooooo`00
IOooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool3o`00
0>Gooooo001Uooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007
ooooo`03o`000?oooooooooo0>Gooooo001Uooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0>Gooooo001Uooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0>Gooooo0012oooo
o`[o00006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`2:ooooo`Wo0000D_ooool003oooooo0ol0000:ooooo`;o0000<_ooool00ol0
003oooooooooo`28ooooo`;o00002Oooool3o`0004oooooo000nooooo`03o`000?oooooooooo00go
oooo0_l0000`ooooo`03o`000?oooooooooo08Kooooo0_l0000>ooooo`;o0000COooool003gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo08Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`1:ooooo`00??ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Poooool2o`0001?ooooo00?o
0000ooooooooool0B_ooool003_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19
ooooo`00>_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo000iooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`20ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0Aoooool003Sooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Yooooo`?o0000Ooooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo04Kooooo000hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0AOoo
ool003Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo07kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`14ooooo`00=_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0OOooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo04?ooooo000eooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0@_ooool003Gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`11ooooo`00=?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0Noooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo047ooooo000d
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1k
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@?ooool003?ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`10ooooo`00<oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03oooooo000booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
?_ooool003;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0nooooo`00<Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo023ooooo0ol0001hooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0?Oooool0037ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0mooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03co
oooo000`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0??ooool002oooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0kooooo`00;oooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo03[ooooo000^ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0>_ooool002kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo07Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0iooooo`00
;_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Wooooo000]ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0>?ooool002gooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0hooooo`00;Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03Oooooo000/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool3o`0007?o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0fooooo`00;?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Loooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03Kooooo000/ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0=Oooool002_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0e
ooooo`00:oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0L_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Cooooo000[ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0=?ooool002[ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0cooooo`00:_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo03?ooooo000Zooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1aooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0<_ooool0
02Wooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
073ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0booooo`00:Oooool00ol0003o
ooooooooo`0iooooo`05onk^k_lb<S;o0000oc8b<_l000001Oooool2ob4Q8@Cooooo1Ol00006oooo
o`03o`000?oooooooooo073ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0aoooo
o`00:Oooool00ol0003oooooooooo`0iooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?ooool2
ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0aooooo`00:?ooool00ol0003oooooooooo`0b
ooooo`Ko00000_ooool01_l@413ooooooooooooooooo410@o`0000_ooooo00?oV9RHob4Q8Oo^k^h0
1oooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
<?ooool002Sooooo00?o0000ooooooooool0>_ooool01ol0003ooooooooooooooooo0000ooooool0
00002oooool00onHV9So8B4Qonk^kP06ooooo`?o0000Koooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo033ooooo000Xooooo`03o`000?oooooooooo03[ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1_oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool0;oooool002Sooooo00?o0000oooooooo
ool0>_ooool01Ol@413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06kooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0_ooooo`009oooool00ol0003oooooooooo`0kooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00_ooool00ol0003oooooooooo`06ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool0
0ol0003oooooooooo`1^ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0;_ooool0
02Oooooo00?o0000ooooooooool0>oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00?o0000
ooooooooool01Oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0K_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02kooooo000Wooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool0;Oooool002Kooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0]ooooo`009_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo02co
oooo000Vooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`1]ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0;?ooool002Gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06gooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0[ooooo`009Oooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo02_ooooo000Uooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool0:_ooool002Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0=ooooo`?o
0000K?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02[ooooo000Tooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1[ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0:Oooool002Cooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Yooooo`009?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo02Sooooo000Sooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`1[ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0:?ooool002?o
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Wooooo`008oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo02Oooooo000Rooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool09_ooool002;ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0V
ooooo`008_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0JOooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo00Oooooo0ol0001Yooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09?oo
ool0027ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Tooooo`008?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo02Cooooo000Pooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool08oooool0023ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`0Sooooo`008?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Ioooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02;ooooo000O
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool08_ooool001oooooo00?o0000oooo
ooooool0Eoooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Oooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooooooo`0Rooooo`007oooool00ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`1Gooooo`03
o`000?oooooooooo027ooooo000Oooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
8Oooool001kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Pooooo`007Oooool4
o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM01kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Vooooo`Co000000?o410@o`000?ooool08oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd08_ooool00ol0003oooooooooo`05
o`0001_ooooo000Nooooo`;o00009oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo01gooooo00?o0000ooooooooool00_ooool3o`0002Gooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Wooooo`03o`000?oo
oooo000002Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08Ooo
ool02?l0003ooooooooooonHV9So8B4Qonk^k_ooooooA4A46oooool001Cooooo1_l00004ooooo`;o
00007oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000002Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Qooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^
7?ooool001kooooo0_l0000Wooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`0Nooooo`05o`000?ooooooooooooooool000009oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool09oooool00ol0003oooooo`00000Wooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool08_ooool01ol0003oooooooooooooooooV9RHob4Q8Oo^k^h06ooo
ool001gooooo00?o0000ooooool000009oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Oooooo`05o`000?ooooooooooooooool000009oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Xooooo`03o`000?oooooo
000002Oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo00Ko
0000ooooooooooooooooogMgMomVIVHKooooo`007Oooool00ol0003oooooo`00000Wooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`00
02Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo02[ooooo0_l0000X
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Wooooo000Mooooo`03o`000?oooooo000002Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo02;ooooo00Co0000oooooooooooo00009ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0:_ooool2o`0002Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`;o000000Co^[ZjoooooonHV9So
410@6oooool001gooooo00?o0000ofIVI_l000009oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l0000Rooooo`03o`000?oooooo000002Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00009oooool01?mEEEGoIVIVo`000?l0000Vooooo`03oeEEEOmVIVKo000000gooooo1?l0000V
ooooo`05o`000?l@413o0000ob4Q8Oo<c<`06oooool001cooooo00?o0000ooooooooool0Goooool0
0ol0003oooooo`00001Vooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool07Oooool0
01cooooo00?o0000ooooooooool0Goooool00ol0003oooooo`00001Uooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool07?ooool001cooooo00?o0000ooooooooool0H?ooool2o`0006Go
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Looooo`007?ooool00ol0003ooooo
ooooo`1Pooooo`;o0000IOooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01cooooo
000Kooooo`03o`000?oooooooooo067ooooo00?oo`00o`000?oo0000Hoooool00ooo003o0000ool0
001Rooooo`03o`000?oooooooooo01_ooooo000Dooooof_o000000?oo`00o`000?oo0000I?l00002
ool006_o00005Oooool001_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2ool00003o`000?oo003ooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ool00?oo00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`006oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`;oo`0000?o0000ool00?ooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool01?oo003o0000ool00?oo0008oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01[ooooo0020ooooo`04ool00?l0003oo`00ool0063ooooo00Coo`00o`00
0?oo003oo`00P?ooool0083ooooo0_oo00000ol0003oo`00ooooo`1Oooooo`03o`000?oo003oo`00
087ooooo0020ooooo`03o`000?oo003o000000;oo`00Goooool00ol0003oo`00ool00021ooooo`00
P?ooool01Ol0003oo`00ool00?l0003oo`0005oooooo00?o0000ool00?oo0000POooool0083ooooo
00Co0000oooooooo003o00000_oo001Mooooo`04ool00?l0003oo`00ool0087ooooo0020ooooo`04
o`000?ooooooo`00o`0000;oo`00GOooool01?l0003oo`00ool00?oo0021ooooo`00P?ooool01Ol0
003ooooooooooooo003o000000;oo`00G?ooool00ol0003oo`00ool00022ooooo`00P?ooool01Ol0
003ooooooooooooo003o000000;oo`00G?ooool00ol0003oo`00ool00022ooooo`00P?ooool01_l0
003oooooooooooooooooo`00o`0000;oo`00Foooool00ol0003oo`00ool00022ooooo`00P?ooool0
1_l0003oooooooooooooooooo`00o`0000;oo`00F_ooool01?l0003oo`00ool00?oo0022ooooo`00
P?ooool3o`0000;ooooo00?o0000ool00?oo0000F_ooool01?l0003oo`00ool00?oo0022ooooo`00
P?ooool00ol0003oooooooooo`02ooooo`04ool00?l0003oo`00ool005Wooooo00?o0000ool00?oo
0000Poooool0083ooooo00?o0000ooooooooool00_ooool01?oo003o0000ool00?oo001Iooooo`03
o`000?oo003oo`0008?ooooo0020ooooo`03o`000?oooooooooo00?ooooo00?oo`00o`000?oo0000
F?ooool01?l0003oo`00ool00?oo0023ooooo`00P?ooool00ol0003oooooooooo`03ooooo`04ool0
0?l0003oo`00ool005Oooooo00Co0000ool00?oo003oo`00Poooool0083ooooo00?o0000oooooooo
ool00oooool01?oo003o0000ool00?oo001Gooooo`04o`000?oo003oo`00ool008?ooooo0020oooo
o`03o`000?oooooooooo00Cooooo00?oo`00o`000?oo0000Eoooool00ol0003oo`00ool00024oooo
o`00P?ooool00ol0003oooooooooo`04ooooo`04ool00?l0003oo`00ool005Gooooo00Co0000ool0
0?oo003oo`00Q?ooool0083ooooo00?o0000ooooooooool01?ooool2ool00003o`000?oo003ooooo
05Cooooo00Co0000ool00?oo003oo`00Q?ooool0083ooooo00?o0000ooooooooool01Oooool01?oo
003o0000ool00?oo001Dooooo`04o`000?oo003oo`00ool008Cooooo0020ooooo`03o`000?oooooo
oooo00Gooooo00Coo`00o`000?oo003oo`00E?ooool00ol0003oo`00ool00025ooooo`00P?ooool0
0ol0003oooooooooo`06ooooo`03ool00?l0003oo`0005?ooooo00Co0000ool00?oo003oo`00QOoo
ool0083ooooo0ol00006ooooo`04ool00?l0003oo`00ool005;ooooo00Co0000ool00?oo003oo`00
QOooool0083ooooo00?o0000ooooooooool01_ooool2ool00003o`000?oo003ooooo057ooooo00?o
0000ool00?oo0000Q_ooool0083ooooo00?o0000ooooooooool01oooool01?oo003o0000ool00?oo
001@ooooo`04ool00?l0003oo`00ool008Kooooo0020ooooo`03o`000?oooooooooo00Oooooo00Co
o`00o`000?oo003oo`00D?ooool01?l0003oo`00ool00?oo0026ooooo`00P?ooool00ol0003ooooo
ooooo`08ooooo`03ool00?l0003oo`00053ooooo00?o0000ool00?oo0000Qoooool0083ooooo00?o
0000ooooooooool02?ooool01?oo003o0000ool00?oo001?ooooo`03o`000?oo003oo`0008Oooooo
0020ooooo`03o`000?oooooooooo00Sooooo0_oo00000ol0003oo`00ooooo`1=ooooo`04ool00?l0
003oo`00ool008Oooooo0020ooooo`03o`000?oooooooooo00Wooooo00Coo`00o`000?oo003oo`00
COooool01?l0003oo`00ool00?oo0027ooooo`00P?ooool00ol0003oooooooooo`09ooooo`;oo`00
00?o0000ool00?ooool0C?ooool00ol0003oo`00ool00028ooooo`00P?ooool00ol0003ooooooooo
o`0:ooooo`04ool00?l0003oo`00ool004_ooooo00Coo`00o`000?oo003oo`00R?ooool0083ooooo
00?o0000ooooooooool02_ooool2ool00003o`000?oo003ooooo04[ooooo00Coo`00o`000?oo003o
o`00R?ooool0083ooooo00?o0000ooooooooool02oooool00ooo003o0000ool0001;ooooo`03o`00
0?oo003oo`0008Wooooo0020ooooo`?o00002oooool01?oo003o0000ool00?oo001:ooooo`03o`00
0?oo003oo`0008Wooooo0020ooooo`03o`000?oooooooooo00_ooooo0_oo00000ol0003oo`00oooo
o`18ooooo`04ool00?l0003oo`00ool008Wooooo0020ooooo`03o`000?oooooooooo00cooooo00Co
o`00o`000?oo003oo`00B?ooool01?oo003o0000ool00?oo0029ooooo`00P?ooool00ol0003ooooo
ooooo`0<ooooo`;oo`0000?o0000ool00?ooool0Aoooool00ol0003oo`00ool0002:ooooo`00P?oo
ool00ol0003oooooooooo`0=ooooo`04ool00?l0003oo`00ool004Kooooo00Coo`00o`000?oo003o
o`00R_ooool0083ooooo00?o0000ooooooooool03Oooool2ool00003o`000?oo003ooooo04Gooooo
00Coo`00o`000?oo003oo`00R_ooool0083ooooo00?o0000ooooooooool03_ooool01?oo003o0000
ool00?oo0015ooooo`03ool00?l0003oo`0008_ooooo0020ooooo`03o`000?oooooooooo00kooooo
0_oo00000ol0003oo`00ool00014ooooo`03o`000?oo003oo`0008_ooooo0020ooooo`03o`000?oo
oooooooo00oooooo00Coo`00o`000?oo003oo`00@oooool01?oo003o0000ool00?oo002;ooooo`00
P?ooool00ol0003oooooooooo`0@ooooo`04ool00?l0003oo`00ool004;ooooo00Coo`00o`000?oo
003oo`00Roooool006Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Kooooo00?o0000ooooooooool04?ooool01?oo003o0000ool00?oo0012ooooo`03ool00?l0003o
o`0008cooooo001Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo017ooooo00Coo`00o`000?oo003oo`00
@?ooool01?oo003o0000ool00?oo002<ooooo`00IOooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01oooool3o`00017ooooo00Coo`00o`000?oo003oo`00@?ooool01?oo
003o0000ool00?oo002<ooooo`00IOooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0Booooo`04ool00?l0003oo`00ool003oooooo00?o
o`00o`000?oo0000SOooool006Gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo00Gooooo00?o0000ooooooooool04_ooool01?oo003o0000ool00?oo000nooooo`;oo`00
00?o0000ool00?ooool0S?ooool006Gooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool01?l0003oo`00ool00?oo000mooooo`04
ool00?l0003oo`00ool008gooooo001Uooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool04oooool01?oo003o0000ool00?oo
000mooooo`03ool00?l0003oo`0008kooooo001Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool05?ooool00ol0003oo`00
ool0000looooo`;oo`0000?o0000ool00?ooool0SOooool0083ooooo00?o0000ooooooooool05?oo
ool01?oo003o0000ool00?oo000kooooo`04ool00?l0003oo`00ool008kooooo0020ooooo`03o`00
0?oooooooooo01Cooooo00Coo`00o`000?oo003oo`00>oooool00ooo003o0000ool0002?ooooo`00
P?ooool00ol0003oooooooooo`0Eooooo`04ool00?l0003oo`00ool003Wooooo0_oo00000ol0003o
o`00ooooo`2>ooooo`00P?ooool00ol0003oooooooooo`0Eooooo`04ool00?l0003oo`00ool003Wo
oooo00Coo`00o`000?oo003oo`00Soooool0083ooooo00?o0000ooooooooool05_ooool01?oo003o
0000ool00?oo000hooooo`03ool00?l0003oo`00093ooooo0020ooooo`03o`000?oooooooooo01Ko
oooo00Coo`00o`000?oo003oo`00=oooool2ool00003o`000?oo003ooooo08oooooo0020ooooo`?o
00005oooool01?oo003o0000ool00?oo000fooooo`04ool00?l0003oo`00ool0093ooooo0020oooo
o`03o`000?oooooooooo01Oooooo0_oo00000ol0003oo`00ooooo`0eooooo`03ool00?l0003oo`00
097ooooo0020ooooo`03o`000?oooooooooo01Sooooo00Coo`00o`000?oo003oo`00=?ooool01?oo
003o0000ool00?oo002Aooooo`00P?ooool00ol0003oooooooooo`0Hooooo`;oo`0000?o0000ool0
0?ooool0<oooool01?oo003o0000ool00?oo002Aooooo`00P?ooool00ol0003oooooooooo`0Ioooo
o`04ool00?l0003oo`00ool003?ooooo00?oo`00o`000?oo0000T_ooool0083ooooo00?o0000oooo
ooooool06Oooool2ool00003o`000?oo003ooooo037ooooo00Coo`00o`000?oo003oo`00T_ooool0
083ooooo00?o0000ooooooooool06_ooool2ool00003o`000?oo003ooooo033ooooo00Coo`00o`00
0?oo003oo`00T_ooool0083ooooo00?o0000ooooooooool06_ooool2ool00003o`000?oo003ooooo
02oooooo0_oo00000ol0003oo`00ooooo`2Booooo`00P?ooool00ol0003oooooooooo`0Kooooo`;o
o`0000?o0000ool00?ooool0;_ooool01?oo003o0000ool00?oo002Cooooo`00P?ooool00ol0003o
ooooooooo`0Kooooo`;oo`0000?o0000ool00?oo0000;_ooool00ooo003o0000ool0002Dooooo`00
P?ooool00ol0003oooooooooo`0Looooo`;oo`0000?o0000ool00?ooool0;?ooool01?oo003o0000
ool00?oo002Dooooo`00P?ooool00ol0003oooooooooo`0Mooooo`;oo`0000?o0000ool00?ooool0
:oooool01?oo003o0000ool00?oo002Dooooo`00P?ooool00ol0003oooooooooo`0Mooooo`;oo`00
00?o0000ool00?ooool0:_ooool01?oo003o0000ool00?oo002Eooooo`00P?ooool3o`0001kooooo
0_oo00000ol0003oo`00ooooo`0Yooooo`04ool00?l0003oo`00ool009Gooooo0020ooooo`03o`00
0?oooooooooo01kooooo0_oo00000ol0003oo`00ool0000Xooooo`;oo`0000?o0000ool00?ooool0
UOooool0083ooooo00?o0000ooooooooool07oooool2ool00003o`000?oo003ooooo02Oooooo00Co
o`00o`000?oo003oo`00U_ooool0083ooooo00?o0000ooooooooool08?ooool2ool00003o`000?oo
003ooooo02Gooooo0_oo00000ol0003oo`00ooooo`2Fooooo`00P?ooool00ol0003oooooooooo`0P
ooooo`;oo`0000?o0000ool00?oo00009Oooool01?oo003o0000ool00?oo002Gooooo`00P?ooool0
0ol0003oooooooooo`0Qooooo`;oo`0000?o0000ool00?ooool08oooool01?oo003o0000ool00?oo
002Hooooo`00P?ooool00ol0003oooooooooo`0Rooooo`04ool00?l0003oo`00ool002?ooooo00Co
o`00o`000?oo003oo`00V?ooool0083ooooo00?o0000ooooooooool08_ooool2ool00003o`000?oo
003oo`00027ooooo00Coo`00o`000?oo003oo`00VOooool0083ooooo00?o0000ooooooooool08ooo
ool2ool00003o`000?oo003oo`0001oooooo0_oo00000ol0003oo`00ool0002Iooooo`00P?ooool0
0ol0003oooooooooo`0Tooooo`;oo`0000?o0000ool00?oo00007Oooool2ool00003o`000?oo003o
o`0009[ooooo0020ooooo`03o`000?oooooooooo02Gooooo0_oo00000ol0003oo`00ool0000Koooo
o`;oo`0000?o0000ool00?oo0000Voooool0083ooooo00?o0000ooooooooool09_ooool2ool00003
o`000?oo003oo`0001Wooooo0ooo00000ol0003oo`00ooooo`2Kooooo`00P?ooool3o`0002Oooooo
0_oo00000ol0003oo`00ool0000Hooooo`;oo`0000?o0000ool00?ooool0W?ooool0083ooooo00?o
0000ooooooooool0:?ooool2ool00003o`000?oo003oo`0001Kooooo0_oo00000ol0003oo`00oooo
o`2Mooooo`00P?ooool00ol0003oooooooooo`0Yooooo`;oo`0000Co0000ool00?oo003oo`004ooo
ool2ool00003o`000?oo003oo`0009kooooo0020ooooo`03o`000?oooooooooo02[ooooo0_oo0000
1?l0003oo`00ool00?oo000Aooooo`03ool00?l0003o000000;oo`00Woooool0083ooooo00?o0000
ooooooooool0:oooool2ool00004o`000?oo003oo`00ool000kooooo0_oo00001?l0003oo`00ool0
0?oo002Pooooo`00P?ooool00ol0003oooooooooo`0]ooooo`03ool00?l0003oo`0000?oo`002_oo
ool3ool00004o`000?oo003oo`00ool00:7ooooo0020ooooo`03o`000?oooooooooo02kooooo00Co
o`00o`000?l0003o00000ooo0007ooooo`04ool00?l0003o0000o`0000?oo`00X_ooool0083ooooo
00?o0000ooooooooool0;oooool3ool000;o00001ooo0002o`0000Coo`00Y?ooool0083ooooo00?o
0000ooooooooool0<Oooool3ool000Oo00001?oo002Vooooo`00IOooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`0cooooo`_oo`00Yoooool006Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>Gooooo001Uooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0000Kooooo00?o0000ooooooooool0iOooool006Gooooo00Go0000
ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0003Uooooo`00IOoo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`3Uooooo`00IOooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l0
0000koooool006Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co00000>oo
oooo001Uooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`3^ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00E?ooool00omgMgOoIVIVooooo`08oooo
o`03ofIVI_mgMgOooooo03Kooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`0Goooo
o`03ogMgMomVIVKooooo02Gooooo00?oIVIVogMgMoooool0P?ooool005?ooooo00?ogMgMoa0@4?o^
k^h02Oooool00oo^k^ko410@omgMg@0eooooo`03omgMgOl@413ok^k^00Wooooo00?ok^k^oa0@4?oM
gMd05_ooool00ooMgMgo410@onk^kP0Vooooo`03onk^k_l@413ogMgM083ooooo000hooooo`03oa0@
4?l0003o000000;o000000?o410@ooooooooool04oooool00omEEEGoV9RHooooo`03ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00_ooool00on7QhOoIVIVooooo`0;ooooo`03oa0@4?l0003o000000;o
000000Go410@ooooooooooook^k^oeEEE@02o`000004oeEEEOo^k^kooooooa0@40Go00002Oooool0
0ol@413o0000o`000002o`000003oa0@4?oooooooooo00?ooooo00?oEEEEoiRHV?ooool00_ooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?oQhN7ofIVI_ooool03?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?oEEEEoiRHV?ooool00oooool4o`000003oa0@4?oooooooooo00oooooo
00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`03ohN7QomVIVKooooo00_ooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h2ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool01_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?oV9RHob4Q8Oooool00_ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Gooooo00?oV9RHob4Q8Oooool00_ooool4o`000003oa0@4?oooooooooo03Oo
oooo000jooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00;ooooo00?ok^k^o`000?ooool03Oooool00ol0003oooooooooo`03ooooo`06
oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o
k^k^o`000?ooool00oooool6o`0000?ooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wo
oooo00?ok^k^o`000?ooool02oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000
ooooooooooooooooo`000009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OoMgMgoIVIV
o`000?mEEEGo^[Zj00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`05omgMgOmVIVKo0000
oeEEEOnj^[X01Oooool00ol0003oooooooooo`0iooooo`00>_ooool00ol0003oooooooooo`0Foooo
o`03oc8b<_oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000kooooo00?o0000ooooooooool01_ooool00olb<S;oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03oc8b<_oooooo
oooo00Gooooo00Co0000oooooooooooooooo1_l0000:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`07ooooo`05oa0@4?ooooooooooooooool@41000_ooool01?nHV9So
0000oa0@4?oMgMd5ooooo`03o`000?oooooooooo00?ooooo00CoV9RHo`000?l@413ogMgM1oooool0
0ol0003oooooooooo`0iooooo`00>_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00olb<S;oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo00?o<S8b
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo1_l00003
ooooo`03o`000?oooooooooo00Kooooo00?o<S8booooooooool01Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`05o`000?oo
ooooooooooooool000000oooool01OoMgMgoIVIVo`000?mEEEGo^[Zj00?ooooo00?o0000oooooooo
ool01?ooool01OoMgMgoIVIVo`000?mEEEGo^[Zj00Gooooo00?o0000ooooooooool0>Oooool003[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000onk^k_ooool00oooool00ol0003oooooooooo`04ooooo`03onk^k_l0003ooooo00go
oooo00?o0000ooooooooool00oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000
oc8b<_oMgMd03?ooool00ol0003oooooooooo`06ooooo`03o`000?o^k^kooooo00;ooooo00?o0000
ooooooooool01Oooool00oo^k^ko0000ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
onk^k_ooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?ok^k^
o`000?ooool02oooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ohN7Qooooooo
ZJVYo`000009ooooo`05o`000?ooooooooooooooool000001_ooool00onHV9So8B4Qooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oooool01?ooool00ol0003oooooooooo`0ioooo
o`00>?ooool00ol@413o0000o`000003o`000003ooooool0003ooooo00?ooooo0_l00006ooooo`03
o`000?oooooooooo00Cooooo00GoEEEEogMgMooooooooooooa0@4005o`0000?ooooo00?oMgMgoeEE
EOooool02oooool00ol@413o0000o`000003o`0000;ooooo00Kok^k^oeEEEOl0003o0000oeEEEOo^
k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q2?ooool00ol@413o0000o`000003o`0000Gooooo
00CoEEEEogMgMooooooo410@1Ol00004ooooo`03ogMgMomEEEGooooo00[ooooo00?o410@o`000?l0
00000ol00005ooooo`03oeEEEOmgMgOooooo00Gooooo00?o0000ooooooooool03oooool00ol@413o
0000o`000003o`0000;ooooo1?l00004ooooo`03ogMgMomEEEGooooo00_ooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h2ooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool01oooool0
1Ol@413ooooooooooooooooo410@00Wooooo00?o410@o`000?l000000ol0000=ooooo`03o`000?oo
oooooooo03Wooooo000jooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ooMgMgo410@onk^
kP03ooooo`03o`000?oooooooooo00?ooooo00?ok^k^oa0@4?oMgMd03_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Kooooo00?ogMgMoa0@4?o^k^h00_ooool00ol0003ooooooooo
o`04ooooo`03onk^k_l@413ogMgM00gooooo00?o0000ooooooooool01_ooool00ooMgMgo410@onk^
kP05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03onk^k_l@413ogMgM02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0>Oooool003[ooooo00?o410@okZj^_ooool00_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03ogMgMomVIVKooooo00;ooooo00?o0000ooooooooool00oooool00omVIVKoMgMg
ooooo`0>ooooo`03oa0@4?nj^[[ooooo01_ooooo00?o410@okZj^_ooool01oooool01OmgMgOoIVIV
oooooooooooo000000Kooooo00?oIVIVogMgMoooool03Oooool00ol0003oooooooooo`07ooooo`03
ogMgMomVIVKooooo00;ooooo00?oEEEEofIVI_l000004oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?oIVIVogMgMoooool08oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00000kooooo`00>_ooool01_nj^[[o
410@o`000?l@413oooooo`0000Cooooo0_l00006ooooo`03o`000?oooooooooo027ooooo00Co^[Zj
oa0@4?l0003o410@6_ooool01?nj^[[o410@o`000?l@411?ooooo`03o`000?oooooooooo08Cooooo
0010ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0T?ooool01?l0003ooooooooo
ool00026ooooo`00@Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09;ooooo0_l0
0027ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-1.27447, -0.423061, \
0.012357, 0.00512259}}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.2.4 Solution of Boundary-Value Problems Using Fourier \
Series\
\>", "Subsubtitle",
  CellTags->{"i:33", "c:17"}],

Cell[TextData[{
  "In linear boundary-value problems, we are asked to solve for an unknown \
function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " on a given interval ",
  Cell[BoxData[
      \(TraditionalForm\`a < x < b\)]],
  ".  (Here we consider a boundary-value problem in space rather than in \
time.) The general form of the linear ordinary differential equation is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \[Phi] = \[Rho]\)]],
  ", "
}], "NE2",
  CellTags->"(2.2.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  " is a given function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is some linear differential operator. This equation is supplemented by \
boundary conditions on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " and/or its derivatives at ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFourier series methods are useful in finding a ",
  StyleBox["particular ",
    FontSlant->"Italic"],
  "solution",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_p\)]],
  " to this inhomogeneous ODE, ",
  "provided that",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is a differential operator with ",
  StyleBox["constant coefficients",
    FontSlant->"Italic"],
  ", of the form given in Eq. ",
  ButtonBox["(1.6.7)",
    ButtonData:>{"Chapter1.nb", "(1.6.7)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor example, consider the problem of determining the electrostatic \
potential between two parallel conducting plates at positions ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  ", between which there is some given distribution of charge, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ". The potential satisfies the Poisson equation ",
  ButtonBox["(1.1.10)",
    ButtonData:>{"Chapter1.nb", "(1.1.10)"},
    ButtonStyle->"Hyperlink"],
  ", which in one spatial dimension takes the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]/\[DifferentialD]x\^2 = \
\(-\(\[Rho](x)\)\)/\[Epsilon]\_o, \ \ \ \ \ \ \ \ \[Phi](a) = 
        V\_1, \ \ \ \ \[Phi](b) = V\_2\)]],
  ",    "
}], "NE2",
  CellTags->"(2.2.13)"],

Cell[TextData[{
  "and where ",
  Cell[BoxData[
      \(TraditionalForm\`V\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_2\)]],
  "are the voltages applied to the two plates. "
}], "Text"],

Cell[TextData[{
  "\tThis problem could be solved by the direct integration technique used to \
solve Eq. ",
  ButtonBox["(1.1.1)",
    ButtonData:>{"Chapter1.nb", "(1.1.1)"},
    ButtonStyle->"Hyperlink"],
  ". Here, however, we will use Fourier techniques, since such techniques can \
also be applied to more complex problems that are not amenable to direct \
integration. We will run across many more problems of this type in future \
sections. "
}], "Text"],

Cell[TextData[{
  "\tTo solve this problem using Fourier techniques, we follow the procedure \
discussed in Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:43"},
    ButtonStyle->"Hyperlink"],
  ", and break \[Phi] into a homogeneous and a particular solution:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = \[Phi]\_h + \[Phi]\_p\)]],
  ","
}], "NE2",
  CellTags->"(2.2.14)"],

Cell[TextData[{
  "where the particular solution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_p\)]],
  " is any solution that  satisfies Eq. ",
  ButtonBox["(2.2.13)",
    ButtonData:>"(2.2.13)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\_p/\[DifferentialD]x\^2 = \
\(-\(\[Rho](x)\)\)/\[Epsilon]\_o\)]],
  ".     "
}], "NE2",
  CellTags->"(2.2.15)"],

Cell["\<\
After we have found a particular solution, we then solve for a \
homogeneous solution that satisfies the proper boundary conditions:\
\>", \
"Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\_h/\[DifferentialD]x\^2 = 
        0, \ \ \ \ \ \ \ \ \(\[Phi]\_h\)(a) = 
        V\_1 - \(\[Phi]\_p\)(a), \ \ \ \ \(\[Phi]\_h\)(b) = 
        V\_2 - \(\[Phi]\_p\)(b)\)]],
  ".     "
}], "NE2",
  CellTags->"(2.2.16)"],

Cell[TextData[{
  "In this way, the particular solution takes care of the inhomogeneity, and \
the homogeneous solution takes care of the boundary conditions. Adding Eqs. \
(",
  ButtonBox["2.2.15",
    ButtonData:>"(2.2.15)",
    ButtonStyle->"Hyperlink"],
  ") and (",
  ButtonBox["2.2.16",
    ButtonData:>"(2.2.16)",
    ButtonStyle->"Hyperlink"],
  "), one can easily see that the total potential, Eq. (",
  ButtonBox["2.2.15",
    ButtonData:>"(2.2.15)",
    ButtonStyle->"Hyperlink"],
  "), satisfies both ODE and boundary conditions in Eq. ",
  ButtonBox["(2.2.13)",
    ButtonData:>"(2.2.13)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor this simple ODE, the general homogeneous solution is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_h\)(x)\  = \ C\_1\  + \ \(C\_2\) x\)]],
  ". To find the particular solution using Fourier methods, we replace ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_p\)]],
  " by a its periodic extension and employ an exponential Fourier series,"
}], "Text",
  CellTags->"i:35"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_p\)(
          x) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( \[Phi]\_n\) \
\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ n\ x\ /L\)\)]],
  ","
}], "NE2",
  CellTags->"(2.2.17)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`L = b - a\)]],
  " is the length of the interval."
}], "Text"],

Cell[TextData[{
  "\tNote the change in sign of the exponential compared to the previous \
section involving Fourier times series, Eq. ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  ". For spatial Fourier series, the above sign is conventional; for Fourier \
series in time, the opposite sign is used. Of course, either sign can be used \
as long as one is consistent throughout the calculation, but we will stick \
with convention and use different signs for time and space series. (Although \
these different conventions may seem arbitrary and confusing at first, there \
is a good reason for them, having to do with the form of traveling waves. See \
Sec. ",
  ButtonBox["5.1.1",
    ButtonData:>{"Chapter5.nb", "c:4"},
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell[TextData[{
  "   The Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_n\)]],
  " can then be found by substitution of Eq. ",
  ButtonBox["(2.2.17)",
    ButtonData:>"(2.2.17)",
    ButtonStyle->"Hyperlink"],
  " into the ODE and taking the derivative of the resulting series \
term-by-term:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\_p/\[DifferentialD]x\^2 = \
\(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\(\(\( \[Phi]\_n\)(\(\
\[ImaginaryI]\ 2  \[Pi]\ n\)\/L)\)\^2\) \[ExponentialE]\^\(\[ImaginaryI]\ 2\ \
\[Pi]\ n\ x\ /L\)\  = \(-\(\[Rho](x)\)\)/\(\(\[Epsilon]\_o\)\(.\)\)\)\)]],
  " "
}], "NE2",
  CellTags->"(2.2.18)"],

Cell[TextData[{
  "If we now multiply both sides of the equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ n\ \
x\ /L\))\)\^*\)\)]],
  ", integrate from ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  ", and use the orthogonality relations ",
  ButtonBox["(2.1.29)",
    ButtonData:>"(2.1.29)",
    ButtonStyle->"Hyperlink"],
  ", the result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_n = \(\((L\/\(2  \[Pi]\ n\))\)\^2\) \
\[Rho]\_n\/\[Epsilon]\_o, \ \ n \[NotEqual] 0\)]],
  ","
}], "NE2",
  CellTags->"(2.2.19)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_n\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th Fourier coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ", given by"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_n = \ \(1\/L\) \(\[Integral]\_a\%b\( \[Rho](
                x)\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 2\ \[Pi]\ n\ x\ \
/L\)\) \[DifferentialD]x\)\)], "NE2"], "NE2"],
  StyleBox[".", "NE2"]
}], "NE2",
  CellTags->"(2.2.20)"],

Cell[TextData[{
  "However, for the  ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " term, the coefficient in front of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_n\)]],
  " in Eq. ",
  ButtonBox["(2.2.18)",
    ButtonData:>"(2.2.18)",
    ButtonStyle->"Hyperlink"],
  " vanishes, so a finite solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_o\)]],
  "cannot be found. This is a case of an exact resonance, discussed in Sec. \
",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:46"},
    ButtonStyle->"Hyperlink"],
  ". For this special resonant term, the solution does not have the form of a \
Fourier mode. Rather, the ",
  "right-hand",
  " side of Eq. ",
  ButtonBox["(2.2.18)",
    ButtonData:>"(2.2.18)",
    ButtonStyle->"Hyperlink"],
  " is a constant,  and we must find a particular solution to  the equation "
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\_\(p\ \
o\)/\[DifferentialD]x\^2 = \(-\[Rho]\_o\)/\[Epsilon]\_o\)], "NE2"], "NE2"],
  StyleBox[",", "NE2"]
}], "NE2",
  CellTags->"(2.2.21)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " Fourier coefficient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ". A particular solution, found by direct integration of Eq. ",
  ButtonBox["(2.2.21)",
    ButtonData:>"(2.2.21)",
    ButtonStyle->"Hyperlink"],
  ", is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_\(p\ o\)\)(x) = \(-\[Rho]\_o\) 
          x\^2/2  \[Epsilon]\_o\)]],
  ","
}], "NE2",
  CellTags->"(2.2.22)"],

Cell[TextData[{
  "which exhibits the secular growth typical of exact resonance. Thus, a \
particular solution to Eq. ",
  ButtonBox["(2.2.13)",
    ButtonData:>"(2.2.13)",
    ButtonStyle->"Hyperlink"],
  "  is"
}], "Text",
  CellTags->"i:34"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(\[Phi]\_p\)(x)\), "=", 
          RowBox[{
            RowBox[{
              UnderoverscriptBox[
                StyleBox["\[CapitalSigma]",
                  
                  FontSize->
                    16], \(\(n = \(-\[Infinity]\)\)\+\(n \[NotEqual] \ 0\)\), 
                "\[Infinity]"], 
              " ", \(\[Phi]\_n\), \(\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \
\[Pi]\ n\ x\ /L\)\)}], "+", \(\(\[Phi]\_\(p\ o\)\)(x)\)}]}], ",", " "}], 
      TraditionalForm]]]], "NE2",
  CellTags->"(2.2.23)"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_n\)]],
  " given by Eq. ",
  ButtonBox["(2.2.19)",
    ButtonData:>"(2.2.19)",
    ButtonStyle->"Hyperlink"],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_\(p\ o\)\)(x)\)]],
  " given by Eq. ",
  ButtonBox["(2.2.22)",
    ButtonData:>"(2.2.22)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tIn order to complete the problem, we must add in the homogeneous \
solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_h\)(x)\  = \ 
        C\_1\  + \ \(\(C\_2\) \(x\)\(\ \)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " chosen to satisfy the boundary conditions as described by Eq. ",
  ButtonBox["(2.2.16)",
    ButtonData:>"(2.2.16)",
    ButtonStyle->"Hyperlink"],
  ". The result is"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi](x)\), "=", 
          
          RowBox[{\(V\_1\), "-", \(\(\[Phi]\_p\)(a)\), 
            "+", \(\([V\_2 - \(\[Phi]\_p\)(b) - 
                  V\_1 + \(\[Phi]\_p\)(a)]\) \(x - a\)\/L\), 
            StyleBox["+",
              "NE2"], 
            StyleBox[Cell[BoxData[
                  \(TraditionalForm\`\(\[Phi]\_p\)(x)\)], "NE2"],
              "NE2"]}]}], TraditionalForm]], "NE2"], "NE2"],
  StyleBox[". ", "NE2"]
}], "NE2",
  CellTags->"(2.2.24)"],

Cell[TextData[{
  "Equation (",
  ButtonBox["2.2.24",
    ButtonData:>"(2.2.24)",
    ButtonStyle->"Hyperlink"],
  ") is our solution to the boundary-value problem (",
  ButtonBox["2.2.13",
    ButtonData:>"(2.2.13)",
    ButtonStyle->"Hyperlink"],
  ").  Of course, this particular boundary-value problem is easy to solve \
using simple techniques such as direct integration. Applying Fourier methods \
to this problem is akin to using a jackhammer to crack an egg: it gets the \
job done, but the result is messier than necessary.  However, in future \
sections we will find many situations for which the powerful machinery of \
Fourier series is essential to finding the solution."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 2.2", "Subsubtitle",
  CellTags->{"Ex. 2.2", "c:18"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " If ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is continuous on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  ", under what circumstances is (a) its periodic extension continuous? (b) \
its even periodic extension continuous? (c) its odd periodic extension \
continuous?"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Use the periodic extension for the following functions on the given \
intervals to determine an exponential Fourier series. In each case plot the \
resulting series, keeping ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20\)]],
  " terms:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = \(\[ExponentialE]\^t\) sin\ 4\ t, \ 
      0 \[LessEqual] \ t \[LessEqual] \ \[Pi]/2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(x) = x\^4, \ \ \ \(-1\) \[LessEqual] \ 
        x \[LessEqual] \ 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = t\^2 - 1/2, \ \ 0 < t < 1. \)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " For each case in Exercise (2) state which type of periodic extension \
(even or odd) will improve convergence the most. Evaluate the series for the \
chosen periodic extension with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(M = 20\)\(,\)\)\)]],
  " and plot the result. "
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " The charge density between two grounded conducting plates (\[Phi] = 0 at \
",
  Cell[BoxData[
      \(TraditionalForm\`x = \ \(-L\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ L\)]],
  ") is given by ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Rho](x)\), "=", 
          RowBox[{"A", " ", 
            FormBox[\(x\^2\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ".  The electrostatic potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]/\[DifferentialD]x\^2 = \
\(-\[Rho]\)/\[Epsilon]\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " between the plates using an exponential Fourier series running from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\)\ to\ M\)]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 10\)]],
  ", plot the shape of \[Phi](x) taking A/",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\_o\)]],
  "=1 and ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Compare the approximate Fourier solution with the exact solution, found \
in any way you wish. "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  "  Exercise (4) can also be solved using the trigonometric eigenfunctions \
of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2\(\(/\)\(\[DifferentialD]x\^2\)\)\
\)]],
  " that satisfy \[Psi]=0  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]L\)\)]],
  ". These eigenfunctions are ",
  Cell[BoxData[
      \(TraditionalForm\`sin[n\ \[Pi]\ \((x - L)\)/2  L]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... \)]],
  ". Repeat Exercise (4) using these eigenfunctions."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " Exercise (4) can also be solved using the trigonometric eigenfunctions of \
the operator ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2\(\(/\)\(\[DifferentialD]x\^2\)\)\
\)]],
  " that satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\^\[Prime]\)]],
  "=0  at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(\[PlusMinus]L\)\)]],
  ". These eigenfunctions are ",
  Cell[BoxData[
      \(TraditionalForm\`cos[n\ \[Pi]\ \((x - L)\)/2  L]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3, , , \)]],
  ". Repeat  Exercise (4) using these eigenfunctions."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)(a)",
    FontWeight->"Bold"],
  " Find particular solutions to the  following boundary-value problems using \
Fourier methods."
}], "Text"],

Cell[TextData[{
  "    ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot the particular solutions."
}], "Text"],

Cell[TextData[{
  "   ",
  StyleBox[" (c)",
    FontWeight->"Bold"],
  " Find homogeneous solutions to match the boundary conditions and solve the \
full problem.  Plot the full solution."
}], "Text"],

Cell[TextData[{
  "(i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\/\[DifferentialD]x\^2 - \
\[Phi] = x\ sin\ 2  x, \[Phi](\(-\[Pi]\)) = 0, \[Phi](\[Pi]) = 0. \)]]
}], "Text"],

Cell[TextData[{
  "(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\/\[DifferentialD]x\^2 + 
          4  \[Phi] = 1/x, \(\[Phi]\^\[Prime]\)(\[Pi]) = 
        2, \[Phi](2  \[Pi]) = 0. \)]],
  " (Caution: there may be an exact resonance depending on the form of the \
Fourier series you use.)"
}], "Text",
  CellTags->"i:36"],

Cell[TextData[{
  "(iii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\/\[DifferentialD]x\^2 + 
          8 \[DifferentialD]\[Phi]\/\[DifferentialD]x + \[Phi] = 
        x\ \[ExponentialE]\^\(-x\), \(\[Phi]\^\[Prime]\)(0) = 
        0, \(\[Phi]\^\[Prime]\)(2) = 0. \)]]
}], "Text"],

Cell[TextData[{
  "(iv) ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 \[Phi]\/\[DifferentialD]x\^2 + 
          2 \[DifferentialD]\[Phi]\/\[DifferentialD]x = 
        x/\((1 + x\^2)\), \[Phi](0) = 0, \(\[Phi]\^\[Prime]\)(1) = 2. \)]]
}], "Text"],

Cell[TextData[{
  "(v) ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 \[Phi]\/\[DifferentialD]x\^3 - 
          2 \[DifferentialD]\^2 \[Phi]\/\[DifferentialD]x\^2 + \ \
\[DifferentialD]\[Phi]\/\[DifferentialD]x - 2  \[Phi] = \(x\^2\) 
          cos\ x, \[Phi](0) = 0, \(\[Phi]\^\[Prime]\)(0) = 
        2, \(\(\[Phi](3)\)\(=\)\(0\)\(\ \)\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Fourier Transforms", "Subtitle",
  CellTags->{"Sec. 2.3", "i:38", "c:19"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["2.3.1 Fourier Representation of Functions on the Real Line", \
"Subsubtitle",
  CellTags->"c:20"],

Cell[TextData[{
  "In Section ",
  ButtonBox["2.2",
    ButtonData:>"c:13",
    ButtonStyle->"Hyperlink"],
  ", we learned how to create a Fourier series representation of a general \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", defined on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ t \[LessEqual] \ b\)]],
  ". In this section, we will extend this representation to general functions \
defined on the entire real line,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < t < \[Infinity]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAs one might expect, this can be accomplished by taking a limit \
(carefully) of the previous series expressions as ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \ \(-\[Infinity]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ \[Infinity]\)]],
  ". In this limit the period ",
  Cell[BoxData[
      \(TraditionalForm\`T = b - a\)]],
  " of the function's periodic extension approaches infinity, and the \
fundamental frequency ",
  Cell[BoxData[
      FormBox[
        RowBox[{Cell["\[CapitalDelta]\[Omega]"], "=", \(2  \[Pi]/T\)}], 
        TraditionalForm]]],
  " approaches zero. "
}], "Text"],

Cell[TextData[{
  "\tIn the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] \[Rule] \ 0\)]],
  ", let us consider the expression for an exponential Fourier series of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", Eq. ",
  ButtonBox["(2.1.27)",
    ButtonData:>"(2.1.27)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        lim\+\(\[CapitalDelta]\[Omega] \[Rule] 0\)\[ThinSpace]\[Alpha]\ \
\[CapitalDelta]\[Omega]\ \(\[Sum]\+\(n = \
\(-\[Infinity]\)\)\%\[Infinity]\(\(\( 
                        c\_n\)\(\ \)\)\/\(\[Alpha]\ \[CapitalDelta]\[Omega]\)\
\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ n\ \[CapitalDelta]\[Omega]\ \
t\)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.1)"],

Cell[TextData[{
  "Here we have multiplied and divided the right-hand side by \[Alpha] \
\[CapitalDelta]\[Omega], where \[Alpha] is a constant that we will choose in \
due course. The reason for doing so is that we can then convert the sum into \
an integral. Recall that for a function ",
  Cell[BoxData[
      \(TraditionalForm\`g(\[Omega])\)]],
  ", the integral of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " can be expressed as a ",
  ButtonBox["Riemann",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Riemann.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " sum,  "
}], "Text",
  CellTags->"i:37"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
              g(\[Omega])\) \[DifferentialD]\[Omega]\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(\[CapitalDelta]\[Omega] \[Rule] 0\)\
\[ThinSpace]\ \[CapitalDelta]\[Omega]\ \(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\
\[Infinity] g(n\ \[CapitalDelta]\[Omega])\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.2)"],

Cell[TextData[{
  "Applying this result to Eq. (",
  ButtonBox["2.3.1",
    ButtonData:>"(2.3.1)",
    ButtonStyle->"Hyperlink"],
  ")  yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \[Alpha]\ \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    f\&~\)(\[Omega])\)\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\
\)\ \[Omega]\ t\)\) \[DifferentialD]\[Omega]\)\)]],
  ","
}], "NE3",
  CellTags->"(2.3.3)"],

Cell[TextData[{
  "where the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  " is defined by  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(n\ \[CapitalDelta]\[Omega]) \[Congruent] 
        c\_n/\((\[Alpha]\ \[CapitalDelta]\[Omega])\)\)]],
  ". An expression for this function can be obtained using our previous \
result for the Fourier coefficient ",
  Cell[BoxData[
      \(TraditionalForm\`c\_n\)]],
  ", Eq. ( ",
  ButtonBox["2.1.33",
    ButtonData:>"(2.1.33)",
    ButtonStyle->"Hyperlink"],
  "),  and taking the limits ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \(-\[Infinity]\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ \[Infinity]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\&~\)(
          n\ \[CapitalDelta]\[Omega])\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`lim\+\(a \[Rule] \(-\[Infinity]\)\[IndentingNewLine]
          b \[Rule] \ \[Infinity]\)\(1\/\(\[Alpha]\ \[CapitalDelta]\[Omega]\ \
T\)\) \(\[Integral]\_a\%b\( f(
                t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ n\ \[CapitalDelta]\
\[Omega]\ t\)\) \(\(\[DifferentialD]t\)\(\ \)\(.\)\)\)\)]]
}], "NE3",
  CellTags->"(2.3.4)"],

Cell[TextData[{
  "Substituting ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\  = \ 2\ \[Pi]/T\)]],
  " yields"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\&~\)(\[Omega])\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(2\)  \(\[Pi]\)\(\ \)\(\[Alpha]\)\(\ \)\)\) \
\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(
              t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.5)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.3.5)",
    ButtonData:>"(2.3.5)",
    ButtonStyle->"Hyperlink"],
  " is called a ",
  StyleBox["Fourier transform",
    FontSlant->"Italic"],
  " of the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ".  Equation ",
  ButtonBox["(2.3.3)",
    ButtonData:>"(2.3.3)",
    ButtonStyle->"Hyperlink"],
  " is called an ",
  StyleBox["inverse Fourier transform",
    FontSlant->"Italic"],
  ", because it transforms the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  " back to ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". "
}], "Text",
  CellTags->"i:39"],

Cell[TextData[{
  "\tThe Fourier transform transforms a function of time, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", to a function of frequency, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ".  This complex function of frequency, often called the ",
  StyleBox["frequency",
    FontSlant->"Italic"],
  " ",
  StyleBox["spectrum",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ",",
  " ",
  " provides the complex amplitude of each Fourier mode making up ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ".  Since ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is not periodic,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  " is nonzero for a continuous range of frequencies, as opposed to the \
discrete values of \[Omega] that enter a Fourier series. "
}], "Text",
  CellTags->"i:110"],

Cell[TextData[{
  "\t Equations ",
  ButtonBox["(2.3.3)",
    ButtonData:>"(2.3.3)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.5)",
    ButtonData:>"(2.3.5)",
    ButtonStyle->"Hyperlink"],
  " are valid of any choice of the constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] \[NotEqual] 0\)]],
  ". Different textbooks often choose different values for \[Alpha]. In the \
physical sciences, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 1/\((2\ \[Pi])\)\)]],
  " is almost a universal convention, and is the choice we will adopt in this \
book. "
}], "Text"],

Cell[TextData[{
  "\tBefore we go on to evaluate some examples of Fourier transforms, we \
should mention one other convention in the physical sciences. Recall that for \
spatial Fourier series we reversed the sign in the exponentials [see Eq. ",
  ButtonBox["(2.2.17)",
    ButtonData:>"(2.2.17)",
    ButtonStyle->"Hyperlink"],
  "]. The same is done for spatial Fourier transforms.  Also, it is \
conventional to replace the frequency argument \[Omega] of the Fourier \
transform function with the ",
  StyleBox["wavenumber",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", with units of 1/length. These differing conventions for time and space \
transforms may seem confusing at first, but we will see in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  " when we discuss wave propagation that there are good reasons for adopting \
them. Table ",
  ButtonBox["2.1",
    ButtonData:>"Table 2.1",
    ButtonStyle->"Hyperlink"],
  " provides a summary of our Fourier transform conventions:"
}], "Text",
  CellTags->"i:95"],

Cell[BoxData[
    FormBox[GridBox[{
          {Cell[TextData[StyleBox[
            "Table 2.1 Fourier Transform Conventions \n",
              FontSlant->"Italic"]], "ColumnHead"], ""},
          {GridBox[{
                {\(\(Time\)\(:\)\)},
                {Cell[TextData[Cell[BoxData[
                      FormBox[
                        RowBox[{\(\(f\&~\)(\[Omega])\), "=", 
                          
                          FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\( f(t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t\),
                            "TraditionalForm"]}], TraditionalForm]]]], 
                    "TableText"]},
                {Cell[TextData[Cell[BoxData[
                      \(TraditionalForm\`f(
                          t) = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\
\( f\&~\)(\[Omega])\)\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\
\) \[DifferentialD]\[Omega]\/\(2\ \[Pi]\)\)]]], "TableText"]},
                {""}
                },
              ColumnAlignments->{Left}], GridBox[{
                {Cell["", "TableText"]},
                {Cell["Fourier transform", "TableText"]},
                {Cell["Inverse Fourier transform", "TableText"]},
                {""}
                },
              ColumnAlignments->{Left}]},
          {\(\(Space\)\(:\)\), ""},
          {Cell[TextData[Cell[BoxData[
                FormBox[
                  RowBox[{\(\(f\&~\)(k)\), "=", 
                    
                    FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(
                            x)\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ \
x\)\) \[DifferentialD]x\),
                      "TraditionalForm"]}], 
                  TraditionalForm]]]]], \(Fourier\ transform\)},
          {Cell[TextData[Cell[BoxData[
                \(TraditionalForm\`f(
                    x) = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                            f\&~\)(
                        k)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\) \
\[DifferentialD]k\/\(2\ \[Pi]\)\)]]]], \(Inverse\ Fourier\ transform\)}
          },
        ColumnAlignments->{Left}], NullForm]], "Table",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->{"i:40", "Table 2.1"}],

Cell["", "Text"],

Cell[TextData[{
  "To obtain a Fourier transform of a given function, we must  evaluate the \
integral given in Table ",
  ButtonBox["2.1",
    ButtonData:>"Table 2.1",
    ButtonStyle->"Hyperlink"],
  ".  For many functions, this integration can be performed analytically. For \
example, consider the Fourier transform of"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(t)\), " ", "=", " ", 
          RowBox[{"1", "/", 
            RowBox[{"(", 
              RowBox[{"1", "+", 
                RowBox[{
                  FormBox[\(s\^2\),
                    "TraditionalForm"], 
                  FormBox[\(t\^2\),
                    "TraditionalForm"]}]}], ")"}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.6)"],

Cell[TextData[{
  "Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to perform the integration,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Integrate[
      Exp[I\ \[Omega]\ t]\ 1/\((1\  + \ s^2\ t\ ^2)\), {t, \(-Infinity\), 
        Infinity}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.39"],

Cell[BoxData[
    RowBox[{"If", "[", 
      RowBox[{\(Im[\[Omega]] == 0 && Arg[s\^2] \[NotEqual] \[Pi]\), 
        ",", \(\(\[ExponentialE]\^\(-\(\(\[Omega]\ Sign[\[Omega]]\)\/\@s\^2\)\
\)\ \[Pi]\)\/\@s\^2\), ",", 
        RowBox[{
          SubsuperscriptBox["\[Integral]", 
            InterpretationBox[\(-\[Infinity]\),
              DirectedInfinity[ -1]], 
            InterpretationBox["\[Infinity]",
              DirectedInfinity[ 
              1]]], \(\(\[ExponentialE]\^\(\[ImaginaryI]\ t\ \[Omega]\)\/\(1 \
+ s\^2\ t\^2\)\) \[DifferentialD]t\)}]}], "]"}]], "Output"]
}, Open  ]],

Cell["\<\
and noting that both inequalities in the output cell are satisfied, \
we obtain\
\>", "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega]) = \[Pi]\ \(\(\[ExponentialE]\^\(-\
\(\(|\)\(\[Omega]/s\)\(|\)\)\)\)\(/\)\) | s | \)]],
  ". "
}], "Text"],

Cell[TextData[{
  " By taking the inverse transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ", we should return to ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " as given by Eq. ",
  ButtonBox["(2.3.6)",
    ButtonData:>"(2.3.6)",
    ButtonStyle->"Hyperlink"],
  ". However, because of the absolute value in ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ", it is best to break the integral up into two pieces, ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Omega] < \[Infinity]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < \[Omega] < 0\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Integrate[
            Exp[\(-I\)\ \[Omega]\ t]\ \[Pi]\ Exp[\(-\[Omega]\)/s]/
                s, {\[Omega], 0, Infinity}]/\((2\ Pi)\)\  + 
        Integrate[
            Exp[\(-I\)\ \[Omega]\ t]\ \[Pi]\ Exp[\[Omega]/s]/
                s, {\[Omega], \(-Infinity\), 0}]/\((2\ Pi)\), 
      s > 0\  && Im[t] \[Equal] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.40"],

Cell[BoxData[
    \(1\/\(1 + s\^2\ t\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "As expected, the inverse transformation returns us to Eq. ",
  ButtonBox["(2.3.6",
    ButtonData:>"(2.3.6)",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["\tMathematica",
    FontSlant->"Italic"],
  " has two intrinsic functions, ",
  StyleBox["FourierTransform",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InverseFourierTransform",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". These two functions perform the integrationss needed for the transform \
and the inverse transform. However, the conventions adopted by these \
functions differ from those listed in Table ",
  ButtonBox["2.1",
    ButtonData:>"Table 2.1",
    ButtonStyle->"Hyperlink"],
  ": the value of \[Alpha] chosen in Eqs. ",
  ButtonBox["(2.3.3)",
    ButtonData:>"(2.3.3)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.5)",
    ButtonData:>"(2.3.5)",
    ButtonStyle->"Hyperlink"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/\@\(2\ \[Pi]\)\)]],
  ", and the transform functions use the time convention, not the space \
convention. To obtain our result for a time transform,  the following syntax \
must be employed:"
}], "Text",
  CellTags->"i:42"],

Cell[TextData[{
  "\t",
  StyleBox["Sqrt[2Pi] FourierTransform[f[t],t,\[Omega]]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["For example,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Sqrt[\ 2\ Pi] 
        FourierTransform[1/\((1 + s^2\ t^2)\), t, \[Omega]]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.41"],

Cell[BoxData[
    \(\(\[ExponentialE]\^\(-\(\(\[Omega]\ Sign[\[Omega]]\)\/\@s\^2\)\)\ \[Pi]\
\)\/\@s\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For the inverse transform, we must divide ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s function by ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(2\ \[Pi]\)\)]],
  " . The notation is"
}], "Text"],

Cell[TextData[{
  StyleBox["\tInverseFourierTransform[f[\[Omega]],\[Omega],t]/Sqrt[2 Pi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell["\<\
For our example problem, we obtain the correct result by applying \
this function:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseFourierTransform[\[Pi]\ Exp[\(-Abs[\[Omega]]\)/s]/s, \[Omega], 
        t]/Sqrt[2\ Pi]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.42"],

Cell[BoxData[
    \(1\/\(1 + s\^2\ t\^2\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "For spatial Fourier transforms, we must reverse the sign of the transform \
variable to match the sign convention for spatial transforms used in Table ",
  ButtonBox["2.1",
    ButtonData:>"Table 2.1",
    ButtonStyle->"Hyperlink"],
  ". The following table summarizes the proper usage of the intrinsic ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions so as to match our conventions."
}], "Text"],

Cell[BoxData[
    FormBox[GridBox[{
          {GridBox[{
                {Cell["Time:", "TableText"]},
                {""},
                {""},
                {Cell["Space:", "TableText"]}
                }], GridBox[{
                {""},
                {Cell[TextData[{
                    Cell[BoxData[
                        \(TraditionalForm\`\@\(2\ \[Pi]\)\)],
                      FontFamily->"Courier"],
                    StyleBox[" FourierTransform[f[t],t,\[Omega]]",
                      FontFamily->"Courier"]
                  }], "TableText"]},
                {Cell[TextData[{
                    StyleBox[
                    "InverseFourierTransform[f[\[Omega]],\[Omega],t] /",
                      FontFamily->"Courier"],
                    Cell[BoxData[
                        \(TraditionalForm\`\@\(2\ \[Pi]\)\)],
                      FontFamily->"Courier"]
                  }], "TableText"]},
                {Cell["", "TableText"]}
                },
              ColumnAlignments->{Left}]},
          {"", 
            
            StyleBox[\(\(\@\(2\ \[Pi]\)\) FourierTransform[f[x], x, \(-k\)]\),
              
              FontFamily->"Courier"]},
          {"", 
            StyleBox[
              RowBox[{\(InverseFourierTransform[f[k], k, \(-x\)]\), "/", 
                FormBox[\(\@\(2\ \[Pi]\)\),
                  "TraditionalForm"]}],
              FontFamily->"Courier"]}
          },
        ColumnAlignments->{Left}], NullForm]], "Table",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:41"],

Cell["\<\
In following sections we will deal with time Fourier transforms \
unless otherwise indicated.  \
\>", "Text"],

Cell[TextData[{
  "\tFourier transforms have many important applications. One is in signal \
processing. For example, a digital bit may look like a square pulse, as shown \
in Cell ",
  ButtonBox["2.43",
    ButtonData:>"Cell 2.43",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(f[t_]\  = \ UnitStep[t - 1] UnitStep[2 - t];\)\), "\n", 
    \(\(Plot[f[t], {t, 0, 3}, PlotStyle \[Rule] Thickness[0.008], 
        AxesLabel \[Rule] {"\<t\>", "\<f(t)\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.43"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.588604 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.02381 .64303 -14 0 ]
[.02381 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.26171 .01472 L
.28158 .01472 L
.30316 .01472 L
.31323 .01472 L
.32392 .01472 L
.33304 .01472 L
.33554 .01472 L
.33823 .01472 L
.33953 .01472 L
.34076 .01472 L
.34187 .60332 L
.34309 .60332 L
.38373 .60332 L
.42286 .60332 L
.46444 .60332 L
.50451 .60332 L
.54306 .60332 L
.58406 .60332 L
.60448 .60332 L
.62355 .60332 L
.64188 .60332 L
.64715 .60332 L
.65215 .60332 L
.65433 .60332 L
.65664 .60332 L
.65785 .60332 L
.65853 .60332 L
.65918 .01472 L
.66031 .01472 L
.66152 .01472 L
.70266 .01472 L
.74229 .01472 L
.78039 .01472 L
.82096 .01472 L
.86 .01472 L
.9015 .01472 L
.94148 .01472 L
.97619 .01472 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00F7oo0P001goo0`001Goo1000;Goo1@00;7oo1@001Goo0`001Goo1000;7oo1P00
:goo1P001Goo0`001Goo1000;Goo1000:Woo001GOol01000Oomoo`001Woo0`0017oo00<007ooOol0
0Woo00<007ooOol0;7oo00<007ooOol0;Woo00<007ooOol01Goo0`0017oo00<007ooOol00Woo00<0
07ooOol0:Woo00D007ooOomoo`0002aoo`05001oogooOol00005Ool30004Ool00`00Oomoo`02Ool0
0`00Oomoo`0YOol00`00Oomoo`02Ool00`00Oomoo`0WOol005Ioo`03001oogoo009oo`03001oogoo
00=oo`<000Uoo`03001oogoo02aoo`03001oogoo02ioo`03001oogoo00Eoo`<000Uoo`03001oogoo
02]oo`03001oogoo02ioo`03001oogoo00Ioo`<000Uoo`03001oogoo02ioo`03001oogoo02Moo`00
EWoo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0;7oo00<007ooOol0;Woo00<007ooOol0
4Goo00<007ooOol0;7oo00<007ooOol0;Woo00<007ooOol04Goo00<007ooOol0;Woo00<007ooOol0
9goo001FOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0/Ool00`00
Oomoo`0^Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0]Ool00`00Oomoo`0^Ool00`00
Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0[Ool3000ZOol005Ioo`03001oogoo009oo`03001o
ogoo00Yoo`D002moo`03001oogoo02ioo`03001oogoo00aoo`D0035oo`03001oogoo02ioo`03001o
ogoo00Yoo`D0035oo`03001oogoo02Moo`00EWoo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool0<Goo00<007ooOol0;Woo00<007ooOol037oo00<007ooOol0<goo00<007ooOol0;Woo00<007oo
Ool02Woo00<007ooOol0<goo00<007ooOol09goo001GOol01000Oomoo`003Goo00<007ooOol0;goo
0`00;Woo0`003Woo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol0:Goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol0;Woo00<007ooOol00Woo00<007ooOol09goo001HOol2000>Ool5
000^Ool2000_Ool2000>Ool5000]Ool4000]Ool4000=Ool5000]Ool4000ZOol002Qoo`03001oogoo
0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOombOol4000@Ool002Qoo`03
001oogoo0?moog5oo`03001oogoo009oo`03001oogoo00eoo`00:7oo00<007ooOol0ogooLGoo00<0
07ooOol04Woo000XOol00`00Oomoo`3oOomaOol00`00Oomoo`0BOol001moool0070000eoo`03001o
ogoo019oo`009gooMP002goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027ooMP005Goo00<007ooOol04Woo000XOol00`00Oomoo`0gOol00`00Oomoo`0fOol2000iOol0
0`00Oomoo`0gOol2000hOol00`00Oomoo`0hOol00`00Oomoo`0AOol7000@Ool002Qoo`03001oogoo
071oo`8007=oo`8008Uoo`03001oogoo019oo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00RGoo00<0
07ooOol04Woo000XOol00`00Oomoo`1`Ool2001cOol20029Ool00`00Oomoo`0BOol002Qoo`03001o
ogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomo
o`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo0`00L7oo0P00
Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=o
o`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2
002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00
WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009io
o`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol0
02Qoo`<0071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00
Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007oo
Ool0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo
071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`
Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo
0P00Lgoo0P00WWoo000XOol3001`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`80
09ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002N
Ool002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo
000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00
37oo0P001goo0`0017oo1P001Woo00<007ooOol0L7oo0P00Lgoo0P00WWoo000;Ool01000Oomoo`00
1Woo0`001Goo00D007ooOomoo`0000Ioo`03001oogoo071oo`8007=oo`8009ioo`002Woo00<007oo
Ool00Woo00<007ooOol00goo0`001Woo00<007ooOol01goo00<007ooOol0L7oo0P00Lgoo0P00WWoo
000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`06Ool3001`Ool2001cOol2002NOol0
00Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo071oo`8007=oo`80
09ioo`002Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0L7oo0P00
Lgoo0P00WWoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`1`
Ool2001cOol2002NOol000]oo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`1`Ool2001cOol2002NOol000aoo`8000moo`@000Moo`03001oogoo071oo`8007=oo`8009io
o`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol0
02Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000X
Ool00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`<0071oo`8007=oo`8009ioo`00:7oo00<007oo
Ool0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo
071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`
Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo
0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`80
07=oo`8009ioo`00:7oo0`00L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002N
Ool002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo
000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00
:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qo
o`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol0
0`00Oomoo`1`Ool2001cOol2002NOol002Qoo`<0071oo`8007=oo`8009ioo`00:7oo00<007ooOol0
L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071o
o`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2
001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00
Lgoo0P00WWoo000<Ool20007Ool30007Ool30006Ool00`00Oomoo`1`Ool2001cOol2002NOol000]o
o`04001oogoo0006Ool30008Ool00`00Oomoo`05Ool00`00Oomoo`1`Ool2001cOol2002NOol000Yo
o`03001oogoo009oo`03001oogoo00=oo`<000Aoo`H000Ioo`03001oogoo071oo`8007=oo`8009io
o`002Woo00<007ooOol00Woo00<007ooOol02Woo00D007ooOomoo`0000Moo`<0071oo`8007=oo`80
09ioo`002Woo00<007ooOol00Woo00<007ooOol02goo00@007ooOol000Moo`03001oogoo071oo`80
07=oo`8009ioo`002Woo00<007ooOol00Woo00<007ooOol037oo00<007oo00001goo00<007ooOol0
L7oo0P00Lgoo0P00WWoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Ool00007Ool00`00
Oomoo`1`Ool2001cOol2002NOol000]oo`04001oogoo000@Ool20007Ool00`00Oomoo`1`Ool2001c
Ool2002NOol000aoo`80019oo`03001oogoo00Eoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo
00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03
001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00
Oomoo`1`Ool2001cOol2002NOol002Qoo`<0071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo
0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`80
07=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool2001c
Ool2002NOol002Qoo`03001oogoo071oo`8007=oo`8009ioo`00:7oo00<007ooOol0L7oo0P00Lgoo
0P00WWoo000XOol00`00Oomoo`1`Ool2001cOol2002NOol002Qoo`03001oogoo071oo`8007=oo`80
09ioo`00:7oo0`00L7oo0P00Lgoo0P00WWoo000XOol00`00Oomoo`1`Ool3001aOol3002NOol002Qo
o`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol0
0`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<0
07ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001o
ogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomo
o`1aOol2001aOol2002OOol002Qoo`<0075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00
LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075o
o`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2
002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00
Wgoo000<Ool20007Ool30005Ool40007Ool00`00Oomoo`1aOol2001aOol2002OOol000]oo`04001o
ogoo0006Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1aOol2001aOol2002O
Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`<000Aoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo075oo`80075oo`8009moo`002Woo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool00Woo00<007ooOol017oo0`00LGoo0P00LGoo0P00Wgoo000:Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`1aOol2001aOol2002OOol000Yoo`03001oogoo
009oo`03001oogoo00Yoo`03001oo`00008000Moo`03001oogoo075oo`80075oo`8009moo`002Woo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol027oo00<007ooOol0LGoo0P00LGoo0P00Wgoo
000;Ool01000Oomoo`003Woo0P002Goo00<007ooOol0LGoo0P00LGoo0P00Wgoo000<Ool2000AOol3
0006Ool00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00
:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qo
o`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol3
001aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0
LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075o
o`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2
001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00
LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`<0075oo`80075oo`8009mo
o`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol0
02Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000X
Ool00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo
00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03
001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol3001a
Ool2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo
0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80
075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001a
Ool2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`0037oo0P001goo0`001Goo10001goo
00<007ooOol0LGoo0P00LGoo0P00Wgoo000;Ool01000Oomoo`001Woo0`0017oo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000:Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`1aOol2001aOol2002OOol0
00Yoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Aoo`<0075oo`80
075oo`8009moo`002Woo00<007ooOol00Woo00<007ooOol02goo10001goo00<007ooOol0LGoo0P00
LGoo0P00Wgoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`1aOol2001aOol2002OOol000Yoo`03001oogoo009oo`03001oogoo00Yoo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo075oo`80075oo`8009moo`002goo00@007ooOol000eo
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo075oo`80075oo`8009moo`0037oo0P003goo
10001goo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol0
02Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000X
Ool00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo
0`00LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo
075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1a
Ool2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo
0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80
075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol3001aOol2001aOol2002O
Ool002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo
000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00
:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qo
o`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol0
0`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo0`00
LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol002Qoo`03001oogoo075o
o`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2
001aOol2002OOol002Qoo`03001oogoo075oo`80075oo`8009moo`00:7oo00<007ooOol0LGoo0P00
LGoo0P00Wgoo000XOol00`00Oomoo`1aOol2001aOol2002OOol001eoo`D000Ioo`03001oogoo075o
o`80075oo`8009moo`007goo00<007ooOol01Woo00<007ooOol0LGoo0P00LGoo0P00Wgoo000OOol0
0`00Oomoo`06Ool00`00Oomoo`1aOol2001aOol2002OOol001moo`03001oogoo00Ioo`<0075oogD0
09moo`007goo00<007ooOol01Woo00<007ooOol0LGooM@00Wgoo000OOol00`00Oomoo`06Ool00`00
Oomoo`3oOon6Ool001moo`03001oogoo00Ioo`03001oogoo0?moohIoo`007Goo0`0027oo00<007oo
Ool0ogooQWoo000NOol20008Ool00`00Oomoo`3oOon6Ool00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo000UOol00`00Oomoo`0;Ool00`00Oomoo`3oOomkOol002Aoo`03001oogoo00eoo`03001oogoo
0?moogYoo`0097oo00<007ooOol03Goo00<007ooOol0ogooNWoo000GOol60006Ool00`00Oomoo`05
Ool40006Ool00`00Oomoo`3oOomiOol001Uoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo0?moogUoo`006Goo00<007ooOol01goo00<007ooOol017oo
00<007ooOol027oo00<007ooOol0ogooNGoo000IOol00`00Oomoo`07Ool00`00Oomoo`04Ool00`00
Oomoo`08Ool00`00Oomoo`3oOomiOol001Uoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo
00Qoo`03001oogoo0?moogUoo`006Goo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo
00<007ooOol0ogooNGoo000GOol60007Ool01000Oomoogoo1`001Goo00<007ooOol0ogooNWoo000I
Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`3oOomjOol001Uoo`03
001oogoo00Uoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0?moog]oo`006Woo0`003Goo
00<007ooOol0ogooQ7oo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["This signal has the following Fourier transform:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(f\&~[\[Omega]_]\  = \ 
      Integrate[Exp[I\ \[Omega]\ t], {t, 1, 2}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.44"],

Cell[BoxData[
    \(\(\[ImaginaryI]\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\)\)\/\
\[Omega] - \(\[ImaginaryI]\ \[ExponentialE]\^\(2\ \[ImaginaryI]\ \[Omega]\)\)\
\/\[Omega]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This Fourier transform has both real and imaginary parts, as shown in Cell \
",
  ButtonBox["2.45",
    ButtonData:>"Cell 2.45",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[Re[f\&~[\[Omega]]], {\[Omega], \(-50\), 50}, 
        AxesLabel \[Rule] {"\<\[Omega]\>", \
\*"\"\<Re[\!\(f\&~\)(\[Omega])]\>\""}, PlotRange \[Rule] All];\)\), "\n", 
    \(\(Plot[Im[f\&~[\[Omega]]], {\[Omega], \(-50\), 50}, 
        AxesLabel \[Rule] {"\<\[Omega]\>", \
\*"\"\<Im[\!\(f\&~\)(\[Omega])]\>\""}, PlotRange \[Rule] All];\)\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 2.45"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.282514 0.321633 [
[.11905 .27001 -9 -9 ]
[.11905 .27001 9 0 ]
[.30952 .27001 -9 -9 ]
[.30952 .27001 9 0 ]
[.69048 .27001 -6 -9 ]
[.69048 .27001 6 0 ]
[.88095 .27001 -6 -9 ]
[.88095 .27001 6 0 ]
[1.025 .28251 0 -6 ]
[1.025 .28251 10 6 ]
[.4875 .04129 -30 -4.5 ]
[.4875 .04129 0 4.5 ]
[.4875 .1217 -24 -4.5 ]
[.4875 .1217 0 4.5 ]
[.4875 .20211 -30 -4.5 ]
[.4875 .20211 0 4.5 ]
[.4875 .36292 -24 -4.5 ]
[.4875 .36292 0 4.5 ]
[.4875 .44333 -18 -4.5 ]
[.4875 .44333 0 4.5 ]
[.4875 .52374 -24 -4.5 ]
[.4875 .52374 0 4.5 ]
[.4875 .60415 -6 -4.5 ]
[.4875 .60415 0 4.5 ]
[.5 .64303 -26 0 ]
[.5 .64303 26 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .28251 m
.11905 .28876 L
s
[(-40)] .11905 .27001 0 1 Mshowa
.30952 .28251 m
.30952 .28876 L
s
[(-20)] .30952 .27001 0 1 Mshowa
.69048 .28251 m
.69048 .28876 L
s
[(20)] .69048 .27001 0 1 Mshowa
.88095 .28251 m
.88095 .28876 L
s
[(40)] .88095 .27001 0 1 Mshowa
.125 Mabswid
.16667 .28251 m
.16667 .28626 L
s
.21429 .28251 m
.21429 .28626 L
s
.2619 .28251 m
.2619 .28626 L
s
.35714 .28251 m
.35714 .28626 L
s
.40476 .28251 m
.40476 .28626 L
s
.45238 .28251 m
.45238 .28626 L
s
.54762 .28251 m
.54762 .28626 L
s
.59524 .28251 m
.59524 .28626 L
s
.64286 .28251 m
.64286 .28626 L
s
.7381 .28251 m
.7381 .28626 L
s
.78571 .28251 m
.78571 .28626 L
s
.83333 .28251 m
.83333 .28626 L
s
.07143 .28251 m
.07143 .28626 L
s
.02381 .28251 m
.02381 .28626 L
s
.92857 .28251 m
.92857 .28626 L
s
.97619 .28251 m
.97619 .28626 L
s
.25 Mabswid
0 .28251 m
1 .28251 L
s
gsave
1.025 .28251 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .04129 m
.50625 .04129 L
s
[(-0.75)] .4875 .04129 1 0 Mshowa
.5 .1217 m
.50625 .1217 L
s
[(-0.5)] .4875 .1217 1 0 Mshowa
.5 .20211 m
.50625 .20211 L
s
[(-0.25)] .4875 .20211 1 0 Mshowa
.5 .36292 m
.50625 .36292 L
s
[(0.25)] .4875 .36292 1 0 Mshowa
.5 .44333 m
.50625 .44333 L
s
[(0.5)] .4875 .44333 1 0 Mshowa
.5 .52374 m
.50625 .52374 L
s
[(0.75)] .4875 .52374 1 0 Mshowa
.5 .60415 m
.50625 .60415 L
s
[(1)] .4875 .60415 1 0 Mshowa
.125 Mabswid
.5 .05737 m
.50375 .05737 L
s
.5 .07345 m
.50375 .07345 L
s
.5 .08953 m
.50375 .08953 L
s
.5 .10562 m
.50375 .10562 L
s
.5 .13778 m
.50375 .13778 L
s
.5 .15386 m
.50375 .15386 L
s
.5 .16994 m
.50375 .16994 L
s
.5 .18602 m
.50375 .18602 L
s
.5 .21819 m
.50375 .21819 L
s
.5 .23427 m
.50375 .23427 L
s
.5 .25035 m
.50375 .25035 L
s
.5 .26643 m
.50375 .26643 L
s
.5 .2986 m
.50375 .2986 L
s
.5 .31468 m
.50375 .31468 L
s
.5 .33076 m
.50375 .33076 L
s
.5 .34684 m
.50375 .34684 L
s
.5 .379 m
.50375 .379 L
s
.5 .39508 m
.50375 .39508 L
s
.5 .41117 m
.50375 .41117 L
s
.5 .42725 m
.50375 .42725 L
s
.5 .45941 m
.50375 .45941 L
s
.5 .47549 m
.50375 .47549 L
s
.5 .49157 m
.50375 .49157 L
s
.5 .50766 m
.50375 .50766 L
s
.5 .53982 m
.50375 .53982 L
s
.5 .5559 m
.50375 .5559 L
s
.5 .57198 m
.50375 .57198 L
s
.5 .58806 m
.50375 .58806 L
s
.5 .02521 m
.50375 .02521 L
s
.5 .00913 m
.50375 .00913 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.875 moveto
(@) show
81.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 7.875 moveto
(\\216) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.875 moveto
(H) show
93.000 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.875 moveto
(L) show
105.000 13.875 moveto
(D) show
111.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .28094 m
.02499 .28043 L
.02605 .28017 L
.02729 .28016 L
.02846 .28047 L
.02954 .28105 L
.03053 .28182 L
.03279 .28429 L
.03746 .29076 L
.03875 .29226 L
.03945 .29294 L
.04012 .29348 L
.04143 .29415 L
.04262 .29428 L
.04377 .29395 L
.045 .29308 L
.04617 .2918 L
.04722 .29028 L
.05224 .28028 L
.05477 .27532 L
.05619 .27309 L
.0575 .27156 L
.05864 .27069 L
.0599 .27027 L
.06122 .27044 L
.06244 .27111 L
.06787 .27802 L
.07073 .28202 L
.07217 .28355 L
.07299 .28421 L
.07376 .28468 L
.07444 .28497 L
.07516 .28514 L
.07644 .28512 L
.07716 .28494 L
.07782 .28468 L
.07855 .28431 L
.07933 .28383 L
.08201 .28183 L
.08319 .281 L
.08448 .28028 L
.08575 .27986 L
.08644 .27978 L
.08708 .27982 L
.08779 .27998 L
.08844 .28025 L
.08919 .2807 L
.0899 .28127 L
.09117 .2826 L
.09235 .28415 L
Mistroke
.09501 .28835 L
.0974 .29213 L
.09857 .2937 L
.09965 .29484 L
.10089 .29573 L
.10155 .29598 L
.10224 .29607 L
.10335 .29581 L
.10458 .29495 L
.10583 .29346 L
.1072 .29121 L
.10967 .28587 L
.1143 .27482 L
.11566 .27222 L
.11693 .27032 L
.11757 .26959 L
.11825 .26899 L
.11902 .26854 L
.11972 .26835 L
.12088 .26847 L
.12215 .2692 L
.1228 .26979 L
.12348 .27055 L
.12472 .27225 L
.12715 .27632 L
.12978 .28078 L
.13099 .28252 L
.13227 .28398 L
.13336 .28488 L
.13456 .28546 L
.13572 .28561 L
.13678 .28542 L
.13801 .28485 L
.13917 .28404 L
.14125 .28226 L
.14234 .2813 L
.14349 .28042 L
.14472 .27971 L
.14585 .27936 L
.14691 .27936 L
.14807 .27975 L
.14933 .28066 L
.15004 .28139 L
.15069 .28218 L
.15313 .28608 L
.15551 .29064 L
.15804 .29511 L
.15936 .29687 L
.16011 .29761 L
.16081 .29811 L
Mistroke
.16205 .29847 L
.16274 .29836 L
.16337 .29807 L
.16458 .29698 L
.16569 .29538 L
.16692 .29302 L
.16823 .28993 L
.17284 .27685 L
.174 .27376 L
.17526 .27083 L
.17636 .26871 L
.17753 .26705 L
.17859 .2661 L
.17975 .26568 L
.1808 .26587 L
.18179 .26651 L
.20044 .2829 L
.20288 .28039 L
.20355 .27982 L
.20425 .27932 L
.20551 .27876 L
.20669 .2787 L
.20778 .2791 L
.20899 .28008 L
.21027 .28172 L
.21161 .28401 L
.21287 .28662 L
.21524 .29207 L
.21662 .29522 L
.21809 .29816 L
.21934 .30012 L
.22005 .30094 L
.22071 .30149 L
.2214 .30182 L
.22205 .3019 L
.22327 .30139 L
.22458 .29988 L
.22533 .2986 L
.22601 .29715 L
.2288 .28922 L
.23176 .27881 L
.23309 .27422 L
.23452 .26977 L
.23578 .2665 L
.23647 .26504 L
.23712 .26391 L
.23832 .26243 L
.23965 .2618 L
.24077 .2621 L
.24197 .26319 L
Mistroke
.2621 .2806 L
.26333 .2792 L
.26401 .27858 L
.26465 .27812 L
.2659 .27769 L
.26705 .27789 L
.26825 .27877 L
.26955 .28052 L
.27024 .28176 L
.27098 .28331 L
.2723 .28658 L
.27533 .29536 L
.27664 .29913 L
.27807 .30269 L
.27876 .30414 L
.2795 .3054 L
.28081 .30686 L
.28204 .3072 L
.28274 .3069 L
.28339 .30629 L
.28464 .30426 L
.28535 .30263 L
.286 .30081 L
.28847 .29181 L
.29311 .27105 L
.29551 .26216 L
.29617 .26029 L
.29688 .2586 L
.29816 .25648 L
.29881 .25589 L
.29952 .25562 L
.30027 .25576 L
.30096 .25627 L
.3022 .25802 L
.3029 .25942 L
.30353 .26093 L
.30837 .27625 L
.30965 .28018 L
.31102 .28377 L
.31232 .28633 L
.3135 .28786 L
.31458 .28854 L
.31575 .28852 L
.31686 .28784 L
.31788 .28671 L
.31911 .28489 L
.32022 .28298 L
.3227 .27873 L
.32401 .27707 L
.32467 .27649 L
Mistroke
.32539 .27611 L
.32666 .27618 L
.32785 .27716 L
.32858 .27822 L
.32926 .27953 L
.33054 .28276 L
.33342 .29291 L
.33576 .30241 L
.33704 .30726 L
.33825 .31116 L
.33955 .31435 L
.34023 .31551 L
.34098 .31629 L
.34229 .31638 L
.3435 .31492 L
.34469 .31201 L
.34595 .30744 L
.34734 .30088 L
.34862 .29369 L
.35344 .26349 L
.35472 .25666 L
.35609 .25073 L
.35688 .24812 L
.3576 .24629 L
.35832 .24501 L
.35901 .24433 L
.36026 .24442 L
.36142 .24601 L
.3627 .24924 L
.36406 .25409 L
.36842 .27438 L
.37071 .28384 L
.37187 .28738 L
.37313 .29007 L
.37381 .29095 L
.37453 .29146 L
.37583 .29127 L
.37712 .28981 L
.3783 .28757 L
.38062 .28172 L
.38193 .27827 L
.38316 .27549 L
.38431 .27361 L
.38554 .27266 L
.38685 .27312 L
.38805 .27504 L
.38916 .27812 L
.39037 .28284 L
.39257 .2945 L
.39511 .31068 L
Mistroke
.39751 .32506 L
.39884 .33127 L
.39958 .33392 L
.40027 .33572 L
.40149 .33722 L
.40277 .33626 L
.40392 .3331 L
.40514 .32731 L
.4063 .31971 L
.40736 .31119 L
.41239 .25946 L
.41458 .23837 L
.41574 .22941 L
.41697 .22213 L
.41804 .21792 L
.41922 .21577 L
.4203 .21613 L
.42131 .21841 L
.42641 .25165 L
.42889 .27276 L
.42997 .28101 L
.43115 .28861 L
.43238 .29468 L
.43354 .29833 L
.43418 .29943 L
.43487 .29986 L
.43609 .2988 L
.43673 .29738 L
.43742 .29526 L
.43867 .29012 L
.4415 .27532 L
.44265 .26965 L
.44387 .26489 L
.44458 .26301 L
.44522 .262 L
.44646 .26219 L
.44763 .26533 L
.44889 .27218 L
.45008 .28197 L
.45117 .29366 L
.45579 .36142 L
.45781 .39115 L
.45888 .40414 L
.46001 .41474 L
.46127 .42169 L
.46243 .42267 L
.46352 .41829 L
.46472 .40718 L
.46598 .38844 L
.46733 .36045 L
Mistroke
.46977 .29239 L
.47412 .14496 L
.47642 .07607 L
.47771 .04653 L
.47887 .02736 L
.47958 .01976 L
.48035 .01526 L
.48107 .01475 L
.48174 .01757 L
.48304 .03218 L
.48369 .04404 L
.48441 .06045 L
.48572 .09905 L
.48713 .15124 L
.48967 .26529 L
.49214 .38462 L
.49446 .48638 L
.49572 .53175 L
.49688 .56482 L
.49817 .59034 L
.49884 .59861 L
.49955 .60332 L
.50086 .60111 L
.50207 .58657 L
.50277 .573 L
.5034 .55754 L
.50483 .51303 L
.50734 .40889 L
.50971 .2951 L
.51229 .17555 L
.5137 .11937 L
.51502 .07604 L
.51576 .05626 L
.51644 .04138 L
.5172 .02861 L
.51801 .01942 L
.51869 .01538 L
.51943 .01472 L
.52013 .01758 L
.52077 .02317 L
.52204 .04168 L
.52275 .05611 L
.52341 .07162 L
.52588 .14512 L
.53051 .30124 L
.53292 .36617 L
.53358 .38012 L
.53429 .39297 L
.53556 .41039 L
.53625 .41666 L
Mistroke
.53699 .42101 L
.5377 .42284 L
.53835 .42263 L
.53958 .41764 L
.54089 .40663 L
.54546 .34156 L
.54795 .30465 L
.54917 .28977 L
.55027 .27876 L
.55149 .26973 L
.55279 .26385 L
.55347 .26229 L
.55421 .26171 L
.55491 .26214 L
.55555 .26329 L
.55667 .26678 L
.5579 .27224 L
.56038 .28538 L
.5616 .29136 L
.56276 .29588 L
.5638 .29861 L
.56494 .29984 L
.56617 .29891 L
.56748 .29525 L
.56871 .28941 L
.56983 .28239 L
.57405 .24778 L
.57628 .23056 L
.57753 .22319 L
.57867 .21848 L
.57997 .21583 L
.5812 .21624 L
.58234 .21916 L
.58357 .22499 L
.58487 .2339 L
.58625 .24587 L
.58873 .2714 L
.59085 .29401 L
.59313 .31528 L
.59443 .32477 L
.59563 .33125 L
.59683 .33542 L
.59797 .33715 L
.59928 .33653 L
.60047 .33375 L
.60113 .3314 L
.60185 .3283 L
.60314 .32148 L
.60794 .29155 L
.60936 .28409 L
Mistroke
.61069 .27863 L
.61136 .27652 L
.61208 .27476 L
.61287 .27343 L
.6136 .27277 L
.61488 .27284 L
.61561 .2735 L
.61628 .27446 L
.61751 .27692 L
.61881 .28019 L
.62119 .28641 L
.62239 .28898 L
.6237 .29088 L
.62482 .29154 L
.62602 .29111 L
.62715 .28958 L
.62818 .28725 L
.62948 .28316 L
.63067 .27842 L
.63338 .26577 L
.63591 .25423 L
.63715 .24972 L
.63828 .24663 L
.63933 .24483 L
.64032 .24416 L
.64137 .24463 L
.64251 .24652 L
.64368 .2499 L
.64492 .25496 L
.64716 .26703 L
.65173 .29574 L
.65404 .3074 L
.65534 .31211 L
.65656 .31502 L
.65726 .31601 L
.65792 .31648 L
.65915 .31619 L
.65985 .3154 L
.66049 .31429 L
.66119 .3127 L
.66193 .31063 L
.66687 .29178 L
.66942 .28288 L
.67012 .28098 L
.67085 .27929 L
.67217 .27714 L
.67291 .27642 L
.67361 .27608 L
.67437 .27605 L
.67518 .27639 L
Mistroke
.67594 .27702 L
.67666 .27785 L
.67801 .27986 L
.68046 .28417 L
.6818 .28628 L
.68305 .28775 L
.68412 .28847 L
.68527 .28858 L
.68654 .28782 L
.6877 .2863 L
.68835 .28512 L
.68904 .28363 L
.69028 .28039 L
.69308 .27141 L
.69557 .2634 L
.69693 .25983 L
.69819 .25736 L
.69931 .25603 L
.70052 .25562 L
.7012 .2559 L
.70185 .25649 L
.70307 .25848 L
.70418 .26125 L
.70521 .26453 L
.70754 .27386 L
.71234 .29511 L
.71366 .29977 L
.71439 .30192 L
.71507 .30364 L
.71571 .30495 L
.71641 .30605 L
.71763 .3071 L
.7188 .30708 L
.71986 .30625 L
.72108 .30443 L
.72223 .302 L
.7265 .28993 L
.7287 .28405 L
.7299 .28149 L
.73102 .27965 L
.73223 .27833 L
.73287 .27793 L
.73356 .27771 L
.73479 .27785 L
.7359 .2785 L
.7384 .28123 L
.73971 .28298 L
.74108 .28473 L
.7423 .28599 L
.74298 .28652 L
Mistroke
.74362 .28688 L
.74475 .28713 L
.74595 .28681 L
.7466 .28636 L
.74731 .28566 L
.7486 .28383 L
.74986 .28145 L
.75102 .27884 L
.75391 .2715 L
.75532 .26808 L
.75661 .26539 L
.75771 .26361 L
.75875 .26244 L
.75985 .26184 L
.76104 .262 L
.76227 .26305 L
.76357 .26513 L
.7648 .26793 L
.76592 .27105 L
.77105 .2887 L
.7733 .29548 L
.77457 .2984 L
.77576 .30037 L
.77693 .30153 L
.778 .3019 L
.77923 .30153 L
.78039 .30046 L
.7816 .2987 L
.78273 .2966 L
.78526 .2909 L
.78783 .28511 L
.78909 .28274 L
.79024 .28099 L
.79145 .27966 L
.79276 .27885 L
.79343 .27868 L
.79417 .2787 L
.79487 .27888 L
.79552 .27919 L
.79669 .28001 L
.79795 .28119 L
.80024 .28361 L
.80132 .28465 L
.80247 .28552 L
.80344 .28602 L
.80452 .28622 L
.80577 .28597 L
.80691 .28526 L
.80823 .28386 L
.80948 .28203 L
Mistroke
.81411 .27287 L
.81631 .26884 L
.81755 .26717 L
.81869 .26614 L
.81996 .26568 L
.8206 .26573 L
.8213 .26603 L
.82257 .26717 L
.82375 .26892 L
.82509 .27159 L
.82635 .27466 L
.82871 .28131 L
.83128 .28865 L
.83269 .29215 L
.834 .29486 L
.83506 .29652 L
.83619 .29775 L
.83745 .29841 L
.8386 .29836 L
.83964 .29781 L
.84077 .29672 L
.84185 .29528 L
.84284 .29367 L
.84527 .28912 L
.84783 .2844 L
.84889 .28276 L
.85002 .28132 L
.85126 .28017 L
.85242 .27953 L
.85308 .27936 L
.85379 .27932 L
.85508 .27962 L
.85634 .2803 L
.85751 .28118 L
.86012 .28347 L
.86151 .28454 L
.86229 .28502 L
.86301 .28534 L
.86422 .28561 L
.8655 .28544 L
.86662 .2849 L
.86784 .28388 L
.86913 .28236 L
.8705 .28034 L
.87297 .27611 L
.87538 .2721 L
.87674 .27029 L
.87799 .26909 L
.87909 .26848 L
.88029 .26835 L
Mistroke
.88155 .26885 L
.88273 .26991 L
.88387 .27146 L
.88496 .27335 L
.887 .27773 L
.88936 .28352 L
.89159 .28874 L
.89379 .29289 L
.89502 .29454 L
.89616 .29554 L
.89733 .29603 L
.89862 .29593 L
.89927 .29565 L
.89996 .29518 L
.90121 .29395 L
.90648 .28592 L
.90774 .28403 L
.90907 .28232 L
.91021 .28118 L
.91146 .2803 L
.91261 .27987 L
.91384 .2798 L
.91501 .28007 L
.91608 .28056 L
.91731 .28134 L
.91865 .28234 L
.91993 .28331 L
.9211 .2841 L
.92223 .28471 L
.9233 .28507 L
.92442 .28517 L
.92564 .28494 L
.92671 .28441 L
.92784 .28354 L
.92881 .28256 L
.92987 .28128 L
.93238 .27765 L
.93511 .27368 L
.93636 .2722 L
.93704 .27153 L
.93769 .27102 L
.93882 .27042 L
.94007 .27027 L
.94121 .27061 L
.94241 .27147 L
.94343 .27258 L
.94455 .27418 L
.94938 .28375 L
.95207 .2891 L
.9534 .29121 L
Mistroke
.95462 .29271 L
.9553 .29334 L
.95602 .29384 L
.95675 .29416 L
.95755 .29429 L
.95821 .29424 L
.95893 .29402 L
.96021 .29322 L
.96151 .29199 L
.96292 .29027 L
.96548 .28666 L
.96801 .28332 L
.96911 .28216 L
.97029 .28117 L
.97106 .2807 L
.97176 .28039 L
.97244 .28021 L
.97315 .28013 L
.9739 .28017 L
.9746 .28031 L
.97537 .28057 L
.97619 .28094 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Obgoo00<007ooOol0
hWoo003;Ool00`00Oomoo`3ROol00<]oo`03001oogoo0>9oo`00bgoo0P00hgoo003;Ool00`00Oomo
o`3ROol00<=oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo0=]oo`00`goo0P001Woo00<0
07ooOol017oo00<007ooOol0fgoo0033Ool20006Ool00`00Oomoo`04Ool00`00Oomoo`3KOol00<=o
o`8000Ioo`03001oogoo00Aoo`800=aoo`00`goo0P001Woo0P001Goo0P00g7oo0033Ool20006Ool0
0`00Oomoo`03Ool00`00Ool0003LOol00<=oo`8000Ioo`03001oogoo00=oo`03001oo`000=aoo`00
`goo0P001Woo00<007ooOol00goo00<007oo0000g7oo002UOol20007Ool30006Ool00`00Oomoo`05
Ool60006Ool00`00Oomoo`03Ool00`00Ool0003LOol00:Aoo`04001oogoo0006Ool30007Ool00`00
Oomoo`03Ool01000Oomoogoo0`001Woo00<007ooOol00goo00<007oo0000g7oo002SOol00`00Oomo
o`02Ool00`00Oomoo`03Ool30007Ool00`00Oomoo`07Ool30006Ool30003Ool00`00Ool0003LOol0
09Yoo`L0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Moo`<000Ioo`03001oogoo
00=oo`03001oo`000=aoo`00Xgoo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo00@0
07ooOomoo`<000Ioo`03001oogoo00=oo`03001oo`000=aoo`00Xgoo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol00Woo1@0000=oo`00Ool01Goo00<007ooOol00goo00<007oo0000g7oo002S
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool01`00Oomoogoo001oo`0000Ioo`03
001oogoo00=oo`03001oo`000=aoo`00Y7oo00@007ooOol000eoo`03001oogoo009oo`05001oogoo
Ool00003Ool00`00Ool00006Ool00`00Oomoo`03Ool00`00Ool0003LOol00:Eoo`8000ioo`H000=o
o`D0009oo`03001oogoo00=oo`03001oogoo00=oo`03001oo`000=aoo`00`Woo00@007ooOol000Eo
o`8000Aoo`03001oo`000=aoo`00`Woo00@007ooOol000Eoo`03001oogoo00=oo`03001oo`000=ao
o`00`Woo00@007ooOol000Eoo`03001oogoo00=oo`03001oo`000=aoo`00`Woo00@007ooOol000Eo
o`03001oogoo00=oo`04001oogoo003KOol00<9oo`04001oogoo0005Ool00`00Oomoo`02Ool01@00
Oomoogoo0000fgoo0032Ool01000Oomoo`001Goo00<007ooOol00Woo00D007ooOomoo`000=]oo`00
`Woo00@007ooOol000Eoo`8000=oo`05001oogooOol0003KOol00<9oo`04001oogoo0005Ool00`00
Oomoo`02Ool01@00Oomoogoo0000fgoo0032Ool01000Oomoo`001Goo00<007ooOol00Woo00D007oo
Oomoo`000=]oo`00`Woo00@007ooOol000Eoo`03001oogoo009oo`05001oogooOol0003KOol00<9o
o`04001oogoo0005Ool00`00Oomoo`02Ool01@00Oomoogoo0000fgoo0032Ool01000Oomoo`001Goo
00<007ooOol00Woo00D007ooOomoo`000=]oo`00`Woo00@007ooOol000Eoo`8000=oo`05001oogoo
Ool0003KOol00<9oo`04001oogoo0005Ool00`00Oomoo`02Ool01@00Oomoogoo0000fgoo0032Ool0
1000Oomoo`001Goo00<007ooOol00Woo00D007ooOomoo`000=]oo`00`Woo00@007ooOol000Eoo`03
001oogoo009oo`05001oogooOol0003KOol00<9oo`04001oogoo0005Ool00`00Oomoo`02Ool01@00
Oomoogoo0000fgoo0032Ool01000Oomoo`001Goo00<007ooOol00Woo00D007ooOomoo`000=]oo`00
`Woo00@007ooOol000Eoo`8000=oo`05001oogooOol0003KOol00<9oo`04001oogoo0005Ool00`00
Oomoo`02Ool01@00Oomoogoo0000fgoo0032Ool01000Oomoo`001Goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0f7oo0031Ool01@00Oomoogoo00001Goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol0f7oo002^Ool20007Ool30005Ool40002Ool00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`3HOol00:eoo`04001oogoo0006Ool30004Ool02000Oomoo`00
Ool007oo0005Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3HOol00:aoo`03001oogoo
009oo`03001oogoo00=oo`<000Moo`05001oo`00Ool00005Ool30002Ool00`00Oomoo`02Ool00`00
Oomoo`3HOol00:=oo`L0009oo`03001oogoo009oo`03001oogoo00eoo`05001oo`00Ool00005Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3HOol00:aoo`03001oogoo009oo`03001oogoo
00Yoo`08001oogoo001oo`00Ool000Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo0=Qo
o`00[7oo00<007ooOol00Woo00<007ooOol02Woo1@000goo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol0f7oo002/Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool01000Oomo
o`0017oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0f7oo002]Ool0
1000Oomoo`003Goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo0=Qoo`00[Woo0P003Woo1@000goo00<007ooOol00Woo0P000goo00<007ooOol00Woo
00<007ooOol0f7oo0031Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`3HOol00<5oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol0f7oo0031Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3HOol00<5oo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol00005Ool00`00Oomoo`3HOol00<5oo`03001oogoo009oo`03001oogoo009oo`05
001oogooOol00005Ool00`00Oomoo`3HOol00<5oo`03001oogoo009oo`03001oogoo009oo`80009o
o`03001oogoo00=oo`03001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo00D007oo
Oomoo`0000Eoo`03001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomo
o`0000Eoo`03001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`00
00Eoo`03001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eo
o`03001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Eoo`03
001oogoo0=Qoo`00`Goo00<007ooOol00Woo00<007ooOol00Woo0P000Woo00<007ooOol00goo00<0
07ooOol0f7oo0031Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007oo
Ool0f7oo0031Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0
f7oo0031Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0f7oo
0031Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0f7oo0030
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0f7oo0030Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`3HOol00<1oo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`3HOol00<1oo`03001o
ogoo00=oo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`3HOol00<1oo`03001oogoo
00=oo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`3HOol00:Eoo`8000Moo`<000Ao
o`H000Aoo`@000=oo`03001oogoo009oo`05001oogooOol00005Ool00`00Oomoo`3HOol00:Aoo`04
001oogoo0006Ool30005Ool01@00Oomoogoo00000goo00<007oo00000Woo00@007ooOol000Aoo`05
001oogooOol00005Ool00`00Oomoo`3HOol00:=oo`03001oogoo009oo`03001oogoo00=oo`<000Io
o`03001oogoo00Ioo`04001oogoo0002Ool00`00Oomoo`02Ool300000goo001oo`04Ool00`00Oomo
o`3HOol009Yoo`L0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Eoo`04001oogoo
0002Ool00`00Oomoo`02Ool01@00Oomoogoo00001Goo00<007ooOol0f7oo002SOol00`00Oomoo`02
Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Ool00002Ool01000Oomoo`0017oo00D007ooOomo
o`0000Eoo`03001oogoo0=Qoo`00Xgoo00<007ooOol00Woo00<007ooOol03goo00@007ooOomoo`D0
00Aoo`05001oogooOol00003Ool00`00Oomoo`03Ool00`00Oomoo`3HOol00:=oo`03001oogoo009o
o`03001oogoo00moo`07001oogooOol007oo00001Woo00D007ooOomoo`0000=oo`03001oogoo00=o
o`03001oogoo0=Qoo`00Y7oo00@007ooOol000Aoo`03001oogoo00Ioo`03001oogoo009oo`07001o
ogooOol007oo00001Woo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo015oo`03001o
ogoo0<Aoo`00YGoo0P0017oo00<007oo000027oo100017oo1@0017oo00@007ooOomoo`80009oo`03
001oogoo00=oo`03001oogoo015oo`800<Eoo`00Zgoo00<007oo00004Woo00<007ooOol017oo00D0
07ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo015oo`800<Eoo`00Zgoo00<007oo00004Woo
00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo00=oo`03001oogoo011oo`03001oo`00
0<Eoo`00Zgoo00<007oo00004Woo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oogoo00Ao
o`03001oogoo00moo`04001oogoo0034Ool00:Yoo`04001oogoo000BOol00`00Oomoo`04Ool01@00
Oomoogoo00000goo00<007ooOol017oo00<007ooOol03goo00@007ooOol00<Aoo`00ZWoo00@007oo
Ool0019oo`03001oogoo00Aoo`05001oogooOol00003Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool0
1000Oomoo`00a7oo002ZOol01000Oomoo`004Woo00<007ooOol017oo00@007ooOomoo`80009oo`03
001oogoo00Aoo`03001oogoo00moo`04001oogoo0034Ool00:Yoo`05001oogooOol0000AOol00`00
Oomoo`04Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol03goo00@007ooOol00<Ao
o`00ZWoo00D007ooOomoo`00015oo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`05
Ool00`00Oomoo`0?Ool01000Oomoo`00a7oo002ZOol01@00Oomoogoo00004Goo00<007ooOol017oo
00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo009oo`03001oogoo
0<5oo`00>7oo0`001Goo0P00?7oo1P001Goo0P002Woo00<007ooOol04Woo00D007ooOomoo`00015o
o`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomo
o`02Ool00`00Oomoo`0BOol00`00Oomoo`08Ool60005Ool2000oOol30005Ool2001>Ool003Uoo`03
001oogoo00=oo`04001oogoo000lOol01@00Oomoogoo000017oo00@007ooOol000Qoo`03001oo`00
01=oo`05001oogooOol0000AOol00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol01Goo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol04Goo0P002goo00D007ooOomoo`0000Aoo`04
001oogoo000oOol00`00Oomoo`03Ool01000Oomoo`00CGoo000eOol60003Ool00`00Oomoo`02Ool0
0`00Oomoo`0jOol00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool0000COol0
1@00Oomoogoo00004Goo00<007ooOol017oo00D007ooOomoo`00009oo`03001oogoo00Eoo`03001o
ogoo00ioo`03001oogoo009oo`03001oogoo011oo`04001oogoo000;Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`0hOol60003Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool002aoo`L0009o
o`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`0_Ool70005Ool00`00Oomoo`03Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool0000BOol00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`04Ool01000Oomoogoo0P0000=oo`00Ool01Woo00<007ooOol03Woo00<007ooOol00Woo
00<007ooOol047oo00@007ooOol000aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo03Qo
o`05001oogooOol00004Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool003Ioo`04001oogoo0004Ool0
0`00Oomoo`02Ool00`00Oomoo`0lOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
1000Oomoo`004Goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo00D007ooOomoo`00
009oo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo009oo`03001oogoo011oo`04001oogoo
000=Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0iOol01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol0BWoo000gOol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`0gOol2
0004Ool01@00Oomoogoo000017oo00<007ooOol017oo00D007ooOomoo`00015oo`03001oogoo009o
o`03001oogoo00moo`03001oogoo00Aoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomo
o`0>Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01000Oomoo`003Woo00H007ooOomoo`00Ool20000
0goo001oo`0kOol00`00Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`1:Ool003Moo`03001oo`00
00Aoo`03001oogoo009oo`03001oogoo03Moo`03001oo`0000=oo`05001oogooOol00004Ool00`00
Oomoo`04Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol01Goo
00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo
011oo`04001oogoo000>Ool01000Oomoogoo0P000Woo0P00?7oo00<007oo000017oo00<007ooOol0
0Woo00<007ooOol0BWoo000hOol20005Ool01000Oomoo`008goo0P0057oo00@007oo000000=oo`03
001oogoo009oo`04001oogoo0007Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol0
17oo0P0027oo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oogoo00Io
o`8000Eoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Ioo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo000DOol2000XOol20005Ool01000Oomoo`00CGoo000i
Ool00`00Oomoo`04Ool2000>Ool00`00Oomoo`0COol01000Ool000004Woo00<007ooOol010001Woo
0P0027oo00D007ooOomoo`00015oo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Moo`03
001oogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`06Ool20005Ool00`00
Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`07Ool40005Ool4000COol20000
0goo001oo`0COol00`00Oomoo`0AOol00`00Oomoo`04Ool2001>Ool004moo`@0019oo`03001oogoo
009oo`03001oogoo00moo`05001oogooOol0000BOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00007Ool00`00Oomoo`05Ool01000Oomoogoo0P0000=o
o`00Ool01Woo00<007ooOol01Woo0P001Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol047oo00@007ooOol001=oo`04001oogoo000COol3001YOol0025oo`8001Eoo`<0
01=oo`8000=oo`03001oogoo00moo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo009oo`03
001oogoo011oo`03001oogoo009oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00=oo`03
001oo`0000Moo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`05
Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool01@00Oomoogoo00004goo00@007ooOol001=oo`04001oogoo000COol3000EOol2000kOol0025o
o`03001oo`0001=oo`05001oogooOol0000BOol00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomo
o`04Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00007Ool00`00Oomo
o`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol01Goo00@007ooOol000Aoo`03
001oogoo00Aoo`03001oogoo00Ioo`8000Ioo`03001oogoo009oo`03001oogoo00moo`03001oogoo
009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`05001oogooOol0000COol01000
Oomoo`004goo10008goo0P000Woo00<007ooOol047oo000POol01@00Oomoogoo00004Woo00D007oo
Oomoo`00019oo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00=oo`03
001oo`0000Moo`03001oogoo00Aoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`05Ool0
1@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol01Goo00@007ooOol000Aoo`03001oogoo
00Aoo`03001oogoo00Ioo`8000Eoo`03001oogoo00=oo`03001oogoo00Moo`8000Ioo`03001oogoo
009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo
00moo`05001oogooOol0000BOol20002Ool00`00Oomoo`0POol00`00Oomoo`0200000goo001oo`0@
Ool0021oo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00ioo`03001o
ogoo00Ioo`05001oogooOol00009Ool00`00Oomoo`07Ool01000Ool000002Goo00<007ooOol00goo
00<007ooOol00goo0`0027oo00<007ooOol00goo00<007ooOol00Woo00@007ooOol000Moo`03001o
ogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00<007ooOol01Goo00<007ooOol01Goo00@007ooOol000=oo`03001oogoo00Eoo`03001oogoo
00Eoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`07Ool20005Ool00`00Oomoo`04Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`03Ool0
0`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0POol0
1000Oomoo`000goo00<007ooOol03Woo000DOol30008Ool00`00Oomoo`03Ool00`00Oomoo`03Ool3
0008Ool00`00Oomoo`04Ool00`00Oomoo`02Ool30008Ool00`00Oomoo`07Ool00`00Ool000020008
Ool00`00Oomoo`08Ool200000goo001oo`07Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Ool0
0008Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol01Goo00D0
07ooOomoo`0000=oo`03001oogoo00Aoo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomo
o`05Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol01Goo00@0
07ooOol000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0004Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool01000Oomoo`0017oo00<007ooOol017oo00<007ooOol01Goo100017oo00<007oo
Ool017oo00<007ooOol01Goo100017oo00<007ooOol00goo00<007ooOol01Woo100017oo00<007oo
Ool00goo00<007ooOol01Woo0`005Woo00D007ooOomoo`00009oo`03001oogoo00ioo`002gooo`00
P@003Goo00D007ooOomoo`00009oo`03001oogoo00ioo`0057oo00D007ooOomoo`0000Eoo`03001o
ogoo00Eoo`@000Aoo`03001oogoo00Aoo`05001oogooOol00004Ool30005Ool00`00Oomoo`02Ool2
000?Ool20006Ool00`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol01Goo0P0000=oo`00
Ool00goo00<007ooOol01Goo00<007oo000017oo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oo`0000Moo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo0000
0Woo00<007ooOol01Goo00<007ooOol017oo0P000goo00@007ooOol000Qoo`8000Eoo`05001oogoo
Ool00002Ool00`00Oomoo`02Ool01000Oomoo`001goo00D007ooOomoo`00009oo`8000Ioo`03001o
ogoo00Aoo`04001oogooOol50008Ool00`00Oomoo`02Ool20004Ool30009Ool20004Ool00`00Oomo
o`02Ool30005Ool01000Oomoo`001Woo00<007ooOol00Woo10001goo00<007ooOol017oo00@007oo
Ool001Moo`03001oogoo00=oo`03001oogoo00ioo`0067oo00<007ooOol00goo00<007ooOol03Woo
00<007ooOol00goo00D007ooOomoo`0000aoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Eoo`@000Aoo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oo`0000Aoo`03001oogoo00Aoo`03001oogoo00Eoo`04001oogoo0004Ool0
0`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol0
1Goo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`03001o
o`0000Moo`03001oogoo00Eoo`03001oogoo009oo`800003Ool007oo00Eoo`03001oogoo00Aoo`03
001oogoo00=oo`8000Uoo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo
00]oo`05001oogooOol00005Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0JOol01@00
Oomoogoo00004Goo000IOol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol047oo00D0
07ooOomoo`00015oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00io
o`03001oogoo00=oo`03001oogoo00Ioo`<000Eoo`03001oogoo00=oo`03001oogoo00Eoo`04001o
ogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo
00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
00=oo`8000Uoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03
001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03
001oogoo011oo`04001oogoo000cOol001Yoo`@0019oo`80009oo`03001oogoo011oo`05001oogoo
Ool0000BOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00
Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Ool00004Ool00`00
Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol01Goo
00D007ooOomoo`00009oo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00moo`05001oogooOol0000AOol01@00
Oomoogoo00004goo00@007ooOol001=oo`@003=oo`00<Goo0`0057oo00@007oo0000019oo`05001o
ogooOol0000BOol00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool0
0`00Oomoo`03Ool00`00Oomoo`06Ool00`00Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
1@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol00Woo00<007oo0000
27oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol047oo00@007ooOol001=oo`04001oo`00000COol3001;Ool004Qoo`<001Aoo`04
001oo`00000BOol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
0goo00<007ooOol01Woo0P001Goo00<007ooOol017oo00<007ooOol01Goo00@007ooOomoo`800003
Ool007oo00Ioo`03001oogoo00Aoo`03001oogoo00=oo`8000Uoo`03001oogoo00=oo`03001oogoo
00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo011oo`04001oogoo
000DOol2001ROol005moo`<001=oo`05001oogooOol0000BOol01@00Oomoogoo00004Goo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol00goo00<007ooOol017oo00<007ooOol01Goo00D007oo
Oomoo`00009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Moo`03
001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`04001oogoo000COol3
001iOol007Ioo`03001oo`0001=oo`05001oogooOol0000AOol00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol047oo00D007ooOomoo`00019oo`03
001oo`00091oo`00MWoo0`004goo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo00io
o`03001oogoo00Aoo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomoo`05Ool00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00004Woo0`00
T7oo002<Ool01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol017oo
00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
00ioo`03001oogoo009oo`03001oogoo011oo`04001oogoo002VOol008eoo`03001oo`00019oo`03
001oogoo009oo`03001oogoo00moo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00002
Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0@
Ool01000Oomoo`00YWoo002=Ool00`00Ool0000BOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00
Oomoo`03Ool00`00Oomoo`05Ool01000Oomoogoo0P0000=oo`00Ool01Woo00<007ooOol017oo00<0
07ooOol03Woo00<007ooOol00Woo00<007ooOol04Goo0`00YWoo002=Ool2000COol00`00Oomoo`02
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol03Woo00D007ooOomoo`0001Aoo`800:Moo`00Xgoo00D0
07ooOomoo`00015oo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00002Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool01@00Oomoogoo0000_Goo002SOol01@00Oomoogoo
00004Goo00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`00009oo`03001oogoo00Eoo`03
001oogoo00Aoo`03001oogoo00moo`04001oogoo002mOol00:=oo`04001oogoo000BOol00`00Oomo
o`03Ool00`00Oomoo`05Ool01@00Oomoogoo00000Woo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol047oo00@007ooOol00;eoo`00Xgoo00@007ooOol0019oo`03001oogoo00=oo`03001oogoo
00Ioo`04001oogoo0002Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool01000Oomo
o`00_Goo002TOol00`00Ool0000BOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`020000
0goo001oo`06Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool01000Oomoo`00_Goo002TOol00`00Ool0
000BOol00`00Oomoo`02Ool00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol047oo00<007oo0000_Woo002TOol00`00Ool0000BOol00`00Oomoo`02Ool0
0`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol04Goo
0P00_Woo002UOol00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`07Ool01000Oomoo`000Woo
00<007ooOol01Woo00<007ooOol00Woo00<007ooOol04Goo0P00_Woo002iOol00`00Oomoo`02Ool0
0`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0dGoo
002iOol00`00Oomoo`02Ool00`00Oomoo`07Ool01000Oomoo`000Woo00<007ooOol01Woo00<007oo
Ool00Woo00<007ooOol0dGoo002jOol01@00Oomoogoo00002Goo00@007ooOol0009oo`03001oogoo
00Ioo`03001oogoo009oo`03001oogoo0=5oo`00^Woo00D007ooOomoo`0000Uoo`03001oogoo0080
0003Ool007oo00Moo`03001oogoo009oo`03001oogoo0=5oo`00^Woo00D007ooOomoo`0000Uoo`04
001oogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`3AOol00;Yoo`05001oogoo
Ool00009Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0dGoo002U
Ool20007Ool30004Ool60003Ool50005Ool01000Oomoo`000Woo00<007ooOol01Woo00<007ooOol0
0Woo00<007ooOol0dGoo002TOol01000Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001o
ogoo009oo`03001oogoo009oo`04001oogoo0002Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00
Oomoo`3AOol00:=oo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`04001oogoo0003Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`000Woo00<007ooOol01Woo00D007ooOomoo`000=Ao
o`00Xgoo00<007ooOol00Woo00<007ooOol03Goo00<007oo00000goo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol0100027oo00D007ooOomoo`000=Aoo`00Xgoo00<007ooOol00Woo00<007oo
Ool03Woo0P000goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0009oo`03001oogoo00Io
o`05001oogooOol0003DOol00:=oo`03001oogoo009oo`03001oogoo00moo`04001oogooOol50005
Ool01000Oomoo`000Woo00<007ooOol01Woo00D007ooOomoo`000=Aoo`00Xgoo00<007ooOol00Woo
00<007ooOol03goo00D007ooOomoo`0000Uoo`04001oogoo0002Ool00`00Oomoo`06Ool01@00Oomo
ogoo0000e7oo002TOol01000Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000Uoo`04001o
ogoo0002Ool00`00Oomoo`07Ool01000Oomoo`00e7oo002UOol2000?Ool50003Ool50005Ool01000
Oomoo`000Woo00<007ooOol01goo00@007ooOol00=Aoo`00^goo00@007ooOol000Uoo`03001oogoo
00800003Ool007oo00Qoo`04001oogoo003DOol00;]oo`04001oogoo0009Ool01000Oomoo`000Woo
00<007ooOol01goo00@007ooOol00=Aoo`00^goo00@007ooOol000Uoo`04001oogoo0002Ool00`00
Oomoo`07Ool01000Oomoo`00e7oo002kOol01000Oomoo`002Goo00@007ooOol0009oo`03001oogoo
00Moo`04001oogoo003DOol00;]oo`04001oogoo0009Ool01000Oomoo`000Woo00<007ooOol01goo
00@007ooOol00=Aoo`00^goo00@007ooOol000Uoo`04001oogoo0002Ool00`00Oomoo`07Ool01000
Oomoo`00e7oo002kOol01000Oomoo`002Goo00<007ooOol00P0000=oo`00Ool027oo00<007oo0000
eGoo002kOol01000Oomoo`002Goo00@007ooOol0009oo`03001oogoo00Moo`03001oo`000=Eoo`00
^goo00<007oo00002Woo00@007ooOol0009oo`03001oogoo00Moo`03001oo`000=Eoo`00^goo00<0
07oo00002Woo00@007ooOol0009oo`03001oogoo00Moo`03001oo`000=Eoo`00^goo00<007oo0000
2Woo00@007ooOol0009oo`03001oogoo00Moo`03001oo`000=Eoo`00^goo00<007oo00002Woo00@0
07ooOol0009oo`03001oogoo00Moo`03001oo`000=Eoo`00^goo00<007oo00002Woo00<007ooOol0
0P0000=oo`00Ool027oo00<007oo0000eGoo002kOol00`00Ool0000:Ool01000Oomoo`000Woo00<0
07ooOol01goo00<007oo0000eGoo002kOol00`00Ool0000:Ool01000Oomoo`000Woo00<007ooOol0
27oo0P00eGoo002kOol00`00Ool0000:Ool01000Oomoo`000Woo00<007ooOol027oo0P00eGoo002l
Ool2000:Ool01000Oomoo`000Woo00<007ooOol027oo0P00eGoo002lOol00`00Oomoo`09Ool01000
Oomoo`000Woo00<007ooOol027oo00<007ooOol0e7oo0038Ool00`00Oomoo`0200000goo001oo`3P
Ool00<Qoo`04001oogoo0002Ool00`00Oomoo`3OOol00<Qoo`04001oogoo0002Ool00`00Oomoo`3O
Ool00<Qoo`04001oogoo0002Ool00`00Oomoo`3OOol00:ioo`8000Moo`<000Eoo`@000Ioo`03001o
o`00009oo`03001oogoo0=moo`00[Goo00@007ooOol000Ioo`<000Aoo`03001oogoo009oo`03001o
ogoo00=oo`03001oo`00009oo`03001oogoo0=moo`00[7oo00<007ooOol00Woo00<007ooOol00goo
0`002Goo00<007ooOol00goo00<007oo00000Woo00<007ooOol0ggoo002/Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Ool00003003QOol00:aoo`03001oogoo009oo`03001o
ogoo00Yoo`03001oogoo009oo`03001oogoo00=oo`03001oo`00009oo`03001oogoo0=moo`00[7oo
00<007ooOol00Woo00<007ooOol02Woo1@001Woo00<007oo00000Woo00<007ooOol0ggoo002/Ool0
0`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Ool00002Ool00`00Oomoo`3OOol0
0:eoo`04001oogoo000=Ool00`00Oomoo`08Ool00`00Ool00002Ool00`00Oomoo`3OOol00:ioo`80
00ioo`D000Ioo`03001oo`00009oo`03001oogoo0=moo`00bGoo00H007oo000007oo003QOol00<Uo
o`05001oo`00Ool0003ROol00<Uoo`05001oo`00Ool0003ROol00<Uoo`05001oo`00Ool0003ROol0
0<Uoo`05001oo`00Ool0003ROol00<Uoo`05001oo`00Ool0003ROol00<Uoo`03001oo`0000800>9o
o`00bGoo00D007oo001oo`000>9oo`00bGoo00D007oo001oo`000>9oo`00bGoo00D007oo001oo`00
0>9oo`00bGoo00D007oo001oo`000>9oo`00bGoo00D007oo001oo`000>9oo`00bGoo00<007oo0000
0P00hWoo0039Ool01@00Ool007oo0000hWoo0039Ool01@00Ool007oo0000hWoo0039Ool01@00Ool0
07oo0000hWoo0039Ool01@00Ool007oo0000hWoo0039Ool01@00Ool007oo0000hWoo0039Ool00`00
Ool00002003ROol00<Uoo`05001oo`00Ool0003ROol00<Uoo`05001oo`00Ool0003ROol00<Uoo`05
001oo`00Ool0003ROol00:Eoo`8000Moo`<000Ioo`03001oogoo00Eoo`@000Ioo`05001oo`00Ool0
003ROol00:Aoo`04001oogoo0006Ool30007Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool01@00Ool007oo0000hWoo002SOol00`00Oomoo`02Ool00`00Oomoo`03Ool30007Ool00`00
Oomoo`08Ool00`00Oomoo`03Ool00`00Ool00002003ROol00:=oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo00Qoo`03001oogoo00=oo`05001oo`00Ool0003ROol00:=oo`03001oogoo009o
o`03001oogoo00ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`05001oo`00Ool0
003ROol00:=oo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`D000Ioo`05001oo`00
Ool0003ROol00:=oo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Qo
o`05001oo`00Ool0003ROol00:Aoo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo0000
2Woo00@007oo00000>=oo`00YGoo0P003Woo1P000goo1@001Woo00@007oo00000>=oo`00bGoo00@0
07oo00000>=oo`00bGoo00@007oo00000>=oo`00bGoo00@007oo00000>=oo`00bGoo00@007oo0000
0>=oo`00bWoo0`00hgoo003:Ool3003SOol00<Yoo`<00>=oo`00bWoo0`00hgoo003:Ool3003SOol0
0<Yoo`<00>=oo`00bWoo0`00hgoo003:Ool3003SOol00<Yoo`<00>=oo`00bWoo0`00hgoo003:Ool3
003SOol00<Yoo`<00>=oo`00bWoo0`00hgoo003:Ool3003SOol00<Yoo`<00>=oo`00bWoo0`00hgoo
003:Ool3003SOol00<Yoo`800>Aoo`00_goo1@001Woo0P00i7oo0031Ool00`00Oomoo`06Ool2003T
Ool00<5oo`03001oogoo00Moo`<00>9oo`00`Goo00<007ooOol01goo00<007ooOol0hWoo0031Ool0
0`00Oomoo`07Ool00`00Oomoo`3ROol00<5oo`03001oogoo00Moo`03001oogoo0>9oo`00`Goo00<0
07ooOol01goo00<007ooOol0hWoo002oOol30009Ool00`00Oomoo`3ROol00<1oo`8000Uoo`03001o
ogoo0>9oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00;eoo`80019oo`03001oogoo00]oo`03
001oogoo00Moo`800<Eoo`00_Goo00<007ooOol047oo00<007ooOol03Goo00<007ooOol01goo00<0
07ooOol0`goo002mOol00`00Oomoo`0@Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`33
Ool00:Qoo`<000=oo`8000=oo`@000Ioo`03001oogoo00=oo`H000Ioo`03001oogoo00Aoo`80009o
o`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo0<=oo`00ZGoo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00=oo`03
001oogoo00800003Ool007oo00Aoo`03001oogoo00Ioo`03001oogoo0<=oo`00ZGoo00D007ooOomo
o`0000=oo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00=oo`04001o
ogoo0003Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`33Ool00:Uoo`04001oogoo0004
Ool70005Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0`goo002YOol50003Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomoogoo0000
0Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0`goo002YOol00`00Oomoo`02Ool01@00
Oomoogoo00000goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01goo00<007ooOol017oo
00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0`goo002YOol00`00Oomo
o`02Ool00`00Oomoo`02Ool30007Ool00`00Oomoo`03Ool60007Ool00`00Oomoo`04Ool01@00Oomo
ogoo000017oo00<007ooOol01goo00<007ooOol0`goo002YOol00`00Oomoo`02Ool00`00Oomoo`0<
Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`33
Ool00:Qoo`H000moo`8000Ioo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Moo`800<Eo
o`00aWoo0`00igoo0034Ool01000Ool00000j7oo0035Ool01000Oomoo`00igoo003oOonaOol00?mo
ok5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-55, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00952381 0.308694 0.30805 [
[.11905 .29619 -9 -9 ]
[.11905 .29619 9 0 ]
[.30952 .29619 -9 -9 ]
[.30952 .29619 9 0 ]
[.69048 .29619 -6 -9 ]
[.69048 .29619 6 0 ]
[.88095 .29619 -6 -9 ]
[.88095 .29619 6 0 ]
[1.025 .30869 0 -6 ]
[1.025 .30869 10 6 ]
[.4875 .00064 -12 -4.5 ]
[.4875 .00064 0 4.5 ]
[.4875 .15467 -24 -4.5 ]
[.4875 .15467 0 4.5 ]
[.4875 .46272 -18 -4.5 ]
[.4875 .46272 0 4.5 ]
[.4875 .61674 -6 -4.5 ]
[.4875 .61674 0 4.5 ]
[.5 .64303 -26.0625 0 ]
[.5 .64303 26.0625 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11905 .30869 m
.11905 .31494 L
s
[(-40)] .11905 .29619 0 1 Mshowa
.30952 .30869 m
.30952 .31494 L
s
[(-20)] .30952 .29619 0 1 Mshowa
.69048 .30869 m
.69048 .31494 L
s
[(20)] .69048 .29619 0 1 Mshowa
.88095 .30869 m
.88095 .31494 L
s
[(40)] .88095 .29619 0 1 Mshowa
.125 Mabswid
.16667 .30869 m
.16667 .31244 L
s
.21429 .30869 m
.21429 .31244 L
s
.2619 .30869 m
.2619 .31244 L
s
.35714 .30869 m
.35714 .31244 L
s
.40476 .30869 m
.40476 .31244 L
s
.45238 .30869 m
.45238 .31244 L
s
.54762 .30869 m
.54762 .31244 L
s
.59524 .30869 m
.59524 .31244 L
s
.64286 .30869 m
.64286 .31244 L
s
.7381 .30869 m
.7381 .31244 L
s
.78571 .30869 m
.78571 .31244 L
s
.83333 .30869 m
.83333 .31244 L
s
.07143 .30869 m
.07143 .31244 L
s
.02381 .30869 m
.02381 .31244 L
s
.92857 .30869 m
.92857 .31244 L
s
.97619 .30869 m
.97619 .31244 L
s
.25 Mabswid
0 .30869 m
1 .30869 L
s
gsave
1.025 .30869 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .00064 m
.50625 .00064 L
s
[(-1)] .4875 .00064 1 0 Mshowa
.5 .15467 m
.50625 .15467 L
s
[(-0.5)] .4875 .15467 1 0 Mshowa
.5 .46272 m
.50625 .46272 L
s
[(0.5)] .4875 .46272 1 0 Mshowa
.5 .61674 m
.50625 .61674 L
s
[(1)] .4875 .61674 1 0 Mshowa
.125 Mabswid
.5 .03145 m
.50375 .03145 L
s
.5 .06225 m
.50375 .06225 L
s
.5 .09306 m
.50375 .09306 L
s
.5 .12386 m
.50375 .12386 L
s
.5 .18547 m
.50375 .18547 L
s
.5 .21628 m
.50375 .21628 L
s
.5 .24708 m
.50375 .24708 L
s
.5 .27789 m
.50375 .27789 L
s
.5 .3395 m
.50375 .3395 L
s
.5 .3703 m
.50375 .3703 L
s
.5 .40111 m
.50375 .40111 L
s
.5 .43191 m
.50375 .43191 L
s
.5 .49352 m
.50375 .49352 L
s
.5 .52433 m
.50375 .52433 L
s
.5 .55513 m
.50375 .55513 L
s
.5 .58594 m
.50375 .58594 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -87.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Im) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.125 13.875 moveto
(@) show
81.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.125 7.875 moveto
(\\216) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.125 13.875 moveto
(H) show
93.125 13.875 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.125 13.875 moveto
(L) show
105.125 13.875 moveto
(D) show
111.125 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .30806 m
.02846 .30455 L
.02952 .30366 L
.03068 .3028 L
.03178 .30216 L
.03279 .30177 L
.03399 .30161 L
.03527 .30187 L
.03635 .30244 L
.03754 .30344 L
.0388 .30492 L
.04016 .30691 L
.04262 .3112 L
.04516 .3158 L
.0465 .31795 L
.04723 .31898 L
.04793 .31982 L
.04858 .32049 L
.0493 .32107 L
.05054 .32167 L
.05181 .32172 L
.05297 .32126 L
.05411 .32036 L
.05517 .31916 L
.05758 .31542 L
.06244 .30648 L
.06371 .30455 L
.06506 .30291 L
.06576 .30224 L
.06654 .30168 L
.06724 .30132 L
.06791 .30112 L
.06921 .30109 L
.0704 .30146 L
.0717 .30222 L
.07308 .30332 L
.07532 .30542 L
.07655 .30652 L
.07771 .30743 L
.07837 .30786 L
.07909 .30823 L
.08034 .30862 L
.08161 .30867 L
.08278 .30838 L
.08404 .30774 L
.08474 .30725 L
.08539 .30674 L
.08782 .30443 L
.08922 .30306 L
.0907 .3018 L
Mistroke
.09142 .30131 L
.0921 .30095 L
.09337 .30059 L
.09469 .30071 L
.09544 .30102 L
.09612 .30146 L
.09682 .30207 L
.09758 .30291 L
.09912 .30511 L
.10174 .31006 L
.10458 .31605 L
.10591 .3186 L
.10731 .3209 L
.10851 .32239 L
.1092 .32301 L
.10984 .32343 L
.11109 .32378 L
.11223 .32353 L
.11349 .32264 L
.11481 .32107 L
.11593 .31931 L
.11712 .31707 L
.11926 .3125 L
.1218 .30708 L
.12413 .30301 L
.12545 .30137 L
.12611 .30076 L
.12684 .30026 L
.12757 .29995 L
.12836 .29981 L
.1291 .29987 L
.12978 .30007 L
.13108 .30081 L
.13182 .3014 L
.13251 .30204 L
.1351 .30481 L
.1363 .30607 L
.13759 .30725 L
.13881 .30808 L
.13993 .30855 L
.14111 .30869 L
.14236 .30843 L
.14365 .30774 L
.14438 .30719 L
.14506 .30657 L
.1475 .30389 L
.1501 .30102 L
.15075 .30044 L
.15145 .29992 L
.15222 .29949 L
Mistroke
.15294 .29924 L
.15364 .29917 L
.15431 .29926 L
.15556 .29988 L
.15675 .30102 L
.15802 .30282 L
.16031 .30731 L
.1628 .31335 L
.16549 .31982 L
.16676 .3224 L
.16746 .32359 L
.1681 .32454 L
.16925 .32579 L
.17051 .32647 L
.1717 .3264 L
.17279 .32574 L
.17405 .32429 L
.17524 .32231 L
.17979 .31141 L
.18202 .30587 L
.18407 .30176 L
.18515 .30015 L
.18628 .29895 L
.18742 .29827 L
.18866 .29813 L
.18993 .29858 L
.19064 .29906 L
.19129 .29962 L
.19373 .30246 L
.19627 .30571 L
.19696 .30649 L
.1977 .30721 L
.19901 .30819 L
.20024 .30864 L
.20139 .30864 L
.20264 .30815 L
.20335 .30766 L
.20399 .3071 L
.20852 .30125 L
.20976 .29965 L
.21108 .29827 L
.21232 .29744 L
.21345 .29718 L
.21461 .29747 L
.21567 .29828 L
.21684 .29977 L
.21807 .30199 L
.22015 .30701 L
.22242 .31368 L
.22494 .32119 L
Mistroke
.22627 .32464 L
.227 .32626 L
.22768 .32758 L
.22891 .32938 L
.22957 .33 L
.23027 .33039 L
.23152 .33036 L
.23266 .32952 L
.23384 .32786 L
.23494 .32568 L
.23744 .31898 L
.24198 .30489 L
.2433 .3015 L
.24399 .29998 L
.24472 .2986 L
.24536 .29759 L
.24606 .29672 L
.24729 .29579 L
.2485 .29561 L
.24979 .29616 L
.251 .29729 L
.25211 .29871 L
.25477 .3029 L
.25617 .30507 L
.25694 .30613 L
.25766 .30699 L
.25896 .30813 L
.25965 .3085 L
.26039 .30868 L
.26171 .30846 L
.26292 .30766 L
.26419 .30625 L
.2654 .30449 L
.26765 .30058 L
.26893 .29836 L
.27028 .29632 L
.27144 .29502 L
.27271 .29423 L
.2738 .2942 L
.27497 .29491 L
.27608 .29631 L
.27709 .29821 L
.27825 .30109 L
.27952 .30497 L
.28183 .31339 L
.28451 .32367 L
.28582 .32819 L
.28703 .33169 L
.2877 .33329 L
.28843 .33471 L
Mistroke
.28916 .33578 L
.28994 .33648 L
.29059 .33671 L
.2913 .3366 L
.29257 .33543 L
.29385 .33305 L
.29458 .33122 L
.29525 .32926 L
.29778 .32002 L
.30026 .30981 L
.30253 .30127 L
.3037 .29767 L
.30479 .29499 L
.30593 .29299 L
.30717 .29176 L
.30844 .29155 L
.30959 .29219 L
.31023 .29286 L
.31092 .2938 L
.31217 .29595 L
.31425 .30026 L
.31648 .30477 L
.31776 .3068 L
.31893 .30806 L
.32011 .30866 L
.32122 .30855 L
.32252 .30758 L
.32372 .30595 L
.32503 .30348 L
.32643 .30031 L
.3278 .29701 L
.32928 .29364 L
.32996 .29228 L
.33067 .29104 L
.33195 .28946 L
.33311 .28892 L
.33419 .28929 L
.33538 .29076 L
.33665 .29357 L
.33731 .29557 L
.33804 .2981 L
.33936 .30359 L
.34183 .31603 L
.34418 .32858 L
.34548 .33492 L
.34671 .34009 L
.34785 .34387 L
.34909 .34667 L
.35023 .34785 L
.35128 .34773 L
Mistroke
.35193 .34705 L
.35264 .34581 L
.35392 .34227 L
.35516 .33741 L
.35631 .33191 L
.35909 .31623 L
.36168 .30152 L
.36288 .29562 L
.36403 .29096 L
.36535 .28693 L
.36655 .28465 L
.3672 .28399 L
.36788 .28372 L
.36912 .28428 L
.3698 .28514 L
.37044 .28625 L
.3719 .28969 L
.37444 .29734 L
.37582 .30149 L
.3771 .3048 L
.37784 .30631 L
.3785 .30739 L
.37924 .30823 L
.38003 .30866 L
.38069 .30864 L
.38141 .30821 L
.38271 .3064 L
.38394 .30354 L
.38507 .30014 L
.3876 .29095 L
.38875 .28677 L
.38997 .28284 L
.39113 .27997 L
.39218 .27835 L
.39349 .27793 L
.39473 .27941 L
.39543 .28109 L
.39607 .2832 L
.39752 .28984 L
.3987 .29703 L
.39999 .30647 L
.40259 .32852 L
.40529 .35129 L
.40662 .36065 L
.40785 .36744 L
.40854 .3703 L
.40926 .37251 L
.40999 .37383 L
.4108 .37419 L
.41146 .37361 L
Mistroke
.41218 .37208 L
.41348 .36702 L
.41478 .35922 L
.4162 .34808 L
.41878 .32326 L
.42131 .29801 L
.42363 .27863 L
.42487 .27108 L
.42618 .2657 L
.4275 .26318 L
.42824 .26303 L
.42894 .2637 L
.4302 .26671 L
.43135 .2712 L
.43394 .28503 L
.43624 .29779 L
.43754 .30351 L
.43874 .30711 L
.43979 .30858 L
.44094 .30819 L
.44215 .30542 L
.44329 .30069 L
.44451 .29354 L
.44585 .28379 L
.44855 .26158 L
.44976 .25241 L
.45105 .24452 L
.45227 .2398 L
.45337 .23848 L
.45405 .2393 L
.45477 .24162 L
.45606 .24979 L
.45677 .25661 L
.45744 .26446 L
.45897 .28743 L
.46152 .33894 L
.46425 .40383 L
.4668 .46002 L
.46753 .47349 L
.46822 .48457 L
.4695 .50022 L
.47072 .50797 L
.47184 .50824 L
.47307 .50044 L
.47437 .48277 L
.47569 .45528 L
.4771 .41603 L
.47964 .32527 L
.4824 .21247 L
.48386 .15488 L
Mistroke
.48541 .1004 L
.48674 .06199 L
.48745 .04563 L
.48822 .03157 L
.48892 .02218 L
.48956 .01665 L
.49081 .01472 L
.492 .02398 L
.4933 .04626 L
.49396 .0621 L
.49466 .08216 L
.49593 .12571 L
.50058 .33684 L
.50313 .45368 L
.50551 .54035 L
.50673 .57193 L
.50805 .59404 L
.5088 .60084 L
.50951 .60332 L
.51015 .60226 L
.51084 .59763 L
.51208 .58078 L
.5134 .55175 L
.51464 .51539 L
.51576 .4765 L
.52111 .26352 L
.52257 .212 L
.52411 .16708 L
.52543 .13813 L
.52618 .12595 L
.52687 .11748 L
.52752 .11209 L
.52822 .10896 L
.5295 .11028 L
.53075 .11964 L
.53189 .13447 L
.53313 .15601 L
.5345 .18466 L
.53726 .24998 L
.53969 .30464 L
.54103 .33 L
.54231 .34965 L
.54349 .36345 L
.54477 .37348 L
.54594 .37808 L
.54703 .37879 L
.54832 .37571 L
.54896 .37281 L
.54967 .36875 L
.55211 .35043 L
Mistroke
.55476 .32898 L
.55624 .31921 L
.55695 .31556 L
.5576 .31284 L
.55886 .30948 L
.55953 .30877 L
.56024 .30882 L
.56143 .31067 L
.56274 .31497 L
.56394 .32048 L
.56522 .32751 L
.56755 .34075 L
.56864 .34616 L
.56981 .3507 L
.57109 .35373 L
.57228 .35435 L
.57292 .35372 L
.57362 .35225 L
.57489 .34751 L
.57612 .34044 L
.57726 .33204 L
.58191 .28718 L
.58394 .26813 L
.58501 .25964 L
.58616 .25229 L
.5874 .24662 L
.58855 .24376 L
.58975 .24332 L
.59083 .24511 L
.59207 .24958 L
.59277 .25313 L
.59341 .25697 L
.59585 .27531 L
.59811 .29504 L
.60054 .31495 L
.60172 .32305 L
.60283 .32939 L
.60383 .33383 L
.60492 .33721 L
.60612 .33921 L
.60741 .33938 L
.6085 .3381 L
.60971 .33544 L
.61101 .33144 L
.61242 .32637 L
.61496 .31717 L
.61625 .31335 L
.61699 .31161 L
.61765 .31035 L
.61837 .3094 L
Mistroke
.61912 .30882 L
.61983 .3087 L
.62049 .30896 L
.62176 .31038 L
.62292 .31265 L
.6242 .31596 L
.62556 .32003 L
.62677 .32382 L
.62809 .32769 L
.62926 .33053 L
.6305 .33267 L
.63161 .3336 L
.63284 .33337 L
.63396 .33193 L
.63501 .3295 L
.63625 .32537 L
.63756 .31969 L
.6399 .30713 L
.64244 .29225 L
.64384 .28469 L
.64517 .27857 L
.6463 .2744 L
.64754 .27122 L
.64866 .2697 L
.64969 .2695 L
.65067 .27036 L
.65174 .27244 L
.65286 .27576 L
.65391 .27979 L
.65888 .30514 L
.6613 .31667 L
.66235 .3207 L
.66349 .32418 L
.66473 .32681 L
.66589 .32816 L
.66654 .32845 L
.66723 .32841 L
.66846 .32752 L
.6691 .32669 L
.66979 .32557 L
.67104 .32306 L
.67388 .31634 L
.67515 .31354 L
.67582 .31224 L
.67653 .31105 L
.67784 .30946 L
.67904 .30876 L
.6802 .30882 L
.68128 .30951 L
.68247 .31091 L
Mistroke
.68375 .31304 L
.68619 .31807 L
.68846 .32259 L
.6896 .32432 L
.69083 .32552 L
.69153 .32583 L
.69218 .32586 L
.69342 .32518 L
.69449 .32376 L
.69563 .32145 L
.6966 .31886 L
.69767 .31545 L
.70228 .29714 L
.70477 .28807 L
.70546 .28607 L
.70619 .28425 L
.7075 .28187 L
.70814 .28116 L
.70883 .28074 L
.71009 .28093 L
.71132 .28227 L
.71245 .28442 L
.71356 .28732 L
.7146 .2906 L
.71697 .29932 L
.71925 .30811 L
.72174 .31626 L
.72242 .31804 L
.72315 .31967 L
.72445 .32184 L
.72567 .32297 L
.72637 .32322 L
.72702 .32322 L
.72823 .32264 L
.72934 .32154 L
.73061 .31976 L
.73183 .31773 L
.73433 .31335 L
.7357 .31128 L
.73699 .30981 L
.73773 .30923 L
.73853 .30884 L
.73925 .3087 L
.73992 .30876 L
.74124 .30939 L
.7419 .30995 L
.74263 .31073 L
.74514 .31434 L
.74646 .31649 L
.74787 .31865 L
Mistroke
.74909 .3202 L
.74979 .32089 L
.75044 .32137 L
.75159 .32179 L
.75283 .32154 L
.75396 .32065 L
.75519 .31895 L
.75648 .3164 L
.75768 .31343 L
.76213 .29974 L
.76344 .29584 L
.76485 .29217 L
.7655 .29075 L
.76619 .28947 L
.76742 .28778 L
.76861 .28699 L
.76972 .287 L
.77093 .28784 L
.77224 .28967 L
.77295 .29103 L
.77362 .2925 L
.77513 .29641 L
.77788 .30462 L
.78057 .31226 L
.78185 .31523 L
.78304 .31743 L
.78422 .319 L
.78551 .31998 L
.78678 .3202 L
.78748 .32003 L
.78813 .31971 L
.78883 .31919 L
.78948 .31859 L
.79095 .31685 L
.79363 .31313 L
.79473 .31169 L
.79592 .31037 L
.79723 .30932 L
.79846 .30878 L
.79976 .30875 L
.80042 .30893 L
.80114 .30929 L
.80241 .31027 L
.80359 .31151 L
.80581 .31433 L
.80698 .31584 L
.80822 .31728 L
.80931 .31829 L
.8105 .31903 L
.81158 .31928 L
Mistroke
.81259 .31911 L
.81386 .31831 L
.81502 .31701 L
.81566 .31607 L
.81636 .31487 L
.81763 .31229 L
.8222 .30081 L
.82453 .29553 L
.82584 .29327 L
.82704 .29181 L
.82809 .29107 L
.82925 .29088 L
.83046 .29137 L
.83158 .29245 L
.83223 .29331 L
.83293 .29444 L
.8342 .2969 L
.83659 .3025 L
.83914 .30879 L
.84049 .3118 L
.84194 .31452 L
.84267 .31563 L
.84337 .31651 L
.84468 .31767 L
.8459 .31818 L
.8466 .31821 L
.84724 .3181 L
.84798 .31781 L
.84867 .31739 L
.84996 .31631 L
.85286 .31308 L
.85521 .31056 L
.8564 .30961 L
.8577 .30894 L
.85838 .30875 L
.85911 .30869 L
.86043 .30895 L
.86174 .30964 L
.86294 .31059 L
.86542 .31315 L
.86774 .3156 L
.86891 .31657 L
.87017 .31729 L
.87085 .31751 L
.87157 .31758 L
.87285 .31728 L
.87395 .31658 L
.87512 .31538 L
.87623 .31385 L
.87723 .31216 L
Mistroke
.88202 .30209 L
.88451 .29734 L
.88577 .29555 L
.88648 .29477 L
.88715 .29422 L
.88788 .29381 L
.88854 .29363 L
.88931 .29365 L
.89004 .29389 L
.89131 .29483 L
.89204 .29562 L
.8927 .29652 L
.89796 .30669 L
.90026 .31122 L
.90157 .31334 L
.90279 .31491 L
.90398 .316 L
.90526 .31667 L
.90597 .3168 L
.90663 .3168 L
.90788 .31645 L
.90854 .3161 L
.90925 .31563 L
.91052 .31458 L
.91338 .31177 L
.91456 .3107 L
.91583 .30973 L
.91703 .30909 L
.91812 .30876 L
.91934 .30872 L
.92003 .30885 L
.92067 .30906 L
.92197 .30974 L
.92269 .31025 L
.92335 .31078 L
.92559 .31283 L
.92795 .31492 L
.92919 .31573 L
.92989 .31605 L
.93055 .31625 L
.9317 .31633 L
.93293 .31599 L
.9341 .31526 L
.93536 .31402 L
.93655 .31246 L
.93766 .31074 L
.94197 .30279 L
.94393 .29948 L
.94501 .29801 L
.946 .29692 L
Mistroke
.94709 .2961 L
.94827 .29565 L
.94928 .29568 L
.95035 .2961 L
.95137 .29686 L
.95247 .29804 L
.95448 .30097 L
.95823 .30773 L
.96057 .3116 L
.96172 .31312 L
.96277 .31424 L
.96387 .31509 L
.96505 .31563 L
.96634 .31577 L
.96757 .31551 L
.96861 .31503 L
.96971 .31432 L
.97169 .3127 L
.97619 .30933 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo002oOol5003/Ool00<5oo`03001oogoo0>aoo`00`Goo00<007ooOol0
1goo0`00hWoo002eOol70005Ool00`00Oomoo`07Ool00`00Oomoo`3ROol00<5oo`03001oogoo00Mo
o`03001oogoo0>9oo`00`Goo00<007ooOol01goo00<007ooOol0hWoo0031Ool00`00Oomoo`07Ool0
0`00Oomoo`3ROol00;moo`<000Uoo`03001oogoo0>9oo`00`7oo0P001Goo00D007ooOomoo`000>Ao
o`00agoo00D007ooOomoo`000>Aoo`00agoo0P000Woo00<007ooOol0hWoo0037Ool20002Ool00`00
Oomoo`3ROol00<Moo`80009oo`03001oogoo0>9oo`00aWoo00<007oo00000Woo00<007ooOol0hWoo
0036Ool00`00Ool00002Ool2003SOol00<Ioo`03001oo`00009oo`03001oogoo0>9oo`00aWoo00<0
07oo00000Woo00<007ooOol0hWoo0036Ool00`00Ool00002Ool00`00Oomoo`3ROol00<Ioo`03001o
o`00009oo`03001oogoo0>9oo`00aWoo00<007oo00000Woo00<007ooOol0hWoo0036Ool00`00Ool0
0002Ool00`00Oomoo`3ROol00<Ioo`03001oo`00009oo`03001oogoo0>9oo`00aWoo00<007oo0000
0Woo00<007ooOol0hWoo0036Ool01P00Oomoo`00Ool00>Aoo`00aWoo00H007ooOol007oo003TOol0
0<Ioo`05001oogoo001oo`02003SOol00<Ioo`06001oogoo001oo`00i7oo0036Ool01P00Oomoo`00
Ool00>Aoo`00aWoo00H007ooOol007oo003TOol00<Ioo`06001oogoo001oo`00i7oo0036Ool01P00
Oomoo`00Ool00>Aoo`00aWoo00H007ooOol007oo003TOol00<Ioo`06001oogoo001oo`00i7oo0035
Ool01`00Oomoogoo001oo`000>Aoo`00aGoo00L007ooOomoo`00Ool0003TOol00<Eoo`07001oogoo
Ool007oo0000i7oo0035Ool01`00Oomoogoo001oo`000>Aoo`00aGoo00H007ooOomoo`00Ool2003S
Ool00<Eoo`07001oogooOol007oo0000i7oo0035Ool01`00Oomoogoo001oo`000>Aoo`00aGoo00L0
07ooOomoo`00Ool0003TOol00<Eoo`07001oogooOol007oo0000i7oo0035Ool01`00Oomoogoo001o
o`000>Aoo`00aGoo00L007ooOomoo`00Ool00009Ool2003IOol00<Eoo`07001oogooOol007oo0000
2Goo0P00fGoo0035Ool01`00Oomoogoo001oo`0000Uoo`800=Uoo`00aGoo00L007ooOomoo`00Ool0
0009Ool2003IOol00<Eoo`07001oogooOol007oo00002Goo0P00fGoo0035Ool01P00Oomoogoo001o
o`8000Qoo`800=Uoo`00aGoo00L007ooOomoo`00Ool00009Ool2003IOol00<Eoo`07001oogooOol0
07oo00002Goo00<007oo0000f7oo0035Ool01`00Oomoogoo001oo`0000Uoo`03001oo`000=Qoo`00
aGoo00L007ooOomoo`00Ool00008Ool01000Oomoo`00f7oo0035Ool01`00Oomoogoo001oo`0000Qo
o`04001oogoo003HOol00<Eoo`07001oogooOol007oo000027oo00@007ooOol00=Qoo`00aGoo00L0
07ooOomoo`00Ool00008Ool01000Oomoo`00f7oo0035Ool01`00Oomoogoo001oo`0000Qoo`04001o
ogoo003HOol00:ioo`8000Moo`<000Eoo`@0009oo`07001oogooOol007oo000027oo00@007ooOol0
0=Qoo`00[Goo00@007ooOol000Ioo`<000Aoo`03001oogoo009oo`03001oo`0000=oo`03001oo`00
00Qoo`04001oogoo003HOol00:aoo`03001oogoo009oo`03001oogoo00=oo`<000Uoo`03001oo`00
00=oo`03001oo`0000Qoo`04001oogoo003HOol00:=oo`L0009oo`03001oogoo009oo`03001oogoo
00moo`03001oo`0000=oo`03001oo`00008000Ioo`04001oogoo003HOol00:aoo`03001oogoo009o
o`03001oogoo00Yoo`03001oogoo009oo`03001oo`0000=oo`03001oo`0000Qoo`04001oogoo003H
Ool00:aoo`03001oogoo009oo`03001oogoo00Yoo`D0009oo`07001oogooOol007oo000027oo00@0
07ooOol00=Qoo`00[7oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol017oo00L007ooOomo
o`00Ool00008Ool01000Oomoo`00f7oo002]Ool01000Oomoo`003Goo00<007ooOol017oo00L007oo
Oomoo`00Ool00008Ool01000Oomoo`00f7oo002^Ool2000>Ool50002Ool01`00Oomoogoo001oo`00
00Qoo`04001oogoo003HOol00<Eoo`07001oogooOol007oo000027oo00D007ooOomoo`000=Moo`00
aGoo00L007ooOomoo`00Ool00008Ool01@00Oomoogoo0000egoo0035Ool01`00Oomoogoo001oo`00
00Qoo`05001oogooOol0003GOol00<Eoo`07001oogooOol007oo000027oo00D007ooOomoo`000=Mo
o`00aGoo00<007ooOol00Woo0P0027oo00D007ooOomoo`000=Moo`00a7oo00<007ooOol00goo0`00
1goo00D007ooOomoo`000=Moo`00a7oo00<007ooOol00goo0P0027oo00D007ooOomoo`000=Moo`00
a7oo00<007ooOol00goo0P0027oo00D007ooOomoo`000=Moo`00a7oo00<007ooOol00goo0P001goo
00<007ooOol00Woo00<007ooOol0eGoo0034Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`02Ool0
0`00Oomoo`3EOol00<Aoo`03001oogoo00=oo`8000Moo`03001oogoo009oo`03001oogoo0=Eoo`00
a7oo00<007ooOol00goo0P001goo00<007ooOol00Woo00<007ooOol0eGoo0034Ool00`00Oomoo`03
Ool20007Ool00`00Oomoo`02Ool00`00Oomoo`3EOol00<Aoo`03001oogoo00=oo`8000Moo`03001o
ogoo009oo`03001oogoo0=Eoo`00a7oo00<007ooOol00goo0P001goo00<007ooOol00Woo00<007oo
Ool0eGoo0034Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`02Ool00`00Oomoo`3EOol00<Aoo`03
001oogoo00=oo`8000Moo`03001oogoo009oo`03001oogoo0=Eoo`00a7oo00<007ooOol00goo0`00
1Woo00<007ooOol00Woo00<007ooOol0eGoo0034Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`03
Ool00`00Oomoo`3DOol00<Aoo`03001oogoo00=oo`8000Moo`03001oogoo00=oo`03001oogoo0=Ao
o`00a7oo00<007ooOol00goo0P001goo00<007ooOol00goo00<007ooOol0e7oo0034Ool00`00Oomo
o`03Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`3DOol00<Aoo`03001oogoo00=oo`8000Moo`03
001oogoo00=oo`03001oogoo0=Aoo`00a7oo00<007ooOol00goo0P001goo00<007ooOol00goo00<0
07ooOol0e7oo0034Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`3DOol00;Uo
o`8000Uoo`03001oogoo00=oo`8000Moo`03001oogoo00=oo`03001oogoo0=Aoo`00^Goo0P002Goo
00<007ooOol00goo0P001goo00<007ooOol00goo00<007ooOol0e7oo002iOol20009Ool00`00Oomo
o`03Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`31Ool00;Uoo`8000Uoo`03
001oogoo00=oo`<000Ioo`03001oogoo00=oo`03001oogoo00moo`03001oo`000<9oo`00^7oo00<0
07oo00002Goo00<007ooOol00goo0P001goo00<007ooOol00goo00<007ooOol03goo00<007oo0000
`Woo002hOol00`00Ool00009Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`03Ool00`00Oomoo`0?
Ool00`00Ool00032Ool00;Qoo`04001oogoo0008Ool00`00Oomoo`03Ool20007Ool00`00Oomoo`03
Ool00`00Oomoo`0?Ool00`00Ool00032Ool00;Qoo`04001oogoo0008Ool00`00Oomoo`03Ool20007
Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool01000Oomoo`00`Goo002hOol01000Oomoo`0027oo00<0
07ooOol00goo0P001goo00<007ooOol00goo00<007ooOol03goo00@007ooOol00<5oo`00/7oo00<0
07ooOol01Goo00@007ooOol000Qoo`03001oogoo00=oo`8000Moo`03001oogoo00=oo`03001oogoo
00moo`04001oogoo0031Ool00:moo`8000Moo`04001oogoo0008Ool00`00Oomoo`03Ool20007Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool01@00Oomoogoo0000`Goo002_Ool00`00Ool00006Ool01000
Oomoo`0027oo00<007ooOol00goo0P001goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol0_Woo000lOol30005Ool2000jOol60005Ool2000ROol00`00Ool00006Ool01000
Oomoo`001goo00<007ooOol017oo0P001goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol047oo0P001Woo1P001Goo0P00?Goo0`001Goo0P00DWoo000mOol00`00Oomoo`03
Ool01000Oomoo`00>Woo00D007ooOomoo`0000Aoo`04001oogoo000QOol00`00Ool00006Ool01000
Oomoo`001goo00<007ooOol017oo0P001goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol047oo0P001goo00D007ooOomoo`0000Aoo`04001oogoo000mOol00`00Oomoo`03
Ool01000Oomoo`00DGoo000iOol60003Ool00`00Oomoo`02Ool00`00Oomoo`0hOol00`00Oomoo`04
Ool00`00Oomoo`02Ool00`00Oomoo`0MOol01000Oomoo`001Goo00D007ooOomoo`0000Moo`03001o
ogoo00Aoo`8000Moo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00mo
o`04001oogoo0007Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0fOol60003Ool00`00
Oomoo`02Ool00`00Oomoo`1>Ool0031oo`L0009oo`05001oogooOol00004Ool00`00Oomoo`02Ool0
0`00Oomoo`0]Ool70005Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0BOol20009Ool0
1000Oomoo`001Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo0`001Woo00<007oo
Ool017oo00<007ooOol037oo00<007ooOol00goo00<007ooOol03goo00@007ooOol000Qoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo03Ioo`05001oogooOol00004Ool00`00Oomoo`02Ool0
0`00Oomoo`1>Ool003Yoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`0jOol00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Ool00009Ool01@00Oomoogoo000017oo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol017oo0P001goo00<007ooOol017oo00<007ooOol0
37oo00<007ooOol00goo00<007ooOol03goo00@007ooOol000Uoo`03001oogoo009oo`03001oogoo
009oo`8003Qoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`1>Ool003]oo`03001oo`00
00Aoo`03001oogoo009oo`03001oogoo03]oo`05001oogooOol00004Ool00`00Oomoo`08Ool20007
Ool00`00Ool00009Ool01@00Oomoogoo000017oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool017oo0P001goo00<007ooOol017oo00<007ooOol037oo00<007ooOol00goo00<007ooOol03goo
00@007ooOol000Yoo`05001oogooOol00004Ool00`00Ool0000hOol00`00Ool00004Ool00`00Oomo
o`02Ool00`00Oomoo`1>Ool003]oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo03]oo`05
001oogooOol00004Ool00`00Oomoo`08Ool20006Ool01000Oomoo`002Goo00D007ooOomoo`0000Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Ao
o`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00moo`04001oogoo000:Ool01@00Oomoogoo
000017oo00@007ooOol001=oo`80029oo`03001oo`0000Aoo`03001oogoo009oo`03001oogoo04io
o`00?7oo0P001Goo00@007ooOol003Uoo`03001oogoo009oo`03001oogoo009oo`04001oo`00000;
Ool00`00Ool00005Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool037oo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol00Woo00@007ooOol000=oo`03001oogoo011oo`<002=oo`8000Eoo`04001o
ogoo001AOol003eoo`03001oogoo00Aoo`8003]oo`@000Ioo`<000Yoo`04001oogoo0005Ool01@00
Oomoogoo00001goo00<007ooOol00Woo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo
00ioo`03001oogoo009oo`03001oogoo00=oo`@000Ioo`<000=oo`03001oogoo011oo`04001oogoo
000COol3000=Ool00`00Oomoo`04Ool2001BOol006eoo`03001oogoo00Ioo`8000Yoo`03001oo`00
00Ioo`04001oogoo0009Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Moo`03001oogoo00=o
o`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01000Oomoo`004Woo00@007ooOol001=oo`<0059oo`00
EWoo0P001goo0`002Woo0`001Woo00@007oo000000Uoo`04001oogoo0005Ool01000Oomoo`002Goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo
0005Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Goo00@0
07ooOol001=oo`@003]oo`00<goo0P002Woo0`001Woo0`002Woo10001Goo00@007ooOol000Uoo`80
0003Ool007oo00Aoo`80009oo`03001oogoo00Moo`04001oogoo0004Ool01@00Oomoogoo000027oo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo
0005Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`0<Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomo
o`03Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool01000Oomoo`004goo00@007ooOol001moo`80009oo`03001oogoo01Eoo`006goo10002Goo
10001Goo0P0000=oo`0000002Goo00@007oo000000Eoo`04001oogoo0009Ool01@00Oomoogoo0000
17oo00D007ooOomoo`0000Qoo`05001oogooOol00004Ool01@00Oomoogoo000027oo00D007ooOomo
o`0000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Ool00005Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0=Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
1@00Oomoogoo00007Woo00<007ooOol00P0000=oo`00Ool05Goo000JOol20003Ool00`00Oomoo`06
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Uoo`05001oogooOol00003Ool01@00Oomoogoo
000027oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Ioo`03001oogoo009oo`04
001oogoo0005Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`001Goo00<007ooOol01Goo
00<007ooOol00goo00@007ooOol000Eoo`03001oogoo00Aoo`03001oogoo00Aoo`8000Ioo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00aoo`03001o
ogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001o
ogoo00aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo01]oo`04001oogoo0003Ool00`00
Oomoo`0COol0011oool007L000eoo`05001oogooOol00002Ool00`00Oomoo`0COol001Uoo`03001o
ogoo00Aoo`03001oogoo00Aoo`05001oogooOol0000:Ool00`00Oomoo`04Ool2000=Ool00`00Ool0
0004Ool00`00Oomoo`0:Ool00`00Ool00007Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool01@00Oomoogoo00002goo00<007ooOol00goo00<007ooOol03Goo0P001Goo00<007ooOol0
2Goo00@007ooOol000Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`04001oogoo
0003Ool20005Ool00`00Oomoo`03Ool00`00Ool00006Ool20006Ool20005Ool00`00Oomoo`04Ool0
0`00Ool00002Ool01000Oomoo`001goo00<007ooOol00goo0`001Woo00<007ooOol01Goo0P000goo
10001Goo00<007ooOol00Woo00<007oo00001Goo0P0000=oo`00Ool017oo0P001Woo00<007ooOol0
0goo100000Eoo`00Oomoo`0000Qoo`03001oogoo009oo`8001Eoo`05001oogooOol00002Ool00`00
Oomoo`0COol001Uoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Qo
o`03001oogoo00Aoo`03001oogoo00eoo`8000Aoo`03001oogoo00Yoo`04001oogoo0006Ool00`00
Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo00002goo00<007ooOol00goo
00<007ooOol03Goo0P001Goo00<007ooOol02Goo00@007ooOol000Ioo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo00Aoo`04001oogoo0002Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00
Ool00005Ool01000Oomoo`001Goo0P001Woo00<007ooOol00Woo00@007ooOol0009oo`04001oogoo
0008Ool02@00Oomoogoo001oo`00Ool00004Ool00`00Oomoo`06Ool20002Ool00`00Oomoo`02Ool0
1@00Oomoogoo00001Goo00@007ooOol000=oo`8000=oo`04001oogooOol30007Ool01@00Oomoogoo
000017oo0P0000=oo`00000027oo0P0000Eoo`00001oo`0001Ioo`03001oogoo00=oo`03001oogoo
01=oo`008Goo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Goo00<0
07ooOol00goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo00D0
07ooOomoo`0000]oo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ao
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00=o
o`03001oo`0000Eoo`03001oogoo00Eoo`03001oogoo00=oo`04001oogoo0004Ool00`00Oomoo`06
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOol000Qoo`05001oogooOol00004Ool01@00
Oomoogoo000027oo00@007ooOol000Eoo`03001oogoo008000Qoo`800003Ool007oo00Eoo`@00003
Ool007oo00Ioo`@000Ioo`<000Yoo`<001Yoo`05001oogooOol0000FOol0029oo`04001oogoo000B
Ool00`00Oomoo`02000AOol01@00Oomoogoo00004Goo00<007ooOol00Woo00<007ooOol03Goo00<0
07ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Goo00<007ooOol017oo00<0
07ooOol037oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol017oo00<0
07ooOol00goo00<007oo00001Goo00<007ooOol01Goo00<007ooOol00goo00@007ooOol000Aoo`03
001oogoo00Ioo`03001oogoo009oo`05001oogooOol00003Ool00`00Oomoo`07Ool01000Oomoo`00
1Goo00@007ooOol000Uoo`@000Ioo`<000]oo`8000Moo`8005Uoo`008Woo0`004goo0P0000=oo`00
Ool04Goo00D007ooOomoo`00015oo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00aoo`03
001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00=oo`04
001oogoo0004Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007ooOol0
1Woo00D007ooOomoo`0000Aoo`05001oogooOol0000:Ool30006Ool3000:Ool2001iOol003Uoo`<0
01=oo`03001oo`0001=oo`04001oogoo000AOol00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomo
o`05Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`03Ool01000Oomoo`0017oo00<007oo
Ool01Woo00D007ooOomoo`0000Aoo`05001oogooOol00009Ool01000Oomoo`001Goo0`002goo0P00
Sgoo001?Ool3000COol01000Oomoo`004Goo00D007ooOomoo`00019oo`05001oogooOol0000@Ool0
0`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Woo00D007ooOomo
o`0000Eoo`04001oogoo0009Ool00`00Ool00007Ool2002LOol006Ioo`8001=oo`04001oogoo000B
Ool01@00Oomoogoo000047oo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Ioo`05001oogooOol00005Ool00`00Ool0000;Ool00`00Oomoo`2TOol007]oo`04001o
ogoo000BOol01@00Oomoogoo000047oo00<007ooOol017oo00<007ooOol037oo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`03001oogoo00Ioo`04001oogoo0006Ool3002bOol007aoo`8001=oo`05001oogooOol0000@
Ool00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00<007oo
00001goo00<007ooOol0/Goo001lOol2000COol01@00Oomoogoo000047oo00<007ooOol00goo00<0
07ooOol03Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Yoo`800;aoo`00TWoo00@007ooOol0011oo`03
001oogoo00=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Eoo`8000Eoo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo009oo`04001oogoo000:Ool2002lOol0099oo`03001oo`00
019oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Ioo`04001oogoo0005Ool01000Oomoo`00b7oo002BOol00`00Ool0000BOol0
0`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool01000Oomoo`001Goo00@007ooOol00<Qoo`00TWoo0`004Woo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo00<007ooOol01Woo
00@007ooOol000Eoo`04001oogoo0038Ool00:Moo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`04001oogoo0006Ool00`00
Ool00038Ool00:Moo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00Eo
o`03001oogoo00Aoo`03001oogoo00Ioo`04001oogoo0006Ool20039Ool00:Moo`05001oogooOol0
000@Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool01000Oomo
o`00dGoo002XOol01000Oomoo`0047oo00<007ooOol017oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol01Woo00@007ooOol00=5oo`00Z7oo00@007ooOol0011oo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oo`000=9oo`00Z7oo00@007ooOol0011o
o`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oo`000=9o
o`00Z7oo00@007ooOol0011oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oo`000=9oo`00ZGoo00<007oo000047oo00<007ooOol017oo00<007ooOol01Goo
0P001Goo00<007ooOol01Woo00<007oo0000dWoo002YOol2000AOol00`00Oomoo`03Ool00`00Oomo
o`06Ool00`00Oomoo`04Ool00`00Oomoo`07Ool2003BOol00:Uoo`80019oo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo00Aoo`03001oogoo00Moo`800=9oo`00_Goo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol017oo00<007ooOol01goo0P00dWoo002mOol00`00Oomoo`02Ool00`00
Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`3AOol00;eoo`03001oogoo009o
o`03001oogoo00Ioo`03001oogoo00Aoo`03001oogoo0=]oo`00_Goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol017oo00<007ooOol0fgoo002mOol00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`04Ool00`00Oomoo`3KOol00;eoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo
00Aoo`03001oogoo0=]oo`00_Goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol0fgoo002mOol00`00Oomoo`02Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`3KOol00;eo
o`03001oogoo009oo`03001oogoo00Ioo`8000Eoo`03001oogoo0=]oo`00_Goo00<007ooOol00Woo
00<007ooOol01Woo0P001Goo00<007ooOol0fgoo002mOol00`00Oomoo`02Ool00`00Oomoo`06Ool2
0005Ool00`00Oomoo`3KOol00;eoo`03001oogoo009oo`03001oogoo00Ioo`8000Eoo`03001oogoo
0=]oo`00_Goo00<007ooOol00Woo00<007ooOol01Woo0P001Goo00<007ooOol0fgoo002mOol00`00
Oomoo`02Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`3KOol00;eoo`03001oogoo009oo`03001o
ogoo00Ioo`8000Eoo`03001oogoo0=]oo`00_Goo00<007ooOol00Woo00<007ooOol01Woo0P001Goo
00<007ooOol0fgoo002mOol00`00Oomoo`02Ool00`00Oomoo`06Ool20005Ool00`00Oomoo`3KOol0
0;eoo`03001oogoo009oo`03001oogoo00Ioo`8000Eoo`03001oogoo0=]oo`00_Goo00<007ooOol0
0Woo00<007ooOol01Woo0P0017oo00<007ooOol0g7oo002mOol00`00Oomoo`02Ool00`00Oomoo`06
Ool20004Ool00`00Oomoo`3LOol00;eoo`03001oogoo009oo`03001oogoo00Ioo`8000Aoo`03001o
ogoo0=aoo`00_Woo00D007ooOomoo`0000Qoo`8000Aoo`03001oogoo0=aoo`00_Woo00D007ooOomo
o`0000Qoo`8000Aoo`03001oogoo0=aoo`00_Woo00D007ooOomoo`0000Qoo`8000Aoo`03001oogoo
0=aoo`00_Woo00D007ooOomoo`0000Qoo`8000Aoo`03001oogoo0=aoo`00_Woo00D007ooOomoo`00
00Qoo`8000Aoo`03001oogoo0=aoo`00_Woo00D007ooOomoo`0000Qoo`8000Aoo`03001oogoo0=ao
o`00_Woo00D007ooOomoo`0000Qoo`8000Aoo`03001oogoo0=aoo`00_Woo00D007ooOomoo`0000Qo
o`8000Aoo`03001oogoo0=aoo`00[Woo0P001goo0`0017oo1@0027oo0P0017oo00<007ooOol0g7oo
002]Ool01000Oomoo`001Woo0`0017oo00@007ooOomoo`8000Moo`8000Aoo`03001oogoo0=aoo`00
[7oo00<007ooOol00Woo00<007ooOol00goo0`0017oo00@007ooOomoo`8000Moo`8000Aoo`03001o
ogoo0=aoo`00[7oo00<007ooOol00Woo00<007ooOol02Woo00@007ooOomoo`8000Moo`<000=oo`03
001oogoo0=aoo`00[7oo00<007ooOol00Woo00<007ooOol02Woo00@007ooOomoo`8000Moo`8000Ao
o`03001oogoo0=aoo`00[7oo00<007ooOol00Woo00<007ooOol02Woo1@0027oo0P0017oo00<007oo
Ool0g7oo002/Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool200000goo001oo`08Ool20004Ool00`00
Oomoo`3LOol00:eoo`04001oogoo000=Ool200000goo001oo`08Ool20004Ool00`00Oomoo`3LOol0
0:ioo`8000ioo`D000Qoo`8000Aoo`03001oogoo0=aoo`00_goo00<007oo00002Goo0P0017oo00<0
07ooOol0g7oo002oOol00`00Ool00009Ool20004Ool00`00Oomoo`3LOol00;moo`03001oo`0000Uo
o`8000Aoo`03001oogoo0=aoo`00_goo00<007oo00002Goo0P0017oo00<007ooOol0g7oo002oOol0
0`00Ool00009Ool20004Ool00`00Oomoo`3LOol00;moo`03001oo`0000Uoo`8000Aoo`03001oogoo
0=aoo`00_goo00<007oo00002Goo0P0017oo00<007ooOol0g7oo002oOol00`00Ool00009Ool00`00
Ool00002Ool00`00Oomoo`3MOol00;moo`03001oo`0000Uoo`03001oo`00009oo`03001oogoo0=eo
o`00_goo00<007oo00002Goo00<007oo00000Woo00<007ooOol0gGoo0030Ool00`00Oomoo`08Ool0
0`00Ool00002Ool00`00Oomoo`3MOol00<1oo`03001oogoo00Qoo`03001oo`00009oo`03001oogoo
0=eoo`00bgoo00<007oo00000Woo00<007ooOol0gGoo003;Ool00`00Ool00002Ool00`00Oomoo`3M
Ool00<]oo`03001oo`00009oo`03001oogoo0=eoo`00bgoo00<007oo00000Woo00<007ooOol0gGoo
003;Ool00`00Ool00002Ool00`00Oomoo`3MOol00<]oo`<0009oo`03001oogoo0=eoo`00bgoo00<0
07oo00000Woo00<007ooOol0gGoo003;Ool00`00Ool00002Ool00`00Oomoo`3MOol00<]oo`03001o
o`00009oo`03001oogoo0=eoo`00bgoo00<007oo00000Woo00<007ooOol0gGoo003;Ool00`00Ool0
0002Ool00`00Oomoo`3MOol00<]oo`03001oo`00009oo`03001oogoo0=eoo`00bgoo00<007oo0000
0Woo00<007ooOol0gGoo003;Ool00`00Ool00002Ool00`00Oomoo`3MOol00<]oo`03001oo`00009o
o`03001oogoo0=eoo`00bgoo00<007oo00000Woo00<007ooOol0gGoo003;Ool30002Ool00`00Oomo
o`3MOol00<]oo`03001oo`00009oo`03001oogoo0=eoo`00bgoo00<007oo00000Woo00<007ooOol0
gGoo003;Ool00`00Ool00002Ool00`00Oomoo`3MOol00<]oo`03001oo`00009oo`03001oogoo0=eo
o`00bgoo00D007oo001oo`000>1oo`00bgoo00D007oo001oo`000>1oo`00bgoo00D007oo001oo`00
0>1oo`00bgoo00D007oo001oo`000>1oo`00bgoo00D007oo001oo`000>1oo`00bgoo00D007oo001o
o`000>1oo`00bgoo00D007oo001oo`000>1oo`00bgoo0P0000=oo`000000h7oo003;Ool00`00Oomo
o`02003POol00<]oo`03001oogoo00800>1oo`00bgoo00<007ooOol00P00h7oo003;Ool00`00Oomo
o`02003POol00<]oo`03001oogoo00800>1oo`00bgoo00<007ooOol00P00h7oo003;Ool00`00Oomo
o`3ROol00<]oo`03001oogoo0>9oo`00_goo1@001goo00<007ooOol0hWoo0031Ool00`00Oomoo`07
Ool00`00Oomoo`3ROol00<5oo`03001oogoo00Moo`<00>9oo`00`Goo00<007ooOol01goo00<007oo
Ool0hWoo0031Ool00`00Oomoo`3/Ool00<5oo`03001oogoo0>aoo`00`Goo00<007ooOol0k7oo002o
Ool3003^Ool00<1oo`800>ioo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00_Goo0P004Woo00<007ooOol02goo00<007ooOol01goo0P00aGoo002mOol00`00Oomo
o`0@Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`33Ool00;eoo`03001oogoo011oo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo0<=oo`00Z7oo1`0000Eoo`00000007oo00800003
Ool0000000Aoo`03001oogoo00=oo`H000Ioo`03001oogoo00Aoo`80009oo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo0<=oo`00Zgoo00<007ooOol00goo00@007ooOol0009oo`03001oogoo
00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo00800003Ool007oo
00Aoo`03001oogoo00Ioo`03001oogoo0<=oo`00Zgoo00<007ooOol00goo00@007ooOol0009oo`03
001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo0003Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`33Ool00:]oo`03001oogoo00=oo`04001oogoo
0002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`03Ool01@00Oomo
ogoo00000Woo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0`goo002[Ool00`00Oomoo`03
Ool01000Oomoo`000Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol0
0goo00D007ooOomoo`00009oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0<=oo`00Zgoo
00<007ooOol00goo00@007ooOol0009oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Mo
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo0<=o
o`00Zgoo00<007ooOol00Woo100000=oo`0000001Woo00<007ooOol00goo1P001goo00<007ooOol0
17oo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo0<=oo`00Zgoo00<007ooOol03goo
00<007ooOol01Goo00<007ooOol027oo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0`goo
002XOol7000>Ool20006Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool20035Ool0
0<Ioo`<00>Moo`00a7oo00@007oo00000>Qoo`00aGoo00@007ooOol00>Moo`00ogoo/Goo003oOona
Ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-57, -1, 0, 0}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "The real part of the transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  " is an even function of \[Omega], and the imaginary part an odd function. \
This follows from the fact that our function",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(f(t)\)\)\)]],
  " was real. In general, for real ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(f(t)\)\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\(-\[Omega]\)) = \
\(\(\(f\&~\)(\[Omega])\)\^*\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.7)"],

Cell[TextData[{
  "Also note that the Fourier transform has nonnegligible high-frequency \
components. This is expected, because the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " has sharp jumps that require high-frequency Fourier modes."
}], "Text"],

Cell[TextData[{
  "\t However, the medium carrying the signal is often such that only \
frequencies within some range \[CapitalDelta]\[Omega] can propagate. This \
range is called the ",
  StyleBox["bandwidth ",
    FontSlant->"Italic"],
  " of the medium. If, in our example, frequencies beyond 10 (in our \
dimensionless units) cannot propagate, then these components are cut out of \
the spectrum  and the inverse transform of this signal is"
}], "Text",
  CellTags->"i:86"],

Cell[BoxData[
    \(\(f\_1[t_]\  = \ 
        Integrate[
            Exp[\(-I\)\ \[Omega]\ t]\ f\&~[\[Omega]], {\[Omega], \(-10\), 
              10}]/\((2\ Pi)\);\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.46"],

Cell[TextData[{
  "This signal looks degraded and broadened due to the loss of the \
high-frequency components, as shown in Cell ",
  ButtonBox["2.47",
    ButtonData:>"Cell 2.47",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[f\_1[t], {t, 0, 3}, AxesLabel \[Rule] {"\<t\>", "\<  \>"}, 
        PlotLabel \[Rule] "\<Signal degraded by finite bandwidth\>"];\)\)], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 2.47"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0709784 0.505665 [
[.18254 .05848 -9 -9 ]
[.18254 .05848 9 0 ]
[.34127 .05848 -3 -9 ]
[.34127 .05848 3 0 ]
[.5 .05848 -9 -9 ]
[.5 .05848 9 0 ]
[.65873 .05848 -3 -9 ]
[.65873 .05848 3 0 ]
[.81746 .05848 -9 -9 ]
[.81746 .05848 9 0 ]
[.97619 .05848 -3 -9 ]
[.97619 .05848 3 0 ]
[1.025 .07098 0 -6 ]
[1.025 .07098 10 6 ]
[.01131 .17211 -18 -4.5 ]
[.01131 .17211 0 4.5 ]
[.01131 .27324 -18 -4.5 ]
[.01131 .27324 0 4.5 ]
[.01131 .37438 -18 -4.5 ]
[.01131 .37438 0 4.5 ]
[.01131 .47551 -18 -4.5 ]
[.01131 .47551 0 4.5 ]
[.01131 .57664 -6 -4.5 ]
[.01131 .57664 0 4.5 ]
[.02381 .64303 -8 0 ]
[.02381 .64303 8 12 ]
[.5 .63053 -107 0 ]
[.5 .63053 107 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .07098 m
.18254 .07723 L
s
[(0.5)] .18254 .05848 0 1 Mshowa
.34127 .07098 m
.34127 .07723 L
s
[(1)] .34127 .05848 0 1 Mshowa
.5 .07098 m
.5 .07723 L
s
[(1.5)] .5 .05848 0 1 Mshowa
.65873 .07098 m
.65873 .07723 L
s
[(2)] .65873 .05848 0 1 Mshowa
.81746 .07098 m
.81746 .07723 L
s
[(2.5)] .81746 .05848 0 1 Mshowa
.97619 .07098 m
.97619 .07723 L
s
[(3)] .97619 .05848 0 1 Mshowa
.125 Mabswid
.05556 .07098 m
.05556 .07473 L
s
.0873 .07098 m
.0873 .07473 L
s
.11905 .07098 m
.11905 .07473 L
s
.15079 .07098 m
.15079 .07473 L
s
.21429 .07098 m
.21429 .07473 L
s
.24603 .07098 m
.24603 .07473 L
s
.27778 .07098 m
.27778 .07473 L
s
.30952 .07098 m
.30952 .07473 L
s
.37302 .07098 m
.37302 .07473 L
s
.40476 .07098 m
.40476 .07473 L
s
.43651 .07098 m
.43651 .07473 L
s
.46825 .07098 m
.46825 .07473 L
s
.53175 .07098 m
.53175 .07473 L
s
.56349 .07098 m
.56349 .07473 L
s
.59524 .07098 m
.59524 .07473 L
s
.62698 .07098 m
.62698 .07473 L
s
.69048 .07098 m
.69048 .07473 L
s
.72222 .07098 m
.72222 .07473 L
s
.75397 .07098 m
.75397 .07473 L
s
.78571 .07098 m
.78571 .07473 L
s
.84921 .07098 m
.84921 .07473 L
s
.88095 .07098 m
.88095 .07473 L
s
.9127 .07098 m
.9127 .07473 L
s
.94444 .07098 m
.94444 .07473 L
s
.25 Mabswid
0 .07098 m
1 .07098 L
s
gsave
1.025 .07098 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .17211 m
.03006 .17211 L
s
[(0.2)] .01131 .17211 1 0 Mshowa
.02381 .27324 m
.03006 .27324 L
s
[(0.4)] .01131 .27324 1 0 Mshowa
.02381 .37438 m
.03006 .37438 L
s
[(0.6)] .01131 .37438 1 0 Mshowa
.02381 .47551 m
.03006 .47551 L
s
[(0.8)] .01131 .47551 1 0 Mshowa
.02381 .57664 m
.03006 .57664 L
s
[(1)] .01131 .57664 1 0 Mshowa
.125 Mabswid
.02381 .09626 m
.02756 .09626 L
s
.02381 .12154 m
.02756 .12154 L
s
.02381 .14683 m
.02756 .14683 L
s
.02381 .19739 m
.02756 .19739 L
s
.02381 .22268 m
.02756 .22268 L
s
.02381 .24796 m
.02756 .24796 L
s
.02381 .29853 m
.02756 .29853 L
s
.02381 .32381 m
.02756 .32381 L
s
.02381 .34909 m
.02756 .34909 L
s
.02381 .39966 m
.02756 .39966 L
s
.02381 .42494 m
.02756 .42494 L
s
.02381 .45023 m
.02756 .45023 L
s
.02381 .50079 m
.02756 .50079 L
s
.02381 .52608 m
.02756 .52608 L
s
.02381 .55136 m
.02756 .55136 L
s
.02381 .0457 m
.02756 .0457 L
s
.02381 .02041 m
.02756 .02041 L
s
.02381 .60193 m
.02756 .60193 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -168 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Signal) show
105.000 13.000 moveto
(degraded) show
159.000 13.000 moveto
(by) show
177.000 13.000 moveto
(finite) show
219.000 13.000 moveto
(bandwidth) show
273.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05326 m
.02846 .05107 L
.03279 .04939 L
.03754 .04798 L
.0402 .04741 L
.04262 .04702 L
.04385 .04688 L
.04516 .04677 L
.04627 .04671 L
.0475 .04668 L
.04882 .04669 L
.04957 .04671 L
.05024 .04675 L
.05156 .04685 L
.05281 .04698 L
.05397 .04714 L
.0552 .04735 L
.05742 .04781 L
.06005 .04853 L
.06244 .04933 L
.06787 .05166 L
.07287 .05439 L
.08414 .06234 L
.10458 .08044 L
.11366 .08847 L
.1234 .09594 L
.12899 .09939 L
.13409 .10185 L
.13654 .10277 L
.13921 .10356 L
.14044 .10384 L
.14173 .10409 L
.14284 .10426 L
.14407 .1044 L
.14528 .10449 L
.14642 .10453 L
.14766 .10451 L
.14835 .10448 L
.14898 .10444 L
.15026 .10431 L
.15098 .10421 L
.15165 .1041 L
.15416 .10354 L
.1563 .10288 L
.15866 .10197 L
.16341 .0995 L
.16861 .09589 L
.17419 .09101 L
.18427 .07987 L
.20402 .05273 L
Mistroke
.21445 .03826 L
.22017 .0311 L
.22555 .02523 L
.23075 .02057 L
.23349 .01861 L
.23637 .01693 L
.23881 .01586 L
.24019 .01541 L
.24148 .01508 L
.24267 .01487 L
.24375 .01476 L
.245 .01472 L
.24618 .01477 L
.24728 .0149 L
.24849 .01514 L
.24976 .0155 L
.25094 .01594 L
.25306 .01698 L
.25535 .01846 L
.25788 .02056 L
.26055 .0233 L
.26531 .0296 L
.27033 .03821 L
.27488 .04781 L
.28509 .07547 L
.30347 .14508 L
.3435 .3498 L
.36186 .44247 L
.37228 .48828 L
.38202 .52483 L
.39243 .55628 L
.40194 .57772 L
.40715 .58656 L
.41209 .59309 L
.41731 .59813 L
.42026 .60018 L
.42299 .6016 L
.42417 .60207 L
.4254 .60249 L
.42647 .60277 L
.42762 .60301 L
.42885 .60319 L
.43 .60329 L
.4307 .60332 L
.43136 .60332 L
.4326 .60327 L
.4337 .60317 L
.43486 .603 L
.43585 .60281 L
.43693 .60256 L
Mistroke
.43936 .60183 L
.44163 .60095 L
.44682 .59837 L
.45156 .59544 L
.46223 .58775 L
.47142 .58105 L
.48123 .57504 L
.48413 .57363 L
.48687 .57249 L
.48953 .57157 L
.49198 .5709 L
.49431 .57042 L
.49548 .57024 L
.49677 .57008 L
.49807 .56998 L
.49879 .56995 L
.49945 .56993 L
.50074 .56993 L
.50195 .56998 L
.5031 .57007 L
.50433 .57021 L
.50549 .57038 L
.50655 .57057 L
.50902 .57115 L
.51162 .57194 L
.51652 .57393 L
.52188 .57675 L
.5403 .58964 L
.5504 .5967 L
.55536 .59955 L
.55993 .60157 L
.56249 .60241 L
.56378 .60273 L
.5652 .60301 L
.56594 .60312 L
.56662 .6032 L
.56741 .60327 L
.56815 .60331 L
.56947 .60331 L
.57022 .60328 L
.57091 .60322 L
.57222 .60304 L
.57345 .60279 L
.57455 .6025 L
.57574 .60211 L
.57842 .60092 L
.58089 .59945 L
.58561 .59554 L
.59066 .58967 L
.59542 .58245 L
Mistroke
.59976 .5744 L
.61039 .54855 L
.62044 .5162 L
.64041 .43173 L
.65885 .33728 L
.67915 .22901 L
.69819 .13789 L
.7164 .07091 L
.72165 .05627 L
.72664 .04442 L
.73146 .03491 L
.73601 .02768 L
.73842 .02452 L
.74103 .02161 L
.7432 .0196 L
.74559 .0178 L
.74817 .01633 L
.74959 .01573 L
.75091 .0153 L
.75214 .015 L
.75327 .01483 L
.75457 .01472 L
.7558 .01473 L
.75686 .01481 L
.75802 .01498 L
.75924 .01525 L
.76038 .01558 L
.76241 .01636 L
.76461 .01745 L
.76961 .02086 L
.77419 .02497 L
.7931 .04862 L
.8138 .07745 L
.82388 .08909 L
.8334 .0974 L
.83867 .10068 L
.84164 .10209 L
.84438 .10311 L
.84668 .10375 L
.84799 .10403 L
.84922 .10424 L
.85051 .10439 L
.85169 .10448 L
.85234 .10451 L
.85305 .10453 L
.85435 .10451 L
.855 .10447 L
.85568 .10442 L
.85691 .1043 L
.85823 .1041 L
Mistroke
.85967 .10382 L
.86227 .10314 L
.86469 .10233 L
.86921 .10034 L
.87405 .0976 L
.89503 .08079 L
.91487 .06313 L
.92608 .05503 L
.93142 .05201 L
.93644 .04975 L
.94085 .04827 L
.94333 .04764 L
.94561 .04721 L
.94683 .04703 L
.94796 .04689 L
.94921 .04678 L
.9499 .04674 L
.95054 .04671 L
.95182 .04668 L
.95254 .04668 L
.95321 .0467 L
.95443 .04675 L
.95572 .04684 L
.95699 .04698 L
.95815 .04713 L
.96076 .04759 L
.96318 .04816 L
.96547 .04882 L
.9706 .05068 L
.97619 .05326 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo000JOol0
0`00Oomoo`3oOom<Ool001Yoo`03001oogoo0?moodaoo`006Woo00<007ooOol0ogooC7oo000JOol0
0`00Oomoo`3oOom<Ool001Yoo`03001oogoo04=oo`<009moo`@0069oo`006Woo00<007ooOol0@Goo
0P000Woo0`00W7oo0P000Woo0`00H7oo000JOol20010Ool20007Ool00`00Oomoo`2GOol20007Ool0
0`00Oomoo`1MOol001Yoo`03001oogoo03ioo`03001oogoo00Qoo`03001oogoo09Eoo`03001oogoo
00Qoo`03001oogoo05aoo`006Woo00<007ooOol0?Goo00<007ooOol02Goo00<007ooOol0UGoo00<0
07ooOol02Goo00<007ooOol0Fgoo000JOol00`00Oomoo`0VOol30006Ool20005Ool40003Ool00`00
Oomoo`0:Ool00`00Oomoo`0COol5000VOol50004Ool20005Ool4000VOol5000GOol00`00Oomoo`09
Ool00`00Oomoo`050005Ool20005Ool4000VOol3000MOol001Yoo`03001oogoo02Eoo`05001oogoo
Ool00005Ool20009Ool00`00Ool0000=Ool00`00Oomoo`0EOol00`00Oomoo`0XOol00`00Oomoo`04
Ool20009Ool00`00Oomoo`0TOol01000Oomoo`005Woo00<007ooOol02goo00@007ooOol0009oo`03
001oogoo00=oo`8000Uoo`03001oogoo029oo`05001oogooOol0000LOol001Yoo`03001oogoo02Eo
o`05001oogooOol0000@Ool2000?Ool00`00Oomoo`0DOol00`00Oomoo`0XOol00`00Oomoo`0?Ool0
0`00Oomoo`0UOol00`00Oomoo`0EOol00`00Oomoo`0=Ool01000Oomoo`004Woo00<007ooOol09Woo
00<007ooOol06Woo000JOol00`00Oomoo`0UOol01@00Oomoogoo000047oo00<007ooOol03goo00<0
07ooOol04goo00<007ooOol0:7oo00<007ooOol03goo00<007ooOol09Woo00<007ooOol057oo00<0
07ooOol03Woo00@007ooOol0015oo`03001oogoo02Ioo`03001oogoo01Yoo`006Woo00<007ooOol0
9Goo00D007ooOomoo`0000aoo`D0015oo`03001oogoo01=oo`03001oogoo02Qoo`03001oogoo00]o
o`@002Yoo`03001oogoo019oo`03001oogoo011oo`04001oogoo000<Ool4000WOol2000MOol001Yo
o`8000Ioo`03001oogoo01eoo`05001oogooOol0000<Ool01000Oomoo`004goo00<007ooOol04Woo
00<007ooOol0:7oo00<007ooOol02goo00<007ooOol0:goo00<007ooOol04Woo00<007ooOol04Goo
00<007oo000037oo00<007ooOol08Woo00<007ooOol01Goo00<007ooOol06Woo000JOol00`00Ool0
000;000JOol01@00Oomoogoo000037oo00<007oo000057oo00<007ooOol04Woo00<007ooOol0:7oo
00<007ooOol02goo00<007ooOol09goo00D007ooOomoo`0001Aoo`03001oogoo00moo`03001oogoo
008000aoo`03001oogoo01aoo``0009oo`03001oogoo01Yoo`006Woo0P0037oo0P006Goo0`003Goo
10004goo00<007ooOol047oo0`00:7oo0`003Goo10009goo0`0057oo00<007ooOol04Goo0`003Goo
10006Goo0P002goo0`007Goo000JOol00`00Oomoo`0=Ool00`00Oomoo`0WOol00`00Oomoo`0DOol0
0`00Oomoo`2<Ool00`00Oomoo`0DOol00`00Oomoo`0VOol00`00Oomoo`0=Ool00`00Oomoo`0KOol0
01Yoo`03001oogoo00ioo`03001oogoo02Eoo`03001oogoo01Eoo`03001oogoo08]oo`03001oogoo
01Ioo`03001oogoo02Aoo`03001oogoo02aoo`006Woo00<007ooOol03goo00<007ooOol08goo00<0
07ooOol05goo00<007ooOol0RWoo00<007ooOol05Woo00<007ooOol08goo00<007ooOol0;Goo000J
Ool00`00Oomoo`0@Ool2000ROol00`00Oomoo`0HOol00`00Oomoo`29Ool00`00Oomoo`0HOol00`00
Oomoo`0POol2000XOol30005Ool001Yoo`03001oogoo019oo`03001oogoo01ioo`03001oogoo01Uo
o`03001oogoo08Uoo`03001oogoo01Uoo`03001oogoo01ioo`03001oogoo02Moo`05001oogooOol0
0004Ool0019oool0048000aoo`03001oogoo00Ioo`006Woo00<007ooOol01goo00<007ooOol01goo
00D007ooOomoo`0000Eoo`03001oogoo00Qoo`03001oogoo00Moo`03001oo`0000Moo`03001oogoo
00Moo`03001oogoo00Moo`03001oo`0000Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo
00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Eoo`03001oo`0000Uoo`03001oogoo00Qoo`03001oogoo00Aoo`04001oogoo0009Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool01@00Oomoogoo00002Goo00<007ooOol01goo00<007ooOol04Woo00<0
07ooOol01Woo000JOol00`00Oomoo`0FOol00`00Oomoo`0GOol2000OOol00`00Oomoo`0>Ool00`00
Oomoo`0`Ool00`00Oomoo`0`Ool00`00Oomoo`0?Ool00`00Oomoo`0LOol00`00Ool0000HOol00`00
Oomoo`0FOol00`00Oomoo`0BOol00`00Oomoo`06Ool001Yoo`03001oogoo01Moo`03001oogoo01Io
o`03001oogoo01ioo`03001oogoo08Eoo`03001oogoo01ioo`03001oogoo01Ioo`03001oogoo02Yo
o`H000Eoo`006Woo00<007ooOol067oo00<007ooOol05Goo00<007ooOol07Woo00<007ooOol0QGoo
00<007ooOol07goo00<007ooOol057oo00<007ooOol0;Goo00<007ooOol01Woo000JOol00`00Oomo
o`0IOol00`00Oomoo`0COol00`00Oomoo`0POol00`00Oomoo`24Ool00`00Oomoo`0POol00`00Oomo
o`0BOol00`00Oomoo`0^Ool00`00Oomoo`06Ool001Yoo`03001oogoo01Yoo`80019oo`03001oogoo
025oo`03001oogoo08Aoo`03001oogoo025oo`03001oogoo011oo`03001oogoo03Qoo`006Woo00<0
07ooOol077oo00<007ooOol03Goo0P0097oo00<007ooOol0Q7oo00<007ooOol08Woo00<007ooOol0
3Woo00<007ooOol0>Goo000JOol2000NOol2000<Ool00`00Oomoo`0TOol00`00Oomoo`23Ool00`00
Oomoo`0TOol00`00Oomoo`0<Ool00`00Oomoo`0jOol001Yoo`03001oogoo01moo`03001oogoo00Mo
o`8002Moo`03001oogoo08=oo`03001oogoo02Eoo`03001oogoo00Uoo`8003eoo`006Woo00<007oo
Ool087oo0P001Goo0P00:Woo00<007ooOol0PWoo00<007ooOol09Woo0P001goo0P00?goo000JOol0
0`00Oomoo`0ROol6000[Ool00`00Oomoo`22Ool00`00Oomoo`0XOol70011Ool001Yoo`03001oogoo
05=oo`03001oogoo085oo`03001oogoo075oo`006Woo00<007ooOol0Dgoo00<007ooOol0PGoo00<0
07ooOol0LGoo000JOol00`00Oomoo`1DOol00`00Oomoo`20Ool00`00Oomoo`1aOol001Yoo`03001o
ogoo05Aoo`03001oogoo081oo`03001oogoo075oo`006Woo0P00EGoo00<007ooOol0Ogoo00<007oo
Ool0LWoo000JOol00`00Oomoo`1DOol00`00Oomoo`1oOol00`00Oomoo`1bOol001Yoo`03001oogoo
05Eoo`03001oogoo07ioo`03001oogoo079oo`006Woo00<007ooOol0EGoo00<007ooOol0OWoo00<0
07ooOol0LWoo000JOol00`00Oomoo`1EOol00`00Oomoo`1nOol00`00Oomoo`1bOol001Yoo`03001o
ogoo05Eoo`03001oogoo07eoo`03001oogoo07=oo`006Woo00<007ooOol0EGoo00<007ooOol0OGoo
00<007ooOol0Lgoo000JOol00`00Oomoo`1FOol00`00Oomoo`1lOol00`00Oomoo`1cOol001Yoo`03
001oogoo05Ioo`03001oogoo07aoo`03001oogoo07=oo`006Woo0P00Egoo00<007ooOol0Ngoo00<0
07ooOol0M7oo000JOol00`00Oomoo`1FOol00`00Oomoo`1kOol00`00Oomoo`1dOol001Yoo`03001o
ogoo05Moo`03001oogoo07Yoo`03001oogoo07Aoo`006Woo00<007ooOol0Egoo00<007ooOol0NWoo
00<007ooOol0M7oo000JOol00`00Oomoo`1GOol00`00Oomoo`1iOol00`00Oomoo`1eOol000<000Io
o`8000Aoo`D000Ioo`03001oogoo05Moo`03001oogoo07Uoo`03001oogoo07Eoo`000goo00<007oo
Ool00goo0P001Goo00@007ooOol000Ioo`03001oogoo05Moo`03001oogoo07Uoo`03001oogoo07Eo
o`000goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol0F7oo00<007ooOol0N7oo00<007oo
Ool0MGoo0003Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool3001HOol00`00Oomoo`1gOol00`00Oomo
o`1fOol000=oo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo05Qoo`03001oogoo07Moo`03
001oogoo07Ioo`000goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0F7oo00<007ooOol0
Mgoo00<007ooOol0MWoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo00001Woo00<007ooOol0F7oo
00<007ooOol0Mgoo00<007ooOol0MWoo0003000=Ool30007Ool00`00Oomoo`1IOol00`00Oomoo`1e
Ool00`00Oomoo`1gOol001Yoo`03001oogoo05Uoo`03001oogoo07Eoo`03001oogoo07Moo`006Woo
00<007ooOol0FGoo00<007ooOol0MGoo00<007ooOol0Mgoo000JOol00`00Oomoo`1IOol00`00Oomo
o`1eOol00`00Oomoo`1gOol001Yoo`8005Yoo`03001oogoo07Eoo`03001oogoo07Moo`006Woo00<0
07ooOol0FWoo00<007ooOol0Lgoo00<007ooOol0N7oo000JOol00`00Oomoo`1JOol00`00Oomoo`1c
Ool00`00Oomoo`1hOol001Yoo`03001oogoo05Yoo`03001oogoo07=oo`03001oogoo07Qoo`006Woo
00<007ooOol0FWoo00<007ooOol0Lgoo00<007ooOol0N7oo000JOol00`00Oomoo`1JOol00`00Oomo
o`1bOol00`00Oomoo`1iOol001Yoo`03001oogoo05]oo`03001oogoo075oo`03001oogoo07Uoo`00
6Woo00<007ooOol0Fgoo00<007ooOol0LGoo00<007ooOol0NGoo000JOol2001LOol00`00Oomoo`1a
Ool00`00Oomoo`1iOol001Yoo`03001oogoo05]oo`03001oogoo071oo`03001oogoo07Yoo`006Woo
00<007ooOol0Fgoo00<007ooOol0L7oo00<007ooOol0NWoo000JOol00`00Oomoo`1LOol00`00Oomo
o`1_Ool00`00Oomoo`1jOol001Yoo`03001oogoo05aoo`03001oogoo06moo`03001oogoo07Yoo`00
6Woo00<007ooOol0G7oo00<007ooOol0Kgoo00<007ooOol0NWoo000JOol00`00Oomoo`1LOol00`00
Oomoo`1^Ool00`00Oomoo`1kOol001Yoo`03001oogoo05aoo`03001oogoo06ioo`03001oogoo07]o
o`006Woo0P00GWoo00<007ooOol0KGoo00<007ooOol0Ngoo000JOol00`00Oomoo`1MOol00`00Oomo
o`1]Ool00`00Oomoo`1kOol001Yoo`03001oogoo05eoo`03001oogoo06eoo`03001oogoo07]oo`00
6Woo00<007ooOol0GGoo00<007ooOol0K7oo00<007ooOol0O7oo000JOol00`00Oomoo`1MOol00`00
Oomoo`1/Ool00`00Oomoo`1lOol000<000Ioo`8000Ioo`<000Ioo`03001oogoo05ioo`03001oogoo
06]oo`03001oogoo07aoo`000goo00<007ooOol00goo0P001goo00<007ooOol01Goo00<007ooOol0
GWoo00<007ooOol0Jgoo00<007ooOol0O7oo0003Ool00`00Oomoo`09Ool50006Ool00`00Oomoo`1N
Ool00`00Oomoo`1[Ool00`00Oomoo`1lOol000=oo`03001oogoo00Uoo`04001oogoo0007Ool3001N
Ool00`00Oomoo`1[Ool00`00Oomoo`1lOol000=oo`03001oogoo00Yoo`03001oo`0000Moo`03001o
ogoo05ioo`03001oogoo06Yoo`03001oogoo07eoo`000goo00<007ooOol02Woo00<007oo00001goo
00<007ooOol0Ggoo00<007ooOol0JGoo00<007ooOol0OGoo0003Ool00`00Oomoo`0;Ool20007Ool0
0`00Oomoo`1OOol00`00Oomoo`1YOol00`00Oomoo`1mOol000<000moo`03001oogoo00Eoo`03001o
ogoo05moo`03001oogoo06Uoo`03001oogoo07eoo`006Woo00<007ooOol0Ggoo00<007ooOol0JGoo
00<007ooOol0OGoo000JOol00`00Oomoo`1OOol00`00Oomoo`1YOol00`00Oomoo`1mOol001Yoo`03
001oogoo061oo`03001oogoo06Moo`03001oogoo07ioo`006Woo0P00HGoo00<007ooOol0Igoo00<0
07ooOol0OWoo000JOol00`00Oomoo`1POol00`00Oomoo`1WOol00`00Oomoo`1nOol001Yoo`03001o
ogoo061oo`03001oogoo06Moo`03001oogoo07ioo`006Woo00<007ooOol0H7oo00<007ooOol0Igoo
00<007ooOol0OWoo000JOol00`00Oomoo`1QOol00`00Oomoo`1UOol00`00Oomoo`1oOol001Yoo`03
001oogoo065oo`03001oogoo06Eoo`03001oogoo07moo`006Woo00<007ooOol0HGoo00<007ooOol0
IGoo00<007ooOol0Ogoo000JOol00`00Oomoo`1QOol00`00Oomoo`1UOol00`00Oomoo`1oOol001Yo
o`80069oo`03001oogoo06Eoo`03001oogoo07moo`006Woo00<007ooOol0HWoo00<007ooOol0I7oo
00<007ooOol0Ogoo000JOol00`00Oomoo`1ROol00`00Oomoo`1SOol00`00Oomoo`20Ool001Yoo`03
001oogoo069oo`03001oogoo06=oo`03001oogoo081oo`006Woo00<007ooOol0HWoo00<007ooOol0
Hgoo00<007ooOol0P7oo000JOol00`00Oomoo`1ROol00`00Oomoo`1SOol00`00Oomoo`20Ool001Yo
o`03001oogoo06=oo`03001oogoo069oo`03001oogoo081oo`006Woo00<007ooOol0Hgoo00<007oo
Ool0HWoo00<007ooOol0P7oo000JOol2001TOol00`00Oomoo`1QOol00`00Oomoo`21Ool001Yoo`03
001oogoo06=oo`03001oogoo065oo`03001oogoo085oo`006Woo00<007ooOol0Hgoo00<007ooOol0
HGoo00<007ooOol0PGoo000JOol00`00Oomoo`1TOol00`00Oomoo`1POol00`00Oomoo`21Ool001Yo
o`03001oogoo06Aoo`03001oogoo061oo`03001oogoo085oo`006Woo00<007ooOol0I7oo00<007oo
Ool0Ggoo00<007ooOol0PWoo00030006Ool20005Ool30007Ool00`00Oomoo`1TOol00`00Oomoo`1O
Ool00`00Oomoo`22Ool000=oo`03001oogoo00=oo`8000Aoo`05001oogooOol00006Ool00`00Oomo
o`1TOol00`00Oomoo`1OOol00`00Oomoo`22Ool000=oo`03001oogoo00Uoo`05001oogooOol00006
Ool3001UOol00`00Oomoo`1NOol00`00Oomoo`22Ool000=oo`03001oogoo00Uoo`05001oogooOol0
0006Ool00`00Oomoo`1UOol00`00Oomoo`1NOol00`00Oomoo`22Ool000=oo`03001oogoo00Uoo`@0
00Moo`03001oogoo06Eoo`03001oogoo05eoo`03001oogoo08=oo`000goo00<007ooOol02Goo00<0
07ooOol027oo00<007ooOol0IGoo00<007ooOol0GGoo00<007ooOol0Pgoo0003Ool00`00Oomoo`0:
Ool00`00Oomoo`07Ool00`00Oomoo`1UOol00`00Oomoo`1MOol00`00Oomoo`23Ool000<000ioo`<0
00Ioo`03001oogoo06Ioo`03001oogoo05aoo`03001oogoo08=oo`006Woo00<007ooOol0IWoo00<0
07ooOol0G7oo00<007ooOol0Pgoo000JOol00`00Oomoo`1VOol00`00Oomoo`1KOol00`00Oomoo`24
Ool001Yoo`8006Moo`03001oogoo05]oo`03001oogoo08Aoo`006Woo00<007ooOol0IWoo00<007oo
Ool0Fgoo00<007ooOol0Q7oo000JOol00`00Oomoo`1WOol00`00Oomoo`1JOol00`00Oomoo`24Ool0
01Yoo`03001oogoo06Moo`03001oogoo05Yoo`03001oogoo08Aoo`006Woo00<007ooOol0Igoo00<0
07ooOol0FGoo00<007ooOol0QGoo000JOol00`00Oomoo`1WOol00`00Oomoo`1IOol00`00Oomoo`25
Ool001Yoo`03001oogoo06Moo`03001oogoo05Uoo`03001oogoo08Eoo`006Woo00<007ooOol0J7oo
00<007ooOol0F7oo00<007ooOol0QGoo000JOol2001YOol00`00Oomoo`1HOol00`00Oomoo`25Ool0
01Yoo`03001oogoo06Qoo`03001oogoo05Moo`03001oogoo08Ioo`006Woo00<007ooOol0J7oo00<0
07ooOol0Egoo00<007ooOol0QWoo000JOol00`00Oomoo`1XOol00`00Oomoo`1GOol00`00Oomoo`26
Ool001Yoo`03001oogoo06Uoo`03001oogoo05Ioo`03001oogoo08Ioo`006Woo00<007ooOol0JGoo
00<007ooOol0EWoo00<007ooOol0QWoo000JOol00`00Oomoo`1YOol00`00Oomoo`1EOol00`00Oomo
o`27Ool001Yoo`03001oogoo06Uoo`03001oogoo05Eoo`03001oogoo08Moo`006Woo0P00JWoo00<0
07ooOol0EGoo00<007ooOol0Qgoo000JOol00`00Oomoo`1ZOol00`00Oomoo`1DOol00`00Oomoo`27
Ool001Yoo`03001oogoo06Yoo`03001oogoo05Aoo`03001oogoo08Moo`006Woo00<007ooOol0JWoo
00<007ooOol0Dgoo00<007ooOol0R7oo000JOol00`00Oomoo`1ZOol00`00Oomoo`1COol00`00Oomo
o`28Ool001Yoo`03001oogoo06Yoo`03001oogoo05=oo`03001oogoo08Qoo`000`001Woo0P001Goo
0`001goo00<007ooOol0Jgoo00<007ooOol0DWoo00<007ooOol0R7oo0003Ool00`00Oomoo`03Ool2
0004Ool01@00Oomoogoo00001Woo00<007ooOol0Jgoo00<007ooOol0DGoo00<007ooOol0RGoo0003
Ool00`00Oomoo`09Ool01@00Oomoogoo00001Woo00<007ooOol0Jgoo00<007ooOol0DGoo00<007oo
Ool0RGoo0003Ool00`00Oomoo`09Ool01@00Oomoogoo00001Woo0`00Jgoo00<007ooOol0DGoo00<0
07ooOol0RGoo0003Ool00`00Oomoo`0:Ool30007Ool00`00Oomoo`1[Ool00`00Oomoo`1AOol00`00
Oomoo`29Ool000=oo`03001oogoo00Uoo`05001oogooOol00006Ool00`00Oomoo`1/Ool00`00Oomo
o`1@Ool00`00Oomoo`29Ool000=oo`03001oogoo00Uoo`05001oogooOol00006Ool00`00Oomoo`1/
Ool00`00Oomoo`1?Ool00`00Oomoo`2:Ool000<000eoo`<000Moo`03001oogoo06aoo`03001oogoo
04moo`03001oogoo08Yoo`006Woo00<007ooOol0K7oo00<007ooOol0Cgoo00<007ooOol0RWoo000J
Ool00`00Oomoo`1/Ool00`00Oomoo`1?Ool00`00Oomoo`2:Ool001Yoo`03001oogoo06eoo`03001o
ogoo04eoo`03001oogoo08]oo`006Woo0P00KWoo00<007ooOol0CGoo00<007ooOol0Rgoo000JOol0
0`00Oomoo`1]Ool00`00Oomoo`1=Ool00`00Oomoo`2;Ool001Yoo`03001oogoo06ioo`03001oogoo
04aoo`03001oogoo08]oo`006Woo00<007ooOol0KWoo00<007ooOol0C7oo00<007ooOol0Rgoo000J
Ool00`00Oomoo`1^Ool00`00Oomoo`1;Ool00`00Oomoo`2<Ool001Yoo`03001oogoo06ioo`03001o
ogoo04]oo`03001oogoo08aoo`006Woo00<007ooOol0Kgoo00<007ooOol0BWoo00<007ooOol0S7oo
000JOol00`00Oomoo`1_Ool00`00Oomoo`19Ool00`00Oomoo`2=Ool001Yoo`80071oo`03001oogoo
04Uoo`03001oogoo08eoo`006Woo00<007ooOol0L7oo00<007ooOol0B7oo00<007ooOol0SGoo000J
Ool00`00Oomoo`1`Ool00`00Oomoo`17Ool00`00Oomoo`2>Ool001Yoo`03001oogoo071oo`03001o
ogoo04Moo`03001oogoo08ioo`006Woo00<007ooOol0LGoo00<007ooOol0AGoo00<007ooOol0Sgoo
000JOol00`00Oomoo`1aOol00`00Oomoo`15Ool00`00Oomoo`2?Ool001Yoo`03001oogoo079oo`03
001oogoo04Aoo`03001oogoo08moo`006Woo00<007ooOol0LWoo00<007ooOol0@goo00<007ooOol0
T7oo000JOol2001cOol00`00Oomoo`13Ool00`00Oomoo`2@Ool001Yoo`03001oogoo07=oo`03001o
ogoo045oo`03001oogoo095oo`006Woo00<007ooOol0Lgoo00<007ooOol0@Goo00<007ooOol0TGoo
000JOol00`00Oomoo`1dOol00`00Oomoo`10Ool00`00Oomoo`2AOol001Yoo`03001oogoo07Aoo`03
001oogoo03moo`03001oogoo099oo`0047oo1@001Goo00<007ooOol0MGoo00<007ooOol0?Woo00<0
07ooOol0TWoo000BOol00`00Oomoo`05Ool00`00Oomoo`1eOol00`00Oomoo`0JOol8000LOol00`00
Oomoo`2BOol0019oo`03001oogoo00Eoo`03001oogoo07Eoo`03001oogoo01Ioo`@000Qoo`8001Uo
o`03001oogoo09=oo`004Woo00<007ooOol01Goo0`00MWoo00<007ooOol057oo00<007ooOol037oo
0P005goo00<007ooOol0Tgoo000BOol00`00Oomoo`05Ool00`00Oomoo`1fOol00`00Oomoo`0BOol2
000AOol00`00Oomoo`0COol00`00Oomoo`2DOol0019oo`03001oogoo00Eoo`03001oogoo07Moo`03
001oogoo011oo`03001oogoo019oo`8001=oo`03001oogoo09Aoo`004Woo00<007ooOol01Goo00<0
07ooOol0N7oo00<007ooOol03Woo00<007ooOol05Goo00<007ooOol03goo00<007ooOol0UGoo000@
Ool30007Ool00`00Oomoo`1hOol00`00Oomoo`0=Ool00`00Oomoo`0GOol2000>Ool00`00Oomoo`2F
Ool001Yoo`03001oogoo07Uoo`03001oogoo00]oo`03001oogoo01Yoo`03001oogoo00]oo`03001o
ogoo09Ioo`006Woo00<007ooOol0NWoo00<007ooOol027oo0P007Woo0P002Goo0P00VGoo000JOol0
0`00Oomoo`1kOol20007Ool00`00Oomoo`0POol00`00Oomoo`05Ool00`00Oomoo`2IOol001Yoo`80
07ioo`L002Aoo`L009aoo`006Woo00<007ooOol0ogooC7oo000JOol00`00Oomoo`3oOom<Ool001Yo
o`03001oogoo0?moodaoo`006Woo00<007ooOol0ogooC7oo000JOol00`00Oomoo`3oOom<Ool00?mo
ofUoo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo0011Ool4000aOol4000eOol4002eOol0
04Eoo`03001oogoo039oo`03001oogoo03Aoo`03001oogoo0;Aoo`00AGoo00<007ooOol0<Woo00<0
07ooOol0=Goo00<007ooOol0/goo000`Ool50004Ool50003Ool3000017oo001oogoo0`0000Aoo`00
0000009oo`D0009oo`D000Uoo`<00003Ool00000009oo`@000Aoo`<00003Ool007oo00H000Aoo`D0
00=oo`<00003Ool00000009oo`@000Aoo`<00003Ool0000000Aoo`800004Ool000000004Ool00`00
Oomoo`0:Ool60003Ool50002Ool3000017oo000000000Woo1@0017oo0`0017oo10001goo0P0000Ao
o`00000000=oo`D0009oo`<00004Ool000000002Ool300000goo00000002Ool01000Oomoo`0017oo
1@000goo0`0000=oo`0000000goo0`000goo0`0000Aoo`00000002ioo`00<7oo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol00Woo00@007ooOomoo`8000=oo`05001oogooOol00002Ool01@00
Oomoogoo00001Goo00<007ooOol027oo00@007ooOomoo`80009oo`03001oogoo009oo`04001oogoo
0003Ool20003Ool00`00Oomoo`04Ool01@00Oomoogoo00000goo00@007ooOomoo`80009oo`03001o
ogoo009oo`04001oogoo0003Ool20006Ool20003Ool01P00Oomoo`00Ool000eoo`03001oogoo00Io
o`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00<007ooOol01Goo0P000goo00<007oo00000goo00<007ooOol00Woo00D007ooOomo
o`00009oo`04001oogooOol20003Ool01000Oomoo`001Woo00<007ooOol00Woo00@007ooOomoo`80
00=oo`05001oogooOol00003Ool01@00Oomoogoo0000;goo000`Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOol000=oo`03
001oogoo00=oo`03001oogoo00Qoo`03001oogoo009oo`04001oogoo0007Ool00`00Oomoo`02Ool0
1@00Oomoogoo00001Woo00D007ooOomoo`0000=oo`03001oogoo009oo`04001oogoo0007Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000eoo`03001oogoo00Io
o`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<0
07ooOol00Woo00D007ooOol007oo00800003Ool007oo00Aoo`03001oogoo009oo`03001oogoo009o
o`05001oogooOol00007Ool01@00Oomoogoo0000;goo000cOol30005Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool01@00Oomoogoo00000goo00@007ooOomoo`@000Eoo`03001oogoo00Qoo`03001oogoo
009oo`03001oogoo00H0009oo`03001oogoo009oo`05001oogooOol00007Ool40003Ool00`00Oomo
o`02Ool00`00Oomoo`060002Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Ool00003Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01@00Oomoogoo00001Goo
00<007ooOol00goo00<007ooOol017oo1P001goo00<007ooOol00Woo00<007ooOol0100017oo00D0
07ooOomoo`00009oo`03001oogoo009oo`05001oogoo001oo`0200000goo001oo`04Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01@00Oomoogoo00001goo00D007ooOomoo`0002moo`00<7oo0`0027oo
00<007ooOol00Woo00@007ooOomoo`8000=oo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00
Oomoo`08Ool01000Oomoogoo0P000Woo00<007ooOol00Woo00@007ooOol000=oo`8000=oo`8000Uo
o`05001oogooOol00003Ool20002Ool00`00Oomoo`02Ool01000Oomoo`000goo0P001Woo0P000goo
00<007oo00000goo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol00goo00D007ooOomoo`00
00Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Eoo`8000=oo`03
001oogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool01000Oomoogoo0P000Woo00H007oo
000007oo0005Ool00`00Oomoo`02Ool01000Oomoogoo0P000goo00<007ooOol01Goo00D007ooOomo
o`0002moo`00<7oo00<007ooOol00Woo00@007ooOomoo`<000Eoo`<00004Ool00000Ool50004Ool3
0006Ool00`00Oomoo`09Ool300000goo001oo`02Ool40004Ool3000017oo000007oo0P0000Aoo`00
000000=oo`<000Eoo`<00003Ool007oo009oo`@000Aoo`<00003Ool007oo00Eoo`03001oo`000080
0005Ool00000001oo`030009Ool60003Ool30004Ool50004Ool30003Ool60004Ool40008Ool00`00
Ool000020003Ool30004Ool50004Ool300000goo001oo`030002Ool30002Ool30005Ool300000goo
001oo`060004Ool4000`Ool0031oo`03001oogoo009oo`03001oogoo029oo`03001oogoo00eoo`03
001oogoo02Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo01aoo`03
001oogoo015oo`03001oogoo01Uoo`03001oogoo01Eoo`05001oogooOol00007Ool00`00Oomoo`0a
Ool0035oo`D000Eoo`03001oogoo01aoo`03001oogoo00eoo`03001oogoo02Eoo`03001oogoo00eo
o`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo00eoo`03001oogoo00=o
o`03001oogoo015oo`03001oogoo01Uoo`03001oogoo00]oo`03001oogoo00Moo`05001oogooOol0
0007Ool00`00Oomoo`0aOol003]oo`03001oogoo01Yoo`<000ioo`8002Ioo`8000ioo`8000Eoo`80
01Qoo`<000Eoo`03001oogoo00eoo`03001oogoo01Ioo`8001Yoo`8000eoo`03001oogoo00Ioo`80
00Yoo`8003=oo`00ogooJGoo003oOomYOol00?moofUoo`00ogooJGoo003oOomYOol00?moofUoo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "If these pulses become so broad that they begin to overlap with \
neighboring pulses in the signal, then the signal will be garbled. For \
example, in order to distinguish a 0 bit travelling between two 1 bits, the \
length in time of each bit, ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", must be larger than roughly half the width ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " of the degraded bits: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(2  T\), "\[GreaterTilde]", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " (see Fig. ",
  ButtonBox["2.6",
    ButtonData:>"Fig. 2.6",
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.97771 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0470883 0.952381 [
[ 0 0 0 0 ]
[ 1 1.97771 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.97771 L
0 1.97771 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
arrl arrl scale
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.17 0.085  moveto 0 0 lineto 
-0.17 -0.085  lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.0470883 0.97619 0.635692 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.127168 0.580088 [
[.02381 .11467 -6 -9 ]
[.02381 .11467 6 0 ]
[.18254 .11467 -6 -9 ]
[.18254 .11467 6 0 ]
[.5 .11467 -3 -9 ]
[.5 .11467 3 0 ]
[.65873 .11467 -3 -9 ]
[.65873 .11467 3 0 ]
[.81746 .11467 -3 -9 ]
[.81746 .11467 3 0 ]
[.97619 .11467 -3 -9 ]
[.97619 .11467 3 0 ]
[1.025 .12717 0 -6 ]
[1.025 .12717 10 6 ]
[.32877 .01115 -24 -4.5 ]
[.32877 .01115 0 4.5 ]
[.32877 .24319 -18 -4.5 ]
[.32877 .24319 0 4.5 ]
[.32877 .3592 -18 -4.5 ]
[.32877 .3592 0 4.5 ]
[.32877 .47522 -18 -4.5 ]
[.32877 .47522 0 4.5 ]
[.32877 .59124 -18 -4.5 ]
[.32877 .59124 0 4.5 ]
[.34127 .64303 -8 0 ]
[.34127 .64303 8 12 ]
[.5 .63053 -14 0 ]
[.5 .63053 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .12717 m
.02381 .13342 L
s
[(-2)] .02381 .11467 0 1 Mshowa
.18254 .12717 m
.18254 .13342 L
s
[(-1)] .18254 .11467 0 1 Mshowa
.5 .12717 m
.5 .13342 L
s
[(1)] .5 .11467 0 1 Mshowa
.65873 .12717 m
.65873 .13342 L
s
[(2)] .65873 .11467 0 1 Mshowa
.81746 .12717 m
.81746 .13342 L
s
[(3)] .81746 .11467 0 1 Mshowa
.97619 .12717 m
.97619 .13342 L
s
[(4)] .97619 .11467 0 1 Mshowa
.125 Mabswid
.05556 .12717 m
.05556 .13092 L
s
.0873 .12717 m
.0873 .13092 L
s
.11905 .12717 m
.11905 .13092 L
s
.15079 .12717 m
.15079 .13092 L
s
.21429 .12717 m
.21429 .13092 L
s
.24603 .12717 m
.24603 .13092 L
s
.27778 .12717 m
.27778 .13092 L
s
.30952 .12717 m
.30952 .13092 L
s
.37302 .12717 m
.37302 .13092 L
s
.40476 .12717 m
.40476 .13092 L
s
.43651 .12717 m
.43651 .13092 L
s
.46825 .12717 m
.46825 .13092 L
s
.53175 .12717 m
.53175 .13092 L
s
.56349 .12717 m
.56349 .13092 L
s
.59524 .12717 m
.59524 .13092 L
s
.62698 .12717 m
.62698 .13092 L
s
.69048 .12717 m
.69048 .13092 L
s
.72222 .12717 m
.72222 .13092 L
s
.75397 .12717 m
.75397 .13092 L
s
.78571 .12717 m
.78571 .13092 L
s
.84921 .12717 m
.84921 .13092 L
s
.88095 .12717 m
.88095 .13092 L
s
.9127 .12717 m
.9127 .13092 L
s
.94444 .12717 m
.94444 .13092 L
s
.25 Mabswid
0 .12717 m
1 .12717 L
s
gsave
1.025 .12717 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 .01115 m
.34752 .01115 L
s
[(-0.2)] .32877 .01115 1 0 Mshowa
.34127 .24319 m
.34752 .24319 L
s
[(0.2)] .32877 .24319 1 0 Mshowa
.34127 .3592 m
.34752 .3592 L
s
[(0.4)] .32877 .3592 1 0 Mshowa
.34127 .47522 m
.34752 .47522 L
s
[(0.6)] .32877 .47522 1 0 Mshowa
.34127 .59124 m
.34752 .59124 L
s
[(0.8)] .32877 .59124 1 0 Mshowa
.125 Mabswid
.34127 .04015 m
.34502 .04015 L
s
.34127 .06916 m
.34502 .06916 L
s
.34127 .09816 m
.34502 .09816 L
s
.34127 .15617 m
.34502 .15617 L
s
.34127 .18518 m
.34502 .18518 L
s
.34127 .21418 m
.34502 .21418 L
s
.34127 .27219 m
.34502 .27219 L
s
.34127 .30119 m
.34502 .30119 L
s
.34127 .3302 m
.34502 .3302 L
s
.34127 .38821 m
.34502 .38821 L
s
.34127 .41721 m
.34502 .41721 L
s
.34127 .44622 m
.34502 .44622 L
s
.34127 .50423 m
.34502 .50423 L
s
.34127 .53323 m
.34502 .53323 L
s
.34127 .56223 m
.34502 .56223 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dw) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .08221 m
.04262 .05226 L
.0522 .0393 L
.06244 .02795 L
.0679 .02318 L
.07286 .0197 L
.07525 .01833 L
.07784 .01708 L
.08027 .01614 L
.08255 .01547 L
.08383 .01519 L
.0852 .01496 L
.08598 .01486 L
.08672 .01479 L
.08739 .01474 L
.08811 .01472 L
.08889 .01472 L
.08959 .01473 L
.0904 .01478 L
.09117 .01485 L
.09188 .01494 L
.09253 .01504 L
.09401 .01533 L
.09527 .01566 L
.09646 .01603 L
.09915 .01711 L
.10177 .01847 L
.10458 .02028 L
.10986 .02466 L
.11475 .02987 L
.12582 .04582 L
.13558 .0646 L
.14594 .08922 L
.18369 .21313 L
.22389 .37567 L
.24237 .44727 L
.26258 .51492 L
.27227 .54172 L
.28262 .5655 L
.28835 .57631 L
.29355 .58461 L
.29849 .59111 L
.30372 .5965 L
.30848 .60005 L
.31118 .60149 L
.31247 .60204 L
.3137 .60246 L
.31481 .60277 L
.31602 .60303 L
.31712 .6032 L
Mistroke
.31814 .60329 L
.31935 .60332 L
.32045 .60327 L
.32172 .60314 L
.32291 .60293 L
.32412 .60264 L
.32544 .60222 L
.32812 .60108 L
.33059 .59968 L
.3329 .59807 L
.33812 .59339 L
.3437 .58682 L
.3539 .57092 L
.36498 .54851 L
.38512 .497 L
.42595 .37447 L
.44624 .31945 L
.45618 .2969 L
.46527 .27955 L
.47414 .26609 L
.47866 .26065 L
.48347 .25595 L
.48602 .25394 L
.48833 .2524 L
.49068 .25111 L
.49284 .25018 L
.49405 .24976 L
.49537 .2494 L
.4967 .24912 L
.49743 .24901 L
.49811 .24893 L
.49936 .24885 L
.5005 .24884 L
.50182 .24892 L
.50307 .24908 L
.50421 .2493 L
.50543 .24961 L
.50765 .25037 L
.51029 .2516 L
.51271 .25306 L
.5177 .25699 L
.52296 .26248 L
.53175 .27463 L
.54137 .29189 L
.56096 .3378 L
.5819 .39787 L
.60179 .45857 L
.62336 .52012 L
.63345 .54496 L
.64414 .56734 L
Mistroke
.65327 .58261 L
.65807 .58908 L
.66331 .59482 L
.66601 .59721 L
.66852 .59909 L
.67111 .60068 L
.67346 .6018 L
.67457 .60222 L
.67577 .6026 L
.67691 .60289 L
.67795 .60309 L
.67906 .60323 L
.68028 .60331 L
.68155 .6033 L
.68274 .60321 L
.68404 .60302 L
.68477 .60287 L
.68545 .60271 L
.68801 .60184 L
.69034 .60073 L
.69282 .59921 L
.69796 .59494 L
.70362 .58849 L
.71372 .57259 L
.72298 .55328 L
.74384 .49498 L
.78349 .34563 L
.82162 .1931 L
.84288 .1208 L
.8622 .06949 L
.87185 .04991 L
.87692 .04133 L
.8823 .03356 L
.887 .02787 L
.89217 .02282 L
.89687 .0193 L
.90126 .01692 L
.90385 .01593 L
.90509 .01556 L
.90625 .01528 L
.90691 .01514 L
.90763 .01501 L
.90888 .01485 L
.90959 .01478 L
.91034 .01474 L
.91098 .01472 L
.91168 .01472 L
.91297 .01477 L
.91415 .01487 L
.9148 .01496 L
Mistroke
.91551 .01507 L
.9168 .01532 L
.91928 .01599 L
.92157 .01683 L
.92585 .01893 L
.93056 .02201 L
.94011 .0305 L
.95749 .05241 L
.97619 .08221 L
Mfstroke
.46032 .47522 m
.34921 .47522 L
s
% Start of user PostScript
0.75 0.6 0.05 0.6 MAarrowhead1
% End of user PostScript
.53968 .47522 m
.65079 .47522 L
s
% Start of user PostScript
1.25 0.6 1.95 0.6 MAarrowhead1
% End of user PostScript
gsave
.6746 .30119 -87 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\230) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(\\231) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .47522 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
75.000 13.000 moveto
(T) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 0.694552 0.97619 1.28316 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.0732755 0.487301 [
[.02381 .06078 -6 -9 ]
[.02381 .06078 6 0 ]
[.18254 .06078 -6 -9 ]
[.18254 .06078 6 0 ]
[.5 .06078 -3 -9 ]
[.5 .06078 3 0 ]
[.65873 .06078 -3 -9 ]
[.65873 .06078 3 0 ]
[.81746 .06078 -3 -9 ]
[.81746 .06078 3 0 ]
[.97619 .06078 -3 -9 ]
[.97619 .06078 3 0 ]
[1.025 .07328 0 -6 ]
[1.025 .07328 10 6 ]
[.32877 .17074 -18 -4.5 ]
[.32877 .17074 0 4.5 ]
[.32877 .2682 -18 -4.5 ]
[.32877 .2682 0 4.5 ]
[.32877 .36566 -18 -4.5 ]
[.32877 .36566 0 4.5 ]
[.32877 .46312 -18 -4.5 ]
[.32877 .46312 0 4.5 ]
[.32877 .56058 -6 -4.5 ]
[.32877 .56058 0 4.5 ]
[.34127 .64303 -8 0 ]
[.34127 .64303 8 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .07328 m
.02381 .07953 L
s
[(-2)] .02381 .06078 0 1 Mshowa
.18254 .07328 m
.18254 .07953 L
s
[(-1)] .18254 .06078 0 1 Mshowa
.5 .07328 m
.5 .07953 L
s
[(1)] .5 .06078 0 1 Mshowa
.65873 .07328 m
.65873 .07953 L
s
[(2)] .65873 .06078 0 1 Mshowa
.81746 .07328 m
.81746 .07953 L
s
[(3)] .81746 .06078 0 1 Mshowa
.97619 .07328 m
.97619 .07953 L
s
[(4)] .97619 .06078 0 1 Mshowa
.125 Mabswid
.05556 .07328 m
.05556 .07703 L
s
.0873 .07328 m
.0873 .07703 L
s
.11905 .07328 m
.11905 .07703 L
s
.15079 .07328 m
.15079 .07703 L
s
.21429 .07328 m
.21429 .07703 L
s
.24603 .07328 m
.24603 .07703 L
s
.27778 .07328 m
.27778 .07703 L
s
.30952 .07328 m
.30952 .07703 L
s
.37302 .07328 m
.37302 .07703 L
s
.40476 .07328 m
.40476 .07703 L
s
.43651 .07328 m
.43651 .07703 L
s
.46825 .07328 m
.46825 .07703 L
s
.53175 .07328 m
.53175 .07703 L
s
.56349 .07328 m
.56349 .07703 L
s
.59524 .07328 m
.59524 .07703 L
s
.62698 .07328 m
.62698 .07703 L
s
.69048 .07328 m
.69048 .07703 L
s
.72222 .07328 m
.72222 .07703 L
s
.75397 .07328 m
.75397 .07703 L
s
.78571 .07328 m
.78571 .07703 L
s
.84921 .07328 m
.84921 .07703 L
s
.88095 .07328 m
.88095 .07703 L
s
.9127 .07328 m
.9127 .07703 L
s
.94444 .07328 m
.94444 .07703 L
s
.25 Mabswid
0 .07328 m
1 .07328 L
s
gsave
1.025 .07328 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 .17074 m
.34752 .17074 L
s
[(0.2)] .32877 .17074 1 0 Mshowa
.34127 .2682 m
.34752 .2682 L
s
[(0.4)] .32877 .2682 1 0 Mshowa
.34127 .36566 m
.34752 .36566 L
s
[(0.6)] .32877 .36566 1 0 Mshowa
.34127 .46312 m
.34752 .46312 L
s
[(0.8)] .32877 .46312 1 0 Mshowa
.34127 .56058 m
.34752 .56058 L
s
[(1)] .32877 .56058 1 0 Mshowa
.125 Mabswid
.34127 .09764 m
.34502 .09764 L
s
.34127 .12201 m
.34502 .12201 L
s
.34127 .14637 m
.34502 .14637 L
s
.34127 .1951 m
.34502 .1951 L
s
.34127 .21947 m
.34502 .21947 L
s
.34127 .24383 m
.34502 .24383 L
s
.34127 .29256 m
.34502 .29256 L
s
.34127 .31693 m
.34502 .31693 L
s
.34127 .34129 m
.34502 .34129 L
s
.34127 .39002 m
.34502 .39002 L
s
.34127 .41439 m
.34502 .41439 L
s
.34127 .43875 m
.34502 .43875 L
s
.34127 .48748 m
.34502 .48748 L
s
.34127 .51185 m
.34502 .51185 L
s
.34127 .53621 m
.34502 .53621 L
s
.34127 .04891 m
.34502 .04891 L
s
.34127 .02455 m
.34502 .02455 L
s
.34127 .00018 m
.34502 .00018 L
s
.34127 .58494 m
.34502 .58494 L
s
.34127 .60931 m
.34502 .60931 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dw) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .0539 m
.02499 .05416 L
.02605 .05448 L
.02729 .05498 L
.02846 .05555 L
.03279 .05855 L
.03524 .06081 L
.0375 .06319 L
.04262 .06942 L
.05285 .08305 L
.05786 .08888 L
.06244 .09298 L
.06359 .09378 L
.06485 .09452 L
.06605 .09512 L
.06713 .09554 L
.0684 .09591 L
.06909 .09605 L
.06975 .09614 L
.07092 .0962 L
.07218 .09612 L
.07347 .09588 L
.07421 .09568 L
.07489 .09544 L
.07628 .09482 L
.07776 .09396 L
.08045 .09191 L
.0829 .08951 L
.08823 .0828 L
.09403 .07391 L
.09947 .06507 L
.10458 .0573 L
.10697 .0541 L
.10948 .05115 L
.11181 .04888 L
.11398 .04722 L
.11513 .04654 L
.11636 .04596 L
.11707 .04571 L
.11773 .04552 L
.11897 .0453 L
.11962 .04526 L
.12032 .04527 L
.12155 .04543 L
.12224 .04559 L
.12289 .0458 L
.12435 .04646 L
.12565 .04725 L
.12707 .04834 L
.12965 .0509 L
Mistroke
.13448 .05755 L
.14536 .07848 L
.15024 .0886 L
.15552 .09842 L
.15794 .1022 L
.1605 .10552 L
.16268 .10772 L
.16392 .10868 L
.16507 .10938 L
.16576 .1097 L
.1665 .10997 L
.16721 .11014 L
.16786 .11023 L
.16909 .11022 L
.17039 .10994 L
.17107 .10968 L
.17179 .10932 L
.1731 .10845 L
.17466 .10704 L
.17609 .1054 L
.17841 .10203 L
.18095 .09739 L
.18606 .0854 L
.19617 .05517 L
.20114 .04011 L
.20571 .02808 L
.20822 .02274 L
.21099 .01826 L
.21242 .0166 L
.21311 .01597 L
.21376 .01549 L
.2145 .01509 L
.21518 .01484 L
.21591 .01472 L
.2167 .01476 L
.21789 .01517 L
.21921 .01612 L
.21987 .0168 L
.22059 .0177 L
.22188 .01974 L
.22438 .0253 L
.22667 .03231 L
.2314 .05268 L
.23646 .0832 L
.24557 .15871 L
.26626 .38086 L
.27649 .47986 L
.28226 .52358 L
.28501 .5406 L
.28759 .55417 L
Mistroke
.29002 .56487 L
.29224 .57286 L
.29471 .57975 L
.29607 .58269 L
.29737 .58494 L
.29861 .58662 L
.29929 .58734 L
.29994 .5879 L
.30119 .58865 L
.30232 .58897 L
.30298 .589 L
.30368 .58892 L
.30492 .58849 L
.30561 .5881 L
.30626 .58764 L
.30773 .58629 L
.31678 .57123 L
.32638 .55179 L
.32879 .54783 L
.33139 .54433 L
.33288 .54276 L
.33424 .54161 L
.33554 .5408 L
.3362 .54049 L
.33692 .54024 L
.3382 .54002 L
.33936 .54007 L
.34 .54019 L
.3407 .54041 L
.34196 .54103 L
.34315 .54185 L
.34441 .54299 L
.34666 .54568 L
.34918 .5496 L
.35189 .55475 L
.35678 .56587 L
.36249 .58009 L
.36791 .59239 L
.37035 .59685 L
.37295 .60048 L
.37372 .6013 L
.37444 .60195 L
.37515 .60247 L
.37579 .60284 L
.37706 .60327 L
.37773 .60332 L
.37843 .60324 L
.37958 .60281 L
.38081 .60192 L
.38196 .60066 L
Mistroke
.38302 .59913 L
.38425 .59688 L
.3856 .59383 L
.38804 .58669 L
.39039 .57781 L
.39291 .56602 L
.39747 .53883 L
.40787 .4515 L
.42889 .22251 L
.43899 .12784 L
.44471 .08759 L
.44744 .07241 L
.45002 .06058 L
.45247 .05159 L
.45375 .04772 L
.45512 .04426 L
.45626 .04185 L
.45752 .0397 L
.45867 .0382 L
.45974 .03717 L
.46038 .03672 L
.46108 .03637 L
.46236 .03609 L
.46359 .03624 L
.46474 .03674 L
.46598 .03762 L
.46734 .03899 L
.47011 .04288 L
.48032 .06503 L
.48589 .07786 L
.4886 .08326 L
.49107 .08742 L
.49335 .09049 L
.49551 .09262 L
.49669 .09346 L
.49778 .094 L
.49898 .09436 L
.50025 .09445 L
.50144 .09426 L
.50272 .09378 L
.50393 .09305 L
.50503 .09216 L
.50773 .08913 L
.5103 .08522 L
.5199 .06453 L
.52448 .05369 L
.5288 .04478 L
.53126 .04078 L
.53256 .03911 L
.53392 .03771 L
Mistroke
.53508 .03684 L
.53634 .03626 L
.53749 .03609 L
.53857 .03625 L
.53921 .0365 L
.53992 .03692 L
.5412 .03805 L
.54244 .03965 L
.54359 .04157 L
.5462 .0476 L
.54897 .05661 L
.55136 .06661 L
.55387 .07937 L
.55836 .10783 L
.56847 .19546 L
.58676 .39583 L
.59633 .49056 L
.60158 .53227 L
.60653 .5631 L
.61116 .58388 L
.61377 .59218 L
.61501 .59528 L
.61617 .5977 L
.61723 .59952 L
.61819 .60085 L
.61926 .60199 L
.62042 .60281 L
.62152 .60323 L
.62272 .6033 L
.62386 .603 L
.62491 .60243 L
.62608 .60149 L
.62732 .60017 L
.62953 .59704 L
.63452 .58719 L
.64354 .56508 L
.64829 .55438 L
.6509 .54946 L
.65337 .54564 L
.65477 .54388 L
.65629 .54233 L
.65767 .54126 L
.65894 .54056 L
.66014 .54016 L
.66146 .54001 L
.66213 .54005 L
.66284 .54018 L
.66413 .54064 L
.66482 .541 L
.66546 .5414 L
Mistroke
.66667 .54235 L
.66937 .54527 L
.67171 .5486 L
.67424 .55291 L
.67961 .56363 L
.68527 .57534 L
.68768 .57979 L
.69026 .58383 L
.69174 .58571 L
.69309 .5871 L
.69374 .58764 L
.69445 .58814 L
.69574 .58876 L
.69689 .58899 L
.69816 .58887 L
.6988 .58865 L
.69949 .58829 L
.70074 .58731 L
.70191 .58597 L
.70315 .5841 L
.70536 .57957 L
.70794 .57227 L
.71037 .56332 L
.71491 .54103 L
.71981 .50911 L
.72511 .46596 L
.74348 .27344 L
.75375 .16518 L
.76336 .08444 L
.76819 .05479 L
.77068 .04274 L
.77338 .03212 L
.77492 .02726 L
.77634 .02349 L
.77781 .02032 L
.77914 .01808 L
.78046 .01644 L
.78169 .01541 L
.783 .01482 L
.78373 .01472 L
.78441 .01475 L
.78568 .01517 L
.78688 .01596 L
.78795 .01698 L
.78912 .01841 L
.79175 .02269 L
.79417 .02781 L
.80327 .05345 L
.80842 .06949 L
.81395 .08543 L
Mistroke
.81663 .09211 L
.81917 .09763 L
.82149 .10186 L
.82395 .10545 L
.82521 .1069 L
.82638 .10803 L
.82753 .10891 L
.82859 .10952 L
.82959 .10993 L
.83066 .11019 L
.83172 .11026 L
.8329 .11012 L
.83417 .10973 L
.83533 .10916 L
.83667 .10825 L
.83794 .10715 L
.8402 .10468 L
.84266 .10131 L
.85246 .08305 L
.85766 .07217 L
.86328 .06132 L
.86587 .05699 L
.86859 .05306 L
.87112 .05006 L
.87347 .0479 L
.8746 .04708 L
.87568 .04644 L
.87691 .04588 L
.87804 .04552 L
.87928 .0453 L
.88043 .04526 L
.8817 .0454 L
.88233 .04554 L
.88304 .04574 L
.88444 .04632 L
.88577 .04706 L
.88826 .04895 L
.89095 .05162 L
.89388 .0552 L
.90404 .07078 L
.90891 .07857 L
.91418 .08606 L
.9166 .08896 L
.91916 .09155 L
.92137 .09336 L
.92373 .09482 L
.92515 .09545 L
.92645 .09586 L
.92775 .09611 L
.92898 .0962 L
Mistroke
.92968 .09618 L
.93041 .09612 L
.93104 .09602 L
.93174 .09588 L
.93248 .09567 L
.93329 .09539 L
.93474 .09474 L
.93727 .09319 L
.93994 .09102 L
.94471 .08602 L
.97619 .0539 L
Mfstroke
gsave
.65873 .31693 -82.1875 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\254) show
76.188 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
94.188 13.000 moveto
(\\256) show
101.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.0238095 1.34202 0.97619 1.93062 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.15873 0.0147151 0.588604 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.18254 .00222 -6 -9 ]
[.18254 .00222 6 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -3 -9 ]
[.81746 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.32877 .13244 -18 -4.5 ]
[.32877 .13244 0 4.5 ]
[.32877 .25016 -18 -4.5 ]
[.32877 .25016 0 4.5 ]
[.32877 .36788 -18 -4.5 ]
[.32877 .36788 0 4.5 ]
[.32877 .4856 -18 -4.5 ]
[.32877 .4856 0 4.5 ]
[.32877 .60332 -6 -4.5 ]
[.32877 .60332 0 4.5 ]
[.34127 .64303 -8 0 ]
[.34127 .64303 8 12 ]
[.5 .63053 -14.5625 0 ]
[.5 .63053 14.5625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-2)] .02381 .00222 0 1 Mshowa
.18254 .01472 m
.18254 .02097 L
s
[(-1)] .18254 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(3)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 .13244 m
.34752 .13244 L
s
[(0.2)] .32877 .13244 1 0 Mshowa
.34127 .25016 m
.34752 .25016 L
s
[(0.4)] .32877 .25016 1 0 Mshowa
.34127 .36788 m
.34752 .36788 L
s
[(0.6)] .32877 .36788 1 0 Mshowa
.34127 .4856 m
.34752 .4856 L
s
[(0.8)] .32877 .4856 1 0 Mshowa
.34127 .60332 m
.34752 .60332 L
s
[(1)] .32877 .60332 1 0 Mshowa
.125 Mabswid
.34127 .04415 m
.34502 .04415 L
s
.34127 .07358 m
.34502 .07358 L
s
.34127 .10301 m
.34502 .10301 L
s
.34127 .16187 m
.34502 .16187 L
s
.34127 .1913 m
.34502 .1913 L
s
.34127 .22073 m
.34502 .22073 L
s
.34127 .27959 m
.34502 .27959 L
s
.34127 .30902 m
.34502 .30902 L
s
.34127 .33845 m
.34502 .33845 L
s
.34127 .39731 m
.34502 .39731 L
s
.34127 .42674 m
.34502 .42674 L
s
.34127 .45617 m
.34502 .45617 L
s
.34127 .51503 m
.34502 .51503 L
s
.34127 .54446 m
.34502 .54446 L
s
.34127 .57389 m
.34502 .57389 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
75.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -75.5625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Dw) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\260) show
88.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .01472 L
.10458 .01472 L
.14415 .01472 L
.18221 .01472 L
.22272 .01472 L
.24141 .01472 L
.25127 .01472 L
.25666 .01472 L
.2593 .01472 L
.26045 .01472 L
.26171 .01472 L
.26301 .60332 L
.26425 .60332 L
.26698 .60332 L
.27279 .60332 L
.28302 .60332 L
.30316 .60332 L
.3438 .60332 L
.38293 .60332 L
.39322 .60332 L
.40434 .60332 L
.40945 .60332 L
.41485 .60332 L
.41707 .60332 L
.4183 .60332 L
.41945 .60332 L
.42011 .60332 L
.42082 .01472 L
.42207 .01472 L
.42451 .01472 L
.46529 .01472 L
.50456 .01472 L
.54231 .01472 L
.56166 .01472 L
.56696 .01472 L
.57254 .01472 L
.57484 .01472 L
.5773 .01472 L
.57803 .01472 L
.57872 .01472 L
.58 .60332 L
.58121 .60332 L
.58251 .60332 L
.62343 .60332 L
.66284 .60332 L
.70072 .60332 L
.72017 .60332 L
.72577 .60332 L
.73109 .60332 L
Mistroke
.7334 .60332 L
.73586 .60332 L
.73659 .60332 L
.73728 .60332 L
.73856 .01472 L
.73976 .01472 L
.74106 .01472 L
.78212 .01472 L
.82166 .01472 L
.85968 .01472 L
.90016 .01472 L
.93912 .01472 L
.97619 .01472 L
Mfstroke
gsave
.65873 .30902 -79.1875 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(\\254) show
76.188 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
88.188 13.000 moveto
(\\256) show
95.375 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{273.562, 541},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005E0002Y2000`400?l00000o`00003ooooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00Loooool00ol0003ooooooooo
o`3Oooooo`00FOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Ooo
ool00ol0003oooooooooo`3Oooooo`00FOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3Oooooo`00DOoo
ool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0003Oooooo`00:oooool2o`0002cooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0Woooool3o`0003gooooo000Wooooo`Co000000Co
ooooo`000?l0003o0000:_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`2Mooooo`?o000000Coooooo`000?l0003o0000>oooool002Ko
oooo0_l00007ooooo`;o0000:?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Kooooo`;o00001oooool00ol0003oooooooooo`0hoooo
o`009Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00Sooooo0_l0000hooooo`009?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0=Oooool002?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0d
ooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0Uoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Gooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0kooooo`;o0000Uoooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03;ooooo000Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<Ooo
ool001oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0`ooooo`007_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0U?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo000Nooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0;oooool001gooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0^ooooo`007Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool0Toooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02kooooo000L
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2B
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;Oooool001_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0gooooo`;o0000Toooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo02cooooo000Kooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0;?ooool001[ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0[ooooo`006_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0TOoo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo000Iooooo`Ko00007?ooool0
0ol0003oooooooooo`0:ooooo`Co000000?o410@ooooooooool09?ooool00ol0003oooooooooo`0X
ooooo`Co000000?o410@ooooooooool09_ooool5o`0002Sooooo00GoV9RHoa0@4?l0003o<S8bolc<
c00:ooooo`03o`000?oooooooooo01gooooo0_l000000ol@413oooooooooo`0Yooooo`006_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A401cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:?ooool01OnHV9So8B4Qonk^
k_ooooooA4A402Sooooo00Go410@okZj^_ooooooMgMgoc8b<P09ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0:_ooool001;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo
00?o0000ooooooooool01_l00005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Yooooo`03oiRHV?lQ8B7ok^k^02gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Looooo`Go0000:oooool001cooooo00?oV9RHob4Q8Oo^k^h07Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0Zooooo`03oiRHV?lQ8B7ok^k^02_ooooo00?oZJVYoa0@4?ooool01ooo
ool00ol0003oooooooooo`0Mooooo`04odA4A?oMgMgoooooo`0002cooooo000Mooooo`03ogMgMomV
IVKooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`;o0000:ooo
ool00ol0003oooooooooo`0[ooooo`03ogMgMomVIVKooooo02Wooooo00?o410@o`000?nj^[X02?oo
ool00ol0003oooooooooo`0Mooooo`04omgMgOmEEEGoooooo`0002cooooo000Nooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Yooooo`03okZj^_lQ
8B7ooooo00Oooooo00?o0000ooooooooool07_ooool00omgMgOoc<c<o`00000/ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:?ooool01Ol0003o^[Zjoooo
oonHV9So410@02Sooooo00Go410@oiRHV?oooooo^[Zjo`000007ooooo`03o`000?oooooooooo01oo
oooo00?ok^k^odA4A?l00000;?ooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Nooooo`03
o`000?oooooooooo00Sooooo00?oEEEEofIVI_l00000:?ooool00ol0003oooooooooo`0Xooooo`03
oeEEEOmVIVKo000002[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Xooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01oooool00ol0003oooooooooo`0Pooooo`03ogMgMol0003ooooo02_ooooo000noooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`1?oooo
o`00?_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo08gooooo00?o0000oooooooo
ool0Coooool003kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2=ooooo`03o`00
0?oooooooooo03Gooooo00GoV9RHo`000?l0003oA4A4okZj^P0Eooooo`00?_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0=_ooool01Ol@413o^[Zj
onk^k_mgMgOo410@01Gooooo000Boooooooo00007ol0000;ooooo`03o`000?oooooooooo01Oooooo
000Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool001Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`00@?ooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0=Oooool00ol@413o0000o`000003
o`0001Kooooo0010ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0Roooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo01Oooooo0010ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Oo
oooo0010ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`1Booooo`00@Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0D_ooool0047ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo05?ooooo0011ooooo`03o`000?oooooooooo02oooooo0_l0002:oooo
o`03o`000?oooooooooo05?ooooo0012ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`1Cooooo`00@_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo08Wooooo00?o0000ooooooooool0Doooool004;ooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo05Cooooo0012ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`1Dooooo`00@oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0E?ooool004?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo05Go
oooo0013ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Qoooool00ol0003ooooo
ooooo`1Eooooo`00A?ooool00ol0003oooooooooo`0/ooooo`;o0000R?ooool00ol0003ooooooooo
o`1Eooooo`00A?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08Kooooo00?o0000
ooooooooool0E_ooool004Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`26oooo
o`03o`000?oooooooooo05Kooooo0014ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool0Q_ooool00ol0003oooooooooo`1Fooooo`00AOooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool0E_ooool004Gooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo05Oooooo0015ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`1Gooooo`00A_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0Eoooool004Ko
oooo00?o0000ooooooooool0:_ooool2o`0008Kooooo00?o0000ooooooooool0Eoooool004Kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo05Sooooo
0016ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`1Hooooo`00Aoooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08Cooooo00?o0000
ooooooooool0F?ooool004Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`24oooo
o`03o`000?oooooooooo05Sooooo0017ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0Poooool00ol0003oooooooooo`1Iooooo`00Aoooool00ol0003oooooooooo`0?ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo08?o
oooo00?o0000ooooooooool0FOooool004Sooooo00?o0000ooooooooool03_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo05Wooooo0018ooooo`03o`000?oooooooooo00ko
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000oooo
ooooool0Poooool00ol0003oooooooooo`1Iooooo`00B?ooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`?o0000P_ooool00ol0
003oooooooooo`1Jooooo`00B?ooool00ol0003oooooooooo`0>ooooo`05o`000?oooooooooooooo
ool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo02Wooooo1?l0001Eoooo
o`03o`000?oooooooooo05[ooooo0019ooooo`03o`000?oooooooooo00gooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool2o`00
00Cooooo0ol0001Booooo`03o`000?oooooooooo05[ooooo0019ooooo`03o`000?oooooooooo00go
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool0
0ol0003oooooooooo`0Vooooo`;o00002?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo
oooo05[ooooo0019ooooo`03o`000?oooooooooo00gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Kooooo`00B_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05_ooooo001:ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0Foooool004[ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`1Kooooo`00B_ooool00ol0003oooooooooo`0Vooooo`;o00008oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`1Looooo`00Boooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo05cooooo001;ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0G?ooool004_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`1Mooooo`00
C?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`03omgMgOl@413ok^k^01;ooooo00?o<S8bo`000?l00000
0ol000001Olb<S;oooooooooooooooooV9RH00;o000000?oA4A4okZj^_ooool04Oooool00oo^k^ko
410@omgMg@06ooooo`03o`000?oooooooooo05gooooo001<ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo
00?ok^k^ob4Q8OnHV9P04oooool00onHV9SoA4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo
00Go410@okZj^_o^k^koMgMgoa0@400Cooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooooooo
ool0GOooool004cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00olb<S;o0000o`00000;o`0000Wooooo
00Go410@omgMgOoooooogMgMoa0@4004ooooo`03o`000?oooooooooo00[ooooo3Ol000000olb<S;o
ooooooooo`03ooooo`03o`000?oooooooooo05gooooo001<ooooo`03o`000?oooooooooo02Cooooo
0_l0000Oooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00oo<c<co0000
oiRHV00Dooooo`05ohN7QomgMgOoooooofIVI_n7QhL01?ooool00ol0003oooooooooo`0Eooooo`03
oiRHV?l0003oc<c<00Cooooo00?o0000ooooooooool0G_ooool004gooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00oo<c<co410@omgMg@0Cooooo`05onk^k_l@413ok^k^oa0@4?o^k^h01?ooool00ol0003o
ooooooooo`0Dooooo`03omgMgOl@413oc<c<00Gooooo00?o0000ooooooooool0G_ooool004gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool07?ooool00omgMgOo8B4QoeEEE@03ooooo`03oa0@4?l0003o000000?o0000
6oooool00ol0003oooooooooo`1Nooooo`00COooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`03omgMgOl0
003ogMgM00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Nooooo`00COooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Looooo`03ojVYZOoooooooooo00Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Oooooo`00C_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
05oooooo001>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0Goooool004kooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Oooooo`00C_ooool00ol0003ooooooooo
o`0Rooooo`;o00006oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool0H?ooool004oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`1P
ooooo`00Coooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo063ooooo001?ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0H?ooool0053ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`1Qooooo`00D?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo067ooooo001@ooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0HOoo
ool0053ooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0HOooool0057ooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo06;ooooo001Aooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo0ol0000Gooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Rooooo`00DOooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo06;ooooo001Aooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0H_ooool005;ooooo
00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l0
00001_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1Sooooo`00D_ooool00ol0003oooooooooo`04ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo06?o
oooo001Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Hoooool005;ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1Sooooo`00Doooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo06Cooooo001Cooooo`03o`000?oooooooooo01gooooo0_l0000Eoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Toooo
o`00Doooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06Cooooo001Cooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool0IOooool005Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`1Uooooo`00E?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo06Gooooo001Dooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0IOooool005Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Vooooo`00EOooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo06Kooooo001Eooooo`03o`000?oooooooooo01_ooooo0_l0
000Booooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1Vooooo`00EOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo06Kooooo001Eoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Ioooool005Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`1Wooooo`00E_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo06Oooooo001Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0Iooo
ool005Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Xooooo`00E_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo06Sooooo001Gooooo`03o`000?oooooooooo01Wo
oooo0_l0000@ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1Xooooo`00Eoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06Sooooo
001Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0JOooool005Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Yooooo`00F?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo06Wooooo001Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0J_ooool005Sooooo00Ko0000onk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000
ooooooooool05?ooool5o`0000;ooooo00Go410@o`000?l0003o0000oa0@400Hooooo`03o`000?oo
oooooooo00Gooooo0_l0000Pooooo`03o`000?oooooooooo06[ooooo001Iooooo`05o`000?nHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`00
0?oooooooooo00;ooooo0_l00009ooooo`03o`000?oooooooooo01Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A004ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool2o`0001ko
oooo00?o0000ooooooooool0J_ooool005Wooooo00Go0000oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool05_ooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06[ooooo001Ioooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo8ol0
0006ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00?o0000ooooooooool01_oooolPo`0001_ooooo00?o
0000ooooooooool0Joooool005Wooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo00Go0000
oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`03o`000?oo
oooooooo01Sooooo00?oMgMgofIVI_ooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Gooooo0ol0000Mooooo`03o`000?oooooooooo06_ooooo001Iooooo`05oa0@4?l0003o
ooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000000;ooooo00Co
0000oooooooooooo00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0Joooool005Wooooo00GoMgMgo`000?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`07o`00
0?nj^[[ooooooiRHV?l@413oooooo`000002ooooo`04o`000?ooooooooooo`0001Wooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1[ooooo`00FOooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Kooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?ooool7o`0001[ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`1/ooooo`00Foooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo06cooooo001Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0K?oo
ool005cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1]ooooo`00G?ooool00ol0
003oooooooooo`0Dooooo`;o00002_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0KOooool005cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1]ooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06kooooo
001Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0K_ooool005gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1^ooooo`00G_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo06oooooo001Nooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0Koooool005kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1_ooooo`00Gooo
ool00ol0003oooooooooo`0Aooooo`;o00001oooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0L?ooool005oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1`ooooo`00Goooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
073ooooo001Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0LOooool0063ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`1aooooo`00HOooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo077ooooo001Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0L_ooool006;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1boooo
o`00H_ooool00ol0003oooooooooo`0>ooooo`;o00001?ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0Loooool006?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1dooooo`00Hoooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo07Cooooo001Tooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
001Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0MOooool006Cooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000005?ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1eooooo`00I?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooo
ooooo`0005Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1fooooo`00FOooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B402Ol0003oooooooooooooooooc<c<ob4Q8Ol0
003o8B4Qolc<c005ooooo`03o`000?oooooo000005Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1fooooo`00FOooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B402Ooo
oooo0000oooooooooooo8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`;o0000F?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo07Kooooo001Iooooo`05oa0@4?ooooooooooooooool@4100
2?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0F?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Oooooo001Iooooo`05o`00
0?ooooooooooooooool000002Oooool2o`000005oc8b<_nHV9SooooooiRHV?lb<S801?ooool4o`00
05Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1hooooo`00FOooool01Ol0003o
oooooooooooooooo000000_ooooo1?l000000oo<c<coooooooooo`02ooooo`;o0000Foooool2o`00
00Oooooo0_l0001kooooo`00FOooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@o`00
0?oooooo^[Zjoa0@4002ooooo`;o000000?oooooo`000?ooool0G?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07_ooooo001Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003o^[Zjo`000005o`0000;ooooo00?o0000ooooooooool0G?ooool5o`0007kooooo001Ioooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o
0000ooooooooool0goooool007?ooooo00?o0000ooooooooool0goooool007?ooooo00?o0000oooo
ooooool0goooool007?ooooo00?o0000ooooooooool0goooool00?ooooooE_ooool00?ooooooE_oo
ool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_oo
ool00?ooooooE_ooool0097ooooo00?o<S8bo`000?l000000ol000002Olb<S;oooooohN7Qol0003o
EEEEofIVI_l0003o<S8bonk^kP09ooooo`05oiRHV?l@413o0000oc8b<_o<c<`0Yoooool0097ooooo
00?oV9RHodA4A?ooool00_ooool02om4A4CoV9RHooooool@413ogMgMogMgMolQ8B7oooooohN7QomV
IVKooooo00Ko00000_ooool01Ol@413o^[ZjoooooomgMgOo<S8b0:Oooooo002Booooo`05oa0@4?oM
gMgoooooomgMgOl@41000_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41003Oooool00ol0
003oooooooooo`2Uooooo`00T_ooool01On7QhOoMgMgoooooomVIVKoQhN700;ooooo00CoEEEEojVY
ZOoooooo00000_ooool00ol0003oooooo`000005o`0000Gooooo00?oZJVYoa0@4?ooool0Y_ooool0
09;ooooo00Gok^k^oa0@4?o^k^ko410@onk^kP02ooooo`03omgMgOlQ8B7ok^k^00?ooooo00?o0000
ooooooooool02Oooool00ol@413o0000okZj^P2Wooooo`00Toooool00omgMgOo8B4QoeEEE@04oooo
o`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool02_ooool00onj^[[o8B4Qooooo`2Voooo
o`00Toooool00ooMgMgo0000omgMg@0Cooooo`05oa0@4?nHV9SooooookZj^_l00000Yoooool009Co
oooo00?oZJVYooooooooool04_ooool01OnYZJWo410@o`000?l@413oZJVY0:Oooooo003ooooooeKo
oooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKo
oooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKo
oooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKo
oooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKo
oooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKooooo003ooooooeKo
oooo001cooooo`;o0000h?ooool007?ooooo00?o0000ooooooooool0goooool007?ooooo00?o0000
ooooooooool0goooool007?ooooo00?o0000ooooooooool0goooool004gooooo0ol0000Sooooo`03
o`000?oooooooooo07_ooooo1?l0001Pooooo`00COooool01?l0003oooooooooool0000Rooooo`03
o`000?oooooooooo07_ooooo00Co0000oooooooooooo0000H?ooool004cooooo00Go0000oooooooo
ooooooooo`00000Rooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1Mooooo`00C?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oo
oooo0_l0001kooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool001Sooooo
1Ol0000Zooooo`Go00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Sooooo
1?l000000ol@413oooooooooo`0Vooooo`Go00008?ooool00ol0003oooooooooo`02ooooo`09o`00
0?oooooooooooooooonHV9So410@o`000?lb<S;oc<c<02_ooooo0_l000000ol@413oooooooooo`0W
ooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A402cooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A401oooooo00?o0000ooooooooool00oooool02Ol0003ooooooooo
oooooooo410@okZj^_ooooooMgMgoc8b<P0/ooooo`03o`000?oooooooooo02Sooooo000@ooooo`Ko
00000oooool00onHV9So8B4Qonk^kP0Rooooo`Ko00001Oooool2o`0000Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Oooooo`?o00002?ooool00ol0003oooooooooo`07ooooo`?o
00007oooool00onHV9So8B4Qonk^kP0Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Wooooo`Go0000:Oooool001[ooooo00?oV9RHob4Q8Oo^k^h0
;?ooool2o`0000Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool01_ooool2o`000003ooooool0003o000001oo
oooo00?oV9RHob4Q8Oo^k^h07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?oZJVYoa0@4?ooool0:?ooool01?m4A4CogMgMooooool0000Zooooo`006oooool00omgMgOo
IVIVooooo`0[ooooo`;o00001oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01go
oooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo0000023ooooo00?oMgMgofIVI_ooool07_ooool00ol0003oooooooooo`05oooo
o`07o`000?ooooooooooooooool@413o0000okZj^P0Yooooo`04omgMgOmEEEGoooooo`0002[ooooo
000Looooo`03o`000?oooooooooo01;ooooo1?l0000Dooooo`;o00001oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03okZj^_lQ8B7ooooo00gooooo1Ol0000Gooooo`03ogMgMoo<c<co000002[ooooo000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`;o00007_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_ooooooV9RH
oa0@400Nooooo`03o`000?oooooooooo00Kooooo00Oo0000ooooool@413oV9RHoooooonj^[[o0000
00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03onk^k_m4A4Co0000
02[ooooo000Gooooo`;o000000Co410@o`000?lQ8B7oc<c<4_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?oEEEEofIVI_l000002Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Ioooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`07_ooool00ol0003oooooooooo`07ooooo`06o`000?nYZJWo
410@o`000?l@413oZJVY3Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo
00?oMgMgo`000?ooool0:Oooool001Sooooo0_l0000Dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0:Oooool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02[ooooo000Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`05oiRHV?l0003o0000odA4A?nj^[X05?ooool0
01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01?ooooo00Go410@okZj^_o^k^koMgMgoa0@400Dooooo`007?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Foooo
o`004?ooooooo`0002?o00002_ooool00ol0003oooooooooo`0Fooooo`005oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo0_l00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool000002?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool000001_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Ko
oooo000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Sooooo0_l0000=ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool00ol@413o0000o`000003o`0001Gooooo000Oooooo`;o00002?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool0027ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05_ooool002;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool2o`0000;ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<oooool002;ooooo1Ol0000Eooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03?ooool3o`0000oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool5o`0003Kooooo000mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`;o
00006oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04kooooo000nooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1?ooooo`00?_oo
ool01?l0003oooooooooooooool2o`00017ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Coooool003oooooo1?l0
000Booooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool04Oooool4o`0005;ooooo001E
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Ioooool005Gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`1Wooooo`00EOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo06Oooooo001Fooooo`03o`000?oooooooooo01[ooooo0_l0000Jooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Wooooo`00E_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06Oooooo001Fooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0Ioooool005Kooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`1Wooooo`00E_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo06Oo
oooo001Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0Ioooool005Kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1Wooooo`00Eoooool00ol0003oooooooooo`0I
ooooo`;o00006Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0J?ooool005Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`1Xoooo
o`00Eoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06Sooooo001Gooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0J?ooool005Oooooo00Ko0000onk^k_lb<S;o0000
oc8b<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0J?ooool005Oooooo
00Ko0000ogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0J?ooool005Oooooo00?o0000oa0@4?ooool00_ooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0J?ooool005Oo
oooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0001Wo
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo06So
oooo001Gooooo`;o00000oooool00ol0003oooooooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0J?ooool005Sooooo00Go0000oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0J?ooool005Sooooo00Go0000oiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1Xooooo`00
F?ooool01Ol0003o<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo06Wooooo001Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0JOooool005Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Yooooo`00F?oo
ool00ol0003oooooooooo`0Hooooo`;o00006?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0JOooool005Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`1Yooooo`00F?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
06Wooooo001Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0JOooool005Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`1Yooooo`00F?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo06Wooooo001Iooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0JOooool005Wooooo00?o0000ooooooooool05oooool2o`0001Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo06Wooooo001Iooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0J_ooool005Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`1Zooooo`00FOooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo06[ooooo001Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0J_ooool0
05Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Zooooo`00FOooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo06[ooooo001Iooooo`03o`000?oooooooooo01Oooooo
0_l0000Fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`1Zooooo`00FOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo06[ooooo001I
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0J_ooool005[ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Zooooo`00F_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo06[ooooo001Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06_ooooo001Hooooo`05ogMg
MonHV9So0000oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`1[ooooo`00F?ooool01Ol@413oooooo`000?oooooo410@00_ooooo1Ol00006ooooo`;o
00005_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0Joooool005Sooooo00Go0000ooooool0003oooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0Joooool005Sooooo00Go0000ooooool0003oooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Joooool005Sooooo00Go410@oooo
ool0003ooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Joooool0
05Sooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0Joooool005Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0Joooool005[ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`1[ooooo`00Foooool00ol0003oooooooooo`0Eooooo`;o00005Oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0Joooool005_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`1/ooooo`00Foooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo06cooooo001Kooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0K?ooool005_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02[ooooo00Co0000omgMgOl@413ok^k^3?ooool00olb<S;o0000o`000003
o`000005oc8b<_oooooooooooooooonHV9P00_l000000om4A4Co^[Zjooooo`0:ooooo`03onk^k_l@
413ogMgM00;ooooo00?o0000ooooooooool0K?ooool005_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo00?o0000ob4Q8OnHV9P03Oooool0
0onHV9SoA4A4ooooo`02ooooo`03odA4A?nHV9Sooooo00;ooooo00Go410@okZj^_o^k^koMgMgoa0@
400<ooooo`05oiRHV?lQ8B7ok^k^ooooool00000K_ooool005_ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo1ol0000:ooooo`05oa0@4?oM
gMgoooooomgMgOl@41001?ooool00ol0003oooooooooo`0:ooooo`Ko000000?o<S8booooool00000
K_ooool005_ooooo00?o0000ooooooooool05Oooool2o`0001Gooooo00?o0000ooooooooool0:_oo
ool2o`000003oiRHV?oooooooooo00cooooo00GoQhN7ogMgMoooooooIVIVohN7Q`04ooooo`03o`00
0?oooooooooo00kooooo00GoV9RHo`000?o<c<coooooo`00001^ooooo`00Foooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:oooool01?l0003oc<c<
oa0@4?oMgMd=ooooo`05onk^k_l@413ok^k^oa0@4?o^k^h01?ooool00ol0003oooooooooo`0=oooo
o`03omgMgOl@413oc<c<00;ooooo00?o0000ooooooooool0K?ooool005_ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool03oooool00omgMgOo8B4QoeEEE@03ooooo`03oa0@4?l0003o000000?o00004Oooool00ol0003o
ooooooooo`1/ooooo`00Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0?ooooo`03omgMgOl0003ogMgM00Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1]ooooo`00G?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0@ooooo`03ojVYZOoooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1]ooooo`00G?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo06gooooo001Loooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0KOooool005cooooo00?o0000oooooooo
ool05?ooool2o`0001Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo06gooooo001Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
KOooool005cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1]ooooo`00G?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo06gooooo001Looooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0KOooool005Sooooo00Gok^k^oc8b<_l0003o<S8bo`000005oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0K_ooool0
05Sooooo00GoMgMgoiRHV?ooooooV9RHo`000005ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonH
V9So8B4Q00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0K_ooool005Sooooo00Go410@ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000001_ooool2o`0001?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06kooooo001Hooooo`04o`000?oo
ooooooooooooo`;o00002_ooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0K_ooool005Sooooo00Co0000oooooooooooooooo0_l0000:ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1^ooooo`00F?ooool01_l@413ooooooooooooooooo410@
o`0000[ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1^ooooo`00F?ooool01_mg
MgOoV9RHoooooonHV9SoMgMgo`0000[ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1^ooooo`00F?ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000_ooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`1^ooooo`00GOooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo06kooooo001Mooooo`03o`000?oooooooooo01?ooooo0_l0000Cooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1_ooooo`00GOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo001Mooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0Koooool005gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1_ooooo`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo
001Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool005kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1_ooooo`00G_ooool00ol0003oooooooooo`0Boooo
o`;o00004_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0Koooool005kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1_ooooo`00
G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo073ooooo001Nooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0L?ooool005kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1`ooooo`00G_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
073ooooo001Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0L?ooool005oooooo
00?o0000ooooooooool04Oooool2o`00017ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo073ooooo001Oooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0L?ooool005oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`
ooooo`00Goooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo073ooooo001Oooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0LOooool005Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`03o`000?oooooooooo00;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0LOooool005Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02oooo
o`03o`000?oooooooooo00;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0LOooool005Sooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000006ooooo`;o00004Oooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0LOooool005Sooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo077ooooo001Hooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1aooooo`00F?ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooooooo
ool01Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0LOooool005So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00Gooooo00Go0000okZj
^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo077ooooo001Hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool00ol0003oooooooooo`05ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo077ooooo001Pooooo`03o`000?oooooooooo013ooooo0_l0000@ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo07;ooooo001Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0L_ooool0067ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`1booooo`00HOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07;ooooo001Qoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0L_ooool0067ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1booooo`00HOooool00ol0003oooooooooo`0?ooooo`;o0000
3oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
L_ooool0067ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1booooo`00H_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo001Rooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Loooool006;ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`1cooooo`00H_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07?ooooo
001Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Loooool006;ooooo00?o0000
ooooooooool03_ooool2o`0000kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo07?ooooo001Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1dooooo`00H_ooool00ol0003oooooooooo`0;ooooo`Co
00003oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00gooooo1?l0000<ooooo`03
o`000?oooooooooo07Cooooo001Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_l0000>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000000cooooo00?o0000ooooooooool0M?ooool006;ooooo00?o0000ooooooooool0
2_ooool01ol0003ooooooooooooooooo0000ooooool000003?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07Cooooo001Sooooo`03o`000?oooooooooo00?ooooo1?l000000ol@413o
0000ooooo`03ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1dooooo`00Hoooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Gooooo001Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool2o`000003
ooooool0003ooooo00[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1eooooo`00
I?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Gooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0MOooool006Cooooo
00?o0000ooooooooool01?ooool2o`0000Kooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0MOooool006Cooooo00?o0000ooooooooool0
1?ooool2o`0000Kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0M_ooool006Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07Kooooo001Tooooo`03o`000?oooooooooo00;ooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1fooooo`00IOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0M_ooool006Kooooo00Go0000oooo
ooooooooooooo`000008ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`05o`000?oooooo
ooooooooool00000NOooool006Kooooo1?l00009ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03_ooool4o`0007Wooooo001Wooooo`;o00002_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00oooooo0_l0001jooooo`00Loooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0?oooool2o`0000?ooooo00?o0000oooooooo
ool0S?ooool007?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000004;o
oooo00Go0000ooooooooooooooooo`00002>ooooo`00Loooool00ol0003oooooooooo`06ooooo`04
o`000?oooooo0000o`0004;ooooo0_l000000ooooooo0000ooooo`2>ooooo`00Loooool00ol0003o
ooooooooo`06ooooo`?o0000A?ooool2o`00093ooooo001cooooo`03o`000?oooooooooo0=oooooo
001cooooo`;o0000h?ooool007?ooooo00?o0000ooooooooool0goooool007?ooooo00?o0000oooo
ooooool0goooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool0
0?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool008kooooo00?o<S8bo`000?l000000ol0
00002Olb<S;oooooohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP09ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kZ?ooooo002>ooooo`03oiRHV?m4A4Cooooo00;ooooo00_o
A4A4oiRHV?oooooo410@omgMgOmgMgOo8B4Qoooooon7QhOoIVIVooooo`06o`0000Cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg0:?ooooo002?ooooo`05oa0@4?oMgMgo
ooooomgMgOl@41000_ooool01ol0003oooooomgMgOlb<S;oooooonk^k_l@41002oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100Xoooool008oooooo00GoQhN7ogMgMooo
ooooIVIVohN7Q`02ooooo`04oeEEEOnYZJWoooooo`0000;ooooo00?o0000ooooool000001Ol00004
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002Sooooo`00Soooool0
1Oo^k^ko410@onk^k_l@413ok^k^00;ooooo00?ogMgMob4Q8Oo^k^h00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00002Sooooo`00T?oo
ool00omgMgOo8B4QoeEEE@04ooooo`03oiRHV?mgMgOooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100Xoooool0093ooooo00?o
gMgMo`000?oMgMd05Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
Xoooool0097ooooo00?oZJVYooooooooool04_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0Xoooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool0023ooooo1Ol0000Wooooo`Co000000?o410@ooooooooool0C?ooool4o`000003oa0@
4?oooooooooo02?ooooo1Ol0000Vooooo`05oiRHV?l@413o0000oc8b<_o<c<`0:?ooool2o`000003
oa0@4?oooooooooo02oooooo000Pooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Voooo
o`05oa0@4?nj^[[oooooogMgMolb<S80:Oooool00ol0003oooooooooo`0`ooooo`006?ooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h07oooool6o`0000Gooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0Vooooo`03oiRHV?lQ8B7ok^k^02_ooooo00?o0000ooooooooool09?ooool5o`00
037ooooo000Rooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0Wooooo`03oiRHV?lQ8B7ok^k^02Wooooo00?oZJVYoa0@4?ooool09Oooool01?m4A4Co
gMgMooooool0000booooo`008oooool00omgMgOoIVIVooooo`0Xooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool0:?ooool00omgMgOoIVIVooooo`0Wooooo`03oa0@4?l0003o^[Zj02Ko
oooo00CogMgMoeEEEOoooooo0000<_ooool002Cooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00onj^[[o
8B4Qooooo`0Vooooo`03ogMgMoo<c<co000003;ooooo000Pooooo`05o`000?nj^[[ooooooiRHV?l@
4100:Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00Go0000okZj^_oo
ooooV9RHoa0@400Vooooo`05oa0@4?nHV9SooooookZj^_l000009oooool00oo^k^koA4A4o`00000b
ooooo`008?ooool01OnHV9So410@o`000?lQ8B7oc<c<02Oooooo00?oEEEEofIVI_l00000D?ooool0
0omEEEGoIVIVo`00000Wooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool01OnYZJWo410@o`00
0?l@413oZJVY02Sooooo00?oMgMgo`000?ooool0<Oooool007Kooooo00?o0000ooooooooool0g?oo
ool007Kooooo00?o0000ooooooooool0^oooool01OnHV9So0000o`000?m4A4Co^[Zj01cooooo001f
ooooo`03o`000?oooooooooo0;_ooooo00Go410@okZj^_o^k^koMgMgoa0@400Looooo`00M_ooool0
0ol0003oooooooooo`2kooooo`03o`000?oooooooooo01kooooo000Ioooooooo00004_l0000:oooo
o`03o`000?oooooooooo01kooooo000Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`007oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00gooooo00?o410@o`000?l000000ol0000Mooooo`00H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool07_ooool0
063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
01kooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo0_l0000C
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`
ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0
063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo
0_l0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001P
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
L?ooool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo
01?ooooo0_l0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073o
oooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0L?ooool005_ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0L?ooool005_ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol0
0004ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
L?ooool005_ooooo00Ko410@oooooooooooooooooa0@4?l0000;ooooo`03oiRHV?lQ8B7ok^k^00Oo
oooo0_l0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`1`ooooo`00Foooool01?l0003oooooooooooooool2o`0000cooooo00?oV9RHob4Q8Oo^
k^h01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1`ooooo`00Foooool01?l0003oooooooooooooool2o`0000go
oooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00Foooool01_l@413ooooo
oooooooooooo410@o`0000kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`oooo
o`00Foooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000[ooooo00Go0000okZj^_ooooooV9RHoa0@
4006ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo073ooooo001Kooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko0000
2_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo0_l0000C
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`
ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0
063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo
0_l0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001P
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
L?ooool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo
01?ooooo0_l0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073o
oooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0L?ooool005_ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00004ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool005_ooooo00KoMgMgoiRH
V?ooooooV9RHogMgMol00004ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo073ooooo001Kooooo`06oa0@4?ooooooooooooooool@413o00002_ooool5o`0000Kooooo
0_l0000Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1`ooooo`00Foooool01?l0003oooooooooooooool2o`0000[ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`1`ooooo`00Foooool01?l0003oooooooooooooool2o`0000[o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00Foooool01_l@413o
oooooooooooooooo410@o`0000_ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`
ooooo`00Foooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000_ooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1`ooooo`00Foooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000cooooo
00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0L?ooool0063ooooo00?o0000ooooooooool04oooool2o`0001?ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo073ooooo001Pooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0L?ooool0
063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Sooooo00Oo0000ooooooooooooooooomgMgOl@413ok^k^00cooooo00Go410@o`000?l0003o0000
oa0@400=ooooo`03onk^k_l@413ogMgM00Cooooo00?o0000ooooooooool0L?ooool0063ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00Ko
0000ooooooooooook^k^ob4Q8OnHV9P?ooooo`03o`000?oooooooooo00kooooo00?oV9RHob4Q8Oo^
k^h00oooool00ol0003oooooooooo`1`ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0:?ooool01?l0003ooooooooooolb<S86o`0000_o
oooo00?o0000ooooooooool02_ooool6o`000005oc8b<_ooooooooooooooool00000L_ooool0063o
oooo00?o0000ooooooooool04oooool2o`0001?ooooo00?o0000ooooooooool0:?ooool01_l0003o
ooooooooooo<c<co0000oiRHV0oooooo00?o0000ooooooooool03_ooool00onHV9So0000olc<c003
ooooo`03o`000?oooooooooo073ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Yooooo`06o`000?ooooooooooolc<c?l@413ogMgM3_oo
ool00ol0003oooooooooo`0=ooooo`03omgMgOl@413oc<c<00?ooooo00?o0000ooooooooool0LOoo
ool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0LOoo
ool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03_ooool7o`0001;ooooo00?o0000ooooooooool0LOooool0
063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool04oooool2o`0001?ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001P
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
LOooool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00Foooool0
1_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1aooooo`00Foooool01_mgMgOoV9RHoooooonHV9SoMgMgo`00
00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1a
ooooo`00Foooool01_l@413ooooooooooooooooo410@o`0000[ooooo00Go0000oooooooooooooooo
o`000006ooooo`;o00004oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0LOooool005_ooooo00Co0000oooooooooooooooo0_l0000:ooooo`05o`00
0?nHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00Foooool01?l0003ooooo
ooooooooool2o`0000[ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
077ooooo001Kooooo`06oa0@4?ooooooooooooooool@413o00002_ooool00omEEEGoQhN7ooooo`08
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo077ooooo001Kooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00002_oo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Kooooo`06onk^k_lb<S;o
0000oc8b<_o^k^ko00002oooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077o
oooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0C
ooooo`;o00004oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0LOooool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aoooo
o`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Pooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003ooooo
ooooo`0Cooooo`;o00004oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Poooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOoo
ool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0
003oooooooooo`0Cooooo`;o00004oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo
001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo077ooooo001Kooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00001?ooool2
ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001K
ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001?ooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Kooooo`06oa0@4?ooooooooooooooool@
413o00002_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0000Cooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00Foooool01?l0
003oooooooooooooool2o`0000[ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo077ooooo001Kooooo`04o`000?ooooooooooooooo`;o00002_ooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0LOooool005_ooooo00Ko410@oooooooooooooooo
oa0@4?l0000:ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aoooo
o`00Foooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000[ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo077ooooo001Kooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko0000
2_ooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo0_l0000C
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1a
ooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Pooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0
063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo
0_l0000Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001P
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
LOooool0063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo
01?ooooo0_l0000Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo077o
oooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0LOooool0063ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`1aooooo`00H?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo077ooooo001Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0LOooool0063ooooo00?o0000ooooooooool02Oooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0LOooool0063ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo077ooooo001Pooooobco0000:oooool[o`0007?ooooo001^
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g?ooool006kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3Looooo`00K_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0=cooooo001^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
g?ooool006cooooo00?oEEEEofIVI_l00000i_ooool00?ooooooE_ooool00?ooooooE_ooool00?oo
ooooE_ooool00?ooooooE_ooool00?ooooooE_ooool00?ooooooE_ooool0097ooooo00?o<S8bo`00
0?l000000ol000002Olb<S;oooooohN7Qol0003oEEEEofIVI_l0003o<S8bonk^kP2eooooo`00TOoo
ool00onHV9SoA4A4ooooo`02ooooo`0;odA4A?nHV9Sooooooa0@4?oMgMgoMgMgob4Q8OooooooQhN7
ofIVI_ooool01_l0002^ooooo`00T_ooool01Ol@413ogMgMoooooooMgMgo410@00;ooooo00Oo0000
oooooooMgMgo<S8booooooo^k^ko410@00Wooooo00OoZJVYo`000?lb<S;ooooooc8b<_l0003oZJVY
0:Gooooo002Booooo`05ohN7QomgMgOoooooofIVI_n7QhL00_ooool01?mEEEGoZJVYooooool00002
ooooo`03o`000?oooooo000000Go00000_ooool01ol@413o^[ZjohN7Qol@413oQhN7okZj^_l@4100
YOooool009;ooooo00Gok^k^oa0@4?o^k^ko410@onk^kP02ooooo`03omgMgOlQ8B7ok^k^00?ooooo
00?o0000ooooooooool01oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo0:?o
oooo002Cooooo`03ogMgMolQ8B7oEEEE00Cooooo00?oV9RHogMgMoooool00_ooool00ol0003ooooo
ooooo`07ooooo`07oa0@4?nj^[[oQhN7oa0@4?n7QhOo^[Zjoa0@402Uooooo`00Toooool00ooMgMgo
0000omgMg@0Cooooo`07oiRHV?l0003o<S8bonk^k_lb<S;o0000ojVYZ@2Uooooo`00U?ooool00onY
ZJWoooooooooo`2nooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomF
ooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00oooooomFooooo`00\
\>"],
  ImageRangeCache->{{{0, 340.938}, {675.25, 0}} -> {0, 0, 0, 0}, {{8.0625, \
332.812}, {658.688, 458}} -> {-2, 0, 0, 0}, {{8.0625, 332.812}, {437.938, \
237.25}} -> {-2, -1, 0, 0}, {{8.0625, 332.812}, {217.188, 16.5}} -> {-2, -2, \
0, 0}}],

Cell[TextData[{
  "Fig. 2.6.: The digital signal consisting of bits 1 0 1, for three \
different bandwidths \[CapitalDelta]\[Omega]. As \[CapitalDelta]\[Omega] \
decreases, the width  \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " of the pulses increases until they begin to overlap, and it is no longer \
possible to distinguish the bits. "
}], "Caption",
  CellTags->"Fig. 2.6"],

Cell[TextData[{
  "\tAlso, Fig. ",
  ButtonBox["2.6",
    ButtonData:>"Fig. 2.6",
    ButtonStyle->"Hyperlink"],
  " indicates that that there is a connection between the degraded pulse \
width ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and the bandwidth ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  ": as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  " decreases, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " increases. In fact, in Sec. ",
  ButtonBox["2.3.3",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  " we will show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], 
          "\[Proportional]", \(1/\[CapitalDelta]\[Omega]\)}], 
        TraditionalForm]]],
  ": See Eq. ",
  ButtonBox["(2.3.24)",
    ButtonData:>"(2.3.24)",
    ButtonStyle->"Hyperlink"],
  ". This implies that the minimum time between distinguishable pulses, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T\_min\)\(,\)\)\)]],
  " is proportional to 1/\[CapitalDelta]\[Omega]. The maximum rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_max\)]],
  " at which pulses can be sent is ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\(\[Nu]\_max\)\(=\)\),
              "TraditionalForm"], " ", \(1/T\_min\)}]}], TraditionalForm]]],
  ", so we find that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Nu]\_max\)\(\[Proportional]\)\(\ \)\(\
\[CapitalDelta]\[Omega]\)\(\ \)\)\)]],
  "."
}], "NE3",
  CellTags->{"(2.3.8)", "i:87"}],

Cell[TextData[{
  "This important result shows that the maximum number of bits per second \
that can be sent through a medium is proportional to the bandwidth of the \
medium. For example, a telephone line has a bandwidth ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  " of roughly 4000 Hz, which limits the rate at which digital signals can be \
sent, as any modem user knows. However, an optical fiber has a bandwidth on \
the order of the frequency of light, around ",
  Cell[BoxData[
      \(TraditionalForm\`10\^15\)]],
  "Hz, which is why optical fibers can transmit much more information than \
phone lines. (Actually, the bandwidth quoted above for optical fibre is a \
\"theoretical\"  bandwidth, applicable only to short fibes;  in long fibers \
dispersion begins to limit the effective bandwidth. Dispersion will be \
discussed in Chapter ",
  ButtonBox["5",
    ButtonData:>{"Chapter5.nb", None},
    ButtonStyle->"Hyperlink"],
  ". Also, the bandwidth of the receiver and the transmitter must be taken \
into account.)"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.2 Fourier sine and cosine Transforms", "Subsubtitle",
  CellTags->{"i:43", "c:21"}],

Cell[TextData[{
  "Sometimes one must Fourier-transform a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " that is defined only on a portion of the real line, ",
  Cell[BoxData[
      \(TraditionalForm\`a \[LessEqual] \ t \[LessEqual] \ \[Infinity]\)]],
  ". For such functions, one can extend the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " to the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < t < a\)]],
  " in any way that one wishes, and then employ the usual transformations of \
Table ",
  ButtonBox["2.1",
    ButtonData:>"Table 2.1",
    ButtonStyle->"Hyperlink"],
  " over the entire real line. "
}], "Text"],

Cell[TextData[{
  "\tOne simple choice is ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < a\)]],
  ". In this case the Fourier transform is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\&~\)(\[Omega])\), "=", 
          
          FormBox[\(\[Integral]\_a\%\[Infinity]\( f(
                  t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t\),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(2.3.9)"],

Cell["and the inverse transformation remains unchanged.", "Text"],

Cell[TextData[{
  "\tFor example, we may use Eq. ",
  ButtonBox["( 2.3.9)",
    ButtonData:>"(2.3.9)",
    ButtonStyle->"Hyperlink"],
  " to take the Fourier transform of the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = exp(\(-t\)), \ t > 0\)]],
  ". The integration in Eq. ",
  ButtonBox["(2.3.9)",
    ButtonData:>"(2.3.9)",
    ButtonStyle->"Hyperlink"],
  " can then be done by hand:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(f\&~\)(\[Omega])\), "=", 
          RowBox[{
            
            FormBox[\(\[Integral]\_0\%\[Infinity]\( \[ExponentialE]\^\(\
\[ImaginaryI]\ \[Omega]\ t - t\)\) \[DifferentialD]t\),
              "TraditionalForm"], 
            "=", \(1/\((1 - \[ImaginaryI]\[Omega])\)\)}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The inverse transformation should then return us to the original function \
",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s intrinsic function can perform this task: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseFourierTransform[1/\((1 - I\ \[Omega])\), \[Omega], t]/
      Sqrt[2\ Pi]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.48"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-t\)\ UnitStep[t]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The function ",
  StyleBox["UnitStep",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", also called the Heaviside step function, is defined by Eq. ",
  ButtonBox["(9.8.1)",
    ButtonData:>{"Chapter9.nb", "(9.8.1)"},
    ButtonStyle->"Hyperlink"],
  ". Since this function is zero for ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  " and unity for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  ", the inverse transform has reproduced ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", including the extension to ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tIt is sometimes useful to create an even or odd  extension of the \
function, rather than setting the function equal to zero for ",
  Cell[BoxData[
      \(TraditionalForm\`t < a\)]],
  ". In this case, the exponential transform is replaced by a ",
  StyleBox["Fourier sine or cosine transform",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFor an odd extension of the function, we require that ",
  Cell[BoxData[
      \(TraditionalForm\`f(a - t)\  = \ \(-f\) \((a + t)\)\)]],
  " for any ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".The formulae for the Fourier sine transform then follow from a limiting \
procedure analogous to that done for the exponential transform, but instead \
applied to the Fourier sine series discussed in Sec. ",
  ButtonBox["2.2.3",
    ButtonData:>"c:16",
    ButtonStyle->"Hyperlink"],
  ". Now one takes ",
  Cell[BoxData[
      \(TraditionalForm\`b \[Rule] \ \[Infinity]\)]],
  " but leaves ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " fixed. It is then an exercise to show that the result for the Fourier \
sine transform and the inverse sine transform is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega]) = \[Integral]\_a\%\[Infinity]\( f(
              t)\) \(sin\[Omega](t - a)\) \[DifferentialD]t\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                  f\&~\)(\[Omega])\) \(sin\[Omega](
              t - a)\) \[DifferentialD]\[Omega]/\[Pi]\)]],
  "."
}], "NE3",
  CellTags->"(2.3.10)"],

Cell[TextData[{
  "On the other hand, if we wish to use an even function, such that ",
  Cell[BoxData[
      \(TraditionalForm\`f(a - t)\  = \ f(a + t)\)]],
  " for any ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", we can employ a cosine transform of the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega]) = \[Integral]\_a\%\[Infinity]\( f(
              t)\) \(cos\[Omega](t - a)\) \[DifferentialD]t\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                  f\&~\)(\[Omega])\) \(cos\[Omega](
              t - a)\) \[DifferentialD]\[Omega]/\[Pi]\)]],
  "."
}], "NE3",
  CellTags->"(2.3.11)"],

Cell[TextData[{
  "The definitions for spatial sine and cosine transforms are identical, \
except for the convention of replacing \[Omega] by ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAs an example of a sine transform, we can again take ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = exp(\(-t\))\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  ". The sine transform is then given by"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Integrate[Exp[\(-t\)] Sin[\[Omega]\ t], {t, 0, Infinity}], 
      Im[\[Omega]] \[Equal] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.49"],

Cell[BoxData[
    \(\[Omega]\/\(1 + \[Omega]\^2\)\)], "Output"]
}, Open  ]],

Cell["The inverse sine transform is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Integrate[%\ Sin[\[Omega]\ t], {\[Omega], \(-Infinity\), Infinity}]/Pi, 
      Im[t] \[Equal] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.50"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-t\)\ Sign[t]\)\ Sign[t]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which returns us to ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", but with an odd extension into the range ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ". For an even extension of the same function, the cosine transform is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Integrate[Exp[\(-t\)] Cos[\[Omega]\ t], {t, 0, Infinity}], 
      Im[\[Omega]] \[Equal] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.51"],

Cell[BoxData[
    \(1\/\(1 + \[Omega]\^2\)\)], "Output"]
}, Open  ]],

Cell["\<\
and the inverse cosine transform returns the correct even function:\
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[
      Integrate[%\ Cos[\[Omega]\ t], {\[Omega], \(-Infinity\), Infinity}]/Pi, 
      Im[t] \[Equal] 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.52"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-t\)\ Sign[t]\)\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.3 Some Properties of Fourier Transforms", "Subsubtitle",
  CellTags->"c:22"],

Cell[CellGroupData[{

Cell["Fourier Transforms as Linear Integral Operators", "Section",
  CellTags->"c:23"],

Cell[TextData[{
  "When one takes the Fourier transform of a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", the result is a new function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ". This is reminiscent of the manner in which a linear differential \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " transforms a function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " to a different function  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\ f\)]],
  " by taking derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". In fact,  a Fourier transform can also be thought of as a linear \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\)]],
  ", defined by its operation on a given function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`F\&^\ f = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\( \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \(f(
              t)\)\ \[DifferentialD]t\)]],
  "."
}], "NE3",
  CellTags->"(2.3.12)"],

Cell[TextData[{
  "The result of the operation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(F\&^\)\(\ \)\)\)]],
  "on a function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is a new function ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\)]],
  ", that is,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(F\&^\ f = f\&~\)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.13)"],

Cell[TextData[{
  "The operator  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(F\&^\)\(=\)\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity] \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\ \[DifferentialD]t\)]],
  " is a linear operator, since it satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\)(C\ f + g) = C\ \(F\&^\) f + \(F\&^\) g\)]],
  " for any functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " and any constant ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  ". However, this linear operator is an integral operator rather than a \
differential operator."
}], "Text"],

Cell[TextData[{
  "\tThe inverse  Fourier transform can also be thought of as  an operator, \
",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\^\(-1\)\)]],
  ". This operator is defined by ",
  "its",
  " action on a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(f\&~\),
            "TraditionalForm"], "(", "\[Omega]", ")"}], TraditionalForm]]],
  ", producing a function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\)\(\ \)\)\)]],
  "according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f = \ \(F\&^\^\(-1\)\ f\&~ = \[Integral]\_\(-\
\[Infinity]\)\%\[Infinity]\( \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ \
t\)\) \(\(f\&~\)(\[Omega])\)\ \[DifferentialD]\[Omega]/2  \[Pi]\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.14)"],

Cell[TextData[{
  "The inverse transform has the property required of any inverse: for any \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\^\(-1\)\) 
          F\&^\ f = \(\(F\&^\) \(F\&^\^\(-1\)\) f = f\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.15)"],

Cell["\<\
This follows directly from the definition of the inverse Fourier \
transform.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Fourier Transforms of Derivatives and Integrals", "Section",
  CellTags->"c:24"],

Cell["\<\
The Fourier transform of the derivative of a function is related to \
the Fourier transform of the function itself. Consider\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\) \[DifferentialD]f/\[DifferentialD]t = \
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \[ExponentialE]\^\(\[ImaginaryI]\
\ \[Omega]\ t\)\) \(\[DifferentialD]f\/\[DifferentialD]t\) \
\[DifferentialD]t\)]],
  "."
}], "NE3",
  CellTags->"(2.3.16)"],

Cell[TextData[{
  "An integration by parts, together with the assumption that ",
  Cell[BoxData[
      \(TraditionalForm\`f(\(\[PlusMinus]\[Infinity]\)) = 0\)]],
  " (required for the convergence of the Fourier integral) implies"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(F\&^\) \[DifferentialD]f/\[DifferentialD]t = \
\(\(-\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(
                t)\)\ \(\[DifferentialD]\/\[DifferentialD]t\) \(\
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \[DifferentialD]t\)\) = \
\(\(-\[ImaginaryI]\[Omega]\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(
                  t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t\) = \(-\[ImaginaryI]\[Omega]\) \(\(f\&~\)(\[Omega])\)\)\)\)\
\(,\)\)\)]]], "NE3",
  CellTags->"(2.3.17)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~ = \(F\&^\) f\)]],
  "is the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". \n\tWe can immediately generalize Eq. ",
  ButtonBox["(2.3.17)",
    ButtonData:>"(2.3.17)",
    ButtonStyle->"Hyperlink"],
  " to the transform of derivatives of any order:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(F\&^\) \[DifferentialD]\^n 
            f/\[DifferentialD]t\^n = \(\((\(-\[ImaginaryI]\[Omega]\))\)\^n\) \
\(\(\(f\&~\)(\[Omega])\)\(.\)\)\)]]], "NE3",
  CellTags->"(2.3.18)"],

Cell[TextData[{
  "This simple result is of great importance in the analysis of particular \
solutions to linear differential equations with constant coefficients, as we \
will see in Sec. ",
  ButtonBox["2.3.6",
    ButtonData:>"c:38",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tAlso, it follows from Eq. ",
  ButtonBox["(2.3.17)",
    ButtonData:>"(2.3.17)",
    ButtonStyle->"Hyperlink"],
  " that the Fourier transform of the indefinite integral of a function is \
given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\) \(\[Integral]\^t\( f(
                t)\) \[DifferentialD]t\) = \(\(f\&~\)(\[Omega])\)/\((\(-\
\[ImaginaryI]\[Omega]\))\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.19)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Convolution Theorem", "Section",
  CellTags->{"i:44", "c:25"}],

Cell[TextData[{
  "The ",
  StyleBox["convolution",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " of two functions, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", is defined by the following integral:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h(
          t)\  = \ \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(
                t\_1)\) \(g(
                t - t\_1)\) \[DifferentialD]t\_1 = \
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(t - t\_2)\) \(g(
                t\_2)\) \[DifferentialD]t\_2\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.20)"],

Cell[TextData[{
  "Either integral is a valid form for the convolution. The second form \
follows from a change of the integration variable from ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  "to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_2 = \ t - t\_1\)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\tConvolutions often appear in the physical sciences, as when we deal with \
Green's functions [see Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " ]. The convolution theorem is a simple relation between the Fourier \
transforms of ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)(\[Omega]) = \(\(f\&~\)(\[Omega])\) \(\(g\&~\
\)(\[Omega])\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.21)"],

Cell[TextData[{
  "To prove this result, we take the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  ":\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)(\[Omega]) = \[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\[DifferentialD]t\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\
\)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(t\_1)\) \(g(
                  t - t\_1)\) \[DifferentialD]t\_1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Changing the integration variable in the ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "-integral to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_2 = \ t - t\_1\)]],
  "yields"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)(\[Omega]) = \[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\[DifferentialD]t\_2\ \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\( \[ExponentialE]\^\(\[ImaginaryI]\ \(\[Omega](\ t\_2 + t\_1)\)\)\) \(f(
                  t\_1)\) \(g(t\_2)\) \[DifferentialD]t\_1\)\)]],
  ".\nIn this change of variables from ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1\)]],
  "is held fixed, so ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t = \[DifferentialD]t\_2\)]],
  " and the range of integration still runs from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(+\[Infinity]\)\)]],
  ".We can now break the exponential into a product of exponentials, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \(\[Omega](\ t\_2 \
+ t\_1)\)\) = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\_2\)\) \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\_1\)\)]],
  ", and break the two integrals up into a product of Fourier transforms:\n\t\
\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(h\&~\)(\[Omega]) = \(\[Integral]\_\(-\
\[Infinity]\)\%\[Infinity]\[DifferentialD]t\_2\ \(\[ExponentialE]\^\(\
\[ImaginaryI]\ \[Omega]\ t\_2\)\) \(g(
                t\_2)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\_1\)\) \(f(
                    t\_1)\) \[DifferentialD]t\_1\) = \(\(g\&~\)(\[Omega])\) \
\(\(f\&~\)(\[Omega])\)\)\)\(,\)\)\)]]
}], "Text"],

Cell["proving the theorem.", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Uncertainty Principle of Fourier Analysis", "Section",
  CellTags->{"i:45", "c:26"}],

Cell[TextData[{
  "Consider a dimensionless function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(f(\[Tau])\)\)\)]],
  " that approaches zero when ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Tau]\)\(|\)\(\(\[GreaterTilde]\)\(1\)\)\)\
\)]],
  ". An example of such a function is ",
  Cell[BoxData[
      \(TraditionalForm\`exp(\(-\(\(|\)\(\[Tau]\)\(|\)\)\))\)]],
  "; another is 1/(1 + ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\^2\)]],
  "). A third example is the set of data bits plotted in Fig. ",
  ButtonBox["2.6",
    ButtonData:>"Fig. 2.6",
    ButtonStyle->"Hyperlink"],
  " . The Fourier transform of this function, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ", will typically approach zero for large ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[VerticalSeparator]\)\(\(\[Omega]\)\(|\)\)\)\)]]\
,
  ", because only frequencies up to some value are necessary to describe the \
function. Let us define the width of this transform function as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\)]],
  ", that is, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega]) \[Rule] \ 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[VerticalSeparator]\)\(\[Omega] | \(\(\
\[GreaterTilde]\)\(\[CapitalDelta]\)\)\)\)\)]],
  ". (Here \[CapitalDelta] is a dimensionless number,  on the order of unity \
for the three examples given above.)"
}], "Text"],

Cell[TextData[{
  "\t Now consider a scale transformation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " to a new time ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", "\[Tau]"}]}], 
        TraditionalForm]]],
  ". When written in terms of the new time, the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Tau])\)]],
  " becomes a new function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ", defined by ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(t)\), " ", "=", 
          RowBox[{"f", "(", 
            RowBox[{"t", "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], ")"}]}], TraditionalForm]]],
  " . This function approaches zero for times ",
  Cell[BoxData[
      FormBox[
        RowBox[{"|", "t", "|", 
          RowBox[{">", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". Therefore,  ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is a measure of the width in time of the function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAn example of the function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " is shown in Fig. ",
  ButtonBox["2.7",
    ButtonData:>"Fig. 2.7",
    ButtonStyle->"Hyperlink"],
  "  for different choices of \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Tau]) = exp(\(-\[Tau]\^2\))\)]],
  " . As \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " increases, the width of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " increases. One can see that varying ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  "defines a class of functions, all of the same shape, but with different \
widths."
}], "Text"],

Cell[TextData[{
  "\tNow consider the Fourier transform of  ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(g\&~\)(\[Omega]) = \[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\[DifferentialD]t\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\
\)\) \(f(t/\[CapitalDelta]t)\)\)], "NE3"], "NE3"],
  StyleBox[".", "NE3"]
}], "NE3",
  CellTags->"(2.3.22)"],

Cell[TextData[{
  "We will now relate the width ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  " of the Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`g\&~\)]],
  " to the width ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " of g. This relation follows from a simple change of the integration \
variable in Eq. ",
  ButtonBox["(2.3.22)",
    ButtonData:>"(2.3.22)",
    ButtonStyle->"Hyperlink"],
  "  back to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Tau]", "=", 
          RowBox[{"t", "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(g\&~\)(\[Omega])\)\(=\)\(\[CapitalDelta]t\)\(\ \
\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]\
\[Tau]\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \[CapitalDelta]t\
\ \ \[Tau]\)\) \(f(\[Tau])\)\), "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{\(f\&~\), "(", 
              RowBox[{"\[Omega]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.23)"],

Cell[TextData[{
  "Now, since the width of  ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\)]],
  " is \[CapitalDelta]",
  ",",
  " Eq. (",
  ButtonBox["2.3.23",
    ButtonData:>"(2.3.23)",
    ButtonStyle->"Hyperlink"],
  ") shows that the width \[CapitalDelta]\[Omega] of ",
  Cell[BoxData[
      \(TraditionalForm\`g\&~\)]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]\[Omega]", "=", 
          RowBox[{"\[CapitalDelta]", "/", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", or in other words,"
}], "Text"],

Cell[TextData[{
  "\[CapitalDelta]\[Omega] \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " = constant,"
}], "NE3",
  CellTags->"(2.3.24)"],

Cell[TextData[{
  "where the constant \[CapitalDelta] is a dimensionless number. This \
constant differs for different functions. However, if one defines the width \
of a function in a particular way,  as the ",
  StyleBox["rms width",
    FontSlant->"Italic"],
  " [see Exercise (",
  ButtonBox["13",
    ButtonData:>"i:106",
    ButtonStyle->"Hyperlink"],
  ")], then one can show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] \[GreaterEqual] \ 1/2\)]],
  ", with equality only for ",
  StyleBox["Gaussian ",
    FontSlant->"Italic"],
  " functions of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t)\  = \ \(f\_o\) \[ExponentialE]\^\(\(-a\)\ t\^2\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tEquation (",
  ButtonBox["2.3.24",
    ButtonData:>"(2.3.24)",
    ButtonStyle->"Hyperlink"],
  "), along with the condition ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] \[GreaterEqual] \ 1/2\)]],
  ", is the uncertainty principle of Fourier analysis. It is called an \
uncertainty principle because it is the mathematical principle at the heart \
of ",
  ButtonBox["Heisenberg",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Heisenberg.\
html"], None},
    ButtonStyle->"Hyperlink"],
  "'s uncertainty principle in quantum mechanics. It shows that as a function \
becomes wider in time, its Fourier transform becomes narrower.  This is \
sensible, because wider functions vary more slowly, and so require fewer \
Fourier modes to describe their variation.  Alternatively, we see that very \
narrow, sharply peaked functions of time require a  broad spectrum of Fourier \
modes in order to describe their variation."
}], "Text",
  CellTags->"i:107"],

Cell[TextData[{
  "\tAs an example of the uncertainty principle, consider the Fourier \
transform of the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(t)\), " ", "=", " ", 
          RowBox[{"exp", "[", 
            RowBox[{"-", 
              SuperscriptBox[
                RowBox[{"(", 
                  RowBox[{\(t/\[CapitalDelta]\), 
                    FormBox["t",
                      "TraditionalForm"]}], ")"}], "2"]}], "]"}]}], 
        TraditionalForm]]],
  ". This function is plotted in Fig. ",
  ButtonBox["2.7",
    ButtonData:>"Fig. 2.7",
    ButtonStyle->"Hyperlink"],
  " The Fourier transform is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FourierTransform[Exp[\(-\((t/\[CapitalDelta]t)\)^2\)], 
        t, \[Omega]]\ Sqrt[2\ Pi]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.53"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(1\/4\)\)\ \[CapitalDelta]t\^2\ \[Omega]\^2\)\ \
\@\[Pi]\ \@\[CapitalDelta]t\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This function is plotted in Fig. ",
  ButtonBox["2.8",
    ButtonData:>"Fig. 2.8",
    ButtonStyle->"Hyperlink"],
  " for the same values of \[CapitalDelta]t as those in Fig. ",
  ButtonBox["2.7",
    ButtonData:>"Fig. 2.7",
    ButtonStyle->"Hyperlink"],
  ". One can see that as \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " increases, the transform function narrows."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0595238 0.0147151 0.588604 [
[.05357 .00222 -12 -9 ]
[.05357 .00222 12 0 ]
[.20238 .00222 -6 -9 ]
[.20238 .00222 6 0 ]
[.35119 .00222 -12 -9 ]
[.35119 .00222 12 0 ]
[.64881 .00222 -9 -9 ]
[.64881 .00222 9 0 ]
[.79762 .00222 -3 -9 ]
[.79762 .00222 3 0 ]
[.94643 .00222 -9 -9 ]
[.94643 .00222 9 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.4875 .13244 -18 -4.5 ]
[.4875 .13244 0 4.5 ]
[.4875 .25016 -18 -4.5 ]
[.4875 .25016 0 4.5 ]
[.4875 .36788 -18 -4.5 ]
[.4875 .36788 0 4.5 ]
[.4875 .4856 -18 -4.5 ]
[.4875 .4856 0 4.5 ]
[.4875 .60332 -6 -4.5 ]
[.4875 .60332 0 4.5 ]
[.5 .64303 -14 0 ]
[.5 .64303 14 12 ]
[.55952 .1913 -14 -6 ]
[.55952 .1913 14 6 ]
[.66667 .1913 -14 -6 ]
[.66667 .1913 14 6 ]
[.79762 .1913 -14 -6 ]
[.79762 .1913 14 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05357 .01472 m
.05357 .02097 L
s
[(-7.5)] .05357 .00222 0 1 Mshowa
.20238 .01472 m
.20238 .02097 L
s
[(-5)] .20238 .00222 0 1 Mshowa
.35119 .01472 m
.35119 .02097 L
s
[(-2.5)] .35119 .00222 0 1 Mshowa
.64881 .01472 m
.64881 .02097 L
s
[(2.5)] .64881 .00222 0 1 Mshowa
.79762 .01472 m
.79762 .02097 L
s
[(5)] .79762 .00222 0 1 Mshowa
.94643 .01472 m
.94643 .02097 L
s
[(7.5)] .94643 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.1131 .01472 m
.1131 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.17262 .01472 m
.17262 .01847 L
s
.23214 .01472 m
.23214 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.29167 .01472 m
.29167 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.41071 .01472 m
.41071 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.47024 .01472 m
.47024 .01847 L
s
.52976 .01472 m
.52976 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.58929 .01472 m
.58929 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.70833 .01472 m
.70833 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76786 .01472 m
.76786 .01847 L
s
.82738 .01472 m
.82738 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.8869 .01472 m
.8869 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .13244 m
.50625 .13244 L
s
[(0.2)] .4875 .13244 1 0 Mshowa
.5 .25016 m
.50625 .25016 L
s
[(0.4)] .4875 .25016 1 0 Mshowa
.5 .36788 m
.50625 .36788 L
s
[(0.6)] .4875 .36788 1 0 Mshowa
.5 .4856 m
.50625 .4856 L
s
[(0.8)] .4875 .4856 1 0 Mshowa
.5 .60332 m
.50625 .60332 L
s
[(1)] .4875 .60332 1 0 Mshowa
.125 Mabswid
.5 .04415 m
.50375 .04415 L
s
.5 .07358 m
.50375 .07358 L
s
.5 .10301 m
.50375 .10301 L
s
.5 .16187 m
.50375 .16187 L
s
.5 .1913 m
.50375 .1913 L
s
.5 .22073 m
.50375 .22073 L
s
.5 .27959 m
.50375 .27959 L
s
.5 .30902 m
.50375 .30902 L
s
.5 .33845 m
.50375 .33845 L
s
.5 .39731 m
.50375 .39731 L
s
.5 .42674 m
.50375 .42674 L
s
.5 .45617 m
.50375 .45617 L
s
.5 .51503 m
.50375 .51503 L
s
.5 .54446 m
.50375 .54446 L
s
.5 .57389 m
.50375 .57389 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.04011 .01472 L
.04141 .01472 L
.04262 .01472 L
.04386 .01472 L
.04521 .01472 L
.04648 .01472 L
.04765 .01472 L
.04871 .01472 L
.04987 .01472 L
.05108 .01472 L
.05221 .01472 L
.05354 .01472 L
.0548 .01472 L
.05592 .01472 L
.05715 .01472 L
.05848 .01472 L
.0599 .01472 L
.06111 .01472 L
.06244 .01472 L
.06371 .01472 L
.0651 .01472 L
.06655 .01472 L
.0679 .01472 L
.06917 .01472 L
.07032 .01472 L
.07165 .01472 L
.0729 .01472 L
.07427 .01472 L
.07572 .01472 L
.07695 .01472 L
.07831 .01472 L
.07977 .01472 L
.08059 .01472 L
.08134 .01472 L
.0828 .01472 L
.08418 .01472 L
Mistroke
.08546 .01472 L
.08663 .01472 L
.08798 .01472 L
.08924 .01472 L
.09042 .01472 L
.0915 .01472 L
.09269 .01472 L
.09394 .01472 L
.09521 .01472 L
.09657 .01472 L
.09785 .01472 L
.09902 .01472 L
.10039 .01472 L
.10187 .01472 L
.10328 .01472 L
.10458 .01472 L
.10576 .01472 L
.10701 .01472 L
.10807 .01472 L
.10923 .01472 L
.11048 .01472 L
.11182 .01472 L
.11309 .01472 L
.11423 .01472 L
.1154 .01472 L
.11647 .01472 L
.11765 .01472 L
.11889 .01472 L
.11997 .01472 L
.12098 .01472 L
.12209 .01472 L
.12328 .01472 L
.12466 .01472 L
.12593 .01472 L
.12733 .01472 L
.12882 .01472 L
.1301 .01472 L
.13131 .01472 L
.13263 .01472 L
.13406 .01472 L
.13525 .01472 L
.13656 .01472 L
.13792 .01472 L
.13919 .01472 L
.14038 .01472 L
.14147 .01472 L
.14272 .01472 L
.1439 .01472 L
.14505 .01472 L
.14628 .01472 L
Mistroke
.14852 .01472 L
.14988 .01472 L
.15117 .01472 L
.15234 .01472 L
.1536 .01472 L
.15496 .01472 L
.15619 .01472 L
.1576 .01472 L
.15894 .01472 L
.16018 .01472 L
.16132 .01472 L
.16257 .01472 L
.16389 .01472 L
.16608 .01472 L
.16732 .01472 L
.16844 .01472 L
.16948 .01472 L
.17062 .01472 L
.17268 .01472 L
.17384 .01472 L
.17511 .01472 L
.17645 .01472 L
.1777 .01472 L
.17993 .01472 L
.18118 .01472 L
.18233 .01472 L
.18361 .01472 L
.18482 .01472 L
.18708 .01472 L
.18834 .01472 L
.18951 .01472 L
.19087 .01472 L
.19215 .01472 L
.19426 .01472 L
.19538 .01472 L
.19658 .01472 L
.19784 .01472 L
.19903 .01472 L
.20127 .01472 L
.20258 .01472 L
.20376 .01472 L
.20504 .01472 L
.20641 .01472 L
.20769 .01472 L
.20887 .01472 L
.21118 .01472 L
.21248 .01472 L
.21369 .01472 L
.21513 .01472 L
.21643 .01472 L
Mistroke
.21911 .01472 L
.22058 .01472 L
.22198 .01472 L
.22436 .01472 L
.22659 .01472 L
.22786 .01472 L
.22903 .01472 L
.2304 .01472 L
.23167 .01472 L
.23418 .01472 L
.23551 .01472 L
.23693 .01472 L
.23828 .01472 L
.23956 .01472 L
.24194 .01472 L
.24418 .01472 L
.24655 .01472 L
.24858 .01472 L
.2508 .01472 L
.25319 .01472 L
.25575 .01472 L
.25817 .01472 L
.26038 .01472 L
.26266 .01472 L
.26518 .01472 L
.26781 .01472 L
.27029 .01472 L
.27259 .01472 L
.2747 .01472 L
.27701 .01472 L
.27945 .01472 L
.28194 .01472 L
.28459 .01472 L
.28709 .01472 L
.28937 .01472 L
.29204 .01472 L
.29494 .01472 L
.29768 .01472 L
.30021 .01472 L
.30265 .01473 L
.30488 .01473 L
.30745 .01473 L
.3099 .01474 L
.31424 .01475 L
.31669 .01476 L
.31897 .01477 L
.32167 .01479 L
.32421 .01481 L
.32896 .01487 L
.33162 .01491 L
Mistroke
.33407 .01496 L
.33676 .01503 L
.3396 .01513 L
.34216 .01523 L
.34457 .01536 L
.3491 .01567 L
.35163 .01589 L
.35397 .01615 L
.35927 .01691 L
.3635 .01778 L
.36817 .01908 L
.37304 .02094 L
.37761 .0233 L
.38232 .02653 L
.38747 .03122 L
.39284 .03774 L
.39783 .04563 L
.40678 .06538 L
.41179 .0802 L
.41634 .09636 L
.42634 .14201 L
.43555 .197 L
.45636 .3586 L
.4662 .44106 L
.47675 .52003 L
.48186 .55113 L
.48671 .57471 L
.49107 .59021 L
.49226 .59344 L
.49353 .5964 L
.49461 .59852 L
.49581 .6004 L
.49694 .60177 L
.49813 .60274 L
.49924 .60322 L
.50027 .60331 L
.50149 .60295 L
.5026 .6022 L
.50388 .60082 L
.50509 .59903 L
.50727 .5946 L
.50928 .58919 L
.51382 .57242 L
.51842 .54955 L
.52349 .51845 L
.53373 .44163 L
.55478 .26708 L
.56476 .19491 L
.57403 .14006 L
.58354 .09684 L
Mistroke
.58898 .07772 L
.59391 .06356 L
.60306 .04409 L
.60808 .03649 L
.61281 .03093 L
.61746 .0267 L
.62257 .02319 L
.62791 .02053 L
.63289 .01874 L
.63756 .01754 L
.64181 .01673 L
.64416 .01638 L
.64672 .01607 L
.65137 .01563 L
.6537 .01546 L
.65622 .01532 L
.66077 .01511 L
.66341 .01503 L
.66618 .01496 L
.67115 .01487 L
.67366 .01483 L
.67634 .01481 L
.67867 .01479 L
.68118 .01477 L
.68414 .01476 L
.68693 .01475 L
.68965 .01474 L
.69216 .01473 L
.6946 .01473 L
.69683 .01473 L
.69941 .01472 L
.70185 .01472 L
.70411 .01472 L
.70619 .01472 L
.70849 .01472 L
.71092 .01472 L
.71361 .01472 L
.71651 .01472 L
.71924 .01472 L
.72176 .01472 L
.72404 .01472 L
.72653 .01472 L
.72914 .01472 L
.73157 .01472 L
.73418 .01472 L
.73659 .01472 L
.73924 .01472 L
.74058 .01472 L
.74205 .01472 L
.74451 .01472 L
Mistroke
.74717 .01472 L
.74967 .01472 L
.75196 .01472 L
.75432 .01472 L
.75651 .01472 L
.75892 .01472 L
.76026 .01472 L
.76148 .01472 L
.76372 .01472 L
.76614 .01472 L
.76843 .01472 L
.77053 .01472 L
.77179 .01472 L
.77299 .01472 L
.77523 .01472 L
.77648 .01472 L
.77764 .01472 L
.77899 .01472 L
.78026 .01472 L
.78235 .01472 L
.78356 .01472 L
.78466 .01472 L
.78691 .01472 L
.7881 .01472 L
.78934 .01472 L
.79181 .01472 L
.79319 .01472 L
.79445 .01472 L
.79562 .01472 L
.79689 .01472 L
.7992 .01472 L
.8005 .01472 L
.80193 .01472 L
.80342 .01472 L
.80482 .01472 L
.80731 .01472 L
.80872 .01472 L
.81 .01472 L
.81129 .01472 L
.8125 .01472 L
.81477 .01472 L
.81604 .01472 L
.81721 .01472 L
.81858 .01472 L
.81986 .01472 L
.82198 .01472 L
.8231 .01472 L
.82431 .01472 L
.82557 .01472 L
.82676 .01472 L
Mistroke
.829 .01472 L
.83019 .01472 L
.83151 .01472 L
.83288 .01472 L
.83416 .01472 L
.83646 .01472 L
.83775 .01472 L
.83894 .01472 L
.84015 .01472 L
.84145 .01472 L
.84287 .01472 L
.8442 .01472 L
.84569 .01472 L
.8471 .01472 L
.84836 .01472 L
.84973 .01472 L
.85097 .01472 L
.8521 .01472 L
.85331 .01472 L
.85463 .01472 L
.85585 .01472 L
.85698 .01472 L
.85805 .01472 L
.85921 .01472 L
.86058 .01472 L
.86186 .01472 L
.86311 .01472 L
.86426 .01472 L
.86551 .01472 L
.86687 .01472 L
.8683 .01472 L
.86963 .01472 L
.87094 .01472 L
.87237 .01472 L
.87371 .01472 L
.87495 .01472 L
.87607 .01472 L
.87731 .01472 L
.87859 .01472 L
.8798 .01472 L
.8812 .01472 L
.88254 .01472 L
.88373 .01472 L
.88504 .01472 L
.88646 .01472 L
.88797 .01472 L
.88939 .01472 L
.89068 .01472 L
.89188 .01472 L
.893 .01472 L
Mistroke
.89423 .01472 L
.89555 .01472 L
.89694 .01472 L
.89825 .01472 L
.89942 .01472 L
.9007 .01472 L
.90181 .01472 L
.90302 .01472 L
.9043 .01472 L
.90549 .01472 L
.9066 .01472 L
.90762 .01472 L
.90874 .01472 L
.90992 .01472 L
.91123 .01472 L
.91241 .01472 L
.91378 .01472 L
.91507 .01472 L
.91627 .01472 L
.91737 .01472 L
.91858 .01472 L
.91987 .01472 L
.92115 .01472 L
.92254 .01472 L
.92385 .01472 L
.92504 .01472 L
.92644 .01472 L
.92718 .01472 L
.92797 .01472 L
.92941 .01472 L
.93074 .01472 L
.93199 .01472 L
.93336 .01472 L
.93478 .01472 L
.93611 .01472 L
.93736 .01472 L
.9385 .01472 L
.93981 .01472 L
.94105 .01472 L
.9424 .01472 L
.94383 .01472 L
.94505 .01472 L
.94639 .01472 L
.94783 .01472 L
.94864 .01472 L
.94938 .01472 L
.95075 .01472 L
.95144 .01472 L
.95219 .01472 L
.95356 .01472 L
Mistroke
.95484 .01472 L
.956 .01472 L
.95725 .01472 L
.95862 .01472 L
.95931 .01472 L
.96006 .01472 L
.9614 .01472 L
.96265 .01472 L
.96391 .01472 L
.9651 .01472 L
.96617 .01472 L
.96734 .01472 L
.96861 .01472 L
.96995 .01472 L
.9711 .01472 L
.97237 .01472 L
.97333 .01472 L
.97421 .01472 L
.97517 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.08944 .01472 L
.0941 .01472 L
.09947 .01472 L
.10458 .01472 L
.10961 .01473 L
.11417 .01473 L
.11943 .01474 L
.12439 .01474 L
.13322 .01476 L
.13819 .01477 L
.14277 .01479 L
.14747 .01481 L
.15251 .01483 L
.1616 .0149 L
.16715 .01495 L
.17241 .01502 L
.17709 .01509 L
.18226 .01519 L
.19191 .01544 L
.1972 .01563 L
.20217 .01584 L
.21103 .01634 L
.22059 .0171 L
.23016 .01817 L
.24063 .01982 L
.25156 .02227 L
.26173 .02543 L
.27225 .02986 L
.28219 .03542 L
.29111 .04179 L
.30077 .05049 L
.32065 .07555 L
.33067 .09255 L
.34169 .11514 L
.36114 .16571 L
.38203 .2352 L
.42331 .4034 L
Mistroke
.44394 .48626 L
.45398 .52162 L
.46307 .54932 L
.47198 .57159 L
.47666 .58112 L
.48159 .58942 L
.48412 .59294 L
.48689 .59622 L
.48944 .5987 L
.49176 .6005 L
.49415 .6019 L
.49546 .60246 L
.4967 .60287 L
.49785 .60313 L
.49891 .60327 L
.50008 .60332 L
.50132 .60325 L
.50246 .60307 L
.50371 .60275 L
.50501 .60228 L
.50622 .60171 L
.50839 .6004 L
.51071 .59857 L
.51601 .59276 L
.52083 .58558 L
.53024 .56654 L
.53912 .54307 L
.57764 .39941 L
.61861 .23285 L
.63901 .16527 L
.65806 .11569 L
.67637 .08028 L
.68663 .06512 L
.696 .05385 L
.70524 .04484 L
.71506 .03723 L
.72584 .03082 L
.73582 .02635 L
.74517 .02318 L
.75526 .02065 L
.76479 .0189 L
.77353 .01771 L
.78332 .01676 L
.79243 .01613 L
.79767 .01585 L
.80243 .01564 L
.80763 .01546 L
.81313 .0153 L
.81787 .01519 L
.82309 .01509 L
Mistroke
.83229 .01496 L
.83746 .01491 L
.84302 .01486 L
.84789 .01483 L
.85308 .0148 L
.85832 .01478 L
.86319 .01477 L
.86898 .01475 L
.87423 .01475 L
.8792 .01474 L
.88458 .01473 L
.88965 .01473 L
.89432 .01473 L
.89902 .01472 L
.90407 .01472 L
.90882 .01472 L
.91316 .01472 L
.91825 .01472 L
.92378 .01472 L
.929 .01472 L
.93383 .01472 L
.93847 .01472 L
.94346 .01472 L
.94818 .01472 L
.95251 .01472 L
.9573 .01472 L
.96255 .01472 L
.96802 .01472 L
.97311 .01472 L
.97619 .01472 L
Mfstroke
.02381 .0255 m
.04262 .02941 L
.06244 .03481 L
.08255 .04193 L
.10458 .05204 L
.12415 .06343 L
.14509 .07852 L
.18653 .11872 L
.22646 .17197 L
.26488 .23669 L
.30574 .31722 L
.3451 .40019 L
.38293 .47691 L
.40397 .51495 L
.42322 .54518 L
.44332 .57089 L
.46199 .58851 L
.47118 .59476 L
.47588 .59731 L
.48098 .59957 L
.48389 .60063 L
.48657 .60145 L
.48909 .60208 L
.49184 .60263 L
.49304 .60282 L
.49432 .60298 L
.49543 .6031 L
.49664 .6032 L
.49734 .60325 L
.498 .60328 L
.49928 .60331 L
.50045 .60332 L
.5017 .60329 L
.50284 .60324 L
.50408 .60315 L
.50538 .60302 L
.50659 .60287 L
.50875 .60252 L
.51107 .60205 L
.51636 .60055 L
.52117 .59868 L
.53057 .59369 L
.53945 .58738 L
.55946 .56773 L
.57792 .54354 L
.61732 .47644 L
.65521 .39955 L
.69555 .31455 L
.73437 .23808 L
.77565 .16879 L
Mistroke
.81541 .1165 L
.85365 .07953 L
.87336 .06505 L
.89435 .0526 L
.9158 .0426 L
.93598 .0353 L
.9561 .02972 L
.97459 .02579 L
.97619 .0255 L
Mfstroke
gsave
.55952 .1913 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.66667 .1913 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.79762 .1913 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
000]ooooo`03ob4Q8On7QhOooooo00Wooooo00?oEEEEo`000?mEEED01_ooool00onj^[[oA4A4oa0@
4002o`000003oa0@4?mgMgOok^k^03Gooooo00?o^[ZjodA4A?l@41000_l000000ol@413oMgMgonk^
kP0eooooo`So00001_ooool00omEEEGo0000oeEEE@06ooooo`03okZj^_m4A4Co410@00;o000000?o
410@ogMgMoo^k^h0KOooool8o`0000Kooooo00?oEEEEo`000?mEEED01_ooool00onj^[[oA4A4oa0@
4002o`000003oa0@4?mgMgOok^k^03Cooooo00?o^[ZjodA4A?l@41000_l000000ol@413oMgMgonk^
kP0hooooo`03ob4Q8On7QhOooooo00Wooooo00?oEEEEo`000?mEEED01_ooool00onj^[[oA4A4oa0@
4002o`000003oa0@4?mgMgOok^k^04Sooooo000]ooooo`03ojVYZOlb<S;ooooo00Wooooo0ol00006
ooooo`09o`000?lb<S;oV9RHomgMgOoooooogMgMogMgMol@413ok^k^03Cooooo00Wo0000oc8b<_nH
V9SogMgMoooooooMgMgoMgMgoa0@4?o^k^h0=?ooool00onHV9So0000oiRHV003ooooo`03olc<c?l0
003ooooo00Gooooo0ol00006ooooo`09o`000?lb<S;oV9RHomgMgOoooooogMgMogMgMol@413ok^k^
06cooooo00?oV9RHo`000?nHV9P00oooool00oo<c<co0000ooooo`05ooooo`?o00001_ooool02Ol0
003o<S8boiRHV?oMgMgoooooomgMgOmgMgOo410@onk^kP0cooooo`09o`000?lb<S;oV9RHomgMgOoo
oooogMgMogMgMol@413ok^k^03Oooooo00?oZJVYoc8b<_ooool02Oooool3o`0000Kooooo00Wo0000
oc8b<_nHV9SogMgMoooooooMgMgoMgMgoa0@4?o^k^h0Aoooool002kooooo00?o410@omgMgOooool0
2?ooool00omEEEGo0000oeEEE@0=ooooo`03ohN7QomEEEGooooo03[ooooo00?oQhN7oeEEEOooool0
=?ooool00oo<c<co0000oiRHV00:ooooo`03oeEEEOl0003oEEEE00gooooo00?oQhN7oeEEEOooool0
K?ooool00oo<c<co0000oiRHV00:ooooo`03oeEEEOl0003oEEEE00gooooo00?oQhN7oeEEEOooool0
>Oooool00on7QhOoEEEEooooo`0gooooo`03oa0@4?oMgMgooooo00Sooooo00?oEEEEo`000?mEEED0
3Oooool00on7QhOoEEEEooooo`16ooooo`00;_ooool00onHV9SoEEEEooooo`0Iooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0=?ooool00oo<c<co0000oiRHV00Jooooo`03o`000?oo
oooooooo06cooooo00?oc<c<o`000?nHV9P06_ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Kooooo00?oV9RHoeEEEOooool06Oooool00ol0003oooooooooo`15ooooo`007oooool9
o`0000Kooooo00?ok^k^o`000?o^k^h06Oooool00ol0003oooooooooo`0Wooooo`Wo00002_ooool0
0ol0003oooooooooo`0Vooooo`Wo00001_ooool00onHV9So0000ogMgM`0Iooooo`03o`000?oooooo
oooo06gooooo00?oV9RHo`000?mgMgL06Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo03Kooooo00?ok^k^o`000?o^k^h06Oooool00ol0003oooooooooo`15ooooo`007oooool9o`00
00Oooooo0_mgMgLHooooo`03ohN7Qom4A4Cooooo02Sooooo2Ol00009ooooo`03ohN7Qom4A4Cooooo
02Oooooo2Ol00007ooooo`03olc<c?l0003oV9RH01Oooooo00?oQhN7odA4A?ooool0Koooool00oo<
c<co0000oiRHV00Gooooo`03ohN7Qom4A4Cooooo03Wooooo00?oQhN7odA4A?ooool0>?ooool2ogMg
MaSooooo00?oQhN7odA4A?ooool0A_ooool002oooooo00?ogMgMoa0@4?ooool04Oooool02?l0003o
EEEEolc<c?ooooook^k^ohN7Qol0003oc<c<=Oooool02?l0003oEEEEolc<c?ooooook^k^ohN7Qol0
003oc<c<>Oooool00oo<c<co0000olc<c00@ooooo`08o`000?mEEEGoc<c<ooooooo^k^koQhN7o`00
0?o<c<aaooooo`03olc<c?l0003oc<c<013ooooo00So0000oeEEEOo<c<coooooonk^k_n7QhOo0000
olc<c3Cooooo00So0000oeEEEOo<c<coooooonk^k_n7QhOo0000olc<c3Wooooo00?ogMgMoa0@4?oo
ool04Oooool02?l0003oEEEEolc<c?ooooook^k^ohN7Qol0003oc<c<Aoooool0033ooooo00?oEEEE
oiRHV?ooool04?ooool00ol0003o<S8bo`000002o`000003oeEEEOoMgMgooooo03Gooooo00?o0000
oc8b<_l000000_l000000omEEEGogMgMooooo`0jooooo`03ohN7Qolb<S;ooooo00oooooo00?o0000
oc8b<_l000000_l000000omEEEGogMgMooooo`1booooo`03ohN7Qolb<S;ooooo00oooooo00?o0000
oc8b<_l000000_l000000omEEEGogMgMooooo`0dooooo`03o`000?lb<S;o000000;o000000?oEEEE
omgMgOooool0>_ooool00omEEEGoV9RHooooo`0@ooooo`03o`000?lb<S;o000000;o000000?oEEEE
omgMgOooool0Aoooool0033ooooo00?o^[Zjoc8b<_ooool04?ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1hoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0ooooo
o`03okZj^_lb<S;ooooo013ooooo00?o0000ooooooooool0C?ooool0037ooooo00?o<S8bolc<c?oo
ool03oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03[ooooo00?o0000ojVYZOoo
ool00_ooool00ooMgMgo410@ooooo`0?ooooo`03o`000?oooooooooo07;ooooo00?o0000ojVYZOoo
ool00_ooool00ooMgMgo410@ooooo`0?ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0@?ooool00olb<S;oc<c<ooooo`0?ooooo`03o`000?oooooooooo04cooooo000[ooooo`03oa0@
4?oooooooooo00?ooooo00?oV9RHoeEEEOooool03oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo03[ooooo00Oo8B4Qo`000?nHV9SoooooomgMgOlQ8B7oV9RH013ooooo00?o0000oooo
ooooool0L_ooool01olQ8B7o0000oiRHV?oooooogMgMob4Q8OnHV9P04?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo03[ooooo00?o410@ooooooooool00oooool00onHV9SoEEEEoooo
o`0?ooooo`03o`000?oooooooooo04cooooo000[ooooo`So00004?ooool7o`0003Kooooo1ol0000g
ooooo`05oiRHV?l@413o0000oa0@4?nHV9P04Oooool7o`0006oooooo00GoV9RHoa0@4?l0003o410@
oiRHV00Aooooo`Oo0000=Oooool7o`0003Kooooo2?l0000@ooooo`Oo0000B?ooool00?oooooooooo
oom2ooooo`00ooooool@ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo4?ooool00ol0
003oooooooooo`3ooooooboooooo003ooooooa3ooooo00?o0000ooooooooool0ooooool5ooooo`03
onk^k_mEEEGo000000;o000000?o<S8bogMgMooMgMd08_ooool00?oooooo4?ooool00ol0003ooooo
ooooo`3oooooo`Gooooo00SoA4A4oeEEEOo^k^koooooolc<c?mVIVKo8B4Qo`0002;ooooo003ooooo
oa3ooooo00?o0000ooooooooool0ooooool5ooooo`03o`000?o^k^kooooo02Oooooo003ooooooa3o
oooo00?o0000ooooooooool0ooooool5ooooo`03o`000?oooooooooo02Oooooo003ooooooa3ooooo
00?o0000ooooooooool0ooooool5ooooo`03o`000?oooooooooo02Oooooo000Koooooooo0000j_l0
000Booooo`03o`000?oooooooooo02Oooooo000Vooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00ko00003?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
1?l0003oooooooooooooool5o`0000Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Gooooo1Ol00002ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo2_l0
0004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool09oooool002Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05o`0000Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool2
o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo0_l00007ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo1Ol0000=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01[ooooo00?o410@o`000?l000001?l000000ol@413oooooooooo`0Rooooo`00=Oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01?ooooo1?l0000^ooooo`03o`000?oooooooooo
00Sooooo0_l0000looooo`03o`000?oooooooooo03[ooooo0ol00009ooooo`03o`000?oooooooooo
02oooooo1?l0000Booooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Wooooo`00V?ooool3o`0003Sooooo0_l0000jooooo`03o`000?oooooooooo03So
oooo0_l0000iooooo`Go0000S?ooool00ol0003oooooooooo`0Wooooo`009_ooool4o`00077ooooo
0_l0000hooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0eooooo`Co0000L?ooool3o`0001kooooo00?o410@ooooooooool09oooool002[ooooo1Ol0
001^ooooo`?o0000=_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0=?ooool2o`0006oooooo1Ol0001;ooooo`00;oooool4o`0006gooooo0_l0000e
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo06_ooooo1?l0001@ooooo`00<oooool3o`0006cooooo0_l0000doooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0coooo
o`;o0000Joooool3o`0005Cooooo000fooooo`?o0000Joooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0booooo`;o
0000J_ooool3o`0005Oooooo000iooooo`?o0000JOooool2o`0003?ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
I_ooool4o`0005[ooooo000looooo`?o0000J?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0`ooooo`;o0000I_oo
ool3o`0005kooooo000oooooo`?o0000I_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0_ooooo`;o0000IOooool3
o`00067ooooo0012ooooo`?o0000I?ooool2o`00037ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0H_ooool3o`00
06Cooooo0015ooooo`;o0000I?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033o
oooo0ol0000_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0HOooool2o`0006Oo
oooo0017ooooo`?o0000H_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo05kooooo
0ol0001Yooooo`00B_ooool2o`00067ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooooooo
o`1Mooooo`;o0000K?ooool004cooooo0_l0001Pooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0G?ooool2o`0006kooooo001>ooooo`;o0000G_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo05_ooooo0_l0001`ooooo`00D?ooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0F_ooool2o`0007;ooooo001Aooooo`;o0000
GOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
L_ooool005?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo05Wooooo0_l0001eooooo`00E?ooool2o`0005_ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`1Hooooo`;o0000Moooool005Kooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0Moooool005Oo
oooo0_l0001Jooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Eoooool2o`0007[o
oooo001Iooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo07[ooooo001Jooooo`;o0000F?ooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0Noooool005cooooo0_l0001G
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0EOooool2o`0007kooooo001Noooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Zoooo
o`?o0000:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0O_ooool005oooooo0_l0001Fooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`1oooooo`00HOooool00ol0003oooooooooo`1Cooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`20ooooo`00H_oo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0D_oo
ool2o`0008?ooooo001Sooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo08?ooooo001Tooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
08Cooooo001Uooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo08Gooooo001Vooooo`03o`000?oooooooooo057ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo08Kooooo
001Wooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo08Oooooo001Xooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo08Sooooo001Yoooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo08Wooooo001Zooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo08[ooooo001[ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo08_ooooo001/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo08cooooo001]ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo08gooooo001^ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Uooooo`?o00009Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0S_ooool006oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Soooool0073ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool0T?ooool0077ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0TOooool007;ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0T_ooool007?ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Toooool007Cooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool0U?ooool007Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0U?ooool007Kooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0UOoo
ool007Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0U_ooool007Oooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Rooooo`06onk^k_l0003o0000o`000?mEEEGok^k^1oooool00omEEEGo0000oeEE
E@07ooooo`So00002?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`2Gooooo`00N?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo027ooooo00Ko8B4Qo`000?ooooooooooohN7QolQ8B47ooooo`?o0000
1oooool00onHV9So0000oiRHV003ooooo`03olc<c?l0003ooooo00Oooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
Uoooool007Wooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Pooooo`03oiRHV?mE
EEGo000000?ooooo00?oEEEEoiRHV?ooool01Oooool00omEEEGo0000oeEEE@08ooooo`03olc<c?l0
003oV9RH00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0V?ooool007Wooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Pooooo`04odA4A?nj^[[oooooo`0000;ooooo00?o^[ZjodA4A?ooool04Ooo
ool00oo<c<co0000oiRHV00;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo09Wooooo001jooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool07oooool01?l0003ok^k^ooooool00002ooooo`03onk^k_l0
003ooooo01;ooooo00?oV9RHo`000?mgMgL02_ooool4o`00027ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo09[ooooo001kooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo01;ooooo00?oc<c<o`000?nHV9P02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Kooooo`00Noooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`0Cooooo`03olc<c?l0003oc<c<00Sooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0Vooo
ool007cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Nooooo`04o`000?o^k^ko
ooooo`0000;ooooo00?ok^k^o`000?ooool05Oooool00on7QhOo<S8booooo`07ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo09cooooo001mooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07_ooool0
2?m4A4Co^[Zjoooooooooooo0000oooooonj^[[oA4A45oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo09gooooo001nooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
7Oooool02?nHV9SoEEEEoooooooooooo0000oooooomEEEGoV9RH4Oooool00ol0003oZJVYooooo`02
ooooo`03omgMgOl@413ooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0W_ooool007kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0Nooooo`06ob4Q8On7QhOoooooo`000?n7QhOo8B4Q4_oo
ool01olQ8B7o0000oiRHV?oooooogMgMob4Q8OnHV9P02?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2Nooooo`00
Ooooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01kooooo00Kok^k^oeEEEOl0003o
0000oeEEEOo^k^hCooooo`05oiRHV?l@413o0000oa0@4?nHV9P02Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2O
ooooo`00P?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`2Pooooo`00POooool00ol0003oooooooooo`14ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Qooooo`00
POooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`2Qooooo`00P_ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`2Rooooo`00Poooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`2Sooooo`00Q?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2Tooooo`00Q?ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`2Uooooo`00QOooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool08?ooool3o`0001oooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo0:Gooooo0026ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0:Kooooo0026
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo0:Oooooo0027ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0:Sooooo0028ooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo0:Sooooo0029ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0:Wooooo0029ooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooooooo0:Wooooo002:ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo0:[ooooo002;ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
0:_ooooo002;ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo00?o<S8bo`000?l000001ol000000olb<S;o
ooooooooo`02ooooo`03onk^k_mEEEGo000000;o000000?o<S8bogMgMooMgMd01Oooool00ol0003o
ooooooooo`08ooooo`03oa0@4?l0003o000000?o000000?o410@ooooooooool01?ooool00olb<S;o
0000o`000007o`000003oc8b<_oooooooooo00;ooooo00?ok^k^oeEEEOl000000_l000000olb<S;o
MgMgomgMg@0?ooooo`So00004_ooool00olb<S;o0000o`000008o`0000Cooooo00?ok^k^oeEEEOl0
00000_l000000olb<S;oMgMgomgMg@0Cooooo`05oa0@4?l0003o0000o`000?l@4100ROooool008co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00_ooool00onHV9So<S8booooo`06ooooo`03odA4A?nHV9Sooooo00?o
oooo00SoA4A4oeEEEOo^k^koooooolc<c?mVIVKo8B4Qo`0000Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`07ooooo`03oiRHV?lb<S;ooooo00Gooooo00?o0000odA4A?nHV9P01?oo
ool02?m4A4CoEEEEonk^k_ooooooc<c<ofIVI_lQ8B7o00003oooool00onHV9So0000oiRHV003oooo
o`03olc<c?l0003ooooo017ooooo00?oV9RHoc8b<_ooool01_ooool00ol0003oV9RHooooo`03oooo
o`08odA4A?mEEEGok^k^ooooooo<c<coIVIVob4Q8Ol0000Eooooo`03o`000?oooooooooo08Wooooo
002<ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00?ooooo00?o410@omgMgOooool01?ooool00ooMgMgo410@oooo
o`04ooooo`03o`000?o^k^kooooo00Sooooo2?l00008ooooo`03o`000?oooooooooo00Sooooo00?o
410@omgMgOooool01?ooool00ol0003o410@ooooo`04ooooo`03o`000?o^k^kooooo00Sooooo2?l0
0005ooooo`03olc<c?l0003oV9RH01Oooooo00?o410@omgMgOooool01?ooool00ooMgMgo0000oooo
o`04ooooo`03o`000?o^k^kooooo00Sooooo2?l0000:ooooo`03o`000?oooooooooo08Wooooo002=
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00?ooooo00?oV9RHoeEEEOooool01?ooool00omEEEGoQhN7ooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`03oiRHV?mEEEGooooo00Cooooo00?o0000ohN7Qoooool01?ooool00ol0003oooooooooo`0F
ooooo`03olc<c?l0003oV9RH01Kooooo00?oV9RHoeEEEOooool01?ooool00ol0003oQhN7ooooo`04
ooooo`03o`000?oooooooooo01Cooooo2Ol00029ooooo`00S_ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03oooo
o`03onk^k_l@413ok^k^00?ooooo00?ok^k^oa0@4?o^k^h01Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00oo^k^ko410@onk^kP03oooo
o`03onk^k_l0003ok^k^00Gooooo00?o0000ooooooooool05oooool00onHV9So0000ogMgM`0Eoooo
o`03onk^k_l@413ok^k^00?ooooo00?o0000oa0@4?o^k^h01Oooool00ol0003oooooooooo`0Doooo
o`03ofIVI_m4A4Cooooo00?ooooo00?o0000ooooooooool0ROooool008kooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo0ol00004ooooo`03
ogMgMon7QhOooooo00;ooooo00?oQhN7ofIVI_ooool01Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00omgMgOoQhN7ooooo`02ooooo`03
o`000?mVIVKooooo00Gooooo00?o0000ooooooooool06?ooool00oo<c<co0000oiRHV00Eooooo`03
ogMgMon7QhOooooo00;ooooo00?o0000ofIVI_ooool01Oooool00ol0003oooooooooo`0Eooooo`03
ob4Q8OnYZJWooooo00;ooooo00?o0000ooooooooool0ROooool008oooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1?ooool00ooMgMgo410@ooooo`02ooooo`03oa0@4?oMgMgooooo00Gooooo00?o0000ooooooooool0
2?ooool8o`0000Sooooo00?o0000ooooooooool02Oooool00ooMgMgo410@ooooo`02ooooo`03o`00
0?oMgMgooooo00Gooooo00?o0000ooooooooool02?ooool8o`0000Wooooo00?oc<c<o`000?o<c<`0
5?ooool01ooMgMgo410@oooooooooooo0000oa0@4?oMgMd01_ooool00ol0003oooooooooo`08oooo
o`So00001Oooool00oo<c<co410@omgMg@02ooooo`03o`000?oooooooooo08Wooooo002?ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Gooooo00GoEEEEoiRHV?ooooooZJVYoeEEE@05ooooo`03oa0@4?l0003o0000
00Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00[ooooo00GoEEEEoiRHV?ooooooZJVYo`000005ooooo`03oa0@4?l0003o000000Co000000?o410@
ooooooooool05Oooool00on7QhOo<S8booooo`0Dooooo`05oeEEEOnHV9Soooooo`000?mEEED01Ooo
ool00ol@413o0000o`000004o`000003oa0@4?oooooooooo017ooooo00GoQhN7oc8b<_oooooooooo
o`00002;ooooo`00T?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`05olc<c?lb<S;ooooooc8b<_nj^[X0
1oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool01Oo<c<co<S8booooool0003o^[Zj00Oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Cooooo`05olc<c?lb<S;o0000oc8b<_nj^[X01oooool00ol0003oooooooooo`0Goooo
o`04oc8b<_n7QhOoooooo`0008_ooooo002Aooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o<S8boiRH
V?lb<S802?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00olb<S;oV9RHo`000008ooooo`03o`000?oooooooooo01Gooooo00?o0000ojVY
ZOooool00_ooool00ooMgMgo410@ooooo`0Eooooo`03o`000?nHV9So<S8b00Sooooo00?o0000oooo
ooooool05oooool01?oMgMgo410@omgMgOl0002;ooooo`00TOooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`03okZj^_l0003oV9RH00Sooooo00?o410@ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`04o`000?l@413oEEEEo`0000gooooo00?o^[Zjo`000?l000002?ooool00ol@413oooooooooo`0E
ooooo`07ob4Q8Ol0003oV9RHoooooooMgMgo8B4QoiRHV00Fooooo`;o000000?oV9RHooooooooool0
1_ooool00ol@413oooooooooo`0Hooooo`03ohN7Qolb<S;o000008_ooooo002Booooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Oooooo00?o<S8booooooooool04_ooool00ol0003oooooooooo`0:ooooo`04omgMgOn7
QhOoA4A4o`0000kooooo00?o0000ooooooooool08?ooool01OnHV9So410@o`000?l@413oV9RH01Ko
oooo00?o0000oooooolb<S809Oooool00olb<S;o410@ooooo`2:ooooo`00Toooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2booooo`00Toooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`2cooooo`00U?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2c
ooooo`00U?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`2dooooo`00UOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2eooooo`00
U_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`2eooooo`00U_ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2fooooo`00Uoooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07?ooool3
o`0001_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo0;Kooooo002Gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo0;Oooooo002Hooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0;So
oooo002Iooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo0;Sooooo002Iooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0;Wooooo002J
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo0;Wooooo002Jooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0;[ooooo002Kooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo0;_ooooo002Looooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0;_ooooo002Looooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo0;cooooo002Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo0;cooooo002Mooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool03oooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPCooooo00Ko
0000ooooooooooooEEEEo`000?mEEED;ooooo`05oa0@4?l0003o0000o`000?l@41001oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`2mooooo`00W_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00oo
oooo00Ko8B4QohN7QoooooooooooohN7QolQ8B44ooooo`03o`000?oooooooooo00?o00003Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo0;gooooo002Nooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03_ooool00onHV9SoEEEEooooo`03ooooo`03oeEEEOnHV9Sooooo
00;ooooo00Ko0000ooooooooooooEEEEo`000?mEEED=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0__ooool009oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`03odA4A?nj^[[ooooo00?ooooo00?o^[ZjodA4A?ooool00_ooool00ol0003oooooooooo`0:
ooooo`Wo00001oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`2nooooo`00Woooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00gooooo00?o0000onk^k_ooool00oooool00oo^k^ko0000ooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?oIVIVodA4A?ooool00oooool00ol0003oooooooooo`07oooo
o`Co00006?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0_oooool00:3ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
ob4Q8OnYZJWooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`2oooooo`00
X?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?oc<c<oa0@4?oMgMd0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0<3ooooo002Qooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool03?ooool00ol0003ok^k^ooooo`03ooooo`03onk^k_l0
003ooooo00?ooooo00?o0000ooooooooool02oooool01On7QhOo<S8boooooooooooo000000Wooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0`?ooool00:7ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0<ooooo`03odA4A?nj^[[ooooo00?ooooo00?o^[ZjodA4A?ooool00oooool00ol0003ooooooooo
o`0<ooooo`04oc8b<_n7QhOoooooo`0000Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0`Oooool00:;ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03oiRHV?mEEEGooooo00?ooooo00?o
EEEEoiRHV?ooool00oooool00ol0003oooooooooo`0<ooooo`04omgMgOl@413ogMgMo`0000Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0`Oooool00:;ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0=ooooo`06ob4Q8On7QhOooooooooooon7QhOo8B4Q1Oooool00ol0003oooooooooo`0=ooooo`03
ohN7Qolb<S;o000000Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0`_ooool00:?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0<ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^1_ooool00ol0
003oooooooooo`0=ooooo`03oc8b<_l@413ooooo00Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0`_ooool00:?o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0`oooool00:Cooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0`oooool00:Cooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0a?ooool00:Gooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0a?ooool00:Gooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool0aOooool00:Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0a_ooool00:Oooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo0ol0000Gooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`36ooooo`00Yooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`37ooooo`00Z?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`37ooooo`00Z?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`38ooooo`00ZOooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`38ooooo`00ZOooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`39ooooo`00Z_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`39ooooo`00Z_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3:
ooooo`00Zoooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`3:ooooo`00Zoooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3;ooooo`00
[?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`3;ooooo`00[?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3<ooooo`00[Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`3<ooooo`00[Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3=ooooo`00[_ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool3o`0001Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0<go
oooo002^ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo0<kooooo002_ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0<kooooo002_
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo0<oooooo002`ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo0<oooooo002`ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo0=3ooooo002aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0=3ooooo002aooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo0=7ooooo002booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0=7ooooo002booooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
0=7ooooo002cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0=;ooooo002cooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0=;ooooo
002cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo0=?ooooo002dooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0=?ooooo002doooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo0=Cooooo002eooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Cooooo`?o00005?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0e?ooool00;Gooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
eOooool00;Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0eOooool00;Kooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0e_ooool0
0;Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0e_ooool00;Oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0e_ooool00;Sooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0eoooool00;Sooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0eoooool00;Wooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0f?ooool00;Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0f?ooool00;[ooooo00?o0000oooooooo
ool09oooool01_l0003oooooooooooooooook^k^oeEEE@;o000000?oEEEEonk^k_ooool01_ooool0
0omEEEGo0000oeEEE@02ooooo`03o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000ob4Q
8OnYZJT9ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo0=Wooooo002jooooo`03o`000?oooooooooo02Oooooo00Ko
0000ooooooooooooooooob4Q8On7QhL2ooooo`03ohN7QolQ8B7ooooo00Kooooo0ol00002ooooo`03
o`000?oooooooooo00;ooooo00Sok^k^oc8b<_n7QhOok^k^oooooonHV9So0000okZj^PSooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0fOooool00;[ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooonH
V9SoEEEE00Cooooo00?oEEEEoiRHV?ooool01Oooool00omEEEGo0000oeEEE@02ooooo`03o`000?oo
oooooooo00;ooooo00?oMgMgohN7Qoooool00oooool00onHV9SoA4A4ooooo`07ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo0=[ooooo002kooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooA4A4okZj
^P04ooooo`03okZj^_m4A4Cooooo00[ooooo00?o0000ooooooooool00_ooool00olQ8B7ok^k^oooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0f_ooool00;_ooooo00?o0000
ooooooooool09oooool01?l0003oooooo`000?o^k^h4ooooo`03onk^k_l0003ooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo1?l0
000Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`3Kooooo`00_?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?nHV9Sooooo00?ooooo00?oV9RH
odA4A?ooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`3Kooooo`00_?ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooo000000Kooooo00?o0000ooooooooool02_ooool01ol0003ooooooooooooooooo
0000oa0@4?nHV9P00_ooool00onHV9So410@olc<c008ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0=_ooooo002m
ooooo`03o`000?oooooooooo02Gooooo00Co0000ooooool0003ok^k^1?ooool00oo^k^ko0000oooo
o`0;ooooo`07o`000?oooooooooooooooom4A4CoV9RHodA4A002o`000003odA4A?o<c<cooooo00So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0g?ooool00;gooooo00?o0000ooooooooool09_ooool00ol0003oA4A4
okZj^P04ooooo`03okZj^_m4A4Cooooo00_ooooo00Ko0000oooooooooooooooooiRHV?mEEED>oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo0=cooooo002nooooo`03o`000?oooooooooo02Gooooo00?o0000oiRHV?mE
EED01?ooool00omEEEGoV9RHooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o<S8boiRHV?oo
ool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`3Mooooo`00__ooool00ol0003oooooooooo`0Uooooo`04o`00
0?oooooo8B4QohN7Q`;ooooo00?oQhN7ob4Q8Oooool03?ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7oEEEEolc<c0_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0gOooool00;oooooo00?o0000oooooooo
ool09?ooool01?l0003oooooonk^k_mEEED2o`000003oeEEEOo^k^kooooo00cooooo00?o0000oooo
ooooool01?ooool01OnHV9So<S8bo`000?l0003o8B4Q00Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0g_ooool0
0;oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0g_ooool00<3ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0goooool00<3ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0goooool00<3ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0h?ooool00<7ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0h?ooool00<7ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0h?ooool00<;ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0hOooool00<;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo013ooooo0ol0000@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`3Qooooo`00`oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3Rooooo`00`oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`3Rooooo`00a?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3Sooooo`00a?ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`3Sooooo`00aOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`3Tooooo`00aOooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`3Tooooo`00a_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`3Uooooo`00a_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3Uoooo
o`00aoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`3Vooooo`00aoooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3Vooooo`00b?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`3Wooooo`00b?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3Wooooo`00bOooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`3Xooooo`00bOooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03oooool3o`0000kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo0>Sooooo003:ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0>Wooooo
003:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0>Wooooo003;ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0>[ooooo003;oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo0>[ooooo003<ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0>_ooooo003=ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0>cooooo003=ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0>cooooo003>ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo0>gooooo003>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo0>gooooo003?ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0>ko
oooo003?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo0>kooooo003@ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0>oooooo003@
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo0>oooooo003Aooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`?o00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0l?ooool00=7ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0l?ooool00=;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0lOooool00=;ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0lOoo
ool00=?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0l_ooool00=?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0l_ooool00=Co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0loooool00=Cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0loooool00=Gooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0m?ooool00=Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0m?ooool00=Kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0mOooool00=Kooooo00?o0000ooooooooool03oooool01_o^k^koEEEEo`000?l0003oEEEE
onk^kPGooooo00Go0000oooooomEEEGo0000oeEEE@08ooooo`06ojVYZOl0003o0000o`000?lQ8B7o
ZJVY2Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`3eooooo`00eoooool00ol0003oooooooooo`0>ooooo`06ob4Q
8On7QhOooooooooooon7QhOo8B4Q1Oooool00ol0003oooooo`000002o`0000Oooooo00?oZJVYo`00
0?l000000_ooool00onYZJWo410@ojVYZ@08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?Kooooo003Gooooo`03
o`000?oooooooooo00gooooo00?oV9RHoeEEEOooool00oooool00omEEEGoV9RHooooo`03ooooo`05
o`000?ooooooEEEEo`000?mEEED01oooool00ol@413o^[Zjo`000003ooooo`03okZj^_l@413ooooo
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0m_ooool00=Sooooo00?o0000ooooooooool03?ooool00om4A4Co
^[Zjooooo`03ooooo`03okZj^_m4A4Cooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0moooool00=Sooooo
00?o0000ooooooooool03?ooool00ol0003ok^k^ooooo`03ooooo`03onk^k_l0003ooooo00Cooooo
00?o0000ooooooooool02?ooool00olb<S;o^[Zjo`000003ooooo`03okZj^_l@413ooooo00Oooooo
1?l00009ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`3hooooo`00fOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`08ohN7Qol@413oZJVYo`000?oooooo
ZJVYo`000?n7QhL8ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo0?Sooooo003Iooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o410@o`000?l000000_l000000ol@413oooooooooo`07ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?Wo
oooo003Jooooo`03o`000?oooooooooo00[ooooo00?o0000onk^k_ooool00oooool00oo^k^ko0000
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00SoQhN7ob4Q8OnYZJWo0000oooooonYZJWo8B4Q
ogMgM`Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0nOooool00=[ooooo00?o0000ooooooooool02_ooool00om4
A4Co^[Zjooooo`03ooooo`03okZj^_m4A4Cooooo00Gooooo00?o0000ooooooooool01oooool01?l0
003ogMgMooooool00002ooooo`03omgMgOl0003ooooo00Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0n_ooool0
0=_ooooo00?o0000ooooooooool02Oooool00onHV9SoEEEEooooo`03ooooo`03oeEEEOnHV9Sooooo
00Gooooo00?o0000ooooooooool01oooool01?l@413ogMgMooooool00002ooooo`03omgMgOl@413o
oooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0n_ooool00=cooooo00?o0000ooooooooool02Oooool01_lQ
8B7oQhN7ooooooooooooQhN7ob4Q8@Oooooo00?o0000ooooooooool01oooool02?nYZJWo8B4QokZj
^_l0003ooooookZj^_lQ8B7oZJVY2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3kooooo`00g?ooool00ol0003o
ooooooooo`09ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^2?ooool00ol0003oooooooooo`07
ooooo`06ojVYZOlQ8B7o0000o`000?lQ8B7oZJVY2Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3looooo`00gOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`3looooo`00gOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3mooooo`00g_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`3mooooo`00g_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3nooooo`00goooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`3oooooo`00goooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`3oooooo`00h?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool3o`0000Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo0Oooool0
0>3ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0ooooool1ooooo`00hOooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3oooooo`;o
oooo003Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0?oooooo0_ooool00>;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0oooo
ool3ooooo`00hoooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`3oooooo`Cooooo003Sooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
0?oooooo1?ooool00>Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0ooooool5ooooo`00iOooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`3oooooo`Gooooo003Uooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo1_ooool00>Kooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0ooooool6ooooo`00i_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3oooooo`Oooooo003Wooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo0?oooooo2?ooool00>Sooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0ooooool8ooooo`00j?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool3o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo0?oooooo2Oooool00>Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0ooooool9ooooo`00jOooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`3oooooo`[ooooo003Zooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo2oooool00>_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0ooooool<ooooo`00k?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3oooooo`cooooo003]
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0?oooooo3Oooool00>kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0ooooool>oooo
o`00k_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`3oooooo`oooooo003_ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo
3oooool00?3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0ooooool@ooooo`00lOooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3o
oooooa7ooooo003booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`;o0000oooooolDooooo`00loooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooaCo
oooo003dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0?oooooo5Oooool00?Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0ol00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooooaKooooo003f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0?oooooo5oooool00?Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolHoooo
o`00n?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3ooooooaWooooo003iooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
6_ooool00?[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0oooooolKooooo`00noooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo7_ooool0
0?cooooo0_l00008ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooakooooo003n
ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolOooooo`00ooooool1ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool2o`000?oooooo
8_ooool00?oooooo0Oooool00ol@413o0000o`000003o`000003oa0@4?l0003ooooo00;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool2o`000?oo
oooo9?ooool00?oooooo1?ooool3o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooobCooooo003oooooo`Co
oooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo0000
00;ooooo00Co0000oooooooooooooooo0_l0003oooooobOooooo003oooooo`Cooooo00Co0000oooo
oooooooooooo0ol000001ooooooo0000o`000?l0003oooooo`000?ooool01ol0003oooooobWooooo
003oooooo`Cooooo00?o0000ooooooooool01?ooool:o`000?oooooo;Oooool00?oooooo1?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo1?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo1?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo1?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo1?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo0Oooool01?l0003o410@oeEEEOl0
000;ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo0Oooool01?oMgMgoQhN7odA4A?l0
000;ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooooooooom2ooooo`00oooooooooooo
od;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003o
oooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo
@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oo
oooooooooom2ooooo`00oooooooooooood;ooooo003jooooo`06ob4Q8Ol0003o0000o`000?m4A4Co
ZJVY2oooool00onYZJWo<S8booooo`0?ooooo`03oc8b<_nYZJWooooo0?oooooo8Oooool00?kooooo
00?o^[Zjob4Q8On7QhL02_ooool00ol@413ogMgMooooo`0?ooooo`03omgMgOl@413ooooo0?oooooo
8Oooool00?oooooo00?o^[Zjoa0@4?ooool02?ooool00onHV9SoEEEEooooo`0Aooooo`03oeEEEOnH
V9Sooooo0?oooooo8?ooool00?oooooo0Oooool00ol0003oooooooooo`07ooooo`03oa0@4?oMgMgo
oooo017ooooo00?ogMgMoa0@4?ooool0oooooolPooooo`00n_ooool01onj^[[oA4A4o`000?l0003o
MgMgonk^k_l000002?ooool00onYZJWoEEEEooooo`06ooooo`03onk^k_mEEEGo000000;o000000?o
<S8bogMgMooMgMd01Oooool00olb<S;oZJVYooooo`3ooooooaoooooo003iooooo`06ogMgMomVIVKo
gMgMoooooooMgMgoIVIV0_l00008ooooo`03ofIVI_nYZJWooooo00Kooooo00SoA4A4oeEEEOo^k^ko
ooooolc<c?mVIVKo8B4Qo`0000Gooooo00?oV9RHofIVI_ooool0oooooolOooooo`00n?ooool00onj
^[[oIVIVooooo`04ooooo`03ofIVI_l0003ooooo00Oooooo00?o<S8bonk^k_ooool01_ooool00ol0
003ok^k^ooooo`0:ooooo`03olc<c?lb<S;ooooo0?oooooo7oooool00?Sooooo00?oA4A4omgMgOoo
ool01?ooool00ooMgMgo0000ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3ooooooakooooo003hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0oooooolNooooo`00n?ooool00om4A4CogMgMooooo`04ooooo`03omgMgOl0
003ooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo0?oooooo7_ooool00?Sooooo00?o^[ZjofIVI_ooool01?ooool00omVIVKo0000ooooo`07
ooooo`03oc8b<_oMgMgooooo00Kooooo00?o0000ooooooooool02_ooool00oo<c<co<S8booooo`3o
oooooaoooooo003iooooo`06oeEEEOmVIVKogMgMoooooooMgMgoIVIV0_l00008ooooo`03ofIVI_nH
V9Sooooo00Cooooo00?o410@o`000?l000001?l000000ol@413oooooooooo`05ooooo`03ohN7QomE
EEGooooo0?oooooo7oooool00?[ooooo00SoMgMgoa0@4?l0003o410@ohN7Qonj^[[o0000oa0@40Oo
oooo00?oZJVYob4Q8Oooool01_ooool00ol0003oooooooooo`0:ooooo`03ob4Q8OnYZJWooooo0?oo
oooo7oooool00?oooooo2oooool00ol@413o^[Zjooooo`05ooooo`03o`000?oooooooooo00Wooooo
00?o^[Zjoa0@4?ooool0oooooolPooooo`00ooooool;ooooo`03oiRHV?m4A4Cooooo00Gooooo00?o
410@ooooooooool02Oooool00olb<S;oV9RHooooo`3oooooob3ooooo003oooooo`cooooo00?o410@
olc<c?ooool03oooool00onj^[[o410@ooooo`3oooooob7ooooo003oooooo`cooooo00?oZJVYoc8b
<_ooool03oooool00olb<S;oZJVYooooo`3oooooob7ooooo003ooooooooooooo@_ooool00?oooooo
oooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-9.3385, -0.0838681, \
0.068818, 0.00695936}}],

Cell[TextData[{
  "Fig. 2.7 The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(t)\), "=", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
              SuperscriptBox[
                RowBox[{"(", 
                  FractionBox["t", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]], ")"}], "2"]}]]}], 
        TraditionalForm]]],
  " for three choices of \[CapitalDelta]t."
}], "Caption",
  CellTags->"Fig. 2.7"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.0147151 0.0830228 [
[.02381 .00222 -6 -9 ]
[.02381 .00222 6 0 ]
[.2619 .00222 -6 -9 ]
[.2619 .00222 6 0 ]
[.7381 .00222 -3 -9 ]
[.7381 .00222 3 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.4875 .09774 -6 -4.5 ]
[.4875 .09774 0 4.5 ]
[.4875 .18076 -6 -4.5 ]
[.4875 .18076 0 4.5 ]
[.4875 .26378 -6 -4.5 ]
[.4875 .26378 0 4.5 ]
[.4875 .34681 -6 -4.5 ]
[.4875 .34681 0 4.5 ]
[.4875 .42983 -6 -4.5 ]
[.4875 .42983 0 4.5 ]
[.4875 .51285 -6 -4.5 ]
[.4875 .51285 0 4.5 ]
[.4875 .59587 -6 -4.5 ]
[.4875 .59587 0 4.5 ]
[.5 .64303 -20 0 ]
[.5 .64303 20 12 ]
[.79762 .07715 -14 -6 ]
[.79762 .07715 14 6 ]
[.64286 .1812 -14 -6 ]
[.64286 .1812 14 6 ]
[.60119 .43093 -14 -6 ]
[.60119 .43093 14 6 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .01472 m
.02381 .02097 L
s
[(-4)] .02381 .00222 0 1 Mshowa
.2619 .01472 m
.2619 .02097 L
s
[(-2)] .2619 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(2)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(4)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08333 .01472 m
.08333 .01847 L
s
.14286 .01472 m
.14286 .01847 L
s
.20238 .01472 m
.20238 .01847 L
s
.32143 .01472 m
.32143 .01847 L
s
.38095 .01472 m
.38095 .01847 L
s
.44048 .01472 m
.44048 .01847 L
s
.55952 .01472 m
.55952 .01847 L
s
.61905 .01472 m
.61905 .01847 L
s
.67857 .01472 m
.67857 .01847 L
s
.79762 .01472 m
.79762 .01847 L
s
.85714 .01472 m
.85714 .01847 L
s
.91667 .01472 m
.91667 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .09774 m
.50625 .09774 L
s
[(1)] .4875 .09774 1 0 Mshowa
.5 .18076 m
.50625 .18076 L
s
[(2)] .4875 .18076 1 0 Mshowa
.5 .26378 m
.50625 .26378 L
s
[(3)] .4875 .26378 1 0 Mshowa
.5 .34681 m
.50625 .34681 L
s
[(4)] .4875 .34681 1 0 Mshowa
.5 .42983 m
.50625 .42983 L
s
[(5)] .4875 .42983 1 0 Mshowa
.5 .51285 m
.50625 .51285 L
s
[(6)] .4875 .51285 1 0 Mshowa
.5 .59587 m
.50625 .59587 L
s
[(7)] .4875 .59587 1 0 Mshowa
.125 Mabswid
.5 .03132 m
.50375 .03132 L
s
.5 .04792 m
.50375 .04792 L
s
.5 .06453 m
.50375 .06453 L
s
.5 .08113 m
.50375 .08113 L
s
.5 .11434 m
.50375 .11434 L
s
.5 .13095 m
.50375 .13095 L
s
.5 .14755 m
.50375 .14755 L
s
.5 .16416 m
.50375 .16416 L
s
.5 .19737 m
.50375 .19737 L
s
.5 .21397 m
.50375 .21397 L
s
.5 .23057 m
.50375 .23057 L
s
.5 .24718 m
.50375 .24718 L
s
.5 .28039 m
.50375 .28039 L
s
.5 .29699 m
.50375 .29699 L
s
.5 .3136 m
.50375 .3136 L
s
.5 .3302 m
.50375 .3302 L
s
.5 .36341 m
.50375 .36341 L
s
.5 .38002 m
.50375 .38002 L
s
.5 .39662 m
.50375 .39662 L
s
.5 .41322 m
.50375 .41322 L
s
.5 .44643 m
.50375 .44643 L
s
.5 .46304 m
.50375 .46304 L
s
.5 .47964 m
.50375 .47964 L
s
.5 .49625 m
.50375 .49625 L
s
.5 .52946 m
.50375 .52946 L
s
.5 .54606 m
.50375 .54606 L
s
.5 .56267 m
.50375 .56267 L
s
.5 .57927 m
.50375 .57927 L
s
.5 .61248 m
.50375 .61248 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .64303 -81 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 8.688 moveto
(\\216) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.000 moveto
(L) show
99.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01741 m
.04262 .01839 L
.06244 .01974 L
.08255 .02152 L
.10458 .02405 L
.12415 .02689 L
.14509 .03067 L
.18653 .04072 L
.22646 .05403 L
.26488 .07021 L
.30574 .09034 L
.3451 .11109 L
.38293 .13027 L
.40397 .13978 L
.42322 .14733 L
.44332 .15376 L
.46199 .15817 L
.47118 .15973 L
.47588 .16037 L
.48098 .16093 L
.48389 .1612 L
.48657 .1614 L
.48909 .16156 L
.49184 .1617 L
.49304 .16174 L
.49432 .16179 L
.49543 .16181 L
.49664 .16184 L
.49734 .16185 L
.498 .16186 L
.49928 .16187 L
.50045 .16187 L
.5017 .16186 L
.50284 .16185 L
.50408 .16183 L
.50538 .16179 L
.50659 .16176 L
.50875 .16167 L
.51107 .16155 L
.51636 .16118 L
.52117 .16071 L
.53057 .15946 L
.53945 .15788 L
.55946 .15297 L
.57792 .14693 L
.61732 .13015 L
.65521 .11093 L
.69555 .08968 L
.73437 .07056 L
.77565 .05324 L
Mistroke
.81541 .04016 L
.85365 .03092 L
.87336 .0273 L
.89435 .02419 L
.9158 .02169 L
.93598 .01986 L
.9561 .01847 L
.97459 .01748 L
.97619 .01741 L
Mfstroke
.02381 .01472 m
.02846 .01472 L
.03279 .01472 L
.03754 .01472 L
.04262 .01472 L
.04795 .01472 L
.053 .01472 L
.05753 .01472 L
.06244 .01472 L
.06751 .01472 L
.07308 .01472 L
.0789 .01472 L
.08435 .01472 L
.08944 .01472 L
.0941 .01472 L
.09947 .01472 L
.10458 .01472 L
.10961 .01472 L
.11417 .01472 L
.11943 .01473 L
.12439 .01473 L
.13322 .01474 L
.13819 .01474 L
.14277 .01475 L
.14747 .01476 L
.15251 .01477 L
.1616 .01481 L
.16715 .01483 L
.17241 .01487 L
.17709 .0149 L
.18226 .01495 L
.19191 .01508 L
.1972 .01517 L
.20217 .01528 L
.21103 .01553 L
.22059 .01591 L
.23016 .01644 L
.24063 .01727 L
.25156 .01849 L
.26173 .02007 L
.27225 .02229 L
.28219 .02507 L
.29111 .02825 L
.30077 .0326 L
.32065 .04513 L
.33067 .05364 L
.34169 .06493 L
.36114 .09021 L
.38203 .12496 L
.42331 .20906 L
Mistroke
.44394 .25049 L
.45398 .26817 L
.46307 .28202 L
.47198 .29316 L
.47666 .29792 L
.48159 .30207 L
.48412 .30383 L
.48689 .30548 L
.48944 .30672 L
.49176 .30762 L
.49415 .30831 L
.49546 .3086 L
.4967 .3088 L
.49785 .30893 L
.49891 .309 L
.50008 .30902 L
.50132 .30899 L
.50246 .3089 L
.50371 .30874 L
.50501 .3085 L
.50622 .30822 L
.50839 .30756 L
.51071 .30665 L
.51601 .30375 L
.52083 .30015 L
.53024 .29063 L
.53912 .2789 L
.57764 .20707 L
.61861 .12379 L
.63901 .09 L
.65806 .0652 L
.67637 .0475 L
.68663 .03992 L
.696 .03428 L
.70524 .02978 L
.71506 .02597 L
.72584 .02277 L
.73582 .02053 L
.74517 .01895 L
.75526 .01768 L
.76479 .01681 L
.77353 .01621 L
.78332 .01574 L
.79243 .01542 L
.79767 .01528 L
.80243 .01518 L
.80763 .01509 L
.81313 .01501 L
.81787 .01495 L
.82309 .0149 L
Mistroke
.83229 .01484 L
.83746 .01481 L
.84302 .01479 L
.84789 .01477 L
.85308 .01476 L
.85832 .01475 L
.86319 .01474 L
.86898 .01473 L
.87423 .01473 L
.8792 .01473 L
.88458 .01472 L
.88965 .01472 L
.89432 .01472 L
.89902 .01472 L
.90407 .01472 L
.90882 .01472 L
.91316 .01472 L
.91825 .01472 L
.92378 .01472 L
.929 .01472 L
.93383 .01472 L
.93847 .01472 L
.94346 .01472 L
.94818 .01472 L
.95251 .01472 L
.9573 .01472 L
.96255 .01472 L
.96802 .01472 L
.97311 .01472 L
.97619 .01472 L
Mfstroke
.02381 .01472 m
.02499 .01472 L
.02605 .01472 L
.02729 .01472 L
.02846 .01472 L
.02954 .01472 L
.03053 .01472 L
.03163 .01472 L
.03279 .01472 L
.03395 .01472 L
.0352 .01472 L
.03638 .01472 L
.03746 .01472 L
.03873 .01472 L
.04011 .01472 L
.04141 .01472 L
.04262 .01472 L
.04386 .01472 L
.04521 .01472 L
.04648 .01472 L
.04765 .01472 L
.04871 .01472 L
.04987 .01472 L
.05108 .01472 L
.05221 .01472 L
.05354 .01472 L
.0548 .01472 L
.05592 .01472 L
.05715 .01472 L
.05848 .01472 L
.0599 .01472 L
.06111 .01472 L
.06244 .01472 L
.06371 .01472 L
.0651 .01472 L
.06655 .01472 L
.0679 .01472 L
.06917 .01472 L
.07032 .01472 L
.07165 .01472 L
.0729 .01472 L
.07427 .01472 L
.07572 .01472 L
.07695 .01472 L
.07831 .01472 L
.07977 .01472 L
.08059 .01472 L
.08134 .01472 L
.0828 .01472 L
.08418 .01472 L
Mistroke
.08546 .01472 L
.08663 .01472 L
.08798 .01472 L
.08924 .01472 L
.09042 .01472 L
.0915 .01472 L
.09269 .01472 L
.09394 .01472 L
.09521 .01472 L
.09657 .01472 L
.09785 .01472 L
.09902 .01472 L
.10039 .01472 L
.10187 .01472 L
.10328 .01472 L
.10458 .01472 L
.10576 .01472 L
.10701 .01472 L
.10807 .01472 L
.10923 .01472 L
.11048 .01472 L
.11182 .01472 L
.11309 .01472 L
.11423 .01472 L
.1154 .01472 L
.11647 .01472 L
.11765 .01472 L
.11889 .01472 L
.11997 .01472 L
.12098 .01472 L
.12209 .01472 L
.12328 .01472 L
.12466 .01472 L
.12593 .01472 L
.12733 .01472 L
.12882 .01472 L
.1301 .01472 L
.13131 .01472 L
.13263 .01472 L
.13406 .01472 L
.13525 .01472 L
.13656 .01472 L
.13792 .01472 L
.13919 .01472 L
.14038 .01472 L
.14147 .01472 L
.14272 .01472 L
.1439 .01472 L
.14505 .01472 L
.14628 .01472 L
Mistroke
.14852 .01472 L
.14988 .01472 L
.15117 .01472 L
.15234 .01472 L
.1536 .01472 L
.15496 .01472 L
.15619 .01472 L
.1576 .01472 L
.15894 .01472 L
.16018 .01472 L
.16132 .01472 L
.16257 .01472 L
.16389 .01472 L
.16608 .01472 L
.16732 .01472 L
.16844 .01472 L
.16948 .01472 L
.17062 .01472 L
.17268 .01472 L
.17384 .01472 L
.17511 .01472 L
.17645 .01472 L
.1777 .01472 L
.17993 .01472 L
.18118 .01472 L
.18233 .01472 L
.18361 .01472 L
.18482 .01472 L
.18708 .01472 L
.18834 .01472 L
.18951 .01472 L
.19087 .01472 L
.19215 .01472 L
.19426 .01472 L
.19538 .01472 L
.19658 .01472 L
.19784 .01472 L
.19903 .01472 L
.20127 .01472 L
.20258 .01472 L
.20376 .01472 L
.20504 .01472 L
.20641 .01472 L
.20769 .01472 L
.20887 .01472 L
.21118 .01472 L
.21248 .01472 L
.21369 .01472 L
.21513 .01472 L
.21643 .01472 L
Mistroke
.21911 .01472 L
.22058 .01472 L
.22198 .01472 L
.22436 .01472 L
.22659 .01472 L
.22786 .01472 L
.22903 .01472 L
.2304 .01472 L
.23167 .01472 L
.23418 .01472 L
.23551 .01472 L
.23693 .01472 L
.23828 .01472 L
.23956 .01472 L
.24194 .01472 L
.24418 .01472 L
.24655 .01472 L
.24858 .01472 L
.2508 .01472 L
.25319 .01472 L
.25575 .01472 L
.25817 .01472 L
.26038 .01472 L
.26266 .01472 L
.26518 .01472 L
.26781 .01472 L
.27029 .01472 L
.27259 .01472 L
.2747 .01472 L
.27701 .01472 L
.27945 .01472 L
.28194 .01472 L
.28459 .01472 L
.28709 .01472 L
.28937 .01472 L
.29204 .01472 L
.29494 .01472 L
.29768 .01472 L
.30021 .01472 L
.30265 .01473 L
.30488 .01473 L
.30745 .01473 L
.3099 .01474 L
.31424 .01475 L
.31669 .01476 L
.31897 .01477 L
.32167 .01479 L
.32421 .01481 L
.32896 .01487 L
.33162 .01491 L
Mistroke
.33407 .01496 L
.33676 .01503 L
.3396 .01513 L
.34216 .01523 L
.34457 .01536 L
.3491 .01567 L
.35163 .01589 L
.35397 .01615 L
.35927 .01691 L
.3635 .01778 L
.36817 .01908 L
.37304 .02094 L
.37761 .0233 L
.38232 .02653 L
.38747 .03122 L
.39284 .03774 L
.39783 .04563 L
.40678 .06538 L
.41179 .0802 L
.41634 .09636 L
.42634 .14201 L
.43555 .197 L
.45636 .35861 L
.4662 .44107 L
.47675 .52004 L
.48186 .55114 L
.48671 .57472 L
.49107 .59022 L
.49226 .59346 L
.49353 .59641 L
.49461 .59853 L
.49581 .60042 L
.49694 .60178 L
.49813 .60275 L
.49924 .60324 L
.50027 .60332 L
.50149 .60296 L
.5026 .60221 L
.50388 .60083 L
.50509 .59904 L
.50727 .59462 L
.50928 .5892 L
.51382 .57243 L
.51842 .54956 L
.52349 .51846 L
.53373 .44164 L
.55478 .26708 L
.56476 .19491 L
.57403 .14006 L
.58354 .09684 L
Mistroke
.58898 .07772 L
.59391 .06356 L
.60306 .04409 L
.60808 .03649 L
.61281 .03093 L
.61746 .0267 L
.62257 .02319 L
.62791 .02053 L
.63289 .01874 L
.63756 .01754 L
.64181 .01673 L
.64416 .01638 L
.64672 .01607 L
.65137 .01563 L
.6537 .01546 L
.65622 .01532 L
.66077 .01511 L
.66341 .01503 L
.66618 .01496 L
.67115 .01487 L
.67366 .01483 L
.67634 .01481 L
.67867 .01479 L
.68118 .01477 L
.68414 .01476 L
.68693 .01475 L
.68965 .01474 L
.69216 .01473 L
.6946 .01473 L
.69683 .01473 L
.69941 .01472 L
.70185 .01472 L
.70411 .01472 L
.70619 .01472 L
.70849 .01472 L
.71092 .01472 L
.71361 .01472 L
.71651 .01472 L
.71924 .01472 L
.72176 .01472 L
.72404 .01472 L
.72653 .01472 L
.72914 .01472 L
.73157 .01472 L
.73418 .01472 L
.73659 .01472 L
.73924 .01472 L
.74058 .01472 L
.74205 .01472 L
.74451 .01472 L
Mistroke
.74717 .01472 L
.74967 .01472 L
.75196 .01472 L
.75432 .01472 L
.75651 .01472 L
.75892 .01472 L
.76026 .01472 L
.76148 .01472 L
.76372 .01472 L
.76614 .01472 L
.76843 .01472 L
.77053 .01472 L
.77179 .01472 L
.77299 .01472 L
.77523 .01472 L
.77648 .01472 L
.77764 .01472 L
.77899 .01472 L
.78026 .01472 L
.78235 .01472 L
.78356 .01472 L
.78466 .01472 L
.78691 .01472 L
.7881 .01472 L
.78934 .01472 L
.79181 .01472 L
.79319 .01472 L
.79445 .01472 L
.79562 .01472 L
.79689 .01472 L
.7992 .01472 L
.8005 .01472 L
.80193 .01472 L
.80342 .01472 L
.80482 .01472 L
.80731 .01472 L
.80872 .01472 L
.81 .01472 L
.81129 .01472 L
.8125 .01472 L
.81477 .01472 L
.81604 .01472 L
.81721 .01472 L
.81858 .01472 L
.81986 .01472 L
.82198 .01472 L
.8231 .01472 L
.82431 .01472 L
.82557 .01472 L
.82676 .01472 L
Mistroke
.829 .01472 L
.83019 .01472 L
.83151 .01472 L
.83288 .01472 L
.83416 .01472 L
.83646 .01472 L
.83775 .01472 L
.83894 .01472 L
.84015 .01472 L
.84145 .01472 L
.84287 .01472 L
.8442 .01472 L
.84569 .01472 L
.8471 .01472 L
.84836 .01472 L
.84973 .01472 L
.85097 .01472 L
.8521 .01472 L
.85331 .01472 L
.85463 .01472 L
.85585 .01472 L
.85698 .01472 L
.85805 .01472 L
.85921 .01472 L
.86058 .01472 L
.86186 .01472 L
.86311 .01472 L
.86426 .01472 L
.86551 .01472 L
.86687 .01472 L
.8683 .01472 L
.86963 .01472 L
.87094 .01472 L
.87237 .01472 L
.87371 .01472 L
.87495 .01472 L
.87607 .01472 L
.87731 .01472 L
.87859 .01472 L
.8798 .01472 L
.8812 .01472 L
.88254 .01472 L
.88373 .01472 L
.88504 .01472 L
.88646 .01472 L
.88797 .01472 L
.88939 .01472 L
.89068 .01472 L
.89188 .01472 L
.893 .01472 L
Mistroke
.89423 .01472 L
.89555 .01472 L
.89694 .01472 L
.89825 .01472 L
.89942 .01472 L
.9007 .01472 L
.90181 .01472 L
.90302 .01472 L
.9043 .01472 L
.90549 .01472 L
.9066 .01472 L
.90762 .01472 L
.90874 .01472 L
.90992 .01472 L
.91123 .01472 L
.91241 .01472 L
.91378 .01472 L
.91507 .01472 L
.91627 .01472 L
.91737 .01472 L
.91858 .01472 L
.91987 .01472 L
.92115 .01472 L
.92254 .01472 L
.92385 .01472 L
.92504 .01472 L
.92644 .01472 L
.92718 .01472 L
.92797 .01472 L
.92941 .01472 L
.93074 .01472 L
.93199 .01472 L
.93336 .01472 L
.93478 .01472 L
.93611 .01472 L
.93736 .01472 L
.9385 .01472 L
.93981 .01472 L
.94105 .01472 L
.9424 .01472 L
.94383 .01472 L
.94505 .01472 L
.94639 .01472 L
.94783 .01472 L
.94864 .01472 L
.94938 .01472 L
.95075 .01472 L
.95144 .01472 L
.95219 .01472 L
.95356 .01472 L
Mistroke
.95484 .01472 L
.956 .01472 L
.95725 .01472 L
.95862 .01472 L
.95931 .01472 L
.96006 .01472 L
.9614 .01472 L
.96265 .01472 L
.96391 .01472 L
.9651 .01472 L
.96617 .01472 L
.96734 .01472 L
.96861 .01472 L
.96995 .01472 L
.9711 .01472 L
.97237 .01472 L
.97333 .01472 L
.97421 .01472 L
.97517 .01472 L
.97619 .01472 L
Mfstroke
gsave
.79762 .07715 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.64286 .1812 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.60119 .43093 -75 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
87.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
000]ooooo`05oa0@4?l0003o0000o`000?l@4100Joooool8o`000=[ooooo2?l0001aooooo`05oa0@
4?l0003o0000o`000?l@4100@oooool002oooooo00?o0000ooooooooool0Joooool00onHV9So0000
oiRHV003ooooo`03olc<c?l0003ooooo0=Wooooo00?oV9RHo`000?nHV9P00oooool00oo<c<co0000
ooooo`1booooo`03o`000?oooooooooo04?ooooo000_ooooo`03o`000?oooooooooo06cooooo00?o
c<c<o`000?nHV9P0goooool00oo<c<co0000oiRHV01gooooo`03o`000?oooooooooo04?ooooo000Y
ooooo`Wo0000KOooool00oo<c<co0000oiRHV03Oooooo`03olc<c?l0003oV9RH073ooooo2Ol00013
ooooo`007Oooool9o`0000?ooooo00?oIVIVodA4A?ooool00oooool00ol0003oooooooooo`1Ooooo
o`Wo00001_ooool00onHV9So0000ogMgM`3Oooooo`03oiRHV?l0003oMgMg06oooooo00?oIVIVodA4
A?ooool00oooool00ol0003oooooooooo`13ooooo`007Oooool9o`0000Cooooo00?o8B4QojVYZOoo
ool00_ooool00ol0003oooooooooo`1Oooooo`Wo00001oooool00oo<c<co0000oiRHV03Oooooo`03
olc<c?l0003oV9RH06oooooo00?o8B4QojVYZOooool00_ooool00ol0003oooooooooo`13ooooo`00
:_ooool00oo<c<co410@omgMg@02ooooo`03o`000?oooooooooo073ooooo00?oc<c<o`000?o<c<`0
goooool00oo<c<co0000olc<c01^ooooo`03olc<c?l@413ogMgM00;ooooo00?o0000ooooooooool0
@oooool002_ooooo00GoQhN7oc8b<_ooooooooooo`00001cooooo`03ohN7Qolb<S;ooooo0=oooooo
00?oQhN7oc8b<_ooool0K_ooool01On7QhOo<S8boooooooooooo000004Gooooo000/ooooo`04oc8b
<_n7QhOoooooo`0007Cooooo00?o0000ooooooooool0goooool00ol0003oooooooooo`1^ooooo`04
oc8b<_n7QhOoooooo`0004Gooooo000/ooooo`04omgMgOl@413ogMgMo`0006kooooo00?o0000ojVY
ZOooool00_ooool00ooMgMgo410@ooooo`3Jooooo`03o`000?nYZJWooooo00;ooooo00?ogMgMoa0@
4?ooool0Koooool01?oMgMgo410@omgMgOl00015ooooo`00;Oooool00on7QhOo<S8bo`00001^oooo
o`07ob4Q8Ol0003oV9RHoooooooMgMgo8B4QoiRHV03Kooooo`07ob4Q8Ol0003oV9RHoooooooMgMgo
8B4QoiRHV01aooooo`03ohN7Qolb<S;o000004Gooooo000^ooooo`03oc8b<_l@413ooooo06kooooo
00GoV9RHoa0@4?l0003o410@oiRHV03Mooooo`05oiRHV?l@413o0000oa0@4?nHV9P0Loooool00olb
<S;o410@ooooo`14ooooo`00oooooooooooood;ooooo003ooooooa3ooooo00?o0000ooooooooool0
ooooool_ooooo`00ooooool@ooooo`03o`000?oooooooooo0?oooooo;oooool00?oooooo4?ooool0
0ol0003oooooooooo`3oooooo`?ooooo00GoV9RHo`000?l0003o^[ZjoiRHV002o`000003odA4A?o^
k^kooooo02;ooooo003ooooooa3ooooo00?o0000ooooooooool0ooooool3ooooo`0:oa0@4?n7QhOo
oooooiRHV?l0003oEEEEoooooonHV9So8B4Qonk^kR;ooooo003ooooooa3ooooo00?o0000oooooooo
ool0ooooool3ooooo`06o`000?oooooooooooooooolQ8B7o^[Zj0_ooool00omEEEGoQhN7ooooo`0Q
ooooo`00ooooool@ooooo`03o`000?oooooooooo0?oooooo0oooool01_l0003ooooooooooooooooo
MgMgohN7Q`;ooooo00?o^[Zjoc8b<_ooool08Oooool00?oooooo4?ooool00ol0003oooooooooo`3o
ooooo`?ooooo00Ko8B4Qolc<c?ooooooooooojVYZOmEEED3ooooo`03o`000?oooooooooo023ooooo
000Koooooooo0000j_l0000@ooooo`06oeEEEOn7QhOooooooooooooMgMgo410@0oooool00ol0003o
ooooooooo`0Pooooo`009oooool6o`0001Oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Wooooo2_l00007ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03oooool5o`0000Kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`05ooooo`Go00004?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo
2Ol0000=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Eooooo`Ko00006oooool00onj^[[o8B4Qooooo`05ooooo`03onk^k_l0003ooooo027ooooo
000Wooooo`03o`000?oooooooooo00?ooooo4_l00005ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`_o00006Oooool00ol0003ooooooooo
o`0Dooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo0_l0
000Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool000001?l0000Fooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06oooool01?l0003ooooooooooooooolDo`0000Gooooo
00?o0000ooooooooool06_ooool00ol@413oZJVYooooo`04ooooo`03oiRHV?m4A4Cooooo027ooooo
000Wooooo`03o`000?oooooooooo01Gooooo2ol0001Aooooo`04o`000?ooooooooooooooo`?o0000
;oooool2o`0003cooooo00?o0000ooooooooool0>oooool2o`00037ooooo1Ol0001@ooooo`[o0000
6Oooool00ol0003oooooooooo`0Jooooo`03okZj^_m4A4Cooooo00Cooooo00?o<S8bokZj^_ooool0
8Oooool004[ooooo2?l0001@ooooo`?o0000;_ooool3o`0003Wooooo00?o0000ooooooooool0>?oo
ool3o`0002kooooo1Ol0001=ooooo`So0000Joooool005;ooooo1Ol0001>ooooo`?o0000;_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0:oooool4
o`0004gooooo1Ol0001cooooo`00Eoooool5o`0004cooooo0ol0000[ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Yooooo`?o0000C?ooool5o`00
07Sooooo001Looooo`Go0000B_ooool3o`0002Wooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo02Sooooo0_l0001:ooooo`Go0000OOooool0067ooooo
1Ol00018ooooo`;o0000:?ooool00ol0003oooooooooo`0dooooo`?o0000=?ooool00ol0003ooooo
ooooo`0Wooooo`;o0000B?ooool4o`0008;ooooo001Vooooo`Go0000AOooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Vooooo`;o0000AOooool5o`0008Kooooo001[ooooo`Go0000@Oooool2o`0002Oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Gooooo0_l00012
ooooo`Go0000Roooool0073ooooo1Ol0000nooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0?Oooool5o`00093ooooo001eooooo`?o0000??ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Sooooo`;o
0000?Oooool3o`0009Gooooo001hooooo`?o0000>_ooool2o`0002Gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
>_ooool3o`0009Sooooo001kooooo`?o0000>Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Sooooo0ol0002Kooooo`00O_ooool3o`0003Oooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0fooooo`?o0000W_ooool0087ooooo0ol0000eooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0;oooool3o`0002kooooo00?o0000ooooooooool08Oooool2o`00
03Oooooo0_l0002Qooooo`00Q?ooool3o`0003?ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0dooooo`?o0000Xoooool008Oooooo0ol0000aooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool0<_ooool3o`000:Kooooo002:ooooo`;o0000<?ooool2o`00027ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0<Oooool2o`000:Wooooo002<ooooo`;o0000<?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo02oooooo0ol0002[ooooo`00S_ooool3o`0002kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0^ooooo`;o0000[_ooool0097ooooo0_l0000]ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool3o`000;3ooooo002Cooooo`;o0000
;?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02_ooooo0_l0002cooooo`00UOoo
ool2o`0002_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Zooooo`?o0000:ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Wooooo0ol0002eooooo`00Uoooool3
o`0002Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Wooooo`;o000000?o<S8b
o`000?l000001ol000000olb<S;oooooooooo`02ooooo`03onk^k_mEEEGo000000;o000000?o<S8b
ogMgMooMgMd04?ooool00ol@413o0000o`000003o`000003oa0@4?oooooooooo08Sooooo002Joooo
o`;o00009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02Gooooo0ol00002oooo
o`03oiRHV?lb<S;ooooo00Kooooo00?oA4A4oiRHV?ooool00oooool02?m4A4CoEEEEonk^k_oooooo
c<c<ofIVI_lQ8B7o00004oooool00ol0003oooooooooo`2;ooooo`00W?ooool2o`0002Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Tooooo`;o00001_ooool00ol@413ogMgMoooo
o`04ooooo`03omgMgOl@413ooooo00Cooooo00?o0000onk^k_ooool02?ooool8o`0000Sooooo00?o
0000ooooooooool0Roooool009kooooo0_l0000Tooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool08oooool2o`0000Sooooo00?oV9RHoeEEEOooool01?ooool00omEEEGoQhN7ooooo`04
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Roooool00:3ooooo0_l0000Soooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08Oooool2o`0000[ooooo00?ok^k^oa0@
4?o^k^h00oooool00oo^k^ko410@onk^kP05ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0Roooool00:;ooooo0_l0000Rooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool08?ooool2o`0000gooooo00?oMgMgohN7Qoooool00_ooool00on7QhOoIVIVooooo`05ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0Roooool00:Cooooo0_l0000Qooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool07_ooool3o`0000oooooo00?ogMgMoa0@4?ooool0
0_ooool00ol@413ogMgMooooo`05ooooo`03o`000?oooooooooo00Sooooo2?l00008ooooo`03o`00
0?oooooooooo08_ooooo002Vooooo`;o00007oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo02Sooooo0ol0000Yooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07Ooo
ool2o`0001?ooooo00GoEEEEoiRHV?ooooooZJVYoeEEE@05ooooo`03oa0@4?l0003o000000Co0000
00?o410@ooooooooool04oooool00ol0003oooooooooo`2;ooooo`00Z?ooool2o`0001kooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`;o00005Oooool01Oo<c<co<S8boooo
oolb<S;o^[Zj00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2;ooooo`00Z_oo
ool2o`0001gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`;o00006?oo
ool00olb<S;oV9RHoc8b<P08ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Rooo
ool00:cooooo0_l0000Kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool2
o`0001[ooooo00?o^[Zjo`000?nHV9P02?ooool00ol@413oooooooooo`0Eooooo`04o`000?l@413o
EEEEo`0008gooooo002^ooooo`;o00006_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Sooooo00?o410@o`000?l000000ol000000ol@413oooooooooo`06ooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`;o00007Oooool0
0olb<S;oooooooooo`0Oooooo`04omgMgOn7QhOoA4A4o`0008gooooo002`ooooo`;o00006Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool2
o`000=;ooooo002booooo`;o00005oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool05Oooool2o`000=Cooooo002dooooo`;o00005_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`3Dooooo`00]_ooool2o`0001Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Wooooo1?l0000Uooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04oooool2o`000=Oooooo002hooooo`;o00004oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool2o`000=Wooooo002j
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo013ooooo0_l0003Kooooo`00^oooool2o`00017ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo0_l0003Moooo
o`00_Oooool2o`00013ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0gOooool00;oooooo0_l0000>ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`;o0000
h?ooool00<7ooooo0_l0000=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_oo
ool01?l0003o410@oeEEEOl0000;ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0<ooooo`;o0000h_ooool00<?ooooo0_l0000<ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool05_ooool01?oMgMgoQhN7odA4A?l0000;ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0:ooooo`;o0000
i?ooool00<Gooooo0_l0000:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09?oo
ool3o`0002Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`;o0000i_oo
ool00<Oooooo0_l00009ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool2
o`000>Sooooo0039ooooo`;o00001oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Kooooo0_l0003Zooooo`00boooool3o`0000Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`?o0000k?ooool00<kooooo0_l00004ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00_ooool2o`000>oooooo003@ooooo`;o00000_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Aooooo`04o`000?ooooooooooooooo`;o0000lOooool00=;ooooo0_l000000ooooooo0000oooo
o`0Booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Aooooo`04o`000?oooooo0000o`000??ooooo003Dooooo`;o00004oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool3o`000?Gooooo003F
ooooo`;o00004_ooool00ol0003oooooooooo`0Rooooo`?o00008_ooool00ol0003oooooooooo`0@
ooooo`;o0000moooool00=Kooooo00Co0000ooooool0003o00004?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool4o`000?Sooooo003Goooo
o`03o`000?oooooooooo00;o00003_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02oooool2o`0000?ooooo00?o0000ooooooooool0m_ooool00=Oo
oooo00?o0000ooooooooool00_ooool2o`0000cooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo0_l00004ooooo`03o`000?oooooooooo0?Oo
oooo003Hooooo`03o`000?oooooooooo00?ooooo0_l0000:ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`?o00001_ooool00ol0003ooooo
ooooo`3gooooo`00f?ooool00ol0003oooooooooo`05ooooo`?o00002?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o
0000ooooooooool0n?ooool00=Wooooo00?o0000ooooooooool01oooool3o`0000Gooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo0_l0000:
ooooo`03o`000?oooooooooo0?Sooooo003Iooooo`03o`000?oooooooooo00[ooooo0ol00002oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03o`00
00_ooooo00?o0000ooooooooool0nOooool00=[ooooo00?o0000ooooooooool03?ooool3o`0002?o
oooo00?o0000ooooooooool08Oooool3o`0000kooooo00?o0000ooooooooool0nOooool00=[ooooo
00?o0000ooooooooool03_ooool3o`00027ooooo0ol0000Oooooo`?o00003oooool00ol0003ooooo
ooooo`3jooooo`00foooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000;o00007_oo
ool00ol0003oooooooooo`0Looooo`?o000000?oooooo`000?ooool03oooool00ol0003ooooooooo
o`3jooooo`00foooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo0_l0000L
ooooo`03o`000?oooooooooo01Sooooo1?l00004ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0noooool00=cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`Co00006?ooool00ol0003oooooooooo`0Eooooo`?o00002?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0?_ooooo003Looooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02?ooool5o`0001?ooooo00?o0000ooooooooool04_ooool3o`0000_ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3looooo`00gOooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo1?l0000?ooooo`03o`000?oooooooooo00[ooooo2?l0000>ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0o?ooool00=gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0@ooooo`co00000oooool01?l0003oooooooooooooool9o`0001Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3mooooo`00g_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01cooooo1ol0000Nooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0oOooool00=kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0O
ooooo`?o00007oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?kooooo003Ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0o_ooool00>3ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`3nooooo`00h?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03oc8b
<_l0003o000000Oo000000?o<S8booooooooool00_ooool00oo^k^koEEEEo`000002o`000003oc8b
<_mgMgOogMgM00oooooo2?l0003Eooooo`00hOooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo2?l00008ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02Ooo
ool00onHV9So0000ooooo`06ooooo`03odA4A?nHV9Sooooo00?ooooo00SoA4A4oeEEEOo^k^kooooo
olc<c?mVIVKo8B4Qo`0000oooooo00?oV9RHo`000?nHV9P00oooool00oo<c<co0000ooooo`3Doooo
o`00hOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?oV9RHo`000?nH
V9P00oooool00oo<c<co0000ooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02Oooool00ol0003o410@omgMg@05ooooo`03omgMgOl@413ooooo00Cooooo00?o0000onk^k_oo
ool02?ooool8o`0000Gooooo00?oc<c<o`000?nHV9P0fOooool00>;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03olc<c?l0003oV9RH00cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0:ooooo`03o`000?nHV9SoEEEE00Gooooo00?oEEEEohN7Qoooool0
1?ooool00ol0003oooooooooo`0Fooooo`03olc<c?l0003oV9RH0=Sooooo003Rooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04?ooool00oo<c<co0000oiRHV00;ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool02Oooool01Ol0003oooooonk^k_l@413ok^k^00?ooooo
00?ok^k^oa0@4?o^k^h01Oooool00ol0003oooooooooo`0Gooooo`03oiRHV?l0003oMgMg0=Oooooo
003Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00onHV9So0000ogMg
M`0:ooooo`Co00007Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooogMgMon7QhL0
0oooool00on7QhOoIVIVooooo`05ooooo`03o`000?oooooooooo01Sooooo00?oc<c<o`000?nHV9P0
e_ooool00>?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03olc<c?l0
003oV9RH00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`06o`000?oo
oooooooooooooooMgMgo410@0oooool00ol@413ogMgMooooo`05ooooo`03o`000?oooooooooo00So
oooo2?l00009ooooo`03olc<c?l0003oc<c<0=Gooooo003Tooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool04_ooool00oo<c<co0000olc<c008ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`05oeEEEOnHV9SoooooojVYZOmE
EED01Oooool00ol@413o0000o`000004o`000003oa0@4?oooooooooo01Gooooo00?oQhN7oc8b<_oo
ool0e?ooool00>Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Cooooo`03ohN7
Qolb<S;ooooo00Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00Goc<c<oc8b<_oooooo<S8bokZj^P07ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0doooool00>Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o<S8boiRHV?lb<S802?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?nYZJWooooo00;ooooo00?ogMgMoa0@4?ooool0e?ooool00>Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?nYZJWooooo00;ooooo00?o
gMgMoa0@4?ooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00onj^[[o0000oiRHV008ooooo`03oa0@4?oooooooooo01Gooooo00Oo
8B4Qo`000?nHV9SoooooomgMgOlQ8B7oV9RH0=Gooooo003Vooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool01olQ8B7o0000oiRHV?oooooogMgMob4Q8OnHV9P02?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00olb
<S;oooooooooo`0Pooooo`05oiRHV?l@413o0000oa0@4?nHV9P0e_ooool00>Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0>ooooo`05oiRHV?l@413o0000oa0@4?nHV9P02Oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool6
ooooo`00ioooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo0ol0000Moooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool6ooooo`00ioooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo1oooool00>Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3oooooo`Oooooo003Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0ooooool8ooooo`00jOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo2?ooool00>Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
o`Wooooo003Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool9ooooo`00
j_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo2_ooool00>_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`?o00007?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo2_ooool00>_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`_ooooo003/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0ooooool;ooooo`00k?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo3?ooool00>gooooo00Go0000ooooooooooooooooo`00000Mooooo`03o`000?oooooooooo01_o
oooo00Go0000ooooooooooooooooo`00003oooooo`oooooo003]ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`05o`000?oooooooooooooo
ool00000ooooool?ooooo`00k_ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000oooo
ooooool06oooool01?l0003oooooooooool0003ooooooa3ooooo003^ooooo`05o`000?oooooooooo
ooooool000007?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`000?oooooo4?oo
ool00>oooooo00Co0000oooooooooooo00007?ooool3o`0001_ooooo00?o0000ooooool00000oooo
oolAooooo`00koooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo01[ooooo00Co
0000oooooooooooo0000oooooolAooooo`00l?ooool00ol0003oooooo`00000Looooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooool00000oooooolBooooo`00l?ooool00ol0003oooooo`00000L
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000oooooolBooooo`00lOooool2o`00
01cooooo00?o0000ooooooooool06_ooool2o`000?oooooo4oooool00?7ooooo00?o0000ooooool0
00006oooool00ol0003oooooooooo`0Jooooo`;o0000oooooolCooooo`00l_ooool2o`0001_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooooa;ooooo003booooo`;o00006ooo
ool00ol0003oooooooooo`0Iooooo`;o0000oooooolDooooo`00loooool00ol0003oooooooooo`0I
ooooo`?o00006Oooool00ol0003oooooooooo`3ooooooa?ooooo003cooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06?ooool2o`000?oooooo5Oooool00??ooooo0_l0000Jooooo`03
o`000?oooooooooo01Sooooo0_l0003ooooooaGooooo003cooooo`;o00006_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooo00000?oooooo5Oooool00??ooooo00?o0000ooooool000002_oo
ool01_o<c<co8B4Qo`000?l0003oA4A4olc<c0Wooooo00?o0000ooooooooool05oooool00ol0003o
ooooo`00003ooooooaGooooo003dooooo`03o`000?oooooo000000Sooooo00?o^[Zjoa0@4?nYZJT0
0_ooool00onYZJWo0000okZj^P08ooooo`03o`000?oooooooooo01Kooooo00Co0000oooooooooooo
0000oooooolEooooo`00m?ooool00ol0003oooooo`000008ooooo`03o`000?nj^[[ooooo00?ooooo
00?o^[Zjob4Q8Oooool01oooool00ol0003oooooooooo`0Fooooo`04o`000?ooooooooooo`000?oo
oooo5Oooool00?Cooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo0000oooooolFooooo`00m?ooool01?l0003o
ooooooooool0000=ooooo`03omgMgOl@413ooooo00Oooooo1?l0000Dooooo`04o`000?oooooooooo
o`000?oooooo5_ooool00?Cooooo00Go0000ooooooooooooooooo`00000;ooooo`03omgMgOlQ8B7o
^[Zj00Sooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo00000?oooooo5_oo
ool00?Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`04oc8b<_l0003o
0000ojVYZ@Wooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo00000?oooooo
5_ooool00?Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03olc<c?lb
<S;oV9RH00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo5?ooool00?Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03onk^k_l0003ooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo5?ooool00?Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03omgMgOlQ8B7ooooo00Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo5?ooool00?Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`07oa0@4?n7QhOok^k^oooooooMgMgo<S8bokZj^P08
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
oooooaCooooo003eooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooooooolc<c?mE
EED2o`000003oa0@4?nHV9Sooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo5Oooool00?Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0@ooooo`?o00004?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo5Oooool00?Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
oaGooooo003eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolEooooo`00
mOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo5Oooool00?Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooooaGooooo003fooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0oooooolEooooo`00m_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0?oooooo5Oooool00?Kooooo00?o0000ooooooooool02?ooool2o`0000co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oo
oooo5Oooool00?Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooaKooooo
003fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3o`0000Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`3ooooooaKooooo003fooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0oooooolFooooo`00m_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0?oooooo5_ooool00?Oooooo00?o0000ooooooooool03Oooool2o`0000Ko
oooo00?o0000ooooooooool01?ooool2o`00013ooooo00?o0000ooooooooool0oooooolFooooo`00
moooool00ol0003oooooooooo`0?ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`;o0000
4_ooool00ol0003oooooooooo`3ooooooaKooooo003gooooo`03o`000?oooooooooo017ooooo2Ol0
000Dooooo`03o`000?oooooooooo0?oooooo5_ooool00?Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo5_ooool00?Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo5oooool00?Oo
oooo00?o0000ooooooooool05Oooool3o`0001Gooooo00?o0000ooooooooool0oooooolGooooo`00
moooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
oooooolGooooo`00moooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0oooooolGooooo`00n?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0oooooolGooooo`00n?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolGooooo`00n?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolGooooo`00
n?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
oooooolGooooo`00n?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0oooooolGooooo`00n?ooool00ol0003oooooooooo`0Dooooo`?o00005?ooool0
0ol0003oooooooooo`3ooooooaSooooo003hooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`3ooooooaSooooo003hooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaSooooo003iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooooaSooooo
003iooooo`03o`000?oooooooooo00Oooooo00Go410@o`000?l0003o0000oa0@4007ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0oooooolHooooo`00nOooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`3ooooooaSooooo003iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo6?ooool00?Wooooo00?o0000oooo
ooooool00oooool9o`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3ooooo
oaSooooo003iooooo`03o`000?oooooooooo00?ooooo00?oIVIVodA4A?ooool00oooool00ol0003o
ooooooooo`07ooooo`Co00004_ooool00ol0003oooooooooo`3ooooooaWooooo003iooooo`03o`00
0?oooooooooo00Cooooo00?o8B4QojVYZOooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0oooooolIooooo`00nOooool00ol0003ooooooooo
o`04ooooo`03olc<c?l@413ogMgM00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo0?oooooo6Oooool00?[ooooo00?o0000ooooooooool01?ooool0
1On7QhOo<S8boooooooooooo000000Wooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`3ooooooaWooooo003jooooo`03o`000?oooooooooo00Gooooo00Co<S8bohN7Qooooooo00002Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo6Oooool00?[ooooo00?o0000
ooooooooool01Oooool01?oMgMgo410@omgMgOl00009ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0oooooolIooooo`00n_ooool00ol0003oooooooooo`06ooooo`03ohN7Qolb<S;o
000000Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3ooooooaWooooo003joooo
o`03o`000?oooooooooo00Oooooo00?o<S8boa0@4?ooool02?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo0?oooooo6Oooool00?[ooooo00?o0000ooooooooool04_ooool3o`0001?o
oooo00?o0000ooooooooool0oooooolIooooo`00n_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0oooooolJooooo`00n_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0oooooolJooooo`00noooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0oooooolJ
ooooo`00noooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0oooooolJooooo`00noooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0oooooolJooooo`00noooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0oooooolJooooo`00noooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0oooooolJooooo`00noooool0
0ol0003oooooooooo`0Aooooo`?o00004_ooool00ol0003oooooooooo`3ooooooa[ooooo003koooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3ooooo
oa_ooooo003kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`3ooooooa_ooooo003looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`3ooooooa_ooooo003looooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`3ooooooa_ooooo003looooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3ooooooa_ooooo003loooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3ooooo
oa_ooooo003looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`3ooooooa_ooooo003looooo`03o`000?oooooooooo013ooooo0ol0000Aooooo`03o`00
0?oooooooooo0?oooooo6oooool00?cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo0?oooooo6oooool00?cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool00?gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool00?go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oo
oooo7?ooool00?gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo0?oooooo7?ooool00?gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool00?gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo7?ooool00?gooooo00?o0000oooo
ooooool03oooool3o`00013ooooo00?o0000ooooooooool0oooooolLooooo`00oOooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oooooolLooooo`00
oOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
oooooolMooooo`00o_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0oooooolMooooo`00o_ooool00ol0003oA4A4oa0@4002o`000003oa0@4?mgMgOo
k^k^00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03oc8b<_l0003o
000000Oo000000?o<S8booooooooool00_ooool00oo^k^koEEEEo`000002o`000003oc8b<_mgMgOo
gMgM01?ooooo00Go410@o`000?l0003o0000oa0@403Yooooo`00o_ooool02Ol0003o<S8boiRHV?oM
gMgoooooomgMgOmgMgOo410@onk^kP08ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01?ooool00onHV9So<S8booooo`06ooooo`03odA4A?nHV9Sooooo00?ooooo00SoA4A4oeEEEOo^
k^koooooolc<c?mVIVKo8B4Qo`0001Gooooo00?o0000ooooooooool0jOooool00?kooooo00?o0000
ooooooooool01?ooool00on7QhOoEEEEooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool01Oooool00ol@413ogMgMooooo`04ooooo`03omgMgOl@413ooooo00Cooooo00?o0000
onk^k_ooool02?ooool8o`0000[ooooo00?o0000ooooooooool0jOooool00?kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00onHV9SoEEEEooooo`04ooooo`03oeEEEOn7QhOooooo00Cooooo00?o0000oooo
ooooool05?ooool9o`000>Wooooo003nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool4o`0000kooooo00?o0000ooooooooool01Oooool00oo^k^ko410@onk^kP03ooooo`03
onk^k_l@413ok^k^00Gooooo00?o0000ooooooooool05?ooool00omVIVKoA4A4ooooo`03ooooo`03
o`000?oooooooooo0>Wooooo003nooooo`03o`000?oooooooooo00Cooooo00?oQhN7odA4A?ooool0
1oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?oMgMgohN7Qoooool0
0_ooool00on7QhOoIVIVooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o8B4QojVYZOooool0
0_ooool00ol0003oooooooooo`3Yooooo`00o_ooool2o`000007oeEEEOo<c<coooooonk^k_n7QhOo
0000olc<c008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ooMgMgo
410@ooooo`02ooooo`03oa0@4?oMgMgooooo00Gooooo00?o0000ooooooooool02?ooool8o`0000Go
oooo00?oc<c<oa0@4?oMgMd00_ooool00ol0003oooooooooo`3Yooooo`00ooooool00ol0003o<S8b
o`000002o`000003oeEEEOoMgMgooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`08ooooo`05oeEEEOnHV9SoooooojVYZOmEEED01Oooool00ol@413o0000o`000004o`000003
oa0@4?oooooooooo017ooooo00GoQhN7oc8b<_ooooooooooo`00003[ooooo`00ooooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool01Oo<c<co
<S8boooooolb<S;o^[Zj00Oooooo00?o0000ooooooooool05oooool01?lb<S;oQhN7ooooool0003[
ooooo`00ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00olb<S;oV9RHoc8b<P08ooooo`03o`000?oooooooooo01Oooooo00CogMgMoa0@
4?oMgMgo0000joooool00?oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Wooooo00?o^[Zjo`000?nHV9P02?ooool00ol@413oooooooooo`0Hoooo
o`03ohN7Qolb<S;o00000>_ooooo003oooooo`Oo00002Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00[ooooo00?o<S8booooooooool08oooool00olb<S;o410@ooooo`3Zooooo`00
ooooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
oooooolNooooo`00ooooool00ol0003oooooooooo`0=ooooo`?o00003_ooool00ol0003ooooooooo
o`3ooooooakooooo003oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`3ooooooakooooo003oooooo`7ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo7oooool00?oooooo0Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0oooooolOooooo`00
ooooool1ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`3ooooooaoooooo003oooooo`7ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo0?oooooo7oooool00?oooooo0Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0oooooolOooooo`00ooooool1oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3ooooo
oaoooooo003oooooo`7ooooo00?o0000ooooooooool03?ooool3o`0000gooooo00?o0000oooooooo
ool0oooooolOooooo`00ooooool2ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`3oooooob3ooooo003oooooo`;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo8?ooool00?oooooo0_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooooolP
ooooo`00ooooool2ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3oooooob3ooooo003oooooo`;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo8?ooool00?oooooo0_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooooolPooooo`00oooo
ool2ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`3oooooob3ooooo003oooooo`;ooooo00?o0000ooooooooool02oooool3o`0000cooooo00?o0000
ooooooooool0oooooolPooooo`00ooooool3ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3oooooob7ooooo003oooooo`?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo8Oooool00?oooooo
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
oooooolQooooo`00ooooool3ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`3oooooob7ooooo003oooooo`?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo8Oooool00?oooooo0oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooolQoooo
o`00ooooool3ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`3oooooob7ooooo003oooooo`?ooooo00?o0000ooooooooool02_ooool3o`0000_ooooo
00?o0000ooooooooool0oooooolQooooo`00ooooool4ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3oooooob;ooooo003oooooo`Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo8_ooool0
0?oooooo1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0oooooolRooooo`00ooooool1ooooo`06onk^k_mEEEGo0000o`000?lQ8B7oZJVY2Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo8_ooool00?oooooo00Sok^k^oc8b
<_n7QhOok^k^o`000?nHV9So0000okZj^PSooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`3oooooob;ooooo003oooooo`08ogMgMon7QhOoooooooooool0003ooooooiRHV?m4A4@8oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolRooooo`00ooooool01OlQ8B7o
k^k^oooooooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0?oooooo8_ooool00?oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000008ooooo`Co00002?ooool00ol0003oooooooooo`3oooooob?ooooo003oooooo`03o`00
0?nHV9Sooooo00;ooooo00?o0000oiRHV?m4A4@02?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo0?oooooo8oooool00?oooooo00?o0000oa0@4?nHV9P00_ooool00ol0003o410@olc<
c008ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooolSooooo`00ooooool0
0om4A4CoV9RHodA4A003o`000003olc<c?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`3oooooob?ooooo003oooooo`03oiRHV?mEEEGooooo00;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo8oooool00?oo
oooo0Oooool01Olb<S;oV9RHoooooooooooo000000[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`3oooooob?ooooo003oooooo`7ooooo00Gok^k^ob4Q8OmEEEGoc<c<o`00000:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolTooooo`00ooooool3ooooo`05
oiRHV?lb<S;o0000o`000?lQ8B402?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
0?oooooo9?ooool00?oooooo1_ooool00ol0003oooooooooo`07ooooo`?o00002?ooool00ol0003o
ooooooooo`3oooooobCooooo003oooooo`Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0?oooooo9?ooool00?oooooo1_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolTooooo`00ooooool6
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooobGooooo003oooooo`Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo9Oooool00?oooooo1_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolUooooo`00ooooool6ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooobGooooo
003oooooo`Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo9Oooool00?oooooo1oooool00ol0003oooooooooo`06ooooo`?o00001_ooool0
0ol0003oooooooooo`3oooooobKooooo003oooooo`Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo9_ooool00?oooooo1oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolVooooo`00
ooooool7ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3oooooobKooooo003oooooo`Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0?oooooo9_ooool00?oooooo1oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolVooooo`00ooooool8oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
obOooooo003oooooo`Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo9oooool00?oooooo2?ooool00ol0003oooooooooo`05ooooo`?o0000
1Oooool00ol0003oooooooooo`3oooooobOooooo003oooooo`Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo9oooool00?oooooo2Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolW
ooooo`00ooooool9ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooobSooooo003oooooo`Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo:?ooool00?oooooo2_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolXooooo`00oooo
ool:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooobSooooo003oooooo`[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo:?ooool00?oooooo2_ooool00ol0003oooooooooo`03oooo
o`?o00000oooool00ol0003oooooooooo`3oooooobWooooo003oooooo`_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:Oooool00?oooooo
2oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
oooooolYooooo`00ooooool;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3oooooobWooooo003oooooo`;ooooo00?o8B4QohN7Qoooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolZ
ooooo`00ooooool2ooooo`03ojVYZOlb<S;ooooo00Oooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo0?oooooo:_ooool00?oooooo0oooool00ol@413ogMgMooooo`06oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`3oooooob[ooooo003ooooo
o`?ooooo00?oV9RHoeEEEOooool01_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0ooooool[ooooo`00ooooool3ooooo`03onk^k_l0003ok^k^00Kooooo00Co0000oooo
oooooooooooo1Ol0003oooooobgooooo003oooooo`Cooooo0_mgMgL7ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00ooooool4ooooo`03omgMgOl@413ooooo
00Kooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`3oooooobcooooo003ooooo
o`Gooooo00?oEEEEoiRHV?ooool01_ooool3o`000003ooooool0003ooooo0?oooooo;_ooool00?oo
oooo1Oooool00onj^[[o<S8booooo`07ooooo`?o0000ooooool`ooooo`00ooooool6ooooo`03oc8b
<_o<c<cooooo00Oooooo00?o0000ooooooooool0ooooool_ooooo`00ooooool00ol@413ooooooooo
o`03ooooo`03oiRHV?mEEEGooooo00Oooooo00?o0000ooooooooool0ooooool_ooooo`00ooooool8
o`0000Sooooo00?o0000ooooooooool0ooooool_ooooo`00ooooool@ooooo`03o`000?oooooooooo
0?oooooo;oooool00?oooooo4?ooool3o`000?oooooo;oooool00?oooooo4?ooool00ol0003ooooo
ooooo`3ooooooboooooo003ooooooa3ooooo00?o0000ooooooooool0ooooool_ooooo`00oooooooo
oooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo
003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooo
oooo@_ooool00?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool0
0?oooooooooooom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?[ooooo00Ko
8B4Qo`000?l0003o0000odA4A?nYZJT;ooooo`03ojVYZOlb<S;ooooo00oooooo00?o<S8bojVYZOoo
ool0oooooolQooooo`00o_ooool00onj^[[o8B4QohN7Q`0:ooooo`03oa0@4?oMgMgooooo00oooooo
00?ogMgMoa0@4?ooool0oooooolQooooo`00ooooool00onj^[[o410@ooooo`08ooooo`03oiRHV?mE
EEGooooo017ooooo00?oEEEEoiRHV?ooool0oooooolPooooo`00ooooool1ooooo`03o`000?oooooo
oooo00Oooooo00?o410@omgMgOooool04Oooool00ooMgMgo410@ooooo`3oooooob3ooooo003joooo
o`07okZj^_m4A4Co0000o`000?mgMgOok^k^o`000008ooooo`03ojVYZOmEEEGooooo00Cooooo00Go
V9RHo`000?l0003o^[ZjoiRHV002o`000003odA4A?o^k^kooooo00Gooooo00?o<S8bojVYZOooool0
oooooolOooooo`00nOooool01_mgMgOoIVIVomgMgOoooooogMgMofIVIP;o00002?ooool00omVIVKo
ZJVYooooo`04ooooo`0:oa0@4?n7QhOooooooiRHV?l0003oEEEEoooooonHV9So8B4Qonk^kPGooooo
00?oV9RHofIVI_ooool0oooooolOooooo`00n?ooool00onj^[[oIVIVooooo`04ooooo`03ofIVI_l0
003ooooo00Oooooo00?o<S8bonk^k_ooool01?ooool01_l0003ooooooooooooooooo8B4QokZj^P;o
oooo00?oEEEEohN7Qoooool01?ooool00oo<c<co<S8booooo`3ooooooaoooooo003hooooo`03odA4
A?oMgMgooooo00Cooooo00?ogMgMo`000?ooool01oooool00ol0003oooooooooo`04ooooo`06o`00
0?oooooooooooooooomgMgOoQhN70_ooool00onj^[[o<S8booooo`05ooooo`03o`000?oooooooooo
0?oooooo7_ooool00?Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00Ko8B4Qolc<c?ooooooooooojVYZOmEEED3ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolNooooo`00n?ooool00om4A4CogMgMooooo`04oooo
o`03omgMgOl0003ooooo00Oooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7oooooooooooo
gMgMoa0@40?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooakooooo003h
ooooo`03okZj^_mVIVKooooo00Cooooo00?oIVIVo`000?ooool01oooool00olb<S;ogMgMooooo`04
ooooo`03okZj^_lQ8B7ooooo00Gooooo00?ok^k^o`000?ooool01?ooool00oo<c<co<S8booooo`3o
oooooaoooooo003iooooo`06oeEEEOmVIVKogMgMoooooooMgMgoIVIV0_l00008ooooo`03ofIVI_nH
V9Sooooo00Gooooo00?o410@ojVYZOooool01?ooool00onHV9SoA4A4ooooo`04ooooo`03ohN7QomE
EEGooooo0?oooooo7oooool00?[ooooo00SoMgMgoa0@4?l0003o410@ohN7Qonj^[[o0000oa0@40Oo
oooo00?oZJVYob4Q8Oooool01Oooool00onj^[[oA4A4ooooo`04ooooo`03oc8b<_nj^[[ooooo00Co
oooo00?o8B4QojVYZOooool0oooooolOooooo`00ooooool;ooooo`03oa0@4?nj^[[ooooo017ooooo
00?o^[Zjoa0@4?ooool0oooooolPooooo`00ooooool;ooooo`03oiRHV?m4A4Cooooo017ooooo00?o
<S8boiRHV?ooool0oooooolPooooo`00nOooool01OlQ8B7oZJVYoooooonj^[[oA4A400;o000000?o
^[Zjooooooooool02?ooool00ol@413oc<c<ooooo`0?ooooo`03okZj^_l@413ooooo0?oooooo8Ooo
ool00?Wooooo00Soc<c<oa0@4?l0003oA4A4okZj^_ooooooZJVYoc8b<P[ooooo00?oZJVYoc8b<_oo
ool03oooool00olb<S;oZJVYooooo`3oooooob7ooooo003ooooooooooooo@_ooool00?oooooooooo
oom2ooooo`00oooooooooooood;ooooo003ooooooooooooo@_ooool00?oooooooooooom2ooooo`00
\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-4.67246, -0.594597, \
0.0344089, 0.0493396}}],

Cell[TextData[{
  "Fig. 2.8 The Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  "."
}], "Caption",
  CellTags->"Fig. 2.8"],

Cell[TextData[{
  "\tAn important application of the uncertainty principle is related to the \
data bit function of width \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", plotted in Cell ",
  ButtonBox["2.43",
    ButtonData:>"Cell 2.43",
    ButtonStyle->"Hyperlink"],
  ". We saw there that when a finite bandwidth \[CapitalDelta]\[Omega] cuts \
off the Fourier spectrum of a signal pulse, the width of the pulse in time, \
\[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", grows larger (see Fig. ",
  ButtonBox["2.6",
    ButtonData:>"Fig. 2.6",
    ButtonStyle->"Hyperlink"],
  "). We now see that this is a consequence of the uncertainty principle. \
This principle says that as the bandwidth \[CapitalDelta]\[Omega] of a medium \
decreases, the signal pulses must become broader in time according to Eq. ",
  ButtonBox["(2.3.24)",
    ButtonData:>"(2.3.24)",
    ButtonStyle->"Hyperlink"],
  ",  and hence the distance in time between pulses must be increased in \
order for the pulses to be distinguishable. "
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  "\tIn turn, this implies that the maximum rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_max\)]],
  " at which signals can be propagated is proportional to the bandwidth of \
the medium: see Eq. ",
  ButtonBox["(2.3.8)",
    ButtonData:>"(2.3.1)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.4 The Dirac \[Delta]-Function", "Subsubtitle",
  CellTags->{"i:46", "c:27"}],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CellTags->"c:28"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(t)\), "=", 
          RowBox[{"f", "(", 
            RowBox[{"t", "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], ")"}]}], TraditionalForm]]],
  " plotted in Fig. ",
  ButtonBox["2.7",
    ButtonData:>"Fig. 2.7",
    ButtonStyle->"Hyperlink"],
  " increases in width as ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " increases . The area under the function also clearly increases with \
increasing ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".  One might expect that the area under the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " should ",
  StyleBox["decrease",
    FontSlant->"Italic"],
  " as the transform becomes narrower: see Fig. ",
  ButtonBox["2.8",
    ButtonData:>"Fig. 2.8",
    ButtonStyle->"Hyperlink"],
  ". However, we will now show that the area under  ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&~\)(\[Omega])\)]],
  " is actually ",
  StyleBox["independent",
    FontSlant->"Italic"],
  " of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ". \n\tThis surprising result follows from the following property of the \
inverse transform:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g(
          t = 0) = \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    g\&~\)(\[Omega])\) \
\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ 0\)\) \[DifferentialD]\
\[Omega]/2\ \[Pi] = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( 
                    g\&~\)(\[Omega])\) \[DifferentialD]\[Omega]/
                2\ \[Pi]\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.25)"],

Cell[TextData[{
  "The area under ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&~\)(\[Omega])\)]],
  " equals ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\ \(g(0)\) = 2  \[Pi]\ \(f(0)\)\)]],
  ", independent of of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ".\n\tWhy is this important?  Consider the limit as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "\[Rule]", " ", "\[Infinity]"}], 
        TraditionalForm]]],
  ".  In this limit, the width of ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&~\)(\[Omega])\)]],
  " vanishes, but the area under the function remains constant, equaling ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\ \(f(0)\)\)]],
  ". One can see from Fig. ",
  ButtonBox["2.8",
    ButtonData:>"Fig. 2.8",
    ButtonStyle->"Hyperlink"],
  " that this can happen because the height",
  StyleBox[" ",
    FontSlant->"Italic"],
  "of ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\&~\)(\[Omega])\)]],
  " approaches infinity as the width vanishes. "
}], "Text"],

Cell[TextData[{
  "\tThis strange curve is called a ",
  ButtonBox["Dirac",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Dirac.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  "-function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](\[Omega])\)]],
  ". To be precise, "
}], "Text",
  CellTags->"i:112"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Delta](\[Omega])\), " ", "=", " ", 
          RowBox[{
            SubscriptBox["lim", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "\[Rule]", " ", 
                "\[Infinity]"}]], \(\(\(g\&~\)(\[Omega])\)\ /\((2\ \[Pi]\ \(g(
                    0)\))\)\)}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.26)"],

Cell["\<\
This function is normalized so as to have unit area under the \
curve. However, since its width is vanishingly small,  the function also has \
the properties that\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Delta](\[Omega])\), "=", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->16], 
            StyleBox[GridBox[{
                  {\(0, \ \ \[Omega] \[NotEqual] 0, \)},
                  {\(\[Infinity], \ \ \[Omega] = \ 0. \)}
                  }],
              ShowAutoStyles->True]}],
          (#&)], " "}], TraditionalForm]]]], "NE3",
  CellTags->"(2.3.27)"],

Cell[TextData[{
  " Therefore, the area integral need not involve the entire real line, \
because the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  "-function is zero everywhere except at the origin. The integral over ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](\[Omega])\)]],
  " equals unity for ",
  StyleBox["any",
    FontSlant->"Italic"],
  " range of integration that includes the origin, no matter how small: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(\[Epsilon] \[Rule] \ 0\)\[Integral]\_\(-\
\[Epsilon]\)\%\[Epsilon]\( \[Delta](\[Omega])\) \[DifferentialD]\[Omega] = 
        1\)]],
  "."
}], "NE3",
  CellTags->"(2.3.28)"],

Cell["\<\
\t Dirac \[Delta]-functions often appear in the physical sciences. \
These functions have many useful properties, which are detailed in the \
following sections.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Integral of a \[Delta]-Function", "Section",
  CellTags->"c:29"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.3.27)",
    ButtonData:>"(2.3.27)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.28)",
    ButtonData:>"(2.3.28)",
    ButtonStyle->"Hyperlink"],
  " lead to the following useful result: for any function ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " that is continuous at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the following integral can be evaluated analytically:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(-a\)\%b\( h(t)\) \(\[Delta](
            t)\) \[DifferentialD]t = \(lim\_\(\[Epsilon] \[Rule] \ 0\)\
\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\( h(t)\) \(\[Delta](
                t)\) \[DifferentialD]t = \(\(h(
              0)\) \(lim\_\(\[Epsilon] \[Rule] \ \
0\)\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\( \[Delta](
                    t)\) \[DifferentialD]t\) = \(\(h(
              0)\)\(.\)\)\)\)\)]]], "NE3",
  CellTags->"(2.3.29)"],

Cell[TextData[{
  "In the first step, we used the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]],
  " equals zero everywhere except at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " in order to shrink the range of integration down to an infinitesimal \
range that includes the origin. Next, we used the assumption that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(h(t)\)\(\ \)\)\)]],
  "is continuous at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", and finally, we employed Eq. ",
  ButtonBox["(2.3.28)",
    ButtonData:>"(2.3.28)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
\[Delta]-Functions of More Complicated Arguments\
\>", "Section",
  CellTags->"c:30"],

Cell["\<\
We will often have occasion to consider integrals over Dirac \
\[Delta]-functions of the form\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( g(t)\)\ \(\[Delta](
            f(t))\) \[DifferentialD]t\)]],
  ","
}], "NE3",
  CellTags->"(2.3.30)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " equals zero at one or more values of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " in the interval ",
  Cell[BoxData[
      \(TraditionalForm\`a < t < b\)]],
  ". Take, for example, the case ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(\(c\)\(\ \)\(t\)\(\ \)\)\)]],
  ", for some constant ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(,\)\)\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`a < 0 < b\)]],
  ". The integration in Eq. ",
  ButtonBox["(2.3.30)",
    ButtonData:>"(2.3.30)",
    ButtonStyle->"Hyperlink"],
  " can then by performed by making a change of variables: let ",
  Cell[BoxData[
      \(TraditionalForm\`u\  = \ c\ t\)]],
  ".  Then Eq. ",
  ButtonBox["(2.3.30)",
    ButtonData:>"(2.3.30)",
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/c\) \(\[Integral]\_\(\(\ \)\(c\ a\)\)\%\(c\ b\)\
\(g(u/c)\)\ \(\[Delta](u)\) \[DifferentialD]t\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tNow, if ",
  Cell[BoxData[
      \(TraditionalForm\`c > 0\)]],
  " the result according to Eq.",
  ButtonBox["(2.3.29)",
    ButtonData:>"(2.3.29)",
    ButtonStyle->"Hyperlink"],
  "  is ",
  Cell[BoxData[
      \(TraditionalForm\`\(g(0)\)/c\)]],
  ", but if ",
  Cell[BoxData[
      \(TraditionalForm\`c < 0\)]],
  ", the result is ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(g(0)\)\)/c\)]],
  ", because the range of integration is from a positive quantity ",
  Cell[BoxData[
      \(TraditionalForm\`c\ a\)]],
  " to a negative quantity, ",
  Cell[BoxData[
      \(TraditionalForm\`c\ b\)]],
  ". Therefore, we find "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(\(\ \)\(a\)\)\%b\( g(t)\)\ \(\[Delta](
              c\ t)\) \[DifferentialD]t\  = \ \(\(g(0)\)\(/\)\) | c | \)]],
  ", assuming ",
  Cell[BoxData[
      \(TraditionalForm\`a < 0 < b\)]],
  "."
}], "NE3",
  CellTags->"(2.3.31)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.3.31)",
    ButtonData:>"(2.3.31)",
    ButtonStyle->"Hyperlink"],
  " can used to determine more general integrals of the form of Eq. ",
  ButtonBox["(2.3.31)",
    ButtonData:>"(2.3.31)",
    ButtonStyle->"Hyperlink"],
  ". Lets assume that ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " passes through zero at ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " points in the range ",
  Cell[BoxData[
      \(TraditionalForm\`a < t < b\)]],
  ", and let us label these points ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ t\_n\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1, 2, 3,  ... , M\)]],
  ".  The integral can then be broken up into contributions from each one of \
these zeros:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( g(t)\)\ \(\[Delta](
              f(t))\) \[DifferentialD]t = \[Sum]\+\(n = \
1\)\%M\[Integral]\_\(t\_n - \[Epsilon]\)\%\(t\_n + \[Epsilon]\)\ \(g(
                t)\)\ \(\[Delta](f(t))\) \[DifferentialD]t\)]],
  "."
}], "NE3",
  CellTags->"(2.3.32)"],

Cell[TextData[{
  "Other regions of integration do not contribute, because the \
\[Delta]-function is only nonzero within the regions kept. Focussing on one \
of the zeros, ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ t\_n\)]],
  ", we note that only values of values of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " near ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t\_n\)\(\ \)\)\)]],
  "are needed, and so we make a change of variables from ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", Cell[""]}], TraditionalForm]]],
  "to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", \(t - \ t\_n\)}], 
        TraditionalForm]]],
  ":  "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(t\_n - \[Epsilon]\)\%\(t\_n + \[Epsilon]\)\ \
\(g(t)\)\ \(\[Delta](f(t))\) \[DifferentialD]t\), "=", 
          RowBox[{\(\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\), " ", 
            RowBox[{
              RowBox[{"g", "(", 
                RowBox[{\(t\_n\), "+", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], ")"}], " ", 
              RowBox[{"\[Delta]", "(", 
                RowBox[{"f", "(", 
                  RowBox[{\(t\_n\), "+", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], ")"}], ")"}], 
              RowBox[{"\[DifferentialD]", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]}]}]}], TraditionalForm]]],
  ".\nTaylor-expanding ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\)\(\ \)\)\)]],
  " for small ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", noting that ",
  Cell[BoxData[
      \(TraditionalForm\`f(t\_n) = 0\)]],
  ", and assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)(t\_n) \[NotEqual] \ 0\)]],
  ",we have"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\_\(t\_n - \[Epsilon]\)\%\(t\_n + \[Epsilon]\)\ \
\(g(t)\)\ \(\[Delta](f(t))\) \[DifferentialD]t\), "=", 
          RowBox[{
            RowBox[{\(\[Integral]\_\(-\[Epsilon]\)\%\[Epsilon]\), " ", 
              RowBox[{
                RowBox[{"g", "(", 
                  RowBox[{\(t\_n\), "+", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], ")"}], " ", 
                RowBox[{"\[Delta]", "(", 
                  RowBox[{\(\(f\^\[Prime]\)(t\_n)\), 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], ")"}], 
                RowBox[{"\[DifferentialD]", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}]}]}], 
            "=", \(\(\(g(t\_n)\)\(/\)\) | \(f\^\[Prime]\)(t\_n) | \)}]}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where we used Eq.",
  ButtonBox["(2.3.31)",
    ButtonData:>"(2.3.31)",
    ButtonStyle->"Hyperlink"],
  " in the last step. Therefore. Eq. ",
  ButtonBox["(2.3.32)",
    ButtonData:>"(2.3.32)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_a\%b\( g(t)\)\ \(\[Delta](
              f(t))\) \[DifferentialD]t = \[Sum]\+\(n = 1\)\%M\(\( g(
                t\_n)\)\(/\)\) | \(f\^\[Prime]\)(t\_n) | \)]],
  "."
}], "NE3",
  CellTags->"(2.3.33)"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generalized Fourier Integrals", "Section",
  CellTags->{"i:50", "c:31"}],

Cell[TextData[{
  "The previous considerations lead us to a startling observation. Consider \
the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]],
  " itself:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[Delta](t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t = \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]0\) = 
        1\)\)\(,\)\)\)]]], "NE3",
  CellTags->"(2.3.34)"],

Cell[TextData[{
  "where we have used Eq. ",
  ButtonBox["(2.3.29)",
    ButtonData:>"(2.3.29)",
    ButtonStyle->"Hyperlink"],
  ". This result, that the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]],
  " equals one, is expected on one level: after all,  since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]],
  " is infinitely narrow, the uncertainty principle implies its transform \
must be infinitely broad. "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox[" ",
    FontSlant->"Italic"],
  "However",
  ", if we write down the inverse Fourier transform of unity, which should \
return us to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]],
  ", we arrive at the strange result"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](
          t) = \[Integral]\_\(-\[Infinity]\)\%\[Infinity] 
            1\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\) \
\[DifferentialD]\[Omega]/2  \[Pi]\)]],
  "."
}], "NE3",
  CellTags->"(2.3.35)"],

Cell["\<\
This integral is not convergent; the integrand does not decay to \
zero at large \[Omega]. But, somehow, it equals a \[Delta]-function! \
\>", \
"Text"],

Cell[TextData[{
  "\tWe can try to understand this strange result by writing the inverse \
transform as\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t) = 
        lim\_\(\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)\[Integral]\_\(-\
\[CapitalDelta]\[Omega]\)\%\[CapitalDelta]\[Omega] 
              1\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\) \
\[DifferentialD]\[Omega]/2 \( \(\[Pi]\)\(.\)\)\)]]
}], "Text"],

Cell["\tThis integral can be evaluated analytically. The result is", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Delta](t)\  = 
      lim\_\(\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)\(\(\(sin(\
\[CapitalDelta]\[Omega]\ t)\)\/\(\[Pi]\ t\)\)\(\ \)\(.\)\)\)]]], "NE3",
  CellTags->"(2.3.36)"],

Cell[TextData[{
  " For a fixed value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", and as \[CapitalDelta]\[Omega] increases, the function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(sin(\[CapitalDelta]\[Omega]\ t)\)/\[Pi]\)\(\ \
\)\(t\)\(\ \)\)\)]],
  " simply oscillates between the values ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)/\[Pi]\ t\)]],
  ". Since this oscillation continues indefinitely as  ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)]],
  ", the limit is not well defined.  How can  this limit equal a \
\[Delta]-function?"
}], "Text"],

Cell[TextData[{
  "\tThe limit equals a \[Delta]-function in the following ",
  StyleBox["average ",
    FontSlant->"Italic"],
  "sense. Consider an integral over this function multiplied by any \
continuous function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ": "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)\
\[Integral]\_\(-a\)\%b\( f(
              t)\) \(\(sin(\[CapitalDelta]\[Omega]\ t)\)\/\(\[Pi]\ t\)\) \(\(\
\[DifferentialD]t\)\(.\)\)\)]]
}], "NE3",
  CellTags->"(2.3.37)"],

Cell[TextData[{
  "If we now make the change of variables to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\  = \ \[CapitalDelta]\[Omega]\ t\)]],
  ", the integral becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`lim\_\(\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)\
\[Integral]\_\(\(-\[CapitalDelta]\[Omega]\)\ a\)\%\(\(\[CapitalDelta]\[Omega]\
\)\(\ \)\(b\)\(\ \)\)\ \(f(\[Tau]/\[CapitalDelta]\[Omega])\)\ \(sin\[Tau]\/\(\
\[Pi]\ \[Tau]\)\) \(\(\[DifferentialD]\[Tau]\)\(.\)\)\)]]], "NE3",
  CellTags->"(2.3.38)"],

Cell[TextData[{
  "However,  the function ",
  Cell[BoxData[
      \(TraditionalForm\`sin\[Tau]\/\(\[Pi]\ \[Tau]\)\)]],
  " is peaked at the origin, with an area under the curve equal to unity:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
                sin\[Tau]\/\(\[Pi]\ \[Tau]\)\) \[DifferentialD]t = 1\)]],
  "."
}], "NE3",
  CellTags->"(2.3.39)"],

Cell[TextData[{
  "Since this integral is convergent, we can replace the limits of \
integration in Eq. ",
  ButtonBox["(2.3.38)",
    ButtonData:>"(2.3.38)",
    ButtonStyle->"Hyperlink"],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Infinity]\)\)]],
  ". Furthermore, in the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)]],
  ", we can replace ",
  Cell[BoxData[
      \(TraditionalForm\`f(\[Tau]/\[CapitalDelta]\[Omega]) \[Rule] \ 
        f(0)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Therefore,using Eq. (",
  ButtonBox["2.3.39",
    ButtonData:>"(2.3.39)",
    ButtonStyle->"Hyperlink"],
  ") we find that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(lim\_\(\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\
\)\[Integral]\_\(-a\)\%b\(\( 
                  sin(\[CapitalDelta]\[Omega]\ t)\)\/\(\[Pi]\ t\)\) \(f(
              t)\)\ \[DifferentialD]t\  = \ f(0)\)\(,\)\)\)]]], "NE3",
  CellTags->"(2.3.40)"],

Cell[TextData[{
  "\tThus, the function ",
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(\[CapitalDelta]\[Omega] \[Rule] \[Infinity]\)\
\(sin(\[CapitalDelta]\[Omega]\ t)\)\/\(\[Pi]\ t\)\)]],
  "has the most important property of a \[Delta] function: it satisfies Eq. \
",
  ButtonBox["(2.3.29)",
    ButtonData:>"(2.3.29)",
    ButtonStyle->"Hyperlink"],
  ". If we take ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ 1\)]],
  ", we can immediately see that the function also satisfies Eq. ",
  ButtonBox["(2.3.28)",
    ButtonData:>"(2.3.28)",
    ButtonStyle->"Hyperlink"],
  ".  On the other hand, it does not satisfy Eq. ",
  ButtonBox["(2.3.27)",
    ButtonData:>"(2.3.27)",
    ButtonStyle->"Hyperlink"],
  ": it is not equal to zero for ",
  Cell[BoxData[
      \(TraditionalForm\`t \[NotEqual] 0\)]],
  "; rather it is undefined, oscillating rapidly between ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]1\)/\[Pi]\ t\)]],
  ". Actually, rapidly is an understatement. In the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] \[Rule] \ \[Infinity]\)]],
  ", the oscillations in the function become ",
  StyleBox["infinitely rapid",
    FontSlant->"Italic"],
  ". Fortunately, the nature of this variation allows us to call this \
function a \[Delta]-function. When evaluating an integral with respect to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t\)\(\ \)\)\)]],
  "over this function, the oscillations ",
  StyleBox["average to zero ",
    FontSlant->"Italic"],
  "unless the origin is included in the range of integration. This can be \
seen in Cell ",
  ButtonBox["2.54",
    ButtonData:>"Cell 2.54",
    ButtonStyle->"Hyperlink"],
  ", which displays the behavior of this function over a range of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " as",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[CapitalDelta]\[Omega]\)\)\)]],
  " increases. "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Sin[\[CapitalDelta]\[Omega]\ t]/\((Pi\ t)\), {t, 1, 2}, 
          PlotRange \[Rule] {\(-1\), 1}], {\[CapitalDelta]\[Omega], 10, 100, 
          10}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.54"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .25551 m
.04262 .24168 L
.06244 .23046 L
.07286 .22607 L
.08255 .22294 L
.08813 .22156 L
.0932 .22058 L
.096 .22015 L
.09905 .21978 L
.10192 .2195 L
.10329 .21941 L
.10458 .21933 L
.10574 .21927 L
.10701 .21923 L
.10817 .2192 L
.10924 .21919 L
.11051 .21919 L
.11166 .2192 L
.1123 .21921 L
.11299 .21923 L
.11425 .21928 L
.11534 .21933 L
.11654 .2194 L
.11897 .21959 L
.12121 .21981 L
.12331 .22007 L
.12851 .22087 L
.13326 .22183 L
.14393 .22474 L
.15384 .22832 L
.16302 .23235 L
.18378 .24375 L
.22304 .27186 L
.26079 .30288 L
.301 .33472 L
.33968 .35938 L
.35972 .36862 L
.3698 .37219 L
.38082 .37523 L
.38611 .37636 L
.3911 .37723 L
.39558 .37784 L
.40043 .37833 L
.40296 .37852 L
.4044 .3786 L
.40573 .37866 L
.40712 .37871 L
.40789 .37873 L
.40862 .37875 L
.40992 .37876 L
Mistroke
.41065 .37877 L
.41133 .37877 L
.41265 .37876 L
.41389 .37874 L
.415 .37871 L
.4162 .37867 L
.41752 .37861 L
.4189 .37853 L
.42138 .37836 L
.42636 .37788 L
.43089 .37728 L
.44106 .37539 L
.45049 .37299 L
.45941 .37018 L
.47936 .36214 L
.49779 .35287 L
.53711 .32902 L
.57491 .30412 L
.61517 .27986 L
.63368 .27059 L
.65391 .26235 L
.66362 .25919 L
.67399 .25643 L
.67972 .25518 L
.68493 .25422 L
.68987 .25347 L
.6951 .25284 L
.69987 .25242 L
.70258 .25225 L
.70387 .25218 L
.70511 .25212 L
.70622 .25208 L
.70743 .25205 L
.70853 .25202 L
.70955 .25201 L
.71065 .252 L
.71186 .25199 L
.71313 .252 L
.71432 .25202 L
.71554 .25205 L
.71686 .25208 L
.71825 .25214 L
.71954 .2522 L
.72433 .25251 L
.72707 .25275 L
.72955 .25301 L
.73513 .25372 L
.7451 .25546 L
.75429 .25756 L
.77508 .26393 L
Mistroke
.81445 .28103 L
.85231 .30114 L
.89262 .32288 L
.93141 .3407 L
.95256 .3481 L
.97265 .35322 L
.97619 .35392 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol05Goo4`00ogooEGoo000aOol00`00Oomoo`0COol2000COol3003oOomBOol000aoo`8000Mo
o`<000Aoo`H000Aoo`@000Moo`03001oogoo011oo`<001Qoo`@00?moodioo`002goo00@007ooOol0
00Ioo`<000Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0=
Ool3000OOol3003oOom;Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo
00Uoo`03001oogoo00Aoo`@000Yoo`8002Eoo`800?moodUoo`0000=oo`0000001@000Woo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol02Goo0P00:Goo
0P00ogooAgoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0[Ool2003oOom5Ool000Yoo`03001oogoo
009oo`03001oogoo00moo`04001oogooOol50007Ool00`00Oomoo`06Ool2000`Ool2003oOom3Ool0
00Yoo`03001oogoo009oo`03001oogoo00moo`05001oogooOol0000;Ool00`00Oomoo`04Ool2000d
Ool2003oOom1Ool000]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<0
07ooOol00goo00<007ooOol0=Woo0P00ogoo?goo000<Ool2000?Ool40004Ool50007Ool30002Ool0
0`00Oomoo`0iOol00`00Oomoo`3oOollOol0035oo`03001oogoo008003eoo`03001oogoo0?mooc]o
o`00<Goo00<007oo0000@7oo0P00`Woo2`00KGoo000aOol20013Ool00`00Oomoo`2iOol6000;Ool7
001VOol0035oo`03001oogoo04=oo`800;Aoo`D001Qoo`@0069oo`00<Goo00<007ooOol0AGoo00<0
07ooOol0[Goo10008Goo1000GWoo000aOol30016Ool00`00Oomoo`2YOol3000YOol4001JOol0035o
o`03001oogoo04Moo`800:Moo`80031oo`<005Moo`00<Goo00<007ooOol0BGoo00<007ooOol0XWoo
0P00=Goo0P00EGoo000aOol00`00Oomoo`1:Ool00`00Oomoo`2OOol2000iOol2001COol0035oo`03
001oogoo03aoo`D000Eoo`<0009oo`P003Aoo`D000Eoo`<000Moo`<003=oo`D000Eoo`<000Eoo`@0
00=oo`8002moo`D000Eoo`<00005Ool00000001oo`04000mOol60008Ool0035oo`03001oogoo03io
o`03001oogoo00Eoo`<000Aoo`8000=oo`03001oogoo03Aoo`03001oogoo00Eoo`<000Qoo`03001o
ogoo03Aoo`03001oogoo00Eoo`<000Aoo`03001oogoo009oo`<003=oo`03001oogoo00Eoo`<000Ao
o`8000=oo`03001oogoo03]oo`05001oogooOol00008Ool0035oo`03001oogoo03ioo`03001oogoo
00Eoo`<000Eoo`8003Uoo`03001oogoo00Eoo`<000Aoo`H003Eoo`03001oogoo00Eoo`<000Aoo`03
001oogoo00<003Eoo`03001oogoo00Eoo`<000Aoo`06001oo`00001oo`00?Woo00<007ooOol02Goo
000aOol3000nOol00`00Oomoo`0>Ool2000hOol00`00Oomoo`0<Ool01@00Oomoogoo0000=Woo00<0
07ooOol037oo0`000Woo00<007ooOol0<goo00<007ooOol037oo00@007ooOomoo`8003moo`03001o
ogoo00Qoo`00<Goo00<007ooOol0?Woo00<007ooOol03goo0P00=goo00<007ooOol03Goo00@007oo
Ool003Ioo`03001oogoo00aoo`8000=oo`03001oogoo03=oo`03001oogoo00eoo`@00003Ool00000
03ioo`03001oogoo00Moo`00<Goo00<007ooOol0?Woo00<007ooOol04Goo00<007ooOol0=7oo00<0
07ooOol03Woo00<007oo0000=Woo00<007ooOol02Woo0`0000Aoo`00000003Ioo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo008003eoo`03001oogoo00Ioo`00<Goo00<007ooOol0?Woo00<0
07ooOol04Goo0P00=Goo00<007ooOol03Woo00<007oo0000=Woo00<007ooOol02Goo00D007ooOomo
o`0003Uoo`03001oogoo00aoo`03001oogoo009oo`03001oogoo009oo`8003]oo`03001oogoo00Io
o`00<Goo00<007ooOol0?7oo0`003Woo00<007ooOol00Woo00<007oo0000<Woo0`004Goo0P00=7oo
0`002Goo0P0017oo0P00=Woo0`003Woo00<007ooOol00Woo00<007ooOol017oo0P00=7oo00<007oo
Ool00Woo00<007ooOol01Woo000aOol00`00Oomoo`0mOol2000?Ool40003Ool2000aOol2000BOol0
0`00Oomoo`0cOol20008Ool00`00Oomoo`06Ool3000dOol2000?Ool40009Ool00`00Oomoo`0bOol4
0009Ool0035oo`<005Moo`03001oogoo081oo`8005moo`8003moo`00<Goo00<007ooOol0F7oo00<0
07ooOol0OWoo00<007ooOol0HGoo0P00?Goo000aOol00`00Oomoo`1IOol00`00Oomoo`1kOol2001V
Ool2000kOol0035oo`03001oogoo05Yoo`8007Yoo`03001oogoo06Qoo`8003Uoo`00<Goo00<007oo
Ool0G7oo00<007ooOol0MGoo0P00KGoo0P00=goo000aOol00`00Oomoo`1MOol00`00Oomoo`1bOol2
001aOol2000eOol002Qoool008T00000<Goo00<007ooOol047oo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol047oo00<007ooOol03goo00<007ooOol00Woo0P0037oo00<007ooOol047oo00<0
07ooOol03goo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol00Woo0P00
2goo00<007ooOol047oo00<007ooOol047oo00<007ooOol03goo00<007ooOol047oo00<007ooOol0
3goo00<007ooOol03Goo0P0000=oo`00Ool04Goo00<007ooOol03goo00<007ooOol027oo000aOol0
0`00Oomoo`18Ool00`00Oomoo`0FOol00`00Oomoo`0^Ool00`00Oomoo`0hOol2000=Ool00`00Oomo
o`18Ool00`00Oomoo`0QOol2000TOol00`00Oomoo`08Ool0035oo`03001oogoo069oo`03001oogoo
06Moo`03001oogoo07ioo`8002eoo`00<Goo00<007ooOol0Hgoo00<007ooOol0I7oo0P00Pgoo0P00
:goo000aOol00`00Oomoo`1TOol00`00Oomoo`1QOol20027Ool2000YOol0035oo`<006Eoo`80061o
o`03001oogoo08Uoo`8002Moo`00<Goo00<007ooOol0Igoo00<007ooOol0Fgoo0P00SWoo0P009Goo
000aOol00`00Oomoo`1XOol00`00Oomoo`1IOol00`00Oomoo`2@Ool3000ROol0035oo`03001oogoo
06Uoo`03001oogoo05Ioo`8009Ioo`80021oo`00<Goo00<007ooOol0JWoo0P00E7oo0P00VWoo0P00
7Woo000aOol00`00Oomoo`1/Ool2001AOol00`00Oomoo`2LOol2000LOol0035oo`<006ioo`03001o
ogoo04aoo`800:5oo`8001Yoo`00<Goo00<007ooOol0Kgoo0P00Bgoo00<007ooOol0Xgoo0`005goo
000aOol00`00Oomoo`1aOol20017Ool2002YOol3000DOol0035oo`03001oogoo07=oo`03001oogoo
049oo`800:ioo`<0015oo`00<Goo00<007ooOol0M7oo0P00@Goo00<007ooOol0/Goo10003Goo000a
Ool00`00Oomoo`1fOol2000mOol2002hOol3000:Ool0035oo`<007Qoo`03001oogoo03Moo`<00<Mo
o`00<Goo00<007ooOol0NGoo0P00=Goo0P00bWoo000aOol00`00Oomoo`1kOol2000aOol2003<Ool0
035oo`03001oogoo07eoo`8002aoo`<00<ioo`00<Goo00<007ooOol0Ogoo0P009goo0`00dGoo000a
Ool00`00Oomoo`21Ool3000ROol2003DOol0035oo`<008Aoo`@001eoo`03001oogoo0=Aoo`00<Goo
00<007ooOol0R7oo0`005goo0`00egoo000aOol00`00Oomoo`2;Ool5000:Ool8003JOol000aoo`80
00Moo`<000Aoo`H000Aoo`@000Moo`03001oogoo091oo`X00>9oo`002goo00@007ooOol000Ioo`<0
00Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol0
00Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`03
001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo1000ogooO7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo
00moo`04001oogooOol50007Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo
00moo`05001oogooOol0000;Ool00`00Oomoo`3oOommOol000]oo`04001oogoo000=Ool00`00Oomo
o`02Ool01@00Oomoogoo00002goo00<007ooOol0ogooOGoo000<Ool2000?Ool40004Ool50007Ool0
0`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol001Eoo`8000Mo
o`<000Eoo`@000Moo`03001oogoo0?moogeoo`0057oo00@007ooOol000Ioo`<000Aoo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007ooOol00goo
0`002Goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`04Ool4003oOomlOol001=oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007ooOol02Woo
1@001goo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo000=Ool00`00Oomoo`09Ool00`00Oomoo`3oOomm
Ool001Eoo`8000ioo`D000Moo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool30006Ool00`00Oomoo`05Ool4
0007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo
00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogaoo`002Woo00<007ooOol00Woo
00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0ogooOGoo000:Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`D000Moo`03
001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo00<007oo
Ool02Goo00<007ooOol0ogooOGoo000;Ool01000Oomoo`003Goo00<007ooOol00Woo00D007ooOomo
o`0000]oo`03001oogoo0?moogeoo`0037oo0P003Woo1P000goo1@001goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000VOol50006Ool00`00Oomoo`3oOomm
Ool002Qoo`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo1000ogooO7oo
000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo
000XOol00`00Oomoo`3oOon6Ool002Ioo`<00?moohQoo`009goo0P00ogooR7oo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.812, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39882 m
.02846 .40185 L
.03068 .40298 L
.03279 .40385 L
.03398 .40427 L
.03527 .40465 L
.03635 .40491 L
.03754 .40514 L
.03882 .40532 L
.03952 .40539 L
.04018 .40543 L
.04135 .40547 L
.04262 .40544 L
.04393 .40534 L
.04516 .40519 L
.0465 .40494 L
.04793 .4046 L
.05057 .40373 L
.05297 .4027 L
.05785 .3999 L
.06244 .39641 L
.07299 .38555 L
.08269 .37248 L
.10458 .33538 L
.125 .29715 L
.14407 .26455 L
.15348 .25116 L
.16239 .24075 L
.16732 .23607 L
.17267 .2319 L
.17754 .229 L
.18204 .22707 L
.18446 .22634 L
.18667 .22586 L
.18783 .22568 L
.1891 .22555 L
.18975 .2255 L
.19043 .22547 L
.19167 .22545 L
.19283 .22549 L
.1941 .22558 L
.1953 .22573 L
.1964 .22591 L
.19849 .22637 L
.2007 .22703 L
.20315 .22796 L
.20577 .22919 L
.21051 .23201 L
.22131 .24112 L
.23144 .25265 L
Mistroke
.24248 .26784 L
.26258 .29972 L
.28394 .33405 L
.30328 .36008 L
.31298 .36995 L
.31809 .37409 L
.32347 .37762 L
.32819 .37997 L
.33087 .38099 L
.33337 .38173 L
.33455 .38201 L
.33567 .38223 L
.33668 .3824 L
.33776 .38254 L
.33893 .38265 L
.34001 .38271 L
.34118 .38274 L
.34246 .38272 L
.34368 .38264 L
.34482 .38253 L
.34606 .38236 L
.34739 .38213 L
.35011 .38147 L
.35258 .38067 L
.35735 .3786 L
.36185 .37602 L
.37187 .36824 L
.38272 .35704 L
.42369 .30051 L
.44408 .27326 L
.45405 .2623 L
.46314 .2542 L
.46764 .25095 L
.47254 .24802 L
.47716 .24586 L
.48145 .2444 L
.48378 .24383 L
.48597 .24344 L
.48722 .24328 L
.48837 .24317 L
.48963 .24309 L
.49027 .24307 L
.49096 .24306 L
.49165 .24307 L
.49229 .24309 L
.4935 .24315 L
.49479 .24327 L
.49553 .24336 L
.4962 .24345 L
.49857 .24389 L
Mistroke
.50108 .24452 L
.506 .24628 L
.5105 .24845 L
.52063 .25524 L
.53002 .2636 L
.53894 .27307 L
.57715 .32164 L
.58814 .33504 L
.59848 .34625 L
.60855 .35535 L
.61297 .35868 L
.61782 .36181 L
.62223 .36418 L
.62697 .36617 L
.62958 .36703 L
.63196 .36766 L
.63311 .36791 L
.63436 .36814 L
.63545 .36831 L
.63663 .36846 L
.63788 .36857 L
.63906 .36864 L
.63975 .36867 L
.64047 .36868 L
.64175 .36867 L
.6424 .36865 L
.6431 .36861 L
.64435 .36852 L
.64512 .36844 L
.64584 .36835 L
.64719 .36814 L
.64963 .36766 L
.65188 .36708 L
.65697 .36529 L
.66164 .3631 L
.66667 .36017 L
.67574 .35353 L
.69639 .33323 L
.71615 .31006 L
.73768 .28538 L
.74769 .27547 L
.75833 .26666 L
.76351 .26316 L
.76838 .26037 L
.77308 .25818 L
.77747 .25658 L
.77991 .25589 L
.78214 .25538 L
.78462 .25496 L
.78598 .25479 L
Mistroke
.78727 .25467 L
.78852 .25459 L
.78915 .25457 L
.78984 .25455 L
.79107 .25455 L
.79222 .25458 L
.79291 .25461 L
.79357 .25466 L
.79481 .25477 L
.79614 .25492 L
.7976 .25515 L
.80003 .25563 L
.80224 .25618 L
.80719 .25783 L
.81177 .25984 L
.81609 .26214 L
.83616 .27732 L
.85463 .29592 L
.87504 .31815 L
.8941 .33706 L
.90351 .34478 L
.91242 .35075 L
.91734 .35341 L
.92269 .35575 L
.92505 .3566 L
.92756 .35736 L
.92971 .35791 L
.93206 .35839 L
.93444 .35876 L
.93574 .35891 L
.93695 .35901 L
.93808 .35908 L
.93911 .35912 L
.9403 .35913 L
.94143 .35911 L
.94265 .35906 L
.94395 .35898 L
.94505 .35887 L
.94627 .35872 L
.94898 .35828 L
.95152 .35773 L
.95613 .35637 L
.96033 .35475 L
.9698 .34986 L
.97619 .34566 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol000aoo`8000Moo`<000Aoo`H000Aoo`@000Mo
o`03001oogoo03aoo`L00?moocYoo`002goo00@007ooOol000Ioo`<000Eoo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0iOol30006Ool4003oOolgOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`@003Ioo`80
00eoo`03001oogoo0?moocAoo`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol027oo00<007ooOol017oo00<007ooOol0=Woo00<007ooOol03Woo00<007ooOol0ogoo
<goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`0eOol00`00Oomoo`0@Ool00`00Oomoo`3oOolbOol000Yoo`03001oogoo
009oo`03001oogoo00moo`04001oogooOol50007Ool00`00Oomoo`0dOol00`00Oomoo`0BOol00`00
Oomoo`3oOolaOol000Yoo`03001oogoo009oo`03001oogoo00moo`05001oogooOol0000;Ool00`00
Oomoo`0cOol00`00Oomoo`0DOol00`00Oomoo`3oOol`Ool000]oo`04001oogoo000=Ool00`00Oomo
o`02Ool01@00Oomoogoo00002goo00<007ooOol0<goo00<007ooOol057oo00<007ooOol0HWoo2`00
`Woo000<Ool2000?Ool40004Ool50007Ool3000bOol00`00Oomoo`0FOol00`00Oomoo`1POol00`00
Oomoo`09Ool00`00Oomoo`2oOol0035oo`03001oogoo035oo`03001oogoo01Qoo`03001oogoo05eo
o`8000eoo`800;moo`00<Goo00<007ooOol0<7oo00<007ooOol06Woo00<007ooOol0FWoo0P004Goo
00<007ooOol0_7oo000aOol00`00Oomoo`0`Ool00`00Oomoo`0KOol00`00Oomoo`1GOol2000DOol0
0`00Oomoo`1UOol6001@Ool0035oo`03001oogoo02moo`03001oogoo01eoo`03001oogoo05Eoo`03
001oogoo01Eoo`80069oo`<000Eoo`@004eoo`00<Goo00<007ooOol0;Woo00<007ooOol07goo00<0
07ooOol0Dgoo00<007ooOol067oo00<007ooOol0GGoo0P0037oo1000BGoo000aOol3000]Ool00`00
Oomoo`0QOol00`00Oomoo`1AOol00`00Oomoo`0JOol00`00Oomoo`1JOol2000BOol20017Ool0035o
o`03001oogoo02aoo`03001oogoo02=oo`03001oogoo051oo`03001oogoo01]oo`03001oogoo05Mo
o`8001Ioo`03001oogoo04Aoo`00<Goo00<007ooOol0;7oo00<007ooOol097oo00<007ooOol0CWoo
00<007ooOol077oo00<007ooOol0EGoo0P006Goo00<007ooOol0@goo000aOol00`00Oomoo`0[Ool0
0`00Oomoo`0UOol00`00Oomoo`1=Ool00`00Oomoo`0NOol00`00Oomoo`1COol00`00Oomoo`0JOol2
0013Ool0035oo`03001oogoo02]oo`03001oogoo00ioo`D000Eoo`<000Aoo`H00003Ool007oo035o
o`D000Eoo`<000Moo`<000Aoo`03001oogoo021oo`03001oogoo00Uoo`D000Eoo`<000Eoo`@0039o
o`03001oo`0000@000Eoo`<000Eoo`@000Qoo`03001oogoo039oo`H000Qoo`00<Goo00<007ooOol0
:Woo00<007ooOol04Goo00<007ooOol01Goo0`001Goo00D007ooOomoo`00009oo`03001oogoo035o
o`03001oogoo00Eoo`<000Qoo`03001oogoo009oo`03001oogoo029oo`03001oogoo00Yoo`03001o
ogoo00Eoo`<000Aoo`03001oogoo009oo`03001oogoo02ioo`03001oogoo009oo`03001oogoo00Eo
o`<000Aoo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo039oo`05001oogooOol00008Ool0
035oo`<002Yoo`03001oogoo015oo`03001oogoo00Eoo`<000Ioo`03001oogoo00=oo`03001oogoo
035oo`03001oogoo00Eoo`<000Aoo`H000=oo`03001oogoo029oo`03001oogoo00Yoo`03001oogoo
00Eoo`<000Aoo`03001oogoo009oo`03001oogoo02eoo`03001oogoo00=oo`03001oogoo00Eoo`<0
00Aoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo039oo`03001oogoo00Uoo`00<Goo00<0
07ooOol0:Goo00<007ooOol04Woo00<007ooOol03goo00<007ooOol00goo00<007ooOol0<7oo00<0
07ooOol037oo00D007ooOomoo`0000=oo`03001oogoo02Aoo`03001oogoo00Uoo`03001oogoo00ao
o`03001oogoo009oo`03001oogoo02aoo`03001oogoo00Aoo`03001oogoo00aoo`03001oogoo009o
o`03001oogoo00Qoo`03001oogoo039oo`03001oogoo00Qoo`00<Goo00<007ooOol0:7oo00<007oo
Ool04goo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0<7oo00<007ooOol03Goo00@007oo
Ool0009oo`03001oogoo02Ioo`03001oogoo00Qoo`03001oogoo00aoo`8000=oo`03001oogoo02]o
o`03001oogoo00Eoo`03001oogoo00eoo`@000aoo`03001oogoo039oo`03001oogoo00Moo`00<Goo
00<007ooOol0:7oo00<007ooOol04goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol0;goo
00<007ooOol03Woo00<007oo00000Woo00<007ooOol09goo00<007ooOol01goo00<007ooOol037oo
00<007oo00000P00;Goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol0
2Woo00<007ooOol0<Woo00<007ooOol01Woo000aOol00`00Oomoo`0WOol00`00Oomoo`0DOol00`00
Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0^Ool00`00Oomoo`0>Ool01@00Ool007oo0000:goo
00<007ooOol01Woo00<007ooOol03Goo00<007ooOol0;Woo00<007ooOol01Woo00<007ooOol037oo
00<007ooOol00Woo00<007ooOol02goo00<007ooOol0<Goo00<007ooOol01Woo000aOol00`00Oomo
o`0WOol00`00Oomoo`0BOol3000>Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0/Ool3
000AOol3000]Ool00`00Oomoo`03Ool3000?Ool2000^Ool00`00Oomoo`05Ool3000>Ool00`00Oomo
o`02Ool00`00Oomoo`0<Ool00`00Oomoo`0[Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0035oo`03
001oogoo02Ioo`03001oogoo01Aoo`8000moo`@000Moo`03001oogoo02aoo`80019oo`03001oogoo
02aoo`03001oogoo00Aoo`80015oo`<002Yoo`03001oogoo00Moo`8000moo`@0011oo`03001oogoo
02]oo`@000Uoo`00<Goo0`009Woo00<007ooOol0<7oo00<007ooOol0@7oo00<007ooOol0;Goo00<0
07ooOol0@Woo00<007ooOol0;Woo00<007ooOol0=goo000aOol00`00Oomoo`0UOol00`00Oomoo`0b
Ool00`00Oomoo`0nOol00`00Oomoo`0_Ool00`00Oomoo`10Ool00`00Oomoo`0_Ool00`00Oomoo`0g
Ool0035oo`03001oogoo02Eoo`03001oogoo03=oo`03001oogoo03aoo`03001oogoo035oo`03001o
ogoo03moo`03001oogoo031oo`03001oogoo03Ioo`00<Goo00<007ooOol097oo00<007ooOol0=7oo
00<007ooOol0?7oo00<007ooOol0<Woo00<007ooOol0?Goo00<007ooOol0<Woo00<007ooOol0=Goo
000aOol00`00Oomoo`0TOol00`00Oomoo`0eOol00`00Oomoo`0jOol00`00Oomoo`0dOol00`00Oomo
o`0kOol00`00Oomoo`0dOol00`00Oomoo`0dOol0035oo`03001oogoo02=oo`03001oogoo03Moo`03
001oogoo03Qoo`03001oogoo03Eoo`03001oogoo03Yoo`03001oogoo03Ioo`03001oogoo03=oo`00
:7ooo`00R@00000aOol00`00Oomoo`0@Ool00`00Oomoo`0?Ool2000AOol00`00Oomoo`0@Ool00`00
Oomoo`0?Ool01@00Oomoogoo00003Woo00<007ooOol047oo00<007ooOol03goo00<007ooOol00Woo
00<007ooOol02goo00<007ooOol03goo00<007ooOol047oo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol047oo00<007ooOol047oo00<007ooOol01goo00<007ooOol01Goo00<007ooOol047oo
00<007ooOol03goo00<007ooOol037oo00D007ooOomoo`00019oo`03001oogoo00moo`03001oogoo
00Qoo`00<Goo00<007ooOol08Woo00<007ooOol08goo00<007ooOol04goo00<007ooOol0<Goo00D0
07ooOomoo`0003aoo`03001oogoo00Ioo`03001oogoo02aoo`03001oogoo01Uoo`03001oogoo01mo
o`03001oogoo02Eoo`03001oogoo00Qoo`00<Goo00<007ooOol08Goo00<007ooOol0>goo00<007oo
Ool0<goo00<007ooOol0?7oo00<007ooOol0<goo00<007ooOol0?Goo00<007ooOol0;goo000aOol0
0`00Oomoo`0POol00`00Oomoo`0mOol00`00Oomoo`0bOol00`00Oomoo`0mOol00`00Oomoo`0aOol0
0`00Oomoo`0nOol00`00Oomoo`0_Ool0035oo`03001oogoo021oo`03001oogoo03eoo`03001oogoo
035oo`03001oogoo03ioo`03001oogoo031oo`03001oogoo041oo`03001oogoo02ioo`00<Goo0`00
7goo00<007ooOol0?goo00<007ooOol0;goo00<007ooOol0@7oo00<007ooOol0;Woo00<007ooOol0
@Woo00<007ooOol0;Goo000aOol00`00Oomoo`0OOol00`00Oomoo`0oOol00`00Oomoo`0^Ool00`00
Oomoo`12Ool00`00Oomoo`0/Ool00`00Oomoo`14Ool00`00Oomoo`0/Ool0035oo`03001oogoo01io
o`03001oogoo045oo`03001oogoo02eoo`03001oogoo04=oo`03001oogoo02Yoo`03001oogoo04Io
o`03001oogoo02]oo`00<Goo00<007ooOol07Woo00<007ooOol0@Woo00<007ooOol0:goo00<007oo
Ool0AGoo00<007ooOol0:7oo00<007ooOol0B7oo00<007ooOol0:Woo000aOol00`00Oomoo`0MOol0
0`00Oomoo`13Ool00`00Oomoo`0ZOol00`00Oomoo`17Ool00`00Oomoo`0VOol00`00Oomoo`1:Ool0
0`00Oomoo`0YOol0035oo`03001oogoo01eoo`03001oogoo04Aoo`03001oogoo02Qoo`03001oogoo
04Uoo`03001oogoo02Aoo`03001oogoo04aoo`8002Uoo`00<Goo0`0077oo00<007ooOol0AWoo00<0
07ooOol09goo00<007ooOol0BWoo00<007ooOol08Woo00<007ooOol0Cgoo00<007ooOol09Woo000a
Ool00`00Oomoo`0KOol00`00Oomoo`17Ool00`00Oomoo`0VOol00`00Oomoo`1<Ool00`00Oomoo`0P
Ool00`00Oomoo`1AOol00`00Oomoo`0UOol0035oo`03001oogoo01]oo`03001oogoo04Qoo`03001o
ogoo02Aoo`03001oogoo04ioo`03001oogoo01ioo`03001oogoo05=oo`8001Yoo`03001oogoo00Qo
o`00<Goo00<007ooOol06Woo00<007ooOol0BWoo00<007ooOol08goo00<007ooOol0Cgoo00<007oo
Ool077oo00<007ooOol0EWoo00<007ooOol05Woo00<007ooOol02Goo000aOol00`00Oomoo`0IOol0
0`00Oomoo`1<Ool00`00Oomoo`0QOol00`00Oomoo`1AOol00`00Oomoo`0JOol00`00Oomoo`1HOol2
000COol3000<Ool0035oo`03001oogoo01Uoo`03001oogoo04aoo`03001oogoo021oo`03001oogoo
05=oo`03001oogoo01Moo`8005eoo`8000ioo`<000moo`00<Goo0`0067oo00<007ooOol0CWoo00<0
07ooOol07Woo00<007ooOol0EGoo00<007ooOol05Goo00<007ooOol0Ggoo0`002Woo00<007ooOol0
47oo000aOol00`00Oomoo`0HOol00`00Oomoo`1?Ool00`00Oomoo`0LOol00`00Oomoo`1GOol2000D
Ool00`00Oomoo`1SOol:000COol0035oo`03001oogoo01Moo`03001oogoo055oo`03001oogoo01Yo
o`03001oogoo05Yoo`80011oo`8008=oo`00<Goo00<007ooOol05Woo00<007ooOol0Dgoo00<007oo
Ool067oo00<007ooOol0GGoo0P003Goo00<007ooOol0Pgoo000aOol00`00Oomoo`0FOol00`00Oomo
o`1DOol00`00Oomoo`0FOol00`00Oomoo`1POol30006Ool40026Ool0035oo`03001oogoo01Eoo`03
001oogoo05Ioo`03001oogoo01=oo`8006Eoo`L008Yoo`00<Goo0`0057oo00<007ooOol0F7oo00<0
07ooOol04Goo00<007ooOol0mWoo000aOol00`00Oomoo`0DOol00`00Oomoo`1IOol2000@Ool00`00
Oomoo`3gOol0035oo`03001oogoo01=oo`03001oogoo05aoo`8000eoo`03001oogoo0?Qoo`0037oo
0P001goo0`0017oo1P0017oo10001goo00<007ooOol04Woo00<007ooOol0Ggoo00<007ooOol027oo
0P00ngoo000;Ool01000Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo019oo`03001oogoo061oo`X00?eoo`002Woo00<007ooOol00Woo00<0
07ooOol00goo0`001Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol0
ogooJGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`04Ool4
000?Ool00`00Oomoo`3oOomZOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo0?moof]oo`002Woo00<0
07ooOol00Woo00<007ooOol03goo00@007ooOomoo`D000Moo`03001oogoo00ioo`03001oogoo0?mo
ofaoo`002Woo00<007ooOol00Woo00<007ooOol03goo00D007ooOomoo`0000]oo`03001oogoo00eo
o`03001oogoo0?moofeoo`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogooOol0000;
Ool00`00Oomoo`0<Ool00`00Oomoo`3oOom^Ool000aoo`8000moo`@000Aoo`D000Moo`8000]oo`80
0?moog5oo`00<Goo100027oo00<007ooOol0ogooLGoo000aOol01000Oomoogoo2000ogooM7oo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
01Eoo`8000Moo`<000Eoo`@000Moo`03001oogoo0?moogeoo`0057oo00@007ooOol000Ioo`<000Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<0
07ooOol00goo0`002Goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`04Ool4003oOomlOol001=oo`03001oogoo009oo`03001oogoo00Yo
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<0
07ooOol02Woo1@001goo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool0
0`00Oomoo`09Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo000=Ool00`00Oomoo`09Ool00`00
Oomoo`3oOommOol001Eoo`8000ioo`D000Moo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool30006Ool00`00
Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009o
o`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogaoo`002Woo00<0
07ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0ogooOGoo
000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009o
o`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol0
0Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000Oomoo`003Goo00<007ooOol00Woo
00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P003Woo1P000goo1@001goo0`00ogoo
OGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogoo
OGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000VOol50006Ool00`00
Oomoo`3oOommOol002Qoo`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo
1000ogooO7oo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007oo
Ool0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Ioo`<00?moohQoo`009goo0P00ogooR7oo003o
OonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21183 m
.06244 .29034 L
.08255 .34802 L
.08806 .36166 L
.09396 .37434 L
.09948 .38406 L
.10458 .39096 L
.10706 .39353 L
.10969 .39569 L
.11096 .39652 L
.11233 .39725 L
.11311 .39759 L
.11383 .39786 L
.11451 .39807 L
.11523 .39825 L
.11651 .39846 L
.1177 .39852 L
.11843 .39849 L
.11911 .39842 L
.12039 .39819 L
.12162 .39782 L
.12275 .39737 L
.1253 .39595 L
.12756 .39423 L
.12967 .39224 L
.13447 .3864 L
.13914 .37906 L
.14415 .3696 L
.16396 .32121 L
.17441 .29327 L
.18551 .26606 L
.19535 .24662 L
.20095 .23824 L
.20351 .23515 L
.20621 .23244 L
.20851 .23057 L
.20972 .22975 L
.21102 .229 L
.21221 .22843 L
.2133 .22802 L
.21439 .22769 L
.21542 .22748 L
.21663 .22734 L
.2179 .22731 L
.21899 .2274 L
.22019 .2276 L
.22148 .22795 L
.22286 .22847 L
.22536 .2298 L
.2279 .23165 L
Mistroke
.23061 .23415 L
.23549 .23997 L
.24653 .25868 L
.26663 .30509 L
.28665 .35128 L
.29213 .3615 L
.29792 .37048 L
.30285 .37649 L
.30564 .37915 L
.30827 .38116 L
.31078 .38261 L
.3122 .38322 L
.31352 .38366 L
.31462 .38392 L
.31584 .38411 L
.31711 .38418 L
.3183 .38415 L
.31961 .38398 L
.32027 .38385 L
.32099 .38367 L
.32228 .38326 L
.32347 .38277 L
.32616 .38128 L
.32903 .37913 L
.33425 .37379 L
.33918 .3672 L
.34839 .35143 L
.36674 .31179 L
.37717 .2885 L
.38691 .26899 L
.39651 .25366 L
.4019 .24728 L
.40682 .24304 L
.40951 .2414 L
.41079 .24078 L
.412 .24031 L
.41329 .23991 L
.41398 .23975 L
.41473 .23961 L
.41546 .23951 L
.41624 .23944 L
.4169 .23942 L
.41763 .23943 L
.41832 .23947 L
.41897 .23954 L
.42019 .23975 L
.42151 .2401 L
.42294 .2406 L
.42551 .24185 L
.42788 .24339 L
Mistroke
.43254 .24745 L
.43756 .25327 L
.44662 .26704 L
.46725 .30808 L
.48697 .34678 L
.49238 .35527 L
.49813 .36277 L
.50093 .36577 L
.50357 .36818 L
.50592 .36998 L
.50849 .37156 L
.5097 .37216 L
.51099 .37271 L
.51211 .37309 L
.51333 .37341 L
.51404 .37356 L
.5147 .37366 L
.516 .37379 L
.51718 .37381 L
.51844 .37373 L
.51952 .37359 L
.52068 .37334 L
.52178 .37304 L
.52278 .37269 L
.52512 .37164 L
.52758 .37017 L
.53269 .36598 L
.53744 .36079 L
.54822 .34509 L
.56697 .30991 L
.58729 .27283 L
.59269 .26502 L
.5984 .25821 L
.60328 .25372 L
.60605 .25176 L
.60865 .25032 L
.60989 .24977 L
.61125 .24928 L
.61254 .24891 L
.61373 .24866 L
.61491 .24849 L
.61598 .24842 L
.61721 .24841 L
.61837 .24849 L
.61964 .24867 L
.62028 .2488 L
.62098 .24897 L
.62339 .24976 L
.62474 .25036 L
.62619 .25112 L
Mistroke
.6288 .25278 L
.63411 .25729 L
.63901 .26271 L
.6501 .27864 L
.67024 .31469 L
.68002 .33197 L
.69054 .34789 L
.69564 .35409 L
.70048 .35889 L
.70483 .36219 L
.70729 .36361 L
.70958 .36464 L
.71073 .36504 L
.71195 .36539 L
.71259 .36554 L
.71329 .36568 L
.71452 .36585 L
.71568 .36594 L
.71693 .36595 L
.7181 .36587 L
.71917 .36574 L
.72029 .36553 L
.72131 .36528 L
.72364 .36449 L
.7257 .36355 L
.72788 .3623 L
.73266 .3587 L
.73716 .35432 L
.7474 .34122 L
.76587 .3108 L
.77633 .29292 L
.78607 .27798 L
.79576 .26615 L
.80118 .26125 L
.8061 .25803 L
.80881 .25678 L
.8101 .25632 L
.81131 .25597 L
.81262 .25567 L
.81331 .25555 L
.81405 .25545 L
.81483 .25538 L
.81557 .25534 L
.81623 .25533 L
.81695 .25535 L
.81765 .25539 L
.81831 .25545 L
.81953 .25563 L
.82085 .25591 L
.82227 .25632 L
Mistroke
.82484 .25731 L
.8272 .25852 L
.83191 .26175 L
.83696 .26634 L
.84605 .27716 L
.86673 .30919 L
.88657 .33935 L
.892 .34591 L
.89777 .35165 L
.9027 .35542 L
.9055 .35706 L
.90813 .35826 L
.91046 .35904 L
.91179 .35936 L
.91301 .35958 L
.91432 .35973 L
.9155 .35979 L
.91616 .3598 L
.91686 .35978 L
.91815 .35967 L
.91926 .35952 L
.92047 .35928 L
.92174 .35895 L
.92293 .35858 L
.92505 .35773 L
.92733 .35658 L
.93288 .35278 L
.93815 .34797 L
.94801 .33628 L
.97619 .29403 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`800?moogioo`00<Goo0P00ogooOWoo
000aOol00`00Ool0003oOommOol000aoo`8000Moo`<000Aoo`H000Aoo`@000Moo`03001oo`000?mo
ogeoo`002goo00@007ooOol000Ioo`<000Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool01000Oomoo`00AGoo1P00ogoo<Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool3
0006Ool00`00Oomoo`09Ool00`00Oomoo`04Ool40014Ool20005Ool2003oOol_Ool00003Ool00000
00D0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`05001o
ogooOol00013Ool00`00Oomoo`06Ool00`00Oomoo`3oOol/Ool000Yoo`03001oogoo009oo`03001o
ogoo00ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`05001oogooOol00012Ool0
0`00Oomoo`07Ool00`00Oomoo`3oOol/Ool000Yoo`03001oogoo009oo`03001oogoo00moo`04001o
ogooOol50007Ool00`00Oomoo`02Ool00`00Oomoo`0nOol00`00Oomoo`09Ool00`00Oomoo`14Ool3
003SOol000Yoo`03001oogoo009oo`03001oogoo00moo`05001oogooOol0000;Ool00`00Oomoo`02
Ool00`00Oomoo`0mOol00`00Oomoo`0;Ool00`00Oomoo`11Ool3000017oo00000000hGoo000;Ool0
1000Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo00=oo`03001oogoo
03]oo`03001oogoo00aoo`03001oogoo03moo`8000Moo`03001oogoo0=ioo`0037oo0P003goo1000
17oo1@001goo0`000goo00<007ooOol0>Woo00<007ooOol03Woo00<007ooOol0?Goo00<007ooOol0
27oo00<007ooOol0gGoo000aOol00`00Oomoo`04Ool00`00Oomoo`0iOol00`00Oomoo`0>Ool00`00
Oomoo`0mOol00`00Oomoo`09Ool00`00Oomoo`12Ool6002DOol0035oo`03001oogoo00Aoo`03001o
ogoo03Qoo`03001oogoo011oo`03001oogoo03]oo`03001oogoo00]oo`03001oogoo041oo`8000Eo
o`80099oo`00<Goo00<007ooOol01Goo00<007ooOol0=goo00<007ooOol04Goo00<007ooOol0>Goo
00<007ooOol03Goo00<007ooOol0?Woo00<007ooOol01goo0P00T7oo000aOol00`00Oomoo`05Ool0
0`00Oomoo`0gOol00`00Oomoo`0AOol00`00Oomoo`0iOol00`00Oomoo`0=Ool00`00Oomoo`0mOol0
0`00Oomoo`0:Ool00`00Oomoo`11Ool70015Ool0035oo`03001oogoo00Ioo`03001oogoo03Eoo`03
001oogoo01=oo`03001oogoo03Moo`03001oogoo00moo`03001oogoo03Yoo`8000ioo`03001oogoo
03ioo`8000Moo`8004=oo`00<Goo0`001Woo00<007ooOol0=Goo00<007ooOol04goo00<007ooOol0
=Woo00<007ooOol04Goo00<007ooOol0>7oo00<007ooOol03goo00<007ooOol0?7oo00<007ooOol0
2Goo00<007ooOol0@7oo000aOol00`00Oomoo`07Ool00`00Oomoo`0dOol00`00Oomoo`0DOol00`00
Oomoo`0eOol00`00Oomoo`0AOol00`00Oomoo`0gOol00`00Oomoo`0@Ool00`00Oomoo`0kOol00`00
Oomoo`0;Ool00`00Oomoo`0oOol0035oo`03001oogoo00Moo`03001oogoo03=oo`03001oogoo01Eo
o`03001oogoo03Aoo`03001oogoo01=oo`03001oogoo03Ioo`03001oogoo015oo`03001oogoo03Uo
o`03001oogoo00eoo`03001oogoo03ioo`00<Goo00<007ooOol027oo00<007ooOol0<Woo00<007oo
Ool05Woo00<007ooOol0<Woo00<007ooOol057oo00<007ooOol0=Goo00<007ooOol04Woo00<007oo
Ool0>7oo00<007ooOol03Woo00<007ooOol0?Woo000aOol00`00Oomoo`08Ool00`00Oomoo`0aOol5
0005Ool30004Ool60003Ool00`00Oomoo`0^Ool50005Ool30007Ool30005Ool00`00Oomoo`0[Ool5
0003Ool00`00Ool000020005Ool40009Ool00`00Oomoo`0XOol50005Ool300000goo001oo`02Ool4
000;Ool00`00Oomoo`0_Ool60008Ool0035oo`03001oogoo00Uoo`03001oogoo031oo`03001oo`00
00Moo`<000Eoo`05001oogooOol00003Ool00`00Oomoo`0`Ool20006Ool30008Ool00`00Oomoo`04
Ool00`00Oomoo`0]Ool00`00Oomoo`03Ool00`00Ool000020004Ool00`00Oomoo`02Ool00`00Oomo
o`07Ool00`00Oomoo`0YOol00`00Oomoo`05Ool40003Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0
0`00Oomoo`0_Ool01@00Oomoogoo000027oo000aOol30009Ool00`00Oomoo`0_Ool01000Oomoo`00
1goo0`001Woo00<007ooOol01Goo00<007ooOol0;goo0P001Woo0`0017oo1P001Woo00<007ooOol0
;7oo00<007ooOol00Woo00<007ooOol00`0017oo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool0:Goo00<007ooOol01Goo0`0017oo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol0;goo
00<007ooOol02Goo000aOol00`00Oomoo`0:Ool00`00Oomoo`0^Ool01000Oomoo`004Goo00<007oo
Ool017oo00<007ooOol0;goo00<007ooOol037oo00D007ooOomoo`0000Qoo`03001oogoo02]oo`03
001oogoo009oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo02Qoo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo031oo`03
001oogoo00Qoo`00<Goo00<007ooOol02Woo00<007ooOol0;Goo00D007ooOomoo`00019oo`03001o
ogoo00Aoo`03001oogoo02ioo`03001oogoo00eoo`04001oogoo0008Ool00`00Oomoo`0[Ool01@00
Oomoogoo00002Woo0P000goo00<007ooOol027oo00<007ooOol0:7oo00<007ooOol01Woo00<007oo
Ool017oo10003Woo00<007ooOol0<7oo00<007ooOol01goo000aOol00`00Oomoo`0;Ool00`00Oomo
o`0/Ool01@00Oomoogoo00004goo00<007ooOol00goo00<007ooOol0;Goo0P0047oo00<007oo0000
2Goo00<007ooOol0:Woo00D007ooOomoo`0000Yoo`03001oo`00008000aoo`03001oogoo02Moo`03
001oogoo00Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00aoo`03001oogoo031oo`03
001oogoo00Ioo`00<Goo00<007ooOol02goo00<007ooOol0:goo00<007ooOol00Woo00<007ooOol0
4Goo00<007ooOol017oo00<007ooOol0;7oo0P0047oo00<007oo00002Goo00<007ooOol0:Woo00@0
07ooOol000aoo`03001oogoo00eoo`03001oogoo02Moo`03001oogoo00Eoo`03001oogoo00Aoo`03
001oogoo009oo`03001oogoo00aoo`03001oogoo031oo`03001oogoo00Ioo`00<Goo00<007ooOol0
37oo00<007ooOol0:Woo00<007ooOol00`003Woo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0:goo0`004Goo0P002Woo00<007ooOol09goo0`000Woo00<007ooOol02Woo0P003goo00<007oo
Ool097oo0`001Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol0:Woo
00<007ooOol00Woo00<007ooOol01Woo000aOol00`00Oomoo`0<Ool00`00Oomoo`0YOol00`00Oomo
o`02Ool2000?Ool40008Ool00`00Oomoo`0ZOol3000BOol00`00Oomoo`08Ool00`00Oomoo`0XOol2
00000goo001oo`0>Ool3000=Ool00`00Oomoo`0TOol20005Ool00`00Oomoo`07Ool4000@Ool00`00
Oomoo`0[Ool40009Ool0035oo`<000eoo`03001oogoo02Qoo`03001oogoo01moo`03001oogoo02Uo
o`03001oogoo01moo`03001oogoo02Uoo`03001oogoo01ioo`03001oogoo02]oo`03001oogoo01ao
o`03001oogoo02aoo`03001oogoo00Qoo`00<Goo00<007ooOol03Goo00<007ooOol09goo00<007oo
Ool087oo00<007ooOol0:Goo00<007ooOol07goo00<007ooOol0:Goo00<007ooOol07goo00<007oo
Ool0:Goo00<007ooOol07Woo00<007ooOol0:goo00<007ooOol027oo000aOol00`00Oomoo`0=Ool0
0`00Oomoo`0WOol00`00Oomoo`0QOol00`00Oomoo`0WOol00`00Oomoo`0QOol00`00Oomoo`0WOol0
0`00Oomoo`0POol00`00Oomoo`0YOol00`00Oomoo`0NOol00`00Oomoo`0ZOol00`00Oomoo`09Ool0
035oo`03001oogoo00ioo`03001oogoo02Ioo`03001oogoo025oo`03001oogoo02Moo`03001oogoo
029oo`03001oogoo02Ioo`03001oogoo025oo`03001oogoo02Moo`03001oogoo021oo`03001oogoo
02Qoo`03001oogoo00Yoo`00<Goo00<007ooOol03Woo00<007ooOol09Goo00<007ooOol08goo00<0
07ooOol09Woo00<007ooOol08Woo00<007ooOol09Goo00<007ooOol08Woo00<007ooOol09Woo00<0
07ooOol08Goo00<007ooOol0:7oo00<007ooOol02Woo000aOol00`00Oomoo`0>Ool00`00Oomoo`0U
Ool00`00Oomoo`0SOol00`00Oomoo`0UOol00`00Oomoo`0TOol00`00Oomoo`0TOol00`00Oomoo`0S
Ool00`00Oomoo`0UOol00`00Oomoo`0ROol00`00Oomoo`0VOol00`00Oomoo`0;Ool002Qoool008T0
0000<Goo00<007ooOol03goo0P004Woo00<007ooOol03goo00<007ooOol047oo00<007ooOol03goo
00@007ooOol000moo`03001oogoo011oo`04001oogoo000>Ool00`00Oomoo`0@Ool00`00Oomoo`04
Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0@
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`05
Ool00`00Oomoo`0?Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`0;
Ool01@00Oomoogoo00002Woo000aOol00`00Oomoo`0?Ool00`00Oomoo`0SOol00`00Oomoo`0@Ool0
0`00Oomoo`0COol00`00Oomoo`0ROol00`00Oomoo`0<Ool00`00Oomoo`0GOol00`00Oomoo`0QOol0
0`00Oomoo`09Ool00`00Oomoo`0KOol00`00Oomoo`0QOol00`00Oomoo`06Ool00`00Oomoo`0MOol0
0`00Oomoo`0ROol00`00Oomoo`02Ool00`00Oomoo`08Ool0035oo`03001oogoo011oo`03001oogoo
029oo`03001oogoo02Ioo`03001oogoo025oo`03001oogoo02Qoo`03001oogoo021oo`03001oogoo
02Moo`03001oogoo025oo`03001oogoo02Moo`03001oogoo021oo`03001oogoo00ioo`00<Goo00<0
07ooOol047oo00<007ooOol08Goo00<007ooOol09goo00<007ooOol08Goo00<007ooOol0:7oo00<0
07ooOol07goo00<007ooOol0:Goo00<007ooOol07goo00<007ooOol0:Goo00<007ooOol07Woo00<0
07ooOol03goo000aOol00`00Oomoo`0@Ool00`00Oomoo`0QOol00`00Oomoo`0XOol00`00Oomoo`0O
Ool00`00Oomoo`0ZOol00`00Oomoo`0NOol00`00Oomoo`0YOol00`00Oomoo`0NOol00`00Oomoo`0Z
Ool00`00Oomoo`0NOol00`00Oomoo`0?Ool0035oo`<0015oo`03001oogoo01moo`03001oogoo02Uo
o`03001oogoo01moo`03001oogoo02Yoo`03001oogoo01eoo`03001oogoo02]oo`03001oogoo01eo
o`03001oogoo02]oo`03001oogoo01aoo`03001oogoo011oo`00<Goo00<007ooOol04Goo00<007oo
Ool07goo00<007ooOol0:Woo00<007ooOol07Goo00<007ooOol0;7oo00<007ooOol077oo00<007oo
Ool0;7oo00<007ooOol06goo00<007ooOol0;Goo00<007ooOol06Woo00<007ooOol04Goo000aOol0
0`00Oomoo`0AOol00`00Oomoo`0OOol00`00Oomoo`0ZOol00`00Oomoo`0MOol00`00Oomoo`0/Ool0
0`00Oomoo`0KOol00`00Oomoo`0]Ool00`00Oomoo`0KOol00`00Oomoo`0]Ool00`00Oomoo`0JOol0
0`00Oomoo`0AOol0035oo`03001oogoo019oo`03001oogoo01eoo`03001oogoo02aoo`03001oogoo
01]oo`03001oogoo02eoo`03001oogoo01]oo`03001oogoo02ioo`03001oogoo01Uoo`03001oogoo
02moo`03001oogoo01Qoo`03001oogoo019oo`00<Goo00<007ooOol04Woo00<007ooOol07Goo00<0
07ooOol0;7oo00<007ooOol06goo00<007ooOol0;Woo00<007ooOol06Goo00<007ooOol0;goo00<0
07ooOol067oo00<007ooOol0<Goo00<007ooOol05Woo00<007ooOol04goo000aOol00`00Oomoo`0B
Ool00`00Oomoo`0LOol00`00Oomoo`0^Ool00`00Oomoo`0JOol00`00Oomoo`0^Ool00`00Oomoo`0I
Ool00`00Oomoo`0`Ool00`00Oomoo`0GOol00`00Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`0C
Ool0035oo`<001=oo`03001oogoo01]oo`03001oogoo02ioo`03001oogoo01Uoo`03001oogoo031o
o`03001oogoo01Moo`03001oogoo039oo`03001oogoo01Eoo`03001oogoo03=oo`03001oogoo01Ao
o`03001oogoo01Aoo`00<Goo00<007ooOol04goo00<007ooOol06Woo00<007ooOol0;goo00<007oo
Ool06Goo00<007ooOol0<7oo00<007ooOol05goo00<007ooOol0<Woo00<007ooOol05Goo00<007oo
Ool0=7oo00<007ooOol04Woo00<007ooOol05Goo000aOol00`00Oomoo`0COol00`00Oomoo`0JOol0
0`00Oomoo`0`Ool00`00Oomoo`0GOol00`00Oomoo`0bOol00`00Oomoo`0EOol00`00Oomoo`0dOol0
0`00Oomoo`0COol00`00Oomoo`0fOol2000AOol00`00Oomoo`0FOol0035oo`03001oogoo01Aoo`03
001oogoo01Uoo`03001oogoo031oo`03001oogoo01Moo`03001oogoo039oo`03001oogoo01Eoo`03
001oogoo03Eoo`03001oogoo015oo`03001oogoo03Uoo`03001oogoo00eoo`03001oogoo01Moo`00
<Goo00<007ooOol057oo00<007ooOol067oo00<007ooOol0<Woo00<007ooOol05Goo00<007ooOol0
=7oo00<007ooOol04goo00<007ooOol0=goo00<007ooOol03goo00<007ooOol0>goo00<007ooOol0
2goo00<007ooOol067oo000aOol00`00Oomoo`0EOol00`00Oomoo`0GOol00`00Oomoo`0bOol00`00
Oomoo`0EOol00`00Oomoo`0dOol00`00Oomoo`0BOol00`00Oomoo`0iOol00`00Oomoo`0=Ool00`00
Oomoo`0mOol00`00Oomoo`08Ool2000KOol0035oo`<001Eoo`03001oogoo01Ioo`03001oogoo03Ao
o`03001oogoo01=oo`03001oogoo03Ioo`03001oogoo015oo`03001oogoo03Yoo`03001oogoo00]o
o`03001oogoo03moo`8000Moo`03001oogoo01]oo`00<Goo00<007ooOol05Goo00<007ooOol05Woo
00<007ooOol0=7oo00<007ooOol04goo00<007ooOol0=goo00<007ooOol03goo00<007ooOol0?7oo
00<007ooOol027oo0P00A7oo1`007Woo000aOol00`00Oomoo`0FOol00`00Oomoo`0DOol00`00Oomo
o`0fOol00`00Oomoo`0AOol00`00Oomoo`0iOol00`00Oomoo`0=Ool00`00Oomoo`0nOol00`00Oomo
o`06Ool00`00Oomoo`1YOol0035oo`03001oogoo01Ioo`03001oogoo01Aoo`03001oogoo03Ioo`03
001oogoo015oo`03001oogoo03Yoo`03001oogoo00]oo`03001oogoo041oo`<000Aoo`03001oogoo
06Yoo`00<Goo00<007ooOol05goo00<007ooOol04goo00<007ooOol0=goo00<007ooOol03goo00<0
07ooOol0?7oo00<007ooOol027oo0P00AGoo1@00KGoo000aOol00`00Oomoo`0HOol00`00Oomoo`0A
Ool00`00Oomoo`0hOol00`00Oomoo`0?Ool00`00Oomoo`0mOol20007Ool00`00Oomoo`2gOol0035o
o`<001Qoo`03001oogoo015oo`03001oogoo03Uoo`03001oogoo00eoo`03001oogoo041oo`8000=o
o`800;Yoo`00<Goo00<007ooOol06Goo00<007ooOol03goo00<007ooOol0>goo00<007ooOol02goo
00<007ooOol0@Woo1@00^goo000aOol00`00Oomoo`0IOol00`00Oomoo`0?Ool00`00Oomoo`0lOol0
0`00Oomoo`09Ool00`00Oomoo`3oOol4Ool000aoo`8000Moo`<000Aoo`H000Aoo`@000Moo`03001o
ogoo01Yoo`03001oogoo00eoo`03001oogoo03ioo`03001oogoo00Ioo`800?moo`Moo`002goo00@0
07ooOol000Ioo`<000Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`0JOol00`00Oomoo`0=Ool00`00Oomoo`0oOol20004Ool2003oOol9Ool000Yoo`03001oogoo
009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo01]oo`03
001oogoo00]oo`03001oogoo049oo`D00?moo`Yoo`002Woo00<007ooOol00Woo00<007ooOol03Goo
00<007ooOol027oo00<007ooOol017oo10006Woo00<007ooOol02goo00<007ooOol0ogooDGoo000:
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`0LOol00`00Oomoo`09Ool00`00Oomoo`3oOomBOol000Yoo`03001oogoo009oo`03
001oogoo00moo`04001oogooOol50007Ool00`00Oomoo`0MOol00`00Oomoo`07Ool00`00Oomoo`3o
OomCOol000Yoo`03001oogoo009oo`03001oogoo00moo`05001oogooOol0000;Ool00`00Oomoo`0N
Ool20006Ool00`00Oomoo`3oOomDOol000]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomo
ogoo00002goo00<007ooOol07goo1`00ogooEgoo000<Ool2000?Ool40004Ool50007Ool00`00Oomo
o`0ROol00`00Oomoo`3oOomHOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol001Eo
o`8000Moo`<000Eoo`@000Moo`03001oogoo0?moogeoo`0057oo00@007ooOol000Ioo`<000Aoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007oo
Ool00goo0`002Goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00
Oomoo`0?Ool00`00Oomoo`04Ool4003oOomlOol001=oo`03001oogoo009oo`03001oogoo00Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007oo
Ool02Woo1@001goo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo000=Ool00`00Oomoo`09Ool00`00Oomo
o`3oOommOol001Eoo`8000ioo`D000Moo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool30006Ool00`00Oomo
o`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogaoo`002Woo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0ogooOGoo000:
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`D0
00Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000Oomoo`003Goo00<007ooOol00Woo00D0
07ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P003Woo1P000goo1@001goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000VOol50006Ool00`00Oomo
o`3oOommOol002Qoo`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo1000
ogooO7oo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0
ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Ioo`<00?moohQoo`009goo0P00ogooR7oo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .38231 m
.04262 .31391 L
.0522 .27612 L
.06244 .2424 L
.06525 .2352 L
.0679 .22936 L
.07047 .22465 L
.07286 .22119 L
.07511 .21874 L
.07625 .21781 L
.07751 .21704 L
.07876 .21652 L
.07947 .21634 L
.08011 .21625 L
.08136 .21626 L
.08255 .21651 L
.08327 .21677 L
.08394 .2171 L
.0852 .21789 L
.08655 .21903 L
.08801 .22059 L
.09066 .22422 L
.09308 .22846 L
.09867 .24123 L
.10458 .25857 L
.12444 .33053 L
.13312 .35946 L
.13769 .37209 L
.14255 .38284 L
.14503 .38713 L
.14776 .39085 L
.14895 .39215 L
.15024 .3933 L
.15146 .39416 L
.15257 .39475 L
.15371 .39517 L
.15478 .39537 L
.15595 .3954 L
.15719 .39519 L
.15851 .39473 L
.15974 .39405 L
.16086 .39324 L
.16206 .39217 L
.16458 .38924 L
.16735 .38502 L
.17294 .37348 L
.18298 .34483 L
.19379 .30774 L
.20406 .27331 L
.21327 .24828 L
Mistroke
.21579 .24293 L
.21848 .23808 L
.22083 .23459 L
.22332 .2317 L
.22457 .23057 L
.22595 .22957 L
.2272 .2289 L
.22836 .22848 L
.22907 .22831 L
.22974 .22823 L
.23099 .22823 L
.2317 .22833 L
.23235 .22849 L
.23306 .22873 L
.23381 .22906 L
.23498 .22973 L
.23624 .23066 L
.23851 .23289 L
.24121 .23644 L
.24369 .24049 L
.25268 .26085 L
.26214 .28912 L
.27244 .32274 L
.28215 .35172 L
.28638 .36228 L
.29086 .37154 L
.2932 .37549 L
.29578 .37908 L
.29812 .38162 L
.3003 .38335 L
.30152 .38404 L
.30221 .38435 L
.30284 .38457 L
.30401 .38485 L
.30526 .38493 L
.30636 .38484 L
.30741 .3846 L
.30855 .38417 L
.30978 .38352 L
.31101 .38266 L
.31236 .38151 L
.31508 .37848 L
.31995 .37088 L
.3252 .35988 L
.33081 .34554 L
.34091 .31555 L
.35114 .28455 L
.35653 .26986 L
.36223 .25661 L
.36722 .24756 L
Mistroke
.37006 .24361 L
.37271 .24077 L
.37396 .23973 L
.37514 .23892 L
.37621 .23834 L
.37737 .23787 L
.37863 .23756 L
.37933 .23747 L
.37997 .23744 L
.38121 .23753 L
.38238 .2378 L
.38354 .23823 L
.38479 .23888 L
.38704 .24054 L
.38971 .2433 L
.39215 .24652 L
.39745 .25568 L
.40247 .26671 L
.42095 .3181 L
.43061 .34428 L
.43591 .35629 L
.44087 .36537 L
.44509 .37113 L
.44746 .37351 L
.44963 .37512 L
.4508 .37576 L
.45188 .37621 L
.45307 .37654 L
.45434 .37671 L
.45498 .37672 L
.45568 .37668 L
.45694 .37646 L
.45817 .37606 L
.4593 .37553 L
.46055 .37477 L
.46174 .37389 L
.46398 .37179 L
.469 .36513 L
.47335 .3574 L
.47808 .34722 L
.49872 .29239 L
.50361 .2799 L
.50889 .26788 L
.51354 .25901 L
.51845 .25178 L
.52119 .2488 L
.52264 .24754 L
.52419 .24646 L
.52562 .2457 L
.52692 .2452 L
Mistroke
.52823 .24489 L
.52947 .24478 L
.53067 .24484 L
.53195 .24509 L
.53305 .24544 L
.53425 .24598 L
.53554 .24674 L
.53693 .24776 L
.53944 .25013 L
.54468 .25709 L
.54954 .26576 L
.56056 .29114 L
.58065 .34175 L
.58572 .35202 L
.58839 .35664 L
.59121 .36085 L
.59368 .36394 L
.59639 .36664 L
.59759 .36758 L
.59886 .36843 L
.59998 .36904 L
.60116 .36953 L
.60241 .36989 L
.60356 .37007 L
.60479 .37011 L
.6055 .37006 L
.60616 .36996 L
.60735 .36967 L
.60844 .36927 L
.60963 .36868 L
.61089 .3679 L
.61309 .36616 L
.61513 .3641 L
.61977 .35799 L
.62481 .34929 L
.63029 .3379 L
.64022 .31405 L
.64982 .29041 L
.6588 .27117 L
.66336 .26337 L
.66826 .25691 L
.67105 .25421 L
.67242 .25316 L
.6737 .25235 L
.67495 .25172 L
.67608 .25128 L
.67733 .25095 L
.67802 .25084 L
.67867 .25078 L
.67989 .25078 L
Mistroke
.68059 .25085 L
.68123 .25096 L
.68254 .25131 L
.68327 .25158 L
.68394 .25187 L
.68643 .25336 L
.68878 .25533 L
.69402 .26151 L
.69971 .27077 L
.71912 .31402 L
.72943 .33714 L
.73484 .34733 L
.73779 .35206 L
.74053 .35585 L
.74318 .35892 L
.74559 .36116 L
.74826 .36302 L
.74973 .36375 L
.75039 .36401 L
.75112 .36425 L
.75229 .36453 L
.75354 .36467 L
.75469 .36467 L
.75577 .36455 L
.75704 .36426 L
.7582 .36386 L
.75954 .36323 L
.76081 .36248 L
.7631 .36075 L
.76554 .3584 L
.76992 .3529 L
.77984 .33547 L
.7995 .29185 L
.80811 .27493 L
.81299 .26725 L
.81538 .26413 L
.81754 .2617 L
.81972 .25965 L
.82209 .25789 L
.82339 .25715 L
.82458 .25659 L
.82573 .25619 L
.82695 .2559 L
.82812 .25575 L
.82938 .25573 L
.83057 .25585 L
.83166 .25608 L
.83294 .25648 L
.83433 .25709 L
.83686 .25866 L
Mistroke
.8396 .26099 L
.84209 .26365 L
.84767 .27132 L
.8577 .28982 L
.86785 .31171 L
.87857 .33396 L
.88299 .34183 L
.88773 .34898 L
.89045 .35237 L
.89293 .35496 L
.89523 .35692 L
.89654 .35783 L
.89778 .35855 L
.89902 .35915 L
.90016 .35957 L
.90139 .3599 L
.9027 .36009 L
.90376 .36014 L
.90492 .36007 L
.90613 .35988 L
.90726 .35957 L
.90861 .35907 L
.90988 .35844 L
.91225 .3569 L
.91481 .35471 L
.91758 .35176 L
.92734 .33717 L
.93633 .31968 L
.94615 .29916 L
.9567 .27928 L
.9618 .27159 L
.96432 .26843 L
.96665 .26591 L
.96893 .26385 L
.971 .26234 L
.9733 .26108 L
.97456 .26058 L
.97574 .26023 L
.97619 .26014 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3000COol2003oOomXOol0035oo`03001oogoo015oo`80009o
o`800?moofIoo`00<Goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol0ogooI7oo000aOol0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`3oOomSOol000aoo`8000Moo`<000Aoo`H000Ao
o`@000Moo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo0?moof=oo`002goo00@007ooOol0
00Ioo`<000Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0?
Ool00`00Oomoo`06Ool00`00Oomoo`0bOol3003oOol]Ool000Yoo`03001oogoo009oo`03001oogoo
00=oo`<000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`@000ioo`03001oogoo00Ioo`03001oogoo
031oo`8000=oo`03001oogoo0?moobYoo`0000=oo`0000001@000Woo00<007ooOol00Woo00<007oo
Ool03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol03Woo00<007ooOol027oo00<007oo
Ool0;goo00<007ooOol00goo00<007ooOol0ogoo:Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`09
Ool00`00Oomoo`0]Ool00`00Oomoo`05Ool00`00Oomoo`3oOolXOol000Yoo`03001oogoo009oo`03
001oogoo00moo`04001oogooOol50007Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0/
Ool00`00Oomoo`06Ool00`00Oomoo`0bOol4003aOol000Yoo`03001oogoo009oo`03001oogoo00mo
o`05001oogooOol0000;Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomo
o`07Ool00`00Oomoo`0`Ool00`00Oomoo`02Ool00`00Oomoo`3^Ool000]oo`04001oogoo000=Ool0
0`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
:Woo00<007ooOol027oo00<007ooOol0;goo00<007ooOol017oo00<007ooOol0=7oo00<007ooOol0
]Woo000<Ool2000?Ool40004Ool50007Ool3000<Ool00`00Oomoo`0<Ool00`00Oomoo`0ZOol00`00
Oomoo`09Ool00`00Oomoo`0]Ool00`00Oomoo`06Ool00`00Oomoo`0aOol5002fOol0035oo`03001o
ogoo00aoo`03001oogoo00eoo`03001oogoo02Qoo`03001oogoo00Yoo`03001oogoo02aoo`03001o
ogoo00Moo`03001oogoo02moo`8000Eoo`03001oogoo0;=oo`00<Goo00<007ooOol02goo00<007oo
Ool03Woo00<007ooOol0:7oo00<007ooOol02goo00<007ooOol0:goo00<007ooOol027oo00<007oo
Ool0;Goo00<007ooOol01Woo00<007ooOol0<Goo1@00O7oo000aOol00`00Oomoo`0;Ool00`00Oomo
o`0>Ool00`00Oomoo`0XOol00`00Oomoo`0;Ool00`00Oomoo`0ZOol00`00Oomoo`09Ool00`00Oomo
o`0]Ool00`00Oomoo`07Ool00`00Oomoo`0_Ool20004Ool00`00Oomoo`1iOol0035oo`03001oogoo
00]oo`03001oogoo00moo`03001oogoo02Ioo`03001oogoo00eoo`03001oogoo02Uoo`03001oogoo
00Yoo`03001oogoo02]oo`03001oogoo00Uoo`03001oogoo02eoo`03001oogoo00Eoo`03001oogoo
039oo`D0045oo`00<Goo00<007ooOol02Woo00<007ooOol047oo00<007ooOol09Woo00<007ooOol0
3Goo00<007ooOol0:Goo00<007ooOol02Woo00<007ooOol0:goo00<007ooOol02Goo00<007ooOol0
;Goo00<007ooOol01Woo00<007ooOol0;goo0P001Goo00<007ooOol0<goo00<007ooOol027oo000a
Ool3000:Ool00`00Oomoo`0@Ool00`00Oomoo`0VOol00`00Oomoo`0>Ool00`00Oomoo`0WOol00`00
Oomoo`0<Ool00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Oomoo`0[Ool00`00Oomoo`08Ool00`00
Oomoo`0]Ool00`00Oomoo`06Ool00`00Oomoo`0`Ool3000:Ool0035oo`03001oogoo00Yoo`03001o
ogoo011oo`03001oogoo02Eoo`03001oogoo00moo`03001oogoo02Ioo`03001oogoo00eoo`03001o
ogoo02Uoo`03001oogoo00]oo`03001oogoo02Yoo`03001oogoo00Uoo`03001oogoo02aoo`03001o
ogoo00Qoo`03001oogoo02ioo`03001oogoo00]oo`00<Goo00<007ooOol02Goo00<007ooOol04Woo
00<007ooOol097oo00<007ooOol03goo00<007ooOol09Woo00<007ooOol03Woo00<007ooOol0:7oo
00<007ooOol037oo00<007ooOol0:Goo00<007ooOol02Woo00<007ooOol0:Woo00<007ooOol02Goo
00<007ooOol0;Goo00<007ooOol037oo000aOol00`00Oomoo`09Ool00`00Oomoo`0BOol00`00Oomo
o`0TOol00`00Oomoo`0@Ool00`00Oomoo`0TOol00`00Oomoo`0?Ool00`00Oomoo`0WOol00`00Oomo
o`0=Ool00`00Oomoo`0XOol00`00Oomoo`0;Ool00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Oomo
o`0/Ool00`00Oomoo`0<Ool0035oo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo01]oo`D0
00=oo`03001oo`00008000Aoo`H000Eoo`03001oogoo02Aoo`03001oogoo00Eoo`D000Eoo`<000Mo
o`<001eoo`03001oogoo00ioo`03001oogoo009oo`D000Eoo`<000Eoo`@000ioo`03001oogoo00eo
o`03001oogoo01=oo`D000Eoo`<000Eoo`@000ioo`03001oogoo02Yoo`03001oo`0000D000Qoo`00
<Goo00<007ooOol027oo00<007ooOol057oo00<007ooOol077oo00<007ooOol00goo00<007oo0000
0P001Goo00D007ooOomoo`0000Eoo`03001oogoo02=oo`03001oogoo00Qoo`03001oogoo00Eoo`<0
00Qoo`03001oogoo01]oo`03001oogoo00moo`03001oogoo00Aoo`03001oogoo00Eoo`<000Aoo`03
001oogoo009oo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo01Eoo`03001oogoo00Eoo`<0
00Aoo`04001oogooOol2000=Ool00`00Oomoo`0ZOol01000Oomoo`000goo00<007ooOol01Woo000a
Ool30008Ool00`00Oomoo`0DOol00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Ool000020006Ool0
0`00Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`08Ool00`00Oomoo`05Ool30004Ool6000LOol0
0`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`05Ool30004Ool00`00Oomoo`02Ool00`00Oomo
o`0:Ool00`00Oomoo`0?Ool00`00Oomoo`0DOol00`00Oomoo`05Ool30004Ool01000Oomoogoo0P00
3Woo00<007ooOol0:7oo00<007ooOol00Woo00<007ooOol02Goo000aOol00`00Oomoo`08Ool00`00
Oomoo`0DOol00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00`00
Oomoo`0ROol00`00Oomoo`08Ool00`00Oomoo`07Ool00`00Oomoo`02Ool01@00Oomoogoo000077oo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol037oo00<007ooOol00Woo00<007ooOol02Woo
00<007ooOol03goo00<007ooOol057oo00<007ooOol037oo00H007ooOol007oo000>Ool00`00Oomo
o`0WOol00`00Oomoo`04Ool00`00Oomoo`08Ool0035oo`03001oogoo00Qoo`03001oogoo01Aoo`03
001oogoo01aoo`03001oogoo009oo`03001oogoo00]oo`03001oogoo00Eoo`03001oogoo025oo`03
001oogoo00Uoo`03001oogoo00Moo`03001oogoo00=oo`04001oogoo000LOol00`00Oomoo`0AOol0
0`00Oomoo`03Ool00`00Oomoo`0<Ool20003Ool00`00Oomoo`09Ool00`00Oomoo`0AOol00`00Oomo
o`0COol00`00Oomoo`0=Ool4000@Ool00`00Oomoo`0VOol00`00Oomoo`05Ool00`00Oomoo`07Ool0
035oo`03001oogoo00Moo`03001oogoo01Ioo`03001oogoo01]oo`03001oogoo009oo`03001oogoo
00aoo`03001oogoo00Aoo`03001oogoo025oo`03001oogoo00Uoo`03001oogoo00Moo`03001oogoo
00Aoo`03001oo`0001]oo`03001oogoo01=oo`03001oogoo009oo`03001oogoo00aoo`03001oo`00
008000aoo`03001oogoo015oo`03001oogoo01=oo`03001oogoo00aoo`03001oo`00009oo`03001o
ogoo00ioo`03001oogoo02Aoo`03001oogoo00Moo`03001oogoo00Ioo`00<Goo00<007ooOol01goo
00<007ooOol05Woo00<007ooOol06goo00<007ooOol00Woo00<007ooOol037oo00<007ooOol01Goo
00<007ooOol087oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol00goo00<007oo00006goo
00<007ooOol04goo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol04Woo
00<007ooOol04Woo00<007ooOol037oo0P000goo00<007ooOol03Woo00<007ooOol08goo00<007oo
Ool027oo00<007ooOol01Woo000aOol00`00Oomoo`07Ool00`00Oomoo`0FOol00`00Oomoo`0IOol3
0003Ool00`00Oomoo`08Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`0OOol00`00Oomo
o`08Ool3000:Ool00`00Oomoo`04Ool2000KOol00`00Oomoo`0COol00`00Oomoo`03000?Ool2000=
Ool00`00Oomoo`0COol00`00Oomoo`0@Ool3000>Ool20003Ool00`00Oomoo`0?Ool00`00Oomoo`0R
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0035oo`03001oogoo00Moo`03001o
ogoo01Moo`03001oogoo01Uoo`8000=oo`03001oogoo00Uoo`@000Qoo`03001oogoo01moo`03001o
ogoo00Uoo`8000Yoo`03001oogoo00Eoo`03001oogoo01Qoo`03001oogoo01Eoo`03001oogoo0080
015oo`<000Yoo`03001oogoo01Aoo`03001oogoo011oo`8000ioo`D0019oo`03001oogoo025oo`03
001oogoo00Eoo`@000Uoo`00<Goo0`001goo00<007ooOol05goo00<007ooOol07Woo00<007ooOol0
5Goo00<007ooOol07goo00<007ooOol05Woo00<007ooOol07goo00<007ooOol05Goo00<007ooOol0
7goo00<007ooOol05Goo00<007ooOol087oo00<007ooOol05Goo00<007ooOol087oo00<007ooOol0
4Woo000aOol00`00Oomoo`06Ool00`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0GOol00`00
Oomoo`0MOol00`00Oomoo`0GOol00`00Oomoo`0NOol00`00Oomoo`0GOol00`00Oomoo`0NOol00`00
Oomoo`0EOol00`00Oomoo`0OOol00`00Oomoo`0FOol00`00Oomoo`0OOol00`00Oomoo`0COol0035o
o`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo01eoo`03001oogoo01Moo`03001oogoo01eo
o`03001oogoo01Moo`03001oogoo01ioo`03001oogoo01Moo`03001oogoo01ioo`03001oogoo01Io
o`03001oogoo01ioo`03001oogoo01Moo`03001oogoo01eoo`03001oogoo01Aoo`00<Goo00<007oo
Ool01Woo00<007ooOol06Goo00<007ooOol077oo00<007ooOol05goo00<007ooOol07Goo00<007oo
Ool067oo00<007ooOol07Goo00<007ooOol05goo00<007ooOol07Goo00<007ooOol05goo00<007oo
Ool07Woo00<007ooOol05goo00<007ooOol07Goo00<007ooOol057oo000aOol00`00Oomoo`06Ool0
0`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0IOol00`00Oomoo`0KOol00`00Oomoo`0IOol0
0`00Oomoo`0LOol00`00Oomoo`0IOol00`00Oomoo`0LOol00`00Oomoo`0HOol00`00Oomoo`0LOol0
0`00Oomoo`0HOol00`00Oomoo`0LOol00`00Oomoo`0EOol0035oo`03001oogoo00Ioo`03001oogoo
01Uoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo
01aoo`03001oogoo01Uoo`03001oogoo01]oo`03001oogoo01Uoo`03001oogoo01aoo`03001oogoo
01Uoo`03001oogoo01]oo`03001oogoo01Eoo`00:7ooo`00R@00000aOol00`00Oomoo`05Ool00`00
Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00
Oomoo`0?Ool01000Oomoo`003goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol03goo00<0
07ooOol00Woo00<007ooOol02goo00<007ooOol037oo00@007ooOol0019oo`03001oogoo00Eoo`03
001oogoo00Moo`03001oogoo011oo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo011oo`03001oo`0000moo`03001oogoo00]oo`03001oogoo009oo`03001oogoo011oo`05
001oogooOol0000=Ool00`00Oomoo`08Ool0035oo`03001oogoo00Eoo`03001oogoo01]oo`03001o
ogoo01Uoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo01Uoo`03001oogoo01Ioo`03001o
ogoo009oo`03001oogoo01Yoo`03001oogoo01aoo`03001oogoo00Ioo`03001oogoo00moo`03001o
ogoo01aoo`03001oogoo01Moo`8001ioo`03001oogoo01Uoo`03001oogoo00]oo`03001oogoo00Qo
o`00<Goo00<007ooOol01Goo00<007ooOol06goo00<007ooOol06Goo00<007ooOol06goo00<007oo
Ool06Goo00<007ooOol077oo00<007ooOol067oo00<007ooOol07Goo00<007ooOol067oo00<007oo
Ool077oo00<007ooOol067oo00<007ooOol07Goo00<007ooOol067oo00<007ooOol05Woo000aOol0
0`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`0LOol00`00Oomoo`0GOol0
0`00Oomoo`0MOol00`00Oomoo`0HOol00`00Oomoo`0MOol00`00Oomoo`0GOol00`00Oomoo`0NOol0
0`00Oomoo`0GOol00`00Oomoo`0MOol00`00Oomoo`0GOol00`00Oomoo`0GOol0035oo`03001oogoo
00Aoo`03001oogoo01eoo`03001oogoo01Qoo`03001oogoo01aoo`03001oogoo01Moo`03001oogoo
01ioo`03001oogoo01Moo`03001oogoo01ioo`03001oogoo01Ioo`03001oogoo01ioo`03001oogoo
01Ioo`03001oogoo01moo`03001oogoo01Ioo`03001oogoo01Moo`00<Goo0`0017oo00<007ooOol0
7Goo00<007ooOol05goo00<007ooOol07Goo00<007ooOol05goo00<007ooOol07Woo00<007ooOol0
5Woo00<007ooOol07goo00<007ooOol05Goo00<007ooOol087oo00<007ooOol05Goo00<007ooOol0
7goo00<007ooOol05Goo00<007ooOol067oo000aOol00`00Oomoo`03Ool00`00Oomoo`0OOol00`00
Oomoo`0FOol00`00Oomoo`0NOol00`00Oomoo`0EOol00`00Oomoo`0OOol00`00Oomoo`0FOol00`00
Oomoo`0POol00`00Oomoo`0DOol00`00Oomoo`0POol00`00Oomoo`0DOol00`00Oomoo`0QOol00`00
Oomoo`0DOol00`00Oomoo`0HOol0035oo`03001oogoo00=oo`03001oogoo01moo`03001oogoo01Io
o`03001oogoo01ioo`03001oogoo01Eoo`03001oogoo021oo`03001oogoo01Aoo`03001oogoo025o
o`03001oogoo01Aoo`03001oogoo021oo`03001oogoo01Aoo`03001oogoo025oo`03001oogoo01=o
o`03001oogoo01Uoo`00<Goo00<007ooOol00goo00<007ooOol07goo00<007ooOol05Goo00<007oo
Ool07goo00<007ooOol05Goo00<007ooOol087oo00<007ooOol057oo00<007ooOol08Woo00<007oo
Ool04Woo00<007ooOol08Woo00<007ooOol04goo00<007ooOol08Woo00<007ooOol04Goo00<007oo
Ool06Woo000aOol00`00Oomoo`02Ool00`00Oomoo`0POol00`00Oomoo`0EOol00`00Oomoo`0POol0
0`00Oomoo`0COol00`00Oomoo`0ROol00`00Oomoo`0COol00`00Oomoo`0ROol00`00Oomoo`0BOol0
0`00Oomoo`0ROol00`00Oomoo`0BOol00`00Oomoo`0SOol00`00Oomoo`0AOol00`00Oomoo`0JOol0
035oo`03001oogoo009oo`03001oogoo025oo`03001oogoo01Aoo`03001oogoo021oo`03001oogoo
01=oo`03001oogoo029oo`03001oogoo019oo`03001oogoo02=oo`03001oogoo015oo`03001oogoo
02Aoo`03001oogoo015oo`03001oogoo02Aoo`03001oogoo00moo`03001oogoo01]oo`00<Goo0`00
0Woo00<007ooOol08Goo00<007ooOol057oo00<007ooOol087oo00<007ooOol04goo00<007ooOol0
8Woo00<007ooOol04Woo00<007ooOol097oo00<007ooOol047oo00<007ooOol097oo00<007ooOol0
47oo00<007ooOol09Woo00<007ooOol03Woo00<007ooOol06goo000aOol00`00Oomoo`02Ool00`00
Oomoo`0QOol00`00Oomoo`0COol00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00
Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomoo`0?Ool00`00
Oomoo`0VOol00`00Oomoo`0=Ool00`00Oomoo`0LOol0035oo`05001oogooOol0000UOol00`00Oomo
o`0BOol00`00Oomoo`0ROol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0@Ool00`00Oomo
o`0VOol00`00Oomoo`0>Ool00`00Oomoo`0VOol00`00Oomoo`0>Ool00`00Oomoo`0XOol00`00Oomo
o`0;Ool00`00Oomoo`0MOol0035oo`05001oogooOol0000UOol00`00Oomoo`0BOol00`00Oomoo`0R
Ool00`00Oomoo`0AOol00`00Oomoo`0UOol00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomoo`0=
Ool00`00Oomoo`0XOol00`00Oomoo`0<Ool00`00Oomoo`0ZOol00`00Oomoo`09Ool00`00Oomoo`0N
Ool0035oo`05001oogooOol0000UOol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0?Ool0
0`00Oomoo`0VOol00`00Oomoo`0>Ool00`00Oomoo`0XOol00`00Oomoo`0<Ool00`00Oomoo`0YOol0
0`00Oomoo`0;Ool00`00Oomoo`0[Ool00`00Oomoo`07Ool00`00Oomoo`0OOol0035oo`04001oogoo
000VOol00`00Oomoo`0AOol00`00Oomoo`0TOol00`00Oomoo`0?Ool00`00Oomoo`0VOol00`00Oomo
o`0>Ool00`00Oomoo`0XOol00`00Oomoo`0;Ool00`00Oomoo`0ZOol00`00Oomoo`0:Ool00`00Oomo
o`0]Ool00`00Oomoo`05Ool00`00Oomoo`0POol0035oo`@002Moo`03001oogoo011oo`03001oogoo
02Eoo`03001oogoo00ioo`03001oogoo02Moo`03001oogoo00aoo`03001oogoo02Yoo`03001oogoo
00Yoo`03001oogoo02]oo`03001oogoo00Qoo`03001oogoo02moo`03001oogoo00=oo`03001oogoo
025oo`00<Goo00@007ooOol002Moo`03001oogoo00moo`03001oogoo02Ioo`03001oogoo00eoo`03
001oogoo02Qoo`03001oogoo00aoo`03001oogoo02Yoo`03001oogoo00Uoo`03001oogoo02eoo`03
001oogoo00Ioo`03001oogoo031oo`H002Aoo`00<Goo00@007ooOol002Moo`03001oogoo00moo`03
001oogoo02Moo`03001oogoo00aoo`03001oogoo02Uoo`03001oogoo00Yoo`03001oogoo02aoo`03
001oogoo00Moo`03001oogoo02moo`03001oogoo00=oo`8003Ioo`03001oogoo02Aoo`00<Goo00<0
07oo0000:Goo00<007ooOol03Woo00<007ooOol09goo00<007ooOol02goo00<007ooOol0:Woo00<0
07ooOol02Goo00<007ooOol0;Woo00<007ooOol01Goo00<007ooOol0<Goo1P00GWoo000aOol00`00
Ool0000YOol00`00Oomoo`0=Ool00`00Oomoo`0YOol00`00Oomoo`0:Ool00`00Oomoo`0[Ool00`00
Oomoo`08Ool00`00Oomoo`0_Ool00`00Oomoo`03Ool00`00Oomoo`2FOol0035oo`03001oo`0002Uo
o`03001oogoo00eoo`03001oogoo02Uoo`03001oogoo00Yoo`03001oogoo02aoo`03001oogoo00Io
o`03001oogoo035oo`H009Qoo`00<Goo0`00:Woo00<007ooOol037oo00<007ooOol0:Woo00<007oo
Ool027oo00<007ooOol0;Woo00<007ooOol017oo00<007ooOol0d7oo000aOol2000[Ool00`00Oomo
o`0;Ool00`00Oomoo`0[Ool00`00Oomoo`08Ool00`00Oomoo`0_Ool20003Ool00`00Oomoo`3AOol0
035oo`8002aoo`03001oogoo00Yoo`03001oogoo02aoo`03001oogoo00Ioo`03001oogoo035oo`@0
0=Aoo`0037oo0P001goo0`0017oo1P0017oo10001goo00<007ooOol0:goo00<007ooOol02Goo00<0
07ooOol0;Woo00<007ooOol017oo00<007ooOol0ogoo2goo000;Ool01000Oomoo`001Woo0`001Goo
00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo02aoo`03001oogoo
00Moo`03001oogoo02moo`03001oogoo00=oo`03001oogoo0?moo`aoo`002Woo00<007ooOol00Woo
00<007ooOol00goo0`001Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol0;7oo00<007oo
Ool01Woo00<007ooOol0<Goo1@00ogoo3goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool4000/Ool00`00Oomoo`05Ool00`00Oomoo`3oOom5Ool000Yoo`03
001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo02eoo`03001oogoo00Aoo`03001oogoo0?moodIoo`002Woo00<007ooOol00Woo00<007oo
Ool03goo00@007ooOomoo`D000Moo`03001oogoo02ioo`8000=oo`03001oogoo0?moodMoo`002Woo
00<007ooOol00Woo00<007ooOol03goo00D007ooOomoo`0000]oo`03001oogoo02moo`@00?moodYo
o`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`3oOomm
Ool000aoo`8000moo`@000Aoo`D000Moo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`005Goo0P001goo0`001Goo10001goo00<007ooOol0ogooOGoo000DOol0
1000Oomoo`001Woo0`0017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000C
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol0
01=oo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`@00?moogaoo`004goo00<007oo
Ool00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000C
Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool50007Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo0?moogeoo`0057oo00@007ooOol000eo
o`03001oogoo00Uoo`03001oogoo0?moogeoo`005Goo0P003Woo1@001goo00<007ooOol0ogooOGoo
000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3
003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol000ao
o`8000Moo`<000Ioo`03001oogoo00Eoo`@000Moo`03001oogoo0?moogeoo`002goo00@007ooOol0
00Ioo`<000Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeo
o`002Woo00<007ooOol00Woo00<007ooOol00goo0`001goo00<007ooOol027oo00<007ooOol017oo
1000ogooO7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`04
Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol00Woo1@001goo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00
Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`3oOommOol000]oo`04001oogoo
000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol0ogooOGoo000<Ool2000>Ool6
0003Ool50007Ool3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3
003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool002Ioo`D000Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000XOol00`00Oomoo`06Ool4003oOomlOol002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0
ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`009Woo0`00ogooR7oo
000WOol2003oOon8Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .28321 m
.03279 .32893 L
.04262 .37276 L
.04758 .38884 L
.05035 .39549 L
.05167 .39799 L
.05288 .39992 L
.054 .40137 L
.05524 .40259 L
.05648 .40342 L
.0578 .40386 L
.05895 .40388 L
.0602 .4035 L
.06137 .40278 L
.06244 .40181 L
.0638 .40016 L
.06504 .39827 L
.0678 .3927 L
.07036 .38601 L
.07277 .37846 L
.08405 .33143 L
.09403 .28374 L
.09949 .26015 L
.10458 .2419 L
.1092 .22958 L
.11053 .22689 L
.11179 .22471 L
.11291 .22309 L
.11415 .22164 L
.11542 .22055 L
.11611 .22012 L
.11677 .21983 L
.11793 .21956 L
.11918 .21965 L
.11985 .21985 L
.12057 .22019 L
.12133 .22069 L
.12204 .22128 L
.12331 .22263 L
.12466 .22449 L
.12705 .2288 L
.12964 .23487 L
.13434 .2492 L
.14313 .2845 L
.1534 .33084 L
.16301 .36809 L
.16784 .3815 L
.17055 .38699 L
.17175 .38892 L
.17303 .39061 L
Mistroke
.17376 .39142 L
.17443 .39205 L
.17573 .39298 L
.17646 .39332 L
.17725 .39356 L
.178 .39365 L
.17868 .39362 L
.17993 .39328 L
.18063 .39293 L
.18129 .39249 L
.18262 .39132 L
.18405 .38962 L
.18662 .38544 L
.18935 .3795 L
.19425 .36541 L
.20533 .32222 L
.21502 .28104 L
.22011 .26192 L
.22289 .25289 L
.22546 .24561 L
.22801 .23956 L
.23033 .23517 L
.23157 .23327 L
.2329 .23159 L
.23364 .23082 L
.23432 .23022 L
.23496 .22974 L
.23565 .22933 L
.23676 .22889 L
.23781 .22873 L
.23905 .22885 L
.24018 .22925 L
.24136 .22997 L
.24264 .23109 L
.24385 .23248 L
.24497 .23403 L
.24919 .2421 L
.25384 .25471 L
.26327 .28878 L
.27267 .32707 L
.28259 .36197 L
.28778 .3749 L
.2892 .37762 L
.29072 .38008 L
.29203 .38185 L
.29346 .38337 L
.29414 .38394 L
.29486 .38445 L
.29615 .38509 L
.29735 .38537 L
Mistroke
.29804 .38539 L
.29868 .38532 L
.29988 .38496 L
.30097 .38437 L
.30224 .38338 L
.30344 .38214 L
.30603 .37849 L
.30847 .37389 L
.31303 .36257 L
.32326 .32771 L
.33203 .29367 L
.34165 .26077 L
.34409 .25414 L
.3467 .24807 L
.34896 .24376 L
.35142 .24013 L
.35286 .23854 L
.3535 .23797 L
.3542 .23743 L
.35547 .2367 L
.35617 .23643 L
.35682 .23627 L
.35806 .23621 L
.35919 .23642 L
.36043 .23694 L
.36174 .23782 L
.3629 .23888 L
.36395 .24007 L
.36632 .24348 L
.37057 .25208 L
.37553 .26557 L
.38022 .28091 L
.38906 .31332 L
.39855 .34645 L
.404 .36159 L
.40658 .36729 L
.40897 .37162 L
.41136 .37494 L
.41262 .37627 L
.41327 .37684 L
.41396 .37737 L
.41525 .37809 L
.41645 .37849 L
.41763 .3786 L
.41871 .37847 L
.41986 .37809 L
.4211 .3774 L
.42226 .37649 L
.42333 .37544 L
.42593 .37202 L
Mistroke
.42839 .36771 L
.43328 .35637 L
.4386 .34068 L
.44861 .30593 L
.45393 .28741 L
.45964 .26955 L
.46238 .2622 L
.46499 .25614 L
.46753 .2512 L
.46988 .24755 L
.4721 .24497 L
.47334 .24391 L
.47447 .24319 L
.4757 .24266 L
.4764 .24249 L
.47704 .24241 L
.47822 .24246 L
.47947 .24278 L
.48078 .24343 L
.48197 .24429 L
.48335 .2456 L
.48465 .24714 L
.48697 .25058 L
.48949 .25529 L
.49521 .26921 L
.5005 .28519 L
.51024 .31806 L
.51535 .33475 L
.52074 .3502 L
.52548 .36102 L
.52816 .36574 L
.52945 .3676 L
.53066 .36911 L
.53176 .37027 L
.53296 .3713 L
.53405 .37202 L
.53505 .37249 L
.53614 .37281 L
.53734 .37292 L
.53858 .37277 L
.53975 .37237 L
.54096 .37172 L
.54208 .37088 L
.54463 .36821 L
.54687 .36499 L
.54926 .36072 L
.55794 .33911 L
.57749 .27765 L
.58251 .2649 L
.58524 .25921 L
Mistroke
.5878 .25484 L
.59056 .25122 L
.59203 .24979 L
.59278 .2492 L
.5936 .24866 L
.59435 .24827 L
.59503 .24798 L
.59569 .24779 L
.59639 .24766 L
.5976 .24764 L
.59829 .24774 L
.59893 .2479 L
.60011 .24838 L
.60141 .24917 L
.60275 .25029 L
.604 .25159 L
.60625 .25453 L
.60865 .2585 L
.61413 .27039 L
.61911 .2839 L
.62924 .31523 L
.63477 .33203 L
.63995 .34591 L
.64436 .35557 L
.64662 .35958 L
.64909 .36311 L
.65049 .36471 L
.65178 .36593 L
.65302 .36684 L
.65434 .36754 L
.65551 .36793 L
.65662 .36809 L
.65783 .36803 L
.65914 .36771 L
.6603 .36719 L
.66155 .36639 L
.66273 .36541 L
.6638 .36433 L
.66643 .36097 L
.66891 .3569 L
.67385 .34649 L
.67921 .33247 L
.69764 .27875 L
.70219 .26813 L
.70708 .25937 L
.70852 .2574 L
.70989 .25581 L
.71122 .25452 L
.71245 .25357 L
.71362 .25288 L
Mistroke
.71486 .25238 L
.71557 .25221 L
.71624 .25211 L
.71748 .25212 L
.7187 .25237 L
.7194 .25261 L
.72004 .25291 L
.72135 .2537 L
.72275 .25483 L
.72528 .25761 L
.72759 .26093 L
.7332 .27178 L
.73852 .28495 L
.75674 .33636 L
.76173 .34785 L
.76435 .35284 L
.76711 .35718 L
.76954 .36016 L
.77082 .36139 L
.7722 .36245 L
.77346 .36318 L
.77461 .36363 L
.77576 .36389 L
.77685 .36395 L
.778 .36381 L
.77925 .36344 L
.78056 .3628 L
.78179 .36197 L
.78399 .35994 L
.78634 .35702 L
.79172 .34773 L
.79663 .33661 L
.80754 .30689 L
.81764 .28007 L
.82239 .26992 L
.82686 .26262 L
.82934 .25967 L
.83064 .25845 L
.83201 .25742 L
.83317 .25676 L
.83444 .25626 L
.83559 .25601 L
.83667 .25595 L
.83796 .2561 L
.83869 .2563 L
.83937 .25655 L
.8406 .25717 L
.84191 .25807 L
.84419 .2602 L
.84669 .26333 L
Mistroke
.85222 .27293 L
.85741 .28462 L
.87593 .33338 L
.881 .34449 L
.88379 .34955 L
.88642 .35351 L
.88887 .35643 L
.89016 .35766 L
.89152 .35871 L
.89267 .3594 L
.89394 .35994 L
.89509 .36024 L
.89616 .36035 L
.89747 .36026 L
.89821 .3601 L
.89889 .35989 L
.90015 .35933 L
.90149 .35849 L
.90379 .35648 L
.90635 .35346 L
.91198 .3441 L
.91727 .33257 L
.92686 .30796 L
.9323 .29384 L
.93736 .28184 L
.9425 .27167 L
.94474 .26806 L
.94718 .2648 L
.94851 .26331 L
.94975 .26214 L
.951 .26115 L
.95218 .26042 L
.95341 .25984 L
.95407 .25963 L
.95477 .25945 L
.95551 .25935 L
.95621 .25932 L
.95752 .25944 L
.95869 .25974 L
.95974 .26018 L
.96096 .26086 L
.96211 .26169 L
.96416 .26359 L
.96637 .26622 L
.9714 .27425 L
.97602 .28373 L
.97619 .28411 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol08Goo1000ogooF7oo000aOol00`00Oomoo`0POol01@00Oomoogoo0000ogooF7oo000<Ool2
0007Ool30004Ool60004Ool40007Ool00`00Oomoo`0OOol20004Ool00`00Oomoo`3oOomEOol000]o
o`04001oogoo0006Ool30005Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol07goo00<007ooOol017oo00<007ooOol09goo0`00ogoo:Woo000:Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool30006Ool00`00Oomoo`09Ool00`00Oomoo`04Ool4000NOol00`00Oomoo`04
Ool00`00Oomoo`0VOol200000goo0000003oOolYOol00003Ool0000000D0009oo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo01moo`03001oogoo00Eo
o`03001oogoo02Aoo`03001oogoo009oo`800?moobQoo`002Woo00<007ooOol00Woo00<007ooOol0
3Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol07Woo00<007ooOol0
1Woo00<007ooOol097oo00<007ooOol00goo00<007ooOol0:7oo0`00nWoo000:Ool00`00Oomoo`02
Ool00`00Oomoo`0?Ool01000Oomoogoo1@001goo00<007ooOol07Woo00<007ooOol01Woo00<007oo
Ool08goo00<007ooOol01Goo00<007ooOol09Woo00<007ooOol00P00nGoo000:Ool00`00Oomoo`02
Ool00`00Oomoo`0?Ool01@00Oomoogoo00002goo00<007ooOol07Goo00<007ooOol027oo00<007oo
Ool08Woo00<007ooOol01Goo00<007ooOol09Goo00<007ooOol00Woo00<007ooOol0mgoo000;Ool0
1000Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo01eoo`03001oogoo
00Qoo`03001oogoo025oo`03001oogoo00Ioo`03001oogoo02Aoo`03001oogoo00Aoo`03001oogoo
02Moo`@00<]oo`0037oo0P003goo100017oo1@001goo0`007Goo00<007ooOol027oo00<007ooOol0
8Goo00<007ooOol01goo00<007ooOol08goo00<007ooOol017oo00<007ooOol09Woo00<007ooOol0
0Woo00<007ooOol0b7oo000aOol00`00Oomoo`0LOol00`00Oomoo`0:Ool00`00Oomoo`0POol00`00
Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`0UOol00`00Oomoo`02Ool00`00
Oomoo`0WOol5002LOol0035oo`03001oogoo01aoo`03001oogoo00Yoo`03001oogoo01moo`03001o
ogoo00Qoo`03001oogoo029oo`03001oogoo00Moo`03001oogoo02=oo`03001oogoo00Aoo`03001o
ogoo02Ioo`04001oogooOol2000ZOol3001^Ool0035oo`03001oogoo01aoo`03001oogoo00Yoo`03
001oogoo01moo`03001oogoo00Uoo`03001oogoo021oo`03001oogoo00Qoo`03001oogoo02=oo`03
001oogoo00Aoo`03001oogoo02Eoo`03001oogoo00Aoo`03001oogoo02Ioo`800003Ool0000006eo
o`00<Goo00<007ooOol06goo00<007ooOol037oo00<007ooOol07Woo00<007ooOol02Goo00<007oo
Ool087oo00<007ooOol02Goo00<007ooOol08Goo00<007ooOol01Woo00<007ooOol097oo00<007oo
Ool017oo00<007ooOol09Goo00<007ooOol00goo00<007ooOol09goo1000?goo000aOol00`00Oomo
o`0KOol00`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomo
o`0:Ool00`00Oomoo`0QOol00`00Oomoo`06Ool00`00Oomoo`0SOol00`00Oomoo`06Ool00`00Oomo
o`0SOol00`00Oomoo`04Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`0XOol4000@Ool0
035oo`<001]oo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo00]oo`03001oogoo01ioo`03
001oogoo00Yoo`03001oogoo021oo`03001oogoo00Qoo`03001oogoo029oo`03001oogoo00Ioo`03
001oogoo02=oo`03001oogoo00Eoo`03001oogoo02Aoo`03001oogoo00Aoo`03001oogoo02Ioo`80
009oo`8000moo`00<Goo00<007ooOol06goo00<007ooOol037oo00<007ooOol07Goo00<007ooOol0
2goo00<007ooOol07Woo00<007ooOol02goo00<007ooOol07goo00<007ooOol027oo00<007ooOol0
8Goo00<007ooOol027oo00<007ooOol08Goo00<007ooOol01Woo00<007ooOol097oo00<007ooOol0
1Goo00<007ooOol097oo00<007ooOol017oo00<007ooOol037oo000aOol00`00Oomoo`0JOol00`00
Oomoo`0=Ool00`00Oomoo`0MOol00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`0;Ool00`00
Oomoo`0NOol00`00Oomoo`09Ool00`00Oomoo`0QOol00`00Oomoo`08Ool00`00Oomoo`0QOol00`00
Oomoo`07Ool00`00Oomoo`0ROol00`00Oomoo`06Ool00`00Oomoo`0TOol00`00Oomoo`04Ool00`00
Oomoo`0<Ool0035oo`03001oogoo01Yoo`03001oogoo00ioo`03001oogoo01]oo`03001oogoo00eo
o`03001oogoo01aoo`03001oogoo00aoo`03001oogoo01ioo`03001oogoo00Yoo`03001oogoo01mo
o`03001oogoo00Yoo`03001oogoo01moo`03001oogoo00Qoo`03001oogoo025oo`03001oogoo00Qo
o`03001oogoo029oo`03001oogoo00Eoo`03001oogoo00aoo`00<Goo00<007ooOol06Woo00<007oo
Ool03Woo00<007ooOol03Woo1@001Goo10000goo1P001Woo00<007ooOol077oo00<007ooOol037oo
1@001Goo0`001goo0`002Woo00<007ooOol02Woo00<007ooOol06Goo1@0000=oo`00Ool00Woo0`00
1Goo10007goo00<007ooOol02Goo00<007ooOol01Woo1@001Goo0`001Goo100017oo00<007ooOol0
2Goo00<007ooOol087oo00<007ooOol01goo1P0027oo000aOol00`00Oomoo`0JOol00`00Oomoo`0>
Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool40004Ool01@00Oomoogoo00001Woo00<007ooOol077oo
00<007ooOol03Goo0P001goo0`0027oo00<007ooOol027oo00<007ooOol037oo00<007ooOol06Woo
00D007ooOomoo`0000=oo`<000Aoo`06001oogoo001oo`007Goo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol01Goo0`0017oo00<007ooOol00Woo00@007ooOol000aoo`03001oogoo021oo`03
001oogoo00Qoo`05001oogooOol00008Ool0035oo`<001Yoo`03001oogoo00ioo`03001oogoo011o
o`03001oogoo00Eoo`@000Eoo`03001oogoo00Moo`03001oogoo01aoo`03001oogoo00eoo`8000Mo
o`<000Aoo`H000Uoo`03001oogoo00aoo`03001oogoo01Yoo`04001oogoo0004Ool30004Ool01P00
Oomoo`00Ool001eoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Eoo`<000Aoo`03001o
ogoo009oo`04001oogoo000=Ool00`00Oomoo`0NOol00`00Oomoo`09Ool2000;Ool0035oo`03001o
ogoo01Uoo`03001oogoo00moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00Eoo`03001o
ogoo00Moo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo00aoo`05001oogooOol00009Ool0
0`00Oomoo`0=Ool00`00Oomoo`0JOol01000Oomoo`002goo00H007ooOol007oo000LOol00`00Oomo
o`0<Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Ool0000>Ool00`00Oomo
o`0NOol00`00Oomoo`0:Ool2000:Ool0035oo`03001oogoo01Uoo`03001oogoo011oo`03001oogoo
00moo`03001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Ioo`03001oogoo01Yoo`03001oogoo
00moo`03001oogoo00eoo`04001oogoo0009Ool00`00Oomoo`0>Ool00`00Oomoo`0IOol00`00Ool0
000<Ool20002Ool2000LOol00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool40002Ool0
0`00Oomoo`0<Ool00`00Oomoo`0MOol00`00Oomoo`0;Ool00`00Ool00009Ool0035oo`03001oogoo
01Uoo`03001oogoo011oo`03001oogoo00moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo
00Eoo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo00ioo`03001oo`0000Uoo`03001oogoo
00ioo`03001oogoo01Uoo`03001oo`0000aoo`03001oo`00008001aoo`03001oogoo00ioo`03001o
ogoo00Ioo`03001oogoo00aoo`03001oogoo009oo`80011oo`03001oogoo01aoo`03001oogoo00ao
o`03001oo`0000Qoo`00<Goo00<007ooOol06Goo00<007ooOol047oo00<007ooOol03goo00<007oo
Ool01goo00<007ooOol01goo00<007ooOol01Woo00<007ooOol06Goo00<007ooOol03goo00<007oo
Ool03Woo00<007oo000027oo00<007ooOol03goo00<007ooOol06Goo00<007oo00003Goo00@007oo
Ool001aoo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo009oo`80011o
o`03001oogoo01]oo`03001oogoo00moo`03001oogoo00Ioo`00<Goo0P006Woo00<007ooOol047oo
00<007ooOol03Goo0`0027oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool06Goo00<007ooOol03Goo100047oo0P0027oo00<007ooOol03goo00<007ooOol05goo10003Woo
0P000Woo00<007ooOol06Goo00<007ooOol03goo00<007ooOol00goo0`003Woo00<007ooOol00Woo
0P004Goo00<007ooOol06Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol01Woo000aOol2
000IOol00`00Oomoo`0BOol00`00Oomoo`0=Ool20008Ool00`00Oomoo`04Ool40009Ool00`00Oomo
o`0HOol00`00Oomoo`0?Ool3000AOol00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`0GOol3
000@Ool3000JOol00`00Oomoo`0@Ool00`00Oomoo`04Ool2000?Ool5000BOol00`00Oomoo`0JOol0
0`00Oomoo`0;Ool40009Ool0035oo`<001Qoo`03001oogoo019oo`03001oogoo01Moo`03001oogoo
015oo`03001oogoo01Qoo`03001oogoo015oo`03001oogoo01Moo`03001oogoo015oo`03001oogoo
01Uoo`03001oogoo011oo`03001oogoo01Qoo`03001oogoo011oo`03001oogoo01Uoo`03001oogoo
011oo`03001oogoo01Uoo`03001oogoo01Uoo`00<Goo0P006Goo00<007ooOol04Woo00<007ooOol0
5goo00<007ooOol04Woo00<007ooOol05goo00<007ooOol04Goo00<007ooOol05goo00<007ooOol0
4Goo00<007ooOol067oo00<007ooOol04Woo00<007ooOol05goo00<007ooOol04Goo00<007ooOol0
67oo00<007ooOol04Goo00<007ooOol067oo00<007ooOol06Goo000aOol2000IOol00`00Oomoo`0B
Ool00`00Oomoo`0FOol00`00Oomoo`0COol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0F
Ool00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0FOol00`00Oomoo`0B
Ool00`00Oomoo`0GOol00`00Oomoo`0BOol00`00Oomoo`0GOol00`00Oomoo`0JOol0035oo`03001o
o`0001Qoo`03001oogoo019oo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo01Ioo`03001o
ogoo01=oo`03001oogoo01Eoo`03001oogoo01=oo`03001oogoo01Moo`03001oogoo019oo`03001o
ogoo01Ioo`03001oogoo01=oo`03001oogoo01Ioo`03001oogoo019oo`03001oogoo01Moo`03001o
ogoo01Yoo`00<Goo00<007oo00005goo00<007ooOol057oo00<007ooOol05Goo00<007ooOol04goo
00<007ooOol05Woo00<007ooOol04goo00<007ooOol05Goo00<007ooOol04goo00<007ooOol05Woo
00<007ooOol057oo00<007ooOol05Goo00<007ooOol04goo00<007ooOol05Woo00<007ooOol04goo
00<007ooOol05Woo00<007ooOol06Woo000aOol00`00Ool0000GOol00`00Oomoo`0DOol00`00Oomo
o`0EOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0COol00`00Oomoo`0EOol00`00Oomo
o`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomo
o`0EOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0KOol002Qoool008T00000<Goo00@0
07ooOol000moo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03
001oogoo00eoo`04001oogoo000AOol01000Oomoo`003goo00<007ooOol017oo00<007ooOol02Goo
00<007ooOol02Goo00<007ooOol00goo00<007ooOol03Goo00@007ooOol0015oo`04001oogoo000?
Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0>
Ool00`00Ool0000AOol01@00Oomoogoo00003Woo00<007ooOol017oo00<007ooOol027oo00<007oo
Ool02goo00<007ooOol00Woo00<007ooOol03Woo00<007oo00004Goo00<007ooOol027oo000aOol0
1000Oomoo`005Goo00<007ooOol05Woo00<007ooOol04goo00@007ooOol001Eoo`03001oogoo01=o
o`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo00eoo`03001oogoo01Ioo`03001oogoo01=o
o`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo019oo`03001oogoo01Moo`03001oogoo00]o
o`03001oogoo00Aoo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo015oo`03001oogoo00Qo
o`00<Goo00@007ooOol001Eoo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo01Ioo`03001o
ogoo019oo`03001oogoo01Ioo`03001oogoo01=oo`03001oogoo01Ioo`03001oogoo01=oo`03001o
ogoo01Ioo`03001oogoo019oo`03001oogoo01Moo`03001oogoo019oo`03001oogoo01Moo`03001o
ogoo019oo`03001oogoo01aoo`00<Goo00@007ooOol001Eoo`03001oogoo01Ioo`03001oogoo019o
o`03001oogoo01Moo`03001oogoo019oo`03001oogoo01Moo`03001oogoo015oo`03001oogoo01Mo
o`03001oogoo019oo`03001oogoo01Moo`03001oogoo019oo`03001oogoo01Moo`03001oogoo015o
o`03001oogoo01Qoo`03001oogoo015oo`03001oogoo01eoo`00<Goo00@007ooOol001Eoo`03001o
ogoo01Ioo`03001oogoo019oo`03001oogoo01Moo`03001oogoo019oo`03001oogoo01Moo`03001o
ogoo015oo`03001oogoo01Moo`03001oogoo019oo`03001oogoo01Qoo`03001oogoo011oo`03001o
ogoo01Uoo`03001oogoo011oo`03001oogoo01Qoo`03001oogoo015oo`03001oogoo01eoo`00<Goo
0`0000=oo`00Ool04goo00<007ooOol05Woo00<007ooOol04Woo00<007ooOol067oo00<007ooOol0
47oo00<007ooOol067oo00<007ooOol04Goo00<007ooOol067oo00<007ooOol04Goo00<007ooOol0
67oo00<007ooOol047oo00<007ooOol06Goo00<007ooOol047oo00<007ooOol06Goo00<007ooOol0
3goo00<007ooOol07Woo000aOol01@00Oomoogoo00004goo00<007ooOol067oo00<007ooOol04Goo
00<007ooOol067oo00<007ooOol047oo00<007ooOol06Goo00<007ooOol047oo00<007ooOol067oo
00<007ooOol047oo00<007ooOol06Goo00<007ooOol047oo00<007ooOol06Woo00<007ooOol03Woo
00<007ooOol06Woo00<007ooOol03goo00<007ooOol07Woo000aOol01@00Oomoogoo00004goo00<0
07ooOol067oo00<007ooOol047oo00<007ooOol06Goo00<007ooOol047oo00<007ooOol06Goo00<0
07ooOol03goo00<007ooOol06Goo00<007ooOol047oo00<007ooOol06Woo00<007ooOol03Woo00<0
07ooOol06goo00<007ooOol03Woo00<007ooOol06Woo00<007ooOol03goo00<007ooOol07Woo000a
Ool01@00Oomoogoo00004goo00<007ooOol067oo00<007ooOol047oo00<007ooOol06Goo00<007oo
Ool047oo00<007ooOol06Goo00<007ooOol03goo00<007ooOol06Woo00<007ooOol03goo00<007oo
Ool06Woo00<007ooOol03Woo00<007ooOol06goo00<007ooOol03Woo00<007ooOol06goo00<007oo
Ool03Goo00<007ooOol07goo000aOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`0HOol0
0`00Oomoo`0@Ool00`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0>Ool0
0`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0>Ool00`00Oomoo`0LOol0
0`00Oomoo`0<Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool00`00Oomoo`0OOol0035oo`03001oogoo
009oo`03001oogoo00moo`03001oogoo01Yoo`03001oogoo00moo`03001oogoo01Yoo`03001oogoo
00ioo`03001oogoo01]oo`03001oogoo00eoo`03001oogoo01]oo`03001oogoo00ioo`03001oogoo
01aoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo
00]oo`03001oogoo021oo`00<Goo0`000Woo00<007ooOol03goo00<007ooOol06Woo00<007ooOol0
3Woo00<007ooOol06goo00<007ooOol03Woo00<007ooOol06goo00<007ooOol03Goo00<007ooOol0
77oo00<007ooOol03Goo00<007ooOol077oo00<007ooOol037oo00<007ooOol07Goo00<007ooOol0
2goo00<007ooOol07Woo00<007ooOol02goo00<007ooOol087oo000aOol00`00Oomoo`02Ool00`00
Oomoo`0?Ool00`00Oomoo`0JOol00`00Oomoo`0>Ool00`00Oomoo`0KOol00`00Oomoo`0=Ool00`00
Oomoo`0MOol00`00Oomoo`0<Ool00`00Oomoo`0LOol00`00Oomoo`0<Ool00`00Oomoo`0MOol00`00
Oomoo`0<Ool00`00Oomoo`0NOol00`00Oomoo`0:Ool00`00Oomoo`0OOol00`00Oomoo`09Ool00`00
Oomoo`0QOol0035oo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo01Yoo`03001oogoo00io
o`03001oogoo01aoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo00]oo`03001oogoo01eo
o`03001oogoo00aoo`03001oogoo01ioo`03001oogoo00Yoo`03001oogoo01moo`03001oogoo00Yo
o`03001oogoo01moo`03001oogoo00Uoo`03001oogoo025oo`00<Goo00<007ooOol00goo00<007oo
Ool03Goo00<007ooOol077oo00<007ooOol03Goo00<007ooOol077oo00<007ooOol037oo00<007oo
Ool07Goo00<007ooOol02goo00<007ooOol07Woo00<007ooOol02goo00<007ooOol07Woo00<007oo
Ool02Woo00<007ooOol07goo00<007ooOol02Goo00<007ooOol08Goo00<007ooOol01goo00<007oo
Ool08Woo000aOol00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`0LOol00`00Oomoo`0=Ool0
0`00Oomoo`0LOol00`00Oomoo`0;Ool00`00Oomoo`0OOol00`00Oomoo`0:Ool00`00Oomoo`0NOol0
0`00Oomoo`0:Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`0POol00`00Oomoo`09Ool0
0`00Oomoo`0QOol00`00Oomoo`07Ool00`00Oomoo`0ROol0035oo`03001oogoo00=oo`03001oogoo
00eoo`03001oogoo01aoo`03001oogoo00aoo`03001oogoo01eoo`03001oogoo00]oo`03001oogoo
01moo`03001oogoo00Uoo`03001oogoo01moo`03001oogoo00Yoo`03001oogoo021oo`03001oogoo
00Qoo`03001oogoo025oo`8000Qoo`03001oogoo02=oo`03001oogoo00Eoo`03001oogoo02=oo`00
<Goo0`000goo00<007ooOol037oo00<007ooOol07Woo00<007ooOol02goo00<007ooOol07Goo00<0
07ooOol02goo00<007ooOol07goo00<007ooOol02Goo00<007ooOol087oo00<007ooOol02Goo00<0
07ooOol08Goo00<007ooOol01Woo00<007ooOol097oo00<007ooOol017oo00<007ooOol09Goo00<0
07ooOol00goo00<007ooOol097oo000aOol00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`0N
Ool00`00Oomoo`0;Ool00`00Oomoo`0NOol00`00Oomoo`09Ool00`00Oomoo`0QOol00`00Oomoo`08
Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`0SOol00`00Oomoo`05Ool00`00Oomoo`0T
Ool00`00Oomoo`03Ool00`00Oomoo`0WOol200000goo0000000WOol0035oo`03001oogoo00Aoo`03
001oogoo00]oo`03001oogoo01ioo`03001oogoo00]oo`03001oogoo01ioo`03001oogoo00Uoo`03
001oogoo025oo`03001oogoo00Moo`03001oogoo029oo`03001oogoo00Moo`03001oogoo02=oo`03
001oogoo00Aoo`03001oogoo02Ioo`80009oo`03001oogoo02Yoo`8002Qoo`00<Goo00<007ooOol0
17oo00<007ooOol02goo00<007ooOol07Woo00<007ooOol02Woo00<007ooOol07goo00<007ooOol0
2Goo00<007ooOol08Goo00<007ooOol01goo00<007ooOol08Woo00<007ooOol01Woo00<007ooOol0
9Goo00<007ooOol00Woo00<007ooOol0:7oo1000EWoo000aOol00`00Oomoo`04Ool00`00Oomoo`0:
Ool00`00Oomoo`0POol00`00Oomoo`09Ool00`00Oomoo`0POol00`00Oomoo`08Ool00`00Oomoo`0R
Ool00`00Oomoo`05Ool00`00Oomoo`0TOol20006Ool00`00Oomoo`0VOol50024Ool0035oo`03001o
ogoo00Eoo`03001oogoo00Uoo`03001oogoo021oo`03001oogoo00Uoo`03001oogoo021oo`03001o
ogoo00Moo`03001oogoo02=oo`03001oogoo00Eoo`03001oogoo02Eoo`8000Aoo`03001oogoo02Qo
o`8008Ioo`00<Goo0`001Goo00<007ooOol02Goo00<007ooOol087oo00<007ooOol027oo00<007oo
Ool08Goo00<007ooOol01goo00<007ooOol097oo00<007ooOol00goo00<007ooOol09goo1@00/goo
000aOol00`00Oomoo`05Ool00`00Oomoo`09Ool00`00Oomoo`0QOol00`00Oomoo`07Ool00`00Oomo
o`0ROol00`00Oomoo`06Ool00`00Oomoo`0UOol01@00Oomoogoo0000;7oo00<007ooOol0/goo000a
Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0ROol00`00Oomoo`07Ool00`00Oomoo`0S
Ool00`00Oomoo`05Ool00`00Oomoo`0UOol200000goo0000003ROol000aoo`8000Moo`<000Aoo`H0
00Aoo`@000Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo029oo`03001oogoo00Ioo`03
001oogoo02Eoo`03001oogoo00=oo`03001oogoo02Moo`<00>=oo`002goo00@007ooOol000Ioo`<0
00Eoo`05001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool00`00Oomoo`0SOol00`00Oomoo`05Ool00`00Oomoo`0UOol00`00Oomoo`02Ool00`00
Oomoo`3oOol?Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03
001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo02=oo`03001oogoo00Aoo`03
001oogoo02Moo`@00?mooa9oo`002Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo
00<007ooOol017oo10001Woo00<007ooOol01Woo00<007ooOol097oo00<007ooOol00goo00<007oo
Ool0ogoo?Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0TOol20003Ool00`00
Oomoo`3oOolnOol000Yoo`03001oogoo009oo`03001oogoo00moo`04001oogooOol50007Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0VOol4003oOom1Ool000Yoo`03001oogoo009oo`03
001oogoo00moo`05001oogooOol0000;Ool00`00Oomoo`08Ool00`00Oomoo`03Ool00`00Oomoo`0X
Ool2003oOom2Ool000]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<0
07ooOol027oo00<007ooOol00Woo00<007ooOol0ogooKGoo000<Ool2000?Ool40004Ool50007Ool0
0`00Oomoo`09Ool01@00Oomoogoo0000ogooKgoo000aOol30009Ool200000goo001oo`3oOom_Ool0
035oo`03001oogoo00]oo`03001oogoo0?moofmoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03
001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000EOol20007Ool30005Ool40007Ool00`00
Oomoo`3oOommOol001Aoo`04001oogoo0006Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Ao
o`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo1000
ogooO7oo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?mo
ogeoo`004goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo
000DOol01000Oomoo`003Goo00<007ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007
Ool00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03
001oogoo0?moogeoo`0037oo0P001goo0`001Woo00<007ooOol01Goo10001goo00<007ooOol0ogoo
OGoo000;Ool01000Oomoo`001Woo0`001goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30007Ool00`00Oomo
o`08Ool00`00Oomoo`04Ool4003oOomlOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00Qoo`03001oogoo00Aoo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol0
3Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000:Ool0
0`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool50007Ool00`00Oomoo`3oOommOol000Yo
o`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo0?mo
ogeoo`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`3o
OommOol000aoo`8000ioo`H000=oo`D000Moo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`009Woo1@001Woo00<007ooOol0ogooOGoo000XOol00`00Oomoo`06
Ool00`00Oomoo`3oOommOol002Qoo`03001oogoo00Ioo`@00?moogaoo`00:7oo00<007ooOol0ogoo
QWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogoo
QWoo000VOol3003oOon8Ool002Moo`800?moohQoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .27903 m
.02846 .25354 L
.03279 .23421 L
.03527 .2256 L
.03754 .21957 L
.03879 .21701 L
.03945 .2159 L
.04015 .2149 L
.04143 .21354 L
.04262 .21284 L
.04384 .21268 L
.04496 .21304 L
.04626 .21404 L
.04749 .21558 L
.04862 .21749 L
.04967 .21967 L
.05205 .22603 L
.05469 .2352 L
.05708 .24524 L
.06244 .27239 L
.07287 .33295 L
.07835 .36187 L
.08134 .37509 L
.08414 .38527 L
.08659 .39221 L
.08796 .39523 L
.08922 .39742 L
.08988 .39836 L
.09059 .39918 L
.09136 .39988 L
.09208 .40033 L
.09336 .40067 L
.0941 .40059 L
.09479 .40034 L
.09598 .3995 L
.09724 .39806 L
.09832 .39639 L
.0995 .39411 L
.10213 .38736 L
.10458 .37919 L
.12332 .28309 L
.12845 .25761 L
.13126 .24588 L
.13388 .23673 L
.13612 .23052 L
.13727 .22794 L
.13852 .22561 L
.13923 .22453 L
.13989 .22367 L
.14119 .22242 L
Mistroke
.14237 .22179 L
.14362 .22165 L
.14433 .22181 L
.14507 .22216 L
.1457 .22261 L
.1464 .22326 L
.14795 .22531 L
.1494 .22792 L
.15202 .23435 L
.15483 .24344 L
.16014 .26578 L
.16497 .29017 L
.17544 .34501 L
.18005 .36524 L
.18249 .37411 L
.18512 .38188 L
.18634 .38481 L
.18762 .3874 L
.18881 .38933 L
.18991 .39073 L
.19095 .39168 L
.19206 .3923 L
.19329 .39252 L
.1944 .39228 L
.19567 .39151 L
.19683 .39035 L
.19811 .38856 L
.19947 .38612 L
.20174 .38077 L
.20425 .37323 L
.20943 .35293 L
.21499 .3263 L
.22502 .27593 L
.22994 .25511 L
.23264 .24583 L
.23518 .23881 L
.2366 .23566 L
.23791 .23329 L
.23935 .23126 L
.24012 .23046 L
.24092 .22981 L
.24223 .22918 L
.24346 .22909 L
.24416 .22926 L
.2448 .22954 L
.24554 .23003 L
.24624 .23064 L
.24739 .232 L
.24867 .23397 L
.25125 .23939 L
Mistroke
.25364 .24604 L
.25588 .25353 L
.26635 .29977 L
.27132 .32413 L
.27674 .34873 L
.27922 .35854 L
.28186 .36762 L
.28434 .37462 L
.28661 .37964 L
.28778 .38166 L
.28902 .38335 L
.29026 .3846 L
.29096 .3851 L
.29162 .38543 L
.29281 .3857 L
.29389 .38557 L
.29515 .38497 L
.29633 .38397 L
.2974 .38272 L
.29852 .38104 L
.30055 .37711 L
.30273 .37167 L
.30514 .36432 L
.31537 .32188 L
.32094 .29562 L
.32613 .27281 L
.33094 .25516 L
.33304 .24897 L
.33532 .24347 L
.33662 .24092 L
.33782 .23899 L
.33896 .23752 L
.34018 .23637 L
.34145 .23562 L
.34265 .23535 L
.34396 .23553 L
.34469 .23585 L
.34536 .23628 L
.34662 .23743 L
.34775 .23885 L
.3503 .24332 L
.35265 .24894 L
.35487 .25542 L
.36523 .29661 L
.37422 .33664 L
.37932 .35601 L
.38181 .36377 L
.38407 .36964 L
.38524 .37219 L
.3865 .37456 L
Mistroke
.3876 .37627 L
.38881 .37778 L
.39008 .37895 L
.39078 .37939 L
.39144 .37969 L
.39261 .37991 L
.39387 .37972 L
.39519 .37904 L
.39594 .37844 L
.39664 .37775 L
.39791 .37614 L
.39927 .37395 L
.40186 .3685 L
.4042 .3622 L
.41372 .32685 L
.42269 .28808 L
.42774 .26863 L
.43245 .2542 L
.43482 .24872 L
.43604 .24642 L
.43737 .24435 L
.43812 .24338 L
.43882 .24261 L
.43947 .24201 L
.44019 .24147 L
.44144 .24088 L
.44212 .24073 L
.44276 .2407 L
.44384 .24092 L
.44502 .24151 L
.44625 .24252 L
.4474 .24382 L
.44945 .24699 L
.45165 .25152 L
.45667 .26574 L
.46123 .28234 L
.47055 .32099 L
.47564 .34104 L
.48041 .35676 L
.4831 .36378 L
.48556 .3688 L
.48696 .37103 L
.48829 .37268 L
.48897 .37336 L
.48969 .37395 L
.49049 .37443 L
.49123 .37474 L
.49252 .37494 L
.49325 .37485 L
.49392 .37465 L
Mistroke
.49516 .37398 L
.49646 .37285 L
.49763 .37146 L
.49872 .36987 L
.5012 .3652 L
.50622 .35179 L
.51167 .33258 L
.52158 .29281 L
.52627 .27544 L
.53123 .26032 L
.53328 .25544 L
.53547 .25118 L
.53673 .24925 L
.53789 .2478 L
.53899 .24673 L
.54015 .24593 L
.54139 .24544 L
.54209 .24534 L
.54273 .24535 L
.54391 .24565 L
.54516 .24635 L
.54628 .2473 L
.54733 .24847 L
.54971 .2521 L
.55229 .25743 L
.55464 .26346 L
.55992 .28036 L
.56883 .31454 L
.5783 .34835 L
.583 .36052 L
.58428 .3631 L
.58567 .36548 L
.58688 .36718 L
.58819 .36866 L
.58939 .36966 L
.59052 .37027 L
.5917 .37058 L
.59297 .37054 L
.59415 .37015 L
.59526 .36947 L
.59626 .3686 L
.59735 .3674 L
.59984 .36362 L
.60259 .35792 L
.60814 .34225 L
.6181 .30593 L
.62286 .28827 L
.62805 .27127 L
.63043 .26477 L
.63296 .25896 L
Mistroke
.63535 .25465 L
.6364 .25314 L
.63751 .25181 L
.63818 .25115 L
.63892 .25054 L
.64021 .24978 L
.64094 .24953 L
.64172 .24939 L
.64246 .24939 L
.64313 .24951 L
.64443 .25004 L
.64517 .25051 L
.64585 .25106 L
.64709 .25234 L
.64842 .25408 L
.65087 .25828 L
.65316 .2633 L
.65839 .27806 L
.66733 .30966 L
.67688 .34255 L
.6797 .3504 L
.68236 .35659 L
.68476 .36099 L
.68599 .36281 L
.68735 .36442 L
.68862 .36557 L
.68981 .36631 L
.69107 .36674 L
.69177 .36682 L
.69242 .3668 L
.69356 .36652 L
.69481 .36588 L
.696 .36495 L
.69709 .36381 L
.69972 .36004 L
.70219 .35523 L
.7068 .34342 L
.71714 .30862 L
.72741 .2746 L
.7299 .26806 L
.73257 .2622 L
.73411 .25943 L
.7355 .25731 L
.73683 .25568 L
.73756 .25494 L
.73824 .25435 L
.73946 .25355 L
.74011 .25326 L
.74081 .25305 L
.74206 .25294 L
Mistroke
.74319 .25315 L
.74451 .25375 L
.74526 .25426 L
.74595 .25484 L
.74731 .25626 L
.74858 .25795 L
.75106 .26217 L
.75331 .26697 L
.75836 .28059 L
.76717 .30999 L
.77685 .34126 L
.77928 .34761 L
.78189 .3534 L
.78435 .35776 L
.7866 .3607 L
.78791 .36195 L
.78913 .36277 L
.78977 .36308 L
.79047 .36331 L
.7912 .36345 L
.79189 .36347 L
.79315 .36324 L
.7943 .36273 L
.79557 .36184 L
.79691 .36055 L
.79911 .35762 L
.80147 .35347 L
.80572 .34361 L
.81537 .31369 L
.8256 .28077 L
.82841 .27331 L
.83138 .26664 L
.83391 .26212 L
.83534 .2601 L
.8367 .25855 L
.83795 .25745 L
.83866 .25697 L
.83932 .25662 L
.84048 .25622 L
.84172 .2561 L
.84242 .25618 L
.84317 .25637 L
.84389 .25667 L
.84454 .25703 L
.84579 .25797 L
.84711 .2593 L
.84951 .26259 L
.85175 .26662 L
.85685 .2787 L
.8659 .30662 L
Mistroke
.8755 .33657 L
.88051 .34876 L
.88337 .35398 L
.88467 .35589 L
.88604 .35756 L
.88721 .35869 L
.88849 .35961 L
.88965 .36017 L
.89073 .36044 L
.89201 .36045 L
.89317 .36017 L
.89382 .3599 L
.89452 .35951 L
.89578 .35856 L
.89711 .35722 L
.89834 .35568 L
.90116 .35113 L
.90685 .33815 L
.91704 .30725 L
.92668 .27879 L
.92932 .27256 L
.93212 .26707 L
.93349 .26486 L
.93477 .26309 L
.93592 .26177 L
.93717 .2606 L
.93844 .25972 L
.93914 .25938 L
.93978 .25914 L
.94094 .25893 L
.94218 .259 L
.94288 .25917 L
.94364 .25947 L
.94436 .25985 L
.94502 .26029 L
.94627 .26136 L
.94759 .26281 L
.95002 .26629 L
.9523 .27045 L
.95748 .28266 L
.97602 .33715 L
.97619 .33757 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol017oo0`00ogooMWoo000aOol30003Ool20002Ool00`00Oomoo`3oOomcOol0035o
o`03001oogoo00=oo`05001oogooOol0003oOomeOol0035oo`03001oogoo00=oo`05001oogooOol0
000TOol00`00Oomoo`3oOom>Ool0035oo`03001oogoo00=oo`05001oogooOol0000SOol3003oOom?
Ool000aoo`8000Moo`<000Aoo`H000Aoo`@000Moo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo01moo`05001oogooOol0003oOom>Ool000]oo`04001oogoo0006Ool30005Ool01@00Oomoogoo
00000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool07goo00D007ooOomoo`0002Aoo`03001oogoo0?moobMoo`002Woo00<007ooOol00Woo00<007oo
Ool00goo0`001Woo00<007ooOol02Goo00<007ooOol017oo1@001Woo00<007ooOol07Woo00<007oo
Ool00Woo00<007ooOol08Goo00@007oo00000?moobMoo`0000=oo`0000001@000Woo00<007ooOol0
0Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00D007ooOomoo`0000Moo`03001o
ogoo01eoo`03001oogoo00=oo`03001oogoo01moo`05001oogooOol0003oOolWOol000Yoo`03001o
ogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`05001o
ogooOol00007Ool00`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`0NOol00`00Oomoo`02Ool0
0`00Oomoo`0QOol3003oOol1Ool000Yoo`03001oogoo009oo`03001oogoo00moo`04001oogooOol5
0007Ool01@00Oomoogoo00001goo00<007ooOol077oo00<007ooOol01Goo00<007ooOol07Goo00<0
07ooOol00goo00<007ooOol07goo00<007ooOol00P00ogoo000:Ool00`00Oomoo`02Ool00`00Oomo
o`0?Ool01@00Oomoogoo00002goo00@007ooOol000Qoo`03001oogoo01aoo`03001oogoo00Eoo`03
001oogoo01eoo`03001oogoo00=oo`03001oogoo01moo`05001oogooOol0000SOol3003IOol000]o
o`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00@007ooOol000Uoo`03001o
ogoo01Yoo`03001oogoo00Moo`03001oogoo01]oo`03001oogoo00Eoo`03001oogoo01eoo`03001o
ogoo00=oo`03001oogoo01moo`03001oogoo00800=Qoo`0037oo0P003goo100017oo1@001goo1000
2Goo00<007ooOol06Woo00<007ooOol01goo00<007ooOol06goo00<007ooOol01Goo00<007ooOol0
7Goo00<007ooOol00goo00<007ooOol07Woo00<007ooOol00goo00<007ooOol087oo0`00/Woo000a
Ool01000Oomoo`002Goo00<007ooOol06Woo00<007ooOol01goo00<007ooOol06goo00<007ooOol0
1Goo00<007ooOol077oo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol00goo00<007ooOol0
7goo00D007ooOomoo`0002=oo`8008aoo`00<Goo00<007oo00002Woo00<007ooOol06Woo00<007oo
Ool027oo00<007ooOol06Woo00<007ooOol01Woo00<007ooOol06goo00<007ooOol01Goo00<007oo
Ool07Goo00<007ooOol00goo00<007ooOol07Woo00<007ooOol00goo00<007ooOol07goo0P0000=o
o`000000RWoo000aOol00`00Ool0000;Ool00`00Oomoo`0HOol00`00Oomoo`09Ool00`00Oomoo`0I
Ool00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomoo`0KOol00`00Oomoo`04
Ool00`00Oomoo`0NOol00`00Oomoo`03Ool00`00Oomoo`0NOol20003Ool00`00Oomoo`0POol4001T
Ool0035oo`03001oo`0000]oo`03001oogoo01Qoo`03001oogoo00Uoo`03001oogoo01Uoo`03001o
ogoo00Moo`03001oogoo01Yoo`03001oogoo00Moo`03001oogoo01]oo`03001oogoo00Eoo`03001o
ogoo01aoo`03001oogoo00Eoo`03001oogoo01eoo`03001oogoo009oo`03001oogoo01moo`8000=o
o`03001oogoo021oo`@003eoo`00<Goo00<007oo00002goo00<007ooOol067oo00<007ooOol02Goo
00<007ooOol06Goo00<007ooOol01goo00<007ooOol06Woo00<007ooOol01goo00<007ooOol06Woo
00<007ooOol01Woo00<007ooOol077oo00<007ooOol01Goo00<007ooOol077oo00<007ooOol017oo
00<007ooOol07Woo00<007ooOol00Woo00<007ooOol07goo0P000Woo0P008Woo10005Woo000aOol3
000;Ool00`00Oomoo`0HOol00`00Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomo
o`0HOol00`00Oomoo`08Ool00`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomo
o`07Ool00`00Oomoo`0KOol00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`04Ool00`00Oomo
o`0NOol00`00Oomoo`03Ool00`00Oomoo`0NOol20002Ool2000EOol0035oo`8000aoo`03001oogoo
01Moo`03001oogoo00]oo`03001oogoo01Moo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo
00Uoo`03001oogoo01Uoo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo00Moo`03001oogoo
01Yoo`03001oogoo00Ioo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo
00=oo`03001oogoo01ioo`03001oogoo009oo`03001oogoo01=oo`00<Goo0P003Goo00<007ooOol0
5Woo00<007ooOol02goo00<007ooOol05goo00<007ooOol02Goo00<007ooOol067oo00<007ooOol0
2Goo00<007ooOol067oo00<007ooOol027oo00<007ooOol06Woo00<007ooOol01goo00<007ooOol0
6Woo00<007ooOol01Woo00<007ooOol06goo00<007ooOol01Woo00<007ooOol077oo00<007ooOol0
1Goo00<007ooOol077oo00<007ooOol017oo00<007ooOol04Woo000aOol2000=Ool00`00Oomoo`0F
Ool00`00Oomoo`0;Ool00`00Oomoo`0GOol00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`0:
Ool00`00Oomoo`0HOol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomoo`09Ool00`00Oomoo`0H
Ool00`00Oomoo`08Ool00`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`05
Ool00`00Oomoo`0LOol00`00Oomoo`04Ool00`00Oomoo`0BOol0035oo`8000eoo`03001oogoo01Io
o`03001oogoo00]oo`03001oogoo00Ioo`D000Eoo`<000Aoo`H000Ioo`03001oogoo01Moo`03001o
ogoo00Yoo`03001oogoo00Aoo`D000Eoo`<000Moo`<000Uoo`03001oogoo01Qoo`03001oogoo00Uo
o`03001oogoo00D000Eoo`<000Eoo`@0009oo`03001oogoo00Qoo`03001oogoo01Yoo`03001oogoo
00Moo`D000Eoo`<000Eoo`@000Moo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo00Ioo`03
001oogoo00=oo`H000Qoo`00<Goo00<007ooOol037oo00<007ooOol05Woo00<007ooOol02goo00<0
07ooOol027oo00<007ooOol01Goo0`000goo00<007oo00000goo00<007ooOol01Goo00<007ooOol0
5Woo00<007ooOol02goo00<007ooOol01Goo00<007ooOol01Goo0`001goo0P002Woo00<007ooOol0
67oo00<007ooOol02Goo00<007ooOol00Woo00<007ooOol01Goo0`0017oo00<007ooOol00Woo00<0
07oo00002Woo00<007ooOol06Goo00<007ooOol027oo00<007oo00001goo0`0017oo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol01goo00<007ooOol06Woo00<007ooOol01Woo00<007ooOol0
17oo00D007ooOomoo`0000Qoo`00<Goo0`0037oo00<007ooOol05Goo00<007ooOol037oo00<007oo
Ool027oo00<007ooOol01Goo0`000goo00@007ooOol000Yoo`03001oogoo01Ioo`03001oogoo00]o
o`03001oogoo00Eoo`03001oogoo00Eoo`<000Aoo`H000Uoo`03001oogoo01Qoo`03001oogoo00Yo
o`05001oogooOol00007Ool30004Ool00`00Oomoo`02Ool2000<Ool00`00Oomoo`0HOol00`00Oomo
o`08Ool00`00Ool00007Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`07Ool0
0`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`09Ool0035oo`03001oogoo
00eoo`03001oogoo01Aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00]oo`05001oogoo
Ool00009Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool01@00
Ool007oo00002goo00<007ooOol05goo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oogoo
009oo`8000aoo`03001oogoo01Qoo`03001oogoo00Uoo`8000ioo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo00Eoo`03001oogoo
00Qoo`00<Goo00<007ooOol03Goo00<007ooOol057oo00<007ooOol03Goo00<007ooOol01goo00<0
07ooOol02goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol037oo00<0
07ooOol01Goo00<007ooOol03Goo0P0000=oo`00Ool02Woo00<007ooOol05Woo00<007ooOol02goo
00D007ooOomoo`0000ioo`8000=oo`8000aoo`03001oogoo01Moo`03001oogoo00Yoo`8000moo`@0
00Eoo`03001oogoo00Yoo`03001oogoo01Qoo`03001oogoo00Uoo`03001oogoo00Eoo`03001oogoo
00Moo`00<Goo00<007ooOol03Goo00<007ooOol057oo00<007ooOol03Goo00<007ooOol01goo00<0
07ooOol02Woo00<007ooOol017oo00<007ooOol01Woo00<007ooOol057oo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol03Goo0P0000=oo`00Ool02Woo00<007ooOol05Woo00<007ooOol02goo
00D007ooOomoo`0000ioo`03001oo`0000<000ioo`03001oogoo01Ioo`03001oogoo00]oo`03001o
ogoo00aoo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo01Moo`03001o
ogoo00Yoo`03001oogoo00Ioo`03001oogoo00Ioo`00<Goo00<007ooOol03Goo00<007ooOol057oo
00<007ooOol03Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol057oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo0P0000=oo`00Ool0
2Woo00<007ooOol05Woo00<007ooOol037oo00@007ooOol000moo`05001oogooOol0000>Ool00`00
Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool01@00Oomoogoo00003Woo
00<007ooOol05Woo00<007ooOol02Woo00<007ooOol01Woo00<007ooOol01Woo000aOol00`00Oomo
o`0=Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomoo`05Ool3000<Ool00`00Ool00004Ool0
0`00Oomoo`06Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomoo`02Ool3000?Ool01000Ool0
000037oo00<007ooOol057oo00<007ooOol03Goo10003goo0P000Woo00<007ooOol037oo00<007oo
Ool05Goo00<007ooOol02Woo0`003Woo00<007ooOol00Woo00D007ooOomoo`0000ioo`03001oogoo
01Ioo`03001oogoo00]oo`04001oogoo0004Ool00`00Oomoo`06Ool0035oo`03001oogoo00ioo`03
001oogoo019oo`03001oogoo00ioo`03001oogoo00Ioo`8000aoo`03001oogoo00@000Uoo`03001o
ogoo01=oo`03001oogoo00ioo`03001oogoo00=oo`8000moo`04001oogoo000<Ool00`00Oomoo`0D
Ool00`00Oomoo`0=Ool01000Ool000004Goo0`003goo00<007ooOol057oo00<007ooOol02goo0`00
3Woo100017oo00<007ooOol037oo00<007ooOol05Goo00<007ooOol037oo00@007ooOomoo`@000Uo
o`00<Goo0`003Woo00<007ooOol04Woo00<007ooOol03Woo00<007ooOol057oo00<007ooOol03Goo
00<007ooOol04goo00<007ooOol03goo00<007ooOol04goo00<007ooOol03Goo00<007ooOol057oo
00<007ooOol03Goo00<007ooOol04goo00<007ooOol03Woo00<007ooOol057oo00<007ooOol03Goo
00<007ooOol04goo00<007ooOol03Woo00<007ooOol057oo00<007ooOol037oo00<007ooOol03Woo
000aOol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0BOol00`00Oomo
o`0?Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0BOol00`00Oomoo`0>Ool00`00Oomo
o`0DOol00`00Oomoo`0=Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomo
o`0>Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomo
o`0=Ool0035oo`03001oogoo00ioo`03001oogoo019oo`03001oogoo00moo`03001oogoo019oo`03
001oogoo00moo`03001oogoo019oo`03001oogoo00moo`03001oogoo019oo`03001oogoo00moo`03
001oogoo019oo`03001oogoo00moo`03001oogoo019oo`03001oogoo00moo`03001oogoo019oo`03
001oogoo00moo`03001oogoo019oo`03001oogoo00ioo`03001oogoo01=oo`03001oogoo00ioo`03
001oogoo00eoo`00<Goo00<007ooOol03Woo00<007ooOol04Woo00<007ooOol03goo00<007ooOol0
4Woo00<007ooOol03goo00<007ooOol04Woo00<007ooOol03goo00<007ooOol04Woo00<007ooOol0
3goo00<007ooOol04Woo00<007ooOol03goo00<007ooOol04Goo00<007ooOol047oo00<007ooOol0
4Woo00<007ooOol03goo00<007ooOol04Goo00<007ooOol03goo00<007ooOol04goo00<007ooOol0
3Woo00<007ooOol03Goo000aOol00`00Oomoo`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0@Ool00`00
Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0AOol00`00Oomoo`0AOol00`00
Oomoo`0?Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00
Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool00`00Oomoo`0BOol00`00
Oomoo`0?Ool00`00Oomoo`0<Ool0035oo`03001oogoo00moo`03001oogoo011oo`03001oogoo011o
o`03001oogoo019oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015oo`03001oogoo015o
o`03001oogoo011oo`03001oogoo015oo`03001oogoo00moo`03001oogoo015oo`03001oogoo015o
o`03001oogoo011oo`03001oogoo015oo`03001oogoo011oo`03001oogoo011oo`03001oogoo015o
o`03001oogoo011oo`03001oogoo00aoo`00:7ooo`00R@00000aOol00`00Oomoo`0?Ool2000AOol2
000AOol2000AOol2000@Ool01000Oomoo`003goo00@007ooOol000moo`05001oogooOol0000=Ool0
0`00Oomoo`02Ool00`00Oomoo`0;Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`04Ool0
0`00Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`08Ool0
0`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`09Ool0
0`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool0
0`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`0<Ool01000Oomoo`002Woo000aOol00`00Oomo
o`0?Ool00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool2000COol00`00Oomoo`0@Ool0
0`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomoo`0@Ool0
0`00Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool0
0`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`08Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool0
0`00Oomoo`0BOol01000Oomoo`002Woo000aOol00`00Oomoo`0@Ool00`00Oomoo`0?Ool00`00Oomo
o`0AOol00`00Oomoo`0@Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomoo`0COol00`00Oomo
o`0?Ool00`00Oomoo`0BOol00`00Oomoo`0?Ool00`00Oomoo`0AOol00`00Oomoo`0?Ool00`00Oomo
o`0COol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0BOol00`00Oomo
o`0?Ool00`00Oomoo`0BOol00`00Oomoo`0;Ool0035oo`03001oogoo011oo`03001oogoo00ioo`03
001oogoo01=oo`03001oogoo00moo`03001oogoo019oo`03001oogoo00ioo`03001oogoo01=oo`03
001oogoo00moo`03001oogoo019oo`03001oogoo00ioo`03001oogoo019oo`03001oogoo00moo`03
001oogoo01=oo`03001oogoo00ioo`03001oogoo01=oo`03001oogoo00eoo`03001oogoo01Aoo`03
001oogoo00eoo`03001oogoo01Aoo`03001oogoo00Yoo`00<Goo00<007ooOol047oo00<007ooOol0
3Woo00<007ooOol04goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol03Woo00<007ooOol0
4goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol03Woo00<007ooOol04goo00<007ooOol0
3Woo00<007ooOol04goo00<007ooOol03Goo00<007ooOol057oo00<007ooOol03Goo00<007ooOol0
57oo00<007ooOol03Goo00<007ooOol057oo00<007ooOol02Woo000aOol3000@Ool00`00Oomoo`0>
Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0C
Ool00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`0>Ool00`00Oomoo`0COol00`00Oomoo`0=
Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomoo`0=Ool00`00Oomoo`0D
Ool00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomoo`0:Ool0035oo`03001oogoo011oo`03001o
ogoo00ioo`03001oogoo01=oo`03001oogoo00ioo`03001oogoo01=oo`03001oogoo00ioo`03001o
ogoo01=oo`03001oogoo00ioo`03001oogoo01Aoo`03001oogoo00eoo`03001oogoo01=oo`03001o
ogoo00eoo`03001oogoo01Eoo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo00aoo`03001o
ogoo01Eoo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo00Uoo`00<Goo00<007ooOol04Goo
00<007ooOol03Goo00<007ooOol057oo00<007ooOol03Goo00<007ooOol057oo00<007ooOol037oo
00<007ooOol05Goo00<007ooOol03Goo00<007ooOol057oo00<007ooOol037oo00<007ooOol05Goo
00<007ooOol037oo00<007ooOol05Goo00<007ooOol037oo00<007ooOol05Goo00<007ooOol02goo
00<007ooOol05Woo00<007ooOol02goo00<007ooOol05Woo00<007ooOol02Goo000aOol00`00Oomo
o`0AOol00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomo
o`0<Ool00`00Oomoo`0EOol00`00Oomoo`0=Ool00`00Oomoo`0DOol00`00Oomoo`0<Ool00`00Oomo
o`0EOol00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomo
o`0;Ool00`00Oomoo`0FOol00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`09Ool0035oo`03
001oogoo015oo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo00aoo`03001oogoo01Eoo`03
001oogoo00aoo`03001oogoo01Eoo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo00aoo`03
001oogoo01Eoo`03001oogoo00aoo`03001oogoo01Eoo`03001oogoo00]oo`03001oogoo01Ioo`03
001oogoo00]oo`03001oogoo01Moo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo00Qoo`00
<Goo00<007ooOol04Goo00<007ooOol037oo00<007ooOol05Goo00<007ooOol037oo00<007ooOol0
5Goo00<007ooOol037oo00<007ooOol05Goo00<007ooOol037oo00<007ooOol05Woo00<007ooOol0
2goo00<007ooOol05Woo00<007ooOol02Woo00<007ooOol05Woo00<007ooOol02goo00<007ooOol0
5goo00<007ooOol02Woo00<007ooOol05goo00<007ooOol02Goo00<007ooOol067oo00<007ooOol0
27oo000aOol3000AOol00`00Oomoo`0<Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool00`00Oomoo`0E
Ool00`00Oomoo`0;Ool00`00Oomoo`0FOol00`00Oomoo`0<Ool00`00Oomoo`0FOol00`00Oomoo`0:
Ool00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`09Ool00`00Oomoo`0H
Ool00`00Oomoo`09Ool00`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomoo`0SOol0035oo`03001o
ogoo019oo`03001oogoo00]oo`03001oogoo01Ioo`03001oogoo00]oo`03001oogoo01Ioo`03001o
ogoo00Yoo`03001oogoo01Moo`03001oogoo00Yoo`03001oogoo01Moo`03001oogoo00Yoo`03001o
ogoo01Moo`03001oogoo00Yoo`03001oogoo01Moo`03001oogoo00Uoo`03001oogoo01Qoo`03001o
ogoo00Uoo`03001oogoo01Uoo`03001oogoo00Moo`03001oogoo02Aoo`00<Goo00<007ooOol04Woo
00<007ooOol02Woo00<007ooOol05goo00<007ooOol02goo00<007ooOol05Woo00<007ooOol02Woo
00<007ooOol05goo00<007ooOol02Woo00<007ooOol067oo00<007ooOol02Goo00<007ooOol067oo
00<007ooOol02Goo00<007ooOol05goo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol027oo
00<007ooOol06Goo00<007ooOol01goo00<007ooOol097oo000aOol00`00Oomoo`0BOol00`00Oomo
o`0:Ool00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomoo`0GOol00`00Oomoo`0:Ool00`00Oomo
o`0GOol00`00Oomoo`0:Ool00`00Oomoo`0HOol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomo
o`08Ool00`00Oomoo`0IOol00`00Oomoo`07Ool00`00Oomoo`0JOol00`00Oomoo`07Ool00`00Oomo
o`0KOol00`00Oomoo`06Ool00`00Oomoo`0TOol0035oo`03001oogoo019oo`03001oogoo00Yoo`03
001oogoo01Moo`03001oogoo00Yoo`03001oogoo01Moo`03001oogoo00Uoo`03001oogoo01Qoo`03
001oogoo00Uoo`03001oogoo01Uoo`03001oogoo00Qoo`03001oogoo01Uoo`03001oogoo00Qoo`03
001oogoo01Uoo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo00Moo`03001oogoo01]oo`03
001oogoo00Eoo`03001oogoo02Eoo`00<Goo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol0
5goo00<007ooOol02Woo00<007ooOol05goo00<007ooOol02Goo00<007ooOol06Goo00<007ooOol0
27oo00<007ooOol06Woo00<007ooOol01goo00<007ooOol06Woo00<007ooOol01Woo00<007ooOol0
6Woo00<007ooOol01goo00<007ooOol06goo00<007ooOol01Goo00<007ooOol07Goo00<007ooOol0
17oo00<007ooOol09Goo000aOol3000COol00`00Oomoo`09Ool00`00Oomoo`0GOol00`00Oomoo`0:
Ool00`00Oomoo`0HOol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomoo`0J
Ool00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`05
Ool00`00Oomoo`0LOol00`00Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`02Ool2000XOol0035o
o`03001oogoo01=oo`03001oogoo00Uoo`03001oogoo01Qoo`03001oogoo00Uoo`03001oogoo01Qo
o`03001oogoo00Qoo`03001oogoo01Uoo`03001oogoo00Moo`03001oogoo01]oo`03001oogoo00Io
o`03001oogoo01]oo`03001oogoo00Eoo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo01io
o`03001oogoo00=oo`03001oogoo01moo`800003Ool0000002Uoo`00<Goo00<007ooOol04goo00<0
07ooOol027oo00<007ooOol06Goo00<007ooOol027oo00<007ooOol06Goo00<007ooOol01goo00<0
07ooOol06goo00<007ooOol01Woo00<007ooOol077oo00<007ooOol01Goo00<007ooOol077oo00<0
07ooOol017oo00<007ooOol07Goo00<007ooOol00goo00<007ooOol07goo0P000Woo00<007ooOol0
8Goo0`00:Woo000aOol00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomoo`08
Ool00`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`06Ool00`00Oomoo`0L
Ool00`00Oomoo`04Ool00`00Oomoo`0MOol00`00Oomoo`03Ool00`00Oomoo`0OOol01@00Oomoogoo
00008goo0`00DGoo000aOol00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0IOol00`00Oomo
o`08Ool00`00Oomoo`0JOol00`00Oomoo`06Ool00`00Oomoo`0KOol00`00Oomoo`05Ool00`00Oomo
o`0MOol00`00Oomoo`04Ool00`00Oomoo`0NOol01@00Oomoogoo00008goo0`00N7oo000aOol00`00
Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`0IOol00`00Oomoo`08Ool00`00Oomoo`0JOol00`00
Oomoo`05Ool00`00Oomoo`0MOol00`00Oomoo`04Ool00`00Oomoo`0NOol00`00Oomoo`02Ool00`00
Oomoo`0POol4002NOol0035oo`<001Aoo`03001oogoo00Moo`03001oogoo01Yoo`03001oogoo00Io
o`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo01eoo`03001oogoo00Aoo`03001oogoo01io
o`80009oo`03001oogoo029oo`8009moo`00<Goo00<007ooOol057oo00<007ooOol01Woo00<007oo
Ool06goo00<007ooOol01Woo00<007ooOol077oo00<007ooOol017oo00<007ooOol07Woo00<007oo
Ool00Woo00<007ooOol087oo0`00aWoo000aOol00`00Oomoo`0DOol00`00Oomoo`06Ool00`00Oomo
o`0KOol00`00Oomoo`06Ool00`00Oomoo`0LOol00`00Oomoo`03Ool00`00Oomoo`0OOol20002Ool0
0`00Oomoo`3ZOol000aoo`8000Moo`<000Aoo`H000Aoo`@000Moo`03001oogoo01Aoo`03001oogoo
00Ioo`03001oogoo01aoo`03001oogoo00Aoo`03001oogoo01ioo`03001oogoo009oo`03001oogoo
021oo`@00>aoo`002goo00@007ooOol000Ioo`<000Eoo`05001oogooOol00003Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`0LOol00`00Oomoo`04
Ool00`00Oomoo`0NOol01000Oomoogoo0P00ogoo4goo000:Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool30006Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`04Ool00`00
Oomoo`0NOol00`00Oomoo`03Ool00`00Oomoo`0OOol4003oOolDOol000Yoo`03001oogoo009oo`03
001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`@001Aoo`03001oogoo00Aoo`03001oogoo
01ioo`03001oogoo009oo`03001oogoo0?moocQoo`002Woo00<007ooOol00Woo00<007ooOol03Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol05Woo00<007ooOol00goo
00<007ooOol07goo00@007ooOol00?mooc]oo`002Woo00<007ooOol00Woo00<007ooOol03goo00@0
07ooOomoo`D000Moo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo025oo`800?moocaoo`00
2Woo00<007ooOol00Woo00<007ooOol03goo00D007ooOomoo`0000]oo`03001oogoo01Ioo`03001o
ogoo009oo`03001oogoo0?mooemoo`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogoo
Ool0000;Ool00`00Oomoo`0GOol01000Oomoo`00ogooHWoo000<Ool2000?Ool40004Ool50007Ool0
0`00Oomoo`0GOol4003oOomROol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol001Eo
o`8000Moo`<000Eoo`@000Moo`03001oogoo0?moogeoo`0057oo00@007ooOol000Ioo`<000Aoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007oo
Ool00goo0`002Goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00
Oomoo`0?Ool00`00Oomoo`04Ool4003oOomlOol001=oo`03001oogoo009oo`03001oogoo00Yoo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007oo
Ool02Woo1@001goo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo000=Ool00`00Oomoo`09Ool00`00Oomo
o`3oOommOol001Eoo`8000ioo`D000Moo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool30006Ool00`00Oomo
o`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogaoo`002Woo00<007oo
Ool00Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol0ogooOGoo000:
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`D0
00Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo
00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000Oomoo`003Goo00<007ooOol00Woo00D0
07ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P003Woo1P000goo1@001goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000VOol50006Ool00`00Oomo
o`3oOommOol002Qoo`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo1000
ogooO7oo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0
ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Ioo`<00?moohQoo`009goo0P00ogooR7oo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .38514 m
.02605 .39414 L
.02729 .3981 L
.02846 .40116 L
.02954 .40339 L
.03072 .40513 L
.0318 .40609 L
.03279 .40643 L
.03396 .40617 L
.03506 .40527 L
.03626 .40357 L
.03756 .40091 L
.03891 .39726 L
.0402 .39299 L
.04262 .38301 L
.04753 .35611 L
.0521 .32588 L
.06244 .25697 L
.06509 .24288 L
.06795 .23054 L
.06927 .22602 L
.07065 .2221 L
.07184 .21948 L
.07314 .21739 L
.07441 .21617 L
.07556 .21575 L
.0762 .21581 L
.07689 .2161 L
.07816 .21726 L
.07934 .21905 L
.08059 .22168 L
.08284 .22824 L
.0854 .23834 L
.08817 .25196 L
.09317 .28192 L
.09908 .32122 L
.10458 .35551 L
.10921 .37851 L
.1118 .38796 L
.11294 .39122 L
.11415 .39404 L
.11479 .39526 L
.1155 .39638 L
.11673 .39777 L
.11743 .39823 L
.11818 .39846 L
.11889 .39843 L
.11954 .3982 L
.12078 .39717 L
.12149 .39626 L
Mistroke
.12214 .39521 L
.12334 .39277 L
.12462 .38947 L
.12736 .38006 L
.13033 .36674 L
.13569 .3364 L
.14572 .27341 L
.15032 .24927 L
.1529 .23864 L
.15525 .23118 L
.15658 .22798 L
.15728 .2266 L
.15803 .22539 L
.15868 .22454 L
.15939 .22382 L
.16066 .22313 L
.16191 .22318 L
.16261 .22353 L
.16326 .22404 L
.16445 .22549 L
.1657 .2277 L
.16702 .23079 L
.16822 .23422 L
.17092 .24396 L
.17577 .26744 L
.18678 .33356 L
.19164 .3599 L
.1943 .37167 L
.19678 .38047 L
.1989 .38609 L
.20009 .38842 L
.20117 .39001 L
.20236 .39116 L
.20365 .39171 L
.20487 .39154 L
.206 .39079 L
.20719 .3894 L
.20847 .38722 L
.20968 .38452 L
.21079 .38153 L
.21337 .37279 L
.21608 .36116 L
.22681 .30113 L
.23171 .27335 L
.23634 .25145 L
.2389 .24211 L
.24025 .23814 L
.24167 .2347 L
.24288 .23244 L
.2442 .23066 L
Mistroke
.2454 .22968 L
.24653 .22932 L
.24766 .22951 L
.2489 .23035 L
.25006 .23174 L
.25115 .23353 L
.25319 .2382 L
.25537 .2449 L
.26036 .26598 L
.26489 .28994 L
.27425 .34241 L
.27897 .36411 L
.28165 .37359 L
.28415 .38015 L
.28555 .38279 L
.28625 .3838 L
.28689 .38457 L
.28808 .38554 L
.28938 .38592 L
.29068 .38561 L
.29141 .38512 L
.29211 .38446 L
.29283 .38356 L
.2935 .38255 L
.295 .37963 L
.29732 .37346 L
.29986 .3646 L
.30497 .34142 L
.31507 .28665 L
.32003 .26267 L
.3222 .25396 L
.3246 .24604 L
.32583 .24272 L
.32716 .23976 L
.32789 .23841 L
.32856 .23736 L
.32987 .2358 L
.3306 .23523 L
.33127 .23489 L
.33201 .23472 L
.3328 .23479 L
.33355 .23509 L
.33426 .23557 L
.33558 .237 L
.3368 .23892 L
.33808 .24154 L
.34037 .2477 L
.34285 .25623 L
.34555 .26752 L
.35561 .31915 L
Mistroke
.36055 .34403 L
.36512 .36285 L
.36767 .37081 L
.36897 .37405 L
.37037 .37685 L
.3711 .37803 L
.37177 .37894 L
.37308 .38021 L
.37382 .38063 L
.37462 .38086 L
.37537 .38084 L
.37608 .38063 L
.37738 .37973 L
.37861 .37829 L
.37971 .37652 L
.3809 .37411 L
.38358 .36693 L
.38605 .35835 L
.3959 .3119 L
.40132 .28435 L
.40646 .26193 L
.40878 .2539 L
.41124 .24714 L
.41252 .24441 L
.4132 .2432 L
.41393 .24207 L
.41522 .24058 L
.41643 .23973 L
.41753 .23944 L
.41874 .23964 L
.42 .24044 L
.42117 .2417 L
.42228 .24335 L
.42328 .24521 L
.42552 .25062 L
.43511 .28871 L
.44527 .33846 L
.44945 .35554 L
.45175 .36314 L
.45394 .3689 L
.45517 .37147 L
.45652 .37368 L
.45774 .37514 L
.45887 .37601 L
.46004 .37643 L
.4611 .37638 L
.46233 .3758 L
.46348 .37477 L
.4646 .37333 L
.46582 .37126 L
Mistroke
.46829 .36558 L
.47057 .35868 L
.4727 .35101 L
.48266 .30551 L
.48782 .28132 L
.4927 .26215 L
.4954 .25405 L
.49682 .25064 L
.49833 .24772 L
.49959 .24585 L
.50032 .24504 L
.50099 .24444 L
.50218 .24377 L
.50345 .2436 L
.50471 .244 L
.50586 .24485 L
.50718 .24639 L
.50842 .24838 L
.51064 .25315 L
.51304 .25997 L
.5185 .2806 L
.52352 .30353 L
.52879 .32812 L
.53169 .3406 L
.53444 .35109 L
.53699 .35926 L
.53833 .36287 L
.53977 .36613 L
.54097 .36836 L
.54229 .37029 L
.5435 .37154 L
.54463 .37226 L
.54573 .37254 L
.54693 .37238 L
.54818 .37168 L
.54935 .37056 L
.55044 .36909 L
.55144 .36742 L
.55367 .36257 L
.55608 .35576 L
.55869 .34675 L
.56343 .32721 L
.57325 .28311 L
.57595 .27252 L
.57884 .26278 L
.58158 .25552 L
.58289 .25279 L
.58408 .25078 L
.5853 .24917 L
.5866 .24799 L
Mistroke
.58781 .2474 L
.58894 .24729 L
.58959 .24742 L
.59027 .2477 L
.59149 .24859 L
.59281 .2501 L
.59425 .25238 L
.59666 .25758 L
.59925 .26493 L
.60392 .28192 L
.61484 .32947 L
.61965 .34785 L
.62238 .35625 L
.62372 .35968 L
.62495 .36238 L
.62608 .3645 L
.62733 .36636 L
.62857 .36775 L
.62989 .36868 L
.6312 .36906 L
.63193 .36902 L
.6326 .36884 L
.6339 .36807 L
.63513 .36685 L
.63647 .36499 L
.63789 .36242 L
.64044 .3564 L
.6462 .3372 L
.6559 .29614 L
.66124 .27514 L
.66388 .26657 L
.66632 .26006 L
.66869 .25525 L
.67002 .25327 L
.67122 .25194 L
.67254 .25099 L
.67328 .25069 L
.67396 .25058 L
.67522 .25075 L
.67586 .25102 L
.67655 .25146 L
.67777 .25261 L
.67889 .25405 L
.68139 .25859 L
.68371 .26431 L
.6859 .27089 L
.69461 .3046 L
.70421 .34278 L
.70662 .35036 L
.70921 .35704 L
Mistroke
.71047 .35966 L
.71166 .36174 L
.71283 .3634 L
.7139 .36455 L
.71513 .36546 L
.71644 .36591 L
.71766 .36586 L
.71881 .3654 L
.71946 .36495 L
.72015 .36435 L
.72138 .36291 L
.72271 .36087 L
.72417 .35806 L
.72877 .34576 L
.7337 .32809 L
.7426 .29196 L
.74753 .27425 L
.75023 .26638 L
.75276 .26052 L
.75408 .25814 L
.75549 .25611 L
.75626 .25525 L
.75707 .25453 L
.75775 .25407 L
.75851 .25373 L
.7592 .25356 L
.75984 .25353 L
.76057 .25365 L
.76126 .25391 L
.76249 .25473 L
.76318 .25538 L
.76382 .25611 L
.76623 .25985 L
.76847 .26474 L
.77359 .28003 L
.78394 .3202 L
.78891 .33851 L
.79154 .3467 L
.79433 .35386 L
.79572 .35672 L
.79702 .35895 L
.79819 .36056 L
.79946 .36187 L
.80066 .36269 L
.80193 .3631 L
.80302 .36308 L
.80421 .36266 L
.80545 .36178 L
.80663 .36055 L
.80769 .35911 L
Mistroke
.80884 .35721 L
.81141 .35173 L
.8138 .34532 L
.82274 .3135 L
.83173 .27998 L
.8342 .27247 L
.83679 .26589 L
.839 .26151 L
.84026 .25959 L
.84142 .25817 L
.84209 .25753 L
.84281 .25698 L
.84412 .25635 L
.84539 .25621 L
.84657 .25649 L
.84784 .25723 L
.84856 .25785 L
.84923 .25856 L
.8506 .26037 L
.85206 .26285 L
.85473 .26873 L
.85727 .27573 L
.86203 .2917 L
.87166 .32784 L
.8742 .33647 L
.87694 .34469 L
.87931 .35062 L
.88065 .35343 L
.8819 .35565 L
.88318 .35752 L
.88435 .35885 L
.8856 .35986 L
.88629 .36023 L
.88694 .36046 L
.88809 .36058 L
.88915 .36037 L
.89032 .35977 L
.89156 .35873 L
.8926 .35754 L
.89371 .35596 L
.89572 .35231 L
.90031 .34066 L
.91041 .30512 L
.91575 .28607 L
.91868 .27696 L
.92144 .26976 L
.92406 .26442 L
.92554 .26214 L
.9269 .26053 L
.92805 .25954 L
Mistroke
.92931 .25887 L
.93062 .25863 L
.93185 .25883 L
.93311 .25946 L
.93429 .26044 L
.93536 .26163 L
.93652 .26326 L
.93912 .26808 L
.94153 .27386 L
.97619 .35723 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3000AOol2003oOomZOol0035oo`03001oogoo015oo`03001o
o`000?moofUoo`00<Goo00<007ooOol047oo00D007ooOomoo`000?moofQoo`00<Goo00<007ooOol0
47oo00D007ooOomoo`0001eoo`<00?moodQoo`0037oo0P001goo0`0017oo1P0017oo10001goo00<0
07ooOol03goo00<007ooOol00Woo00<007ooOol06Woo0P0000=oo`00Ool0ogooAgoo000;Ool01000
Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo00moo`03001oogoo009oo`03001oogoo01Yoo`05001oogooOol0000NOol00`00Oomoo`3oOolV
Ool000Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03001oogoo00Ao
o`@000ioo`03001oogoo009oo`03001oogoo01Yoo`05001oogooOol0000MOol4003oOolVOol00003
Ool0000000D0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Ao
o`03001oogoo00moo`03001oogoo009oo`03001oogoo01Yoo`03001oogoo009oo`03001oogoo01Yo
o`04001oogoo003oOolVOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo01Qoo`03
001oogoo00=oo`03001oogoo01Uoo`05001oogooOol0000NOol3003oOol5Ool000Yoo`03001oogoo
009oo`03001oogoo00moo`04001oogooOol50007Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00
Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0JOol01@00
Oomoogoo00007Woo0P00hgoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo0000
2goo00<007ooOol03Woo00<007ooOol017oo00<007ooOol067oo00<007ooOol017oo00<007ooOol0
5goo00<007ooOol00goo00<007ooOol06Woo00D007ooOomoo`0001eoo`@00>9oo`002goo00@007oo
Ool000eoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool0
0`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0HOol0
0`00Oomoo`02Ool00`00Oomoo`0JOol01@00Oomoogoo00007Woo0P00`Woo000<Ool2000?Ool40004
Ool50007Ool3000>Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0G
Ool00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0IOol01@00Oomoogoo
00007Goo00@007ooOol001moo`03001oogoo09moo`00<Goo00<007ooOol03Goo00<007ooOol01Woo
00<007ooOol05Woo00<007ooOol01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol067oo
00<007ooOol00goo00<007ooOol06Goo00D007ooOomoo`0001eoo`05001oogooOol0000MOol3002P
Ool0035oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo00Ioo`03001o
ogoo01Eoo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo01Qoo`03001o
ogoo00=oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo01Yoo`05001oogooOol0000MOol3
001oOol0035oo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo00Ioo`03
001oogoo01Eoo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo01Moo`03
001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo01Yoo`05001oogooOol0000M
Ool01000Oomoo`007Woo0`00GGoo000aOol00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`00Oomoo`05
Ool00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0I
Ool00`00Oomoo`03Ool00`00Oomoo`0IOol01@00Oomoogoo00007Goo00@007ooOol001ioo`<003ao
o`00<Goo00<007ooOol037oo00<007ooOol027oo00<007ooOol057oo00<007ooOol01goo00<007oo
Ool05Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol05Woo00<007oo
Ool01Goo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol067oo00<007ooOol00goo00<007oo
Ool067oo00<007ooOol00goo00<007ooOol06Goo00<007ooOol00Woo00<007ooOol06Woo0P0000=o
o`0000007Goo0`006goo000aOol3000<Ool00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0F
Ool00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`05
Ool00`00Oomoo`0GOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0J
Ool01@00Oomoogoo000077oo0P000Woo00<007ooOol067oo000aOol00`00Oomoo`0<Ool00`00Oomo
o`08Ool00`00Oomoo`0DOol00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomo
o`0DOol00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomo
o`06Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomo
o`0HOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0IOol00`00Oomo
o`02Ool00`00Oomoo`0GOol0035oo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo01Aoo`03
001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo01Aoo`03001oogoo00Moo`03
001oogoo01Eoo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Ioo`03001oogoo01Ioo`03
001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo00Aoo`03
001oogoo01Qoo`03001oogoo00=oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo01Moo`00
<Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol0
4goo00<007ooOol027oo00<007ooOol04goo00<007ooOol027oo00<007ooOol057oo00<007ooOol0
1goo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol0
5Woo00<007ooOol01Woo00<007ooOol05Woo00<007ooOol01Goo00<007ooOol05goo00<007ooOol0
17oo00<007ooOol05goo00<007ooOol017oo00<007ooOol05Woo000aOol00`00Oomoo`0;Ool00`00
Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`050005Ool30004Ool60007Ool0
0`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`09Ool50005Ool30007Ool3000FOol00`00Oomo
o`07Ool00`00Oomoo`0@Ool50005Ool300000goo001oo`02Ool4000?Ool00`00Oomoo`07Ool00`00
Oomoo`0EOol00`00Oomoo`0500000goo001oo`02Ool30005Ool40009Ool00`00Oomoo`05Ool00`00
Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`08Ool60008Ool0035oo`03001oogoo00]oo`03001o
ogoo00Yoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00Eoo`<000Eo
o`80009oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Qoo`03001oogoo00]oo`03001o
ogoo00Eoo`<000Qoo`03001oogoo01Aoo`03001oogoo00Qoo`03001oogoo019oo`03001oo`0000Eo
o`<00005Ool007ooOol00004Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0EOol00`00
Oomoo`02Ool01@00Oomoogoo00000goo0`0017oo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol027oo00D007ooOomoo`0000Qoo`00
<Goo0`002goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Woo00D007ooOomoo`0000Mo
o`<000Ioo`03001oogoo00Uoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Eoo`<000Aoo`H001Eoo`03001oogoo00Qoo`03001oogoo019oo`03001oo`0000Eoo`<00005
Ool007ooOol00004Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`030004Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`07Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`09Ool0035oo`03
001oogoo00]oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo00Yoo`05001oogooOol0000@
Ool2000:Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool00`00
Oomoo`03Ool01000Oomoogoo0P005Goo00<007ooOol02Goo00<007ooOol04Goo0P002goo00<007oo
000017oo00<007ooOol037oo00<007ooOol027oo00<007ooOol057oo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol01goo00<007oo
Ool05Goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol027oo000aOol00`00Oomoo`0;Ool0
0`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool01@00Oomoogoo00003goo00@007ooOol0
00Uoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo
00Eoo`03001oogoo008001Eoo`03001oogoo00Uoo`03001oogoo015oo`8000]oo`04001oo`000003
Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02
Ool00`00Oomoo`08Ool40008Ool00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool0035oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo015o
o`03001oogoo00]oo`05001oogooOol0000?Ool01@00Oomoogoo000027oo00<007ooOol04Goo00<0
07ooOol02Woo00<007ooOol02Woo00<007ooOol01Goo00<007ooOol01Woo00@007oo000001Eoo`03
001oogoo00Uoo`03001oogoo015oo`8000]oo`04001oo`00Ool3000>Ool00`00Oomoo`09Ool00`00
Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00
Oomoo`06Ool0035oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo015oo`03001oogoo00]o
o`05001oogooOol0000?Ool01@00Oomoogoo00002Goo00<007ooOol047oo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol01Woo00D007oo001oo`0001Aoo`03001oogoo00Uo
o`03001oogoo015oo`8000]oo`04001oogoo000AOol00`00Oomoo`09Ool00`00Oomoo`0COol00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`06Ool0035o
o`03001oogoo00Yoo`03001oogoo00aoo`03001oogoo011oo`03001oogoo00]oo`03001oo`000080
00ioo`8000=oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00]oo`03001oogoo00Moo`<0
00Moo`03001oogoo00Moo`800003Ool007oo019oo`03001oogoo00Yoo`03001oogoo00moo`<000eo
o`04001oo`00000@Ool00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`02Ool30005Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00
Oomoo`09Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0035oo`03001oogoo00Yo
o`03001oogoo00aoo`03001oogoo011oo`03001oogoo00]oo`03001oogoo008000moo`@000Yoo`03
001oogoo011oo`03001oogoo00]oo`03001oogoo00Qoo`8000Moo`03001oogoo00Qoo`03001oo`00
01=oo`03001oogoo00]oo`03001oogoo00moo`8000eoo`04001oogooOol3000=Ool00`00Oomoo`0:
Ool00`00Oomoo`0AOol00`00Oomoo`03Ool20005Ool00`00Oomoo`07Ool40007Ool00`00Oomoo`0:
Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`05Ool40009Ool0035oo`<000Yoo`03001o
ogoo00aoo`03001oogoo011oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001o
ogoo011oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo015oo`03001o
ogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001o
ogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00]oo`03001oogoo015oo`03001o
ogoo00]oo`03001oogoo019oo`00<Goo00<007ooOol02Woo00<007ooOol037oo00<007ooOol047oo
00<007ooOol037oo00<007ooOol03goo00<007ooOol037oo00<007ooOol03goo00<007ooOol037oo
00<007ooOol047oo00<007ooOol037oo00<007ooOol047oo00<007ooOol02goo00<007ooOol047oo
00<007ooOol02goo00<007ooOol047oo00<007ooOol02goo00<007ooOol04Goo00<007ooOol02goo
00<007ooOol047oo00<007ooOol02goo00<007ooOol04Goo00<007ooOol02goo00<007ooOol04Woo
000aOol00`00Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomo
o`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool00`00Oomo
o`0<Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomo
o`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0@Ool00`00Oomo
o`0<Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0AOol0035oo`03001oogoo00Uoo`03
001oogoo00ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00moo`03001oogoo00eoo`03
001oogoo00ioo`03001oogoo00eoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00moo`03
001oogoo00aoo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00moo`03001oogoo00aoo`03
001oogoo00moo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00eoo`03001oogoo00moo`03
001oogoo00eoo`03001oogoo015oo`00<Goo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol0
3Woo00<007ooOol03Goo00<007ooOol03goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol0
3Goo00<007ooOol03goo00<007ooOol037oo00<007ooOol03goo00<007ooOol037oo00<007ooOol0
3goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03goo00<007ooOol0
37oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol03goo00<007ooOol03Woo00<007ooOol0
47oo000aOol00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00
Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00
Oomoo`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0>Ool00`00
Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0@Ool002Qoool008T00000<Goo
00<007ooOol02Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol01Goo
00<007ooOol01goo00<007ooOol017oo00<007ooOol02Goo00D007ooOomoo`0000eoo`04001oogoo
000?Ool00`00Oomoo`0>Ool00`00Ool0000>Ool01000Oomoo`003Goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol017oo00<007ooOol01goo00<007ooOol01Woo00<007ooOol017oo00<007oo
Ool027oo00<007ooOol00goo00<007ooOol02Woo00D007ooOomoo`0000ioo`03001oo`0000moo`03
001oogoo00ioo`03001oo`0000eoo`05001oogooOol0000=Ool00`00Oomoo`02Ool00`00Oomoo`08
Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`08Ool0035oo`03001o
ogoo00Uoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00Uoo`05001o
ogooOol0000@Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool01000Oomoo`003Goo
00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo
00<007ooOol037oo00<007ooOol03goo00<007ooOol03Goo00<007ooOol03Woo00<007oo00003Goo
00<007ooOol03goo00<007ooOol03Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol027oo
000aOol00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomo
o`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomo
o`0>Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomo
o`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomo
o`0?Ool00`00Oomoo`0=Ool00`00Oomoo`0AOol00`00Oomoo`0>Ool0035oo`03001oogoo00Qoo`03
001oogoo011oo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo011oo`03
001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00eoo`03
001oogoo00moo`03001oogoo00aoo`03001oogoo00moo`03001oogoo00aoo`03001oogoo00moo`03
001oogoo00eoo`03001oogoo00moo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00aoo`03
001oogoo019oo`03001oogoo00ioo`00<Goo00<007ooOol027oo00<007ooOol047oo00<007ooOol0
37oo00<007ooOol03goo00<007ooOol037oo00<007ooOol047oo00<007ooOol02goo00<007ooOol0
47oo00<007ooOol037oo00<007ooOol047oo00<007ooOol037oo00<007ooOol03goo00<007ooOol0
37oo00<007ooOol03goo00<007ooOol037oo00<007ooOol047oo00<007ooOol037oo00<007ooOol0
3goo00<007ooOol02goo00<007ooOol047oo00<007ooOol037oo00<007ooOol04goo00<007ooOol0
3Goo000aOol30008Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0?Ool00`00Oomoo`0<
Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0@
Ool00`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0@Ool00`00Oomoo`0;
Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`0@Ool00`00Oomoo`0;Ool00`00Oomoo`0A
Ool00`00Oomoo`0;Ool00`00Oomoo`0COol00`00Oomoo`0=Ool0035oo`03001oogoo00Qoo`03001o
ogoo011oo`03001oogoo00aoo`03001oogoo011oo`03001oogoo00]oo`03001oogoo011oo`03001o
ogoo00]oo`03001oogoo015oo`03001oogoo00]oo`03001oogoo011oo`03001oogoo00]oo`03001o
ogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001o
ogoo00]oo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00]oo`03001o
ogoo01=oo`03001oogoo00eoo`00<Goo00<007ooOol027oo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02goo00<007ooOol047oo00<007ooOol02goo00<007ooOol04Goo
00<007ooOol02goo00<007ooOol047oo00<007ooOol02goo00<007ooOol04Goo00<007ooOol02Woo
00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol04Goo
00<007ooOol02Goo00<007ooOol04Woo00<007ooOol02Woo00<007ooOol05Goo00<007ooOol037oo
000aOol00`00Oomoo`08Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`0AOol00`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomo
o`0AOol00`00Oomoo`0;Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomo
o`0:Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`0AOol00`00Oomoo`09Ool00`00Oomo
o`0COol00`00Oomoo`09Ool00`00Oomoo`0EOol00`00Oomoo`0<Ool0035oo`03001oogoo00Qoo`03
001oogoo015oo`03001oogoo00Yoo`03001oogoo015oo`03001oogoo00Yoo`03001oogoo019oo`03
001oogoo00Uoo`03001oogoo019oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo00Uoo`03
001oogoo01=oo`03001oogoo00Qoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo01=oo`03
001oogoo00Uoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Uoo`03
001oogoo01Ioo`03001oogoo00]oo`00<Goo00<007ooOol027oo00<007ooOol04Goo00<007ooOol0
2Woo00<007ooOol04Goo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol0
4Woo00<007ooOol02Woo00<007ooOol04Woo00<007ooOol02Goo00<007ooOol04goo00<007ooOol0
27oo00<007ooOol04goo00<007ooOol027oo00<007ooOol04goo00<007ooOol02Goo00<007ooOol0
4goo00<007ooOol027oo00<007ooOol04goo00<007ooOol027oo00<007ooOol05goo00<007ooOol0
2goo000aOol30008Ool00`00Oomoo`0AOol00`00Oomoo`0:Ool00`00Oomoo`0BOol00`00Oomoo`09
Ool00`00Oomoo`0BOol00`00Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`0B
Ool00`00Oomoo`09Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08
Ool00`00Oomoo`0DOol00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0D
Ool00`00Oomoo`07Ool00`00Oomoo`0GOol00`00Oomoo`0;Ool0035oo`03001oogoo00Moo`03001o
ogoo019oo`03001oogoo00Yoo`03001oogoo019oo`03001oogoo00Uoo`03001oogoo019oo`03001o
ogoo00Uoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Uoo`03001o
ogoo01=oo`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo00Qoo`03001oogoo01Aoo`03001o
ogoo00Moo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Moo`03001o
ogoo01Qoo`03001oogoo00Yoo`00<Goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol02Goo
00<007ooOol04goo00<007ooOol027oo00<007ooOol04goo00<007ooOol02Goo00<007ooOol04goo
00<007ooOol027oo00<007ooOol057oo00<007ooOol027oo00<007ooOol04goo00<007ooOol01goo
00<007ooOol05Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01goo00<007ooOol05Goo
00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol06Goo00<007ooOol02Woo
000aOol00`00Oomoo`07Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0COol00`00Oomo
o`08Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`08Ool00`00Oomo
o`0DOol00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomo
o`06Ool00`00Oomoo`0FOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomo
o`0FOol00`00Oomoo`05Ool00`00Oomoo`0JOol00`00Oomoo`09Ool0035oo`03001oogoo00Moo`03
001oogoo01=oo`03001oogoo00Qoo`03001oogoo01=oo`03001oogoo00Qoo`03001oogoo01Aoo`03
001oogoo00Moo`03001oogoo01Eoo`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo00Moo`03
001oogoo01Eoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo01Ioo`03
001oogoo00Eoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo01Moo`03001oogoo00Aoo`03
001oogoo01]oo`03001oogoo00Uoo`00<Goo00<007ooOol01goo00<007ooOol04goo00<007ooOol0
27oo00<007ooOol057oo00<007ooOol01goo00<007ooOol057oo00<007ooOol01goo00<007ooOol0
5Goo00<007ooOol01goo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol0
1Goo00<007ooOol05goo00<007ooOol017oo00<007ooOol05goo00<007ooOol01Goo00<007ooOol0
5goo00<007ooOol017oo00<007ooOol067oo00<007ooOol00goo00<007ooOol06goo00<007ooOol0
2Goo000aOol30007Ool00`00Oomoo`0COol00`00Oomoo`08Ool00`00Oomoo`0DOol00`00Oomoo`07
Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0F
Ool00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04
Ool00`00Oomoo`0HOol00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`0I
Ool20003Ool00`00Oomoo`0MOol00`00Oomoo`08Ool0035oo`03001oogoo00Moo`03001oogoo01=o
o`03001oogoo00Qoo`03001oogoo01Aoo`03001oogoo00Ioo`03001oogoo01Eoo`03001oogoo00Mo
o`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo01Ioo`03001oogoo00Eoo`03001oogoo01Mo
o`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo01Qoo`03001oogoo00=o
o`03001oogoo01Uoo`05001oogooOol0000MOol200000goo0000000ZOol0035oo`03001oogoo00Mo
o`03001oogoo01=oo`03001oogoo00Moo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo01Io
o`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo00Eoo`03001oogoo01Ioo`03001oogoo00Eo
o`03001oogoo01Moo`03001oogoo00=oo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo01Yo
o`05001oogooOol0000MOol01000Oomoo`007Woo0P00;7oo000aOol00`00Oomoo`06Ool00`00Oomo
o`0EOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`00Oomo
o`05Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomo
o`0HOol00`00Oomoo`03Ool00`00Oomoo`0JOol01@00Oomoogoo000077oo0P0000=oo`0000007Woo
0P00CGoo000aOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0FOol0
0`00Oomoo`05Ool00`00Oomoo`0FOol00`00Oomoo`05Ool00`00Oomoo`0GOol00`00Oomoo`04Ool0
0`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0IOol01@00Oomoogoo00007Goo00@007ooOol0
01ioo`<006ioo`00<Goo00<007ooOol01Woo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol0
5Woo00<007ooOol017oo00<007ooOol05goo00<007ooOol01Goo00<007ooOol067oo00<007ooOol0
0goo00<007ooOol067oo00<007ooOol00goo00<007ooOol06Goo0P000Woo00<007ooOol077oo0`00
Sgoo000aOol30006Ool00`00Oomoo`0EOol00`00Oomoo`06Ool00`00Oomoo`0FOol00`00Oomoo`04
Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`0J
Ool01@00Oomoogoo00007Goo1000/7oo000aOol00`00Oomoo`06Ool00`00Oomoo`0EOol00`00Oomo
o`05Ool00`00Oomoo`0GOol00`00Oomoo`04Ool00`00Oomoo`0HOol00`00Oomoo`03Ool00`00Oomo
o`0IOol00`00Oomoo`02Ool00`00Oomoo`0JOol200000goo001oo`3AOol0035oo`03001oogoo00Eo
o`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo01Qoo`03001oogoo00=oo`03001oogoo01Qo
o`03001oogoo00=oo`03001oogoo01Yoo`04001oogoo000NOol3003BOol000aoo`8000Moo`<000Ao
o`H000Aoo`@000Moo`03001oogoo00Eoo`03001oogoo01Moo`03001oogoo00Aoo`03001oogoo01Qo
o`03001oogoo009oo`03001oogoo01Yoo`05001oogooOol0000MOol4003cOol000]oo`04001oogoo
0006Ool30005Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
1Goo00<007ooOol05goo00<007ooOol017oo00<007ooOol067oo00<007ooOol00Woo00<007ooOol0
6goo00@007ooOol001ioo`800?Aoo`002Woo00<007ooOol00Woo00<007ooOol00goo0`001Woo00<0
07ooOol02Goo00<007ooOol017oo00<007ooOol01Goo00<007ooOol067oo00<007ooOol00goo00<0
07ooOol06Goo00D007ooOomoo`0001eoo`<00?mooaIoo`002Woo00<007ooOol00Woo00<007ooOol0
3Goo00<007ooOol027oo00<007ooOol017oo100017oo00<007ooOol067oo00<007ooOol00Woo00<0
07ooOol06Woo00@007ooOol001moo`03001oogoo0?mooaEoo`002Woo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo00<007oo
Ool06Goo00<007ooOol00Woo00<007ooOol06Woo0P0000=oo`00Ool0ogoo=Woo000:Ool00`00Oomo
o`02Ool00`00Oomoo`0?Ool01000Oomoogoo1@001goo0P001Goo00<007ooOol06Goo00D007ooOomo
o`0001ioo`800?moocQoo`002Woo00<007ooOol00Woo00<007ooOol03goo00D007ooOomoo`0000]o
o`8000Eoo`03001oogoo01Yoo`04001oogoo003oOomHOol000]oo`04001oogoo000=Ool00`00Oomo
o`02Ool01@00Oomoogoo00002goo00<007oo00000goo00<007ooOol06goo1000ogooF7oo000<Ool2
000?Ool40004Ool50007Ool00`00Ool00003Ool00`00Oomoo`3oOomgOol0035oo`@00003Ool007oo
0?moogUoo`00<Goo00<007ooOol00`00ogooNWoo000aOol01@00Oomoogoo0000ogooNgoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3
003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000EOol20007Ool30005Ool40007Ool0
0`00Oomoo`3oOommOol001Aoo`04001oogoo0006Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00=oo`<000Uoo`03001oogoo
00Aoo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo
1000ogooO7oo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo
0?moogeoo`004goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogoo
OGoo000DOol01000Oomoo`003Goo00<007ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool5
0007Ool00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`0037oo0P001goo0`001Woo00<007ooOol01Goo10001goo00<007ooOol0
ogooOGoo000;Ool01000Oomoo`001Woo0`001goo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30007Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool4003oOomlOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03
001oogoo00Qoo`03001oogoo00Aoo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000:
Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool50007Ool00`00Oomoo`3oOommOol0
00Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo
0?moogeoo`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomo
o`3oOommOol000aoo`8000ioo`H000=oo`D000Moo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo0?moogeoo`009Woo1@001Woo00<007ooOol0ogooOGoo000XOol00`00Oomo
o`06Ool00`00Oomoo`3oOommOol002Qoo`03001oogoo00Ioo`@00?moogaoo`00:7oo00<007ooOol0
ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0
ogooQWoo000VOol3003oOon8Ool002Moo`800?moohQoo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21125 m
.04262 .29924 L
.04754 .33849 L
.0522 .37078 L
.05477 .38477 L
.05613 .39073 L
.05756 .39588 L
.05877 .39922 L
.05941 .40061 L
.0601 .40181 L
.06131 .40316 L
.06244 .40354 L
.06314 .40336 L
.06378 .4029 L
.06448 .40208 L
.06523 .40086 L
.06662 .39763 L
.06788 .39368 L
.07044 .38281 L
.07286 .36951 L
.08255 .29871 L
.0877 .26133 L
.09051 .24438 L
.09313 .23185 L
.09451 .22678 L
.09598 .22257 L
.09681 .22076 L
.09761 .21945 L
.09832 .21862 L
.0991 .21808 L
.09975 .21793 L
.10048 .21808 L
.10123 .2186 L
.10194 .21941 L
.10321 .22166 L
.10393 .22336 L
.10458 .22518 L
.1145 .27854 L
.11996 .31899 L
.12511 .35506 L
.12744 .36885 L
.12991 .38089 L
.1312 .38595 L
.13262 .39047 L
.13391 .39357 L
.13511 .39557 L
.13629 .39666 L
.1374 .3969 L
.1384 .39646 L
.1395 .39527 L
Mistroke
.14068 .39318 L
.14194 .39004 L
.1442 .38217 L
.15312 .32996 L
.16252 .26445 L
.1649 .25091 L
.16744 .23905 L
.1689 .23367 L
.17023 .22976 L
.17087 .22823 L
.17157 .22684 L
.17284 .22503 L
.17397 .22422 L
.17523 .22422 L
.17653 .22522 L
.17776 .22708 L
.17891 .22959 L
.17995 .23252 L
.18231 .24124 L
.1849 .2538 L
.18731 .26776 L
.19277 .30441 L
.19853 .34359 L
.20105 .35854 L
.20376 .37217 L
.20504 .37743 L
.20638 .38213 L
.20763 .38565 L
.20879 .38817 L
.20988 .38984 L
.21105 .39088 L
.21235 .39111 L
.21353 .39047 L
.21417 .38979 L
.21486 .3888 L
.21609 .38636 L
.21741 .38283 L
.21888 .37788 L
.22149 .36654 L
.22395 .35341 L
.23376 .28934 L
.23635 .27302 L
.23912 .25755 L
.24168 .24572 L
.24294 .24097 L
.2441 .23727 L
.24516 .23451 L
.24632 .23215 L
.24749 .23052 L
.24873 .22962 L
Mistroke
.24978 .22953 L
.2509 .23012 L
.25196 .23132 L
.25293 .23296 L
.25416 .23575 L
.25531 .23903 L
.25789 .24877 L
.2626 .27323 L
.26768 .30546 L
.27318 .34053 L
.2757 .35473 L
.27837 .36743 L
.28064 .37595 L
.28193 .3797 L
.28314 .38245 L
.2843 .38438 L
.28555 .38566 L
.28674 .38609 L
.28784 .3858 L
.28883 .38499 L
.28992 .38348 L
.29106 .38125 L
.29212 .37856 L
.29454 .37046 L
.29676 .36084 L
.30175 .33336 L
.31091 .27656 L
.31355 .26245 L
.31604 .25127 L
.31827 .2434 L
.31953 .23997 L
.32069 .2375 L
.32197 .23556 L
.32317 .23453 L
.32449 .23426 L
.32523 .23452 L
.3259 .235 L
.32661 .23575 L
.32726 .23667 L
.32873 .23956 L
.33003 .24298 L
.33142 .24748 L
.33666 .27126 L
.3414 .29895 L
.34626 .32873 L
.35079 .35346 L
.35326 .3644 L
.35552 .37227 L
.3568 .37575 L
.35802 .37833 L
Mistroke
.3593 .38025 L
.36003 .38098 L
.3607 .38141 L
.36199 .38159 L
.3632 .38098 L
.3639 .38029 L
.36453 .37945 L
.36597 .37684 L
.36734 .37342 L
.36883 .36873 L
.37156 .35786 L
.38153 .30237 L
.38684 .27246 L
.38945 .26016 L
.39185 .25093 L
.39403 .24458 L
.39513 .2422 L
.39634 .24024 L
.39755 .23899 L
.39885 .23846 L
.40008 .23874 L
.4012 .23963 L
.4025 .24144 L
.40315 .24266 L
.40388 .24423 L
.40635 .25139 L
.40925 .26282 L
.41196 .27599 L
.42217 .33376 L
.42463 .34645 L
.42726 .35821 L
.42974 .36707 L
.43091 .3704 L
.43199 .37294 L
.43321 .37516 L
.43453 .37678 L
.4357 .37752 L
.43693 .37758 L
.43757 .37732 L
.43826 .37683 L
.43951 .37535 L
.44027 .3741 L
.44099 .37267 L
.44234 .36936 L
.44456 .36227 L
.44693 .35271 L
.45119 .33159 L
.46084 .27837 L
.46346 .26611 L
.46621 .25546 L
Mistroke
.46857 .24864 L
.4699 .24582 L
.47115 .2439 L
.47184 .24315 L
.47259 .24258 L
.47331 .24228 L
.47396 .24222 L
.47521 .24267 L
.47653 .24393 L
.47721 .24489 L
.47794 .24616 L
.47926 .24906 L
.48228 .25833 L
.48474 .26824 L
.48742 .28099 L
.49282 .31008 L
.49745 .33491 L
.50246 .35717 L
.5038 .3618 L
.50522 .36596 L
.50654 .36908 L
.50776 .37134 L
.50891 .37285 L
.51014 .37381 L
.51085 .37405 L
.51151 .37406 L
.51276 .37354 L
.51389 .37247 L
.51508 .3707 L
.5161 .36871 L
.51723 .36599 L
.51974 .35819 L
.5221 .34888 L
.53231 .29679 L
.535 .28304 L
.53788 .26987 L
.54055 .25972 L
.54186 .25562 L
.54307 .25242 L
.54421 .24992 L
.54548 .24781 L
.54675 .24639 L
.54745 .24591 L
.5481 .24566 L
.54925 .24569 L
.55031 .24623 L
.55153 .24747 L
.55268 .24924 L
.55395 .25181 L
.55529 .25525 L
Mistroke
.55772 .26313 L
.56321 .28726 L
.5679 .31151 L
.57285 .33646 L
.57707 .35409 L
.57947 .36168 L
.58054 .36439 L
.58171 .36682 L
.5824 .36801 L
.58304 .36892 L
.58431 .37022 L
.58545 .37079 L
.58667 .37078 L
.58798 .37004 L
.5892 .36868 L
.58991 .36762 L
.59055 .36647 L
.592 .36328 L
.59459 .35563 L
.59742 .34479 L
.60313 .31772 L
.60856 .29019 L
.61123 .27782 L
.6137 .26783 L
.61589 .26041 L
.6183 .25419 L
.61956 .25184 L
.62073 .25021 L
.62197 .24912 L
.62266 .24879 L
.6233 .24866 L
.62451 .2489 L
.6258 .24984 L
.62701 .25136 L
.62811 .25325 L
.62941 .2561 L
.63082 .25987 L
.63336 .26838 L
.64291 .31247 L
.64823 .33772 L
.65113 .34935 L
.65383 .35802 L
.65615 .36343 L
.65744 .36557 L
.65862 .36694 L
.65991 .36778 L
.66064 .36795 L
.66132 .36791 L
.66255 .36734 L
.66387 .36606 L
Mistroke
.66507 .36428 L
.66638 .36169 L
.66877 .35537 L
.67327 .33879 L
.68338 .29098 L
.68797 .27163 L
.69054 .2631 L
.69175 .2598 L
.69287 .25721 L
.6939 .25521 L
.69504 .2535 L
.69619 .25228 L
.6974 .25158 L
.69847 .25144 L
.69961 .25182 L
.70069 .25265 L
.70168 .25382 L
.70285 .2557 L
.70396 .25794 L
.70648 .26464 L
.71158 .28379 L
.72074 .32647 L
.72561 .34639 L
.72805 .35422 L
.72945 .35786 L
.73073 .36057 L
.73213 .36288 L
.73291 .36383 L
.73364 .36451 L
.73494 .36521 L
.73567 .36531 L
.73634 .36521 L
.73754 .36459 L
.73885 .36328 L
.73951 .36237 L
.74022 .36121 L
.7415 .35864 L
.75105 .32461 L
.75629 .30033 L
.76123 .27903 L
.76404 .26901 L
.76552 .26462 L
.76709 .26073 L
.7684 .2581 L
.7691 .25696 L
.76985 .25593 L
.77117 .25465 L
.77239 .25405 L
.77309 .25397 L
.77373 .25406 L
Mistroke
.77443 .25434 L
.77518 .25485 L
.77643 .25618 L
.77714 .25719 L
.77781 .25832 L
.78019 .26357 L
.78275 .27121 L
.79285 .31372 L
.79836 .33734 L
.80105 .34691 L
.80349 .35392 L
.80457 .35645 L
.80575 .35874 L
.80685 .36045 L
.80788 .36164 L
.80896 .36247 L
.81015 .36287 L
.8114 .36271 L
.81256 .36203 L
.81385 .3607 L
.81506 .35888 L
.81735 .3541 L
.81981 .34712 L
.82249 .33771 L
.83266 .2939 L
.83508 .28392 L
.83764 .27457 L
.84001 .26733 L
.84222 .26208 L
.84344 .25986 L
.84475 .25806 L
.84549 .25731 L
.8462 .25679 L
.84752 .2563 L
.84821 .25631 L
.84894 .25651 L
.85026 .25736 L
.85099 .25811 L
.85168 .25899 L
.85324 .26159 L
.85575 .26745 L
.85804 .27441 L
.86321 .29423 L
.8724 .33327 L
.87504 .34276 L
.87753 .35017 L
.87977 .35529 L
.88103 .35746 L
.88219 .35897 L
.88348 .3601 L
Mistroke
.88468 .36061 L
.886 .36056 L
.88674 .36026 L
.88742 .35981 L
.88812 .35916 L
.88878 .35841 L
.89025 .35617 L
.89155 .3536 L
.89294 .35028 L
.89768 .33508 L
.90291 .31378 L
.90783 .29299 L
.91051 .28262 L
.91301 .27418 L
.91532 .26772 L
.91742 .26322 L
.91863 .26128 L
.91976 .2599 L
.92096 .25892 L
.92226 .25844 L
.92355 .25856 L
.92477 .25921 L
.92546 .25982 L
.9261 .26052 L
.92753 .2626 L
.9289 .26521 L
.93039 .26872 L
.93311 .27666 L
.94311 .31609 L
.94744 .33321 L
.94957 .34054 L
.95152 .34639 L
.95327 .35076 L
.95518 .35452 L
.95617 .35601 L
.9571 .35711 L
.95808 .35794 L
.95913 .35847 L
.96028 .35861 L
.96133 .35833 L
.96249 .35758 L
.96372 .35628 L
.96479 .35475 L
.96578 .35298 L
.96806 .34783 L
.97198 .33584 L
.97619 .31981 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`8001]oo`<00?moof1oo`00<Goo0P00
6goo00<007oo0000ogooH7oo000aOol2000KOol01000Oomoo`006Woo0P00ogoo@goo000<Ool20007
Ool30004Ool60004Ool40007Ool2000JOol01@00Oomoogoo00006Goo0`00ogoo@goo000;Ool01000
Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`8001Yo
o`05001oogooOol0000IOol00`00Ool0003oOom3Ool000Yoo`03001oogoo009oo`03001oogoo00=o
o`<000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`@001Moo`03001oogoo009oo`03001oogoo01Mo
o`04001oogoo000JOol2003oOolVOol00003Ool0000000D0009oo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oo`0001Qoo`03001oogoo009oo`03001oogoo
01Ioo`05001oogooOol0000IOol01000Oomoo`006Woo0P00ogoo2Goo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Ool0000HOol0
0`00Oomoo`03Ool00`00Oomoo`0EOol01@00Oomoogoo00006Goo00@007ooOol001Yoo`<00?moo`Qo
o`002Woo00<007ooOol00Woo00<007ooOol03goo00@007ooOomoo`D000Moo`03001oo`0001Moo`03
001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo009oo`03
001oogoo01Ioo`04001oogoo000JOol3003ZOol000Yoo`03001oogoo009oo`03001oogoo00moo`05
001oogooOol0000;Ool01000Oomoo`005Woo00<007ooOol017oo00<007ooOol057oo00<007ooOol0
0goo00<007ooOol05Goo00<007ooOol00Woo00<007ooOol05Woo00@007ooOol001Uoo`800003Ool0
07oo01Yoo`03001oogoo0<aoo`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogooOol0
000;Ool01000Oomoo`005Woo00<007ooOol017oo00<007ooOol057oo00<007ooOol00goo00<007oo
Ool05Goo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol00Woo00<007ooOol05Woo00<007oo
Ool00P006Goo0`00cGoo000<Ool2000?Ool40004Ool50007Ool4000FOol00`00Oomoo`04Ool00`00
Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`04Ool00`00Oomoo`0DOol00`00
Oomoo`02Ool00`00Oomoo`0FOol01@00Oomoogoo00006Goo00@007oo000001Yoo`800;1oo`00<Goo
00@007ooOol001Ioo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo01=o
o`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo00=o
o`03001oogoo01Eoo`05001oogooOol0000IOol01000Ool000006Woo0P00Tgoo000aOol01@00Oomo
ogoo00005Goo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol04goo00<0
07ooOol017oo00<007ooOol04goo00<007ooOol00goo00<007ooOol05Goo00<007ooOol00goo00<0
07ooOol05Goo00D007ooOomoo`0001Qoo`05001oogooOol0000IOol01000Oomoo`006Woo0P00MWoo
000aOol01@00Oomoogoo000057oo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol01Goo00<0
07ooOol04Woo00<007ooOol01Goo00<007ooOol04goo00<007ooOol017oo00<007ooOol057oo00<0
07ooOol00goo00<007ooOol057oo00<007ooOol00Woo00<007ooOol05Woo00D007ooOomoo`0001Qo
o`05001oogooOol0000IOol01000Oomoo`006Woo0`00F7oo000aOol01@00Oomoogoo000057oo00<0
07ooOol01Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol01Woo00<0
07ooOol04Woo00<007ooOol017oo00<007ooOol04goo00<007ooOol017oo00<007ooOol057oo00<0
07ooOol00goo00<007ooOol05Goo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol00Woo00<0
07ooOol05Woo00@007ooOol001Uoo`800003Ool007oo01Uoo`<003]oo`00<Goo00D007ooOomoo`00
01Aoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo
00Ioo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo00Eoo`03001oogoo
01=oo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo
009oo`03001oogoo01Eoo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol0000HOol20000
0goo0000000IOol3000NOol0035oo`<00003Ool007oo01=oo`03001oogoo00Moo`03001oogoo015o
o`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Eo
o`03001oogoo019oo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo01Ao
o`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo009o
o`03001oogoo01Ioo`05001oogooOol0000HOol01@00Oomoogoo00006Goo00@007ooOol001eoo`00
<Goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol04Goo00<007ooOol0
1Woo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol0
4Woo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol017oo00<007ooOol057oo00<007ooOol0
17oo00<007ooOol057oo00<007ooOol00Woo00<007ooOol05Goo00<007ooOol00goo00<007ooOol0
57oo00<007ooOol00goo00<007ooOol05Goo00D007ooOomoo`0001Qoo`03001oogoo009oo`03001o
ogoo01Yoo`00<Goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol04Goo
00<007ooOol01Woo00<007ooOol047oo00<007ooOol01goo00<007ooOol04Goo00<007ooOol01Woo
00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol04Woo
00<007ooOol01Goo00<007ooOol04goo00<007ooOol017oo00<007ooOol057oo00<007ooOol00goo
00<007ooOol057oo00<007ooOol00goo00<007ooOol057oo00<007ooOol00goo00<007ooOol057oo
00<007ooOol00goo00<007ooOol06Woo000aOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomo
o`07Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomo
o`0@Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomo
o`05Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomo
o`0COol00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomo
o`03Ool00`00Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`0JOol0035oo`03001oogoo009oo`03
001oogoo015oo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00Eoo`D000Eoo`<000Aoo`H0
00Qoo`03001oogoo011oo`03001oogoo00Moo`03001oogoo00aoo`D000Eoo`<00003Ool007oo00Ao
o`<000]oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00Ioo`03001oo`0000@000Eoo`<0
00Eoo`@000Aoo`03001oogoo01=oo`03001oogoo00Eoo`03001oogoo00moo`D000Eoo`<000Eoo`@0
00Yoo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo00aoo`H000Qoo`00
<Goo00<007ooOol00goo00<007ooOol03goo00<007ooOol02Goo00<007ooOol03goo00<007ooOol0
1goo0P001goo0`001Goo00D007oo001oo`0000Qoo`03001oogoo00moo`03001oogoo00Qoo`03001o
ogoo00ioo`03001oo`0000Eoo`<00003Ool007oo00Eoo`03001oogoo00Uoo`03001oogoo00Ioo`03
001oogoo019oo`03001oogoo00Ioo`05001oogooOol00007Ool30004Ool20003Ool01@00Oomoogoo
00005Goo00<007ooOol01Goo00<007ooOol04Goo0P001Woo0`0017oo00<007ooOol00Woo00<007oo
Ool01goo00<007ooOol01Goo00<007ooOol04goo00<007ooOol017oo00<007ooOol037oo00D007oo
Oomoo`0000Qoo`00<Goo0`000goo00<007ooOol03goo00<007ooOol02Goo00<007ooOol03goo00<0
07ooOol01goo0P001goo0`001Woo0P002Woo00<007ooOol03goo00<007ooOol027oo00<007ooOol0
3Woo00<007oo00001Goo0`0000Aoo`00Oomoo`H000Yoo`03001oogoo00Moo`03001oogoo011oo`03
001oogoo00Moo`05001oogooOol00007Ool30004Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`0B
Ool00`00Oomoo`05Ool00`00Oomoo`0AOol00`00Oomoo`05Ool30004Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00
Oomoo`09Ool0035oo`03001oogoo00=oo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00mo
o`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qo
o`03001oogoo00ioo`03001oo`0000Uoo`04001oogoo0003Ool00`00Oomoo`09Ool00`00Oomoo`07
Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool01@00Oomoogoo00003Woo0P000goo00<007ooOol00Woo
00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol01Goo
00<007ooOol03Woo00<007ooOol027oo000aOol00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomo
o`09Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool20009Ool00`00Oomoo`0?Ool0
0`00Oomoo`08Ool00`00Oomoo`0>Ool2000:Ool01@00Oomoogoo00000Woo00<007ooOol02Goo00<0
07ooOol01goo00<007ooOol047oo00<007ooOol01goo00D007ooOomoo`0000ioo`8000=oo`03001o
ogoo009oo`03001oogoo015oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001o
ogoo00=oo`@000Uoo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo00mo
o`03001oogoo00Moo`00<Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol02Goo00<007oo
Ool03goo00<007ooOol027oo00<007ooOol03Woo00@007ooOol000Uoo`03001oogoo00ioo`03001o
ogoo00Qoo`03001oogoo00ioo`8000Yoo`03001oogoo009oo`03001oo`0000]oo`03001oogoo00Mo
o`03001oogoo011oo`03001oogoo00Qoo`04001oogoo000>Ool00`00Ool000020005Ool00`00Oomo
o`0AOol00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomo
o`0?Ool00`00Oomoo`06Ool0035oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Uoo`03
001oogoo00moo`03001oogoo00Qoo`03001oogoo00ioo`04001oogoo0009Ool00`00Oomoo`0>Ool0
0`00Oomoo`09Ool00`00Oomoo`0=Ool2000;Ool01`00Oomoogoo001oo`0000Yoo`03001oogoo00Qo
o`03001oogoo011oo`03001oogoo00Qoo`04001oogoo000>Ool20009Ool00`00Oomoo`0@Ool00`00
Oomoo`07Ool00`00Oomoo`0?Ool20009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`06
Ool0035oo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo00moo`03001o
ogoo00Ioo`<000ioo`03001oo`00009oo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Yo
o`03001oogoo00]oo`@000]oo`03001oogoo009oo`8000Yoo`03001oogoo00Qoo`03001oogoo011o
o`03001oogoo00Qoo`@000ioo`<000Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00io
o`<000Yoo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool0
0`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0035oo`03001oogoo
00Aoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00Qoo`8000moo`@0
00Yoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00aoo`<000]oo`03001oogoo00=oo`03
001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`04001oo`00000>Ool0
0`00Oomoo`030005Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool2000:Ool00`00
Oomoo`02Ool40008Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`07Ool00`00Oomoo`0;
Ool40009Ool0035oo`<000Aoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00eoo`03001o
ogoo00Uoo`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00Yoo`03001o
ogoo00ioo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo00ioo`03001o
ogoo00Yoo`03001oogoo00ioo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Uoo`03001o
ogoo00ioo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo00moo`03001o
ogoo00Qoo`03001oogoo01Moo`00<Goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol02goo
00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Goo
00<007ooOol02Woo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol02Goo
00<007ooOol03Woo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol027oo00<007ooOol03goo
00<007ooOol02Goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Woo00<007ooOol02Goo
00<007ooOol03goo00<007ooOol027oo00<007ooOol05goo000aOol00`00Oomoo`05Ool00`00Oomo
o`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomo
o`0<Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomo
o`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomo
o`0=Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0GOol0035oo`03
001oogoo00Eoo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00Yoo`03
001oogoo00aoo`03001oogoo00aoo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00eoo`03
001oogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03001oogoo00ioo`03001oogoo00Yoo`03
001oogoo00eoo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00eoo`03
001oogoo00]oo`03001oogoo00aoo`03001oogoo00]oo`03001oogoo00eoo`03001oogoo00Yoo`03
001oogoo01Ioo`00<Goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
3Goo00<007ooOol02Woo00<007ooOol037oo00<007ooOol037oo00<007ooOol037oo00<007ooOol0
2Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol0
2Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
3Goo00<007ooOol02Woo00<007ooOol05Woo000aOol00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0:Ool00`00
Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00
Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0FOol002Qoool008T00000<Goo
00<007ooOol01Woo00<007ooOol01goo00@007ooOol000moo`03001oogoo00]oo`05001oogooOol0
000:Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`09Ool01000Oomoo`003Goo00<007oo
000037oo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00Woo00<007oo
Ool02goo00<007ooOol037oo00@007ooOol000]oo`03001oogoo00Aoo`03001oogoo00Eoo`03001o
ogoo00Moo`05001oogooOol0000>Ool00`00Oomoo`0;Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool01000Oomoo`0037oo00<007oo00003Goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol01goo00<007ooOol00Woo00<007ooOol02Woo
00<007ooOol027oo000aOol00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomo
o`0;Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomo
o`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool01@00Oomo
ogoo00003Woo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol02Woo00@0
07ooOol000aoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00aoo`03001oogoo00Yoo`03
001oogoo00Qoo`00<Goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol0
2goo00<007ooOol037oo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol0
2Woo00<007ooOol03Goo00<007ooOol02goo00<007ooOol037oo00<007ooOol02goo00<007ooOol0
37oo00<007ooOol02goo00<007ooOol03Goo00<007ooOol02Woo00<007ooOol03Goo00<007ooOol0
2goo00<007ooOol037oo00<007ooOol05Goo000aOol00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00
Oomoo`0=Ool00`00Oomoo`0;Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00
Oomoo`0:Ool00`00Oomoo`0<Ool00`00Oomoo`0;Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00
Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00
Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00
Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool0035o
o`03001oogoo00Ioo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00]oo`03001oogoo00ao
o`03001oogoo00Yoo`03001oogoo00ioo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00Yo
o`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00Yoo`03001oogoo00io
o`03001oogoo00Yoo`03001oogoo00eoo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uo
o`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo00io
o`03001oogoo00Uoo`03001oogoo00Qoo`00<Goo0`001Woo00<007ooOol02Woo00<007ooOol03Goo
00<007ooOol02Woo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol02Goo
00<007ooOol03Woo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol03Woo
00<007ooOol02Woo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol02Goo
00<007ooOol03Woo00<007ooOol02Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol03goo
00<007ooOol02Goo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol027oo000aOol00`00Oomo
o`06Ool00`00Oomoo`0:Ool00`00Oomoo`0=Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomo
o`09Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomo
o`0?Ool00`00Oomoo`08Ool00`00Oomoo`0>Ool00`00Oomoo`0:Ool00`00Oomoo`0>Ool00`00Oomo
o`09Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomo
o`0?Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomo
o`09Ool00`00Oomoo`08Ool0035oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo00ioo`03
001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03
001oogoo00ioo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00moo`03
001oogoo00Qoo`03001oogoo00moo`03001oogoo00Uoo`03001oogoo00ioo`03001oogoo00Uoo`03
001oogoo00ioo`03001oogoo00Uoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo011oo`03
001oogoo00Qoo`03001oogoo00moo`03001oogoo00Moo`03001oogoo00Uoo`00<Goo00<007ooOol0
1goo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol03Woo00<007ooOol0
2Goo00<007ooOol03goo00<007ooOol027oo00<007ooOol03Woo00<007ooOol02Goo00<007ooOol0
3goo00<007ooOol027oo00<007ooOol03goo00<007ooOol027oo00<007ooOol047oo00<007ooOol0
1goo00<007ooOol047oo00<007ooOol027oo00<007ooOol03goo00<007ooOol01goo00<007ooOol0
4Goo00<007ooOol01goo00<007ooOol047oo00<007ooOol01goo00<007ooOol047oo00<007ooOol0
1goo00<007ooOol02Goo000aOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00
Oomoo`09Ool00`00Oomoo`0>Ool00`00Oomoo`09Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00
Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00
Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00
Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00
Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`09Ool0035oo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo00Qo
o`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo00mo
o`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03001oogoo011oo`03001oogoo00Mo
o`03001oogoo011oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo015o
o`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Moo`03001oogoo015oo`03001oogoo00Io
o`03001oogoo00Uoo`00<Goo0`001goo00<007ooOol027oo00<007ooOol03goo00<007ooOol027oo
00<007ooOol047oo00<007ooOol027oo00<007ooOol03goo00<007ooOol027oo00<007ooOol03goo
00<007ooOol01goo00<007ooOol04Goo00<007ooOol01goo00<007ooOol03goo00<007ooOol027oo
00<007ooOol047oo00<007ooOol01goo00<007ooOol047oo00<007ooOol01goo00<007ooOol047oo
00<007ooOol01goo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol01Goo
00<007ooOol04Woo00<007ooOol01Goo00<007ooOol02Woo000aOol00`00Oomoo`07Ool00`00Oomo
o`08Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`08Ool00`00Oomo
o`0?Ool00`00Oomoo`07Ool00`00Oomoo`0@Ool00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomo
o`06Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomo
o`0AOol00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`05Ool00`00Oomoo`0COol00`00Oomo
o`04Ool00`00Oomoo`0COol00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomo
o`0:Ool0035oo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo00Qoo`03
001oogoo011oo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Moo`03001oogoo011oo`03
001oogoo00Moo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Ioo`03
001oogoo019oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo019oo`03
001oogoo00Eoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo00Eoo`03
001oogoo01=oo`03001oogoo00Aoo`03001oogoo00Yoo`00<Goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol047oo00<007ooOol01goo00<007ooOol047oo00<007ooOol01goo00<007ooOol0
4Goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Goo00<007ooOol0
1Woo00<007ooOol04Goo00<007ooOol01Woo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol0
4Woo00<007ooOol01Goo00<007ooOol04Woo00<007ooOol01Goo00<007ooOol04goo00<007ooOol0
17oo00<007ooOol057oo00<007ooOol00goo00<007ooOol057oo00<007ooOol00goo00<007ooOol0
2goo000aOol00`00Oomoo`07Ool00`00Oomoo`08Ool00`00Oomoo`0@Ool00`00Oomoo`06Ool00`00
Oomoo`0AOol00`00Oomoo`07Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00
Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00Oomoo`0AOol00`00Oomoo`06Ool00`00
Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0BOol00`00Oomoo`05Ool00`00Oomoo`0COol00`00
Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`03Ool00`00
Oomoo`0DOol00`00Oomoo`03Ool00`00Oomoo`0;Ool0035oo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo011oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Ioo`03001oogoo015o
o`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00Eo
o`03001oogoo019oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo01=o
o`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo009o
o`03001oogoo01Eoo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol0000>Ool0035oo`<0
00Qoo`03001oogoo00Moo`03001oogoo011oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo
00Ioo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00Eoo`03001oogoo
01=oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo
00Aoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo
01Eoo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol0000HOol200000goo001oo`0>Ool0
035oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo
019oo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo019oo`03001oogoo
00Eoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo
01Aoo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo
009oo`03001oogoo01Ioo`04001oogoo000JOol00`00Ool0000JOol3000?Ool0035oo`03001oogoo
00Qoo`03001oogoo00Ioo`03001oogoo015oo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo
00Eoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo
01=oo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo
009oo`03001oogoo01Eoo`03001oogoo009oo`03001oogoo01Ioo`05001oogooOol0000IOol4000J
Ool2000]Ool0035oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Ao
o`03001oogoo01=oo`03001oogoo00Eoo`03001oogoo01=oo`03001oogoo00Aoo`03001oogoo01=o
o`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo01Aoo`03001oogoo009o
o`03001oogoo01Ioo`05001oogooOol0000HOol01@00Oomoogoo00006Goo10006Woo0P00BWoo000a
Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`0BOol00`00Oomoo`04Ool00`00Oomoo`0D
Ool00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`03
Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`0EOol00`00Oomoo`02Ool00`00Oomoo`0F
Ool00`00Oomoo`02000IOol00`00Ool0000KOol00`00Oomoo`1VOol0035oo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00Aoo`03
001oogoo01=oo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo009oo`03001oogoo01Eoo`03
001oogoo009oo`03001oogoo01Ioo`05001oogooOol0000HOol200000goo001oo`0JOol00`00Oomo
o`23Ool0035oo`<000Qoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo
01Aoo`03001oogoo00Aoo`03001oogoo01=oo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo
009oo`03001oogoo01Eoo`05001oogooOol0000IOol200000goo001oo`0JOol00`00Oomoo`2POol0
035oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo019oo`03001oogoo00Aoo`03001oogoo
01Aoo`03001oogoo00=oo`03001oogoo01Eoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo
009oo`03001oogoo01Ioo`04001oogoo000JOol2002oOol0035oo`03001oogoo00Qoo`03001oogoo
00Eoo`03001oogoo01Aoo`03001oogoo009oo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo
01Eoo`05001oogooOol0000HOol01@00Oomoogoo00006Woo0P00g7oo000<Ool20007Ool30004Ool6
0004Ool40007Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`02Ool0
0`00Oomoo`0EOol00`00Oomoo`03Ool00`00Oomoo`0EOol01@00Oomoogoo00006Goo00<007oo0000
nGoo000;Ool01000Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo009oo`03001o
ogoo01Ioo`05001oogooOol0000IOol01000Oomoo`006Woo0P00nGoo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool30006Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomo
o`04Ool00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0FOol01@00Oomoogoo00006Goo0`00
ogoo5goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`04Ool4
0008Ool00`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0GOol00`00Ool0
000KOol00`00Oomoo`3oOolFOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo01Io
o`05001oogooOol0000IOol3003oOoldOol000Yoo`03001oogoo009oo`03001oogoo00moo`04001o
ogooOol50007Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`0FOol01000Oomoo`006Woo
0P00ogoo=Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00002goo00<007oo
Ool02goo00D007ooOomoo`0001Qoo`800003Ool007oo0?mooe1oo`002goo00@007ooOol000eoo`03
001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`0;Ool01000Oomoo`006Woo0P00ogooDWoo
000<Ool2000?Ool40004Ool50007Ool00`00Oomoo`0;Ool01000Oomoo`00ogooKWoo000aOol3000<
Ool2003oOom_Ool0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03
001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000EOol20007Ool30005Ool40007Ool00`00
Oomoo`3oOommOol001Aoo`04001oogoo0006Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Ao
o`03001oogoo0?moogeoo`004goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo1000
ogooO7oo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?mo
ogeoo`004goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo
000DOol01000Oomoo`003Goo00<007ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007
Ool00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03
001oogoo0?moogeoo`0037oo0P001goo0`001Woo00<007ooOol01Goo10001goo00<007ooOol0ogoo
OGoo000;Ool01000Oomoo`001Woo0`001goo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`03Ool30007Ool00`00Oomo
o`08Ool00`00Oomoo`04Ool4003oOomlOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00Qoo`03001oogoo00Aoo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol0
3Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000:Ool0
0`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool50007Ool00`00Oomoo`3oOommOol000Yo
o`03001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo0?mo
ogeoo`002goo00@007ooOol000eoo`03001oogoo009oo`05001oogooOol0000;Ool00`00Oomoo`3o
OommOol000aoo`8000ioo`H000=oo`D000Moo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3o
OommOol0035oo`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`009Woo1@001Woo00<007ooOol0ogooOGoo000XOol00`00Oomoo`06
Ool00`00Oomoo`3oOommOol002Qoo`03001oogoo00Ioo`@00?moogaoo`00:7oo00<007ooOol0ogoo
QWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogoo
QWoo000VOol3003oOon8Ool002Moo`800?moohQoo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39695 m
.03279 .33387 L
.03793 .28706 L
.04262 .24903 L
.04517 .23294 L
.04634 .22701 L
.04758 .22182 L
.0489 .21763 L
.05012 .21503 L
.05143 .21364 L
.05218 .2135 L
.05288 .2138 L
.05412 .21535 L
.05529 .21799 L
.05634 .22131 L
.05749 .22591 L
.06006 .23959 L
.06244 .2559 L
.06749 .29775 L
.07295 .34506 L
.07545 .36417 L
.0781 .38089 L
.08036 .3916 L
.08164 .39602 L
.08284 .39898 L
.08355 .40019 L
.08432 .40104 L
.08504 .40139 L
.08572 .40133 L
.08699 .4002 L
.08763 .39912 L
.08834 .39756 L
.08981 .39308 L
.09138 .38648 L
.09424 .37034 L
.09963 .32925 L
.10458 .28716 L
.10932 .25147 L
.11197 .23621 L
.11323 .23055 L
.11438 .22632 L
.11548 .22324 L
.11663 .22097 L
.1178 .21976 L
.11907 .21968 L
.12018 .22065 L
.12136 .22276 L
.12248 .22574 L
.1235 .22927 L
.12614 .24166 L
Mistroke
.12858 .25683 L
.13412 .29966 L
.13938 .34238 L
.14168 .359 L
.1442 .37441 L
.14668 .38588 L
.14804 .39038 L
.1493 .39337 L
.15001 .39453 L
.15069 .39527 L
.15195 .39571 L
.15266 .39542 L
.15332 .3948 L
.15404 .39374 L
.1548 .3922 L
.15598 .38897 L
.15725 .3844 L
.15954 .37347 L
.16477 .33857 L
.16944 .30142 L
.17442 .26391 L
.17684 .2489 L
.17912 .23766 L
.18012 .23378 L
.18117 .23041 L
.18232 .22761 L
.18339 .22589 L
.18453 .22499 L
.18575 .2251 L
.1869 .22623 L
.18796 .22813 L
.18919 .23136 L
.19054 .23606 L
.19298 .24753 L
.19843 .28343 L
.20347 .32247 L
.206 .34141 L
.20874 .35964 L
.21115 .37289 L
.21247 .37873 L
.2137 .3832 L
.21498 .38681 L
.21567 .38825 L
.21639 .38943 L
.21769 .39058 L
.21887 .39056 L
.2196 .39005 L
.22028 .38923 L
.22102 .38795 L
.2218 .38617 L
Mistroke
.22312 .38225 L
.22458 .37663 L
.22707 .36415 L
.22978 .34718 L
.23472 .31098 L
.23959 .27518 L
.24171 .26148 L
.244 .24887 L
.24541 .24251 L
.2467 .23771 L
.24794 .23412 L
.24925 .23145 L
.24991 .23054 L
.25062 .22991 L
.25191 .22969 L
.2527 .23014 L
.25344 .23095 L
.25411 .23202 L
.25483 .23352 L
.25604 .23678 L
.25737 .24145 L
.26006 .25404 L
.26489 .28465 L
.27432 .35143 L
.27661 .36438 L
.27906 .37528 L
.28047 .37996 L
.28175 .38312 L
.28303 .3852 L
.28425 .38613 L
.28557 .386 L
.28623 .38547 L
.28697 .38455 L
.28826 .38203 L
.28947 .3787 L
.2909 .37362 L
.2922 .36796 L
.29513 .35217 L
.29997 .31982 L
.30511 .28342 L
.30778 .26646 L
.3103 .25301 L
.31255 .24365 L
.31382 .23967 L
.31499 .2369 L
.31609 .23509 L
.31712 .23413 L
.31824 .23389 L
.31945 .23457 L
.32071 .23632 L
Mistroke
.32191 .23892 L
.32298 .24201 L
.32415 .24614 L
.32664 .25742 L
.32938 .27305 L
.33493 .31053 L
.33969 .34249 L
.34239 .35789 L
.34489 .36934 L
.34621 .37404 L
.3474 .37742 L
.34806 .37892 L
.34878 .38023 L
.35008 .38177 L
.35133 .38221 L
.35265 .38157 L
.35378 .38013 L
.35502 .37763 L
.35623 .37428 L
.35733 .37049 L
.35981 .35962 L
.36429 .33364 L
.36955 .29824 L
.37243 .27952 L
.37513 .26396 L
.37762 .25227 L
.3799 .24432 L
.38113 .24125 L
.38243 .23903 L
.38374 .23786 L
.38448 .23768 L
.38516 .23782 L
.38636 .23877 L
.38765 .24081 L
.38887 .24367 L
.39 .24707 L
.39213 .25537 L
.39439 .26649 L
.40424 .32892 L
.409 .3561 L
.41038 .36235 L
.41168 .36745 L
.41286 .37131 L
.41412 .37456 L
.41485 .37602 L
.41552 .37706 L
.41681 .37833 L
.41754 .37858 L
.41832 .37849 L
.41906 .37806 L
Mistroke
.41974 .37736 L
.42096 .37541 L
.42165 .37391 L
.4223 .37226 L
.425 .36293 L
.42761 .35063 L
.43002 .33706 L
.43547 .30239 L
.44018 .27371 L
.44269 .26105 L
.444 .25544 L
.44538 .25045 L
.44654 .24704 L
.44781 .24417 L
.44896 .24236 L
.45003 .24139 L
.45113 .24112 L
.45214 .24151 L
.45329 .24272 L
.45439 .24458 L
.45555 .24731 L
.45678 .25099 L
.45898 .25949 L
.46395 .2857 L
.4734 .34335 L
.47613 .35671 L
.47747 .36217 L
.47871 .36646 L
.47981 .36959 L
.48103 .37229 L
.48225 .37416 L
.48355 .37518 L
.4847 .37526 L
.48592 .37449 L
.48696 .37314 L
.48809 .37097 L
.48932 .36783 L
.49063 .36361 L
.493 .35395 L
.50187 .30323 L
.50683 .27449 L
.50955 .26166 L
.51209 .25247 L
.51342 .24897 L
.5141 .24753 L
.51484 .24625 L
.51565 .24521 L
.51642 .24456 L
.51717 .24426 L
.51786 .24428 L
Mistroke
.51856 .24457 L
.51921 .2451 L
.52044 .24674 L
.52176 .24944 L
.52318 .2534 L
.52562 .26239 L
.52829 .27502 L
.53368 .30596 L
.5383 .33325 L
.54074 .34604 L
.54333 .35743 L
.54462 .36206 L
.54605 .36624 L
.54735 .36914 L
.54857 .37103 L
.54982 .37211 L
.55096 .37233 L
.55221 .37172 L
.55354 .37013 L
.55465 .36805 L
.55584 .36511 L
.55798 .35809 L
.56053 .34718 L
.56284 .33538 L
.56813 .30486 L
.57373 .27405 L
.57603 .26379 L
.5785 .25519 L
.57992 .25157 L
.58122 .24917 L
.58252 .24767 L
.58376 .2471 L
.58497 .24736 L
.58607 .24829 L
.58733 .25017 L
.58852 .25271 L
.59065 .25896 L
.59294 .26794 L
.60295 .32209 L
.60822 .34893 L
.61088 .35903 L
.61239 .36339 L
.61306 .36499 L
.61379 .36646 L
.61508 .36839 L
.61631 .36939 L
.6175 .3696 L
.6186 .3691 L
.61979 .36784 L
.6211 .3656 L
Mistroke
.62247 .36234 L
.62375 .35848 L
.6287 .33746 L
.63412 .30788 L
.63889 .28195 L
.64151 .26979 L
.64398 .26053 L
.64515 .25703 L
.64639 .25404 L
.64704 .25277 L
.64776 .25163 L
.64901 .25025 L
.65015 .24972 L
.65137 .24991 L
.65252 .25081 L
.65358 .25223 L
.65472 .2544 L
.65577 .25697 L
.65816 .26463 L
.6625 .2839 L
.67147 .3322 L
.67392 .34389 L
.67651 .35415 L
.67872 .36077 L
.67998 .36353 L
.68114 .36541 L
.6818 .36618 L
.68252 .36675 L
.68383 .36712 L
.6851 .36662 L
.68627 .36542 L
.68754 .36336 L
.68894 .36019 L
.69176 .35115 L
.69424 .34075 L
.69691 .32768 L
.70174 .30179 L
.70664 .27719 L
.70932 .26631 L
.71186 .25859 L
.7133 .25546 L
.71411 .25414 L
.71486 .2532 L
.71549 .25263 L
.71618 .25224 L
.71691 .25209 L
.71758 .25219 L
.71827 .25253 L
.71892 .25307 L
.72015 .25465 L
Mistroke
.72146 .25716 L
.72289 .26079 L
.7253 .26883 L
.72796 .28006 L
.73333 .30735 L
.73795 .33124 L
.74056 .34313 L
.74299 .35231 L
.74537 .35909 L
.74606 .36058 L
.7467 .36179 L
.74791 .36352 L
.74921 .36457 L
.7504 .36481 L
.75171 .36425 L
.75237 .36365 L
.7531 .36275 L
.7543 .36069 L
.7554 .35823 L
.75788 .3508 L
.76236 .33204 L
.7676 .3053 L
.77048 .29067 L
.77319 .27817 L
.77572 .2683 L
.77705 .26402 L
.77845 .26029 L
.77964 .25781 L
.78094 .25583 L
.78212 .25473 L
.78322 .25431 L
.78441 .25452 L
.7857 .25553 L
.78691 .2572 L
.78804 .25935 L
.79016 .26493 L
.79242 .27275 L
.80226 .31982 L
.80702 .3417 L
.80969 .35133 L
.81096 .35498 L
.81213 .35778 L
.81351 .36028 L
.81424 .36125 L
.81501 .36202 L
.81575 .36248 L
.81645 .36268 L
.81775 .36243 L
.81906 .36135 L
.82027 .35965 L
Mistroke
.8216 .35703 L
.82301 .35344 L
.83321 .3099 L
.83822 .28559 L
.84043 .27629 L
.84287 .26771 L
.84391 .26468 L
.84504 .26191 L
.84601 .25994 L
.84707 .25827 L
.84821 .25705 L
.8494 .25641 L
.85051 .25642 L
.85154 .25695 L
.85277 .25821 L
.85393 .26004 L
.85497 .26218 L
.8561 .26501 L
.85864 .2731 L
.86097 .28238 L
.87026 .32657 L
.87281 .3377 L
.87554 .34778 L
.87687 .35175 L
.87812 .35491 L
.87925 .35719 L
.88048 .35904 L
.88117 .35979 L
.88182 .36029 L
.88303 .36072 L
.88434 .36041 L
.88508 .3599 L
.88575 .35921 L
.88689 .3576 L
.88813 .35519 L
.89064 .34845 L
.89333 .33882 L
.8962 .32644 L
.90139 .30166 L
.90634 .2797 L
.90884 .27079 L
.91028 .26661 L
.91159 .26347 L
.91302 .26086 L
.91377 .25984 L
.91456 .25903 L
.91525 .25856 L
.9159 .25831 L
.9166 .25825 L
.91735 .25843 L
Mistroke
.91804 .25883 L
.91879 .25949 L
.91949 .26035 L
.92014 .26133 L
.92137 .26367 L
.92267 .2668 L
.92506 .27417 L
.92763 .28402 L
.93226 .30498 L
.93774 .33025 L
.94014 .33992 L
.9428 .34871 L
.94379 .35136 L
.94485 .35379 L
.94577 .35553 L
.94678 .35703 L
.94785 .35815 L
.94898 .35879 L
.95003 .35886 L
.95101 .3585 L
.95217 .35751 L
.95327 .35605 L
.95425 .3543 L
.95532 .35197 L
.95773 .34518 L
.95994 .33729 L
.97619 .26962 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol027oo0P00ogooLgoo000aOol30008Ool2003oOomcOol0035oo`03001oogoo00Mo
o`04001oogoo003oOombOol0035oo`03001oogoo00Moo`04001oogoo000GOol2003oOomIOol0035o
o`03001oogoo00Moo`04001oogoo000FOol00`00Ool0003oOomIOol000aoo`8000Moo`<000Aoo`H0
00Aoo`@000Moo`03001oogoo00Moo`05001oogooOol0000EOol01000Oomoo`005goo0P00ogoo?goo
000;Ool01000Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo01=oo`04001oogoo000FOol00`00Ool0
003oOoloOol000Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03001o
ogoo00Aoo`@000Eoo`03001oogoo009oo`03001oogoo019oo`05001oogooOol0000FOol01000Oomo
o`005Woo0`00ogoo9Goo00000goo000000050002Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0AOol01@00
Oomoogoo00005Goo00D007ooOomoo`0001Ioo`04001oo`00000GOol2003oOol;Ool000Yoo`03001o
ogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oogoo00=oo`03001oogoo015oo`03001oogoo009oo`03001oogoo019oo`05001o
ogooOol0000FOol01000Oomoo`005Woo00<007oo0000ogoo2goo000:Ool00`00Oomoo`02Ool00`00
Oomoo`0?Ool01000Oomoogoo1@001goo00<007ooOol01Woo00<007ooOol00goo00<007ooOol04Goo
00<007ooOol00Woo00<007ooOol04Woo00D007ooOomoo`0001Eoo`05001oogooOol0000FOol01000
Oomoo`005Woo0`00l7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00002goo
00<007ooOol01Woo00<007ooOol00goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Woo
00D007ooOomoo`0001Eoo`03001oogoo009oo`03001oogoo01=oo`04001oogoo000FOol00`00Ool0
000HOol2003FOol000]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Woo00<0
07ooOol00Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00D007ooOomoo`0001Eo
o`05001oogooOol0000FOol00`00Ool0000HOol2002lOol000aoo`8000moo`@000Aoo`D000Moo`<0
00Eoo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo
00=oo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03001oogoo009oo`03001oogoo
019oo`05001oogooOol0000EOol01@00Oomoogoo00005Woo00<007oo000067oo00<007ooOol0XGoo
000aOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomo
o`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomo
o`02Ool00`00Oomoo`0BOol01@00Oomoogoo00005Goo00D007ooOomoo`0001Ioo`04001oogoo000F
Ool3000HOol00`00Oomoo`27Ool0035oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo011o
o`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Ao
o`03001oogoo011oo`03001oogoo00=oo`03001oogoo019oo`05001oogooOol0000EOol01@00Oomo
ogoo00005Goo00D007ooOomoo`0001Eoo`04001oogoo000GOol00`00Ool0000HOol00`00Oomoo`1]
Ool0035oo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00Aoo`03001o
ogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo011oo`03001o
ogoo00Aoo`03001oogoo015oo`03001oogoo009oo`03001oogoo019oo`05001oogooOol0000EOol0
1@00Oomoogoo00005Goo00D007ooOomoo`0001Eoo`80009oo`03001oogoo01Aoo`03001oo`0001Mo
o`8005Eoo`00<Goo00<007ooOol01Goo00<007ooOol017oo00<007ooOol047oo00<007ooOol017oo
00<007ooOol047oo00<007ooOol017oo00<007ooOol03goo00<007ooOol01Goo00<007ooOol047oo
00<007ooOol017oo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Goo00<007ooOol00goo
00<007ooOol04Woo00D007ooOomoo`0001Eoo`05001oogooOol0000EOol01@00Oomoogoo00005Woo
00@007ooOol001Ioo`03001oo`0001Moo`<003Yoo`00<Goo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol047oo00<007ooOol017oo00<007ooOol03goo00<007ooOol01Goo00<007ooOol03goo
00<007ooOol01Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol047oo00<007ooOol00goo
00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Woo
00<007ooOol00Woo00<007ooOol04Woo00D007ooOomoo`0001Eoo`05001oogooOol0000EOol01@00
Oomoogoo00005Goo0P0000=oo`00Ool05Woo0`0087oo000aOol30004Ool00`00Oomoo`05Ool00`00
Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00
Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00
Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0AOol00`00
Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0BOol01@00Oomoogoo00005Goo
00D007ooOomoo`0001Eoo`05001oogooOol0000FOol00`00Ool0000POol0035oo`03001oogoo00Ao
o`03001oogoo00Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo00Eo
o`03001oogoo00moo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo011o
o`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00=o
o`03001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo009oo`03001oogoo015o
o`03001oogoo009oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo019oo`05001oogooOol0
000EOol01@00Oomoogoo00007goo000aOol00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0?
Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`06
Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`04Ool00`00Oomoo`0@
Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`04
Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`0A
Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`02
Ool00`00Oomoo`0MOol0035oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00ioo`03001o
ogoo00Ioo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Ioo`03001o
ogoo00ioo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo00moo`03001o
ogoo00Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo00Aoo`03001o
ogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo015oo`03001o
ogoo00=oo`03001oogoo015oo`03001oogoo009oo`03001oogoo019oo`03001oogoo009oo`03001o
ogoo019oo`03001oogoo00Qoo`00<Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol03Woo
00<007ooOol01Woo00<007ooOol03Woo00@007ooOomoo`H000Aoo`<000Aoo`H000Qoo`03001oogoo
00ioo`03001oogoo00Ioo`03001oogoo00ioo`H0009oo`03001oogoo00<000Moo`<0009oo`03001o
ogoo00Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00aoo`D000Eoo`<000Eoo`@000Qo
o`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo00Uoo`D000=oo`03001o
o`0000800003Ool007oo009oo`@000aoo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00=o
o`03001oogoo00ioo`H000Qoo`00<Goo00<007ooOol017oo00<007ooOol01Woo00<007ooOol03Woo
00<007ooOol01Woo00<007ooOol03Woo00<007ooOol00goo00@007ooOol000Aoo`<000Eoo`05001o
ogooOol00008Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool01000Oomoo`0017oo
00<007ooOol00`0027oo00D007ooOomoo`0000Moo`03001oogoo00moo`03001oogoo00Eoo`03001o
ogoo00ioo`8000Ioo`<000Aoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00Aoo`03001o
ogoo00moo`03001oogoo00Aoo`03001oogoo00]oo`03001oogoo00=oo`03001oo`0000800005Ool0
07ooOol00004Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool0
0`00Oomoo`0?Ool01@00Ool007oo000027oo000aOol30004Ool00`00Oomoo`06Ool00`00Oomoo`0>
Ool00`00Oomoo`06Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool01000Oomoo`0017oo0`001Woo00@0
07ooOol000Qoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`05001oogooOol00005
Ool00`00Ool000020004Ool60002Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool0
0`00Oomoo`0>Ool20006Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`05Ool0
0`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`030000
1Goo001oogoo000017oo00<007ooOol027oo00<007ooOol017oo00<007ooOol047oo00<007ooOol0
17oo00<007ooOol047oo00<007ooOol02Goo000aOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool01000Oomoo`003Woo00<0
07oo00002Goo00<007ooOol037oo00<007ooOol01goo00<007ooOol03Goo00D007ooOomoo`0000Eo
o`03001oogoo00Ioo`05001oogooOol00003Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomo
o`05Ool00`00Oomoo`0>Ool20008Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`05Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Ool00004Ool00`00Oomoo`08Ool00`00Oomoo`05Ool00`00Oomoo`0?Ool0
0`00Oomoo`04Ool00`00Oomoo`0@Ool2000:Ool0035oo`03001oogoo00=oo`03001oogoo00Moo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Aoo`05001oogooOol0000>
Ool20009Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool01@00Oomoogoo00001Goo
00<007ooOol01goo00@007ooOol000=oo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Eo
o`03001oogoo00ioo`8000Qoo`03001oogoo009oo`8000=oo`03001oogoo00Aoo`03001oogoo00Io
o`03001oogoo00ioo`03001oogoo00Eoo`03001oogoo00Yoo`03001oogoo009oo`03001oogoo00Eo
o`03001oogoo00@000Yoo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo
00moo`03001oo`0000Uoo`00<Goo00<007ooOol00goo00<007ooOol01goo00<007ooOol03Goo00<0
07ooOol01goo00<007ooOol03Goo00<007ooOol017oo00D007ooOomoo`0000ioo`8000Uoo`03001o
ogoo00aoo`03001oogoo00Qoo`03001oogoo00aoo`05001oogooOol00005Ool00`00Oomoo`08Ool0
0`00Ool00002Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool0
0`00Oomoo`07Ool00`00Oomoo`02Ool00`00Ool000020007Ool00`00Oomoo`06Ool00`00Oomoo`0=
Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Ool00004
Ool00`00Oomoo`07Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0?
Ool01000Oomoo`0027oo000aOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00
Oomoo`07Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool01@00Oomoogoo00003Woo0P002Goo00<007oo
Ool037oo00<007ooOol027oo00<007ooOol037oo00D007ooOomoo`0000Eoo`03001oogoo00Qoo`03
001oo`00009oo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo00Qoo`03001oogoo00Ioo`03001oogoo00eoo`03
001oogoo00Ioo`03001oogoo00Yoo`05001oogooOol00008Ool00`00Ool00004Ool00`00Oomoo`07
Ool00`00Oomoo`06Ool00`00Oomoo`0>Ool00`00Oomoo`06Ool00`00Oomoo`0?Ool01000Oomoo`00
27oo000aOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00
Oomoo`0=Ool00`00Oomoo`02Ool30003Ool00`00Oomoo`08Ool01000Oomoogoo0P002Goo00<007oo
Ool037oo00<007ooOol027oo00<007ooOol02goo00<007ooOol00`001Goo00<007ooOol02Goo0P00
0Woo00<007ooOol01goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol02goo0`002Goo00<0
07ooOol00goo0P0027oo00<007ooOol01goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0
1goo0`000goo00<007ooOol01Woo00<007oo000017oo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol03Goo00<007ooOol01Woo00<007ooOol03Goo0P000goo00<007ooOol01Woo000aOol00`00
Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00
Oomoo`03Ool20003Ool00`00Oomoo`09Ool4000:Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00
Oomoo`0;Ool01000Oomoogoo0P001Woo00<007ooOol02Goo00@007ooOol000Uoo`03001oogoo00eo
o`03001oogoo00Moo`03001oogoo00aoo`8000Uoo`03001oogoo00Eoo`<000Eoo`03001oogoo00Mo
o`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00Qoo`8000=oo`03001oogoo00Moo`03001o
o`0000<000Uoo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`@0
00Uoo`00<Goo0`000goo00<007ooOol027oo00<007ooOol037oo00<007ooOol027oo00<007ooOol0
2goo00<007ooOol02Goo00<007ooOol037oo00<007ooOol027oo00<007ooOol02goo00<007ooOol0
2Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol037oo00<007ooOol027oo00<007ooOol0
37oo00<007ooOol01goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol03Goo00<007ooOol0
27oo00<007ooOol037oo00<007ooOol01goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0
37oo00<007ooOol027oo00<007ooOol03Goo00<007ooOol01goo00<007ooOol03Goo00<007ooOol0
2Woo000aOol00`00Oomoo`03Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00
Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00
Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00
Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00
Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00
Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0=Ool00`00
Oomoo`0:Ool0035oo`03001oogoo009oo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Uo
o`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00Yo
o`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Uo
o`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00ao
o`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00Qo
o`03001oogoo00aoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00ao
o`03001oogoo00]oo`00<Goo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol02goo00<007oo
Ool02Goo00<007ooOol02goo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Woo00<007oo
Ool02Woo00<007ooOol02Woo00<007ooOol02Woo00<007ooOol02Goo00<007ooOol02goo00<007oo
Ool02Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007oo
Ool02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<007oo
Ool027oo00<007ooOol037oo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007oo
Ool02goo00<007ooOol02goo000aOol00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool0
0`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Oomoo`0;Ool00`00Oomoo`0;Ool0035oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo
00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo
00Yoo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo
00Uoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo
00]oo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
00Uoo`03001oogoo00]oo`03001oogoo00]oo`00:7ooo`00R@00000aOol00`00Oomoo`02Ool00`00
Oomoo`0:Ool2000;Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`0;
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`07Ool01000Oomoo`002goo00D007ooOomo
o`0000Uoo`03001oogoo00Ioo`04001oogoo000=Ool2000:Ool00`00Oomoo`05Ool00`00Oomoo`03
Ool00`00Oomoo`09Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`07
Ool00`00Ool0000=Ool01000Oomoo`002Goo00<007ooOol01Woo00@007ooOol000aoo`03001oo`00
00]oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00]oo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo00Uoo`03001oo`0000]oo`05001oogooOol0000:Ool0035o
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uo
o`03001oogoo00aoo`05001oogooOol00007Ool00`00Oomoo`0:Ool00`00Oomoo`09Ool00`00Oomo
o`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool2000:Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool0
0`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`08Ool01000Oomoo`0037oo00<007ooOol02Woo
00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol01Goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo
00D007ooOomoo`0000Yoo`00<Goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol02Woo00<0
07ooOol02Woo00<007ooOol02Goo00<007ooOol037oo00<007ooOol02Goo00<007ooOol02Woo00<0
07ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<0
07ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<0
07ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol02Goo00<0
07ooOol02goo00<007ooOol027oo00<007ooOol037oo00<007ooOol02Goo00<007ooOol02goo00<0
07ooOol02Goo00<007ooOol037oo000aOol00`00Oomoo`02Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0<
Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`09
Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;
Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`09
Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool00`00Oomoo`0;
Ool00`00Oomoo`09Ool00`00Oomoo`0<Ool0035oo`05001oogooOol0000>Ool00`00Oomoo`08Ool0
0`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool0
0`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`08Ool0
0`00Oomoo`0<Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomoo`09Ool00`00Oomoo`0;Ool0
0`00Oomoo`09Ool00`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`09Ool0
0`00Oomoo`0;Ool00`00Oomoo`08Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool0
0`00Oomoo`08Ool00`00Oomoo`0=Ool0035oo`<00003Ool007oo00eoo`03001oogoo00Qoo`03001o
ogoo00aoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00aoo`03001o
ogoo00Qoo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Qoo`03001o
ogoo00aoo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo00Uoo`03001oogoo00]oo`03001o
ogoo00Uoo`03001oogoo00]oo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00Uoo`03001o
ogoo00]oo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001o
ogoo00Moo`03001oogoo00eoo`00<Goo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo
00aoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo
00Qoo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo
00aoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00Qoo`03001oogoo00]oo`03001oogoo
00Uoo`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
00eoo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo
00Moo`03001oogoo00eoo`00<Goo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo00ao
o`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00aoo`03001oogoo00Mo
o`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eo
o`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Qo
o`03001oogoo00aoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eo
o`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Mo
o`03001oogoo00eoo`00<Goo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo00aoo`03
001oogoo00Moo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo00Moo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03
001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03
001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03
001oogoo00Ioo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo00Moo`03
001oogoo00eoo`00<Goo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo00aoo`03001o
ogoo00Moo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo00aoo`03001oogoo00Moo`03001o
ogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001o
ogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00eoo`03001oogoo00Moo`03001o
ogoo00eoo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Moo`03001oogoo00eoo`03001o
ogoo00Ioo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00ioo`03001oogoo00Ioo`03001o
ogoo00ioo`00<Goo00D007ooOomoo`0000ioo`03001oogoo00Qoo`03001oogoo00eoo`03001oogoo
00Ioo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo
00ioo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo
00Ioo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00ioo`03001oogoo00Ioo`03001oogoo
00eoo`03001oogoo00Ioo`03001oogoo00moo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo
00Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo
00ioo`00<Goo0`0000=oo`00Ool03Woo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo
00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Goo00<007ooOol01goo00<007ooOol03Woo
00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo
00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Woo
00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol017oo
00<007ooOol047oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol03Woo
000aOol01000Oomoo`0047oo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo00<007oo
Ool03Woo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Woo00<007oo
Ool01Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo00<007oo
Ool03Woo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Woo00<007ooOol03Woo00<007oo
Ool01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol017oo00<007oo
Ool047oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol017oo00<007ooOol03goo000aOol0
1000Oomoo`0047oo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Woo00<007ooOol03Woo
00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Woo
00<007ooOol03Woo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Woo00<007ooOol03Woo
00<007ooOol01Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol03goo00<007ooOol01Goo
00<007ooOol03goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol017oo00<007ooOol04Goo
00<007ooOol00goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol03goo000aOol01000Oomo
o`0047oo00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol03goo00<007oo
Ool01Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007oo
Ool03goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol03goo00<007oo
Ool01Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol03goo00<007ooOol017oo00<007oo
Ool04Goo00<007ooOol00goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol04Goo00<007oo
Ool00goo00<007ooOol04Goo00<007ooOol00goo00<007ooOol03goo000aOol01000Oomoo`0047oo
00<007ooOol01Woo00<007ooOol03Woo00<007ooOol01Goo00<007ooOol047oo00<007ooOol01Goo
00<007ooOol03Woo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol047oo
00<007ooOol017oo00<007ooOol047oo00<007ooOol017oo00<007ooOol03goo00<007ooOol01Goo
00<007ooOol047oo00<007ooOol017oo00<007ooOol047oo00<007ooOol00goo00<007ooOol04Goo
00<007ooOol00goo00<007ooOol04Goo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol00goo
00<007ooOol04Woo00D007ooOomoo`00019oo`00<Goo00@007ooOol0011oo`03001oogoo00Ioo`03
001oogoo00ioo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo00Eoo`03001oogoo00ioo`03
001oogoo00Eoo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00Aoo`03
001oogoo011oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015oo`03
001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00=oo`03
001oogoo015oo`03001oogoo009oo`03001oogoo01=oo`05001oogooOol0000EOol01@00Oomoogoo
00004Woo000aOol4000AOol00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomo
o`0@Ool00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`0@Ool00`00Oomo
o`04Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`04Ool00`00Oomo
o`0@Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomo
o`03Ool00`00Oomoo`0BOol01@00Oomoogoo00005Goo00D007ooOomoo`0001Eoo`05001oogooOol0
000EOol200000goo001oo`0BOol0035oo`03001oo`00019oo`03001oogoo00Eoo`03001oogoo00io
o`03001oogoo00Eoo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00Ao
o`03001oogoo011oo`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015o
o`03001oogoo00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo009o
o`03001oogoo019oo`05001oogooOol0000EOol01@00Oomoogoo00005Goo00@007ooOol001Moo`03
001oo`0001Moo`8001Aoo`00<Goo00<007oo00004Woo00<007ooOol01Goo00<007ooOol03Woo00<0
07ooOol01Goo00<007ooOol047oo00<007ooOol017oo00<007ooOol047oo00<007ooOol00goo00<0
07ooOol04Goo00<007ooOol017oo00<007ooOol047oo00<007ooOol00goo00<007ooOol04Goo00<0
07ooOol00goo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00D007ooOomoo`0001Eo
o`05001oogooOol0000EOol20002Ool00`00Oomoo`0DOol3000GOol2000^Ool0035oo`03001oo`00
019oo`03001oogoo00Aoo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo011oo`03001oogoo
00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo
011oo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00=oo`03001oogoo019oo`05001oogoo
Ool0000EOol01@00Oomoogoo00005Woo00@007ooOol001Ioo`<001Qoo`03001oogoo04Ioo`00<Goo
00<007oo00004Woo00<007ooOol017oo00<007ooOol03goo00<007ooOol017oo00<007ooOol04Woo
00<007ooOol00goo00<007ooOol047oo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Woo
00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo
00D007ooOomoo`0001Ioo`04001oogoo000FOol3001kOol0035oo`03001oo`00019oo`03001oogoo
00Aoo`03001oogoo011oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo
011oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`05001oogoo
Ool0000EOol01@00Oomoogoo00005Woo00@007oo000001Ioo`<009Eoo`00<Goo0`004Woo00<007oo
Ool017oo00<007ooOol047oo00<007ooOol00goo00<007ooOol04Woo00<007ooOol00Woo00<007oo
Ool04Woo00<007ooOol00Woo00<007ooOol04Woo00<007ooOol00Woo00<007ooOol04Woo00D007oo
Oomoo`0001Ioo`04001oogoo000FOol3002_Ool0035oo`03001oo`0001=oo`03001oogoo00=oo`03
001oogoo011oo`03001oogoo00=oo`03001oogoo019oo`03001oogoo009oo`03001oogoo019oo`03
001oogoo009oo`03001oogoo019oo`05001oogooOol0000FOol01000Ool000005Woo0`00bGoo000a
Ool2000DOol00`00Oomoo`03Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00
Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0COol01000Oomoo`005Woo00<0
07oo0000hgoo000<Ool20007Ool30004Ool60004Ool40007Ool2000DOol00`00Oomoo`03Ool00`00
Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0COol01000
Oomoo`005Woo00<007oo000067oo0P00hgoo000;Ool01000Oomoo`001Woo0`001Goo00D007ooOomo
o`0000=oo`03001oogoo009oo`03001oogoo00Aoo`8001Aoo`03001oogoo009oo`03001oogoo019o
o`05001oogooOol0000EOol01@00Oomoogoo00005Woo00@007ooOol001Moo`800?eoo`002Woo00<0
07ooOol00Woo00<007ooOol00goo0`001Woo00<007ooOol02Goo00<007ooOol017oo0P0057oo00<0
07ooOol00Woo00<007ooOol04Woo00D007ooOomoo`0001Ioo`04001oogoo000GOol2003oOolHOol0
00Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo00Aoo`@0019oo`03
001oogoo009oo`03001oogoo019oo`05001oogooOol0000FOol01000Ool000005goo0P00ogoo67oo
000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool2000DOol00`00Oomoo`02Ool00`00Oomoo`0COol01000Oomoo`005goo0P00ogoo<Woo000:
Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01000Oomoogoo1@001goo00<007ooOol04goo00D007oo
Oomoo`0001Ioo`04001oogoo003oOom;Ool000Yoo`03001oogoo009oo`03001oogoo00moo`05001o
ogooOol0000;Ool00`00Oomoo`0COol01@00Oomoogoo00005goo0P00ogooC7oo000;Ool01000Oomo
o`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo01Aoo`04001oogoo003oOomU
Ool000aoo`8000moo`@000Aoo`D000Moo`03001oogoo01Aoo`<00?moofIoo`00<Goo0`005Goo0P00
ogooIWoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`005Goo0P001goo0`001Goo10001goo00<007ooOol0
ogooOGoo000DOol01000Oomoo`001Woo0`0017oo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`04Ool00`00
Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`@00?moogao
o`004goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0:Ool50007Ool00`00Oomoo`3oOommOol0
01=oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo0?moogeoo`0057oo
00@007ooOol000eoo`03001oogoo00Uoo`03001oogoo0?moogeoo`005Goo0P003Woo1@001goo00<0
07ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3
003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomo
o`3oOommOol000aoo`8000Moo`<000Ioo`03001oogoo00Eoo`@000Moo`03001oogoo0?moogeoo`00
2goo00@007ooOol000Ioo`<000Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol00goo0`001goo00<007ooOol027oo
00<007ooOol017oo1000ogooO7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`002Woo00<007oo
Ool00Woo00<007ooOol03Woo00<007ooOol00Woo1@001goo00<007ooOol0ogooOGoo000:Ool00`00
Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`3oOommOol0
00]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol0ogooOGoo
000<Ool2000>Ool60003Ool50007Ool3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol002Ioo`D000Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<0
07ooOol0ogooOGoo000XOol00`00Oomoo`06Ool4003oOomlOol002Qoo`03001oogoo0?moohIoo`00
:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`00
9Woo0`00ogooR7oo000WOol2003oOon8Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928572 0.952381 0.309017 0.309017 [
[.21429 .29652 -9 -9 ]
[.21429 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -9 -9 ]
[.59524 .29652 9 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[.01131 0 -12 -4.5 ]
[.01131 0 0 4.5 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -24 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -30 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .38627 -24 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -18 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -24 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -6 -4.5 ]
[.01131 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .30902 m
.21429 .31527 L
s
[(1.2)] .21429 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.4)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(1.6)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(1.8)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(2)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.07143 .30902 m
.07143 .31277 L
s
.11905 .30902 m
.11905 .31277 L
s
.16667 .30902 m
.16667 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.35714 .30902 m
.35714 .31277 L
s
.45238 .30902 m
.45238 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.54762 .30902 m
.54762 .31277 L
s
.64286 .30902 m
.64286 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.83333 .30902 m
.83333 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.92857 .30902 m
.92857 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.02381 0 m
.03006 0 L
s
[(-1)] .01131 0 1 0 Mshowa
.02381 .07725 m
.03006 .07725 L
s
[(-0.75)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(-0.5)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(-0.25)] .01131 .23176 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(0.25)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(0.5)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(0.75)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(1)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .25921 m
.02846 .30481 L
.03279 .348 L
.03523 .36922 L
.03754 .38559 L
.03881 .39274 L
.03948 .3959 L
.0402 .39878 L
.04146 .40261 L
.04262 .4047 L
.04384 .40535 L
.04496 .40456 L
.04626 .402 L
.04749 .39798 L
.04862 .39299 L
.04967 .38731 L
.05205 .37107 L
.06244 .27359 L
.06509 .25107 L
.06648 .24095 L
.06795 .23188 L
.06924 .22544 L
.06992 .22266 L
.07065 .22016 L
.07194 .21706 L
.07314 .21569 L
.07439 .21583 L
.07509 .21661 L
.07575 .21779 L
.07694 .22105 L
.07821 .22602 L
.08041 .238 L
.08284 .2555 L
.08836 .30571 L
.09138 .33444 L
.09418 .35882 L
.09678 .37754 L
.09792 .38415 L
.09915 .3901 L
.09985 .39289 L
.1005 .39506 L
.10177 .39815 L
.10242 .39911 L
.10314 .39968 L
.10388 .39973 L
.10458 .39927 L
.10578 .39737 L
.10708 .39372 L
.10831 .38883 L
.10945 .38311 L
Mistroke
.11391 .35175 L
.11907 .30485 L
.12393 .262 L
.12648 .24385 L
.12781 .23613 L
.12923 .22957 L
.13042 .2254 L
.13173 .22234 L
.13292 .22098 L
.13403 .22095 L
.1347 .22151 L
.13543 .22261 L
.13675 .22588 L
.13803 .23059 L
.13922 .23621 L
.14192 .25293 L
.14478 .27542 L
.14936 .31646 L
.15418 .35725 L
.1567 .37423 L
.15804 .38139 L
.15946 .38746 L
.16077 .39149 L
.16196 .3938 L
.16316 .39477 L
.16429 .39444 L
.16535 .39305 L
.16652 .39033 L
.16773 .3862 L
.16887 .38121 L
.1709 .36982 L
.17308 .35461 L
.18259 .27367 L
.18514 .25477 L
.18654 .24601 L
.18786 .23904 L
.18907 .23382 L
.19018 .2301 L
.19141 .22724 L
.19206 .22628 L
.19274 .22569 L
.19406 .22576 L
.1948 .2265 L
.19548 .2276 L
.19679 .2309 L
.19802 .23536 L
.19946 .24211 L
.20079 .24968 L
.2038 .27071 L
.20881 .31265 L
Mistroke
.21157 .33595 L
.21419 .35593 L
.21662 .37124 L
.2179 .37774 L
.21927 .38327 L
.22053 .38701 L
.22168 .38921 L
.22283 .39026 L
.22391 .39016 L
.225 .389 L
.2262 .38653 L
.22744 .38267 L
.22861 .37794 L
.23069 .36698 L
.23292 .35224 L
.24265 .27375 L
.24531 .25547 L
.24671 .24745 L
.2482 .24041 L
.2495 .23565 L
.25023 .23354 L
.25093 .23198 L
.25214 .23023 L
.25345 .22978 L
.25464 .23067 L
.25595 .23305 L
.25661 .2348 L
.25731 .23705 L
.25858 .24208 L
.26105 .25512 L
.26329 .27005 L
.27261 .34369 L
.27488 .35909 L
.27732 .37241 L
.27871 .37821 L
.27999 .3822 L
.28127 .38488 L
.28248 .38616 L
.28379 .38613 L
.28452 .38549 L
.28517 .38452 L
.28646 .38161 L
.28767 .37768 L
.28908 .37168 L
.29038 .36497 L
.29331 .34629 L
.29813 .30914 L
.30329 .26993 L
.30592 .25374 L
.30721 .24728 L
Mistroke
.3084 .24233 L
.30949 .23875 L
.31063 .23595 L
.31179 .23421 L
.31306 .23357 L
.31424 .23417 L
.31532 .23574 L
.31657 .23871 L
.31776 .24265 L
.31986 .2521 L
.32216 .26552 L
.32775 .30653 L
.33301 .34586 L
.33531 .3601 L
.33773 .37187 L
.339 .37643 L
.33968 .37836 L
.3404 .38005 L
.34166 .38201 L
.34285 .38268 L
.34416 .3821 L
.34538 .38032 L
.34601 .37894 L
.34671 .37705 L
.34813 .37211 L
.35071 .35969 L
.35313 .34468 L
.36251 .27582 L
.36507 .25996 L
.36647 .25276 L
.36777 .24715 L
.36898 .24299 L
.37008 .24013 L
.3713 .23803 L
.3726 .23707 L
.37328 .2371 L
.374 .23754 L
.37528 .23933 L
.376 .24087 L
.37667 .24267 L
.3782 .24795 L
.38074 .26014 L
.38348 .27702 L
.38838 .31258 L
.3936 .34893 L
.39515 .35782 L
.39661 .365 L
.39803 .37072 L
.39933 .37477 L
.40057 .37747 L
Mistroke
.40189 .37906 L
.4032 .37931 L
.40395 .37887 L
.40465 .37806 L
.4059 .37569 L
.4066 .37385 L
.40725 .37183 L
.40972 .36164 L
.41197 .34933 L
.41435 .33391 L
.41978 .29489 L
.42215 .2786 L
.42474 .26304 L
.42589 .2572 L
.42712 .2518 L
.42817 .24791 L
.42932 .24454 L
.43062 .24187 L
.43184 .24049 L
.43304 .24024 L
.43413 .24096 L
.43534 .2428 L
.43647 .24548 L
.43772 .24944 L
.43905 .2548 L
.44425 .2845 L
.44885 .31686 L
.45374 .34891 L
.45575 .35943 L
.45792 .36823 L
.45916 .3719 L
.4603 .37432 L
.46139 .37577 L
.46253 .37635 L
.46375 .3759 L
.46504 .37422 L
.46627 .37154 L
.46738 .3682 L
.47011 .35676 L
.47269 .3424 L
.47843 .30365 L
.48096 .28649 L
.48374 .26952 L
.486 .2582 L
.48724 .25315 L
.48842 .24924 L
.48906 .24751 L
.48976 .24593 L
.49098 .244 L
.49223 .24314 L
Mistroke
.49338 .24335 L
.49404 .24389 L
.49475 .24484 L
.49604 .24745 L
.4973 .25106 L
.49845 .25527 L
.50108 .26765 L
.50385 .28403 L
.50872 .31677 L
.51333 .34589 L
.51588 .35862 L
.51722 .36395 L
.51865 .36841 L
.51985 .37111 L
.52117 .37296 L
.52237 .37357 L
.52349 .37321 L
.52457 .37204 L
.52574 .36985 L
.52696 .36658 L
.5281 .3627 L
.53232 .34223 L
.54183 .28107 L
.54428 .26747 L
.54688 .25613 L
.54824 .25173 L
.54896 .24986 L
.54973 .24824 L
.55044 .2471 L
.55109 .24637 L
.55236 .24576 L
.55362 .24628 L
.5548 .24775 L
.55608 .25042 L
.55746 .25443 L
.55999 .26475 L
.56229 .27678 L
.57134 .33398 L
.57354 .34636 L
.57589 .35737 L
.57725 .36239 L
.57848 .36601 L
.57971 .3687 L
.58088 .37031 L
.5821 .371 L
.58339 .37063 L
.58449 .36943 L
.5857 .36716 L
.587 .3637 L
.5884 .35884 L
Mistroke
.59094 .34744 L
.60017 .29108 L
.60284 .27566 L
.60425 .2685 L
.60575 .26187 L
.60719 .25661 L
.6085 .25288 L
.60981 .2502 L
.61105 .2487 L
.61226 .24822 L
.61354 .24878 L
.61463 .25012 L
.61583 .25248 L
.61712 .25601 L
.61851 .26087 L
.62101 .2721 L
.63117 .33296 L
.63395 .34775 L
.63548 .35451 L
.63691 .35979 L
.63813 .36337 L
.63944 .36623 L
.64015 .36732 L
.6409 .36812 L
.64153 .36852 L
.64223 .36865 L
.64288 .36849 L
.64359 .368 L
.64487 .36628 L
.64612 .36361 L
.64727 .36033 L
.64988 .35021 L
.65265 .33618 L
.65771 .30574 L
.66235 .27865 L
.66466 .26747 L
.66588 .26253 L
.66718 .25811 L
.66843 .25477 L
.66956 .25254 L
.6707 .25111 L
.67177 .25053 L
.673 .25076 L
.67431 .25207 L
.67542 .25403 L
.67664 .25704 L
.67795 .26122 L
.67936 .2667 L
.6819 .27879 L
.68652 .30543 L
Mistroke
.69141 .3343 L
.69343 .3446 L
.6956 .35389 L
.69684 .35819 L
.69798 .36138 L
.69906 .36374 L
.70021 .36544 L
.70143 .36636 L
.70273 .3663 L
.70396 .36527 L
.70508 .36352 L
.70639 .36051 L
.70781 .35615 L
.7104 .34566 L
.71578 .31646 L
.72147 .28347 L
.72388 .27166 L
.72646 .26167 L
.72794 .25748 L
.7293 .25475 L
.72995 .25382 L
.73066 .25311 L
.73195 .2526 L
.73322 .25312 L
.73437 .25445 L
.73501 .25553 L
.7357 .25697 L
.73696 .26026 L
.73938 .26893 L
.7416 .27915 L
.75072 .33056 L
.75335 .3437 L
.75583 .3537 L
.75691 .35713 L
.75806 .36009 L
.75932 .36248 L
.76048 .36386 L
.76175 .36443 L
.76246 .36432 L
.76311 .36395 L
.76437 .3625 L
.76558 .36026 L
.76697 .35665 L
.76826 .35239 L
.77119 .33996 L
.78116 .28511 L
.78363 .27333 L
.78624 .26352 L
.7876 .25971 L
.78832 .2581 L
Mistroke
.7891 .2567 L
.78981 .25572 L
.79046 .25508 L
.79173 .25456 L
.793 .25502 L
.79418 .25629 L
.79547 .25861 L
.79684 .26208 L
.79914 .27003 L
.80168 .28138 L
.81075 .33078 L
.81295 .34146 L
.8153 .35091 L
.81666 .35522 L
.81789 .35832 L
.81912 .3606 L
.82029 .36196 L
.82151 .36253 L
.82281 .36217 L
.82391 .36109 L
.82513 .35909 L
.82644 .35604 L
.82784 .35179 L
.83038 .34184 L
.83963 .29298 L
.84231 .27966 L
.84372 .27351 L
.84522 .26783 L
.84667 .26334 L
.84798 .26019 L
.84929 .25795 L
.85053 .25673 L
.85174 .2564 L
.85302 .25697 L
.85412 .2582 L
.85532 .26032 L
.85661 .26346 L
.85799 .26774 L
.86049 .27757 L
.87069 .33055 L
.87348 .34329 L
.87501 .34906 L
.87644 .35354 L
.87766 .35655 L
.87897 .35891 L
.87968 .3598 L
.88043 .36042 L
.88107 .36071 L
.88176 .36075 L
.88242 .36055 L
Mistroke
.88313 .36005 L
.88441 .35843 L
.88566 .35599 L
.88681 .35304 L
.88943 .34402 L
.8922 .33168 L
.89727 .30511 L
.9019 .28175 L
.90422 .27214 L
.90545 .26792 L
.90675 .2642 L
.90789 .26164 L
.90914 .2596 L
.91028 .25849 L
.91136 .25811 L
.9126 .25847 L
.9139 .25978 L
.91502 .26162 L
.91624 .26438 L
.91897 .2731 L
.92151 .28383 L
.9303 .32875 L
.9327 .33968 L
.93525 .3491 L
.9363 .35216 L
.93743 .35488 L
.93867 .35711 L
.93983 .35846 L
.94109 .35909 L
.94179 .35907 L
.94245 .35879 L
.94366 .35768 L
.94494 .35564 L
.94621 .35281 L
.9474 .34945 L
.94962 .34153 L
.95887 .2962 L
.96292 .27764 L
.96496 .27026 L
.96613 .26681 L
.96719 .26422 L
.96836 .26203 L
.96962 .26047 L
.97078 .25978 L
.97188 .2598 L
.97295 .26045 L
.97395 .2616 L
.97503 .26345 L
.97619 .26607 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
9Woo1@00ogooQWoo000XOol00`00Oomoo`3oOon6Ool002Qoo`03001oogoo0?moohIoo`0077oo1`00
1Goo00<007ooOol01Woo1000ogooO7oo000XOol00`00Oomoo`06Ool00`00Oomoo`3oOommOol002Qo
o`03001oogoo00Ioo`03001oogoo0?moogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo
000VOol30008Ool00`00Oomoo`3oOommOol002Moo`8000Qoo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol0
0`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomo
o`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000<Ool20007Ool3
0006Ool00`00Oomoo`05Ool40007Ool00`00Oomoo`3oOommOol000]oo`04001oogoo0006Ool30007
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Qoo`03001oogoo00Aoo`@00?moogao
o`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007oo
Ool017oo00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03001oogoo009oo`03
001oogoo00ioo`03001oogoo009oo`D000Moo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol00Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00D007ooOomoo`0000]oo`03001oogoo0?moogeoo`0037oo0P00
3Woo1P000goo1@001goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`00
ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0
ogooOGoo000EOol20007Ool30005Ool40007Ool00`00Oomoo`3oOommOol001Aoo`04001oogoo0006
Ool30004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo
009oo`03001oogoo00=oo`<000Uoo`03001oogoo00Aoo`@00?moogaoo`002Woo1`000Woo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03
001oogoo009oo`03001oogoo00Yoo`D000Moo`03001oogoo0?moogeoo`004goo00<007ooOol00Woo
00<007ooOol02Woo00<007ooOol02Goo00<007ooOol0ogooOGoo000DOol01000Oomoo`003Goo00<0
07ooOol02Goo00<007ooOol0ogooOGoo000EOol2000>Ool50007Ool3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3000AOol00`00Oomoo`3oOomYOol0035oo`03001oogoo011o
o`03001oo`000?moofYoo`00<Goo00<007ooOol047oo00<007oo00005Goo0P00ogooDgoo000aOol0
0`00Oomoo`0?Ool01000Oomoo`005Goo0P00ogooDgoo000<Ool20007Ool30004Ool60004Ool40007
Ool00`00Oomoo`0?Ool01@00Oomoogoo00004goo00<007oo00005Goo0P00ogoo?7oo000;Ool01000
Oomoo`001Woo0`001Goo00D007ooOomoo`0000=oo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo00moo`05001oogooOol0000COol00`00Ool0000EOol2003oOollOol000Yoo`03001oogoo009o
o`03001oogoo00=oo`<000Ioo`03001oogoo00Uoo`03001oogoo00Aoo`@000ioo`05001oogooOol0
000COol01000Oomoo`004goo00@007ooOol001Aoo`<00?moobAoo`0000=oo`0000001@000Woo00<0
07ooOol00Woo00<007ooOol03Goo00<007ooOol027oo00<007ooOol017oo00<007ooOol03goo00D0
07ooOomoo`0001=oo`04001oogoo000COol01000Oomoo`0057oo00<007oo00005Goo0P00ogoo3Goo
000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`04Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00D007ooOomoo`0001=oo`04001oogoo000C
Ool00`00Oomoo`02000COol00`00Ool0000FOol00`00Oomoo`3cOol000Yoo`03001oogoo009oo`03
001oogoo00moo`04001oogooOol50007Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0@
Ool01@00Oomoogoo00004Woo00D007ooOomoo`0001=oo`05001oogooOol0000COol01000Oomoo`00
57oo0`00m7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00002goo00<007oo
Ool03Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol047oo00<007oo
Ool00Woo00<007ooOol047oo00D007ooOomoo`0001=oo`04001oogoo000DOol00`00Ool0000DOol3
003MOol000]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol0
3Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol0
0Woo00<007ooOol047oo00D007ooOomoo`00019oo`05001oogooOol0000COol01000Oomoo`0057oo
00<007oo00005Goo0P00aWoo000<Ool2000?Ool40004Ool50007Ool3000>Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00004goo00@007ooOol001Aoo`03001oo`00
01Aoo`03001oo`0001Eoo`800:moo`00<Goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
0Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol047oo00D007ooOomoo`00019oo`05001o
ogooOol0000COol01000Oomoo`004goo0P0000=oo`00Ool057oo0P00Ugoo000aOol00`00Oomoo`0>
Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03
Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00004goo00@007ooOol001=oo`04001o
ogoo000DOol01000Ool0000057oo0P00P7oo000aOol00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00
Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00
Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00
Oomoo`0@Ool01@00Oomoogoo00004Woo00D007ooOomoo`0001=oo`05001oogooOol0000COol01000
Oomoo`004goo00@007ooOol001Aoo`<001Eoo`80055oo`00<Goo00<007ooOol03Woo00<007ooOol0
0goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
0goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol0
47oo00D007ooOomoo`00019oo`05001oogooOol0000COol01000Oomoo`004goo00@007ooOol001Ao
o`<001Eoo`8003Yoo`00<Goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007oo
Ool017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol00goo00<007oo
Ool03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00goo00<007ooOol03Woo00<007oo
Ool00Woo00<007ooOol047oo00<007ooOol00Woo00<007ooOol047oo00D007ooOomoo`00019oo`05
001oogooOol0000COol01000Oomoo`004goo00@007ooOol001Aoo`04001oogoo000COol200000goo
001oo`0COol3000EOol2000;Ool0035oo`<000eoo`03001oogoo00Aoo`03001oogoo00eoo`03001o
ogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001o
ogoo00ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`05001o
ogooOol0000COol01000Oomoo`004goo00@007ooOol001Aoo`03001oo`0001Aoo`<000]oo`00<Goo
00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol03Goo
00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03goo
00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00Woo
00<007ooOol03goo00<007ooOol00Woo00<007ooOol047oo00D007ooOomoo`00019oo`05001oogoo
Ool0000COol01@00Oomoogoo00004Woo00D007ooOomoo`0001=oo`04001oogoo000:Ool0035oo`03
001oogoo00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03
001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03
001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03
001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo00moo`03001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0000B
Ool01@00Oomoogoo00002Woo000aOol00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0
0`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool0
0`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0@Ool01@00Oomoogoo00004Woo00<007ooOol037oo000aOol2000=Ool00`00Oomoo`06
Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool60003Ool00`00Ool000020004Ool7
0007Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`02Ool50005Ool3
0006Ool40003Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool6
0005Ool30002Ool00`00Oomoo`05000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool50005Ool30004Ool5000<Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00
Oomoo`03Ool00`00Oomoo`0?Ool70008Ool0035oo`8000eoo`03001oogoo00Ioo`03001oogoo00ao
o`03001oogoo00Ioo`03001oogoo00]oo`04001oogoo0005Ool00`00Ool000020005Ool01000Oomo
ogoo0P001goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol017oo0P00
1Woo0`001Goo00@007ooOol000Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03
001oogoo00Aoo`04001oogoo0007Ool300001Goo001oogoo000017oo00<007ooOol03Goo00<007oo
Ool017oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol01Goo00<007ooOol01Goo0`0017oo
00<007ooOol00Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol00goo
00<007ooOol03Woo00@007ooOol000=oo`03001oogoo00Ioo`00<Goo0`0037oo00<007ooOol01Woo
00<007ooOol037oo00<007ooOol01Woo00<007ooOol02goo00@007ooOol000Eoo`03001oo`000080
00Ioo`05001oogooOol00007Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00
Oomoo`04Ool20006Ool30004Ool60003Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomoo`0<
Ool00`00Oomoo`05Ool01000Oomoo`001goo0`0000Eoo`00Oomoo`0000Aoo`03001oogoo00eoo`03
001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Eoo`<0
00Aoo`8000=oo`03001oogoo00Uoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo00ioo`05001oogooOol0000;Ool0035oo`8000eoo`03001oogoo00Ioo`03001oogoo00ao
o`03001oogoo00Ioo`03001oogoo00]oo`04001oogoo0005Ool00`00Oomoo`09Ool01000Oomoo`00
1goo00<007ooOol037oo00<007ooOol01Woo00<007ooOol037oo00<007ooOol017oo0P003Goo0P00
0Woo00<007ooOol00Woo00<007ooOol037oo00<007ooOol01Woo00<007ooOol037oo00<007ooOol0
1Goo00@007ooOol000]oo`04001oogoo0004Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomo
o`0=Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomoo`03Ool20003Ool0
0`00Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool0035oo`8000eoo`03001oogoo00Moo`03001oogoo00]oo`03
001oogoo00Ioo`03001oogoo00]oo`04001oogoo0005Ool00`00Oomoo`0:Ool00`00Ool00008Ool0
0`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0<Ool00`00Oomoo`04Ool2000>Ool01000Oomo
o`001Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol01Goo00@007oo
Ool000]oo`03001oogoo008000=oo`8000ioo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo
00Eoo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo00Eoo`@000aoo`03001oogoo00Aoo`03
001oogoo00eoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo00Moo`00
<Goo0P003Goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02goo00@0
07ooOol000Ioo`03001oogoo00Yoo`8000Qoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo
00aoo`03001oogoo00Aoo`8000ioo`800003Ool007oo00Aoo`03001oogoo00]oo`03001oogoo00Io
o`03001oogoo00aoo`03001oogoo00Eoo`04001oogoo000;Ool01@00Oomoo`00Ool00`0000=oo`00
Ool03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool01Goo00<007ooOol017oo0P000goo00<007ooOol02Goo00<007ooOol017oo00<007ooOol03Goo
00<007ooOol01Goo00<007ooOol037oo00<007ooOol01Goo00<007ooOol01Woo000aOol2000=Ool0
0`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool01000Oomoo`001Woo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02goo
00<007ooOol01Goo00<007oo00003Goo0P0000=oo`00Ool017oo00<007ooOol02goo00<007ooOol0
1Woo00<007ooOol037oo00<007ooOol01Goo00@007ooOol000Yoo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo00Aoo`8000=oo`03001oogoo00Qoo`03001oogoo00Ioo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00Ioo`00
<Goo0P0037oo00<007ooOol027oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<0
07oo00000P001Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol02Woo
00<007ooOol01goo00<007ooOol02goo00<007ooOol00goo0`0000=oo`00Ool02goo00<007ooOol0
0P001Goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol037oo00<007ooOol01Woo0`002Woo
00<007ooOol00Woo0P000goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol037oo00<007oo
Ool01Woo00@007ooOomoo`<000Moo`03001oogoo00Aoo`03001oo`00009oo`03001oogoo00Qoo`03
001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00aoo`04001oogoo0004Ool0
0`00Oomoo`06Ool0035oo`8000aoo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo008000Ioo`03001oogoo00Ioo`D000Uoo`03001oogoo00Yoo`03001o
ogoo00Moo`03001oogoo00]oo`03001oogoo00Aoo`800003Ool007oo00]oo`05001oogooOol00005
Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool3000:Ool00`00
Oomoo`04Ool4000=Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`02
Ool20007Ool00`00Oomoo`05Ool4000;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06
Ool00`00Oomoo`0<Ool01000Oomoogoo10002Goo000aOol3000;Ool00`00Oomoo`08Ool00`00Oomo
o`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`0?Ool0035oo`03
001oo`0000]oo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Uoo`03
001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03
001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Qoo`03
001oogoo00Yoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00Yoo`03
001oogoo00Moo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Moo`03
001oogoo00Yoo`03001oogoo00moo`00<Goo00<007oo00002goo00<007ooOol02Goo00<007ooOol0
2Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol0
2Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Woo00<007ooOol0
1goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol0
2Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol0
27oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol03goo000aOol00`00
Ool0000;Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00
Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00
Oomoo`0:Ool00`00Oomoo`0?Ool0035oo`03001oo`0000]oo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uo
o`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00Mo
o`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Yo
o`03001oogoo00Moo`03001oogoo00Yoo`03001oogoo00Qoo`03001oogoo00Uoo`03001oogoo00Qo
o`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Yoo`03001oogoo00moo`00<Goo00<007oo
00002goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Goo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol047oo000XOooo00290000035oo`03001oo`0000Yoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Qoo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Uoo`03001oo`0000Qoo`03001oogoo00Ioo`04001oogoo000:Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`09Ool00`00Ool00009Ool00`00Oomoo`05Ool01@00Oomoogoo00002Woo00D007ooOomo
o`0000Moo`03001oogoo00Moo`8000aoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Qo
o`03001oo`0000Uoo`03001oogoo00Eoo`05001oogooOol0000:Ool01@00Oomoogoo00001goo00<0
07ooOol01goo0P0037oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol02Woo0P002Goo00<0
07ooOol01Goo00<007ooOol027oo000aOol00`00Ool0000:Ool00`00Oomoo`0:Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Ool00008Ool00`00Oomoo`09
Ool00`00Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomoo`08
Ool00`00Oomoo`09Ool00`00Oomoo`07Ool2000<Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00
Oomoo`08Ool00`00Oomoo`09Ool00`00Oomoo`08Ool01@00Oomoogoo000027oo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol01Goo
00<007ooOol027oo000aOol01000Oomoo`002Goo00<007ooOol02Woo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol02Goo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Goo00<007oo
Ool027oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol027oo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol02Woo00<007ooOol027oo00<007ooOol047oo000aOol01000Oomoo`002Goo
00<007ooOol02goo00<007ooOol01goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol01goo
00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Goo00<007ooOol027oo00<007ooOol02Woo
00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo
00<007ooOol04Goo000aOol01000Oomoo`002Goo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol027oo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool02Goo00<007ooOol027oo00<007ooOol02Woo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol02goo00<007ooOol01goo00<007ooOol02Woo00<007ooOol01goo00<007oo
Ool02Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol01goo00<007ooOol02Woo00<007oo
Ool01goo00<007ooOol02goo00<007ooOol01Woo00<007ooOol04Goo000aOol40009Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomo
o`0AOol0035oo`04001oogoo0009Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool0
0`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0AOol0035oo`04001oogoo0009Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomo
o`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomo
o`0<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomo
o`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomo
o`0AOol0035oo`04001oogoo0009Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool0
0`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0AOol0035oo`04001oogoo0009Ool00`00Oomo
o`0;Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool00`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomo
o`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomo
o`0;Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomo
o`06Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomo
o`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomo
o`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomo
o`0BOol0035oo`04001oogoo0008Ool00`00Oomoo`0<Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool0
0`00Oomoo`07Ool00`00Oomoo`0;Ool00`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool0
0`00Oomoo`06Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`06Ool0
0`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool0
0`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool0
0`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`0BOol0035oo`<00003Ool007oo00Ioo`03001o
ogoo00aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo00]oo`03001o
ogoo00Ioo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00eoo`03001oogoo00Eoo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00aoo`03001o
ogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Eoo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001o
ogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00Aoo`03001o
ogoo019oo`00<Goo00D007ooOomoo`0000Moo`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo
00]oo`03001oogoo00Ioo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo
00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo
00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo
00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00=oo`03001oogoo
00ioo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo
00=oo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo019oo`00<Goo00D007ooOomoo`0000Mo
o`03001oogoo00aoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Ioo`03001oogoo00ao
o`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eo
o`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo00ao
o`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=o
o`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00eo
o`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00moo`03001oogoo009o
o`03001oogoo01=oo`00<Goo00D007ooOomoo`0000Moo`03001oogoo00eoo`03001oogoo00Eoo`03
001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03
001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03
001oogoo00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001oogoo00eoo`03
001oogoo00Aoo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo00ioo`03001oogoo00=oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`03
001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo01=oo`00<Goo00D007ooOomo
o`0000Moo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Eoo`03001oogoo00aoo`03001o
ogoo00Eoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001o
ogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00ioo`03001o
ogoo00=oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001o
ogoo00moo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0000COol01@00Oomoogoo0000
5Goo000aOol01@00Oomoogoo00001goo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol037oo
00<007ooOol01Goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo
00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Woo00<007ooOol017oo00<007ooOol03Goo
00<007ooOol017oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol00goo00<007ooOol03goo00D007ooOomoo`00019oo`03001oogoo
009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0000COol01000
Oomoo`005Woo000aOol300000goo001oo`06Ool00`00Oomoo`0=Ool00`00Oomoo`05Ool00`00Oomo
o`0<Ool00`00Oomoo`05Ool00`00Oomoo`0=Ool00`00Oomoo`04Ool00`00Oomoo`0=Ool00`00Oomo
o`04Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomo
o`0?Ool00`00Oomoo`03Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomo
o`02Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool01@00Oomoogoo00004goo00D0
07ooOomoo`00019oo`05001oogooOol0000COol01000Oomoo`0057oo00<007oo00005Woo000aOol0
1@00Oomoogoo00001goo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol037oo00<007ooOol0
1Goo00<007ooOol03Goo00<007ooOol017oo00<007ooOol03Goo00<007ooOol017oo00<007ooOol0
3Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol0
0goo00<007ooOol03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol0
47oo00D007ooOomoo`00019oo`05001oogooOol0000COol01@00Oomoogoo00004Woo00@007ooOol0
01Aoo`<001Eoo`<001Ioo`00<Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol017oo00<007ooOol03Goo00<007ooOol01Goo00<007ooOol03Goo00<007ooOol00goo00<0
07ooOol03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol03goo00<007ooOol00goo00<007ooOol03Woo00<007ooOol00Woo00<0
07ooOol047oo00<007ooOol00Woo00<007ooOol047oo00D007ooOomoo`0001=oo`04001oogoo000C
Ool200000goo001oo`0COol3000EOol2000^Ool0035oo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo00ioo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00ioo`03
001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00moo`03001oogoo00=oo`03
001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`05
001oogooOol0000BOol01@00Oomoogoo00004goo00@007ooOol001Aoo`03001oo`0001Eoo`8005eo
o`00<Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol03Woo00<007ooOol017oo00<007oo
Ool03Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00Woo00<007ooOol03goo00<007oo
Ool00Woo00<007ooOol03goo00<007ooOol00Woo00<007ooOol047oo00<007ooOol00Woo00<007oo
Ool047oo00D007ooOomoo`00019oo`05001oogooOol0000COol01000Oomoo`0057oo00<007oo0000
57oo0`00M7oo000aOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`03
Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?
Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00004Woo00D007ooOomoo`0001=oo`05
001oogooOol0000COol00`00Ool0000DOol3000EOol2002<Ool0035oo`<0009oo`03001oogoo00=o
o`03001oogoo00moo`03001oogoo00=oo`03001oogoo00ioo`03001oogoo00=oo`03001oogoo00mo
o`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0
000BOol01@00Oomoogoo00004goo00@007ooOol001Aoo`03001oo`0001Eoo`800:=oo`00<Goo00<0
07ooOol00Woo00<007ooOol00goo00<007ooOol03goo00<007ooOol00goo00<007ooOol03Woo00<0
07ooOol00goo00<007ooOol03goo00D007ooOomoo`00019oo`03001oogoo009oo`03001oogoo011o
o`05001oogooOol0000COol01000Oomoo`0057oo00<007oo00005Goo00<007ooOol0^Goo000aOol0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool0
0`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomoogoo00004goo00@007ooOol001=oo`04001oogoo
000DOol01000Oomoo`0057oo0P00dWoo000<Ool20007Ool30004Ool60004Ool40007Ool00`00Oomo
o`03Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool01@00Oomo
ogoo00004Woo00D007ooOomoo`0001=oo`04001oogoo000DOol00`00Ool0000EOol2003YOol000]o
o`04001oogoo0006Ool30005Ool01@00Oomoogoo00000goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol00goo00D007ooOomoo`00019oo`03001oogoo009oo`03001oogoo011oo`05001oogoo
Ool0000COol01000Oomoo`004goo00@007ooOol001Aoo`800?moo`9oo`002Woo00<007ooOol00Woo
00<007ooOol00goo0`001Woo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00goo00D007oo
Oomoo`00019oo`03001oogoo009oo`03001oogoo011oo`05001oogooOol0000COol01000Oomoo`00
57oo0P00ogoo6Goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomo
o`04Ool40002Ool01@00Oomoogoo00004Woo00D007ooOomoo`0001=oo`05001oogooOol0000COol0
0`00Ool0000EOol2003oOolIOol000Yoo`03001oogoo009oo`03001oogoo00ioo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`05001oogooOol0000COol01000Oomo
o`004goo00@007ooOol001Eoo`800?mooc1oo`002Woo00<007ooOol00Woo00<007ooOol03goo00@0
07ooOomoo`D000Moo`03001oogoo00=oo`05001oogooOol0000COol01000Oomoo`0057oo00<007oo
0000ogooAgoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00002goo00<007oo
Ool017oo00@007ooOol001=oo`04001oogoo000DOol2003oOom8Ool000]oo`04001oogoo000=Ool0
0`00Oomoo`02Ool01@00Oomoogoo00002goo00<007ooOol017oo00@007ooOol001Aoo`800?mooemo
o`0037oo0P003goo100017oo1@001goo00<007ooOol017oo00@007ooOol001Aoo`800?mooemoo`00
<Goo0`0017oo00<007oo0000ogooMWoo000aOol00`00Oomoo`05Ool2003oOomfOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`005Goo0P00
1goo0`001Goo10001goo00<007ooOol0ogooOGoo000DOol01000Oomoo`001Woo0`0017oo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`03
Ool30009Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Aoo`@00?moogaoo`004goo00<007ooOol00Woo00<007ooOol02Woo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol0ogooOGoo000COol00`00Oomoo`02Ool00`00Oomoo`0:
Ool50007Ool00`00Oomoo`3oOommOol001=oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo
00Uoo`03001oogoo0?moogeoo`0057oo00@007ooOol000eoo`03001oogoo00Uoo`03001oogoo0?mo
ogeoo`005Goo0P003Woo1@001goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<0
07ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol000aoo`8000Moo`<000Ioo`03001oogoo00Eo
o`@000Moo`03001oogoo0?moogeoo`002goo00@007ooOol000Ioo`<000Moo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo00Aoo`03001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007oo
Ool00goo0`001goo00<007ooOol027oo00<007ooOol017oo1000ogooO7oo000:Ool00`00Oomoo`02
Ool00`00Oomoo`0=Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol000Yoo`03
001oogoo009oo`03001oogoo00ioo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo0?moogeoo`002Woo00<007ooOol00Woo00<007ooOol03Woo00<007ooOol00Woo1@001goo
00<007ooOol0ogooOGoo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool00`00Oomoo`3oOommOol000]oo`04001oogoo000=Ool00`00Oomoo`02Ool01@00Oomo
ogoo00002goo00<007ooOol0ogooOGoo000<Ool2000>Ool60003Ool50007Ool3003oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol002Ioo`D000Ioo`03001oogoo0?mo
ogeoo`00:7oo00<007ooOol01Woo00<007ooOol0ogooOGoo000XOol00`00Oomoo`06Ool4003oOoml
Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6
Ool002Qoo`03001oogoo0?moohIoo`009Woo0`00ogooR7oo000WOol2003oOon8Ool00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "This sequence of plots shows that, if the origin is not included in the \
plots, the amplitude of the oscillations in ",
  Cell[BoxData[
      FormBox[
        RowBox[{\([sin(\[CapitalDelta]\[Omega]\ t)]\), "/", 
          RowBox[{"(", 
            RowBox[{
              FormBox["\[Pi]",
                "TraditionalForm"], " ", "t"}], ")"}]}], TraditionalForm]]],
  " does not change as \[CapitalDelta]\[Omega] increases; only the frequency \
increases until in the limit the function is zero ",
  StyleBox["on average. ",
    FontSlant->"Italic"],
  "(Try changing the limits of the plot, and the range of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  ",  to test this.)"
}], "Text"],

Cell[TextData[{
  "\tHowever, if the origin is included, the amplitude of the peak at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " ",
  StyleBox["increases",
    FontSlant->"Italic"],
  " as \[CapitalDelta]\[Omega] becomes larger, since by l'Hospital's rule, ",
  Cell[BoxData[
      \(TraditionalForm\`lim\_\(t \[Rule] 0\)\ 
          Sin[\[CapitalDelta]\[Omega]\ t]/\((\[Pi]\ t)\) = \[CapitalDelta]\
\[Omega]/\[Pi]\)]],
  ". This is what allows the area under the function to remain unity in the \
limit as \[CapitalDelta]\[Omega] becomes large. "
}], "Text"],

Cell[TextData[{
  "\tThus, Eq. ",
  ButtonBox["(2.3.35)",
    ButtonData:>"(2.3.35)",
    ButtonStyle->"Hyperlink"],
  " is a \[Delta]-function in an ",
  StyleBox["average",
    FontSlant->"Italic"],
  " sense: integrals over this function have the correct property given by \
Eq. ",
  ButtonBox["(2.3.29)",
    ButtonData:>"(2.3.29)",
    ButtonStyle->"Hyperlink"],
  ". However, the function itself contains infinitely rapid oscillations."
}], "Text"],

Cell[TextData[{
  "\tFourier integrals such as Eq.  ",
  ButtonBox["(2.3.35)",
    ButtonData:>"(2.3.35)",
    ButtonStyle->"Hyperlink"],
  " are called ",
  StyleBox["generalized ",
    FontSlant->"Italic"],
  " Fourier integrals: they do not converge in the usual sense of the term. \
Rather, the resulting functions contain infinitely rapid oscillations. We \
neglect these oscillations because all we use in applications are ",
  StyleBox["integrals",
    FontSlant->"Italic"],
  " over these functions, which average out the oscillations. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Derivatives of a \[Delta]-Function", "Section",
  CellTags->{"i:89", "c:32"}],

Cell[TextData[{
  " Several other generalized Fourier integrals are also of use.  Consider, \
for example, the",
  StyleBox[" derivative",
    FontSlant->"Italic"],
  " of a \[Delta]-function, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\[Prime]\)(
          t) = \[DifferentialD]\(\[Delta](t)\)/\[DifferentialD]t\)]],
  ". According to Eq. (",
  ButtonBox["2.3.35",
    ButtonData:>"(2.3.35)",
    ButtonStyle->"Hyperlink"],
  "), this derivative can be written as a generalized Fourier integral, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\[Prime]\)(
          t) = \(\((\[DifferentialD]\(\(/\)\(\[DifferentialD]t\)\))\)\ \(\
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\ \[Omega]\ t\)\) \[DifferentialD]\[Omega]/
                  2  \[Pi]\) = \ \
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\((\(-\[ImaginaryI]\)\ \[Omega])\)\ \
\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\) \[DifferentialD]\
\[Omega]/2  \[Pi]\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.41)"],

Cell[TextData[{
  "The integrand in Eq. ",
  ButtonBox["(2.3.41)",
    ButtonData:>"(2.3.41)",
    ButtonStyle->"Hyperlink"],
  " exhibits even worse convergence properties than Eq. ",
  ButtonBox["(2.3.35)",
    ButtonData:>"(2.3.35)",
    ButtonStyle->"Hyperlink"],
  ".  The resulting function has infinitely rapid oscillations of ",
  StyleBox["infinite magnitude. ",
    FontSlant->"Italic"],
  " Nevertheless, integrals over this function are well behaved. We therefore \
may say, with a straight face, that the Fourier transform of a ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\[Prime]\)(t)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[ImaginaryI]\)\ \[Omega]\)]],
  ", and compute the inverse transform of this function. In fact, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["FourierTransform ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function knows all about generalized Fourier integrals. For instance,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseFourierTransform[1, \[Omega], t]/Sqrt[2\ Pi]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.55"],

Cell[BoxData[
    \(DiracDelta[t]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The intrinsic function ",
  StyleBox["DiracDelta[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " is the Dirac \[Delta]-function.  Also,"
}], "Text",
  CellTags->"i:96"],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseFourierTransform[\(-I\)\ \[Omega], \[Omega], t]/
      Sqrt[2\ Pi]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.56"],

Cell[BoxData[
    RowBox[{
      SuperscriptBox["DiracDelta", "\[Prime]",
        MultilineFunction->None], "[", "t", "]"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Of course, we can't plot these functions, because they are singular, but \
we know what they look like. The \[Delta]-function has a single positive \
spike at the origin. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\[Prime]\)(t)\)]],
  " is the slope of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](t)\)]],
  ", it has a positive spike just to the left of zero, and a negative spike \
just to the right. "
}], "Text"],

Cell[TextData[{
  "\tThe derivative of a \[Delta]-function has a useful property: for any \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " that is differentiable at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the following integral that includes the origin can be evaluated \
analytically via an integration by parts:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(-a\)\%b\( f(
            t)\) \(\(\[Delta]\^\[Prime]\)(
            t)\) \[DifferentialD]t = \(\(-\(\[Integral]\_\(-a\)\%b\(\( 
                    f\^\[Prime]\)(t)\) \(\[Delta](
                t)\) \[DifferentialD]t\)\) = \(-\(\(\(f\^\[Prime]\)(
              0)\)\(.\)\)\)\)\)]]], "NE3",
  CellTags->"(2.3.42)"],

Cell[TextData[{
  " Similarly, the ",
  StyleBox["n",
    FontSlant->"Italic"],
  "th derivative of a \[Delta]-function has the property that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Integral]\_\(-a\)\%b\( f(
            t)\) \(\[DifferentialD]\^n\( \[Delta](
                  t)\)\/\[DifferentialD]t\^n\) \[DifferentialD]t = \
\(\((\(-1\))\)\^n\) \(\[DifferentialD]\^n 
              f\/\[DifferentialD]t\^n\) \(\((0)\)\(.\)\)\)]]], "NE3",
  CellTags->"(2.3.43)"],

Cell[TextData[{
  "The Fourier integral representation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^n\( \
\[Delta](t)\)\/\[DifferentialD]t\^n\)]],
  " becomes progressively less convergent as ",
  StyleBox["n",
    FontSlant->"Italic"],
  " increases:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[DifferentialD]\^n\( \[Delta](t)\)\/\[DifferentialD]t\
\^n = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\((\(-\[ImaginaryI]\)\ \
\[Omega])\)\^n\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\) \
\[DifferentialD]\[Omega]/2  \[Pi]\)]]], "NE3",
  CellTags->"(2.3.44)"],

Cell[TextData[{
  "\tThese generalized Fourier integrals allow us to do things that we \
couldn't do before.  For instance, we can now compute the value of a \
nonconvergent integral, such as \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
t\^2\/\(1 + t\^2\)\) cos\[Omega]\ t \[DifferentialD]t\)]],
  "."
}], "Text"],

Cell["\<\
Normally, we would throw up our hands and declare that the integral \
does not exist. This is technically correct so far as it goes, but we still \
can compute its value as a generalized Fourier integral:\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
t\^2\/\(1 + t\^2\)\) 
            cos\[Omega]\ t \[DifferentialD]t = \(Re\ \(\[Integral]\_\(-\
\[Infinity]\)\%\[Infinity]\(\( 1 + t\^2 - 1\)\/\(1 + 
                      t\^2\)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \
t\)\) \[DifferentialD]t\)\  = 
          Re\ \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \[DifferentialD]t\)\  - 
            Re\ \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity] 1\/\(1 + t\^2\)\
\ \ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \(\(\[DifferentialD]t\
\)\(\ \)\)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The first integral is proportional to a \[Delta]-function, while the \
second integral is convergent, equaling ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Pi]\)\ \
\[ExponentialE]\^\(-\(\(|\)\(\[Omega]\)\(|\)\)\)\)]],
  ". Thus, we obtain\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
t\^2\/\(1 + t\^2\)\) cos\[Omega]\ t \[DifferentialD]t = 
        2 \( \[Pi]\[Delta](\[Omega])\) + \[Pi]\ \(\(\[ExponentialE]\^\(-\(\(|\
\)\(\[Omega]\)\(|\)\)\)\)\(.\)\)\)]],
  " "
}], "Text"],

Cell["\<\
However, we must always remember that the equality is correct only \
in the average sense discussed above; the right-hand side neglects infinitely \
rapid oscillations.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Heaviside Step Function", "Section",
  CellTags->{"i:51", "c:33"}],

Cell[TextData[{
  "Before we move on to other topics, there is one more generalized Fourier \
integral of interest. Consider the ",
  StyleBox["integral ",
    FontSlant->"Italic"],
  " of a \[Delta]-function, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`h(
          t) = \[Integral]\_\(-\[Infinity]\)\%t\( \[Delta](
              t\_1)\) \[DifferentialD]t\_1\)]],
  "."
}], "NE3",
  CellTags->"(2.3.45)"],

Cell[TextData[{
  "This function equals zero if ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ", but for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  " the range of integration includes the origin, and then according to Eq. \
",
  ButtonBox["(2.3.28)",
    ButtonData:>"(2.3.28)",
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\  = \ 1\)]],
  ". Therefore, ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is nothing other than the Heaviside step function ",
  StyleBox["UnitStep[t]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", encountered previously [Eq. ",
  ButtonBox["(9.8.1)",
    ButtonData:>{"Chapter9.nb", "(9.8.1)"},
    ButtonStyle->"Hyperlink"],
  " and Cell ",
  ButtonBox["2.48",
    ButtonData:>"Cell 2.48",
    ButtonStyle->"Hyperlink"],
  "]. For convenience, we reproduce the definition of",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(h(t)\)\)\)]],
  " below:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(h(t)\), " ", "=", " ", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->16], 
            StyleBox[GridBox[{
                  {\(0, t < 0, \)},
                  {\(1, t > \ 0. \)}
                  }],
              ShowAutoStyles->True]}],
          (#&)]}], TraditionalForm]]]], "NE3",
  CellTags->"(2.3.46)"],

Cell[TextData[{
  "We can find the Fourier integral of ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " by directly applying the transform:\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)(\[Omega]) = \(\[Integral]\_\(-\[Infinity]\)\
\%\[Infinity]\( \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \(h(
                t)\) \[DifferentialD]t = \[Integral]\_0\%\[Infinity]\( \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\(\(\[DifferentialD]t\)\(.\)\)\)\)]]
}], "Text"],

Cell["\<\
Now, this is not a convergent integral; rather, it is a generalized \
Fourier integral, and it provides an instructive example of some of the \
methods used to evaluate such integrals.\
\>", "Text"],

Cell[TextData[{
  "\tBreaking the integrand into real and imaginary parts via ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\) = \ 
        cos\[Omega]\ t\  + \ \[ImaginaryI]\ sin\ \[Omega]\ t\)]],
  ", we can write the result as"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(h\&~\)(\[Omega]) = \[Integral]\_0\%\[Infinity] 
              cos\[Omega]\ t \[DifferentialD]t + \[ImaginaryI] \
\(\[Integral]\_0\%\[Infinity] sin\ \[Omega]\ t \[DifferentialD]t\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "In the first integral, note that ",
  Cell[BoxData[
      \(TraditionalForm\`cos\[Omega]t\)]],
  " is an even function of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", so we can double the range of integration to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < t < \[Infinity]\)]],
  ", and divide by 1/2. Expressing the second integral as a limit, we can \
write\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(h\&~\)(\[Omega])\), "=", 
          
          RowBox[{\(\(1\/2\) 
              Re \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \[DifferentialD]t\)\), "+", 
            
            RowBox[{"\[ImaginaryI]", "  ", 
              RowBox[{
                SubscriptBox["lim", 
                  RowBox[{
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "\[Rule]", 
                    "\[Infinity]"}]], 
                RowBox[{
                  SubsuperscriptBox["\[Integral]", "0", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          
                          FontSlant->
                            "Italic"]}]]], \(sin\ \[Omega]\ t \(\(\
\[DifferentialD]t\)\(\ \)\)\)}]}]}]}]}], TraditionalForm]]],
  ".\n The first integral yields a \[Delta]-function via Eq. ",
  ButtonBox["(2.3.34)",
    ButtonData:>"(2.3.34)",
    ButtonStyle->"Hyperlink"],
  ", and the second integral can be evaluated analytically:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(h\&~\)(\[Omega])\), "=", 
        RowBox[{\(\[Pi]\ \(\[Delta](\[Omega])\)\), 
          "-", \(1\/\(\[ImaginaryI]\ \[Omega]\)\), "-", " ", 
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              SubscriptBox["lim", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "\[Rule]", "\[Infinity]"}]], 
              
              RowBox[{
                FractionBox[
                  RowBox[{"cos", " ", 
                    RowBox[{"(", 
                      RowBox[{"\[Omega]", " ", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["t",
                              FontSlant->"Italic"]}]]}], 
                      StyleBox[")",
                        FontSlant->"Italic"]}]}], "\[Omega]"], "."}]}]}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(2.3.47)"],

Cell[TextData[{
  "As usual, we neglect the infinite oscillations. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can also derive the same result:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[
      FourierTransform[UnitStep[t], t, \[Omega]] Sqrt[2\ Pi]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.57"],

Cell[BoxData[
    \(\[ImaginaryI]\/\[Omega] + \[Pi]\ DiracDelta[\[Omega]]\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Connection of Fourier Transforms to Fourier Series ", "Section",
  CellTags->{"i:49", "c:34"}],

Cell["\<\
Since Fourier transforms can be used to represent any function as \
an integral over Fourier modes, they can be used to represent periodic \
functions as a special case. It is a useful exercise to see how this \
representation connects back to Fourier series.\
\>", "Text"],

Cell[TextData[{
  "\tAs a first step, we will consider the Fourier series for a simple \
periodic function, the periodic \[Delta]-function of period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(t)\)]],
  ". This function is a periodic extension of a Dirac \[Delta]-function, and \
can be written as"
}], "Text",
  CellTags->"i:48"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(
          t) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity] \[Delta](
            t - m\ T)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.48)"],

Cell["\<\
Since this is a periodic function, it has a Fourier series \
representation of the form\
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(
          t) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\( 
                c\_n\) \[ExponentialE]\^\(\(-\[Iota]\)\ 2  \[Pi]\ n\ \
t/T\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "The Fourier coefficients are given by an integral over one period of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(t)\)]],
  ", which contains a single \[Delta]-function :\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`c\_n = \
\(\[Integral]\_\(\(-T\)/2\)\%\(T/2\)\(\[Delta](
                t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ n\ t/
                      T\)\) \[DifferentialD]t = 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Thus, the periodic \[Delta]-function of period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " has a Fourier series of the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(
          t) = \(\[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity] \[Delta](
              t - m\ T) = \[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] \
\[ExponentialE]\^\(\(-\[Iota]\)\ 2  \[Pi]\ n\ t/T\)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.49)"],

Cell[TextData[{
  "It is easy to see why Eq. ",
  ButtonBox["(2.3.49)",
    ButtonData:>"(2.3.49)",
    ButtonStyle->"Hyperlink"],
  " is a periodic \[Delta]-function. If ",
  Cell[BoxData[
      \(TraditionalForm\`t = \ m\ T\)]],
  " for any integer ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[Iota]\)\ 2  \[Pi]\ n\ t/T\) \
= \(\(\[ExponentialE]\^\(\(-\[Iota]\)\ 2  \[Pi]\ n\ m\)\)\(=\)\(1\)\(\ \
\)\)\)]],
  "for all ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", and the series sums to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Infinity]\)]],
  " . At these instants of time, each Fourier mode is ",
  StyleBox["in phase",
    FontSlant->"Italic"],
  ". However, if ",
  Cell[BoxData[
      \(TraditionalForm\`t \[NotEqual] \ \ m\ T\)]],
  ", the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[Iota]\)\ 2  \[Pi]\ n\ \
t/T\)\)]],
  " evaluates to a series of complex numbers, each with magnitude of unity, \
but with different phases. Adding together these complex numbers, there is ",
  StyleBox[" destructive interference",
    FontSlant->"Italic"],
  " between the modes, causing the sum to equal zero. Thus, we get a function \
that is infinite for ",
  Cell[BoxData[
      \(TraditionalForm\`t = \ m\ T\)]],
  ", and zero for ",
  Cell[BoxData[
      \(TraditionalForm\`t \[NotEqual] \ \ m\ T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tHowever, the easiest way to see that this series creates a periodic \
\[Delta]-function is to examine the series as a function of time using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The following evaluation creates a periodic \[Delta]-function by keeping \
300 terms in the Fourier series of Eq. ",
  ButtonBox["(2.3.49)",
    ButtonData:>"(2.3.49)",
    ButtonStyle->"Hyperlink"],
  ". We choose a period of 1/5 s, and note that the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " can be written in terms of cosines since the sine functions are odd in ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " and  cancel:"
}], "Text"],

Cell[BoxData[
    \(\(1\  + \ 2  Sum[\ Cos[2\ Pi\ n\ 5\ t], {n, 1, 300}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.58"],

Cell[TextData[{
  "We could plot this function, but it is more fun to ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " it (Cell ",
  ButtonBox["2.59",
    ButtonData:>"Cell 2.59",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Play[%, {t, \(-1.5\),  .5}, PlayRange \[Rule] All]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.59"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 16384 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D
2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D
2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D
2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2C
2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C
2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C
2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C
2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C
2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C
2C2E2E2D2C2C2D2E2E2D2B2C2E2E2D2C2C2D2E2E2C2B2C2E2F2D2C2B2D2F2E2C2B2C2E2F2D2B
2B2D2F2E2C2B2C2F2F2D2B2B2E2F2E2C2B2D2F2F2D2B2B2E2F2E2B2A2D2F2F2C2A2B2F302E2B
2A2D302F2C2A2B2F302D2A2A2E31302B292B30312D29292E32302A272B32332C262830353127
242C35362B2125343C32201B2C444323020F5CC3FEE3862700133948371F1B2B3A392A212632
373026252D34332B262931332E28282D32302B282B30312D29292E312F2B292C30302D2A2A2E
302F2B2A2C2F2F2D2A2B2E302E2B2A2D2F2F2C2B2C2E2F2E2B2B2D2F2F2C2B2C2E2F2D2B2B2D
2F2E2C2B2C2E2F2D2B2C2D2F2E2C2B2C2E2E2D2B2C2D2F2E2C2B2D2E2E2D2C2C2E2E2D2C2C2D
2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D
2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D
2E2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C
2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C
2D2E2D2D2C2D2D2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C
2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2D2D2D2C
2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C
2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C
2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D
2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D
2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D
2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2C2D
2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D
2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D
2E2E2D2C2D2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D
2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C
2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C
2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2B2C2E2E2D2C2C2D2F2E2C2B2C2E2F2D2B2C
2D2F2E2C2B2D2F2F2D2B2C2E2F2E2C2B2D2F2F2C2B2C2E2F2E2B2B2D2F2F2C2A2C2F302D2B2A
2D302F2C2A2C2F302D2A2A2E302F2B292C30312D292A2E322F2A282C31322C272930332F2826
2C34332B242832373024222D3A38271A233C48320C02379BEFF8AF4907062B4640271A23363C
3123222D37342A242932342E27272E33312A272B31322D28292E322F2A292C30312D292A2E31
2F2B2A2C30302C2A2B2E302E2B2A2D2F2F2C2A2C2E2F2E2B2B2D2F2F2C2B2C2E2F2D2B2B2D2F
2E2C2B2C2E2F2D2B2C2D2F2E2C2B2D2E2E2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2E2D2C2C2D2E
2E2C2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E
2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2D2E
2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D
2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D
2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D
2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D
2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D
2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D
2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D
2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D
2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D
2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D
2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E
2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E
2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E
2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E
2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2D2E
2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E
2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2B2C2E2E2D2C2C2D2F2E2C2B2D2E2E2D2B2C2E
2F2E2C2B2D2E2E2D2B2C2E2F2E2C2B2D2F2F2C2B2C2E2F2D2B2B2D2F2F2C2A2C2F2F2D2B2B2D
302F2C2A2C2F302D2A2B2E302F2B2A2C30302D292A2E312F2A292C31312C282A2F322F29282D
33322B262931352F26252E3734282128363B2F1D1C32463F1B001A71D4FFD4711A001B3F4632
1C1D2F3B3628212834372E25262F353129262B32332D28292F322F2A282C31312C292A2F312E
2A292D30302C2A2B2F302E2B2A2D302F2C2A2C2F302D2B2B2D2F2F2C2A2C2F2F2D2B2B2D2F2E
2C2B2C2F2F2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2F2D2C2C2D2E2E
2C2B2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E
2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E
2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E
2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E
2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E
2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D
2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D
2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D
2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D
2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D
2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D
2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D
2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2E2D
2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D
2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D
2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E
2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E
2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E
2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2B2D2E2E2D2B2C2E2F
2E2C2B2D2E2E2D2B2C2E2F2D2C2B2D2F2E2C2B2C2E2F2D2B2B2D2F2E2C2B2C2F2F2D2B2B2E2F
2E2C2A2C2F2F2D2A2B2E302E2B2A2C30302C2A2B2F312E2A292D31302C292A2F322E29282D32
312B272A31332E27272E343229242A34372D2223313C36231A2740462B060749AFF8EF9B3702
0C32483C231A27383A2D222430373228242B33342C26282F333029272C32312C282A2F322E2A
292D31302C292B2F302E2A2A2D302F2C2A2C2F302D2A2B2D302F2C2A2C2F2F2D2B2B2E2F2E2C
2B2C2F2F2D2B2C2E2F2E2C2B2D2F2F2D2B2C2E2F2D2C2B2D2F2E2C2B2C2E2F2D2C2C2D2E2E2C
2B2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D
2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D
2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D
2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D
2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D
2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D
2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D
2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D
2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D
2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C
2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C
2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C
2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2E2D2D
2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D
2C2D2D2E2D2C2C2D2E2D2D2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D
2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D
2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D
2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D
2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2B2C2E2F2D
2C2B2D2E2E2C2B2C2E2F2D2C2B2D2F2E2C2B2C2E2F2D2B2B2D2F2E2C2B2C2F2F2D2B2B2E2F2E
2C2B2C2F2F2D2A2B2E302E2B2A2D2F2F2C2A2B2F302E2A2A2D30302C292B2F312E29292D3130
2B282B30322D28282E333129262B33342D252630373226212A393A2B1B1F37483913002786E3
FEC35C0F022343442C1B20323C3425212B36352C242731353028262C33322B272A30322E2929
2D31302B292B30312E2A2A2D302F2B2A2C2F302D2A2B2E302F2B2A2C2F2F2D2A2B2E2F2E2B2B
2D2F2F2D2B2C2E2F2E2B2B2D2F2F2C2B2C2E2F2D2B2B2D2F2E2C2B2C2E2F2D2B2C2D2F2E2C2B
2C2E2E2D2C2C2D2E2E2C2B2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C
2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C
2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C
2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C
2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D
2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D
2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D
2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D
2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D
2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D
2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D
2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2D
2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C
2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C
2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C
2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C
2D2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C
2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C
2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2B2C2E2E2D2C
2C2D2E2E2C2B2C2E2F2D2C2B2D2F2E2C2B2C2E2F2D2B2B2D2F2E2C2B2C2F2F2D2B2B2E2F2E2C
2B2D2F2F2D2B2B2E2F2E2B2A2D2F2F2C2A2B2F302E2B2A2D302F2C2A2B2F302D2A2A2E31302B
292B30312D29292E32302A272B32332C262830353127242C35362B2125343C32201B2C444323
020F5CC3FEE3862700133948371F1B2B3A392A212632373026252D34332B262931332E28282D
32302B282B30312D29292E312F2B292C30302D2A2A2E302F2B2A2C2F2F2D2A2B2E302E2B2A2D
2F2F2C2B2C2E2F2E2B2B2D2F2F2C2B2C2E2F2D2B2B2D2F2E2C2B2C2E2F2D2B2C2D2F2E2C2B2C
2E2E2D2B2C2D2F2E2C2B2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C
2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C
2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C
2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C
2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2D2D2E2D2C2C
2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C
2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C
2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C
2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D
2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D
2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D
2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D
2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D
2D2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D
2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D
2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2E2D2C2D
2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C
2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C
2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C
2D2E2E2C2B2C2E2E2D2C2C2D2F2E2C2B2C2E2F2D2B2C2D2F2E2C2B2D2F2F2D2B2C2E2F2E2C2B
2D2F2F2C2B2C2E2F2E2B2B2D2F2F2C2A2C2F302D2B2A2D302F2C2A2C2F302D2A2A2E302F2B29
2C30312D292A2E322F2A282C31322C272930332F28262C34332B242832373024222D3A38271A
233C48320C02379BEFF8AF4907062B4640271A23363C3123222D37342A242932342E27272E33
312A272B31322D28292E322F2A292C30312D292A2E312F2B2A2C30302C2A2B2E302E2B2A2D2F
2F2C2A2C2E2F2E2B2B2D2F2F2C2B2C2E2F2D2B2B2D2F2E2C2B2C2E2F2D2B2C2D2F2E2C2B2D2E
2E2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E2C2C2C2E
2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D
2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D
2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D
2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D
2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D
2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D
2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D
2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D
2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D
2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D
2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D
2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D
2D2D2C2D2D2D2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D
2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D
2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D
2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D
2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D
2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D
2E2E2C2B2C2E2E2D2C2C2D2F2E2C2B2D2E2E2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2F2E2C2B2D
2F2F2C2B2C2E2F2D2B2B2D2F2F2C2A2C2F2F2D2B2B2D302F2C2A2C2F302D2A2B2E302F2B2A2C
30302D292A2E312F2A292C31312C282A2F322F29282D33322B262931352F26252E3734282128
363B2F1D1C32463F1B001A71D4FFD4711A001B3F46321C1D2F3B3628212834372E25262F3531
29262B32332D28292F322F2A282C31312C292A2F312E2A292D30302C2A2B2F302E2B2A2D302F
2C2A2C2F302D2B2B2D2F2F2C2A2C2F2F2D2B2B2D2F2E2C2B2C2F2F2D2B2C2E2F2E2C2B2D2E2E
2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2F2D2C2C2D2E2E2C2B2C2E2E2D2C2C2D2E2E2C2C2C2E2E
2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E
2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E
2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E
2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E
2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D
2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D
2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D
2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D
2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D
2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D
2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D
2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D
2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D
2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E
2D2C2C2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E
2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E
2D2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E
2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E
2E2C2C2C2E2E2D2C2C2D2E2E2C2B2D2E2E2D2B2C2E2F2E2C2B2D2E2E2D2B2C2E2F2D2C2B2D2F
2E2C2B2C2E2F2D2B2B2D2F2E2C2B2C2F2F2D2B2B2E2F2E2C2A2C2F2F2D2A2B2E302E2B2A2C30
302C2A2B2F312E2A292D31302C292A2F322E29282D32312B272A31332E27272E343229242A34
372D2223313C36231A2740462B060749AFF8EF9B37020C32483C231A27383A2D222430373228
242B33342C26282F333029272C32312C282A2F322E2A292D31302C292B2F302E2A2A2D302F2C
2A2C2F302D2A2B2D302F2C2A2C2F2F2D2B2B2E2F2E2C2B2C2F2F2D2B2C2E2F2E2C2B2D2F2F2D
2B2C2E2F2D2C2B2D2F2E2C2B2C2E2F2D2C2C2D2E2E2C2B2C2E2E2D2C2C2D2E2E2C2C2D2E2E2D
2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D
2C2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D
2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D
2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D
2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D
2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D
2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D
2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D
2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D
2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D
2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2C2C2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D
2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D
2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2D2D
2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D
2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D
2C2C2D2E2E2D2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D
2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C2C2D2E2E
2C2C2D2E2E2D2C2C2D2E2E2C2C2D2E2E2D2B2C2E2F2D2C2B2D2E2E2C2B2C2E2F2D2C2B2D2F2E
2C2B2C2E2F2D2B2B2D2F2E2C2B2C2F2F2D2B2B2E2F2E2C2B2C2F2F2D2A2B2E302E2B2A2D2F2F
2C2A2B2F302E2A2A2D30302C292B2F312E29292D31302B282B30322D28282E333129262B3334
2D252630373226212A393A2B1B1F37483913002786E3FEC35C0F022343442C1B20323C342521
2B36352C242731353028262C33322B272A30322E29292D31302B292B30312E2A2A2D302F2B2A
2C2F302D2A2B2E302F2B2A2C2F2F2D2A2B2E2F2E2B2B2D2F2F2D2B2C2E2F2E2B2B2D2F2F2C2B
2C2E2F2D2B2B2D2F2E2C2B2C2E2F2D2B2C2D2F2E2C2B2C2E2E2D2C2C2D2E2E2C2B2D2E2E2D2C
2C2D2E2E2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2D2C2C2E2E2D2C2C2D2E2E2C2C2C2E2E2D2C
2C2D2E2E2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2C2D2E2D2C
2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2D2C2D2E2E2D2C2C2D2E2D2C
2C2D2E2E2D2C2C2D2E2D2C2C2D2E2E2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D
2C2D2D2E2D2C2C2D2E2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2E2D2C2C2D2D2D2D
2C2D2D2E2D2C2C2D2D2D2D2C2D2D2E2D2C2C2D2E2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D
2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D
2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D2D2C2D2D2D2D2C2D2D2D2D
2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D2D2C2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D2D
2D2D2D2D2D2D
pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oo`00/@0000000`00
Oomoo`3oOon]Ool100000003001oogoo01Aoo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo
02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo
02Qoo`03001oogoo02Qoo`03001oogoo01Aoo`40000000<007ooOol0JWoo00<007ooOol09goo00<0
07ooOol0:7oo00<007ooOol0OGoo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol057oo0@00
00000`00Oomoo`0oOol00`00Oomoo`3COol00`00Oomoo`2DOol100000003001oogoo09Aoo`03001o
ogoo02Qoo`03001oogoo0:Qoo`03001oogoo02Qoo`03001oogoo01Aoo`40000000<007ooOol057oo
00<007ooOol0:7oo00<007ooOol09goo00<007ooOol0Dgoo00<007ooOol0:7oo00<007ooOol09goo
00<007ooOol0:7oo00<007ooOol0Dgoo00<007ooOol057oo0@0000000`00Oomoo`0DOol00`00Oomo
o`0XOol00`00Oomoo`0WOol2000YOol00`00Oomoo`1COol00`00Oomoo`0XOol00`00Oomoo`0WOol0
0`00Oomoo`0XOol00`00Oomoo`0oOol100000003001oo`0001Aoo`03001oogoo02Moo`8002Uoo`80
02Uoo`8002Uoo`03001oogoo02Moo`8002Uoo`8002Uoo`8002Uoo`03001oogoo02Moo`8001Ioo`40
000000<007oo0000o`00[0000Goo0@0000000`00Oomoo`0BOol5000VOol4000WOol5000UOol5000V
Ool5000UOol6000VOol4000VOol6000UOol5000VOol5000DOol100000003001oogoo01Aoo`03001o
ogoo02Moo`8002Uoo`8002Uoo`8002Uoo`03001oogoo02Qoo`03001oogoo02Moo`8002Uoo`8002Uo
o`03001oogoo02Qoo`03001oogoo01Aoo`40000000<007ooOol057oo00<007ooOol0:7oo00<007oo
Ool0:7oo00<007ooOol09goo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007oo
Ool09goo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol057oo0@0000000`00Oomoo`0oOol0
0`00Oomoo`0WOol00`00Oomoo`2XOol00`00Oomoo`0XOol00`00Oomoo`1ZOol100000003001oogoo
01Aoo`03001oogoo07eoo`03001oogoo05=oo`03001oogoo07eoo`03001oogoo03moo`40000000<0
07ooOol057oo00<007ooOol0OGoo00<007ooOol0Dgoo00<007ooOol0OGoo00<007ooOol0?goo0@00
00000`00Oomoo`0oOol00`00Oomoo`0WOol00`00Oomoo`1COol00`00Oomoo`1COol00`00Oomoo`0W
Ool00`00Oomoo`1COol00`00Oomoo`0DOol100000003001oogoo01Aoo`03001oogoo02Qoo`03001o
ogoo02Moo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Moo`03001o
ogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo01Aoo`40000000<007ooOol0ogoo
[Goo0@00003o002a00000003001oogoo0?moojeoo`40000000<007ooOol057oo00<007ooOol0DWoo
0P00E7oo00<007ooOol0:7oo00<007ooOol0DWoo00<007ooOol0Dgoo00<007ooOol057oo0@000000
0`00Oomoo`0DOol00`00Oomoo`0XOol00`00Oomoo`1BOol00`00Oomoo`0XOol00`00Oomoo`0XOol0
0`00Oomoo`0WOol00`00Oomoo`1COol00`00Oomoo`0XOol00`00Oomoo`0DOol100000003001oogoo
0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo
03moo`03001oogoo059oo`03001oogoo07ioo`03001oogoo059oo`03001oogoo03moo`40000000<0
07ooOol0?goo00<007ooOol0DWoo00<007ooOol0OWoo00<007ooOol0DWoo00<007ooOol0?goo0@00
00000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@00
00000`00Oomoo`3oOon]Ool100000003001oogoo03moo`03001oogoo059oo`03001oogoo07eoo`03
001oogoo05=oo`03001oogoo03moo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]
Ool100000003001oogoo01Aoo`03001oogoo0:Qoo`03001oogoo02Qoo`03001oogoo0:Qoo`03001o
ogoo01Aoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo
0?moojeoo`40000000<007ooOol057oo00<007ooOol0Z7oo00<007ooOol0:7oo00<007ooOol0Z7oo
00<007ooOol057oo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<0
07ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<0
07ooOol0?Woo0P00:Goo00<007ooOol0:7oo00<007ooOol0OGoo0P00:Goo00<007ooOol0:7oo00<0
07ooOol0?goo0@0000000`00Oomoo`0DOol00`00Oomoo`1BOol2001DOol00`00Oomoo`0WOol2001D
Ool00`00Oomoo`1COol00`00Oomoo`0DOol100000003001oogoo06Uoo`800=Aoo`8006]oo`400000
00<007ooOol0JGoo0P00e7oo0P00Jgoo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo01Ao
o`03001oogoo0:Qoo`03001oogoo02Qoo`03001oogoo0:Qoo`03001oogoo01Aoo`40000000<007oo
Ool057oo00<007ooOol0Z7oo00<007ooOol09goo00<007ooOol0ZGoo00<007ooOol057oo0@000000
0`00Oomoo`0COol2001DOol2001DOol00`00Oomoo`0WOol2001DOol2001COol2000FOol100000003
001oogoo03ioo`8005Aoo`8007ioo`8005Aoo`03001oogoo03moo`40000000<007ooOol057oo00<0
07ooOol09goo0P00E7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol09goo0P00E7oo00<0
07ooOol0:7oo00<007ooOol057oo0@0000000`00Oomoo`0COol00`00Oomoo`0XOol2001DOol2000Y
Ool00`00Oomoo`0WOol00`00Oomoo`0XOol2001DOol2000YOol00`00Oomoo`0DOol100000003001o
ogoo01=oo`8005Aoo`8005=oo`8002Uoo`8005Aoo`8005=oo`8001Ioo`40000000<007ooOol04goo
0`00:7oo00<007ooOol0:7oo0P00:Woo00<007ooOol09Woo0`00:7oo0P00:Goo00<007ooOol0:7oo
0P00:Woo00<007ooOol09Woo00<007oo00005Goo0@0000000`00Oomoo`0COol3000XOol3000WOol3
000XOol3000XOol3000XOol3000XOol2000XOol3000XOol3000XOol3000EOol100000003001oogoo
01=oo`03001oo`0002Moo`@002Moo`@002Moo`<002Qoo`03001oo`0002Qoo`<002Moo`@002Moo`@0
02Moo`<002Qoo`03001oo`0001Eoo`40000000<007ooOol04Woo1@009Woo10009Woo0P0000=oo`00
00009Woo1@009Woo1@009Woo1@009Woo10009Woo0P0000=oo`0000009Woo1@009Woo0P0000=oo`00
000057oo0@0000000`00Oomoo`0AOol7000TOol7000SOol8000SOol7000TOol7000SOol8000SOol8
000SOol8000SOol7000TOol7000COol100000003001oogoo00QooaT0015oo`d00003Ool0000000X0
015oo``00003Ool0000000/0015oo``00003Ool0000000X0019ooaT0019ooaT0015oo`d00003Ool0
000000X0015oo``00003Ool0000000/0015oo``00003Ool0000000X0019ooaT000Yoo`40000000<0
07oo0000_`0000=oo`000000d`0000=oo`0000004`000Goo0@0000000`00Oomoo`0;Ool900000goo
00000007000HOolB000HOolC000HOolC000HOol900000goo00000007000HOol900000goo00000007
000HOol800000goo00000007000HOolC000HOol900000goo00000007000HOol900000goo00000007
000=Ool100000003001oogoo015oo`<00004Ool00000000TOol3000017oo000000008goo1`0097oo
0`0000Aoo`00000002Aoo`<00004Ool00000000TOol20002Ool3000TOol300000goo0000000TOol7
000TOol3000017oo0000000097oo0`0000Aoo`00000001=oo`40000000<007ooOol04Woo1@009Woo
0P0000=oo`00Ool09Woo00@007ooOol002Moo`04001oo`00000VOol200000goo0000000VOol4000W
Ool200000goo001oo`0VOol01000Oomoo`009Woo1@009Woo10005Goo0@0000000`00Oomoo`0COol0
0`00Ool0000WOol4000WOol4000WOol3000XOol00`00Ool0000XOol3000WOol4000WOol3000XOol3
000XOol3000EOol100000003001oogoo01=oo`<002Qoo`<002Qoo`8002Qoo`<002Qoo`<002Qoo`<0
02Moo`@002Moo`<002Qoo`<002Qoo`<001Eoo`40000000<007ooOol04goo0`00:7oo0P00:Goo0P00
:7oo00<007oo0000:7oo00<007oo0000:7oo0P00:Goo0P00:Goo0P00:7oo00<007oo0000:7oo00<0
07oo00005Goo0@0000000`00Oomoo`0DOol00`00Oomoo`0WOol2000YOol2000YOol2000XOol2000Y
Ool2000YOol2000YOol2000XOol3000XOol2000FOol100000003001oogoo01=oo`03001oogoo05=o
o`8005Aoo`8002Qoo`03001oogoo05=oo`8005Aoo`03001oogoo01Aoo`40000000<007ooOol04goo
00<007ooOol0:Goo00<007ooOol09goo0P00:Goo00<007ooOol0:7oo00<007ooOol09goo00<007oo
Ool0:Goo00<007ooOol09goo0P00:Goo00<007ooOol0:7oo00<007ooOol057oo0@0000000`00Oomo
o`0DOol00`00Oomoo`0WOol2000YOol2000YOol2000XOol2000ZOol00`00Oomoo`0WOol2000YOol2
000YOol2000XOol2000FOol100000003001oogoo03ioo`03001oogoo05=oo`03001oogoo07eoo`03
001oogoo05=oo`03001oogoo03moo`40000000<007ooOol057oo00<007ooOol0Z7oo00<007ooOol0
:7oo00<007ooOol0Z7oo00<007ooOol057oo0@0000000`00Oomoo`0DOol00`00Oomoo`0WOol00`00
Oomoo`1DOol00`00Oomoo`0WOol00`00Oomoo`0XOol00`00Oomoo`0WOol00`00Oomoo`1COol00`00
Oomoo`0XOol00`00Oomoo`0DOol100000003001oogoo01Aoo`03001oogoo02Moo`8002Uoo`8002Uo
o`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo02Qoo`8002Uoo`8002Uoo`03001oogoo02Qo
o`03001oogoo01Aoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003
001oogoo06Uoo`800=Aoo`03001oogoo06Yoo`40000000<007ooOol0?goo00<007ooOol0DWoo00<0
07ooOol0OWoo00<007ooOol0DWoo00<007ooOol0?goo0@0000000`00Oomoo`3oOon]Ool100000003
001oogoo0?moojeoo`40000000<007ooOol057oo00<007ooOol0Z7oo00<007ooOol0:7oo00<007oo
Ool0Z7oo00<007ooOol057oo0@0000000`00Oomoo`0DOol00`00Oomoo`2XOol00`00Oomoo`0XOol0
0`00Oomoo`2XOol00`00Oomoo`0DOol100000003001oogoo0?moojeoo`40000000<007ooOol0?goo
00<007ooOol09goo0P00:Goo00<007ooOol0OWoo00<007ooOol09goo00<007ooOol0:7oo00<007oo
Ool0?goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo01Aoo`03001oogoo02Moo`03001o
ogoo05=oo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Moo`03001oogoo05=oo`03001o
ogoo02Qoo`03001oogoo01Aoo`40000000<007ooOol0?goo00<007ooOol0DWoo00<007ooOol0OWoo
00<007ooOol0DWoo00<007ooOol0?goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?mo
ojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?mo
ojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?mo
ojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?mo
ojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?mo
ojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?mo
ojeoo`40000000<007ooOol057oo00<007ooOol0Z7oo00<007ooOol0:7oo00<007ooOol0Z7oo00<0
07ooOol057oo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007oo
Ool0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007oo
Ool0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007oo
Ool0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007oo
Ool0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007oo
Ool0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007oo
Ool0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo06Uoo`03001oogoo0==oo`03
001oogoo06Yoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`0DOol00`00Oomoo`2XOol0
0`00Oomoo`0XOol00`00Oomoo`2XOol00`00Oomoo`0DOol100000003001oogoo0?moojeoo`400000
00<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`400000
00<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`400000
00<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`400000
00<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`400000
00<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`400000
00<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`400000
00<007ooOol0?goo00<007ooOol0DWoo00<007ooOol0OGoo00<007ooOol0Dgoo00<007ooOol0?goo
0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo
0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo
0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo
0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo
0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo
0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo
0@0000000`00Oomoo`0oOol00`00Oomoo`1BOol00`00Oomoo`1nOol00`00Oomoo`1BOol00`00Oomo
o`0oOol100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3o
Oon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3o
Oon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3o
Oon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3o
Oon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3o
Oon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3o
Oon]Ool100000003001oogoo01Aoo`03001oogoo0:Qoo`03001oogoo02Qoo`03001oogoo0:Qoo`03
001oogoo01Aoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001o
ogoo0?moojeoo`40000000<007ooOol0JGoo00<007ooOol0dgoo00<007ooOol0JWoo0@0000000`00
Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00
Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00
Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00
Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00
Oomoo`3oOon]Ool100000003001oogoo01Aoo`03001oogoo0:Qoo`03001oogoo02Qoo`03001oogoo
0:Qoo`03001oogoo01Aoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool10000
0003001oogoo0?moojeoo`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`0oOol00`00Oomo
o`1BOol00`00Oomoo`1mOol00`00Oomoo`1COol00`00Oomoo`0oOol100000003001oogoo0?moojeo
o`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeo
o`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeo
o`40000000<007ooOol0ogoo[Goo0@0000000`00Oomoo`0oOol00`00Oomoo`1BOol00`00Oomoo`1n
Ool00`00Oomoo`1BOol00`00Oomoo`0oOol100000003001oogoo0?moojeoo`40000000<007ooOol0
ogoo[Goo0@0000000`00Oomoo`3oOon]Ool100000003001oogoo0?moojeoo`40000000<007ooOol0
ogoo[Goo0@0000000`00Oomoo`0DOol00`00Oomoo`2XOol00`00Oomoo`0XOol00`00Oomoo`2XOol0
0`00Oomoo`0DOol100000003001oogoo06Uoo`03001oogoo0==oo`03001oogoo06Yoo`40000000<0
07ooOol0ogoo[Goo0@00003o002a00000001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 431}, {265.875, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@0000000100200000000000000000l;Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/
;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];2d];Bd]
;2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd^;B`/;Bh]
;B`];Bd];2`];Rd];2d];Bd/;2d^;Bd/;Bd];B`];Bh];2`];Rd];2d];Rd/;2d^
;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`]
;Rh];2d];Rd/;2d^;Rd/;Bd^;B`/;Bh];B`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/
;Bh^;B`/;Bh];2`];Rh];2`^;Rd/;2d^;R`/;2h^;B`/;Bh^;2`];Rh];2`];Rh/
;2d^;Rd/;2h^;B`/;Bh^;B//;Rh];2`];Rh/:b`^;bd/:bd_;R`[;2h_;B/[;Bl^
;2//;bl]:b/^;bh/:bd_;bd[:bh_;R/Z;Bl_;2X[;c0^:bX]<2l/:R/_<2dZ:Rha
<2/Y:c0a;BTY;S8`:RL[<S</9RP`=C4W92`e=R/Q9C@l<R0K;4A38`8?G<?nhhHW
01<iB3LO6b/j>BXQ9S8g<2HU;C@c:bHY<C<^:2P]<S0[:2/`<BdY:Bha;b/Y;30`
;BXZ;S0_:bX/;bl]:R/^<2h[:Rd_;b`[;2h_;R/[;Bl_;2//;Rl]:b/];bh/:b`^
;bd[;2d_;R`[;2h^;B//;Bl^;2/];Rh];2`^;Rd/;2d^;Rd/;2h^;B`/;Bh^;2`/
;Rh];2`];Rh/;2d^;Rd/;2d^;R`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/
;2d^;B`/;Bh^;B`];Rh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh]
;2`];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^
;B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bd];2`];Rd];2d]
;Bd/;Bd^;Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];B`/;Bd];B`]
;Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];Bd];Bd/
;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd]
;2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd]
;B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];2`];Bd];2d];Bd/;2d^
;Bd/;Bd];B`/;Bh];B`];Bd];2d];Rd];2d];Bd/;Bd^;B`/;Bh];B`];Bh];2`]
;Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/
;Bh^;B`];Bh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/
;2d^;Rd/;2d^;B`/;Bh^;B`/;Rh];2`];Rh/;2d^;Rd/;2d^;R`/;Bh^;B`/;Bh]
;2`];Rh];2`^;Rd/;2d^;Rd/;2h^;B`/;Bh^;2//;Rh];2`];bh/:b`^;bd[;2d_
;R`[;Bl_;B//;Rl^;2/];bl/:b`^;bh[:bd_;b`Z;2l`;B/Z;C0_;2X/;c0]:RX^
<2l[:B``<BdY:Rhb;bXX;34b;2LY<3<_:2H/=3<[92Pb=c0T8Rdj>2LJ8ca8<P`2
=i__n:m91`H[AT0W6R<f?34S8Rdg=2XT:C8d;RLW;S<a:RL[<C8]:2T^<RlZ:B``
<BdY:Rha;b/Z;30`;2X[;S0^:bX];bl/:R`^;bh[:bd_;b`[;2h_;B/[;Bl^;2//
;Rl]:b`];bh/:bd^;Rd[;2h_;R`[;Bh^;B//;Rh];2`];Rh/;2`^;Rd/;2d^;R`/
;2h^;B`/;Bh^;2`];Rh];2`];Rh/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh]
;2`^;Rd/;2d^;Rd/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^
;B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd/;2d^
;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd];B`/;Bh];B`]
;Bd];2d];Rd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];2`];Bd];2d];Bd/;Bd];Bd/
;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];Bd];Bd]
;2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd]
;B`];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd]
;B`];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd/;Bd]
;Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];B`/;Bd];B`];Bd];2`]
;Rd];2d];Bd/;Bd^;Bd/;Bd];B`];Bh];B`];Bd];2d];Rd/;2d^;Bd/;Bd^;B`/
;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;B`/;Bh^;B`];Bh];2`];Rd];2d];Rd/
;2d^;Bd/;Bd^;B`/;Bh];B`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh]
;2`];Rh];2`^;Rd/;2d^;Rd/;Bh^;B`/;Bh^;2`];Rh];2`];Rd/;2d^;Rd/;2d^
;B`/;Bh^;B`/;Rh];2`];Rh/;2`^;Rd/;2d^;R`[;2h^;B`/;Bl^;2/];Rh]:b`^
;bh/:bd^;Rd[;2h_;R`[;Bl_;2//;Rl]:b/];bl/:R`_;bd[:bd`;b`Z;2l`;BX[
;S0_:bX/<30]:BX^<BlZ:B`a<B`X:Rlb;bTX;C<b:bHY<CD_9RD^=c@X8BPf>blM
7396?a/06W7DomAa6P0K?dHb71d_>cHX8BPd=bhU9Rle<BTV:c8c;BPY;c8_:RP/
<C4/:BX_<BhZ:Bd`<2`Z:bl`;R/Z;C0_;2X/;c0]:b/];bl/:R`_;bd[:bd_;R`[
;2l_;B//;Rl^;2/];Rh]:b`^;bh/:bd^;Rd[;2h_;B`/;Bh^;2//;Rh];2`];Rh/
;2`^;Rd/;2d^;R`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2h^;B`/;Bh^
;B`];Rh];2`];Rh/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^
;Rd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bh^;B`/;Bh];2`]
;Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Bd/;Bd^;Bd/
;Bd];B`];Bh];B`];Bd];2d];Rd/;2d];Bd/;Bd];B`/;Bd];B`];Bd];2d];Bd]
;2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd]
;B`];Bd];Bd];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];Bd];Bd];2d];Bd];Bd]
;Bd/;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd/;Bd]
;Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd];B`];Bd];2d]
;Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd/;2d];Bd/;Bd];B`]
;Bd];B`];Bd];2d];Rd];2d];Bd/;Bd^;B`/;Bd];B`];Bh];2`];Rd];2d];Rd/
;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh]
;2`];Rd];2d];Rd/;2d^;Bd/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^
;B`/;Bh^;B`];Rh];2`];Rh/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`^
;Rd/;2d^;Rd/;2h^;B`/;Bh^;2`/;Rh];2`];Rh/;2`^;Rd/;2d^;R`[;Bh^;B//
;Rl^;2/];Rh]:b`^;bd/:bd_;R`[;2h_;B/[;Bl^;2//;bl]:b/^;bh/:R`_;bdZ
:bh`;R/Z;30`;2X[;c4^:RT]<C0/:BX_<RhY:2db<B/W:S4c;RLW;S@b:B@Z=3L]
8R<a?3HS6RM0AR/61dV_n>nK=`8<<TPl8aXW>3X]8R@`=c8X92/c=2`V:2lc<2TW
;38a;2PZ;c8^:RT]<C0/:B/_<2hZ:Rd`;b`Z;2l`;BX[;C0_;2X/;bl]:b/^;bh/
:b`_;bd[;2h_;R`[;Bl_;B//;Rl];2/];bh/:b`^;bd/;2d^;R`[;2h^;B`/;Bh^
;2`];Rh];2`];Rh/;2d^;Rd/;2d^;B`/;Bh^;B`/;Rh];2`];Rh];2`^;Rd/;2d^
;R`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`]
;Rh];2d];Rd/;2d^;Bd/;Bh^;B`/;Bh];B`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/
;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bd];2d];Rd]
;2d];Bd/;Bd^;B`/;Bd];B`];Bh];2`];Bd];2d];Bd/;2d];Bd/;Bd];B`];Bd]
;B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];Bd];Bd];2d];Bd/;Bd]
;Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd]
;Bd];2d];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];2d]
;Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd/;Bd];Bd/;Bd];B`]
;Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];B`/;Bd];B`];Bd];2d];Bd];2d];Bd/
;Bd];Bd/;Bd];B`];Bh];B`];Bd];2d];Rd/;2d];Bd/;Bd^;B`/;Bh];B`];Bh]
;2`];Rd];2d];Rd/;2d^;Bd/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^
;B`/;Bh];B`];Bh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2d]
;Rd/;2d^;Rd/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/
;Rh];2`];Rh];2`^;Rd/;2d^;R`/;2h^;B`/;Bh^;2`];Rh];2`];Rh/;2d^;Rd[
;2h_;B`[;Bh^;2//;Rl];2/];bh/:b`^;bd[:bd_;R`[;2l_;B/[;Rl^;2//;bl]
:R/^<2h[:Rd_;b`Z:bl`;RXZ;C0`;2T[;c4^:BT]<C0[:2/`<RdX:2hc<BTV:c<d
;BDV<3Lb9R4Z>CX[6algB3TC02N6hok3G0l28d=4;1/P<S`d9B4[=SD/92La=C0X
9R`c<R/W:S0b;RTY;C4`:bT[<34^:RX]<2l[:R`_<2dZ:bh`;b/Z;2l_;BX[;Rl^
:b/];bl]:b`^;bh[:bd_;b`[;2h_;B/[;Bl^;2//;Rl]:b`];bh/:b`^;Rd/;2d^
;R`[;Bh^;B`/;Bh^;2`];Rh];2`^;Rd/;2d^;Rd/;2h^;B`/;Bh^;2`/;Rh];2`]
;Rh/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/
;Bh];B`];Rh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2d];Rd/
;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd];B`];Bh]
;2`];Bd];2d];Rd/;2d];Bd/;Bd^;B`/;Bh];B`];Bd];2d];Bd];2d];Bd/;Bd]
;Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];B`];Bd];B`];Bd];2d]
;Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];Bd]
;Bd];B`];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];B`]
;Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];2d];Bd];2d];Bd/
;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd]
;2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bh];2`];Rd];2d];Bd/;2d^;Bd/;Bd]
;B`/;Bh];B`];Bd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d]
;Rd/;2d^;Bd/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/;Bh^;B`]
;Bh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/
;2h^;B`/;Bh^;2`/;Rh];2`];Rh/;2d^;Rd/;2d^;R`/;Bh^;B`/;Rh];2`];Rh]
:b`^;Rd/;2d^;R`[;2h_;B`[;Bl^;2//;Rl]:b/];bh/:b`_;bd[:bh_;R`[;Bl_
;B/[;Rl^:bX];bl/:R/_<2h[:Rd`;b`Z:bl`;BXZ;S4`:bT[<34]:BT^<S0Z9b/b
<b`V:30e<BLT;3Df:b4U=3`b81//A4<S0PmL`okSQRL04cU8=alK:cXi:R4V<SL`
9RD]=3<[9RTa<bhX:2db<2/X:c0a;BTY;S4_:bT/<30]:RX^<2l[:R`_;bdZ:bh`
;R/Z;Bl_;2//;Rl^:b/];bl/:b`^;bd[:bd_;R`[;2h_;B//;Bl^;2//;Rh]:b`]
;bh/:bd^;Rd/;2h^;B`/;Bh^;B`/;Rh];2`];Rh/;2`^;Rd/;2d^;R`/;Bh^;B`/
;Bh^;2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2d^;Rd/
;2d^;Bd/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh];B`];Bh]
;2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2d];Rd/;2d^;Bd/;Bd^
;B`/;Bh];B`];Bh];2`];Rd];2d];Bd/;2d^;Bd/;Bd];B`];Bh];B`];Bd];2d]
;Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];2`];Bd];2d];Bd/;Bd];Bd/;Bd];B`]
;Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd]
;Bd];Bd/;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd/
;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd];B`];Bd]
;2d];Bd];2d];Bd/;Bd];Bd];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd]
;B`];Bd];B`];Bd];2d];Bd/;2d];Bd/;Bd];B`/;Bh];B`];Bd];2`];Rd];2d]
;Bd/;Bd^;Bd/;Bd];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`]
;Bh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`];Bh];2`];Rh];2d];Rd/;2d^;Bd/
;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh]
;2`^;Rd/;2d^;R`/;Bh^;B`/;Bh^;2`];Rh];2`];Rd/;2d^;Rd/;2h^;B`/;Bh^
;B`/;Rh];2`];Rh/:b`^;Rd/;2d_;R`[;2h_;B//;Bl^;2/];bl]:b`^;bh/:bd_
;b`[;2h_;R/[;Bl_;2X/;c0]:bX]<2l/:R`_<2dZ:Rh`;b/Y;30a;BTZ;S8_:RP/
<C8/9bT`<blX9R`d<b/T:38g<2@R;CXh9aXS?4Pb308gVnoh[dT71R]6@2LJ8cHl
<B<R;CLd:R@Y<S@^9bL^<c4Z9b/a<RdX:Bhb;bXY;30a;BTZ;S4_:bX/<30/:R/^
<2h[:Rd_;b`Z;2h_;R/[;Bl_;2//;Rl]:b/];bh/:b`^;bd[;2d_;R`[;Bh^;B//
;Rl^;2/];Rh]:b`^;Rd/;2d^;R`/;2h^;B`/;Bh^;2`/;Rh];2`];Rh/;2d^;Rd/
;2d^;R`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2h^;B`/;Bh^;B`];Rh]
;2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2d];Rd/;2d^;Bd/;Bd^
;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;B`/;Bh];B`];Bh];2`];Rd];2d]
;Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bd];2`];Rd];2d];Bd/;Bd^;Bd/;Bd];B`]
;Bd];B`];Bd];2d];Bd/;2d];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/
;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd]
;Bd];Bd];2d];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd];Bd]
;B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d]
;Bd/;Bd];Bd/;Bd];B`];Bd];2`];Bd];2d];Bd/;2d^;Bd/;Bd];B`];Bh];B`]
;Bd];2d];Rd];2d];Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/
;Bd^;B`/;Bh];2`];Rh];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd]
;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2h^;B`/;Bh^
;B`];Rh];2`];Rh/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`^;Rd/;2d^
;R`/;2h^;B`/;Bh^;2//;Rh];2`];bh/:bd^;Rd[;2h_;R`[;Bh^;B//;Rl^;2/]
;bl/:b`^;bd[:bd_;b`Z;2l_;B/[;C0_;2X/;c0]:R/^<2l[:R``<2dY:Rha;bXY
;34a;2PZ;c8_:BP]<c8[9RTa=BlV9Bhg=2PQ:3Hk;adL<THo6`0JLMCoe74J01/o
AS8L7Blk=RPQ:3@g;RDV;cDa:BH[<S<]:2T_<RlZ:2`a<B`Y:Rla;RXY;C0`;2X[
;c0^:bX]<2l/:R`_<2d[:bd_;b`Z;2l_;B/[;Bl^;2//;bl]:b`^;bh/:bd^;Rd[
;2h_;R`[;Bh^;B//;Rl];2`];Rh/:b`^;Rd/;2d^;R`/;2h^;B`/;Bh^;2`];Rh]
;2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Rh];2`];Rh];2d^;Rd/;2d^;R`/;Bh^
;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`];Bh];2`];Rd];2d]
;Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Rh];2`];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`]
;Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd];B`];Bh];B`];Bd];2d];Rd];2d];Bd/
;Bd^;B`/;Bd];B`];Bd];2`];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd]
;2d];Bd];2d];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd]
;B`];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd];Bd];Bd];2d];Bd];Bd]
;Bd/;Bd];Bd];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`]
;Bd];2d];Bd];2d];Bd/;Bd];B`/;Bd];B`];Bd];2d];Bd];2d];Bd/;Bd^;Bd/
;Bd];B`];Bh];2`];Bd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd]
;2d];Rd/;2d^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh]
;B`];Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2d^;Rd/;2d^
;R`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;2h^;B`/;Bh^;B`/;Rh];2`]
;Rh/;2`^;Rd/;2d^;R`/;2h^;B`/;Bh^;2/];Rh]:b`^;bh/:bd^;Rd[;2h_;B`[
;Bl^;2//;Rl]:b/];bh/:b`_;bd[:bh_;R`Z;2l_;BX[;S0^:bX/<30/:R/_<BhZ
:Bda<2`Y:Rlb;RTX;C8a:bLZ<C<^9bL^=38Y92Xd=bdR8c4l=R<J9d16:`H7BJoh
ki/g0P`bB3`S6RLh>RdR930g<RPT:c<d;2HX;c<`:BL/<S4/:2X_<RhZ:Bda<2`Y
:bl`;RXZ;C0_;2X/;c0]:R/]<2l/:R`_;bd[:bh_;R`[;2l_;B//;Rl^;2/];bl]
:b`^;bd/:bd_;R`[;2h_;B`/;Bh^;2//;Rh];2`];Rh/;2d^;Rd/;2d^;R`/;Bh^
;B`/;Bh];2`];Rh];2`^;Rd/;2d^;Rd/;2h^;B`/;Bh^;2`];Rh];2`];Rd/;2d^
;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/;Bh];B`]
;Rh];2`];Rd];2d^;Rd/;2d^;B`/;Bh^;B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/
;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Bd/;Bd^;Bd/;Bd];B`];Bh];2`];Bd]
;2d];Rd/;2d];Bd/;Bd];B`/;Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd]
;B`];Bd];B`];Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d]
;Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd]
;Bd];2d];Bd];Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/
;Bd];B`];Bd];2`];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Rd]
;2d];Bd/;Bd^;B`/;Bd];B`];Bh];2`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh]
;B`];Rd];2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bh];2`];Rd];2d];Rd/;2d^
;B`/;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/;Bh^;B`];Rh];2`]
;Rd/;2d^;Rd/;2d^;B`/;Bh^;B`/;Bh];2`];Rh];2`^;Rd/;2d^;Rd/;2h^;B`/
;Bh^;2`/;Rh];2`];Rh/;2d^;Rd/;2d^;R`/;Bh^;B//;Rl];2/];Rh/:b`^;bd/
:bd_;R`[;2h_;B/[;Bl^;2//;bl]:b/^;bh/:b`_;bdZ:bh`;R/Z;Bl_;2X[;c0^
:RX]<30/:B/_<BhY:Bda<2/X:c0b;BPX;S<a:BH[<c@]9BH`=c8V8BXi>R/K7cM8
>A<09hKSo/=L3`8S@d@/6b0b?3@U8B/f=B`T9c4e<2PV;3<b:bLZ<38^:BT]<C0[
:B/`<BhZ:Rd`;b/Z;2l`;BX[;S0_:bX/;bl]:R/^;bh[:bd_;bd[;2h_;R/[;Bl_
;2//;Rl]:b/];bh/:b`^;bd[;2d_;R`[;2h^;B`/;Bh^;2/];Rh];2`];Rh/;2d^
;Rd/;2h^;B`/;Bh^;B`/;Rh];2`];Rh/;2`^;Rd/;2d^;R`/;Bh^;B`/;Bh];2`]
;Rh];2`];Rd/;2d^;Rd/;2d^;B`/;Bh^;B`];Bh];2`];Rd];2d^;Rd/;2d^;Bd/
;Bh^;B`/;Bh];2`];Rh];2`];Rd/;2d^;Rd/;Bd^;B`/;Bh];B`];Bh];2`];Rd]
;2d];Rd/;2d^;Bd/;Bd^;B`/;Bh];B`];Bd];2d];Rd/;2d];Bd/;Bd^;B`/;Bd]
;B`];Bh];2`];Rd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`];Bd];2d];Bd];2d]
;Bd/;Bd];Bd/;Bd];B`];Bd];2d];Bd];2d];Bd/;Bd];Bd/;Bd];B`];Bd];B`]
;Bd];2d];Bd];Bd];Bd/;Bd];Bd];Bd];B`];Bd];Bd];Bd];2d];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd];Bd]
;Bd];Bd];Bd];@\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
It is necessary to keep several hundred terms in the series, \
because our ears can pick up frequencies of up to several thousand hertz. \
Since the fundamental frequency is 5 Hz, keeping 300 terms in the series \
keeps frequencies up to 1500 Hz. It would be even better to keep more terms; \
the sound of the \"pops\" then becomes higher pitched. However, keeping more \
terms makes the evaluation of the series rather slow.\
\>", "Text"],

Cell[TextData[{
  "\tThe periodic \[Delta]-function is useful in understanding the connection \
between Fourier transforms and Fourier series. Consider an arbitrary periodic \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " with period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ". This function has a Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ", given by"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega]) = \[Integral]\_\(-\[Infinity]\)\%\
\[Infinity]\( f(
              t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t\)]],
  ".\nUsing the periodic nature of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", we can break the Fourier integral into a sum over separate periods:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\&~\)(\[Omega]) = \[Sum]\+\(n = \
\(-\[Infinity]\)\)\%\[Infinity]\[Integral]\_\(t\_o - n\ T\)\%\(t\_o - n\ T\  \
+ \ T\)\(f(
                t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\[DifferentialD]t\)\(,\)\)\)]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " is an arbitrary time. Now we may change variables in the integral to ",
  Cell[BoxData[
      \(TraditionalForm\`t\_1 = t + n\ T\)]],
  ", and use Eq. ",
  ButtonBox["(2.1.1)",
    ButtonData:>"(2.1.1)",
    ButtonStyle->"Hyperlink"],
  " to obtain "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(f\&~\)(\[Omega]) = \[Sum]\+\(n = \
\(-\[Infinity]\)\)\%\[Infinity]\( \[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \
n\ T\)\) \(\[Integral]\_\(t\_o\)\%\(t\_o\  + \ T\)\(f(
                t\_1)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \
t\_1\)\) \(\(\[DifferentialD]t\_1\)\(.\)\)\)\)]]], "NE3",
  CellTags->"(2.3.50)"],

Cell[TextData[{
  "However, Eq. ",
  ButtonBox["(2.3.49)",
    ButtonData:>"(2.3.49)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity] \
\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ n\ T\) = \(\[Delta]\^\((P)\)\)(\
\[Omega]\ T\^2/2\ \[Pi])\)]],
  ". Then Eq. ",
  ButtonBox["(2.3.50)",
    ButtonData:>"(2.3.50)",
    ButtonStyle->"Hyperlink"],
  " becomes "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(f\&~\)(\[Omega]) = \(\[Sum]\+\(m = \
\(-\[Infinity]\)\)\%\[Infinity]\( \[Delta](\(\[Omega]\ \ T\^2\)\/\(2\ \[Pi]\) \
- m\ T)\) \(\[Integral]\_\(t\_o\)\%\(t\_o\  + \ T\)\(f(
                  t\_1)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \
t\_1\)\) \[DifferentialD]t\_1\) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\
\[Infinity] 
            2\ \[Pi]\ \(\[Delta](\[Omega] - \(2\ \[Pi]\ m\)\/\(\(\ \)\(T\)\))\
\) \(1\/T\) \(\[Integral]\_\(t\_o\)\%\(t\_o\  + \ T\)\(f(
                  t\_1)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ \
t\_1\)\) \[DifferentialD]t\_1\)\)\)\(,\)\)\)]]], "NE3",
  CellTags->"(2.3.51)"],

Cell[TextData[{
  "where we have used Eqs. ",
  ButtonBox["(2.3.48)",
    ButtonData:>"(2.3.48)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.33)",
    ButtonData:>"(2.3.33)",
    ButtonStyle->"Hyperlink"],
  ". Furthermore, note that the integral in Eq. ",
  ButtonBox["(2.3.51)",
    ButtonData:>"(2.3.51)",
    ButtonStyle->"Hyperlink"],
  " is the expression for the ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "th Fourier coefficient, ",
  Cell[BoxData[
      \(TraditionalForm\`c\_m\)]],
  ", Eq. ",
  ButtonBox["(2.1.33)",
    ButtonData:>"(2.1.33)",
    ButtonStyle->"Hyperlink"],
  ". Therefore, we can write"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(f\&~\)(\[Omega]) = \[Sum]\+\(m = \
\(-\[Infinity]\)\)\%\[Infinity] 
          2\ \[Pi]\ \(\[Delta](\[Omega] - \(2\ \[Pi]\ m\)\/\(\(\ \)\(T\)\))\) \
\(\(c\_m\)\(.\)\)\)]]], "NE3",
  CellTags->"(2.3.52)"],

Cell[TextData[{
  "This equation connects the Fourier integral of a periodic function  ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " to the function's exponential Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`c\_m\)]],
  ". We see that in frequency space a periodic function consists of a sum of \
\[Delta] functions at all harmonics of the fundamental frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] = 2\ \[Pi]/T\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t Finally, applying the inverse transform to Eq. ",
  ButtonBox["(2.3.52)",
    ButtonData:>"(2.3.52)",
    ButtonStyle->"Hyperlink"],
  ", the integral over each \[Delta]-function in the sum can be evaluated, \
and we return to our previous expression for ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " as a Fourier series:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity]\( 
                c\_m\) \[ExponentialE]\^\(\(-\ \[ImaginaryI]\)\ m\ \
\[CapitalDelta]\[Omega]\ t\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3.5 Fast Fourier Transforms", "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{

Cell["Discrete Fourier Transforms", "Section",
  CellTags->{"i:53", "c:36"}],

Cell[TextData[{
  "\tIn this section we consider methods for performing numerical Fourier \
transforms. The idea is that one is given a set of data ",
  Cell[BoxData[
      \(TraditionalForm\`{\ f\_n}\)]],
  " measured at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "evenly spaced discrete times ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", " ", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2,  ... , N - 1\)]],
  ". From this data, one wishes to determine a numerical frequency spectrum."
}], "Text"],

Cell["\<\
\tThis sort of problem arises in experimental physics as well as in \
numerical simulation methods, and in many other fields of science, including  \
economics, engineering, signal processing, and acoustics. \
\>", "Text"],

Cell[TextData[{
  "\tOne way to attack this problem is simply to discretize the integrals in \
the Fourier transform and the inverse transform.  If we consider a \
discretized version of a Fourier transform, Eq. ",
  ButtonBox["(2.3.12)",
    ButtonData:>"(2.3.12)",
    ButtonStyle->"Hyperlink"],
  ", with the time variable replaced by closely spaced discrete timesteps ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n = n\ \[CapitalDelta]t\)]],
  ", and the frequency replaced by closely spaced discrete frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_m = \ m\ \[CapitalDelta]\[Omega]\)]],
  ", one can immediately see that the operation of Fourier transformation,  \
",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\ f\)]],
  ", is equivalent to the dot product of a vector with a matrix:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(f\&~\)(\[Omega])\), "=", 
        RowBox[{
          RowBox[{\(F\&^\ \(f(t)\)\), "\[Rule]", 
            SubscriptBox[\(f\&~\), 
              StyleBox["m",
                FontWeight->"Plain"]]}], "=", 
          RowBox[{\(\[Sum]\+\(n = \(-\[Infinity]\)\)\%\[Infinity]\), 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox["F",
                    FontWeight->"Plain",
                    FontSlant->"Italic"], 
                  StyleBox[\(m\ n\),
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], 
              StyleBox[
                SubscriptBox["f", 
                  StyleBox["n",
                    FontWeight->"Plain"]],
                FontWeight->"Plain"]}]}]}]}], TraditionalForm]]]], "NE3",
  CellTags->"(2.3.53)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["f",
                FontWeight->"Plain"], 
              StyleBox["n",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], " ", "=", \(f(n\ \[CapitalDelta]t)\)}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox[\(f\&~\),
                FontWeight->"Plain"], 
              StyleBox["m",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], " ", 
          "=", \(\(f\&~\)(m\ \[CapitalDelta]\[Omega])\)}], 
        TraditionalForm]]],
  ", and the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["F",
              FontWeight->"Plain",
              FontSlant->"Italic"], 
            StyleBox[\(m\ n\),
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " has components "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["F",
                FontWeight->"Plain",
                FontSlant->"Italic"], 
              StyleBox[\(m\ n\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], 
            StyleBox[" ",
              FontSlant->"Italic"], 
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{"\[ImaginaryI]", " ", "m", "  ", "n", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], 
                StyleBox[" ",
                  FontSlant->"Italic"], "\[CapitalDelta]\[Omega]"}]]}]}], 
        TraditionalForm]]],
  " ."
}], "NE3",
  CellTags->"(2.3.54)"],

Cell[TextData[{
  "This matrix  is a discretized form of the Fourier transform operator ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\)]],
  ". Equation ",
  ButtonBox["(2.3.54)",
    ButtonData:>"(2.3.54)",
    ButtonStyle->"Hyperlink"],
  " shows directly that there is an analogy between the linear integral \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\)]],
  " acting on functions and a matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["F",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " acting on vectors.  Previously, we saw that there was a similar analogy \
between linear ",
  StyleBox["differential",
    FontSlant->"Italic"],
  " operators and matrices. "
}], "Text"],

Cell[TextData[{
  "\t When the inverse transform operator ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\^\(-1\)\)]],
  "is discretized, it  also becomes a matrix, with components"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox["F",
                    FontSlant->"Plain"], 
                  StyleBox[\(-1\),
                    FontWeight->"Plain"]], ")"}], 
              StyleBox[\(m\ n\),
                FontWeight->"Plain"]],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Bold"], 
          RowBox[{
            StyleBox["\[CapitalDelta]\[Omega]",
              FontWeight->"Plain"], 
            StyleBox[
              RowBox[{
                StyleBox[" ",
                  FontWeight->"Plain"], " "}]], 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{\(-\[ImaginaryI]\), " ", "m", "  ", "n", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], " ", 
                  "\[CapitalDelta]\[Omega]"}]], "/", "2"}], "\[Pi]"}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.55)"],

Cell[TextData[{
  "This matrix can be applied to discretized functions of frequency ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox["f", 
            StyleBox["~",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " in order to reconstruct the corresponding discretized function of time, \
according to the matrix equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[\(-1\),
                FontWeight->"Plain"]], "\[CenterDot]", 
            OverscriptBox[
              StyleBox["f",
                FontWeight->"Bold"], "~"]}], "=", 
          StyleBox["f",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.56)"],

Cell[TextData[{
  "So, in order to take a numerical Fourier transform of a data set ",
  Cell[BoxData[
      \(TraditionalForm\`{\ f\_n}\)]],
  ",  it appears that all we need do is apply the matrix ",
  StyleBox["F",
    FontWeight->"Bold"],
  " to  the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold"], TraditionalForm]]],
  " with components ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  ", according to Eq. ",
  ButtonBox["(2.3.53)",
    ButtonData:>"(2.3.53)",
    ButtonStyle->"Hyperlink"],
  ". To turn the resulting discretized spectral function ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["f",
            FontWeight->"Bold"], "~"], TraditionalForm]]],
  " back into the time data, all we need do is apply the matrix  ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[\(-1\),
            FontWeight->"Plain"]], TraditionalForm]]],
  ", defined by Eq. ",
  ButtonBox["(2.3.55)",
    ButtonData:>"(2.3.55)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThis is fine so far as it goes, but there are several problems hiding in \
this procedure. First, the matrices ",
  Cell[BoxData[
      FormBox[
        StyleBox["F",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["F",
              FontWeight->"Bold"], 
            StyleBox[\(-1\),
              FontWeight->"Plain"]],
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " are formally infinite-dimensional.  We can try to get around this problem \
by cutting off the Fourier integrals.  Since the data runs from ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "\[LessEqual]", " ", "t", "\[LessEqual]", " ", 
          RowBox[{\((N - 1)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ",   we can cut off the time integral in the Fourier transform beyond this \
range of times. For the frequency integral in the inverse transform, we can \
also impose a frequency cutoff, keeping only frequencies in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-M\)\ \[CapitalDelta]\[Omega] \[LessEqual] \ \
\[Omega] \[LessEqual] \ M\ \[CapitalDelta]\[Omega]\)]],
  " for some large integer value of ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  ". The hope is that the frequency spectrum goes to zero for sufficiently \
large \[Omega], so that this cutoff does not neglect anything important. "
}], "Text"],

Cell[TextData[{
  "\tThere is a second problem: although \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " is determined by the dataset, what should our choice for \[CapitalDelta]\
\[Omega] be? Apparently we can choose anything we want,  so long as ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  " is \"small\". This is technically correct - if \[CapitalDelta]\[Omega] is \
small  compared to the scale of variation of the frequency spectrum, then the \
discretized integral in the Fourier transform is well represented by the \
Riemann sum  given by Eq. ",
  ButtonBox["(2.3.56)",
    ButtonData:>"(2.3.56)",
    ButtonStyle->"Hyperlink"],
  ".  However, we also must keep enough terms so that ",
  Cell[BoxData[
      \(TraditionalForm\`M\ \[CapitalDelta]\[Omega]\)]],
  " is a large frequency - large enough to encompass the bulk of the \
frequency spectrum. "
}], "Text"],

Cell[TextData[{
  "\t   For very smooth time data with only low-frequency spectral \
components,  this prescription works (see the exercises). However, for real \
data, which may have high-frequency spectral components and rapid variation \
in the spectrum, the above method becomes impractical, because we must take \
",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " very large. Also, the matrices ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[\(-1\),
            FontWeight->"Plain"]], TraditionalForm]]],
  " and ",
  StyleBox["F ",
    FontWeight->"Bold"],
  " are only approximately the inverses of one another, because of the errors \
introduced by discretizing the Fourier and inverse Fourier integrals."
}], "Text"],

Cell[TextData[{
  " \tOne way to improve matters is to recognize that the time data, \
extending only over a finite time range",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"0", "\[LessEqual]", " ", "t", "\[LessEqual]", " ", 
            RowBox[{\((N\  - 1)\), " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", can be replaced by a periodic extension with period ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{"N", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ". We take this time as the period (rather than, say",
  ",",
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((N - 1)\), " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ") so that the first data point beyond this interval, at time ",
  Cell[BoxData[
      \(TraditionalForm\`N\ \[CapitalDelta]t\)]],
  ",  has value ",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  ". This way, the data can be seen to repeat with period ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "=", 
          RowBox[{"N", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " (see Fig. ",
  ButtonBox["2.9",
    ButtonData:>"Fig. 2.9",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.057971 0.0724638 0.0147151 0.588604 [
[.2029 .00222 -3 -9 ]
[.2029 .00222 3 0 ]
[.34783 .00222 -3 -9 ]
[.34783 .00222 3 0 ]
[.49275 .00222 -3 -9 ]
[.49275 .00222 3 0 ]
[.63768 .00222 -3 -9 ]
[.63768 .00222 3 0 ]
[.78261 .00222 -6 -9 ]
[.78261 .00222 6 0 ]
[.92754 .00222 -6 -9 ]
[.92754 .00222 6 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.04547 .13244 -18 -4.5 ]
[.04547 .13244 0 4.5 ]
[.04547 .25016 -18 -4.5 ]
[.04547 .25016 0 4.5 ]
[.04547 .36788 -18 -4.5 ]
[.04547 .36788 0 4.5 ]
[.04547 .4856 -18 -4.5 ]
[.04547 .4856 0 4.5 ]
[.04547 .60332 -6 -4.5 ]
[.04547 .60332 0 4.5 ]
[.05797 .64303 -7.625 0 ]
[.05797 .64303 7.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2029 .01472 m
.2029 .02097 L
s
[(2)] .2029 .00222 0 1 Mshowa
.34783 .01472 m
.34783 .02097 L
s
[(4)] .34783 .00222 0 1 Mshowa
.49275 .01472 m
.49275 .02097 L
s
[(6)] .49275 .00222 0 1 Mshowa
.63768 .01472 m
.63768 .02097 L
s
[(8)] .63768 .00222 0 1 Mshowa
.78261 .01472 m
.78261 .02097 L
s
[(10)] .78261 .00222 0 1 Mshowa
.92754 .01472 m
.92754 .02097 L
s
[(12)] .92754 .00222 0 1 Mshowa
.125 Mabswid
.0942 .01472 m
.0942 .01847 L
s
.13043 .01472 m
.13043 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.23913 .01472 m
.23913 .01847 L
s
.27536 .01472 m
.27536 .01847 L
s
.31159 .01472 m
.31159 .01847 L
s
.38406 .01472 m
.38406 .01847 L
s
.42029 .01472 m
.42029 .01847 L
s
.45652 .01472 m
.45652 .01847 L
s
.52899 .01472 m
.52899 .01847 L
s
.56522 .01472 m
.56522 .01847 L
s
.60145 .01472 m
.60145 .01847 L
s
.67391 .01472 m
.67391 .01847 L
s
.71014 .01472 m
.71014 .01847 L
s
.74638 .01472 m
.74638 .01847 L
s
.81884 .01472 m
.81884 .01847 L
s
.85507 .01472 m
.85507 .01847 L
s
.8913 .01472 m
.8913 .01847 L
s
.02174 .01472 m
.02174 .01847 L
s
.96377 .01472 m
.96377 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05797 .13244 m
.06422 .13244 L
s
[(0.2)] .04547 .13244 1 0 Mshowa
.05797 .25016 m
.06422 .25016 L
s
[(0.4)] .04547 .25016 1 0 Mshowa
.05797 .36788 m
.06422 .36788 L
s
[(0.6)] .04547 .36788 1 0 Mshowa
.05797 .4856 m
.06422 .4856 L
s
[(0.8)] .04547 .4856 1 0 Mshowa
.05797 .60332 m
.06422 .60332 L
s
[(1)] .04547 .60332 1 0 Mshowa
.125 Mabswid
.05797 .04415 m
.06172 .04415 L
s
.05797 .07358 m
.06172 .07358 L
s
.05797 .10301 m
.06172 .10301 L
s
.05797 .16187 m
.06172 .16187 L
s
.05797 .1913 m
.06172 .1913 L
s
.05797 .22073 m
.06172 .22073 L
s
.05797 .27959 m
.06172 .27959 L
s
.05797 .30902 m
.06172 .30902 L
s
.05797 .33845 m
.06172 .33845 L
s
.05797 .39731 m
.06172 .39731 L
s
.05797 .42674 m
.06172 .42674 L
s
.05797 .45617 m
.06172 .45617 L
s
.05797 .51503 m
.06172 .51503 L
s
.05797 .54446 m
.06172 .54446 L
s
.05797 .57389 m
.06172 .57389 L
s
.25 Mabswid
.05797 0 m
.05797 .61803 L
s
gsave
.05797 .64303 -68.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.05797 .01472 Mdot
.13043 .07092 Mdot
.2029 .21807 Mdot
.27536 .39996 Mdot
.34783 .54711 Mdot
.42029 .60332 Mdot
.49275 .54711 Mdot
.56522 .39996 Mdot
.63768 .21807 Mdot
.71014 .07092 Mdot
.78261 .01472 Mdot
.85507 .07092 Mdot
.92754 .21807 Mdot
1 .39996 Mdot
gsave
.02174 .0412 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.10507 .09123 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.19928 .25016 -80.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(...) show
98.250 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.74638 .0412 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.82971 .09123 -68.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
74.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.92391 .25016 -80.625 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
80.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(...) show
98.250 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00Oogooogoo@Woo003o
OoooOom2Ool00?mooomood9oo`00ogooogoo@Woo0021Ool80013Ool5000oOol40013Ool4000lOol7
0006Ool4000fOol70004Ool8001?Ool0089oo`03001oogoo00=oo`03001oogoo04=oo`03001oogoo
03ioo`03001oogoo009oo`03001oogoo03moo`03001oogoo009oo`03001oogoo03aoo`03001oogoo
00Ioo`03001oogoo009oo`03001oogoo03Ioo`03001oogoo00Ioo`03001oogoo00=oo`03001oogoo
04eoo`00Pgoo00<007ooOol0B7oo00<007ooOol0?Goo00<007ooOol017oo00<007ooOol0?Goo00<0
07ooOol017oo00<007ooOol0>goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0=Woo00<0
07ooOol01goo00<007ooOol0DWoo0024Ool00`00Oomoo`11Ool9000mOol00`00Oomoo`04Ool00`00
Oomoo`0mOol00`00Oomoo`04Ool00`00Oomoo`0kOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00
Oomoo`0eOol00`00Oomoo`08Ool00`00Oomoo`1AOol008Eoo`03001oogoo045oo`03001oogoo009o
o`03001oogoo03eoo`03001oogoo00Aoo`03001oogoo03eoo`03001oogoo00Aoo`03001oogoo03]o
o`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo03Eoo`03001oogoo00Uoo`03001oogoo051o
o`00QWoo00<007ooOol0@7oo00<007ooOol00Woo00<007ooOol0?Goo00<007ooOol017oo00<007oo
Ool0?Woo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol01Goo00<007ooOol017oo00<007oo
Ool0=Goo00<007ooOol02Woo00<007ooOol0Cgoo0027Ool00`00Oomoo`10Ool01@00Oomoogoo0000
?goo0P0017oo00<007ooOol0?goo1P00?Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
=Goo00<007ooOol02goo00<007ooOol0CWoo0028Ool00`00Oomoo`10Ool01000Oomoo`00?goo00<0
07oo00000`00@Woo00<007ooOol00Woo00<007ooOol0?7oo00<007ooOol01Goo00<007ooOol017oo
00<007ooOol0=Goo00<007ooOol037oo00<007ooOol0CGoo0028Ool00`00Oomoo`10Ool01000Oomo
o`00@7oo00<007ooOol0@goo00<007ooOol017oo00<007ooOol0>goo00<007ooOol01Goo00<007oo
Ool017oo00<007ooOol0=Goo00<007ooOol037oo00<007ooOol0CGoo0022Ool00`00Oomoo`03Ool0
0`00Oomoo`11Ool00`00Ool00010Ool00`00Oomoo`13Ool00`00Oomoo`04Ool00`00Oomoo`0kOol0
0`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`0fOol00`00Oomoo`06Ool00`00Oomoo`03Ool0
0`00Oomoo`1=Ool0089oo`8000=oo`03001oogoo04=oo`80045oo`8004Aoo`03001oogoo009oo`03
001oogoo03Uoo`@000Qoo`03001oogoo009oo`03001oogoo03=oo`@000Qoo`8000=oo`03001oogoo
04ioo`00Q7oo0`00AWoo0P00@goo1000@Goo1000?Woo0P002Goo1000>7oo0P002Woo0`00DGoo003o
OoooOom2Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol0
0`00Oomoo`3oOooKOol30004Ool3000KOol003aoo`D00?mooeeoo`D007Yoo`03001oogoo00Aoo`03
001oogoo01Yoo`00>goo1`00ogooFgoo1`00NGoo00<007ooOol017oo00<007ooOol06Woo000jOol9
003oOomIOol9001hOol00`00Oomoo`04Ool00`00Oomoo`0JOol003Yoo`T00?mooeUoo`T007Qoo`03
001oogoo00Aoo`03001oogoo01Yoo`008Wooo`00jP004Goo00<007ooOol017oo00<007ooOol06Woo
000/Ool00`00Oomoo`0;Ool9000=Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool0
0`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool0
0`00Oomoo`0>Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0>Ool00`00Oomoo`0?Ool0
0`00Oomoo`0:Ool9000=Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomoo`0?Ool00`00Oomo
o`0>Ool00`00Oomoo`0QOol00`00Oomoo`04Ool00`00Oomoo`0JOol002aoo`03001oogoo00]oo`T0
00eoo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00moo`03001oogoo00ioo`03001oogoo
00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00ioo`03001oogoo00moo`03001oogoo
00moo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00moo`03001oogoo00ioo`03001oogoo
00moo`03001oogoo00moo`03001oogoo00ioo`03001oogoo00moo`03001oogoo00Yoo`T000eoo`03
001oogoo00moo`03001oogoo00moo`03001oogoo00moo`03001oogoo00ioo`03001oogoo025oo`80
00Aoo`8001aoo`00>goo1`00@goo00<007ooOol0A7oo00<007ooOol0@goo00<007ooOol0A7oo00<0
07ooOol0@7oo1`00A7oo00<007ooOol0<Goo0P0000=oo`0000000`007Goo000lOol5003oOomMOol5
002NOol002moo`<000aoo`03001oogoo0?mooe5oo`<00:aoo`00;Woo00D007ooOomoo`0000]oo`03
001oogoo0?mooe1oo`05001oogooOol0002[Ool002ioo`05001oogooOol0000;Ool00`00Oomoo`3o
Oom@Ool01@00Oomoogoo0000Zgoo000SOol70004Ool01@00Oomoogoo00002goo00<007ooOol0ogoo
AGoo1`0017oo00D007ooOomoo`000:]oo`009Goo00<007ooOol01Woo00D007ooOomoo`0000]oo`03
001oogoo0?moodMoo`03001oogoo00Ioo`05001oogooOol0002[Ool002Eoo`03001oogoo00Ioo`05
001oogooOol0000;Ool00`00Oomoo`3oOom7Ool00`00Oomoo`06Ool01@00Oomoogoo0000Zgoo000U
Ool00`00Oomoo`06Ool01@00Oomoogoo00002goo00<007ooOol0ogooAgoo00<007ooOol01Woo00D0
07ooOomoo`000:]oo`009Goo00<007ooOol01Woo00D007ooOomoo`0000]oo`03001oogoo0?moodMo
o`03001oogoo00Ioo`05001oogooOol0002[Ool002Eoo`03001oogoo00Moo`<000aoo`03001oogoo
0?moodMoo`03001oogoo00Moo`<00:aoo`009Goo00<007ooOol05Woo0`00ogooAgoo00<007ooOol0
]Woo000UOol00`00Oomoo`0FOol00`00Oomoo`3oOom7Ool00`00Oomoo`2fOol002=oo`L001Aoo`03
001oogoo0?moodEoo`L00;Aoo`009Goo00<007ooOol05Woo00<007ooOol0ogooAgoo00<007ooOol0
]Woo000UOol00`00Oomoo`0FOol00`00Oomoo`3oOom7Ool00`00Oomoo`2fOol002Eoo`8001Moo`03
001oogoo0?moodMoo`800;Moo`009Woo1@004goo00<007ooOol0ogooB7oo1@00/goo000nOol00`00
Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo
000nOol00`00Oomoo`0NOol5003oOolGOol50012Ool5001jOol003ioo`03001oogoo01eoo`L00?mo
oaEoo`L0041oo`L007Uoo`00?Woo00<007ooOol077oo2@00ogoo4goo2@00?Woo2@00N7oo000nOol0
0`00Oomoo`0LOol9003oOolCOol9000nOol9001hOol003ioo`<001aoo`T00?mooa=oo`T003ioo`T0
07Qoo`00?Woo00<007ooOol05Woo1@0000=oo`0000001`00ogoo4goo2@00>7oo1@0000=oo`000000
1`00N7oo000nOol00`00Oomoo`0HOol01000Oomoogoo2@00ogoo4goo2@00>Woo00@007ooOomoo`T0
07Qoo`00?Woo00<007ooOol067oo00<007ooOol00Woo1`00ogoo5Goo1`00>goo00<007ooOol00Woo
1`00NGoo000nOol00`00Oomoo`0;Ool70006Ool00`00Oomoo`03Ool5003oOolGOol5000_Ool70006
Ool00`00Oomoo`03Ool5001jOol003ioo`03001oogoo00eoo`03001oogoo00Qoo`03001oogoo0?mo
oeEoo`03001oogoo00Qoo`03001oogoo089oo`00?Woo00<007ooOol03Goo00<007ooOol027oo00<0
07ooOol0ogooEGoo00<007ooOol027oo00<007ooOol0PWoo000nOol00`00Oomoo`0=Ool00`00Oomo
o`06Ool00`00Ool0003oOomGOol00`00Oomoo`06Ool00`00Ool00024Ool003ioo`03001oogoo00eo
o`03001oogoo00Moo`800?mooeMoo`03001oogoo00Moo`8008Aoo`00?Woo00<007ooOol03Goo00<0
07ooOol027oo00<007ooOol0ogooEGoo00<007ooOol027oo00<007ooOol0PWoo000nOol00`00Oomo
o`0=Ool00`00Oomoo`3oOomPOol00`00Oomoo`2=Ool003ioo`03001oogoo00eoo`03001oogoo0?mo
of1oo`03001oogoo08eoo`00?Woo00<007ooOol02goo1`00ogooG7oo1`00Rgoo000nOol00`00Oomo
o`0=Ool00`00Oomoo`3oOomPOol00`00Oomoo`2=Ool003ioo`03001oogoo00eoo`03001oogoo0?mo
of1oo`03001oogoo08eoo`00?Woo0`003Goo0P00ogooHGoo0P00SWoo000nOol00`00Oomoo`0>Ool5
003oOomNOol5002:Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo
000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0
ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo
00<007ooOol0ogooogoo0Goo000HOol40008Ool30007Ool80008Ool00`00Oomoo`3oOoooOol1Ool0
01Moo`03001oogoo009oo`03001oogoo00Eoo`<000Qoo`03001oogoo00=oo`03001oogoo00Ioo`03
001oogoo0?mooomoo`5oo`005goo00<007ooOol00Woo00<007ooOol01Goo0`002Goo00<007ooOol0
2goo00<007ooOol0ogooogoo0Goo000FOol00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`0:
Ool00`00Oomoo`3oOoooOol1Ool001Ioo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Uo
o`@00?mooomoo`005Woo00<007ooOol017oo00<007ooOol04goo00<007ooOol027oo00<007ooOol0
ogooogoo0Goo000FOol00`00Oomoo`04Ool00`00Oomoo`0DOol00`00Oomoo`07Ool00`00Oomoo`3o
OoooOol1Ool001Ioo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Ioo`03001oogoo0?mo
oomoo`5oo`005Woo00<007ooOol017oo00<007ooOol05Goo00<007ooOol01Woo00<007ooOol0ogoo
ogoo0Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`06Ool0
0`00Oomoo`3oOoooOol1Ool001Moo`03001oogoo009oo`03001oogoo011oo`8000=oo`03001oogoo
00Moo`03001oogoo0?mooomoo`5oo`0067oo10005Goo0`002Woo00<007ooOol0ogooogoo0Goo000n
Ool00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogoo
ogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<0
07ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`<00?mooomoo`5oo`00?Woo
00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomo
o`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001o
ogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool0
03ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3o
OoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol3
003oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000n
Ool00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogoo
ogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<0
07ooOol0ogooogoo0Goo000nOol00`00Oomoo`11Ool5003@Ool50028Ool5001GOol003ioo`03001o
ogoo041oo`L00<ioo`L008Ioo`L005Ioo`00?Woo00<007ooOol0?goo2@00c7oo2@00Q7oo2@00EGoo
000nOol00`00Oomoo`0oOol9003<Ool90024Ool9001EOol003ioo`03001oogoo03moo`T00<aoo`T0
08Aoo`T005Eoo`00?Woo0`00?goo2@00c7oo2@00Q7oo2@00EGoo000nOol00`00Oomoo`0oOol9003<
Ool90024Ool9001EOol003ioo`03001oogoo041oo`L00<ioo`L008Ioo`L005Ioo`00?Woo00<007oo
Ool0@Goo1@00d7oo1@00R7oo1@00Egoo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo
0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`0/Ool6003oOomMOol6
001[Ool003ioo`03001oogoo02aoo`03001oogoo009oo`03001oogoo0?mooe]oo`03001oogoo009o
o`03001oogoo06Uoo`00?Woo00<007ooOol0;Goo00<007ooOol0ogooH7oo00<007ooOol0KGoo000n
Ool00`00Oomoo`0QOol70006Ool00`00Oomoo`0DOol30009Ool30009Ool3003oOolTOol70006Ool0
0`00Oomoo`0DOol30009Ool30009Ool3000mOol001Qoo`@000Qoo`<000]oo`D000Moo`03001oogoo
02=oo`03001oogoo00Uoo`03001oogoo01=oo`<000Uoo`<000Uoo`<00?moobIoo`03001oogoo00Uo
o`03001oogoo01=oo`<000Uoo`<000Uoo`<003eoo`005goo00<007ooOol00Woo00<007ooOol01Goo
0`003Goo00<007ooOol01goo00<007ooOol08goo00<007ooOol02Woo00<007ooOol04Woo0`002Goo
0`002Goo0`00ogoo9Woo00<007ooOol02Woo00<007ooOol04Woo0`002Goo0`002Goo0`00?Goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool3000=Ool00`00Oomoo`07Ool00`00Oomoo`0SOol00`00
Oomoo`0;Ool00`00Oomoo`3oOomBOol00`00Oomoo`0;Ool00`00Oomoo`1YOol001Ioo`03001oogoo
00Aoo`03001oogoo00ioo`T000Moo`03001oogoo02=oo`03001oogoo00Ioo`03001oogoo009oo`03
001oogoo0?mooe9oo`03001oogoo00Ioo`03001oogoo009oo`03001oogoo06Uoo`005Woo00<007oo
Ool017oo00<007ooOol03goo00<007ooOol00Woo00<007ooOol01goo10008Woo00<007ooOol01goo
1000ogooEGoo00<007ooOol01goo1000K7oo000FOol00`00Oomoo`04Ool00`00Oomoo`0?Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0SOol00`00Oomoo`3oOomPOol00`00Oomoo`1gOol0
01Ioo`03001oogoo00Aoo`03001oogoo011oo`05001oogooOol00009Ool00`00Oomoo`0SOol00`00
Oomoo`3oOomPOol00`00Oomoo`1gOol001Ioo`03001oogoo00Aoo`03001oogoo015oo`04001oogoo
0009Ool00`00Oomoo`0QOol7003oOomLOol7001eOol001Ioo`03001oogoo00Aoo`03001oogoo015o
o`04001oogoo0009Ool00`00Oomoo`0SOol00`00Oomoo`3oOomPOol00`00Oomoo`1gOol001Moo`03
001oogoo009oo`03001oogoo01=oo`03001oo`0000Uoo`03001oogoo02=oo`03001oogoo0?moof1o
o`03001oogoo07Moo`005goo00<007ooOol00Woo00<007ooOol057oo0P002Goo00<007ooOol08goo
0P00ogooHGoo0P00N7oo000HOol4000GOol20009Ool00`00Oomoo`0TOol5003oOomNOol5001dOol0
03ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3o
OoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol0
0`00Oomoo`3oOoooOol1Ool003ioo`<00?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000n
Ool00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogoo
ogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<0
07ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5o
o`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo
0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol3003oOoooOol1Ool003ioo`03001o
ogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool0
03ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3o
OoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol0
0`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo
0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007oo
Ool0ogooogoo0Goo000nOol3003oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<0
07ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5o
o`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo
0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool001Qo
o`@000Qoo`<000Uoo`@000Yoo`03001oogoo0?mooomoo`5oo`005goo00<007ooOol00Woo00<007oo
Ool01Goo0`0027oo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogooogoo0Goo000GOol0
0`00Oomoo`02Ool00`00Oomoo`05Ool30007Ool00`00Oomoo`04Ool00`00Oomoo`06Ool00`00Oomo
o`3oOoooOol1Ool001Ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo
00Ioo`03001oogoo0?mooomoo`5oo`005Woo00<007ooOol017oo00<007ooOol03Woo00<007ooOol0
17oo00<007ooOol01Woo1000ogooogoo000FOol00`00Oomoo`04Ool00`00Oomoo`0>Ool00`00Oomo
o`04Ool00`00Oomoo`06Ool00`00Oomoo`3oOoooOol1Ool001Ioo`03001oogoo00Aoo`03001oogoo
00ioo`8000Aoo`03001oogoo00Moo`03001oogoo0?mooomoo`5oo`005Woo00<007ooOol017oo00<0
07ooOol03Woo00<007oo00000`002Woo00<007ooOol0ogooogoo0Goo000FOol00`00Oomoo`04Ool0
0`00Oomoo`0?Ool00`00Oomoo`0<Ool00`00Oomoo`3oOoooOol1Ool001Moo`03001oogoo009oo`03
001oogoo011oo`03001oogoo00aoo`03001oogoo0?mooomoo`5oo`005goo00<007ooOol00Woo00<0
07ooOol04Goo0P0037oo00<007ooOol0ogooogoo0Goo000HOol4000FOol40008Ool00`00Oomoo`3o
OoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol0
0`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0IGoo1@00
R7oo1@00d7oo1@00<goo000nOol00`00Oomoo`1TOol70026Ool7003>Ool7000bOol003ioo`03001o
ogoo06=oo`T008Aoo`T00<aoo`T0035oo`00?Woo0`00Hgoo2@00Q7oo2@00c7oo2@00<Goo000nOol0
0`00Oomoo`1SOol90024Ool9003<Ool9000aOol003ioo`03001oogoo06=oo`T008Aoo`T00<aoo`T0
035oo`00?Woo00<007ooOol0Hgoo2@00Q7oo2@00c7oo2@00<Goo000nOol00`00Oomoo`1TOol70026
Ool7003>Ool7000bOol003ioo`03001oogoo06Eoo`D008Qoo`D00=1oo`D003=oo`00?Woo00<007oo
Ool0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00
?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mo
oomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`<0
0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003io
o`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOooo
Ool1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00
Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo
000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0
ogooogoo0Goo000nOol3003oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007oo
Ool0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00
?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mo
oomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03
001oogoo0?mooomoo`5oo`0067oo100027oo0`002Goo10002Woo00<007ooOol0ogooogoo0Goo000G
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool30008Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`3oOoooOol1Ool001Moo`03001oogoo009oo`03001oogoo00Eoo`<000Moo`03001oogoo00Ao
o`03001oogoo00Ioo`03001oogoo0?mooomoo`5oo`005Woo00<007ooOol017oo00<007ooOol03Woo
00<007ooOol017oo00<007ooOol01Woo00<007ooOol0ogooogoo0Goo000FOol00`00Oomoo`04Ool0
0`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`06Ool4003oOoooOol001Ioo`03001oogoo00Ao
o`03001oogoo00moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0?mooomoo`5oo`005Woo
00<007ooOol017oo00<007ooOol03goo1P002Goo00<007ooOol0ogooogoo0Goo000FOol00`00Oomo
o`04Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3oOoooOol1Ool0
01Ioo`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo
0?mooomoo`5oo`005goo00<007ooOol00Woo00<007ooOol03goo00<007ooOol017oo00<007ooOol0
1Woo00<007ooOol0ogooogoo0Goo000GOol00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`3oOoooOol1Ool001Qoo`@001Aoo`@000Yoo`03001oogoo0?mo
oomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03
001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1
Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo0`00ogooogoo0Goo000nOol00`00Oomoo`3oOooo
Ool1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00
Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo
000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0
ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo
00<007ooOol0R7oo1@00@Woo1@00ogoo;7oo000nOol00`00Oomoo`27Ool70010Ool7003oOol[Ool0
03ioo`<008Ioo`T003ioo`T00?moobYoo`00?Woo00<007ooOol0QWoo2@00?Woo2@00ogoo:Woo000n
Ool00`00Oomoo`26Ool9000nOol9003oOolZOol003ioo`03001oogoo08Ioo`T003ioo`T00?moobYo
o`00?Woo00<007ooOol0QWoo2@00?Woo2@00ogoo:Woo000nOol00`00Oomoo`27Ool70010Ool7003o
Ool[Ool003ioo`03001oogoo08Qoo`D0049oo`D00?moobaoo`00?Woo00<007ooOol0ogooogoo0Goo
000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0
ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mooomoo`5oo`00?Woo
00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`<00?mooomoo`5oo`00
?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03001oogoo0?mo
oomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1Ool003ioo`03
001oogoo0?mooomoo`5oo`00?Woo00<007ooOol0ogooogoo0Goo000nOol00`00Oomoo`3oOoooOol1
Ool003ioo`03001oogoo0?mooomoo`5oo`00;goo1`0027oo00<007ooOol0[7oo1@00ogooCgoo000b
Ool00`00Oomoo`09Ool00`00Oomoo`2[Ool7003oOom>Ool0039oo`03001oogoo00Uoo`03001oogoo
0:Yoo`T00?moodeoo`00<Woo00<007ooOol02Goo00<007ooOol0ZWoo2@00ogooCGoo000bOol00`00
Oomoo`09Ool4002YOol9003oOom=Ool0039oo`03001oogoo00Uoo`03001oogoo0:Yoo`T00?moodeo
o`00<Woo00<007ooOol02Goo00<007ooOol0ZWoo2@00ogooCGoo000bOol00`00Oomoo`09Ool00`00
Oomoo`2[Ool7003oOom>Ool0039oo`03001oogoo00Uoo`03001oogoo0:aoo`D00?moodmoo`00<Woo
00<007ooOol02Goo00<007ooOol0ogooogoo0Goo000_Ool4000;Ool00`00Oomoo`3oOoooOol1Ool0
035oo`8000]oo`03001oogoo0?mooomoo`5oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9o
o`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mo
oomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2
Ool00?mooomood9oo`00?goo0`000Woo0`00ogoonWoo0010Ool00`00Oomoo`02Ool00`00Oomoo`3o
OooiOol0041oo`03001oogoo009oo`03001oogoo0?moooUoo`00=Goo1`0017oo00<007ooOol00Woo
00<007ooOol0ogoonGoo000gOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`3oOooiOol0
03Moo`03001oogoo00Ioo`8000=oo`03001oogoo0?moooUoo`00=goo00<007ooOol01Goo0P0000Ao
o`0000000?moooaoo`00=goo00<007ooOol0ogooogoo27oo000gOol00`00Oomoo`3oOoooOol8Ool0
03Moo`03001oogoo0?mooomoo`Qoo`00=goo00<007ooOol0ogooogoo27oo000eOol7003oOoooOol6
Ool003Moo`03001oogoo0?mooomoo`Qoo`00=goo00<007ooOol0ogooogoo27oo000gOol2003oOooo
Ool9Ool003Qoo`D00?mooomoo`Eoo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogoo
ogoo@Woo003oOoooOom2Ool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-1, 0, 0, 0}}],

Cell["\<\
Fig. 2.9  A dataset with 10 elements, periodically replicated. \
\
\>", "Caption",
  CellTags->"Fig. 2.9"],

Cell[TextData[{
  "\t Since the periodic extension has period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", the data can be represented by a Fourier series rather than a transform, \
with a fundamental frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] = 2\ \[Pi]/T\)]],
  ". This is the smallest frequency that can be represented by this data, and \
so is a good choice for our frequency discretization. Hearkening back to our \
equation for Fourier series, Eq. ",
  ButtonBox["(2.2.2)",
    ButtonData:>"(2.2.2)",
    ButtonStyle->"Hyperlink"],
  ", we would like to write"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(
          t) = \[Sum]\+\(m = \(-\[Infinity]\)\)\%\[Infinity]\( f\&~\_m\) \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\)\)]],
  ","
}], "NE3",
  CellTags->"(2.3.57)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(t)\)]],
  " is a periodic function of time that represents the discrete data (we will \
see what this function of continuous time looks like in a moment), and the ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(f\&~\_m\), " ", 
            StyleBox["'",
              FontSlant->"Italic"]}], 
          StyleBox["s",
            FontSlant->"Plain"], " "}], TraditionalForm]]],
  "are the Fourier coefficients in the series. As in all Fourier series, the \
sum runs over all integers, and of course this is a problem in numerical \
applications. However, we will see momentarily that this problem can be \
solved in a natural way."
}], "Text"],

Cell[TextData[{
  " \tThe Fourier components ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m\)]],
  " are determined by the integral:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\&~\_m\), "=", 
          RowBox[{
            FractionBox["1", 
              RowBox[{"N", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}]], 
            RowBox[{
              SubsuperscriptBox["\[Integral]", "0", 
                RowBox[{"N", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}]], \(\(f(
                  t)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ m\ \[CapitalDelta]\
\[Omega]\ t\)\) \[DifferentialD]t\)}]}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(2.3.58)"],

Cell[TextData[{
  "[see Eq. ",
  ButtonBox["(2.2.3)]",
    ButtonData:>"(2.2.3)",
    ButtonStyle->"Hyperlink"],
  ". However, since the time data is discrete, we replace this integral by \
the Riemann sum, just as in Eq. ",
  ButtonBox["(2.3.53)",
    ButtonData:>"(2.3.53)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\&~\_m\), "=", 
          RowBox[{
            RowBox[{
              FractionBox["1", 
                RowBox[{"N", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}]], 
              RowBox[{\(\[Sum]\+\(n = 0\)\%\(N - 1\)\), 
                RowBox[{"\[CapitalDelta]t", " ", \(f\_n\), " ", 
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    "\[ImaginaryI]", " ", "m", " ", "\[CapitalDelta]\[Omega]",
                       " ", "n", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["t",
                            FontSlant->"Italic"]}]]}]]}]}]}], 
            "=", \(\(1\/\(\(N\)\(\ \)\)\) \(\[Sum]\+\(n = 0\)\%\(N - 1\)\ 
                f\_n\ \[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ m\ n\ \
/N\)\)\)}]}], TraditionalForm]]],
  ", "
}], "NE3",
  CellTags->"(2.3.59)"],

Cell[TextData[{
  "where in the second step we have used ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] = 2  \[Pi]/T\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t These Fourier components have an important property: they are \
themselves periodic",
  ",",
  " satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_\(m + N\) = f\&~\_m\)]],
  ". The proof is simple:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(f\&~\_\(m + N\)\), "=", 
        FormBox[
          
          RowBox[{\(\(1\/\(\(N\)\(\ \)\)\) \(\[Sum]\+\(n = 0\)\%\(N - 1\)f\_n\
\ \[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ \((m + N)\)\ n\ /N\)\)\), "=", 
            
            FormBox[\(\(1\/\(\(N\)\(\ \)\)\) \(\[Sum]\+\(n = 0\)\%\(N - 1\)\ 
                    f\_n\ \[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ m\ n\ \
/N + \[ImaginaryI]\ 2  \[Pi]\ n\)\) = \(\(f\&~\_m\)\(.\)\)\),
              "TraditionalForm"]}],
          "TraditionalForm"]}], TraditionalForm]]]], "NE3",
  CellTags->"(2.3.60)"],

Cell[TextData[{
  "Now, since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\&~\_m\)\(\ \)\)\)]],
  "repeats periodically, we can rewrite the infinite sum over these ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m\)]],
  "'s in Eq. ",
  ButtonBox["(2.3.57)",
    ButtonData:>"(2.3.57)",
    ButtonStyle->"Hyperlink"],
  " as sums over repeating intervals of size ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox["\t\t", "NE3"],
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(
          t) = \(\[Sum]\+\(p = \(-\[Infinity]\)\)\%\[Infinity]\(\[Sum]\+\(m = \
N\ p\)\%\(N - 1 + N\ p\)\ \(f\&~\_m\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
m\ \[CapitalDelta]\[Omega]\ t\)\) = \[Sum]\+\(p = \(-\[Infinity]\)\)\%\
\[Infinity]\( \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ N\ p\ \[CapitalDelta]\
\[Omega]\ t\)\) \(\[Sum]\+\(m = 0\)\%\(N - 1\)\ \(f\&~\_m\) \(\(\
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\ t\)\)\(.\)\
\)\)\)\)], "NE3"], "NE3"]
}], "Text"],

Cell[TextData[{
  "However, the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " can be written as a periodic \[Delta]-function using Eq. ",
  ButtonBox["(2.3.49)",
    ButtonData:>"(2.3.49)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(f\^\((p)\)\)(
        t) = \[CapitalDelta]t\ \(\[Sum]\+\(n = \
\(-\[Infinity]\)\)\%\[Infinity]\( \[Delta](
              t - n\ \[CapitalDelta]t)\) \(\[Sum]\+\(m = 0\)\%\(N - 1\)\ \
\(f\&~\_m\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ m\ \[CapitalDelta]\[Omega]\
\ t\)\)\)\)]]], "NE3",
  CellTags->"(2.3.61)"],

Cell[TextData[{
  "This equation represents our discrete data as a sum of \[Delta]-functions \
at the discrete times ",
  Cell[BoxData[
      \(TraditionalForm\`n\ \[CapitalDelta]t\)]],
  ", periodically extended to the entire real line.  This is not a bad way to \
think about the data, since the \[Delta]-functions provide a natural way of \
modeling the discrete data in continuous time. Also, we implicitly used this \
representation when we wrote the Riemann sum in Eq. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  ". That is,  if we define a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " for use in Eq. ",
  ButtonBox["(2.3.58)",
    ButtonData:>"(2.3.58)",
    ButtonStyle->"Hyperlink"],
  " according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(t)\), "=", Cell[TextData[Cell[BoxData[
              FormBox[
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], " ", 
                  RowBox[{\(\[Sum]\+\(n = 0\)\%\(N - 1\)\), 
                    RowBox[{\(f\_n\), 
                      RowBox[{"\[Delta]", "(", 
                        RowBox[{"t", "-", 
                          RowBox[{"n", " ", 
                            StyleBox[
                              RowBox[{"\[CapitalDelta]", 
                                StyleBox["t",
                                  FontSlant->"Italic"]}]]}]}], ")"}]}]}]}], 
                TraditionalForm]]]]]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(2.3.62)"],

Cell[TextData[{
  "we directly obtain Eq. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  ". The function ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\((p)\)\)(t)\)]],
  " in Eq. ",
  ButtonBox["(2.3.61)",
    ButtonData:>"(2.3.61)",
    ButtonStyle->"Hyperlink"],
  " is merely the periodic extension of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFurthermore, comparing Eq. ",
  ButtonBox["(2.3.61)",
    ButtonData:>"(2.3.61)",
    ButtonStyle->"Hyperlink"],
  " to ",
  ButtonBox["(2.3.62)",
    ButtonData:>"(2.3.62)",
    ButtonStyle->"Hyperlink"],
  " we  see that the time data ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\_n\)\(\ \)\)\)]],
  "can be written directly in terms of the Fourier coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\&~\_m\)\(\ \)\)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_n\), "=", 
          RowBox[{
            RowBox[{\(\[Sum]\+\(m = 0\)\%\(N - 1\)\), 
              RowBox[{\(f\&~\_m\), 
                SuperscriptBox["\[ExponentialE]", 
                  
                  RowBox[{\(-\[ImaginaryI]\), " ", "m", " ", 
                    "\[CapitalDelta]\[Omega]", " ", "n", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}]]}]}], 
            "=", \(\[Sum]\+\(m = 0\)\%\(N - 1\)\ \(f\&~\_m\) \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 2\ \[Pi]\ m\ \ n/N\)\)}]}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.63)"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.63)",
    ButtonData:>"(2.3.63)",
    ButtonStyle->"Hyperlink"],
  " are called a discrete Fourier transform and a discrete inverse Fourier \
transform respectively. These two equations provide a method for taking a set \
of discrete time data ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  " at times ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0\  \[LessEqual] \ \ n\  \[LessEqual] \ \ N - 1\)]],
  ", and obtaining a frequency spectrum ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m\)]],
  " at frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`m\ \[CapitalDelta]\[Omega]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ m \[LessEqual] \ N - 1\)]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]\[Omega]", "=", 
          RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", 
              RowBox[{"(", 
                RowBox[{"N", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], ")"}]}]}]}], 
        TraditionalForm]]],
  " is the fundamental frequency of the periodic extension of the data. "
}], "Text"],

Cell[TextData[{
  "Discrete Fourier transform of time data ",
  Cell[BoxData[
      \(TraditionalForm\`{\ f\_n}\)]],
  ":\n",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m = \(1\/\(\(N\)\(\ \)\)\) \(\[Sum]\+\(n = 0\)\
\%\(N - 1\)\ 
            f\_n\ \(\(\[ExponentialE]\^\(\[ImaginaryI]\ 2  \[Pi]\ m\ n\ /
                        N\)\)\(.\)\)\)\)]],
  "\nDiscrete inverse transform of frequency data ",
  Cell[BoxData[
      \(TraditionalForm\`{f\&~\_m}\)]],
  ":\n",
  Cell[BoxData[
      \(TraditionalForm\`f\_n = \[Sum]\+\(m = 0\)\%\(N - 1\)\ \(f\&~\_m\) \
\(\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 2\ \[Pi]\ m\ \ n/N\)\)\(.\)\)\)]]
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989]],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.63)",
    ButtonData:>"(2.3.63)",
    ButtonStyle->"Hyperlink"],
  " can be written as matrix equations, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(f\&~\),
            FontWeight->"Bold"], "=", 
          RowBox[{
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["f",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold"], "=", 
          RowBox[{
            SuperscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(-1\)], "\[CenterDot]", 
            OverscriptBox[
              StyleBox["f",
                FontWeight->"Bold"], "~"]}]}], TraditionalForm]]],
  ". The ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "-by-",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " matrices ",
  StyleBox["F",
    FontWeight->"Bold"],
  " and ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["F",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(-1\)], TraditionalForm]]],
  " have components"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(m\ n\)], 
            "=", \(\(1\/N\) \[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ n\ \
/N\)\)}], ",", " ", "\[IndentingNewLine]", 
          RowBox[{
            SubscriptBox[
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox["F",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], \(-1\)], ")"}], \(m\ n\)], 
            "=", \(\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ 2\ \[Pi]\ m\ n\ /
                      N\)\)\(.\)\(\ \)\)}]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(2.3.64)"],

Cell[TextData[{
  "These matrices are similar to the discretized forms for the Fourier \
transform operators, Eqs.",
  ButtonBox[" (2.3.54",
    ButtonData:>"(2.3.54)",
    ButtonStyle->"Hyperlink"],
  ") and ",
  ButtonBox["(2.3.55)",
    ButtonData:>"(2.3.55)",
    ButtonStyle->"Hyperlink"],
  ". However, according to Eqs. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.63)",
    ButtonData:>"(2.3.63)",
    ButtonStyle->"Hyperlink"],
  ", the matrices in Eq. ",
  ButtonBox["(2.3.64)",
    ButtonData:>"(2.3.64)",
    ButtonStyle->"Hyperlink"],
  " are exact inverses of one another, unlike the finite-dimensional versions \
of the discretized Fourier and inverse Fourier transforms, Eqs. ",
  ButtonBox["(2.3.54)",
    ButtonData:>"(2.3.54)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.55)",
    ButtonData:>"(2.3.55)",
    ButtonStyle->"Hyperlink"],
  ". Therefore, these matrices are much more useful than the discretized \
Fourier transform operators."
}], "Text"],

Cell[TextData[{
  "\tAfter constructing these matrices, we can use them to take the \
discretized Fourier transform of a set of data. The matrices themselves are \
easy to create using a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. For instance, here are 100-by-100 versions:"
}], "Text"],

Cell[BoxData[{
    \(nn = \ 100; 
    F = Table[
        Exp[I\ 2. \ Pi\ m\ n/nn]/nn, {m, 0, nn - 1}, {n, 0, 
          nn - 1}];\), "\n", 
    \(\(F1 = 
        Table[Exp[I\ 2. \ Pi\ m\ n/nn], {m, 0, nn - 1}, {n, 0, 
            nn - 1}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.60"],

Cell["\<\
Note the use of approximate numerical mathematics, rather than \
exact mathematics, in creating the matrices. When dealing with such large \
matrices, exact mathematical operations take too long. \
\>", "Text"],

Cell["\<\
\tWe can use these matrices to Fourier analyze data. Lets create \
some artificial time data:\
\>", "Text"],

Cell[BoxData[
    \(\(f = 
        Table[N[Sin[40\ Pi\ n/100] + \((Random[] - 1/2)\)], {n, 
            100}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.61"],

Cell[TextData[{
  "This data is a single sine wave, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(sin(40\ \[Pi]\ \ t)\)\(,\)\)\)]],
  " sampled at times ",
  Cell[BoxData[
      \(TraditionalForm\`t\_n = n/100\)]],
  ", with some noise added:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[f, PlotJoined \[Rule] True]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.62"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.31001 0.217739 [
[.21429 .29751 -6 -9 ]
[.21429 .29751 6 0 ]
[.40476 .29751 -6 -9 ]
[.40476 .29751 6 0 ]
[.59524 .29751 -6 -9 ]
[.59524 .29751 6 0 ]
[.78571 .29751 -6 -9 ]
[.78571 .29751 6 0 ]
[.97619 .29751 -9 -9 ]
[.97619 .29751 9 0 ]
[.01131 .09227 -12 -4.5 ]
[.01131 .09227 0 4.5 ]
[.01131 .20114 -24 -4.5 ]
[.01131 .20114 0 4.5 ]
[.01131 .41888 -18 -4.5 ]
[.01131 .41888 0 4.5 ]
[.01131 .52775 -6 -4.5 ]
[.01131 .52775 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .31001 m
.21429 .31626 L
s
[(20)] .21429 .29751 0 1 Mshowa
.40476 .31001 m
.40476 .31626 L
s
[(40)] .40476 .29751 0 1 Mshowa
.59524 .31001 m
.59524 .31626 L
s
[(60)] .59524 .29751 0 1 Mshowa
.78571 .31001 m
.78571 .31626 L
s
[(80)] .78571 .29751 0 1 Mshowa
.97619 .31001 m
.97619 .31626 L
s
[(100)] .97619 .29751 0 1 Mshowa
.125 Mabswid
.07143 .31001 m
.07143 .31376 L
s
.11905 .31001 m
.11905 .31376 L
s
.16667 .31001 m
.16667 .31376 L
s
.2619 .31001 m
.2619 .31376 L
s
.30952 .31001 m
.30952 .31376 L
s
.35714 .31001 m
.35714 .31376 L
s
.45238 .31001 m
.45238 .31376 L
s
.5 .31001 m
.5 .31376 L
s
.54762 .31001 m
.54762 .31376 L
s
.64286 .31001 m
.64286 .31376 L
s
.69048 .31001 m
.69048 .31376 L
s
.7381 .31001 m
.7381 .31376 L
s
.83333 .31001 m
.83333 .31376 L
s
.88095 .31001 m
.88095 .31376 L
s
.92857 .31001 m
.92857 .31376 L
s
.25 Mabswid
0 .31001 m
1 .31001 L
s
.02381 .09227 m
.03006 .09227 L
s
[(-1)] .01131 .09227 1 0 Mshowa
.02381 .20114 m
.03006 .20114 L
s
[(-0.5)] .01131 .20114 1 0 Mshowa
.02381 .41888 m
.03006 .41888 L
s
[(0.5)] .01131 .41888 1 0 Mshowa
.02381 .52775 m
.03006 .52775 L
s
[(1)] .01131 .52775 1 0 Mshowa
.125 Mabswid
.02381 .11405 m
.02756 .11405 L
s
.02381 .13582 m
.02756 .13582 L
s
.02381 .15759 m
.02756 .15759 L
s
.02381 .17937 m
.02756 .17937 L
s
.02381 .22291 m
.02756 .22291 L
s
.02381 .24469 m
.02756 .24469 L
s
.02381 .26646 m
.02756 .26646 L
s
.02381 .28824 m
.02756 .28824 L
s
.02381 .33178 m
.02756 .33178 L
s
.02381 .35356 m
.02756 .35356 L
s
.02381 .37533 m
.02756 .37533 L
s
.02381 .39711 m
.02756 .39711 L
s
.02381 .44065 m
.02756 .44065 L
s
.02381 .46243 m
.02756 .46243 L
s
.02381 .4842 m
.02756 .4842 L
s
.02381 .50597 m
.02756 .50597 L
s
.02381 .0705 m
.02756 .0705 L
s
.02381 .04872 m
.02756 .04872 L
s
.02381 .02695 m
.02756 .02695 L
s
.02381 .00518 m
.02756 .00518 L
s
.02381 .54952 m
.02756 .54952 L
s
.02381 .5713 m
.02756 .5713 L
s
.02381 .59307 m
.02756 .59307 L
s
.02381 .61484 m
.02756 .61484 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03333 .57314 m
.04286 .54586 L
.05238 .09182 L
.0619 .05524 L
.07143 .38068 L
.08095 .46676 L
.09048 .54492 L
.1 .26899 L
.10952 .18181 L
.11905 .36563 L
.12857 .47375 L
.1381 .39294 L
.14762 .25393 L
.15714 .16317 L
.16667 .27852 L
.17619 .60332 L
.18571 .37369 L
.19524 .28642 L
.20476 .05075 L
.21429 .36026 L
.22381 .58169 L
.23333 .45665 L
.24286 .28115 L
.25238 .15537 L
.2619 .20969 L
.27143 .53676 L
.28095 .51846 L
.29048 .17328 L
.3 .04081 L
.30952 .27114 L
.31905 .59951 L
.32857 .45116 L
.3381 .14989 L
.34762 .11731 L
.35714 .3269 L
.36667 .46644 L
.37619 .44282 L
.38571 .24504 L
.39524 .04244 L
.40476 .282 L
.41429 .47735 L
.42381 .50549 L
.43333 .28258 L
.44286 .13354 L
.45238 .31454 L
.4619 .45706 L
.47143 .33055 L
.48095 .26907 L
.49048 .09891 L
.5 .33918 L
Mistroke
.50952 .43805 L
.51905 .42491 L
.52857 .13126 L
.5381 .0621 L
.54762 .25742 L
.55714 .59971 L
.56667 .52823 L
.57619 .23568 L
.58571 .14232 L
.59524 .33441 L
.60476 .49363 L
.61429 .5375 L
.62381 .17304 L
.63333 .04647 L
.64286 .21742 L
.65238 .44023 L
.6619 .43732 L
.67143 .20382 L
.68095 .11467 L
.69048 .40206 L
.7 .51499 L
.70952 .48161 L
.71905 .08892 L
.72857 .05693 L
.7381 .27808 L
.74762 .46492 L
.75714 .50452 L
.76667 .28573 L
.77619 .01472 L
.78571 .28409 L
.79524 .60225 L
.80476 .37918 L
.81429 .16329 L
.82381 .16148 L
.83333 .30976 L
.84286 .46764 L
.85238 .53711 L
.8619 .18817 L
.87143 .0864 L
.88095 .22855 L
.89048 .50801 L
.9 .53121 L
.90952 .26262 L
.91905 .03829 L
.92857 .4119 L
.9381 .45782 L
.94762 .50283 L
.95714 .27225 L
.96667 .12787 L
.97619 .41177 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo0_l0003ooooo
odGooooo000Rooooo`03o`000?oooooooooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0
oooooom4ooooo`008_ooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo04cooooo000R
ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool0C?ooool002;ooooo00?o0000oooo
ooooool0m?ooool00ol0003oooooooooo`1<ooooo`008_ooool00ol0003oooooooooo`3dooooo`03
o`000?oooooooooo04cooooo000Rooooo`;o0000mOooool00ol0003oooooooooo`1<ooooo`008_oo
ool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo04cooooo000Rooooo`03o`000?oooooo
oooo0?Cooooo00?o0000ooooooooool0C?ooool002;ooooo00?o0000ooooooooool0m?ooool00ol0
003oooooooooo`1<ooooo`008_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Mooooo`008_ooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0N_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01gooooo000Rooooo`03o`000?oooooooooo05Sooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0Mooooo`008_ooool2o`0005Wooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Mooooo`008_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo02cooooo0_l0000]ooooo`03o`000?oooooooooo01gooooo000Rooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0/ooooo`;o
0000;Oooool00ol0003oooooooooo`0Mooooo`008_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool07?ooool2o`0001kooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo0_l0000]ooooo`03o`00
0?oooooooooo01gooooo000Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0Looooo`;o00007_ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`;o0000;Ooo
ool00ol0003oooooooooo`0Mooooo`008_ooool00ol0003oooooooooo`08ooooo`;o0000;_ooool0
0ol0003oooooooooo`0Looooo`;o00007_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
000002gooooo00?o0000ooooooooool07Oooool002;ooooo00?o0000ooooooooool02?ooool2o`00
02kooooo00?o0000ooooooooool07?ooool2o`0001kooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo0_l0000=ooooo`03o`000?oooooo0000
02gooooo00?o0000ooooooooool07Oooool002;ooooo0_l00009ooooo`;o0000;_ooool00ol0003o
ooooooooo`0Looooo`;o00007_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01_o
oooo0_l0000Nooooo`;o00003Oooool00ol0003oooooo`00000]ooooo`03o`000?oooooooooo01go
oooo000Rooooo`03o`000?oooooooooo00Sooooo0_l0000^ooooo`03o`000?oooooooooo01cooooo
0_l0000Nooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool06oooool2o`0001kooooo
0_l0000=ooooo`03o`000?oooooo000002gooooo00?o0000ooooooooool07Oooool002;ooooo00?o
0000ooooooooool01oooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo01cooooo0_l0
000Nooooo`03o`000?oooooooooo02_ooooo0_l0000Mooooo`03o`000?oooooo000001cooooo00?o
0000ooooool000003Oooool00ol0003oooooo`00000]ooooo`03o`000?oooooooooo01gooooo000R
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000;_ooool00ol0003oooooooooo`0L
ooooo`;o00007Oooool2o`0002gooooo0_l0000Mooooo`03o`000?oooooo000001cooooo00?o0000
ooooool000003Oooool00ol0003oooooo`00000/ooooo`;o00007oooool002;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000^ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ool000007?ooool2o`0002gooooo0_l0000Mooooo`03o`000?oooooo000001cooooo00?o0000oooo
ool000003Oooool00ol0003oooooo`00000/ooooo`;o00007oooool001Sooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000;_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooo000001cooooo00?o0000ooooool00000;?ooool2o`0001go
oooo00?o0000ooooool000006oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo0000
02cooooo0_l0000Oooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo0000
01cooooo00?o0000ooooool00000;?ooool2o`0001gooooo00?o0000ooooool000006oooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooo000001kooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000Nooooo`003oooool6o`0000Gooooo00?o0000ooooooooool01Oooool3o`00
00Kooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`0Kooooo`04o`000?oooooo
ooooo`0001cooooo00?o0000ooooool00000;?ooool2o`0001gooooo00?o0000ooooool000006ooo
ool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000001kooooo00?o0000ooooooooool0
2oooool00ol0003oooooo`00000Nooooo`006_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo0000;Oooool2o`0001gooooo00Co0000oooooooooooo
00007?ooool00ol0003oooooo`00000/ooooo`;o00007Oooool00ol0003oooooo`00000Kooooo`04
o`000?ooooooooooo`0000gooooo00?o0000ooooool000007_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000001kooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool0000]ooooo`;o00007Oooool01?l0003oooooooooool0000L
ooooo`03o`000?oooooo000002_ooooo00Co0000oooooooooooo00007?ooool00ol0003oooooo`00
000Kooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`00000Nooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooool000007_ooool001[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0002gooooo0_l0000Mooooo`04o`00
0?ooooooooooo`0001cooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`0;ooooo`04
o`000?ooooooooooo`0001cooooo00?o0000ooooool000006oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooool000007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
000001kooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01?l0
003oooooooooool0000]ooooo`;o00007Oooool01?l0003oooooooooool0000Looooo`03o`000?oo
oooo000001gooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooo000001_ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo000001ko
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Nooooo`006?ooool00omEEEGoIVIV
o`000007ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000;Oooool00ol0003o
ooooo`00000Looooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooool000007Oooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooool000006oooool0
1Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool000007Oooool2o`0000gooooo00?o
0000ooooool000007_ooool002;ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0
000]ooooo`03o`000?oooooo000001cooooo00Co0000oooooooooooo00007?ooool00ol0003ooooo
o`00000Mooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00007?ooool00ol0003o
ooooo`00000Kooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`00000Moooo
o`;o00003Oooool00ol0003oooooo`00000Nooooo`008_ooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool00000;?ooool00ol0003oooooo`00000Looooo`04o`000?oooooooooo
o`0001cooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`0;ooooo`04o`000?oooooo
ooooo`0001_ooooo00Co0000oooooooooooo00006oooool01Ol0003ooooooooooooooooo000000co
oooo00?o0000ooooool000007Oooool2o`0000gooooo00?o0000ooooool000007_ooool002;ooooo
0_l00007ooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooo`00000Looooo`04
o`000?ooooooooooo`0001cooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`0;oooo
o`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00003_ooool00ol0003ooooooooo
o`0:ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`00000Mooooo`03o`00
0?oooooo000000cooooo00?o0000ooooool000007_ooool002;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooool000007?ooool01?l0003ooooo
ooooool0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000007Oooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0001_ooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003ooooooooo
ool0000Looooo`03o`000?oooooo000000cooooo00?o0000ooooool000007_ooool002;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooool00000
7?ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool0
00007Oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000006oooool01?l0
003oooooooooool0000>ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`04o`000?ooooooooooo`0001cooooo00?o0000ooooool000003?ooool00ol0003ooooo
o`00000Nooooo`008_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
;?ooool00ol0003oooooo`00000Kooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool02_ooool01Ol0003o
oooooooooooooooo000001_ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0:
ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooo000000cooooo00?o0000ooooool000007_ooool002;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooool000006oooool01Ol0003ooooo
oooooooooooo000000cooooo0_l0000>ooooo`03o`000?oooooo000001gooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo00003_ooool0
0ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003ooooooooo
ool0000Looooo`03o`000?oooooo000000cooooo00?o0000ooooool000003_ooool00ol0003ooooo
ooooo`0=ooooo`008_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
;?ooool00ol0003oooooo`00000Kooooo`05o`000?ooooooooooooooool000003?ooool2o`0000ko
oooo00?o0000ooooool000007?ooool2o`0000cooooo00Go0000ooooooooooooooooo`00000Koooo
o`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000cooooo00Co0000oooooooooooo00007?ooool00ol0003oooooo`00000<ooooo`03o`00
0?oooooo000000kooooo00?o0000ooooooooool03Oooool002;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooool000006oooool01Ol0003ooooo
oooooooooooo000000cooooo0_l0000>ooooo`03o`000?oooooo000000kooooo00?o0000oooooooo
ool02oooool2o`0000cooooo00Go0000ooooooooooooooooo`00000Kooooo`05o`000?oooooooooo
ooooool000003?ooool2o`0000cooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?oo
ooooooooo`0001cooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000>ooooo`03o`00
0?oooooooooo00gooooo000Rooooo`;o00001oooool01Ol0003ooooooooooooooooo000002cooooo
00?o0000ooooool000006oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooool0
00003_ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00_ooooo0_l0000<ooooo`05
o`000?ooooooooooooooool000006oooool01Ol0003ooooooooooooooooo000000cooooo0_l0000<
ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000Looooo`03o`00
0?oooooo000000cooooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0=ooooo`008_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003ooooo
o`00000Kooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooo`00000>ooooo`03
o`000?oooooo000000kooooo00?o0000ooooooooool02oooool2o`0000cooooo00Go0000oooooooo
ooooooooo`00000Kooooo`05o`000?ooooooooooooooool000003?ooool2o`0000_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0001_ooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00gooooo
000Rooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`00
0?oooooo000001_ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo000000ko
oooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000_o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00[ooooo00Go0000oooo
ooooooooooooo`00000<ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00006oooool01?l0003oooooooooool0000<ooooo`03o`00
0?oooooo000000kooooo00?o0000ooooooooool03Oooool002;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000002cooooo00?o0000ooooool000006oooool01Ol0003ooooo
oooooooooooo000000[ooooo00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000>
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000cooooo
0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0003ooooo
ooooool0000Kooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooool000003_ooool00ol0
003oooooooooo`0=ooooo`008_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool00000;?ooool00ol0003oooooo`00000Kooooo`05o`000?ooooooooooooooool000002_ooool0
1?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooooooool0
2oooool00ol0003oooooo`00000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000003?ooool2o`0000_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0001_ooooo00Co0000
oooooooooooo00003?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooooooo00gooooo000R
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oo
oooo000001_ooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000go
oooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`00000<ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Wooooo00Go0000ooooooooooooooooo`00000Kooooo`04o`000?ooooooooooo`0000co
oooo00?o0000ooooool000003_ooool00ol0003oooooooooo`0=ooooo`008_ooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooo`00000>ooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?oooooooooo
ooooool000003?ooool01?l0003oooooooooool0000=ooooo`;o00003Oooool00ol0003oooooo`00
000;ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool2o`0000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000006oooool01?l0003o
ooooooooool0000;ooooo`04o`000?ooooooooooo`0000gooooo0_l0000?ooooo`008_ooool2o`00
00Oooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooo000000kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000gooooo0_l0000=ooooo`03o`00
0?oooooo000000_ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`;o00002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000Koooo
o`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00003Oooool2o`0000oooooo000R
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000go
oooo0_l0000=ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0:ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`00000<ooooo`;o00003Oooool01Ol0003ooooooooooooooooo
000000[ooooo00Co0000oooooooooooo00003Oooool2o`0000oooooo000Rooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooool000003_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooooooooooo
ooooo`00000<ooooo`;o00003Oooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000002_ooool2o`000003ooooool0003ooooo
00cooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000gooooo0_l0
000?ooooo`008_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000007_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo0_l0000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000cooooo00?o0000ooooool0
00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo0_l0000;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000[ooooo00Co0000oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000[ooooo
00Co0000oooooooooooo00003Oooool2o`0000oooooo000Rooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooo00003_ooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02_ooool2o`0000_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002_ooool01?l0003ooooo
ooooool0000=ooooo`05o`000?ooooooooooooooool000002_ooool01?l0003oooooooooool0000=
ooooo`;o00003oooool002;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000>
ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003ooooo
o`00000<ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000gooooo0_l0
000?ooooo`008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000kooooo0_l0
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000co
oooo00?o0000ooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000gooooo
0_l0000?ooooo`008_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Kooooo`;o00003?ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool000003?ooool00ol0
003oooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooo`00000>ooooo`008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`;o00003?ooool01?l0003ooooo
ooooool0000=ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`07ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000[ooooo
00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000kooooo000Rooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooool000002oooool01?l0003oooooooooool0000=oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000cooooo
00?o0000ooooool000003?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000kooooo000Rooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooool000002oooool01?l0003oooooooooool0000=ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooo
ool000002oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool000003_ooool002;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool00ol0003oooooo`00000;ooooo`04o`000?ooooooooooo`0000go
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?ooooooooooooooool000002ooo
ool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`00
0?oooooo000000kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool0
00002oooool01?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000003?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo00002oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0
003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooo`00000>ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooo`00000;ooooo`04o`000?ooooooooooo`0000gooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?ooooooooooooooool000002oooool01?l0003ooooo
ooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000ko
oooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?o
oooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool2o`0000go
oooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool0000=ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooo
oooo00002oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`00000>oooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool2o`00
00gooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool0000=ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
00002oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04o`000?ooooooooooo`0000kooooo0007ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo0_l0000=ooooo`04o`000?oooooo
ooooo`0000_ooooo00Co0000oooooooooooo00003Oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooo
oooooooo00002oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool01?l0
003oooooooooool0000>ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02oooool2o`0000gooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooo
oooooooo000000cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo00003_ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo0_l0000=
ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooooooo
ool000002oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04o`000?ooooooooooo`0000kooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003?ooool01?l0003oooooooooool0
000;ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00002oooool01?l0003oooooooooool0000>ooooo`008_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00000<ooooo`04
o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000kooooo000Rooooo`;o00001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003?oo
ool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`00
00kooooo000Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002oooool01Ol0003ooooooooooooo
oooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo00003_ooool0
02;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000[ooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000kooooo
000Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05
o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0000>ooooo`008_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003_ooool002;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000kooooo000Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000>ooooo`008_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Co0000oooooooooooo00003_ooool002;ooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00003_ooool002;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`04o`000?ooooooooooo`0000kooooo000Rooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000kooooo000Rooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
000000kooooo000Rooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08
ooooo`05o`000?ooooooooooooooool000003_ooool002;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000>ooooo`008_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000kooooo000Rooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000>ooooo`008_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`Go000000Soooooo`00
0?ooooook^k^oc8b<_l0003o<S8bonk^kPCooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo0ol000002Ol@413oooooooooool0003ok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`0=onk^k_l0003o0000oa0@4?o<c<coooooo`000?ooooook^k^oc8b
<_l0003o<S8bonk^kP02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`05o`000?lQ8B7o0000ob4Q8Oo<c<`00_ooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kP;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo1Ol00002ooooo`05onk^k_l0003o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo000Rooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00goV9RHo`000?o^k^koooooodA4
A?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000000oooool0
1_l0003oMgMgoiRHV?ooooooV9RHogMgM`?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00goEEEEo`000?ooooooV9RHob4Q8Ooooooo0000
oooooomgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go0000oiRHV?ooooooV9RHob4Q8@02ooooo`08
o`000?mgMgOoV9RHoooooonHV9SoMgMgooooool00006ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`000002ooooo`05ogMgMonHV9So0000oiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000Rooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ob4Q8Oo^k^h00_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
1Ol00002ooooo`03o`000?l@413ooooo00;ooooo00Go410@ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool02Ol0003ooooooooooooooooo0000
ooooool0003ooooooa0@4003ooooo`04oa0@4?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
410@ooooo`02ooooo`03oa0@4?oooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000;ooooo00Go410@ooooool0003ooooooa0@4003oooo
o`05oa0@4?ooooooooooooooool@41000oooool002;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool02?l0
003oV9RHob4Q8Oo^k^koooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`04odA4
A?l0003oooooo`0000?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Wo0000oiRHV?ooooooV9RHob4Q8Ooo
oooo0000ooooool000000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool01Ol0003oV9RHoooooonHV9So<S8b00;ooooo0_l00003oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool002;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool02?l0003oooooogMgMomV
IVKoooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`04o`000?mEEEGoooooo`00
00?ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00Wo0000oeEEEOl0003o410@olc<c?oooooo0000ooooool0
00000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool4o`000003olc<c?oooooooooo00;o00000oooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000002oooo
o`05o`000?oooooo0000ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo000R
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00So0000oooooooooooo0000ooooool0003ooooooa0@40?o
oooo00?o410@ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool01?l0003oMgMgolc<c?l00003ooooo`03o`000?l@413ooooo
00;ooooo00Go410@ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oQhN7ooooo`03ooooo`03o`000?oooooo410@00?ooooo00Co410@
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00Go
0000okZj^_oooooo^[Zjoa0@4002ooooo`03o`000?l@413ooooo00;ooooo00?o410@ooooool00000
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
0_ooool01Ol@413oooooo`000?oooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`008_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo0_l000002oooooooV9RHoa0@4?oooooo0000oooooomgMgOoV9RHoooo
oonHV9SoMgMg00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00Co0000onk^k_m4A4Co00000oooool01_l0003oMgMgoiRHV?ooooooV9RH
ogMgM`?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000oa0@4?nHV9P00oooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol0003o^[Zjoooooonj^[[o000000;ooooo00So0000ogMgMonHV9SooooooiRHV?mgMgOo
ooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo000000;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool002;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool03OnHV9So0000o`000?lQ8B7oc<c<oooo
ool0003oooooonk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool01?l0003oooooogMgMol00003ooooo`06
o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool03Ol0003oc<c<odA4A?l0003o410@ooooool0003o
ooooonk^k_lb<S;o0000oc8b<_o^k^h00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool01Ol0003o410@o`000?l@413oZJVY00;ooooo00So
0000onk^k_lb<S;o0000oc8b<_o^k^koooooo`0000Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`05oeEEEOmVIVKo0000ooooool000000_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`008_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo000Rooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02oooool002;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo000Rooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02oooool001[oooooool0001;o`0000Cooooo000R
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2o`0000Wooooo00?o0000
ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo0_l00007
ooooo`03o`000?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool2o`0000Kooooo00?o0000ooooooooool01?ooool2o`0000Sooooo00?o0000
ooooooooool00_ooool2o`0000cooooo000Rooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo0_l0000<oooo
o`008_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo000Rooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool002;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0;ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo000Rooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`008_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo000Rooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool002;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0;ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo000Roooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool002;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`008_ooool2o`0000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2oooool002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`008_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo000000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo000Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool002;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo
000Rooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`00000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`008_ooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo000Rooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool002;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooo00002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool002;ooooo0_l0
0005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000=ooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0:ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`00000=ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooo`00000=ooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooool000003Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_oo
ool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000003Oooool01Ol0003o
oooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0B
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3
o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo000000gooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool000Oooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooool000003Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Booooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000003Oooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooool000003_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000oooooooooooooooo
o`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`09ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000003_ooool00ol0003oooooo`00000;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0
003oooooo`00000<ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000kooooo0_l0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool002;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooo`00000<ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`;o00003_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000
ooooool0003o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool002;ooooo
0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooo000000cooooo00Go0000ooooooooooooooooo`00000:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?oooooooooo
ooooool000002Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooooooooooooooo
o`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01;ooooo000Rooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000003Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00Co0000oooooooooooo00003?ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04_ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
o`00000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Co0000oooooooooooo00003?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo
00Co0000oooooooooooo00003?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool04_ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooo`00000=ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000ooooool000003?ooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo
00003?ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`05o`000?ooooooooooooooool000005?ooool002;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000=ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool000003?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000000[ooooo00Co0000oooooooooooo00003?ooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000005?ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool2o`0000gooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
3?ooool2o`0000gooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000cooooo00Go0000
ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000001Cooooo000Rooooo`;o00001Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooo
oooooooooooo000000cooooo0_l0000=ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooooo
oooo000000[ooooo00Co0000oooooooooooo00003?ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000005?ooool002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000cooooo0_l0
000=ooooo`05o`000?ooooooooooooooool00000:Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooo
oooooooo00003?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000005?ooool002;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000cooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooo
oooo000002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000cooooo
00Go0000ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000cooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`00
000Eooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00Co0000
oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000006oooool01Ol0003o
oooooooooooooooo000002Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000006Oooool01Ol0003ooooooooooooooooo000000cooooo00Co
0000oooooooooooo00002oooool01?l0003oooooooooool0000<ooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooool000005Oooool0
02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`04o`000?oooooooooo
o`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo0000:_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000I
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooo`00000;ooooo`04o`000?oo
ooooooooo`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooooooo
ool000003?ooool00ol0003oooooo`00000Eooooo`008_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`04
o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000001_ooooo00Co0000oooooooooooo
0000:_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`00000Iooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooo`00000;
ooooo`04o`000?ooooooooooo`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000003?ooool00ol0003oooooo`00000Eooooo`008_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000Iooooo`04
o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000002oooool01?l0003oooooooooool0000Looooo`04o`000?ooooooooooo`0002[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`00
01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo000000_ooooo00Co0000
oooooooooooo00003?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooo000001Gooooo000Rooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000001Wooooo00Co0000oooooooo
oooo00002oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00
000;ooooo`04o`000?ooooooooooo`0001cooooo00Co0000oooooooooooo0000:_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00006_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooool000002oooool01?l0003oooooooooool0
000=ooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`;o
00005Oooool002;ooooo0_l00004ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooo
ooooo`00000Iooooo`04o`000?ooooooooooo`0000_ooooo00Go0000ooooooooooooooooo`00000<
ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00007Oooool00ol0003ooooo
o`00000Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003ooooo
ooooool0000Jooooo`05o`000?ooooooooooooooool000003_ooool2o`0000_ooooo00Co0000oooo
oooooooo00003Oooool01?l0003oooooooooool0000;ooooo`05o`000?ooooooooooooooool00000
3Oooool2o`0001Gooooo000Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000001Wooooo00Co0000oooooooooooo00002oooool01Ol0003o
oooooooooooooooo000000cooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool0
000Mooooo`03o`000?oooooo000002[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`0001[ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o
00002oooool01?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000
oooooooooooo00003_ooool2o`0001Gooooo000Rooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooool000003?oo
ool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooo00002oooool01?l0003o
ooooooooool0000Mooooo`03o`000?oooooo000002[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0001[ooooo00Co0000oooooooooooo00003ooo
ool2o`0000_ooooo00?o0000ooooool000003_ooool01?l0003oooooooooool0000;ooooo`04o`00
0?ooooooooooo`0000kooooo0_l0000Eooooo`008_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo000000co
oooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000
oooooooooooo00007_ooool2o`0002[ooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`00
0?ooooooooooo`0001[ooooo00Co0000oooooooooooo00003oooool2o`0000_ooooo00?o0000oooo
ool000003_ooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000kooooo0_l0
000Eooooo`008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo00006Oooool00ol0003oooooo`00000<ooooo`05o`000?ooooooooooooooool00000
3?ooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0001kooooo0_l0000Zoooo
o`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000Jooooo`04o`000?oo
ooooooooo`0000oooooo0_l0000;ooooo`03o`000?oooooo000000kooooo00?o0000ooooool00000
3?ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooooooo01?ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Jooooo`03o`00
0?oooooo000000cooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`00
00_ooooo00Co0000oooooooooooo00007_ooool2o`0002[ooooo00Go0000ooooooooooooooooo`00
000<ooooo`04o`000?ooooooooooo`0001_ooooo0_l0000Aooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooool000003_ooool00ol0003oooooo`00000<ooooo`04o`000?ooooooooooo`0000oo
oooo00?o0000ooooooooool04oooool002;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000001[ooooo00?o0000ooooool000003?ooool01Ol0003ooooo
oooooooooooo000000cooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool0000O
ooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oo
oooo000001_ooooo0_l0000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000003ooo
ool2o`0000cooooo00Co0000oooooooooooo00003oooool00ol0003oooooooooo`0Cooooo`008_oo
ool2o`0000Cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Jooooo`03o`000?oo
oooo000000cooooo00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000;ooooo`04
o`000?ooooooooooo`0001oooooo00?o0000ooooooooool0:?ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooool000006oooool2o`0001gooooo00?o0000ooooool000003oooool2
o`0000cooooo00Co0000oooooooooooo00009Oooool002;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000001[ooooo00?o0000ooooool000003?ooool0
1?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo
0000B_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooool000006oooool2o`00
01gooooo00?o0000ooooool000003oooool2o`0000cooooo00Co0000oooooooooooo00009Oooool0
02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
01[ooooo00?o0000ooooool000003?ooool01?l0003oooooooooool0000=ooooo`04o`000?oooooo
ooooo`0000_ooooo00Co0000oooooooooooo0000B_ooool01Ol0003ooooooooooooooooo000000go
oooo00?o0000ooooool000006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000000oo
oooo0_l0000=ooooo`03o`000?oooooo000002Gooooo000Rooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000Jooooo`03o`000?oooooo000000cooooo
00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000;ooooo`04o`000?oooooooooo
o`0004[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo000001_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooo`00000?ooooo`;o00003Oooool00ol0003oooooo`00
000Uooooo`006?ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0<ooooo`;o00006_ooool00ol0003oooooo`00000<ooooo`04o`000?oooooo
ooooo`0000gooooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool0001:ooooo`05
o`000?ooooooooooooooool000003_ooool2o`0003[ooooo00?o0000ooooool000003oooool2o`00
00gooooo00?o0000ooooool000009Oooool001[ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0000Jooooo`03o`000?oooooo000000co
oooo00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000;ooooo`04o`000?oooooo
ooooo`0004[ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000>_ooool00ol0003ooooo
o`00000?ooooo`;o00003_ooool2o`0002Gooooo000Jooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o00006_ooool00ol0003oooooo`00
000<ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooool000003?ooool01?l0003ooooo
ooooool0001:ooooo`05o`000?ooooooooooooooool000003_ooool2o`0003[ooooo00?o0000oooo
ool000003oooool2o`0000kooooo0_l0000Uooooo`006_ooool00ol0003oooooooooo`05ooooo`?o
00000oooool00ol0003oooooooooo`0<ooooo`;o00006_ooool00ol0003oooooo`00000<ooooo`04
o`000?ooooooooooo`0000gooooo00?o0000ooooool000003?ooool00ol0003oooooo`00001;oooo
o`05o`000?ooooooooooooooool000003_ooool2o`0003[ooooo00?o0000ooooool000004?ooool0
0ol0003oooooooooo`0<ooooo`;o00009Oooool001[ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo0_l0000Jooooo`03o`000?oooooo0000
00cooooo00Co0000oooooooooooo00003Oooool2o`0000gooooo00?o0000ooooool00000Boooool0
1Ol0003ooooooooooooooooo000000kooooo0_l0000jooooo`03o`000?oooooo0000013ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Sooooo`006_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool2o`0001[ooooo00?o0000
ooooool000003?ooool01?l0003oooooooooool0000=ooooo`;o00003Oooool00ol0003oooooo`00
001;ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooo0000013ooooo00?o0000ooooooooool0<oooool001[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooo`00000<ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooo`00001;ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0<oooool001Sooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooo000001gooooo00?o
0000ooooool00000Boooool01Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooool00000
A_ooool002;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000Mooooo`03o`000?oo
oooo000004_ooooo00Co0000oooooooooooo0000Boooool00ol0003oooooo`000016ooooo`008_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000003?oo
ool00ol0003oooooo`00000Nooooo`;o0000C?ooool00ol0003oooooo`00001;ooooo`03o`000?oo
oooo000004Kooooo000Rooooo`;o00001?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
000000gooooo0_l0000Nooooo`;o0000C?ooool00ol0003oooooo`00001;ooooo`03o`000?oooooo
000004Kooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool2o`00
00gooooo0_l0000Nooooo`;o0000C?ooool00ol0003oooooo`00001<ooooo`;o0000A_ooool002;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`;o00003Oooool2o`0001ko
oooo0_l0001<ooooo`03o`000?oooooo000004cooooo0_l00016ooooo`008_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02[ooooo0_l0000=ooooo`;o00007_ooool2o`0004cooooo
00?o0000ooooool00000C?ooool2o`0004Kooooo000Rooooo`05o`000?ooooooooooooooool00000
;Oooool2o`0000gooooo0_l0000Nooooo`;o0000C?ooool00ol0003oooooo`00001<ooooo`;o0000
A_ooool002;ooooo00Go0000ooooooooooooooooo`00000]ooooo`;o00003Oooool2o`0001kooooo
0_l0001<ooooo`03o`000?oooooo000004cooooo0_l00016ooooo`008_ooool01Ol0003ooooooooo
oooooooo000002gooooo00?o0000ooooooooool03?ooool2o`0001kooooo0_l0001<ooooo`;o0000
COooool00ol0003oooooooooo`15ooooo`008_ooool2o`000003ooooool0003ooooo02gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`;o0000C?ooool2o`0004gooooo00?o
0000ooooooooool0AOooool002;ooooo00Co0000oooooooooooo0000;_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01gooooo0_l0001<ooooo`;o0000COooool00ol0003ooooooooo
o`15ooooo`008_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1;ooooo`;o0000COooool00ol0003oooooooooo`15
ooooo`008_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1;ooooo`;o0000COooool00ol0003oooooooooo`15oooo
o`008_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`1;ooooo`;o0000COooool00ol0003oooooooooo`15ooooo`00
8_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
Boooool2o`0004gooooo00?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04_ooooo0_l0001=ooooo`03o`000?oo
oooooooo04Gooooo000Rooooo`;o0000<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`15ooooo`008_ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo04Gooooo000Rooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool0AOooool002;ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0AOooool002;ooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`3ooooooa;ooooo000Rooooo`03o`000?oooooo
oooo0?ooooooA?ooool002;ooooo00?o0000ooooooooool0oooooom4ooooo`008_ooool00ol0003o
ooooooooo`3oooooodCooooo000Rooooo`;o0000oooooom5ooooo`008_ooool00ol0003ooooooooo
o`3oooooodCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-10, -1, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "The frequency spectrum for this data is obtained by applying the Fourier \
matrix ",
  StyleBox["F",
    FontWeight->"Bold"],
  " to it:"
}], "Text"],

Cell[BoxData[
    \(\(f\&~ = F . f;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.63"],

Cell[TextData[{
  "Again, we will use a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to look at the spectrum. However, since ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\)]],
  " is complex, we will plot the real and imaginary parts of the spectrum \
separately, in Cells ",
  ButtonBox["2.64",
    ButtonData:>"Cell 2.64",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["2.65",
    ButtonData:>"Cell 2.65",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Re[f\&~], PlotJoined \[Rule] True, 
        PlotRange \[Rule] All];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.64"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 0.071848 1.15056 [
[.20659 .05935 -6 -9 ]
[.20659 .05935 6 0 ]
[.39899 .05935 -6 -9 ]
[.39899 .05935 6 0 ]
[.59139 .05935 -6 -9 ]
[.59139 .05935 6 0 ]
[.78379 .05935 -6 -9 ]
[.78379 .05935 6 0 ]
[.97619 .05935 -9 -9 ]
[.97619 .05935 9 0 ]
[.00169 .1869 -18 -4.5 ]
[.00169 .1869 0 4.5 ]
[.00169 .30196 -18 -4.5 ]
[.00169 .30196 0 4.5 ]
[.00169 .41702 -18 -4.5 ]
[.00169 .41702 0 4.5 ]
[.00169 .53207 -18 -4.5 ]
[.00169 .53207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20659 .07185 m
.20659 .0781 L
s
[(20)] .20659 .05935 0 1 Mshowa
.39899 .07185 m
.39899 .0781 L
s
[(40)] .39899 .05935 0 1 Mshowa
.59139 .07185 m
.59139 .0781 L
s
[(60)] .59139 .05935 0 1 Mshowa
.78379 .07185 m
.78379 .0781 L
s
[(80)] .78379 .05935 0 1 Mshowa
.97619 .07185 m
.97619 .0781 L
s
[(100)] .97619 .05935 0 1 Mshowa
.125 Mabswid
.06229 .07185 m
.06229 .0756 L
s
.11039 .07185 m
.11039 .0756 L
s
.15849 .07185 m
.15849 .0756 L
s
.25469 .07185 m
.25469 .0756 L
s
.30279 .07185 m
.30279 .0756 L
s
.35089 .07185 m
.35089 .0756 L
s
.44709 .07185 m
.44709 .0756 L
s
.49519 .07185 m
.49519 .0756 L
s
.54329 .07185 m
.54329 .0756 L
s
.63949 .07185 m
.63949 .0756 L
s
.68759 .07185 m
.68759 .0756 L
s
.73569 .07185 m
.73569 .0756 L
s
.83189 .07185 m
.83189 .0756 L
s
.87999 .07185 m
.87999 .0756 L
s
.92809 .07185 m
.92809 .0756 L
s
.25 Mabswid
0 .07185 m
1 .07185 L
s
.01419 .1869 m
.02044 .1869 L
s
[(0.1)] .00169 .1869 1 0 Mshowa
.01419 .30196 m
.02044 .30196 L
s
[(0.2)] .00169 .30196 1 0 Mshowa
.01419 .41702 m
.02044 .41702 L
s
[(0.3)] .00169 .41702 1 0 Mshowa
.01419 .53207 m
.02044 .53207 L
s
[(0.4)] .00169 .53207 1 0 Mshowa
.125 Mabswid
.01419 .09486 m
.01794 .09486 L
s
.01419 .11787 m
.01794 .11787 L
s
.01419 .14088 m
.01794 .14088 L
s
.01419 .16389 m
.01794 .16389 L
s
.01419 .20992 m
.01794 .20992 L
s
.01419 .23293 m
.01794 .23293 L
s
.01419 .25594 m
.01794 .25594 L
s
.01419 .27895 m
.01794 .27895 L
s
.01419 .32497 m
.01794 .32497 L
s
.01419 .34798 m
.01794 .34798 L
s
.01419 .37099 m
.01794 .37099 L
s
.01419 .394 m
.01794 .394 L
s
.01419 .44003 m
.01794 .44003 L
s
.01419 .46304 m
.01794 .46304 L
s
.01419 .48605 m
.01794 .48605 L
s
.01419 .50906 m
.01794 .50906 L
s
.01419 .04884 m
.01794 .04884 L
s
.01419 .02583 m
.01794 .02583 L
s
.01419 .00281 m
.01794 .00281 L
s
.01419 .55508 m
.01794 .55508 L
s
.01419 .57809 m
.01794 .57809 L
s
.01419 .60111 m
.01794 .60111 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
.5 Mabswid
.02381 .13053 m
.03343 .11406 L
.04305 .09189 L
.05267 .07489 L
.06229 .0727 L
.07191 .0991 L
.08153 .05126 L
.09115 .08994 L
.10077 .03015 L
.11039 .09106 L
.12001 .08933 L
.12963 .04032 L
.13925 .10162 L
.14887 .10526 L
.15849 .10106 L
.16811 .07818 L
.17773 .10028 L
.18735 .06578 L
.19697 .04745 L
.20659 .07364 L
.21621 .60332 L
.22583 .08528 L
.23545 .06916 L
.24507 .11513 L
.25469 .09434 L
.26431 .07692 L
.27393 .0769 L
.28355 .08641 L
.29317 .03324 L
.30279 .07734 L
.31241 .11054 L
.32203 .09664 L
.33165 .05918 L
.34127 .07256 L
.35089 .10282 L
.36051 .09899 L
.37013 .09612 L
.37975 .01472 L
.38937 .04612 L
.39899 .04944 L
.40861 .04246 L
.41823 .07278 L
.42785 .03732 L
.43747 .04688 L
.44709 .03693 L
.45671 .05724 L
.46633 .06091 L
.47595 .08685 L
.48557 .07298 L
.49519 .10525 L
Mistroke
.50481 .03921 L
.51443 .10525 L
.52405 .07298 L
.53367 .08685 L
.54329 .06091 L
.55291 .05724 L
.56253 .03693 L
.57215 .04688 L
.58177 .03732 L
.59139 .07278 L
.60101 .04246 L
.61063 .04944 L
.62025 .04612 L
.62987 .01472 L
.63949 .09612 L
.64911 .09899 L
.65873 .10282 L
.66835 .07256 L
.67797 .05918 L
.68759 .09664 L
.69721 .11054 L
.70683 .07734 L
.71645 .03324 L
.72607 .08641 L
.73569 .0769 L
.74531 .07692 L
.75493 .09434 L
.76455 .11513 L
.77417 .06916 L
.78379 .08528 L
.79341 .60332 L
.80303 .07364 L
.81265 .04745 L
.82227 .06578 L
.83189 .10028 L
.84151 .07818 L
.85113 .10106 L
.86075 .10526 L
.87037 .10162 L
.87999 .04032 L
.88961 .08933 L
.89923 .09106 L
.90885 .03015 L
.91847 .08994 L
.92809 .05126 L
.93771 .0991 L
.94733 .0727 L
.95695 .07489 L
.96657 .09189 L
.97619 .11406 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
87oo00<007ooOol0ogooSWoo000POol2003oOon?Ool0021oo`03001oogoo0?moohioo`0087oo00<0
07ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<0
07ooOol0Sgoo00<007ooOol0HGoo00<007ooOol0Ugoo000POol00`00Oomoo`2?Ool00`00Oomoo`1Q
Ool00`00Oomoo`2GOol0021oo`03001oogoo08moo`80065oo`8009Uoo`0087oo00<007ooOol0Sgoo
0P00HGoo0P00VGoo000POol2002@Ool2001QOol2002IOol0021oo`03001oogoo08ioo`04001oogoo
001OOol01000Oomoo`00V7oo000POol00`00Oomoo`0OOol00`00Oomoo`1/Ool01000Oomoo`00Ggoo
00@007ooOol006ioo`03001oogoo02Moo`0087oo00<007ooOol07goo00<007ooOol0BWoo00<007oo
Ool07goo00@007ooOol005moo`04001oogoo000QOol00`00Oomoo`1:Ool00`00Oomoo`0WOol0021o
o`03001oogoo01moo`03001oogoo021oo`H000Eoo`8001eoo`03001oogoo01moo`04001oogooOol3
0005Ool20011Ool40006Ool20007Ool01@00Oomoogoo00008Goo00<007ooOol04Goo10001Woo0P00
;Goo00<007ooOol03Goo1@001Goo0P001goo0P001Goo000POol00`00Oomoo`0OOol00`00Oomoo`0Q
Ool01@00Oomoogoo000017oo00@007ooOol001aoo`03001oogoo01moo`04001oogooOol20005Ool0
1000Oomoo`001Goo00<007ooOol01Goo00<007ooOol057oo00<007ooOol057oo00D007ooOomoo`00
00=oo`8000Aoo`04001oogoo0006Ool01@00Oomoogoo00008Goo00<007ooOol047oo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol002aoo`03001oogoo00moo`03001oogoo00Aoo`04001oogoo
0005Ool01000Oomoo`0017oo000POol00`00Oomoo`0NOol00`00Ool0000:Ool00`00Oomoo`0FOol0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0IOol2000POol70003Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool20005Ool2000FOol00`00Oomoo`0DOol20002Ool00`00Oomoo`030003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo000087oo0P004Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo01eoo`03001oogoo00Qoo`03001oo`00011oo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`01Ool0021oo`03001oogoo01ioo`03001o
o`0000Yoo`03001oogoo01Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Qoo`03001o
o`00021oo`8000=oo`03001oogoo009oo`06001oo`00001oo`0017oo00<007oo00000goo00@007oo
Ool001Eoo`03001oogoo01=oo`09001oogoo001oo`00Ool007oo008000=oo`03001oogoo00<000Ao
o`03001oogoo009oo`03001oogoo01ioo`03001oo`00015oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0MOol00`00Oomoo`08Ool00`00Ool0000@Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo000POol00`00Oomoo`0NOol00`00Ool0000:
Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Ool0000P
Ool00`00Ool00002Ool20003Ool2000017oo001oo`000goo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`0COol00`00Oomoo`0COol01000Oomoogoo0`000goo00D007ooOomoo`00009oo`03001oo`00
00=oo`8000Aoo`03001oogoo01ioo`03001oo`00019oo`@000Aoo`03001oogoo009oo`03001oogoo
01eoo`03001oogoo00Qoo`03001oo`00011oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool0021oo`8001moo`03001oo`0000Uoo`8001Yoo`8000=oo`03001o
ogoo009oo`03001oogoo01Qoo`03001oo`0001moo`08001oogooOol007oo001oo`800007Ool007oo
Ool007oo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol04Goo00<007oo00004goo
00<007ooOol00goo00<007oo00000`000goo00<007oo00000Woo0P0000=oo`00Ool01Woo00<007oo
Ool07Goo00<007oo00004Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo01Qoo`8000Uoo`03001oo`00011oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool0021oo`03001oogoo01Moo`03001oogoo00Aoo`03001oo`0000Uo
o`03001oo`0001Uoo`8000=oo`03001oogoo009oo`03001oogoo01Qoo`03001oo`0001moo`07001o
ogooOol007oo00000goo0P000goo0P000goo00<007ooOol027oo00<007ooOol04Goo00<007oo0000
4goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oo`00009oo`03001oo`0000Qoo`03001o
ogoo01eoo`03001oo`00015oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool0
0`00Oomoo`0HOol20009Ool00`00Ool00006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo000POol00`00Oomoo`0GOol00`00Oomoo`04
Ool00`00Ool00009Ool00`00Ool0000EOol01P00Oomoo`00Ool000Aoo`04001oogoo000KOol01000
Oomoo`007Woo00<007ooOol00Woo0P001Goo00@007ooOol000=oo`03001oogoo00Yoo`03001oogoo
011oo`03001oo`00019oo`03001oogoo00Eoo`8000=oo`04001oogooOol200000goo001oo`0:Ool0
0`00Oomoo`0LOol01000Oomoo`004Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Eo
o`8001Qoo`03001oo`0000Uoo`03001oo`0000Ioo`03001oogoo00Eoo`<000Ioo`04001oogoo0005
Ool01000Oomoo`0017oo000POol00`00Oomoo`0GOol00`00Oomoo`03Ool01@00Oomoogoo000027oo
00<007oo00005Woo1@001Goo0P006goo00D007ooOomoo`0001ioo`03001oogoo00=oo`03001oogoo
00Aoo`<000=oo`03001oogoo00Yoo`03001oogoo011oo`03001oo`00019oo`03001oogoo00Moo`@0
00=oo`<000aoo`03001oogoo01aoo`05001oogooOol0000AOol40006Ool20005Ool00`00Ool0000H
Ool00`00Ool00008Ool01@00Oomoogoo00001Goo00<007ooOol01Woo0P001goo0P001goo0P001Goo
000POol00`00Oomoo`0GOol20004Ool01@00Oomoogoo000027oo00<007oo00005goo00@007ooOol0
029oo`05001oogooOol0000=Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool01@00Oomoogoo00003Goo
0`003goo00<007oo000047oo0P003Goo00D007ooOomoo`0000ioo`03001oogoo00ioo`03001oogoo
00]oo`05001oogooOol0000ROol01000Oomoo`005goo00<007oo000027oo00D007ooOomoo`0000Ao
o`03001oo`00021oo`0087oo00<007ooOol05Woo00<007oo000017oo00D007ooOomoo`0000Moo`04
001oogoo000FOol00`00Oomoo`02Ool00`00Oomoo`0OOol01@00Oomoogoo00003Goo00<007ooOol0
3Woo00<007ooOol03Goo00@007ooOol0011oo`8000eoo`03001oo`0000ioo`8000moo`05001oogoo
Ool0000>Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool01@00Oomoogoo00008Woo00D007ooOomoo`00
01Ioo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007oo000087oo000POol00`00Oomoo`0F
Ool00`00Ool00004Ool01@00Oomoogoo00001goo00@007ooOol001Ioo`03001oogoo009oo`03001o
ogoo01moo`03001oogoo009oo`03001oogoo00Yoo`8000moo`03001oogoo00eoo`03001oo`00019o
o`03001oogoo00]oo`03001oo`0000ioo`03001oogoo00moo`03001oo`0000moo`03001oogoo00eo
o`8000aoo`03001oogoo009oo`03001oogoo01moo`03001oogoo009oo`03001oogoo01Aoo`04001o
ogoo0007Ool01@00Oomoogoo000017oo00<007oo000087oo000POol00`00Oomoo`0FOol00`00Ool0
0004Ool01@00Oomoogoo00001goo00D007ooOomoo`0001Aoo`03001oogoo00Aoo`03001oogoo01io
o`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000>Ool00`00Oomoo`0=Ool00`00Ool0000C
Ool00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007ooOol047oo00<007oo00003goo00<007oo
Ool03Goo00<007oo00002goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol00goo00<007oo
Ool04goo00@007ooOol000Moo`05001oogooOol00004Ool00`00Ool0000POol0021oo`03001oogoo
01Ioo`04001oogoo0003Ool01@00Oomoogoo00001goo00D007ooOomoo`0001Aoo`03001oogoo00Ao
o`03001oogoo00Uoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo00Uoo`04001oogoo000=
Ool00`00Oomoo`0>Ool00`00Ool0000COol00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007oo
Ool047oo00<007oo000047oo00<007ooOol02goo00@007ooOol000]oo`03001oogoo00=oo`03001o
ogoo015oo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo01=oo`04001oogoo0007Ool01@00
Oomoogoo00000goo00@007ooOol0021oo`0087oo00<007ooOol05Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`05001oogooOol0000DOol00`00Oomoo`04Ool00`00Oomoo`09Ool0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007ooOol0
3goo00<007ooOol04Woo00<007ooOol02Goo00D007ooOomoo`0000aoo`03001oogoo015oo`03001o
ogoo00moo`03001oogoo00]oo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00
Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0COol01000Oomoo`001Woo00<007ooOol00goo00@0
07ooOol000=oo`03001oogoo01eoo`006Wooo`00T`0017oo000POol00`00Oomoo`0<Ool20002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol00goo0P0017oo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007oo00001Woo00<0
07ooOol02Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00@007ooOol000Qoo`03
001oogoo00Qoo`03001oogoo011oo`03001oogoo00Moo`03001oogoo009oo`07001oogooOol007oo
00000goo00<007ooOol00goo00<007ooOol00goo00<007oo00004Woo00<007ooOol03goo0P002goo
00<007ooOol00Woo00<007oo00001goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol02goo
00<007oo00000Woo00<007ooOol01Goo00<007ooOol01Goo00@007ooOol0011oo`03001oo`00009o
o`03001oogoo00=oo`03001oogoo00=oo`08001oogoo001oo`00Ool000Aoo`03001oogoo008000Mo
o`03001oogoo00aoo`0087oo00<007ooOol037oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oo`0000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00Ioo`04001oogoo000:Ool50003Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0JOol01000Oomo
ogoo0P001Goo00D007ooOomoo`0000Eoo`8000Aoo`03001oogoo019oo`03001oogoo00moo`03001o
ogoo00Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`04001oogooOol5000:Ool0
1P00Oomoo`00Ool000Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo009oo`05001oogoo
Ool00007Ool00`00Oomoo`0<Ool0021oo`03001oogoo00]oo`03001oogoo00=oo`05001oogooOol0
0004Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`05Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<0
07oo00001goo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol09Woo00H0
07ooOol007oo0004Ool01@00Oomoogoo000017oo00@007ooOol0009oo`03001oogoo02Eoo`03001o
ogoo00Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Eoo`03001oo`0000Aoo`03001o
ogoo00Qoo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00004Ool01@00Oomoogoo0000
1Goo00<007ooOol04goo000POol00`00Oomoo`0;Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo
00<007oo00001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol027oo00<007oo000017oo
00<007ooOol01goo00<007ooOol01Goo00D007ooOomoo`0000Uoo`03001oogoo00Aoo`8000Moo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo02Ioo`03001oo`00009oo`05
001oogooOol00005Ool01@00Oomoogoo00000Woo00@007ooOol002Moo`03001oogoo00Uoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Eoo`8000Ioo`03001oogoo00Moo`05001oogooOol0
0008Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0000;Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Ool00005Ool01000Oomoo`001Goo00<007ooOol04goo000POol0
0`00Oomoo`0:Ool00`00Oomoo`05Ool01000Oomoo`0017oo0P001goo00D007ooOomoo`0000Ioo`03
001oogoo00Qoo`03001oo`0000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Qoo`03001oogoo02Ioo`03001oo`00009oo`05001oogooOol00005Ool01@00Oomoogoo
00000goo00<007oo00009goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool01Woo00<007ooOol00Woo00<007oo00002goo00<007ooOol00goo00D007ooOomoo`0000Moo`80
00Eoo`04001oogoo0006Ool00`00Oomoo`0BOol0021oo`03001oogoo00Uoo`03001oogoo00Ioo`04
001oogoo0005Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo00<007ooOol01goo00D007ooOomo
o`0000=oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00moo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo02Qoo`03001o
ogoo009oo`04001oogoo0005Ool01000Oomoo`001Goo00<007ooOol09goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo00=o
o`05001oogooOol00007Ool00`00Oomoo`04Ool00`00Ool00008Ool00`00Oomoo`0AOol0021oo`03
001oogoo00Uoo`03001oogoo00Moo`03001oo`0000Eoo`03001oogoo00Eoo`D000Ioo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`0]Ool01000Oomoo`001Goo00@007ooOol002moo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`08Ool00`00Oomoo`03Ool50007Ool00`00Oomo
o`04Ool00`00Ool00008Ool00`00Oomoo`0AOol0021oo`03001oogoo00Qoo`03001oogoo00Qoo`80
01Uoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`0]Ool01000Oomoo`001Goo00@007ooOol002moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`07Ool00`00Oomoo`0GOol0
0`00Ool00009Ool00`00Oomoo`0@Ool0021oo`8000Uoo`03001oogoo00Qoo`8001Yoo`03001oogoo
00Eoo`03001oogoo00=oo`03001oo`0000Yoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`<0031oo`03
001oo`0000Eoo`03001oo`00031oo`<000Ioo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
019oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oo`00
00Eoo`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo011oo`0087oo00<0
07ooOol01goo00<007ooOol02Woo00<007ooOol067oo00<007ooOol01Goo00<007ooOol00goo0P00
2goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol0
0goo00<007ooOol01goo00@007ooOomoo`<003=oo`03001oo`0000Eoo`03001oo`0003=oo`<000=o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo00Qoo`8000Eoo`03001oogoo00Ioo`03001oogoo01Qoo`03001o
ogoo00Uoo`03001oogoo00moo`0087oo00<007ooOol01goo00<007ooOol09Goo0P0017oo0P001goo
00<007ooOol02Goo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`0001Ioo`05001oogoo
Ool0000;Ool3000fOol20007Ool2000fOol3000;Ool01@00Oomoogoo00005Woo00D007ooOomoo`00
00Ioo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Eoo`8000Eoo`8002Ioo`03001oogoo
00moo`0087oo00<007ooOol01Woo00<007ooOol0:7oo00@007oo000001Eoo`03001oogoo00Aoo`03
001oogoo00Aoo`05001oogooOol0000FOol01000Oomoo`0037oo00<007ooOol0=goo00<007ooOol0
1Goo00<007ooOol0=goo00<007ooOol02Woo00@007ooOol001Ioo`05001oogooOol00006Ool00`00
Oomoo`05Ool00`00Oomoo`0BOol200000goo0000000YOol00`00Oomoo`0>Ool0021oo`03001oogoo
00Ioo`03001oogoo02Uoo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo
000GOol01000Oomoo`00AWoo00<007ooOol01Goo00<007ooOol0A7oo00@007ooOol001Moo`04001o
ogoo0006Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`00Oomoo`0YOol00`00Oomoo`0>Ool0021o
o`03001oogoo00Eoo`03001oogoo049oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo000H
Ool2002GOol2000HOol01000Oomoo`001Woo00<007ooOol01Goo00<007ooOol0@Goo00<007ooOol0
3Goo000POol00`00Oomoo`05Ool00`00Oomoo`12Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Ool0000IOol00`00Oomoo`2GOol00`00Oomoo`0GOol00`00Ool00006Ool00`00Oomoo`05Ool00`00
Oomoo`11Ool00`00Oomoo`0=Ool0021oo`03001oogoo00Aoo`03001oogoo04=oo`03001oogoo00Ao
o`03001oogoo00Eoo`800<eoo`8000Moo`03001oogoo00Eoo`03001oogoo049oo`03001oogoo00ao
o`0087oo00<007ooOol017oo00<007ooOol0@goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool0cGoo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0DGoo000POol20004Ool00`00Oomo
o`14Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00Oomoo`05Ool00`00Oomoo`1AOol0021oo`03
001oogoo00=oo`03001oogoo04Aoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00Eoo`03
001oogoo055oo`0087oo00<007ooOol00Woo00<007ooOol0AGoo00<007ooOol017oo00<007ooOol0
gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol01@00Oomoogoo0000B7oo00<007ooOol017oo
00<007ooOol0gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol01@00Oomoogoo0000B7oo00<0
07ooOol017oo00<007ooOol0gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol01000Oomoo`00
BGoo00<007ooOol017oo00<007ooOol0gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol00`00
Oomoo`1:Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00Oomoo`05Ool00`00Oomoo`1AOol0021o
o`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00Eoo`03001oogoo055o
o`0087oo00<007ooOol0BWoo00<007ooOol017oo00<007ooOol0gGoo00<007ooOol01Goo00<007oo
Ool0DGoo000POol2001;Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00Oomoo`04Ool00`00Oomo
o`1BOol0021oo`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00Aoo`03
001oogoo059oo`0087oo00<007ooOol0BWoo00<007ooOol017oo00<007ooOol0gGoo00<007ooOol0
17oo00<007ooOol0DWoo000POol00`00Oomoo`1:Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00
Oomoo`04Ool00`00Oomoo`1BOol0021oo`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo0=eo
o`03001oogoo00Aoo`03001oogoo059oo`0087oo00<007ooOol0BWoo00<007ooOol00goo00<007oo
Ool0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1:Ool00`00Oomoo`03Ool0
0`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04Yoo`03001oogoo
00=oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0BWoo00<0
07ooOol00goo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol2001<Ool00`00
Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]o
o`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007oo
Ool0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol0
0`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0
021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo
059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<0
07ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03
Ool00`00Oomoo`1BOol000=oo`8000Moo`<000Eoo`D000Moo`03001oogoo04]oo`03001oogoo009o
o`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`000Woo00@007ooOol000Ioo`<000Mo
o`03001oogoo00Moo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=o
o`03001oogoo059oo`0000=oo`00Ool00goo00<007ooOol00goo0`001goo00<007ooOol01goo00<0
07ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo0000
0goo001oo`03Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool3001;Ool00`00Oomoo`02Ool00`00Oomo
o`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol00003Ool007oo00=oo`03001oogoo00eoo`03001o
ogoo00Moo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001o
ogoo059oo`0000=oo`00Ool00goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0Bgoo00<0
07ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo00000goo001oo`03Ool0
0`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol0
0`00Oomoo`03Ool00`00Oomoo`1BOol0009oo`04001oogoo000>Ool30009Ool00`00Oomoo`1;Ool0
0`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol000=oo`80011oo`80
00Uoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo
059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<0
07ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03
Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001o
ogoo00=oo`03001oogoo059oo`0087oo0P00C7oo00<007ooOol00Woo00<007ooOol0ggoo00<007oo
Ool00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol0
0`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo
0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<0
07ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02
Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001o
ogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0Bgoo
00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomo
o`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03
001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`00
87oo0P00C7oo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000P
Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1B
Ool0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001o
ogoo059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo
00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomo
o`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03
001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0
ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00
Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009o
o`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo0P00C7oo00<007ooOol00Woo
00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomo
o`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03
001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0
Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00
Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021o
o`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059o
o`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007oo
Ool0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`02Ool0
0`00Oomoo`1COol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo
009oo`03001oogoo05=oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<0
07ooOol00Woo00<007ooOol0Dgoo000POol2001<Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00
Oomoo`02Ool00`00Oomoo`1COol0021oo`03001oogoo04]oo`05001oogooOol0003SOol01@00Oomo
ogoo0000EGoo000POol00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`00
87oo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001EOol0021oo`03001oogoo
04]oo`05001oogooOol0003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1;Ool01@00Oomo
ogoo0000hgoo00D007ooOomoo`0005Eoo`000goo0P001goo0`0017oo1P001goo00<007ooOol0Bgoo
00D007ooOomoo`000>=oo`05001oogooOol0001EOol0009oo`04001oogoo0006Ool30005Ool01@00
Oomoogoo00001goo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001EOol00003
Ool007oo00=oo`03001oogoo00=oo`<000Ioo`03001oogoo00Qoo`03001oogoo04]oo`05001oogoo
Ool0003SOol01@00Oomoogoo0000EGoo00000goo001oo`03Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool3001;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`0000=oo`00Ool00goo00<007oo
Ool03Woo00<007ooOol01Woo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001E
Ool00003Ool007oo00=oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo04]oo`05001oogoo
Ool0003SOol01@00Oomoogoo0000EGoo00000goo001oo`03Ool00`00Oomoo`0?Ool00`00Oomoo`05
Ool00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`000Woo00@007ooOol0
00eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo04]oo`05001oogooOol0003SOol01@00
Oomoogoo0000EGoo0003Ool2000?Ool40008Ool00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D0
07ooOomoo`0005Eoo`0087oo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001E
Ool0021oo`03001oogoo04]oo`05001oogooOol0003SOol01@00Oomoogoo0000EGoo000POol00`00
Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`0087oo0P00C7oo00D007ooOomo
o`000>=oo`05001oogooOol0001EOol0021oo`03001oogoo04]oo`05001oogooOol0003SOol01@00
Oomoogoo0000EGoo000POol00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eo
o`0087oo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001EOol0021oo`03001o
ogoo04]oo`05001oogooOol0003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1;Ool01@00
Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05
001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo
000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo0P00CGoo00@0
07ooOol00>=oo`05001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00
Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`00
87oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogooOol0001EOol0021oo`03001oogoo04ao
o`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo
00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogooOol0001E
Ool0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomo
o`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo0P00CGoo00@007ooOol00>=oo`05
001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo
000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0
C7oo00@007ooOol00>=oo`05001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003S
Ool01@00Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`00
05Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogooOol0001EOol0021oo`03001o
ogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomo
o`00hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogoo
Ool0001EOol0021oo`8004eoo`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomo
o`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol0
0>=oo`05001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo
0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00@007ooOol005Ioo`0087oo00<007oo
Ool0C7oo00@007ooOol00>=oo`04001oogoo001FOol000=oo`8000Moo`<000Eoo`@000Qoo`03001o
ogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`000Woo00@007ooOol000Ioo`<000Aoo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0000=o
o`00Ool00goo00<007ooOol00goo0`002Goo00<007ooOol01Goo00<007ooOol0C7oo00<007oo0000
iGoo00<007oo0000EWoo00000goo001oo`03Ool00`00Oomoo`0?Ool00`00Oomoo`05Ool3001<Ool0
0`00Ool0003UOol00`00Ool0001FOol00003Ool007oo00=oo`03001oogoo00aoo`<000Qoo`03001o
ogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0000=oo`00Ool00goo00<007ooOol03goo00<0
07ooOol01Goo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo00000goo001oo`03Ool0
0`00Oomoo`0?Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0
009oo`04001oogoo000=Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool00`00Ool0
003UOol00`00Ool0001FOol000=oo`8000moo`@000Qoo`03001oogoo04aoo`03001oo`000>Eoo`03
001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo000POol00`00
Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`000>Eo
o`03001oo`0005Ioo`0087oo0P00CGoo00<007oo0000iGoo00<007oo0000EWoo000POol00`00Oomo
o`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`000>Eoo`03
001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo000POol00`00
Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`000>Eo
o`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo000POol0
0`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`00
0>Eoo`03001oo`0005Ioo`0087oo0P00CGoo00<007oo0000iGoo00<007oo0000EWoo000POol00`00
Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`000>Eo
o`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo000POol0
0`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`00
0>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo000P
Ool00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001o
o`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo
000POol2001=Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001oo`00
0>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo000P
Ool00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001o
o`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo
000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03
001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000
EWoo000POol2001=Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03001oogoo04aoo`03001o
o`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo
000POol00`00Oomoo`1=Ool2003UOol00`00Ool0001FOol0021oo`03001oogoo04eoo`800>Eoo`03
001oo`0005Ioo`0087oo00<007ooOol0CGoo0P00iGoo00<007oo0000EWoo0003Ool20007Ool30007
Ool30007Ool00`00Oomoo`1=Ool2003UOol00`00Ool0001FOol0009oo`04001oogoo0006Ool30008
Ool00`00Oomoo`06Ool00`00Oomoo`1=Ool2003UOol00`00Ool0001FOol00003Ool007oo00=oo`03
001oogoo00=oo`<000Aoo`H000Moo`03001oogoo04eoo`800>Eoo`03001oo`0005Ioo`0000=oo`00
Ool00goo00<007ooOol02Woo00D007ooOomoo`0000Qoo`<004eoo`800>Eoo`03001oo`0005Ioo`00
00=oo`00Ool00goo00<007ooOol02goo00@007ooOol000Qoo`03001oogoo04eoo`800>Eoo`03001o
o`0005Ioo`0000=oo`00Ool00goo00<007ooOol037oo00<007oo000027oo00<007ooOol0CGoo0P00
iGoo0P00Egoo00000goo001oo`03Ool00`00Oomoo`0<Ool00`00Ool00008Ool00`00Oomoo`1=Ool0
0`00Oomoo`3UOol00`00Oomoo`1EOol0009oo`04001oogoo000@Ool20008Ool00`00Oomoo`1=Ool0
0`00Oomoo`3UOol00`00Oomoo`1EOol000=oo`80019oo`03001oogoo00Ioo`03001oogoo04eoo`03
001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<007ooOol0iGoo00<007ooOol0
EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo04eo
o`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo0P00CWoo00<007ooOol0iGoo00<007ooOol0EGoo
000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo04eoo`03
001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<007ooOol0iGoo00<007ooOol0
EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo04eo
o`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<007ooOol0iGoo00<007oo
Ool0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo
04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo0P00CWoo00<007ooOol0iGoo00<007ooOol0
EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo04eo
o`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<007ooOol0iGoo00<007oo
Ool0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo
04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<007ooOol0iGoo00<0
07ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001o
ogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<007ooOol0iGoo
00<007ooOol0EGoo000POol2001>Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0021oo`03001oogoo
0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo
0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-8, 0, 0, 0}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Im[f\&~], PlotJoined \[Rule] True, 
        PlotRange \[Rule] All];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.65"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 0.309017 1.44702 [
[.20659 .29652 -6 -9 ]
[.20659 .29652 6 0 ]
[.39899 .29652 -6 -9 ]
[.39899 .29652 6 0 ]
[.59139 .29652 -6 -9 ]
[.59139 .29652 6 0 ]
[.78379 .29652 -6 -9 ]
[.78379 .29652 6 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.00169 .01961 -24 -4.5 ]
[.00169 .01961 0 4.5 ]
[.00169 .16431 -24 -4.5 ]
[.00169 .16431 0 4.5 ]
[.00169 .45372 -18 -4.5 ]
[.00169 .45372 0 4.5 ]
[.00169 .59842 -18 -4.5 ]
[.00169 .59842 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20659 .30902 m
.20659 .31527 L
s
[(20)] .20659 .29652 0 1 Mshowa
.39899 .30902 m
.39899 .31527 L
s
[(40)] .39899 .29652 0 1 Mshowa
.59139 .30902 m
.59139 .31527 L
s
[(60)] .59139 .29652 0 1 Mshowa
.78379 .30902 m
.78379 .31527 L
s
[(80)] .78379 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(100)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.06229 .30902 m
.06229 .31277 L
s
.11039 .30902 m
.11039 .31277 L
s
.15849 .30902 m
.15849 .31277 L
s
.25469 .30902 m
.25469 .31277 L
s
.30279 .30902 m
.30279 .31277 L
s
.35089 .30902 m
.35089 .31277 L
s
.44709 .30902 m
.44709 .31277 L
s
.49519 .30902 m
.49519 .31277 L
s
.54329 .30902 m
.54329 .31277 L
s
.63949 .30902 m
.63949 .31277 L
s
.68759 .30902 m
.68759 .31277 L
s
.73569 .30902 m
.73569 .31277 L
s
.83189 .30902 m
.83189 .31277 L
s
.87999 .30902 m
.87999 .31277 L
s
.92809 .30902 m
.92809 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.01419 .01961 m
.02044 .01961 L
s
[(-0.2)] .00169 .01961 1 0 Mshowa
.01419 .16431 m
.02044 .16431 L
s
[(-0.1)] .00169 .16431 1 0 Mshowa
.01419 .45372 m
.02044 .45372 L
s
[(0.1)] .00169 .45372 1 0 Mshowa
.01419 .59842 m
.02044 .59842 L
s
[(0.2)] .00169 .59842 1 0 Mshowa
.125 Mabswid
.01419 .04855 m
.01794 .04855 L
s
.01419 .07749 m
.01794 .07749 L
s
.01419 .10643 m
.01794 .10643 L
s
.01419 .13537 m
.01794 .13537 L
s
.01419 .19326 m
.01794 .19326 L
s
.01419 .2222 m
.01794 .2222 L
s
.01419 .25114 m
.01794 .25114 L
s
.01419 .28008 m
.01794 .28008 L
s
.01419 .33796 m
.01794 .33796 L
s
.01419 .3669 m
.01794 .3669 L
s
.01419 .39584 m
.01794 .39584 L
s
.01419 .42478 m
.01794 .42478 L
s
.01419 .48266 m
.01794 .48266 L
s
.01419 .5116 m
.01794 .5116 L
s
.01419 .54054 m
.01794 .54054 L
s
.01419 .56948 m
.01794 .56948 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
.5 Mabswid
.02381 .30902 m
.03343 .33293 L
.04305 .3258 L
.05267 .29552 L
.06229 .30764 L
.07191 .2931 L
.08153 .31667 L
.09115 .29103 L
.10077 .27861 L
.11039 .30877 L
.12001 .26786 L
.12963 .30184 L
.13925 .30263 L
.14887 .28545 L
.15849 .23725 L
.16811 .34568 L
.17773 .27583 L
.18735 .3371 L
.19697 .29224 L
.20659 .31728 L
.21621 .60332 L
.22583 .29194 L
.23545 .29732 L
.24507 .28846 L
.25469 .32653 L
.26431 .3064 L
.27393 .27911 L
.28355 .31295 L
.29317 .38391 L
.30279 .31985 L
.31241 .30754 L
.32203 .29941 L
.33165 .31397 L
.34127 .35471 L
.35089 .33204 L
.36051 .30595 L
.37013 .30426 L
.37975 .32938 L
.38937 .29328 L
.39899 .27284 L
.40861 .27985 L
.41823 .33827 L
.42785 .30942 L
.43747 .31987 L
.44709 .31116 L
.45671 .28679 L
.46633 .27935 L
.47595 .33048 L
.48557 .3535 L
.49519 .32496 L
Mistroke
.50481 .30902 L
.51443 .29307 L
.52405 .26453 L
.53367 .28756 L
.54329 .33868 L
.55291 .33124 L
.56253 .30688 L
.57215 .29816 L
.58177 .30861 L
.59139 .27977 L
.60101 .33819 L
.61063 .34519 L
.62025 .32475 L
.62987 .28865 L
.63949 .31377 L
.64911 .31209 L
.65873 .286 L
.66835 .26332 L
.67797 .30406 L
.68759 .31863 L
.69721 .31049 L
.70683 .29818 L
.71645 .23412 L
.72607 .30508 L
.73569 .33892 L
.74531 .31164 L
.75493 .2915 L
.76455 .32957 L
.77417 .32072 L
.78379 .3261 L
.79341 .01472 L
.80303 .30076 L
.81265 .32579 L
.82227 .28093 L
.83189 .3422 L
.84151 .27236 L
.85113 .38078 L
.86075 .33258 L
.87037 .3154 L
.87999 .31619 L
.88961 .35017 L
.89923 .30927 L
.90885 .33942 L
.91847 .327 L
.92809 .30136 L
.93771 .32494 L
.94733 .3104 L
.95695 .32252 L
.96657 .29223 L
.97619 .28511 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6
Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6
Ool000aoo`8000Moo`<000Aoo`H000Ioo`03001oogoo0?moobmoo`03001oogoo05Aoo`002goo00@0
07ooOol000Ioo`<000Eoo`05001oogooOol00006Ool00`00Oomoo`3oOol_Ool00`00Oomoo`1DOol0
00Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Moo`@00?moobioo`03001o
ogoo05Aoo`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo
00<007ooOol0ogoo;goo00<007ooOol0E7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol_Ool00`00Oomoo`1DOol000Yoo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Aoo`03001oogoo0?moobmoo`03001oogoo05Aoo`002Woo00<007ooOol00Woo
00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogoo;goo00<007ooOol0E7oo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogoo;goo00<007ooOol0E7oo
000<Ool2000?Ool40007Ool00`00Oomoo`3oOol_Ool00`00Oomoo`1DOol002Qoo`03001oogoo0?mo
obmoo`03001oogoo05Aoo`00:7oo00<007ooOol0ogoo;goo00<007ooOol0E7oo000XOol00`00Oomo
o`3oOol_Ool00`00Oomoo`1DOol002Qoo`03001oogoo0?moobmoo`03001oogoo05Aoo`00:7oo00<0
07ooOol0ogoo;goo00<007ooOol0E7oo000XOol3003oOol_Ool00`00Oomoo`1DOol002Qoo`03001o
ogoo0?moobmoo`8005Eoo`00:7oo00<007ooOol0ogoo;goo0P00EGoo000XOol00`00Oomoo`3oOol_
Ool2001EOol002Qoo`03001oogoo0?moobmoo`8005Eoo`00:7oo00<007ooOol0ogoo;goo0P00EGoo
000XOol00`00Oomoo`3oOol_Ool2001EOol002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00
:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00Ool0001E
Ool002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00:7oo0`00ogoo;Woo00<007oo0000EGoo
000XOol00`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001oogoo0?moobioo`03001oo`00
05Eoo`00:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00
Ool0001EOol002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00:7oo00<007ooOol0ogoo;Woo
00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001oogoo0?mo
obioo`03001oo`0005Eoo`00:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol00`00Oomo
o`3oOol^Ool00`00Ool0001EOol002Qoo`<00?moobioo`03001oo`0005Eoo`00:7oo00<007ooOol0
ogoo;Woo00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001o
ogoo0?moobioo`03001oo`0005Eoo`00:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol0
0`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00
:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol0
05Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@0
07ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo0`00ogoo;Woo00@0
07ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo
;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007oo
Ool0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo
00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Ao
o`0037oo0P001goo0`001Goo1@001Woo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`002goo00@0
07ooOol000Ioo`<000Moo`03001oogoo00Ioo`03001oogoo0?moobioo`04001oogoo001DOol000Yo
o`03001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Ioo`03001oogoo0?moobioo`04
001oogoo001DOol00003Ool0000000D0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo
00Ioo`@00?moobeoo`04001oogoo001DOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00Ioo`03001oogoo0?moobioo`04001oogoo001DOol000Yoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo00Ioo`03001oogoo0?moobioo`04001oogoo001DOol000Yoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo0?moobeoo`05001oogooOol0001DOol000]o
o`04001oogoo000>Ool30008Ool00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000<Ool2000@
Ool20008Ool00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool0
1@00Oomoogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol00`00
Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool01@00Oomoogoo0000
E7oo000XOol00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol3003oOol]Ool01@00Oomo
ogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool00`00Oomoo`02Ool00`00Oomoo`1AOol002Qoo`03
001oogoo0?moobeoo`03001oogoo009oo`03001oogoo055oo`00:7oo00<007ooOol0ogoo;Goo00<0
07ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`3oOol]Ool00`00Oomoo`02Ool00`00Oomo
o`1AOol002Qoo`03001oogoo0?moobeoo`03001oogoo009oo`03001oogoo055oo`00:7oo00<007oo
Ool0ogoo;Goo00<007ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`3oOol]Ool00`00Oomo
o`02Ool00`00Oomoo`1AOol002Qoo`03001oogoo0?moobeoo`03001oogoo009oo`03001oogoo055o
o`00:7oo00<007ooOol0ogoo;Goo00<007ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`3o
Ool]Ool00`00Oomoo`02Ool00`00Oomoo`1AOol002Qoo`03001oogoo0?moobeoo`03001oogoo009o
o`03001oogoo055oo`00:7oo0`00ogoo;Goo00<007ooOol00Woo00<007ooOol0DGoo000XOol00`00
Oomoo`3oOol]Ool00`00Oomoo`02Ool00`00Oomoo`1AOol002Qoo`03001oogoo0?moobeoo`03001o
ogoo009oo`03001oogoo055oo`00:7oo00<007ooOol0ogoo;Goo00<007ooOol00Woo00<007ooOol0
DGoo000XOol00`00Oomoo`3oOolAOol00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`1AOol0
02Qoo`03001oogoo03Ioo`03001oogoo0=Moo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo
055oo`00:7oo00<007ooOol0=Woo00<007ooOol0egoo00<007ooOol06Goo00<007ooOol00Woo00<0
07ooOol0DGoo000XOol00`00Oomoo`0fOol00`00Oomoo`3GOol00`00Oomoo`0IOol00`00Oomoo`02
Ool00`00Oomoo`1AOol002Qoo`03001oogoo03Eoo`800=Uoo`8001Yoo`03001oogoo009oo`03001o
ogoo055oo`00:7oo00<007ooOol0=Goo0P00f7oo00<007oo00006Woo00<007ooOol00Woo00<007oo
Ool0DGoo000XOol00`00Oomoo`0eOol2003HOol00`00Ool0000JOol00`00Oomoo`02Ool00`00Oomo
o`1AOol002Qoo`<003Eoo`03001oo`000=Moo`03001oo`0001Yoo`03001oogoo009oo`03001oogoo
055oo`00:7oo00<007ooOol0=Goo00<007oo0000egoo00<007oo00006Woo00<007ooOol00Woo00<0
07ooOol0DGoo000XOol00`00Oomoo`0dOol01000Oomoo`00egoo00<007oo00006Woo00<007ooOol0
0Woo00<007ooOol0DGoo000XOol00`00Oomoo`0dOol01000Oomoo`00egoo00<007oo00006Woo00<0
07ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`0dOol01000Oomoo`00egoo00@007ooOol0
01Uoo`03001oogoo009oo`03001oogoo055oo`00:7oo00<007ooOol0=7oo00@007ooOol008eoo`03
001oogoo03Eoo`03001oogoo00moo`04001oogoo000IOol00`00Oomoo`02Ool00`00Oomoo`1AOol0
02Qoo`03001oogoo02Moo`03001oogoo00Yoo`04001oogoo002=Ool00`00Oomoo`0eOol00`00Oomo
o`0>Ool01@00Oomoogoo00006Goo00<007ooOol00goo00<007ooOol0D7oo000XOol00`00Oomoo`0W
Ool00`00Oomoo`09Ool01@00Oomoogoo0000S7oo00<007oo0000=Goo0P0047oo00D007ooOomoo`00
01Uoo`03001oogoo00=oo`03001oogoo051oo`00:7oo00<007ooOol09goo00<007ooOol02Goo00D0
07ooOomoo`0000Uoo`H000Eoo`80045oo`<0009oo`800003Ool0000002]oo`03001oo`00015oo`@0
00Ioo`8001Qoo`03001oo`0000moo`05001oogooOol0000AOol40004Ool01000Ool000000Woo00<0
07ooOol037oo00<007ooOol09goo1@001Goo0P001goo0P001Goo000XOol00`00Oomoo`0VOol00`00
Ool0000:Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000Aoo`04001oogoo0011Ool01`00Oomo
ogoo001oo`00009oo`03001oogoo02Qoo`04001oogoo000?Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`005goo00<007oo00003goo00D007ooOomoo`00011oo`03001oogoo009oo`04001o
ogooOol20002Ool00`00Ool0000>Ool00`00Oomoo`0YOol00`00Oomoo`04Ool01000Oomoo`001Goo
00@007ooOol000Aoo`00:7oo00<007ooOol09Woo00<007oo00002Woo00D007ooOomoo`0000Eoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo03Yoo`H00006Ool007oo001o
o`000Woo00<007ooOol09Woo00D007ooOomoo`0000moo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0COol01000Oomoo`003goo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo008000Aoo`8000ioo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool002Qoo`<001moo`03001oogoo00Aoo`03001oo`0000Yoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo015oo`03001oogoo02Ioo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool0000COol0
0`00Oomoo`0BOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol00P0017oo00<007oo
Ool04goo00@007ooOol000moo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001o
ogoo008000Aoo`8000ioo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool002Qoo`03001oogoo01moo`03001oogoo00Aoo`04001oogoo0008
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol00`00Oomoo`0WOol01P00Oomoo`00Ool0009oo`06001oogoo001oo`004Woo
0P0057oo00<007ooOol00Woo00<007ooOol037oo0P000goo00<007ooOol00P0017oo00<007ooOol0
4goo00D007ooOomoo`0000ioo`03001oogoo009oo`03001oogoo00ioo`@000=oo`8000Aoo`8000Mo
o`03001oogoo00Aoo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`01Ool002Qoo`03001oogoo01ioo`03001oo`0000Aoo`05001oogooOol00008
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo000017oo00<007oo
Ool047oo0P00:Woo00D007oo001oo`00009oo`06001oogoo001oo`004Goo00<007oo00004goo00<0
07ooOol00goo00<007ooOol037oo00<007oo00000P000goo0P0017oo00<007ooOol04Woo00<007oo
Ool00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007oo
Ool00P0017oo0P001goo00<007ooOol017oo00<007ooOol0:Goo00<007ooOol00goo00H007oo0000
07oo0003Ool00`00Oomoo`02Ool00`00Oomoo`01Ool002Qoo`03001oogoo01eoo`04001oogoo0004
Ool01@00Oomoogoo000027oo00<007ooOol00goo00<007ooOol00Woo0P001goo00D007ooOomoo`00
00Aoo`03001oogoo011oo`03001oo`0002Uoo`04001oo`000003Ool01P00Oomoo`00Ool0011oo`05
001oogooOol0000BOol00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool30004Ool00`00
Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`020004Ool20007Ool00`00Oomoo`03Ool00`00Ool0000ZOol00`00Oomo
o`03Ool20003Ool01@00Oomoogoo000017oo00<007ooOol00Goo000XOol00`00Oomoo`0MOol01000
Oomoo`0017oo00D007ooOomoo`0000Moo`03001oogoo00Aoo`07001oogooOol007oo00000Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Qoo`8000Uoo`03001oo`0002Yoo`<000Aoo`04
001oogoo000AOol01@00Oomoogoo00004Woo00<007ooOol017oo00<007ooOol037oo0P0017oo00@0
07oo0000009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00eoo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo0000
1Woo0P001Goo00<007oo0000:7oo0`001Goo0P000Woo00<007ooOol00goo00@007ooOol000Aoo`00
:7oo00<007ooOol057oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`07001oogooOol007oo00000goo10001Woo0P000Woo0P0017oo00<0
07oo000027oo00@007ooOol002]oo`03001oogoo00Aoo`<0011oo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Eoo`03001oogoo00ioo`<00005Ool007oo001oo`02000:Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool40003Ool00`00Oomoo`020002Ool00`00Oomoo`04Ool00`00Ool00004Ool00`00Ool0000YOol2
0004Ool00`00Oomoo`020007Ool20005Ool002Qoo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01`00
Oomoogoo001oo`0000Ioo`03001oogoo00Qoo`06001oo`00001oo`000Woo00<007ooOol01Woo00D0
07ooOomoo`0002Yoo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00mo
o`03001oogoo00Ioo`03001oogoo011oo`04001oogoo000=Ool20009Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Ool00004Ool00`00Ool0000_Ool00`00Oomoo`0@Ool002Qoo`03001oogoo00ao
o`03001oogoo00Aoo`03001oo`0000Eoo`03001oogoo00=oo`04001oogoo0005Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`0000Ioo`8000Uoo`05001oogooOol00004Ool00`00
Oomoo`05Ool01@00Oomoogoo0000:Woo00<007ooOol01Woo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol00Woo00@007ooOol000ao
o`03001oo`0000Uoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Mo
o`8000]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oo`0000Aoo`03001oo`0002ioo`03001o
ogoo015oo`00:7oo00<007ooOol037oo0P0017oo00@007ooOol000Eoo`03001oogoo00Aoo`03001o
o`0000Ioo`05001oogooOol00008Ool01`00Oomoogoo001oo`0000Eoo`03001oo`0000Uoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00eoo`8001Qoo`03001oogoo00Mo
o`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00Yo
o`03001oo`0000=oo`04001oogoo000<Ool01000Oomoo`001goo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol017oo00<007ooOol01goo00<007oo00002Woo00<007ooOol017oo00<007ooOol0
0goo00@007ooOol000Aoo`03001oo`0002ioo`03001oogoo015oo`00:7oo00<007ooOol02goo00@0
07ooOol000=oo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Ool00006Ool40009Ool01@00Oomo
ogoo00000Woo00<007ooOol00Woo00<007oo00002Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol02goo00<007oo000067oo00<007ooOol01goo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol037oo00<007ooOol027oo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo000<Ool01000Oomoo`001goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
1Goo00<007ooOol01goo00<007oo00002Woo00<007ooOol017oo00<007ooOol00goo00@007ooOol0
00Aoo`03001oo`00021oo`03001oogoo00]oo`03001oogoo015oo`00:7oo00<007ooOol02goo00L0
07ooOomoo`00Ool00004Ool01@00Oomoogoo00001goo0P0057oo00D007ooOomoo`00009oo`03001o
ogoo009oo`04001oogoo0008Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`0:Ool01@00Oomoogoo00003Goo1@001Goo00<007ooOol027oo00<007ooOol02goo00<007oo
Ool01Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol00goo0P0017oo
00<007ooOol02Goo00@007ooOol000Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Ioo`04001oogoo000:Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007oo000087oo00<007ooOol02Woo00<007ooOol04Woo000XOol00`00Oomoo`0;Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol04goo00@007ooOol0009o
o`03001oogoo009oo`04001oogoo0008Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo00<007oo
Ool027oo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol02Woo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol02Goo00D007ooOomoo`0000Eoo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`04001oogoo000:Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo00007goo00<007oo0000
2goo00<007ooOol04Woo000SOooo00290005Ool002Qoo`05001oogooOol00008Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Ool00009Ool00`00Oomoo`0@Ool01P00Oomoo`00Ool000=oo`05001o
ogooOol00004Ool20006Ool00`00Oomoo`07Ool01@00Ool007oo000027oo00<007ooOol017oo00@0
07ooOol000Moo`03001oogoo00Eoo`04001oogoo0005Ool01@00Oomoogoo00001Goo00<007ooOol0
0goo00<007ooOol00Woo0P001Goo0P002Goo00<007ooOol01Woo00@007ooOol000eoo`03001oo`00
00Eoo`03001oogoo00Uoo`03001oo`0000Yoo`03001oogoo00=oo`D000aoo`05001oo`00Ool0000=
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00@007ooOol0
00Aoo`04001oo`000002Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`07Ool200000goo
001oo`04Ool01@00Oomoogoo00001Woo00<007ooOol037oo000XOol00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Ool0000OOol00`00Ool00003Ool01@00Oomoogoo000017oo0P00
1Woo00<007ooOol027oo00@007ooOol000Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Ool00003Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Ool0000:Ool00`00Oomoo`0EOol00`00Ool0000>Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`06Ool01000Oomoo`0017oo00@007ooOol000=oo`03
001oogoo00Moo`@000Moo`8000Moo`05001oogooOol00004Ool00`00Ool00002Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool002Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00]oo`03001o
ogoo01ioo`03001oo`0000Aoo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00
Ool00009Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01000
Oomoo`0037oo00@007ooOol000=oo`03001oo`0000aoo`03001oogoo00Qoo`03001oogoo00aoo`03
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Ioo`03001oogoo00eoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oo`0000Aoo`04
001oogoo0003Ool00`00Oomoo`07Ool01000Oomoo`001Woo00<007oo00001goo00D007ooOomoo`00
00=oo`07001oogooOol007oo00005Goo000XOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`0/Ool00`00Ool00004Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol027oo00<007oo
00002Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Goo00@007oo
Ool000aoo`04001oogoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00
Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`07Ool00`00Ool00004Ool01000Oomoo`00
0goo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001oo`0000Ioo`03001oogoo00=oo`04001o
ogoo0003Ool2000FOol002Qoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo02eoo`03001o
o`0000Aoo`03001oo`0000Ioo`03001oogoo00Aoo`03001oogoo00Uoo`8000Yoo`03001oogoo00=o
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oo`0000aoo`04001oogoo000B
Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`06
Ool00`00Oomoo`0XOol00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo0`002Goo
0P001Woo00<007oo00000goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo00@007oo
Ool000Eoo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo01Aoo`00:7oo00<007ooOol00goo
00<007ooOol00Woo0P00;goo00<007oo000017oo00<007oo00001Woo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool01goo0P003Goo00<007oo000057oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol01Woo00<007ooOol0:7oo00D007ooOomoo`0000Moo`04001oogoo
0005Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Ool00003Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol06goo000XOol0
0`00Oomoo`04Ool01000Oomoo`00<Goo00<007oo000017oo00<007oo00001Woo00<007ooOol017oo
00<007ooOol05Goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol01goo
0P003Goo00<007oo000057oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol01Woo00<007ooOol0:Goo00@007ooOol000Qoo`8001Qoo`03001oo`0000=o
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`0SOol002Qoo`03001oogoo00Aoo`03001oo`00039oo`03001oo`0000Aoo`03001oo`0000Ioo`03
001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Qoo`03001oogoo00]oo`03001oo`0001Aoo`03001oogoo00Aoo`03001oogoo011oo`05
001oogooOol0000AOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Ool00009Ool00`00Oomoo`0G
Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0002Eoo`00:7oo00<007ooOol01Goo00<007ooOol0<Goo00<007oo00001Goo0P001Woo00<0
07ooOol00goo00<007ooOol05Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol067oo0P0057oo00<007ooOol017oo00<007ooOol04Goo00<007oo00004goo00<007ooOol0
17oo00<007ooOol0:Woo00<007oo00008goo0P0017oo00<007ooOol00goo00<007ooOol01Woo00D0
07ooOomoo`0000Aoo`04001oogoo000VOol002Qoo`03001oogoo03Yoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo01Qoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo015oo`8001Ao
o`03001oogoo00=oo`03001oogoo02aoo`8002=oo`8000Aoo`03001oogoo00=oo`03001oogoo00Io
o`05001oogooOol00004Ool00`00Ool0000WOol002Qoo`<003Yoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo00aoo`05001oogoo
Ool0000KOol00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0COol20004
Ool00`00Oomoo`0/Ool00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06
Ool01000Oomoo`001Woo00<007ooOol09Woo000XOol00`00Oomoo`0jOol00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`0GOol01@00Oomoogoo00003Woo00D007ooOomoo`0003=oo`05001oogoo
Ool0000/Ool01000Oomoo`00EGoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<0
07oo0000;goo000XOol00`00Oomoo`0jOol00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0G
Ool01@00Oomoogoo00003Woo00@007ooOol003Aoo`05001oogooOol0000]Ool00`00Ool0001EOol0
0`00Oomoo`03Ool01@00Oomoogoo00002Woo00<007oo0000;goo000XOol00`00Oomoo`0jOol00`00
Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0GOol01@00Oomoogoo00003Woo00@007ooOol003Ao
o`04001oogoo000_Ool00`00Oomoo`1JOol01@00Oomoogoo00002Woo00<007oo0000;goo000XOol0
0`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0GOol01@00Oomoogoo00003goo0P00=Woo00<0
07oo0000S7oo00D007ooOomoo`0000]oo`03001oogoo02ioo`00:7oo00<007ooOol0BGoo00<007oo
Ool00goo00<007ooOol05goo00D007ooOomoo`0000moo`8003Ioo`03001oo`0008aoo`05001oogoo
Ool0000;Ool00`00Oomoo`0^Ool002Qoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo01Mo
o`04001oogoo000@Ool00`00Oomoo`0fOol00`00Oomoo`2;Ool01000Oomoo`00?Goo000XOol00`00
Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0GOol01000Oomoo`00egoo00@007ooOol003eoo`00
:7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000egoo00@007ooOol0
03eoo`00:7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000egoo00@0
07ooOol003eoo`00:7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000
egoo00@007ooOol003eoo`00:7oo0`00BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000
egoo00<007oo0000?Woo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00
Ool0003GOol00`00Ool0000nOol002Qoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo01Qo
o`03001oo`000=Qoo`8003ioo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007ooOol067oo
00<007oo0000f7oo0P00?Woo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
0`00Oomoo`3GOol2000nOol002Qoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo01Uoo`03
001oogoo0=Moo`03001oogoo03eoo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007ooOol0
6Goo00<007ooOol0egoo00<007ooOol0?Goo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol00`00Oomoo`3oOolHOol002Qoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo
0?moocAoo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007ooOol0ogoo=7oo000XOol00`00
Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`3oOoldOol002Qoo`03001oogoo04Yoo`03001oogoo
009oo`03001oogoo0?moocAoo`00:7oo0`00BWoo00<007ooOol00Woo00<007ooOol0ogoo=7oo000X
Ool00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`3oOoldOol002Qoo`03001oogoo04Yoo`03
001oogoo009oo`03001oogoo0?moocAoo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007oo
Ool0ogoo=7oo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`3oOoldOol002Qoo`03
001oogoo04Yoo`03001oogoo009oo`03001oogoo0?moocAoo`00:7oo00<007ooOol0BWoo00D007oo
Oomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007oo
Ool0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMo
o`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo0`00BWoo00D007ooOomoo`00
0?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo
00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo
00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`00
0?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo
00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`0037oo
0P001goo0`001Goo1@001Woo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`002goo00@007oo
Ool000Ioo`<000Moo`03001oogoo00Ioo`03001oogoo04Yoo`05001oogooOol0003oOolgOol000Yo
o`03001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Ioo`@004Uoo`05001oogooOol0
003oOolgOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo04Yo
o`05001oogooOol0003oOolgOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Io
o`03001oogoo04Yoo`05001oogooOol0003oOolgOol000Yoo`03001oogoo009oo`03001oogoo00eo
o`03001oogoo00Ioo`03001oogoo04Yoo`05001oogooOol0003oOolgOol000Yoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo04]oo`04001oogoo003oOolgOol000]oo`04
001oogoo000>Ool30008Ool00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000<Ool2000@Ool20008
Ool00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool01000Oomoo`00ogoo
=goo000XOol00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool01000Oomo
o`00ogoo=goo000XOol00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool0
1000Oomoo`00ogoo=goo000XOol3001;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool0
1000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo
04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00
Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo
00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol0
02Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo
>7oo000XOol3001;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQo
o`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003o
OolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo
0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03
001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;
Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo0`00Bgoo
00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo
04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00
Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo
00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1<Ool2003oOolhOol002Qoo`03
001oogoo04aoo`800?moocQoo`00:7oo00<007ooOol0C7oo0P00ogoo>7oo000XOol00`00Oomoo`1<
Ool2003oOolhOol002Qoo`03001oogoo04aoo`03001oogoo0?moocMoo`00:7oo0`00C7oo00<007oo
Ool0ogoo=goo000XOol00`00Oomoo`1<Ool00`00Oomoo`3oOolgOol002Qoo`03001oogoo04aoo`03
001oogoo0?moocMoo`00:7oo00<007ooOol0C7oo00<007ooOol0ogoo=goo000XOol00`00Oomoo`1<
Ool00`00Oomoo`3oOolgOol002Qoo`03001oogoo04aoo`03001oogoo0?moocMoo`00:7oo00<007oo
Ool0C7oo00<007ooOol0ogoo=goo000XOol00`00Oomoo`1<Ool00`00Oomoo`3oOolgOol000aoo`80
00Moo`<000Aoo`H000Ioo`03001oogoo04aoo`03001oogoo0?moocMoo`002goo00@007ooOol000Io
o`<000Eoo`05001oogooOol00006Ool00`00Oomoo`1<Ool00`00Oomoo`3oOolgOol000Yoo`03001o
ogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Moo`03001oogoo04aoo`03001oogoo0?mo
ocMoo`002Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo1000Bgoo00<007ooOol0
ogoo=goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool0
0`00Oomoo`3oOolgOol000Yoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03001o
ogoo04aoo`03001oogoo0?moocMoo`002Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
17oo00<007ooOol0ogooQWoo000;Ool01000Oomoo`003Goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol0ogooQWoo000<Ool2000?Ool40007Ool00`00Oomoo`3oOon6Ool002Qoo`03001oogoo
0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-10, 0, 0, 0}}]
}, Open  ]],

Cell[TextData[{
  "Evidently, the two peaks in the real and imaginary parts of the spectrum \
correspond to the two Fourier components of ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(sin(40  \[DoubledPi]\ t)\), " ", "=", " ", 
          
          FormBox[\(\((\[ExponentialE]\^\(\(40\)\(\ \)\(\[Pi]\)\(\ \)\(\
\[ImaginaryI]\)\(\ \)\(t\)\(\ \)\) - \ \[ExponentialE]\^\(\(-40\)\ \[Pi]\ \
\[ImaginaryI]\ t\))\)/2\ \[ImaginaryI]\),
            "TraditionalForm"]}], TraditionalForm]]],
  ".  These components have frequencies of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]40\)\ \[Pi]\)]],
  ".  Since the frequency is discretized in units of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] = \(2\ \[Pi]/\((N\ \
\[CapitalDelta]t)\) = 2\ \[Pi]\)\)]],
  ", the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`40\ \[Pi]\)]],
  " corresponds to the 21st element of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f\&~\),
          FontWeight->"Bold"], TraditionalForm]]],
  " (since \[Omega]=0 corresponds to the first element). This agrees with the \
plots, which show a peak at the 21st element. "
}], "Text"],

Cell[TextData[{
  "\tWhat about the other peak, which is supposed to occur at ",
  Cell[BoxData[
      \(TraditionalForm\`\(-40\)\ \[Pi]\)]],
  "? There are no negative frequencies in our spectrum. Rather, frequencies \
run from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`\((N - 1)\) \[CapitalDelta]\[Omega]\)]],
  " in units of ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega] = 2\ \[Pi]\)]],
  ". Recall, however, that ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f\&~\),
          FontWeight->"Bold"], TraditionalForm]]],
  " is periodic with period ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ", [see Eq. ",
  ButtonBox["(2.3.60)",
    ButtonData:>"(2.3.60)",
    ButtonStyle->"Hyperlink"],
  "].  In particular, it repeats over the negative frequency range. So we can \
think of the second peak in the plots, at element 80 of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f\&~\),
          FontWeight->"Bold"], TraditionalForm]]],
  ", as actually being at a negative frequency. Since ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_100 = f\&~\_0\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_80 = f\&~\_\(-20\)\)]],
  ", corresponding to the spectral component with frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\(-20\)\ \[CapitalDelta]\[Omega]\  = \ \(-40\)\ \
\[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tThus, the upper half of the frequency spectrum should be thought of as \
corresponding to negative frequencies. This implies that as we count upwards \
through the elements of our frequency spectrum, starting with the first \
element, the frequency increases  like ",
  Cell[BoxData[
      \(TraditionalForm\`m\ \[CapitalDelta]\[Omega]\)]],
  " ",
  StyleBox["until we get to the center of the spectrum. ",
    FontSlant->"Italic"],
  "At this point the frequency jumps to negative values and approaches zero \
from the negative side. Therefore, the maximum frequency ",
  StyleBox["magnitude ",
    FontSlant->"Italic"],
  "kept in our spectrum is  "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_max\), "=", 
          RowBox[{\(N\ \[CapitalDelta]\[Omega]/2\), "=", 
            RowBox[{"\[Pi]", "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " "}]}]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(2.3.65)"],

Cell[TextData[{
  "The frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_max\)]],
  " is called the ",
  StyleBox["Nyquist frequency",
    FontSlant->"Italic"],
  " for the data. The physical reason why this is the maximum frequency in a \
set of data can be understood from Fig. ",
  ButtonBox["2.10",
    ButtonData:>"Fig. 2.10",
    ButtonStyle->"Hyperlink"],
  ", which displays some time data. The highest-frequency sinusoidal wave \
that we can interpolate through these data points has a ",
  StyleBox["half period",
    FontSlant->"Italic"],
  " equal to \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ": one needs at least two points to determine a sine wave, one at a minimum \
at one at a neighboring maximum. Thus, the minimum full period defined by the \
data is 2\[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", and the maximum frequency is given by the Nyquist frequency ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_max\), "=", 
          RowBox[{"2", " ", 
            RowBox[{"\[Pi]", "/", 
              RowBox[{"(", 
                RowBox[{"2", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]]}], ")"}]}]}]}], 
        TraditionalForm]]],
  ", Eq. ",
  ButtonBox["(2.3.65)",
    ButtonData:>"(2.3.65)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:55"],

Cell[TextData[{
  "\tMore rapid oscillations, with frequency  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_max + \ 
          p\ N\ \[CapitalDelta]\[Omega] = \((2  p + 1)\) \[Omega]\_max\)]],
  ", for any integer ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " can also be made to go through these points as well - see the dashed \
curve in Fig. ",
  ButtonBox["2.10",
    ButtonData:>"Fig. 2.10",
    ButtonStyle->"Hyperlink"],
  ", which corresponds to ",
  Cell[BoxData[
      \(TraditionalForm\`p = 1\)]],
  ". However, since these higher-frequency oscillations can always be \
referred back to the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_max\)]],
  ", we use ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_max\)]],
  "to describe them - there is nothing in the data to distinguish them from \
an oscillation at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_max\)]],
  ". The identification of  higher frequencies with a lower frequency is \
called ",
  StyleBox["aliasing. ",
    FontSlant->"Italic"],
  "This identification arises from the discreteness of the data - there are \
no data points in between the given data points  that can determine the \
locations of the peaks and troughs in the dashed curve."
}], "Text",
  CellTags->"i:111"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.190476 0.132539 0.141188 [
[.21429 .12004 -3 -9 ]
[.21429 .12004 3 0 ]
[.40476 .12004 -3 -9 ]
[.40476 .12004 3 0 ]
[.59524 .12004 -3 -9 ]
[.59524 .12004 3 0 ]
[.78571 .12004 -3 -9 ]
[.78571 .12004 3 0 ]
[.97619 .12004 -3 -9 ]
[.97619 .12004 3 0 ]
[1.025 .13254 0 -6 ]
[1.025 .13254 10 6 ]
[.01131 .27373 -6 -4.5 ]
[.01131 .27373 0 4.5 ]
[.01131 .41492 -6 -4.5 ]
[.01131 .41492 0 4.5 ]
[.01131 .5561 -6 -4.5 ]
[.01131 .5561 0 4.5 ]
[.02381 .64303 -7.625 0 ]
[.02381 .64303 7.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .13254 m
.21429 .13879 L
s
[(1)] .21429 .12004 0 1 Mshowa
.40476 .13254 m
.40476 .13879 L
s
[(2)] .40476 .12004 0 1 Mshowa
.59524 .13254 m
.59524 .13879 L
s
[(3)] .59524 .12004 0 1 Mshowa
.78571 .13254 m
.78571 .13879 L
s
[(4)] .78571 .12004 0 1 Mshowa
.97619 .13254 m
.97619 .13879 L
s
[(5)] .97619 .12004 0 1 Mshowa
.125 Mabswid
.0619 .13254 m
.0619 .13629 L
s
.1 .13254 m
.1 .13629 L
s
.1381 .13254 m
.1381 .13629 L
s
.17619 .13254 m
.17619 .13629 L
s
.25238 .13254 m
.25238 .13629 L
s
.29048 .13254 m
.29048 .13629 L
s
.32857 .13254 m
.32857 .13629 L
s
.36667 .13254 m
.36667 .13629 L
s
.44286 .13254 m
.44286 .13629 L
s
.48095 .13254 m
.48095 .13629 L
s
.51905 .13254 m
.51905 .13629 L
s
.55714 .13254 m
.55714 .13629 L
s
.63333 .13254 m
.63333 .13629 L
s
.67143 .13254 m
.67143 .13629 L
s
.70952 .13254 m
.70952 .13629 L
s
.74762 .13254 m
.74762 .13629 L
s
.82381 .13254 m
.82381 .13629 L
s
.8619 .13254 m
.8619 .13629 L
s
.9 .13254 m
.9 .13629 L
s
.9381 .13254 m
.9381 .13629 L
s
.25 Mabswid
0 .13254 m
1 .13254 L
s
gsave
1.025 .13254 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .27373 m
.03006 .27373 L
s
[(1)] .01131 .27373 1 0 Mshowa
.02381 .41492 m
.03006 .41492 L
s
[(2)] .01131 .41492 1 0 Mshowa
.02381 .5561 m
.03006 .5561 L
s
[(3)] .01131 .5561 1 0 Mshowa
.125 Mabswid
.02381 .16078 m
.02756 .16078 L
s
.02381 .18901 m
.02756 .18901 L
s
.02381 .21725 m
.02756 .21725 L
s
.02381 .24549 m
.02756 .24549 L
s
.02381 .30196 m
.02756 .30196 L
s
.02381 .3302 m
.02756 .3302 L
s
.02381 .35844 m
.02756 .35844 L
s
.02381 .38668 m
.02756 .38668 L
s
.02381 .44315 m
.02756 .44315 L
s
.02381 .47139 m
.02756 .47139 L
s
.02381 .49963 m
.02756 .49963 L
s
.02381 .52787 m
.02756 .52787 L
s
.02381 .1043 m
.02756 .1043 L
s
.02381 .07606 m
.02756 .07606 L
s
.02381 .04783 m
.02756 .04783 L
s
.02381 .01959 m
.02756 .01959 L
s
.02381 .58434 m
.02756 .58434 L
s
.02381 .61258 m
.02756 .61258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -68.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
74.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.02 w
.02381 .27373 Mdot
.21429 .06194 Mdot
.40476 .41492 Mdot
.59524 .20313 Mdot
.78571 .5561 Mdot
.97619 .34432 Mdot
1 0 0 r
.5 Mabswid
[ .05 .02 ] 0 setdash
.02381 .27373 m
.02499 .27392 L
.02605 .27369 L
.02729 .27293 L
.02846 .27173 L
.02954 .27022 L
.03053 .26848 L
.03279 .26336 L
.03506 .25659 L
.03756 .24739 L
.04262 .22385 L
.06244 .09966 L
.06782 .06834 L
.07293 .04379 L
.07574 .03308 L
.07723 .02833 L
.07881 .02401 L
.08028 .02072 L
.08161 .01834 L
.08225 .0174 L
.08294 .01654 L
.0842 .01539 L
.08547 .01478 L
.08666 .01472 L
.08796 .0152 L
.08869 .01573 L
.08936 .01638 L
.0907 .01814 L
.09216 .02074 L
.09481 .02731 L
.09727 .03542 L
.09989 .04605 L
.10458 .06982 L
.12427 .20588 L
.1329 .26233 L
.13778 .28771 L
.14233 .30545 L
.14472 .31221 L
.14689 .31671 L
.14809 .31852 L
.14939 .31993 L
.15062 .32072 L
.15175 .32099 L
.15294 .32079 L
.15405 .32017 L
.15527 .319 L
.15657 .3172 L
.15794 .3147 L
.15924 .31177 L
.16168 .30484 L
Mistroke
.16686 .28445 L
.17166 .25975 L
.18253 .19141 L
.19313 .12466 L
.19832 .09783 L
.2006 .08803 L
.2031 .07889 L
.2052 .07261 L
.20745 .06741 L
.2087 .06524 L
.20983 .06371 L
.21097 .06261 L
.21205 .06198 L
.21322 .06175 L
.21446 .06201 L
.21551 .06266 L
.21668 .06382 L
.21793 .06559 L
.21928 .06808 L
.22172 .07413 L
.22412 .08199 L
.22669 .09231 L
.23131 .11546 L
.2418 .18395 L
.25279 .26372 L
.26291 .32582 L
.2679 .34766 L
.27041 .35585 L
.27318 .3625 L
.27463 .36497 L
.27595 .3666 L
.27668 .36724 L
.27748 .36772 L
.27823 .36798 L
.27892 .36805 L
.28016 .36776 L
.28086 .36735 L
.28153 .36682 L
.28286 .3653 L
.28429 .36299 L
.28674 .35752 L
.28941 .3494 L
.29481 .32693 L
.30446 .27158 L
.31453 .20568 L
.32404 .15088 L
.3293 .1286 L
.33227 .11943 L
.33369 .11602 L
.33501 .1134 L
Mistroke
.33612 .11165 L
.33732 .11023 L
.338 .10964 L
.33864 .10922 L
.33985 .10883 L
.34113 .10896 L
.34231 .10958 L
.34361 .11081 L
.34433 .11176 L
.34499 .11276 L
.34731 .11751 L
.34987 .12478 L
.35502 .14554 L
.35979 .17114 L
.36425 .19936 L
.37494 .27613 L
.38507 .34575 L
.38981 .37244 L
.39483 .39453 L
.39745 .40307 L
.39884 .40671 L
.40034 .40992 L
.40171 .41218 L
.40297 .4137 L
.40417 .41464 L
.40544 .41509 L
.4066 .41501 L
.40766 .41454 L
.40888 .41352 L
.41003 .41209 L
.4111 .41038 L
.41208 .40846 L
.41431 .403 L
.41655 .39594 L
.41902 .38651 L
.424 .36276 L
.43483 .29661 L
.4451 .23047 L
.44956 .20534 L
.45432 .18317 L
.45705 .17306 L
.45953 .16579 L
.46073 .16296 L
.46202 .16042 L
.46324 .15853 L
.46436 .15724 L
.46554 .15633 L
.46662 .15593 L
.46786 .15595 L
.46903 .15646 L
Mistroke
.47012 .15736 L
.47112 .15855 L
.47222 .16024 L
.47338 .16249 L
.47581 .16862 L
.47809 .17609 L
.48327 .19883 L
.49287 .2576 L
.5032 .33251 L
.5133 .40032 L
.51902 .43018 L
.52175 .44137 L
.52433 .44983 L
.52678 .45589 L
.52816 .45843 L
.52943 .46019 L
.5305 .46125 L
.53168 .46195 L
.5329 .46218 L
.53405 .46192 L
.53469 .46157 L
.53539 .46104 L
.53667 .45964 L
.53791 .45775 L
.53905 .45556 L
.54165 .44902 L
.54442 .43982 L
.5493 .41849 L
.55378 .39422 L
.56388 .33 L
.57271 .27376 L
.57757 .24719 L
.58216 .22685 L
.58462 .21825 L
.58591 .21444 L
.58729 .21097 L
.58844 .20852 L
.58971 .20633 L
.59087 .2048 L
.59195 .20378 L
.59313 .20312 L
.59425 .20294 L
.59525 .20314 L
.59635 .20376 L
.59753 .20489 L
.5988 .20664 L
.59999 .20878 L
.60107 .21113 L
.60374 .21859 L
.60619 .22744 L
Mistroke
.61173 .25372 L
.62177 .31811 L
.63164 .39007 L
.63708 .42744 L
.64222 .45837 L
.647 .48159 L
.6497 .49185 L
.6522 .49932 L
.6543 .50402 L
.65549 .50603 L
.65661 .50748 L
.65779 .50854 L
.65887 .50909 L
.66005 .50923 L
.66129 .50886 L
.66252 .50797 L
.66368 .50666 L
.66472 .5051 L
.66585 .50301 L
.66838 .49683 L
.67071 .4894 L
.67496 .47192 L
.67946 .44875 L
.68903 .38917 L
.69931 .32315 L
.70457 .29419 L
.70716 .28206 L
.70956 .27234 L
.71168 .26506 L
.71403 .25859 L
.71517 .25609 L
.7164 .25386 L
.71769 .25205 L
.71891 .25086 L
.72006 .2502 L
.72113 .25 L
.72231 .25023 L
.72356 .251 L
.72488 .2524 L
.72613 .25427 L
.72846 .25919 L
.73065 .26542 L
.73267 .27251 L
.73723 .29295 L
.75756 .42941 L
.7675 .49578 L
.77221 .52075 L
.77659 .53858 L
.77876 .54524 L
.78106 .55065 L
Mistroke
.78238 .55295 L
.78362 .55457 L
.78473 .55557 L
.78594 .55618 L
.78701 .55629 L
.78819 .55596 L
.78942 .55511 L
.79057 .55385 L
.79164 .55227 L
.79262 .5505 L
.79482 .54538 L
.79733 .53772 L
.79965 .52902 L
.8049 .50425 L
.81443 .44662 L
.82342 .38786 L
.82814 .35947 L
.8331 .33378 L
.83575 .32242 L
.83865 .31217 L
.83992 .30845 L
.84128 .30503 L
.84256 .30237 L
.84373 .30038 L
.84502 .29872 L
.8457 .29808 L
.84642 .29756 L
.84763 .2971 L
.84832 .29707 L
.84896 .29718 L
.85016 .29777 L
.85125 .29874 L
.85251 .30037 L
.85371 .30242 L
.85631 .30852 L
.85876 .31626 L
.86332 .33556 L
.87356 .39697 L
.89196 .52745 L
.89703 .55701 L
.90175 .57891 L
.90413 .58751 L
.90668 .59473 L
.90814 .59789 L
.90951 .60023 L
.91074 .60178 L
.91144 .60243 L
.91208 .60287 L
.91315 .6033 L
.91429 .60332 L
Mistroke
.91537 .60293 L
.91635 .60222 L
.9175 .60097 L
.91876 .59911 L
.92106 .59436 L
.92344 .58766 L
.92599 .57865 L
.93057 .55808 L
.95053 .43414 L
.956 .40165 L
.96178 .3734 L
.96416 .36416 L
.96671 .35606 L
.96817 .35231 L
.96951 .34949 L
.97086 .34723 L
.97213 .34566 L
.97314 .3448 L
.97407 .34431 L
.9751 .34412 L
.97619 .34432 L
Mfstroke
0 g
[ ] 0 setdash
.02381 .27373 m
.02605 .27446 L
.02729 .27478 L
.02846 .27503 L
.02954 .27522 L
.03072 .27537 L
.0318 .27546 L
.03279 .27551 L
.03396 .27551 L
.03506 .27547 L
.03626 .27537 L
.03756 .27521 L
.03891 .27497 L
.0402 .27467 L
.04262 .27396 L
.045 .27305 L
.04753 .27185 L
.0521 .26912 L
.06244 .26034 L
.07382 .24689 L
.08454 .23113 L
.10458 .19585 L
.14313 .12214 L
.16307 .09041 L
.17311 .07801 L
.17877 .07232 L
.18413 .06787 L
.18902 .06466 L
.1916 .06331 L
.19434 .06212 L
.19664 .06134 L
.19786 .06101 L
.19917 .06071 L
.20038 .06049 L
.20148 .06034 L
.20253 .06023 L
.20364 .06017 L
.20495 .06015 L
.20615 .0602 L
.2068 .06025 L
.20752 .06032 L
.20882 .06049 L
.21003 .06072 L
.21132 .06101 L
.21363 .06171 L
.21632 .06278 L
.21883 .06403 L
.22456 .06777 L
.22954 .07204 L
.23497 .07774 L
Mistroke
.24485 .09083 L
.26338 .12396 L
.30408 .22375 L
.34326 .32551 L
.35357 .34854 L
.36471 .37038 L
.37434 .38624 L
.3849 .40004 L
.38989 .40518 L
.39523 .40964 L
.40028 .41287 L
.40251 .41398 L
.40487 .41496 L
.40616 .41539 L
.40757 .4158 L
.40887 .41611 L
.41006 .41634 L
.41147 .41654 L
.4122 .41661 L
.41298 .41667 L
.41428 .41671 L
.41502 .4167 L
.4157 .41668 L
.41635 .41664 L
.41704 .41658 L
.4183 .41643 L
.41953 .41622 L
.42066 .41598 L
.42323 .41526 L
.42595 .41423 L
.4309 .41169 L
.43541 .40861 L
.44557 .39925 L
.45497 .38781 L
.46389 .37484 L
.50219 .30474 L
.52155 .26788 L
.53184 .25004 L
.54294 .2331 L
.55349 .21983 L
.55811 .21503 L
.56317 .21054 L
.56764 .20728 L
.57242 .20456 L
.57507 .2034 L
.57747 .20257 L
.57863 .20224 L
.57989 .20194 L
.58106 .20172 L
.58217 .20156 L
Mistroke
.5834 .20143 L
.58452 .20136 L
.58573 .20134 L
.58705 .20138 L
.5882 .20147 L
.58942 .20163 L
.59058 .20182 L
.59162 .20204 L
.5942 .20277 L
.59698 .20384 L
.60202 .20653 L
.60735 .21043 L
.61298 .21571 L
.62306 .22805 L
.64271 .26184 L
.66105 .30285 L
.69998 .40518 L
.7198 .45615 L
.74136 .50354 L
.75141 .52138 L
.76207 .53674 L
.77118 .54668 L
.77636 .55096 L
.78123 .55405 L
.7835 .55519 L
.78593 .55618 L
.78732 .55665 L
.78859 .55701 L
.78979 .5573 L
.79107 .55754 L
.7917 .55763 L
.7924 .55772 L
.79362 .55784 L
.79431 .55787 L
.79506 .55789 L
.79576 .55789 L
.7964 .55788 L
.79763 .5578 L
.79833 .55773 L
.79897 .55765 L
.80016 .55747 L
.80142 .55721 L
.80383 .55656 L
.80643 .55562 L
.81114 .55329 L
.81572 .55028 L
.81993 .54689 L
.8297 .53685 L
.83881 .52502 L
.85949 .4912 L
Mistroke
.89847 .41647 L
.91834 .38242 L
.92881 .36773 L
.93991 .35541 L
.94423 .35164 L
.94888 .34828 L
.95155 .34669 L
.95399 .34545 L
.95647 .34442 L
.95877 .34365 L
.96084 .34313 L
.96199 .34291 L
.96304 .34276 L
.96419 .34263 L
.96544 .34255 L
.96662 .34253 L
.9677 .34256 L
.96872 .34262 L
.96967 .34272 L
.97071 .34287 L
.97183 .34307 L
.97411 .34363 L
.97619 .34432 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o4_ooool0
0ol0003oooooooooo`3ooooooeCooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool001;o
oooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo
000Booooo`03o`000?oooooooooo0?ooooooE?ooool001;ooooo00?o0000ooooooooool04?ooool3
ool00?oooooo@Oooool001;ooooo0_l0000@ooooo`;oo`0000?oooooool00?ooool0oooooom0oooo
o`004_ooool00ol0003oooooooooo`0?ooooo`05ool00?oooooooooooooooooo0000oooooom0oooo
o`004_ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo0?oooooo@oooool001;ooooo
00?o0000ooooooooool03_ooool00ooo003oooooooooo`3ooooood?ooooo000Booooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool0oooooom3ooooo`004_ooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo0?oooooo@oooool001;ooooo00?o0000ooooooooool03_ooool00ooo
003oooooooooo`3ooooood?ooooo000Booooo`03o`000?oooooooooo00gooooo00?oo`00oooooooo
ool01Oooool00ooo003oooooooooo`3ooooooccooooo000Booooo`03o`000?oooooooooo00gooooo
00?oo`00ooooooooool01Oooool00ooo003oooooooooo`3ooooooccooooo000Booooo`;o00003_oo
ool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo0?oooooo??ooool001;ooooo00?o0000
ooooooooool03?ooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo0?oooooo??ooool0
01;ooooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`3ooooooccooooo000Booooo`03
o`000?oooooooooo01Kooooo00?oo`00ooooooooool07oooool4o`000?oooooo6?ooool001;ooooo
00?o0000ooooooooool05_ooool00ooo003oooooooooo`0Mooooo`Oo0000oooooolGooooo`004_oo
ool00ol0003oooooooooo`0Fooooo`03ool00?oooooooooo01[ooooo2_l0003ooooooaOooooo000B
ooooo`03o`000?oooooooooo01Kooooo00?oo`00ooooooooool06?ooool2o`0000Cooooo00?o0000
ool00?oo00000ol0003ooooooaOooooo000Booooo`03o`000?oooooooooo01Oooooo00?oo`00oooo
ooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oo003o000000;o000000?oo`00o`00
0?l00000oooooolEooooo`004_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`06ooooo`Co000000Coo`00oooooooo
oooo0000oooooolDooooo`004_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Wo
oooo00?oo`00ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`05ool00?oooooooooooooo
ool00000oooooolCooooo`004_ooool2o`0000cooooo00?oo`00ooooooooool02Oooool00ooo003o
ooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool00_ooool00ol0003o
ooooooooo`3ooooooa3ooooo000Booooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00Goo`00oooooooooooo
ooooo`00003ooooooa;ooooo000Booooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool0
2oooool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool0
0_ooool00ol0003oooooooooo`3oooooo`oooooo000Booooo`03o`000?oooooooooo00[ooooo00?o
o`00ooooooooool02oooool00ooo003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o
o`00ooooooooool01?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo3_oo
ool001;ooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`0;ooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00?ooooo00?o0000ooooooooool0ooooool=ooooo`004_ooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ooo003oooooo`000003o`00
0003oa0@4?ooooooo`0000Gooooo00?o0000ooooooooool0;Oooool5o`0003Sooooo00GoV9RHoa0@
4?l0003o<S8bolc<c00jooooo`;o000000?o410@ooooooooool0>?ooool01Om4A4Co0000o`000?lb
<S;ogMgM027ooooo000Booooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool07Oooool0
0ol0003oooooooooo`09ooooo`03ool00?oooooooooo00;ooooo00Go0000ooooooooooooooooool0
0006ooooo`03o`000?oooooooooo02cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00hooooo`05oa0@
4?nj^[[oooooogMgMolb<S80>oooool00ol0003oooooooooo`0looooo`03ogMgMolb<S;ooooo023o
oooo000Booooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool07?ooool00ol0003ooooo
ooooo`0:ooooo`03ool00?oooooooooo00;ooooo00Go0000ooooooooooooooooool00006ooooo`03
o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0?Oooool00ol0003oooooooooo`0fooooo`Go
0000?_ooool00ol0003oooooooooo`0Oooooo`004_ooool00ol0003oooooooooo`09ooooo`03ool0
0?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ooo003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0;Oooool00onHV9So8B4Qonk^kP0kooooo`03ojVY
ZOl@413ooooo03Oooooo00CoA4A4omgMgOoooooo0000?_ooool00omgMgOo<S8booooo`0Pooooo`00
4_ooool2o`0000[ooooo00?oo`00ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03ool0
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0^ooooo`03ogMg
MomVIVKooooo03Wooooo00?o410@o`000?nj^[X0>?ooool01?oMgMgoEEEEooooool0000kooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`08Oooool001;ooooo00?o0000ooooooooool02Oooool00ooo003o
ooooooooo`0=ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ooo003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool2ool001Co
oooo00?o0000ooooooooool0>Oooool00onj^[[o8B4Qooooo`0hooooo`03ogMgMoo<c<co000003_o
oooo00?o0000ooooooooool08oooool001;ooooo00?o0000ooooooooool02?ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ooo003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool01?oo003ooooo
ool00?oo000?ooooo`05o`000?nj^[[ooooooiRHV?l@4100>?ooool01Ol@413oV9RHoooooonj^[[o
000003Wooooo00?ok^k^odA4A?l00000>oooool00ol0003oooooooooo`0Sooooo`004_ooool00ol0
003oooooooooo`08ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool02Oooool00ol0
003oooooooooo`0<ooooo`07ool00?oooooooooooooooomEEEGoIVIVo`00000=ooooo`03o`000?oo
oooooooo01Gooooo0_oo0002ooooo`03ool00?oooooooooo00gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00hooooo`05ojVYZOl@413o0000oa0@4?nYZJT0>_ooool00omgMgOo0000ooooo`0jooooo`Co
00008_ooool001;ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0>ooooo`03ool0
0?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ooo003oooooooooo`02ooooo`03ool0
0?oooooooooo0>_ooooo000Booooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool01_oo
ool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0jooo
ool001;ooooo00?o0000ooooooooool06_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooo
oooo00gooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooo
oooo01;ooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`3Jooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool02?ooool001;ooooo00?o0000ooooooooool06_ooool0
0ooo003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool02_ooool0
0ooo003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`3Kooooo`05o`000?ooooooooooooooool000002oooool001;ooooo00?o0000
ooooooooool06_ooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?oo`00
ooooooooool02_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?oo`00
ooooooooool01?ooool00ooo003oooooooooo`3Jooooo`05o`000?ooooooooooooooool000002ooo
ool000[ooooo9Ol000000ooo003o0000o`00000Fo`000003ool00?l0003o000000_o000000?oo`00
o`000?l000006ol000000ooo003o0000o`000004o`000003ool00?l0003o00000<ko00003?ooool0
1Ol0003ooooooooooooooooo000000_ooooo000Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo0_l0000;
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Wooooo00?oo`00o`000?ooool01Oooool00ooo003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool01Ol0003oQhN7oooooonY
ZJWo000000_ooooo000Booooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool04?ooool0
0ooo003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool0
0ooo003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool01_ooool0
0ooo003oooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo013ooooo00?o410@o`000?mgMgL00_l00000
0onHV9Soooooooooo`09ooooo`004_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo
013ooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03ool00?oooooooooo
00Sooooo00?o0000ooooooooool03oooool00ooo003oooooooooo`3booooo`004_ooool00ol0003o
ooooooooo`07ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool00_ooool00ol0003o
ooooooooo`0Oooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0ooooool4ooooo`00
4_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo017ooooo00Goo`00oooooooooooo
ooooo`00000Qooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0ooooool4ooooo`00
4_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo017ooooo00Coo`00oooooooooooo
00008_ooool00ooo003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo1?ooool001;ooooo
00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Booooo`04ool00?ooooooooooo`0001?o
oooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo03[o
oooo0_oo0036ooooo`004_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo01;ooooo
00?oo`00ooooool000005?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00Wooooo
00?o0000ooooooooool0>Oooool00ooo003oooooooooo`36ooooo`004_ooool2o`0000Oooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo00gooooo00?o
o`00ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Sooooo00?o
o`00ooooooooool07_ooool00ooo003oooooooooo`37ooooo`004_ooool00ol0003oooooooooo`06
ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0=
ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`08
ooooo`03ool00?oooooooooo01kooooo00Goo`00ooooooooooooooooool00035ooooo`004_ooool0
0ol0003oooooooooo`06ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
0ooo003oooooooooo`09ooooo`03ool00?oooooooooo01gooooo00?oo`00ooooooooool00_ooool0
0ooo003oooooooooo`32ooooo`004_ooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo
01;ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Looooo`03o`000?oooooooooo
00Wooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo
00?ooooo00?oo`00ooooooooool0`_ooool001;ooooo00?o0000ooooooooool01_ooool00ooo003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?oo`00ooooooooool07?ooool00ol0003o
ooooooooo`09ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool07?ooool00ooo003o
ooooooooo`04ooooo`03ool00?oooooooooo0<7ooooo000Booooo`03o`000?oooooooooo00Kooooo
00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03ool00?oooooooooo01gooooo
00?o0000ooooooooool02?ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo01cooooo
00?oo`00ooooooooool01?ooool00ooo003oooooooooo`31ooooo`004_ooool00ol0003ooooooooo
o`05ooooo`03ool00?oooooooooo01;ooooo00?o0000oooooooo00005?ooool00ooo003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool02_ooool00ooo003ooooooooo
o`0Kooooo`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0`Oooool001;ooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`0Aooooo`04o`000?ooooooooooool001Cooooo00?o
o`00ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00[ooooo00?o
o`00ooooooooool06oooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo0<7ooooo000B
ooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool04Oooool01?l0003ooooooooooooo
000Cooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool03?ooool00ol0003ooooooooo
o`06ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool06_ooool00ooo003ooooooooo
o`05ooooo`03ool00?oooooooooo0<7ooooo000Booooo`;o00001_ooool00ooo003oooooooooo`0@
ooooo`05o`000?oooooooooooooooooo00004oooool00ooo003oooooooooo`0@ooooo`03ool00?oo
oooooooo00cooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0<ooooo`03ool00?oo
oooooooo01Wooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`30ooooo`004_ooool0
0ol0003oooooooooo`0Hooooo`05o`000?oooooooooooooooooo00004oooool00ooo003ooooooooo
o`0@ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ooo003ooooooooo
o`0<ooooo`03ool00?oooooooooo01Wooooo00?oo`00ooooooooool01oooool00ooo003ooooooooo
o`30ooooo`004_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?oo`00
ooooooooool04?ooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00gooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo02?ooooo00?oo`00
ooooooooool08?ooool4o`0009cooooo000Booooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo013ooooo00?oo`00oooo
ooooool03_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00cooooo00?oo`00oooo
ooooool08oooool00ooo003oooooooooo`0Oooooo`Ko0000Voooool001;ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00oooooo00?oo`00oooooooo
ool04_ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?oo`00oooooooo
ool03Oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo01_ooooo2_l0002Kooooo`00
4_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool0
3oooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool0
0oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool0
6Oooool2o`0000Cooooo0_oo0004o`0009_ooooo000Booooo`03o`000?oooooooooo00Cooooo00?o
o`00ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo02Cooooo00?o
o`00ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool08oooool00ooo003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00Ko
o`00o`000?l0003o0000ool00?l0002Kooooo`004_ooool00ol0003oooooooooo`04ooooo`03ool0
0?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0Tooooo`03ool0
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0>ooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0Eooooo`;o0000
1oooool01_oo003o0000o`000?l0003oo`00ooooo`;o0000VOooool001;ooooo00?o0000oooooooo
ool01?ooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?oo`00oooooooo
ool09?ooool00ooo003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00?oo`00oooooooo
ool02Oooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?oo`00oooooooo
ool00_ooool01Ooo003ooooooooooooooooo000009Sooooo000Booooo`;o00001?ooool00ooo003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool09?ooool00ooo003o
ooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00?oo`00ooooooooool08?ooool00ol0003o
ooooooooo`0<ooooo`04ool00?ooooooooooo`0009Sooooo000Booooo`03o`000?oooooooooo00?o
oooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo02?o
oooo00?oo`00ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03ool00?oooooooooo01oo
oooo00?o0000ooooooooool03Oooool01Ooo003ooooooooooooooooo000009Oooooo000Booooo`03
o`000?oooooooooo00?ooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
ool00?oooooooooo02?ooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`03
ool00?oooooooooo01oooooo00?o0000ooooooooool03oooool01Ooo003ooooooooooooooooo0000
09Kooooo000Booooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool05?ooool00ooo003o
ooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?oo`00ooooooooool07_ooool00ol0003o
ooooooooo`0@ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0Toooool001;ooooo
00?o0000ooooooooool00oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Dooooo`03ool00?oooooooooo013ooooo
00?o0000ool00?ooool04?ooool00ooo003oooooooooo`0Fooooo`03ool00?oooooooooo01gooooo
00?o0000ooooooooool04Oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo09?ooooo
000Booooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool02oooool00ol0003ooooooooo
o`0Kooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool04?ooool00ol0003oo`00oooo
o`0@ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool02oooool00ooo003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool01_ooool00ooo003ooooooooo
o`03ooooo`03o`000?oooooooooo09;ooooo000Booooo`03o`000?oooooooooo00;ooooo00?oo`00
ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo01Gooooo00?oo`00
ooooooooool04?ooool00ol0003oo`00ooooo`0@ooooo`03ool00?oooooooooo01Kooooo00?oo`00
ooooooooool02oooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?oo`00
ooooooooool01oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo09;ooooo000Boooo
o`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0Loooo
o`03ool00?oooooooooo02Wooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`0Doooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`2Aoooo
o`004_ooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00?o0000oooooooo
ool07?ooool00ooo003oooooooooo`0Xooooo`03ool00?l0003ooooo017ooooo00?oo`00oooooooo
ool05?ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00?ooooo00?o0000oooooooo
ool0TOooool001;ooooo0_l00002ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0
7Oooool00ooo003oooooooooo`0Xooooo`03ool00?l0003ooooo017ooooo00?oo`00ooooooooool0
5?ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0
T?ooool001;ooooo00Go0000ooooooooooooooooool0000;ooooo`03o`000?oooooooooo00oooooo
00?oo`00ooooooooool02oooool00ooo003oooooooooo`0Xooooo`03ool00?oooooo0000017ooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00[ooooo
00?o0000ooooooooool03?ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00Gooooo
00?o0000ooooooooool06?ooool2ool007Gooooo000Booooo`05o`000?oooooooooooooooooo0000
2_ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool0
:Oooool00ooo003oooooo`00000Aooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool0
3Oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo0ooo001dooooo`004_oo
ool01?l0003ooooooooooooo000:ooooo`03o`000?oooooooooo017ooooo00?oo`00ooooooooool0
2_ooool00ooo003oooooooooo`0Gooooo`03ool00?oooooooooo00oooooo00?oo`00ooooool00000
4_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
2Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Wooooo00?oo`00ooooooooool0
1Oooool00ol0003oooooooooo`0Fooooo`04ool00?ooooooooooool007Cooooo000Booooo`04o`00
0?ooooooooooool000Wooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool03oooool01?oo003oooooooooool0000Aoooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`09oooo
o`03o`000?oooooooooo00cooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`05oooo
o`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool00_ooool00ooo003oooooooooo`1aoooo
o`004_ooool00ol0003oooooooooo`08ooooo`;o00005_ooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo01Oooooo00?oo`00ooooooooool03oooool01?oo003oooooooooool0000Aoooo
o`03ool00?oooooooooo01;ooooo00?oo`00ooooooooool03_ooool00ooo003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0Doooo
o`03ool00?oooooooooo00;ooooo00?oo`00ooooooooool0LOooool000Sooooo1?l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ooo003o
ooooooooo`09ooooo`03ool00?oooooooooo01Oooooo00?oo`00ooooooooool03_ooool00ooo003o
ooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?oo`00ooooooooool08oooool00ooo003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool04_ooool00ol0003o
ooooooooo`0Dooooo`03ool00?oooooooooo00?ooooo00?oo`00ooooooooool0L?ooool000[ooooo
00?o0000ooooooooool00oooool4o`0000Kooooo0_l0000Iooooo`03ool00?oooooooooo00Sooooo
00?oo`00ooooooooool06?ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00Oooooo
00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo
00?oo`00ooooooooool0L?ooool000[ooooo00?o0000ooooooooool00_ooool6o`0000Cooooo00?o
0000ooooooooool06Oooool00ooo003oooooooooo`08ooooo`03ool00?oooooooooo01Sooooo00?o
o`00ooooooooool03_ooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o
o`00ooooooooool08_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo073ooooo000:
ooooo`03o`000?oooooooooo00;ooooo1_l000000ooooooo0000o`000002o`0001_ooooo00?oo`00
ooooooooool02?ooool00ooo003oooooooooo`0Hooooo`03ool00?oooooooooo00kooooo00?oo`00
ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo02?ooooo00?oo`00
ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo01Gooooo00?o0000
ooooooooool06?ooool00ooo003oooooooooo`1`ooooo`002_ooool00ol0003oooooooooo`02oooo
o`So00007oooool00ooo003oooooooooo`0Sooooo`03ool00?oooooooooo00cooooo00?oo`00oooo
ooooool01?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo02?ooooo00?oo`00oooo
ooooool01Oooool00ol0003oooooooooo`0>ooooo`03ool00?oooooooooo00_ooooo00?oo`00oooo
ooooool01oooool00ol0003oooooooooo`0Iooooo`03ool00?oooooooooo06oooooo000:ooooo`03
o`000?oooooooooo00;ooooo1_l0000Qooooo`03ool00?oooooooooo02?ooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool08oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?oo`00oooooooo
ool03?ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo08[ooooo000:ooooo`03o`00
0?oooooooooo00?ooooo1?l0000Rooooo`03ool00?oooooooooo02?ooooo00?oo`00ooooooooool0
5?ooool00ol0003oooooooooo`0Pooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
0oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0
2?ooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo07Sooooo0008ooooo`03oeEEEOmV
IVKo000000Oooooo00?o0000ooooooooool08Oooool00ooo003oooooooooo`0Sooooo`03ool00?oo
oooooooo01Cooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`0Fooooo`03o`000?oo
oooooooo01kooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03ool00?oo
oooooooo07Sooooo000Booooo`03o`000?oooooooooo027ooooo00?oo`00ooooooooool08oooool0
0ooo003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?oo`00ooooooooool05Oooool0
0ol0003oooooooooo`0Pooooo`03ool00?oooooooooo00Sooooo00?o0000ooooooooool03_ooool0
0ooo003oooooooooo`1hooooo`004_ooool00ol0003oooooooooo`0Qooooo`03ool00?oooooooooo
02?ooooo00?oo`00ooooooooool05Oooool00ol0003oooooooooo`0Oooooo`03ool00?oooooooooo
01Gooooo00?o0000ooooooooool08?ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00?oo`00ooooooooool0NOooool001;ooooo00?o0000ooooooooool08_ooool00ooo003o
ooooooooo`05ooooo`03ool00?oooooooooo01[ooooo00?oo`00ooooooooool05Oooool00ol0003o
ooooooooo`0Oooooo`03ool00?oooooooooo01Cooooo00?o0000ooooooooool08Oooool00ooo003o
ooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0NOooool001;ooooo
00?o0000ooooooooool08_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo01_ooooo
00?oo`00ooooooooool02_ooool00ooo003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo
00?oo`00ooooooooool03oooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo02;ooooo
00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00Sooooo
00?oo`00ooooooooool07oooool2ool004gooooo000Booooo`;o0000:_ooool00ooo003ooooooooo
o`0Looooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool02?ooool00ol0003ooooooooo
o`0<ooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool04Oooool00ooo003oooooo`00
000Tooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ooo003ooooooooo
o`08ooooo`03ool00?oooooooooo01oooooo00?oo`00ooooooooool0C?ooool001;ooooo00?o0000
ooooooooool0:Oooool00ooo003oooooooooo`0Looooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00oooooo00?oo`00
ooooooooool04Oooool00ooo003o0000ooooo`0Cooooo`03ool00?oooooooooo00kooooo00?oo`00
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00Sooooo00?oo`00
ooooooooool07_ooool00ooo003oooooooooo`1=ooooo`004_ooool00ol0003oooooooooo`0Yoooo
o`03ool00?oooooooooo02Wooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0;oooo
o`03ool00?oooooooooo00kooooo00?oo`00ooooooooool04_ooool00ooo003o0000ooooo`0Coooo
o`03ool00?oooooooooo00kooooo00?oo`00ooooooooool02oooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo00Sooooo00?oo`00ooooooooool07_ooool00ooo003oooooooooo`1=oooo
o`004_ooool00ol0003oooooooooo`0Xooooo`03ool00?oooooooooo02[ooooo00?oo`00oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00kooooo00?oo`00oooooooo
ool04_ooool00ol0003oo`00ooooo`0Cooooo`03ool00?oooooooooo00oooooo00?oo`00oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?oo`00oooooooo
ool07Oooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo04Sooooo000Booooo`03o`00
0?oooooooooo02Sooooo00?oo`00ooooooooool0:Oooool00ooo003oooooooooo`0:ooooo`03o`00
0?oooooooooo00cooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Booooo`03o`00
0?oo003ooooo01?ooooo00?oo`00ooooooooool03oooool00ooo003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Looooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool0B?ooool001;ooooo00?o0000ooooooooool09?oo
ool2ool00003oooooooo003ooooo02_ooooo00?oo`00ooooooooool02oooool00ol0003ooooooooo
o`0;ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool04Oooool00ol0003oooooool0
000Dooooo`03ool00?oooooooooo00oooooo00?oo`00ooooooooool02oooool00ol0003ooooooooo
o`08ooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool07?ooool00ooo003ooooooooo
o`04ooooo`03ool00?oooooooooo04Oooooo000Booooo`03o`000?oooooooooo02Gooooo0ooo000/
ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`0=
ooooo`03ool00?oooooooooo017ooooo00?o0000oooooooo00004oooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0:
ooooo`03ool00?oooooooooo01_ooooo00?oo`00ooooooooool01Oooool00ooo003oooooooooo`17
ooooo`004_ooool00ol0003oooooooooo`1Dooooo`03ool00?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo017ooooo00Co0000oooo
ooooooooo`004oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo00cooooo00?o0000
ooooooooool01oooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo01_ooooo00?oo`00
ooooooooool01Oooool00ooo003oooooooooo`17ooooo`004_ooool00ol0003oooooooooo`1:oooo
o`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0:oooo
o`03ool00?oooooooooo00cooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`03ool00?oooooooooo013ooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0<oooo
o`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`0Koooo
o`03ool00?oooooooooo00Gooooo00?oo`00ooooooooool0Aoooool001;ooooo0_l0001;ooooo`03
ool00?oooooooooo00Oooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03
ool00?oooooooooo00cooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03
ool00?oooooooooo013ooooo00?oo`00ooooooooool07oooool00ol0003oooooooooo`06ooooo`03
ool00?oooooooooo00_ooooo00?oo`00ooooooooool06oooool00ooo003oooooooooo`06ooooo`03
ool00?oooooooooo04Kooooo000Booooo`03o`000?oooooooooo04[ooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0
7_ooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
8?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0
6oooool00ooo003oooooooooo`06ooooo`03ool00?oooooooooo04Kooooo000Booooo`03o`000?oo
oooooooo04[ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03o`000?oo
oooooooo00[ooooo00?oo`00ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03ool00?oo
oooooooo013ooooo00?oo`00ooooooooool08?ooool00ol0003oooooooooo`0Cooooo`03ool00?oo
oooooooo01_ooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0Pooooo`Co00008_oo
ool001;ooooo00?o0000ooooooooool0Boooool00ooo003oooooooooo`05ooooo`03ool00?oooooo
oooo00oooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0Looooo`03o`000?oooooo
oooo00Cooooo00?oo`00ooooooooool04?ooool00ooo003oooooooooo`0Qooooo`03o`000?oooooo
oooo01?ooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`06ooooo`03ool00?oooooo
oooo01oooooo1_l0000Qooooo`004_ooool00ol0003oooooooooo`1;ooooo`03ool00?oooooooooo
00Gooooo00?oo`00ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
01cooooo00?o0000ooooooooool01?ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo
02;ooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0Iooooo`03ool00?oooooooooo
00Oooooo00?oo`00ooooooooool07?ooool9o`00027ooooo000Booooo`03o`000?oooooooooo04_o
oooo00?oo`00ooooooooool01?ooool00ooo003oooooooooo`0Aooooo`03o`000?oooooooooo00So
oooo00?oo`00ooooooooool06oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool08_ooool00ol0003oooooooooo`0Cooooo`03ool00?oooooooooo01Wo
oooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0Iooooo`;o00000oooool00ol0003o
o`00ool00003o`00027ooooo000Booooo`03o`000?oooooooooo04_ooooo00?oo`00ooooooooool0
1?ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?oo`00ooooooooool0
6oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool0
4_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?oo`00ooooooooool0
9?ooool00ooo003oooooooooo`0Gooooo`;o00001Oooool2ool000Co00008Oooool001;ooooo00?o
0000ooooooooool0Boooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o
o`00ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00kooooo00?o
o`00ooooooooool04_ooool00ooo003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
o`00ooooooooool0=?ooool00ooo003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o
o`00o`000?l000000_l0000Rooooo`004_ooool00ol0003oooooooooo`1<ooooo`03ool00?oooooo
oooo01Wooooo00?o0000ooooooooool04oooool00ooo003oooooooooo`0=ooooo`03o`000?oooooo
oooo02gooooo00?oo`00ooooooooool03oooool01Ol0003oooooooooooooooooo`0003Oooooo00?o
o`00ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo02Gooooo000B
ooooo`;o0000COooool00ooo003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?oo`00
ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`03ool00?oooooooooo00oooooo00Go0000
ooooooooooooooooool0000gooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool01_oo
ool00ooo003oooooooooo`0Uooooo`004_ooool00ol0003oooooooooo`1=ooooo`03ool00?oooooo
oooo01Wooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0<ooooo`03o`000?oooooo
oooo033ooooo00?oo`00ooooooooool03_ooool01Ol0003oooooooooooooooooo`0004cooooo00?o
0000ooooooooool01oooool00ooo003oooooooooo`0Uooooo`004_ooool00ol0003oooooooooo`1=
ooooo`03ool00?oooooooooo01Wooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0<
ooooo`03o`000?oooooooooo033ooooo00?oo`00ooooooooool03oooool00ol0003oooooool0001<
ooooo`03o`000?oooooooooo00Sooooo00?oo`00ooooooooool09Oooool001;ooooo00?o0000oooo
ooooool0C_ooool2ool001Wooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`08oooo
o`03ool00?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ooo003oooooooooo`0?oooo
o`03o`000?ooooooo`00017ooooo00?oo`00ooooooooool05oooool00ooo003oooooooooo`0Moooo
o`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool09Oooool001;ooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Sooooo00?oo`00oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo02?ooooo00?oo`00oooooooo
ool03oooool00ol0003oooooool0000Aooooo`03ool00?oooooooooo01Oooooo00?oo`00oooooooo
ool07Oooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo02Kooooo000Booooo`03o`00
0?oooooooooo06[ooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`08ooooo`03ool0
0?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0<ooooo`03ool0
0?oooooooooo01Cooooo00?oo`00ooooooooool04?ooool00ol0003oo`00ooooo`0@ooooo`03ool0
0?oooooooooo01Oooooo00?oo`00ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03ool0
0?oooooooooo02Kooooo000Booooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool01?oo
ool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool04?oo
ool00ol0003oo`00ooooo`0@ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool07?oo
ool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo02Kooooo000Booooo`03o`000?oooooo
oooo06cooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo00[ooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0<ooooo`03ool00?oooooo
oooo01Cooooo00?oo`00ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03ool00?oooooo
oooo01Gooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00?oo`00ooooooooool09_ooool001;ooooo00?o0000ooooooooool0K?ooool00ol0
003oooooooooo`04ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0?ooooo`03ool00?l0003ooooo017ooooo00?oo`00ooooooooool05Oooool00ooo
003oooooooooo`0<ooooo`03ool00?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ooo
003oooooooooo`0Wooooo`004_ooool2o`0006kooooo00?o0000ooooooooool00oooool00ooo003o
ooooooooo`06ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ooo003o
ooooooooo`0;ooooo`03ool00?oooooooooo01Kooooo00?oo`00ooooooooool03oooool00ooo003o
0000ooooo`0Aooooo`03ool00?oooooooooo01Cooooo00?oo`00ooooooooool03Oooool00ooo003o
ooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?oo`00ooooooooool09oooool001;ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`03ooooo`03ool00?oooooooooo00Kooooo
00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03ool00?oooooooooo00[ooooo
00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooo0000017ooooo
00?oo`00ooooooooool05?ooool00ooo003oooooooooo`0=ooooo`03ool00?oooooooooo00_ooooo
00?o0000ooooooooool0=Oooool001;ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02?ooool00ol0003ooooooooo
o`0Aooooo`03ool00?oooooooooo00[ooooo00?oo`00ooooooooool05_ooool00ooo003ooooooooo
o`0?ooooo`03ool00?oooooo0000017ooooo00?oo`00ooooooooool05?ooool00ooo003ooooooooo
o`0>ooooo`03ool00?oooooooooo00[ooooo00?o0000ooooooooool0=Oooool001;ooooo00?o0000
ooooooooool0Koooool00ol0003oooooooooo`02ooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool01oooool00ol0003oooooooooo`0Booooo`03ool00?oooooooooo00[ooooo00?oo`00
ooooooooool05_ooool00ooo003oooooooooo`0?ooooo`04ool00?ooooooooooo`00017ooooo00?o
o`00ooooooooool04oooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo00Wooooo00?o
0000ooooooooool0=_ooool001;ooooo00?o0000ooooooooool0L?ooool01Ol0003ooooooooooooo
ooooo`0000Kooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03ool00?oo
oooooooo00[ooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`0?ooooo`04ool00?oo
ooooooooo`00017ooooo00?oo`00ooooooooool04oooool00ooo003oooooooooo`0>ooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool0=_ooool001;ooooo00?o0000ooooooooool0LOoo
ool01Ol0003oooooooooooooooooo`0000gooooo00?o0000ooooooooool05?ooool00ooo003ooooo
ooooo`0:ooooo`03ool00?oooooooooo02Sooooo00Coo`00oooooooooooo00004Oooool00ooo003o
ooooooooo`0Cooooo`03ool00?oooooooooo00kooooo00?oo`00ooooooooool02?ooool00ol0003o
ooooooooo`0gooooo`004_ooool00ol0003oooooooooo`1booooo`04o`000?ooooooooooool000co
oooo00?o0000ooooooooool05Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo02go
oooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Booooo`03ool00?oooooooooo00oo
oooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo02So
oooo0007ooooo`Go00001_ooool00ol0003oooooooooo`1cooooo`03o`000?ooooooo`0000?o0000
1oooool2o`0001Sooooo00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0]ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool04_ooool00ooo003oooooooooo`0?ooooo`03ool0
0?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0Xooooo`001ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0M?ooool2o`000004ool0
0?l0003o0000o`0000Gooooo00?o0000ooooooooool06?ooool00ooo003oooooooooo`09ooooo`03
ool00?oooooooooo02kooooo00?o0000ooooooooool03_ooool00ooo003oooooooooo`0Aooooo`03
ool00?oooooooooo00oooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03
ool00?oooooooooo02Sooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0001dooooo`Ko0000
0oooool2o`0001cooooo00?oo`00ooooooooool01oooool00ooo003oooooooooo`0_ooooo`03o`00
0?oooooooooo00kooooo00?oo`00ooooooooool04Oooool00ooo003oooooooooo`0?ooooo`03ool0
0?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0Yooooo`002Ooo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo07Cooooo2Ol0000Nooooo`03ool00?oo
oooooooo00Oooooo00?oo`00ooooooooool06Oooool00ooo003oooooooooo`0Cooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool09?ooool00ooo003oooooooooo`04ooooo`03o`000?oo
oooooooo00kooooo00?oo`00ooooooooool0:Oooool000[ooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`1dooooo`Ko00008Oooool00ooo003oooooooooo`07ooooo`03ool00?oooooo
oooo01Wooooo00?oo`00ooooooooool03Oooool00ooo003oooooooooo`04ooooo`03o`000?oooooo
oooo03Cooooo00?oo`00ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03ool00?oooooo
oooo02Wooooo000;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0MOooool4o`00
02cooooo00?oo`00ooooooooool06_ooool00ooo003oooooooooo`0<ooooo`03ool00?oooooooooo
00Cooooo00?o0000ooooooooool0=?ooool00ooo003oooooooooo`03ooooo`03o`000?oooooooooo
00oooooo00?oo`00ooooooooool0:Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4006oooo
o`03o`000?oooooooooo0<;ooooo00?oo`00ooooooooool03?ooool00ooo003oooooooooo`04oooo
o`03o`000?oooooooooo03Cooooo00?oo`00ooooooooool00oooool00ol0003oooooooooo`0?oooo
o`03ool00?oooooooooo02Wooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`32ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool01_ooool00ol0
003oooooooooo`0cooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ooo
003oooooooooo`0Zooooo`004_ooool00ol0003oooooooooo`32ooooo`03ool00?oooooooooo00_o
oooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00oo
oooo00?oo`00ooooooooool0:_ooool001;ooooo00?o0000ooooooooool0`_ooool00ooo003ooooo
ooooo`0;ooooo`03ool00?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ooo003ooooo
ooooo`0?ooooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ooo003ooooo
ooooo`0Zooooo`004_ooool00ol0003oooooooooo`2Mooooo`03ool00?oooooooooo02;ooooo00?o
o`00ooooooooool02oooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o
o`00ooooooooool03oooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo017ooooo00?o
o`00ooooooooool0:_ooool001;ooooo0_l0002Nooooo`03ool00?oooooooooo00Cooooo00?oo`00
ooooooooool06oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00Oooooo00?o0000
ooooooooool03?ooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01Cooooo00?o0000
ooooooooool04Oooool00ooo003oooooooooo`0Zooooo`004_ooool00ol0003oooooooooo`2Moooo
o`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool07?ooool00ooo003oooooooooo`09oooo
o`03ool00?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0?oooo
o`03ool00?oooooooooo01?ooooo00?o0000ooooooooool04Oooool00ooo003oooooooooo`0[oooo
o`004_ooool00ol0003oooooooooo`2Mooooo`03ool00?oooooooooo00?ooooo00?oo`00oooooooo
ool07Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool00ooo003oooooooooo`0?ooooo`03ool00?oooooooooo01;ooooo00?oo`00o`000?oo
ool04_ooool00ooo003oooooooooo`0[ooooo`004_ooool00ol0003oooooooooo`2Mooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`09ooooo`03ool0
0?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ooo003oooooooooo`0>ooooo`03ool0
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ooo003oooooooooo`0[ooooo`004_oo
ool00ol0003oooooooooo`2Nooooo`05ool00?oooooooooooooooooo00008?ooool00ooo003ooooo
ooooo`09ooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ooo003ooooo
ooooo`0>ooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ooo003ooooo
ooooo`0[ooooo`004_ooool00ol0003oooooooooo`2Oooooo`04ool00?ooooooooooool0023ooooo
00?oo`00ooooooooool02Oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo
00?oo`00ooooooooool03Oooool00ooo003oooooooooo`0Booooo`03o`000?oo003ooooo047ooooo
000Booooo`03o`000?oooooooooo09oooooo0ooo000Qooooo`03ool00?oooooooooo00Sooooo00?o
o`00ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03ool00?oooooooooo00gooooo00?o
o`00ooooooooool04_ooool00ol0003oo`00ooooo`11ooooo`004_ooool00ol0003oooooooooo`34
ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool03?ooool00ol0003oooooooooo`0:
ooooo`03ool00?oooooooooo00gooooo00?oo`00ooooooooool04Oooool01?l0003ooooooooooooo
0011ooooo`004_ooool00ol0003oooooooooo`34ooooo`03ool00?oooooooooo00Oooooo00?oo`00
ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool04Oooool01?l0003ooooooooooooo0011ooooo`004_ooool2o`000<oooooo00?oo`00
ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo00gooooo00?oo`00
ooooooooool04?ooool01Ol0003oooooooooooooooooo`00047ooooo000Booooo`03o`000?oooooo
oooo0=kooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0=ooooo`03ool00?oooooo
oooo013ooooo00Go0000ooooooooooooooooool0000Booooo`03ool00?oooooooooo02cooooo000B
ooooo`03o`000?oooooooooo0=oooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`0<
ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ooo003oooooooooo`0@
ooooo`03ool00?oooooooooo02cooooo000Booooo`03o`000?oooooooooo0=oooooo00?o0000oooo
ooooool02Oooool00ooo003oooooooooo`0;ooooo`03ool00?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ooo003oooooooooo`0@ooooo`03ool00?oooooooooo02cooooo000Booooo`03
o`000?oooooooooo0>3ooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`0;ooooo`03
ool00?oooooooooo00oooooo00?o0000ooooooooool00oooool00ooo003oooooooooo`0@ooooo`03
ool00?oooooooooo02cooooo000Booooo`03o`000?oooooooooo0<Gooooo00?oo`00ooooooooool0
6?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo00_ooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo013ooooo00?oo`00ooooooooool0
;?ooool001;ooooo00?o0000ooooooooool0aOooool00ooo003oooooooooo`0Hooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`0>ooooo`03ool00?oo
oooooooo02gooooo000Booooo`03o`000?oooooooooo0<Kooooo00?oo`00ooooooooool00oooool0
0ooo003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool0
0ooo003oooooooooo`0>ooooo`03ool00?oooooooooo02gooooo000Booooo`03o`000?oooooooooo
0<Kooooo00?oo`00ooooooooool00oooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`0>ooooo`03ool00?oooooooooo
02gooooo000Booooo`;o0000b?ooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo01?o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo00ko
oooo00?oo`00ooooooooool0;Oooool001;ooooo00?o0000ooooooooool0aoooool00ooo003ooooo
ooooo`02ooooo`03ool00?oooooooooo01?ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Iooooo`03ool00?oooooooooo02gooooo000Booooo`03o`000?oooooooooo0<Oooooo00Go
o`00ooooooooooooooooool0000Gooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool0
2Oooool00ooo003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?oo`00ooooooooool0
;Oooool001;ooooo00?o0000ooooooooool0b?ooool3ool001Sooooo00?o0000ooooooooool01_oo
ool00ooo003oooooooooo`09ooooo`03ool00?oooooooooo00_ooooo00?o0000ooooooooool06_oo
ool00ooo003oooooooooo`0]ooooo`004_ooool00ol0003oooooooooo`39ooooo`03ool00?oooooo
oooo01Sooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`09ooooo`03ool00?oooooo
oooo00[ooooo00?o0000ooooooooool06oooool00ooo003oooooooooo`0]ooooo`004_ooool00ol0
003oooooooooo`3Uooooo`03o`000?oooooooooo00Gooooo00?oo`00ooooooooool01oooool00ooo
003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00?oo`00ooooooooool0;_ooool001;o
oooo00?o0000ooooooooool0iOooool00ol0003oooooooooo`05ooooo`03ool00?oooooooooo00Oo
oooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03ool00?oooooooooo00co
oooo00?oo`00ooooooooool0;_ooool001;ooooo00?o0000ooooooooool0i_ooool00ol0003ooooo
ooooo`04ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool02_ooool00ol0003ooooo
ooooo`0<ooooo`03ool00?oooooooooo00cooooo00?oo`00ooooooooool0;_ooool001;ooooo00?o
0000ooooooooool0i_ooool00ol0003oooooooooo`04ooooo`03ool00?oooooooooo00Oooooo00?o
o`00ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo00cooooo00?o
o`00ooooooooool0;_ooool001;ooooo00?o0000ooooooooool0ioooool00ol0003oooooooooo`03
ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02Oooool00ol0003oooooooooo`0>
ooooo`03ool00?oooooooooo03gooooo000Booooo`;o0000jOooool00ol0003oooooooooo`02oooo
o`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`03ool00?oooooooooo03gooooo000Booooo`03o`000?oooooooooo0>Wooooo00?o0000oooooooo
ool00_ooool00ooo003oooooooooo`05ooooo`03ool00?oooooooooo00Oooooo00?o0000oooooooo
ool04?ooool00ooo003oooooooooo`0mooooo`004_ooool00ol0003oooooooooo`3Zooooo`05o`00
0?oooooooooooooooooo00001_ooool00ooo003oooooooooo`07ooooo`03o`000?oooooooooo01;o
oooo00?oo`00ooooooooool0??ooool001;ooooo00?o0000ooooooooool0j_ooool01Ol0003ooooo
ooooooooooooo`0000Kooooo00?oo`00ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
ool00?oooooooooo03cooooo000Booooo`03o`000?oooooooooo0>_ooooo00Co0000oooooooooooo
o`001_ooool00ooo003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?oo`00oooooooo
ool02_ooool00ooo003oooooooooo`0_ooooo`004_ooool00ol0003oooooooooo`3/ooooo`04o`00
0?ooooooooooool000Cooooo00?oo`00ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03
ool00?oooooooooo00[ooooo00?oo`00ooooooooool0;oooool000Oooooo00GoV9RHoa0@4?l0003o
<S8bolc<c006ooooo`03o`000?oooooooooo0>gooooo00?o0000oooooooo00001?l000000ooo003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?oo`00ooooooooool02_ooool00ooo003o
ooooooooo`0_ooooo`001oooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0k_ooool2o`000003ool00?l0003o000000;oo`001_ooool00ol0003oooooooooo`0Gooooo`03
ool00?oooooooooo00Sooooo00?oo`00ooooooooool0<?ooool000_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3_ooooo`Ko00000oooool3o`0001[ooooo00?oo`00ooooooooool0
2?ooool00ooo003oooooooooo`0`ooooo`002_ooool00onYZJWo410@ooooo`05ooooo`?o0000kooo
ool9o`0001gooooo00?oo`00ooooooooool02?ooool00ooo003oooooooooo`0`ooooo`002Oooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>oooooo1_l0000Pooooo`03ool00?oooooo
oooo00Sooooo00?oo`00ooooooooool0<?ooool000[ooooo00?o^[Zjob4Q8Oooool01Oooool00ol0
003oooooooooo`3`ooooo`Co00008_ooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo
033ooooo0007ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooo
oaOooooo00?oo`00ooooooooool01_ooool00ooo003oooooooooo`0aooooo`001oooool01OnYZJWo
410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooolPooooo`03ool00?oooooooooo
037ooooo000Booooo`03o`000?oooooooooo0?oooooo8?ooool00ooo003oooooooooo`0aooooo`00
4_ooool00ol0003oooooooooo`3ooooooaoooooo00?oo`00ooooooooool0<_ooool001;ooooo00?o
0000ooooooooool0oooooolOooooo`03ool00?oooooooooo03;ooooo000Booooo`03o`000?oooooo
oooo0?oooooo7oooool00ooo003oooooooooo`0booooo`004_ooool2o`000?oooooo6Oooool00ooo
003oooooooooo`04ooooo`03ool00?oooooooooo03;ooooo000Booooo`03o`000?oooooooooo0?oo
oooo6?ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo03;ooooo000Booooo`03o`00
0?oooooooooo0?oooooo6?ooool00ooo003oooooooooo`03ooooo`03ool00?oooooooooo03?ooooo
000Booooo`03o`000?oooooooooo0?oooooo6Oooool00ooo003oooooooooo`0hooooo`004_ooool0
0ol0003oooooooooo`3ooooooa[ooooo00?oo`00ooooooooool0=oooool001;ooooo00?o0000oooo
ooooool0oooooolJooooo`;oo`00>?ooool001;ooooo00?o0000ooooooooool0oooooolKooooo`;o
o`00=oooool001;ooooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003ooooooooo
o`3ooooooeCooooo000Booooo`;o0000oooooomEooooo`004_ooool00ol0003oooooooooo`3ooooo
oeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo000Booooo`04o`000?ooooooooooo`000?ooooooDoooool001;ooooo00Co0000oooooooo
oooo0000oooooomCooooo`003?ooool00ol@413o0000o`000002o`000005oa0@4?l0003ooooooooo
ool00000oooooomCooooo`003_ooool01?l0003oooooooooooooool3o`000?ooooooE?ooool000ko
oooo00?o0000ooooooooool0oooooomHooooo`003_ooool00ol0003oooooooooo`3ooooooeSooooo
000>ooooo`03o`000?oooooooooo0?ooooooF?ooool000cooooo00?o410@o`000?l000000ol0003o
oooooeOooooo000>ooooo`03o`000?oooooooooo0?ooooooF?ooool000kooooo00?o410@okZj^_oo
ool0oooooomHooooo`003_ooool01?nj^[[o410@o`000?l@413ooooooeOooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.300103, -0.938764, \
0.0204479, 0.0275861}}],

Cell[TextData[{
  "Fig. 2.10 The fastest sinusoidal oscillation that can be unambiguously \
identified in a set of data has the Nyquist frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_max\)]],
  " and period",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"2", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " (black curve). Higher-frequency oscillations (dashed curve)  can be \
translated back to lower frequency."
}], "Caption",
  CellTags->"Fig. 2.10"],

Cell[TextData[{
  "\tThere is something else that one can see in the real and imaginary parts \
of the plotted spectrum. Because the input data ",
  Cell[BoxData[
      FormBox[
        StyleBox["f",
          FontWeight->"Bold"], TraditionalForm]]],
  " was real, the spectral components ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(f\&~\),
          FontWeight->"Bold"], TraditionalForm]]],
  " have the property that ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_\(-m\) = \(f\&~\)\_m\%\(\(\ \)\(*\)\)\)]],
  ". This is analogous to Eq. ",
  ButtonBox["(2.3.7)",
    ButtonData:>"(2.3.7)",
    ButtonStyle->"Hyperlink"],
  " for continuous Fourier transforms, and follows directly from Eq. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  " for any real set of time data ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  ". We  can also see this symmetry in the previous plots if we remember that \
the periodicity of ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_\(-m\) = f\&~\_\(N - m\)\)]],
  ". Thus, for real data, the discrete Fourier transform has the property \
that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_\(-m\) = \(f\&~\_\(N - m\) = \(f\&~\)\_m\%\(\(\
\ \)\(*\)\)\)\)]],
  "."
}], "NE3",
  CellTags->{"(2.3.66)", "i:56"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Fast Fourier Transforms", "Section"],

Cell[TextData[{
  "Although the discrete Fourier transforms given by Eqs. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.63)",
    ButtonData:>"(2.3.63)",
    ButtonStyle->"Hyperlink"],
  " work, they are not very useful in practice. The reason is that they are \
too slow. To evaluate the spectrum for a data set of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " elements, a sum over the data set must be done for each frequency in the \
spectrum. Since there are ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " elements in the sum and ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " frequencies in the spectrum, determining every frequency component of a \
dataset requires of order ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  "operations. For ",
  Cell[BoxData[
      \(TraditionalForm\`N = 100\)]],
  " this is not a problem (as we saw above), but for ",
  Cell[BoxData[
      \(TraditionalForm\`N = 10\^6\)]],
  " it is out of the question. Datasets of this size are routinely created in \
all sorts of applications."
}], "Text"],

Cell[TextData[{
  "\tFortunately, a method was developed that allows one to perform the \
discrete transform and inverse transform with far fewer than ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\^2\)\(\ \)\)\)]],
  "operations. The method is called the method of ",
  StyleBox["fast fourier transforms ",
    FontSlant->"Italic"],
  "(FFT for short).",
  StyleBox[" ",
    FontSlant->"Italic"],
  " Invented by several individuals working independently as far back as the \
1940s, it later became well known through the work of Cooley and ",
  ButtonBox["Tukey",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Tukey.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " at IBM Research Center in the mid-1960s."
}], "Text"],

Cell[TextData[{
  "\t The method relies on symmetries of the discrete Fourier transform that \
allow one to divide the problem into a hierarchy of smaller problems, each of \
which can be done quickly (the ",
  StyleBox["divide and conquer ",
    FontSlant->"Italic"],
  "approach",
  "). We will not examine the nuts and bolts of the procedure in detail. But \
it is worthwhile to briefly discuss the idea behind the method. "
}], "Text"],

Cell[TextData[{
  "\t Given a discrete Fourier transform of a data set with ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " elements,",
  StyleBox[" ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  StyleBox[" ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  "assumed even",
  ", one can break this transform up into two discrete transforms with ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)]],
  " elements each. One transform is formed from the even-numbered data \
points, the other from the odd-numbered data points:"
}], "Text"],

Cell[TextData[Cell[BoxData[{
    \(TraditionalForm\`f\&~\_m = \[Sum]\+\(n = 0\)\%\(N - 1\)\(f\_n\) \
\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ n/N\)\), \
"\[IndentingNewLine]", 
    \(TraditionalForm\`\(\(=\)\(\[Sum]\+\(n = 0\)\%\(N/2 - 1\)\(f\_\(2  
                  n\)\) \[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ 2  n/N\
\) + \ \[Sum]\+\(n = 0\)\%\(N/2 - 1\)\(f\_\(2  n + 
                  1\)\) \[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ \((2  \
n + 1)\) n/N\)\)\)\), "\[IndentingNewLine]", 
    \(TraditionalForm\`\(\(=\)\(\[Sum]\+\(n = 0\)\%\(N/2 - 1\)\(f\_\(2  
                  n\)\) \[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ \
n/\((N/2)\)\) + \ \(\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ /
                  N\)\) \(\[Sum]\+\(n = 0\)\%\(N/2 - 1\)\(f\_\(2  n + 
                    1\)\) \[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ \
/\((N/2)\)\)\)\)\)\), "\[IndentingNewLine]", 
    \(TraditionalForm\`\(\(=\)\(\ \)\(\(f\&~\)\_m\%\((e)\) + \
\(\[ExponentialE]\^\(\[ImaginaryI]\ 2\ \[Pi]\ m\ /
                  N\)\) \(\(\(f\&~\)\_m\%\((o)\)\)\(.\)\)\)\)\)}]]], "NE3",
  CellTags->"(2.3.67)"],

Cell[TextData[{
  "In the last line, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)\_m\%\((e)\)\)]],
  " denotes the discrete Fourier transform over the ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)]],
  " even elements of ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)\_m\%\((o)\)\)]],
  " denotes the discrete Fourier transform over ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)]],
  " odd elements of the data."
}], "Text"],

Cell[TextData[{
  "\tAt this point it appears that we have gained nothing. The two separate \
transforms each require of order  ",
  Cell[BoxData[
      \(TraditionalForm\`N/2\)]],
  " operations, and there are still ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " separate frequencies ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m\)]],
  " to be calculated, for a total of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\^2\)\(\ \)\)\)]],
  "operations again.  ",
  "However, according to Eq. (",
  ButtonBox["2.3.60",
    ButtonData:>"(2.3.60)",
    ButtonStyle->"Hyperlink"],
  "), both ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)\_m\%\((e)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)\_m\%\((o)\)\)]],
  " are periodic with period N/2. Therefore, we really only need to calculate \
the components ",
  Cell[BoxData[
      \(TraditionalForm\`m = 1, 2,  ... , N/2\)]],
  " for each transform. "
}], "Text"],

Cell[TextData[{
  "\tIn this single step, we have saved ourselves a factor of 2. Now, we \
apply this procedure again, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N/2\)\(\ \)\)\)]],
  "is an even number, saving ",
  "another",
  " factor of 2, and so on, repeating until there is only ",
  StyleBox["one ",
    FontSlant->"Italic"],
  " element in each series. This assumes that ",
  Cell[BoxData[
      \(TraditionalForm\`N\  = \ 2\^P\)]],
  " for some integer ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ". In fact,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(=\)\(2\^P\)\(\ \)\)\)]],
  " are the only values allowed in the simplest implementations of the FFT \
method. (If ",
  Cell[BoxData[
      \(TraditionalForm\`N\  \[NotEqual] \ \ 2\^P\)]],
  "for some integer ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ", one typically pads the data with zeros until it reaches a length of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^P\)]],
  " for some ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  ".) "
}], "Text"],

Cell[TextData[{
  "\tIt appears from the above argument that we have taken the original ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  " steps and reduced their number by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^P = N\)]],
  ", resulting in a code that scales linearly with ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  ". However,  a more careful accounting shows that the resulting recursive \
algorithm actually scales as ",
  Cell[BoxData[
      \(TraditionalForm\`N\ \(log\_2\) N\)]],
  ", because the number of steps in the recursion equals ",
  Cell[BoxData[
      \(TraditionalForm\`P = \(log\_2\) N\)]],
  ". Nevertheless, this is a huge saving over the original ",
  Cell[BoxData[
      \(TraditionalForm\`N\^2\)]],
  " operations required for the discrete Fourier transform."
}], "Text"],

Cell[TextData[{
  "\tWriting an efficient FFT code based on the above ideas is not entirely \
straightforward, and will not be pursued here. [An implementation of the code \
can be found in ",
  ButtonBox["Press et al.(1986)",
    ButtonData:>{"Chapter1.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  "; see the references at the end of Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  ".]  Fortunately, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has done the job for us, with the intrinsic functions ",
  StyleBox["Fourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InverseFourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Fourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " acts on a list of data ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\({f\_n}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " to produce a frequency spectrum ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(f\&~\),
            FontWeight->"Bold"], "=", \({f\&~\_m}\)}], TraditionalForm]]],
  ". The syntax is ",
  StyleBox["Fourier[f] ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "and ",
  StyleBox["InverseFourier[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["f",
              FontSlant->"Plain"], "~"],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text",
  CellTags->"i:101"],

Cell[TextData[{
  " However, just as with continuous Fourier transforms, many different \
conventions exist for the definitions of the discrete transform. The default \
convention used by ",
  StyleBox["Fourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InverseFourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " differs from that used in Eqs. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.63)",
    ButtonData:>"(2.3.63)",
    ButtonStyle->"Hyperlink"],
  ". For a dataset of length ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " our convention corresponds to "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            OverscriptBox[
              StyleBox["f",
                FontSlant->"Plain"], "~"], "="}],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["Fourier[f]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"/", 
            SqrtBox[
              StyleBox["N",
                FontSlant->"Plain"]]}],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", \n\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontFamily->"Courier",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontFamily->"Courier",
            FontWeight->"Bold"]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          SqrtBox[
            StyleBox["N",
              FontSlant->"Plain"]],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["InverseFourier[",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["f",
              FontSlant->"Plain"], "~"],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "NE3",
  CellTags->"(2.3.68)"],

Cell[TextData[{
  "Of course, any convention can be used, provided that one is consistent in \
its application. We will stick to the convention of Eq. ",
  ButtonBox["(2.3.68)",
    ButtonData:>"(2.3.68)",
    ButtonStyle->"Hyperlink"],
  ", since it corresponds to our previous discussion."
}], "Text"],

Cell[TextData[{
  "\tThe length of the data sets taken as arguments in ",
  StyleBox["Fourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["InverseFourier",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " need not be ",
  Cell[BoxData[
      \(TraditionalForm\`2\^P\)]],
  ".   For example, in Cell ",
  ButtonBox["2.66",
    ButtonData:>"Cell 2.66",
    ButtonStyle->"Hyperlink"],
  " we apply them to the original data of 100 elements created in the \
previous section."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(nn = 100; f\&~ = \ Fourier[f]/Sqrt[nn]\ ;\), "\n", 
    \(\(ListPlot[Re[f\&~], PlotJoined \[Rule] True, 
        PlotRange \[Rule] All];\)\), "\n", 
    \(\(ListPlot[Im[f\&~], PlotJoined \[Rule] True, 
        PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.66"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 0.071848 1.15056 [
[.20659 .05935 -6 -9 ]
[.20659 .05935 6 0 ]
[.39899 .05935 -6 -9 ]
[.39899 .05935 6 0 ]
[.59139 .05935 -6 -9 ]
[.59139 .05935 6 0 ]
[.78379 .05935 -6 -9 ]
[.78379 .05935 6 0 ]
[.97619 .05935 -9 -9 ]
[.97619 .05935 9 0 ]
[.00169 .1869 -18 -4.5 ]
[.00169 .1869 0 4.5 ]
[.00169 .30196 -18 -4.5 ]
[.00169 .30196 0 4.5 ]
[.00169 .41702 -18 -4.5 ]
[.00169 .41702 0 4.5 ]
[.00169 .53207 -18 -4.5 ]
[.00169 .53207 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20659 .07185 m
.20659 .0781 L
s
[(20)] .20659 .05935 0 1 Mshowa
.39899 .07185 m
.39899 .0781 L
s
[(40)] .39899 .05935 0 1 Mshowa
.59139 .07185 m
.59139 .0781 L
s
[(60)] .59139 .05935 0 1 Mshowa
.78379 .07185 m
.78379 .0781 L
s
[(80)] .78379 .05935 0 1 Mshowa
.97619 .07185 m
.97619 .0781 L
s
[(100)] .97619 .05935 0 1 Mshowa
.125 Mabswid
.06229 .07185 m
.06229 .0756 L
s
.11039 .07185 m
.11039 .0756 L
s
.15849 .07185 m
.15849 .0756 L
s
.25469 .07185 m
.25469 .0756 L
s
.30279 .07185 m
.30279 .0756 L
s
.35089 .07185 m
.35089 .0756 L
s
.44709 .07185 m
.44709 .0756 L
s
.49519 .07185 m
.49519 .0756 L
s
.54329 .07185 m
.54329 .0756 L
s
.63949 .07185 m
.63949 .0756 L
s
.68759 .07185 m
.68759 .0756 L
s
.73569 .07185 m
.73569 .0756 L
s
.83189 .07185 m
.83189 .0756 L
s
.87999 .07185 m
.87999 .0756 L
s
.92809 .07185 m
.92809 .0756 L
s
.25 Mabswid
0 .07185 m
1 .07185 L
s
.01419 .1869 m
.02044 .1869 L
s
[(0.1)] .00169 .1869 1 0 Mshowa
.01419 .30196 m
.02044 .30196 L
s
[(0.2)] .00169 .30196 1 0 Mshowa
.01419 .41702 m
.02044 .41702 L
s
[(0.3)] .00169 .41702 1 0 Mshowa
.01419 .53207 m
.02044 .53207 L
s
[(0.4)] .00169 .53207 1 0 Mshowa
.125 Mabswid
.01419 .09486 m
.01794 .09486 L
s
.01419 .11787 m
.01794 .11787 L
s
.01419 .14088 m
.01794 .14088 L
s
.01419 .16389 m
.01794 .16389 L
s
.01419 .20992 m
.01794 .20992 L
s
.01419 .23293 m
.01794 .23293 L
s
.01419 .25594 m
.01794 .25594 L
s
.01419 .27895 m
.01794 .27895 L
s
.01419 .32497 m
.01794 .32497 L
s
.01419 .34798 m
.01794 .34798 L
s
.01419 .37099 m
.01794 .37099 L
s
.01419 .394 m
.01794 .394 L
s
.01419 .44003 m
.01794 .44003 L
s
.01419 .46304 m
.01794 .46304 L
s
.01419 .48605 m
.01794 .48605 L
s
.01419 .50906 m
.01794 .50906 L
s
.01419 .04884 m
.01794 .04884 L
s
.01419 .02583 m
.01794 .02583 L
s
.01419 .00281 m
.01794 .00281 L
s
.01419 .55508 m
.01794 .55508 L
s
.01419 .57809 m
.01794 .57809 L
s
.01419 .60111 m
.01794 .60111 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
.5 Mabswid
.02381 .13053 m
.03343 .11406 L
.04305 .09189 L
.05267 .07489 L
.06229 .0727 L
.07191 .0991 L
.08153 .05126 L
.09115 .08994 L
.10077 .03015 L
.11039 .09106 L
.12001 .08933 L
.12963 .04032 L
.13925 .10162 L
.14887 .10526 L
.15849 .10106 L
.16811 .07818 L
.17773 .10028 L
.18735 .06578 L
.19697 .04745 L
.20659 .07364 L
.21621 .60332 L
.22583 .08528 L
.23545 .06916 L
.24507 .11513 L
.25469 .09434 L
.26431 .07692 L
.27393 .0769 L
.28355 .08641 L
.29317 .03324 L
.30279 .07734 L
.31241 .11054 L
.32203 .09664 L
.33165 .05918 L
.34127 .07256 L
.35089 .10282 L
.36051 .09899 L
.37013 .09612 L
.37975 .01472 L
.38937 .04612 L
.39899 .04944 L
.40861 .04246 L
.41823 .07278 L
.42785 .03732 L
.43747 .04688 L
.44709 .03693 L
.45671 .05724 L
.46633 .06091 L
.47595 .08685 L
.48557 .07298 L
.49519 .10525 L
Mistroke
.50481 .03921 L
.51443 .10525 L
.52405 .07298 L
.53367 .08685 L
.54329 .06091 L
.55291 .05724 L
.56253 .03693 L
.57215 .04688 L
.58177 .03732 L
.59139 .07278 L
.60101 .04246 L
.61063 .04944 L
.62025 .04612 L
.62987 .01472 L
.63949 .09612 L
.64911 .09899 L
.65873 .10282 L
.66835 .07256 L
.67797 .05918 L
.68759 .09664 L
.69721 .11054 L
.70683 .07734 L
.71645 .03324 L
.72607 .08641 L
.73569 .0769 L
.74531 .07692 L
.75493 .09434 L
.76455 .11513 L
.77417 .06916 L
.78379 .08528 L
.79341 .60332 L
.80303 .07364 L
.81265 .04745 L
.82227 .06578 L
.83189 .10028 L
.84151 .07818 L
.85113 .10106 L
.86075 .10526 L
.87037 .10162 L
.87999 .04032 L
.88961 .08933 L
.89923 .09106 L
.90885 .03015 L
.91847 .08994 L
.92809 .05126 L
.93771 .0991 L
.94733 .0727 L
.95695 .07489 L
.96657 .09189 L
.97619 .11406 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
87oo00<007ooOol0ogooSWoo000POol2003oOon?Ool0021oo`03001oogoo0?moohioo`0087oo00<0
07ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo0?moohioo`0087oo00<0
07ooOol0Sgoo00<007ooOol0HGoo00<007ooOol0Ugoo000POol00`00Oomoo`2?Ool00`00Oomoo`1Q
Ool00`00Oomoo`2GOol0021oo`03001oogoo08moo`80065oo`8009Uoo`0087oo00<007ooOol0Sgoo
0P00HGoo0P00VGoo000POol2002@Ool2001QOol2002IOol0021oo`03001oogoo08ioo`04001oogoo
001OOol01000Oomoo`00V7oo000POol00`00Oomoo`0OOol00`00Oomoo`1/Ool01000Oomoo`00Ggoo
00@007ooOol006ioo`03001oogoo02Moo`0087oo00<007ooOol07goo00<007ooOol0BWoo00<007oo
Ool07goo00@007ooOol005moo`04001oogoo000QOol00`00Oomoo`1:Ool00`00Oomoo`0WOol0021o
o`03001oogoo01moo`03001oogoo021oo`H000Eoo`8001eoo`03001oogoo01moo`04001oogooOol3
0005Ool20011Ool40006Ool20007Ool01@00Oomoogoo00008Goo00<007ooOol04Goo10001Woo0P00
;Goo00<007ooOol03Goo1@001Goo0P001goo0P001Goo000POol00`00Oomoo`0OOol00`00Oomoo`0Q
Ool01@00Oomoogoo000017oo00@007ooOol001aoo`03001oogoo01moo`04001oogooOol20005Ool0
1000Oomoo`001Goo00<007ooOol01Goo00<007ooOol057oo00<007ooOol057oo00D007ooOomoo`00
00=oo`8000Aoo`04001oogoo0006Ool01@00Oomoogoo00008Goo00<007ooOol047oo00<007ooOol0
0Woo00<007ooOol00Woo00@007ooOol002aoo`03001oogoo00moo`03001oogoo00Aoo`04001oogoo
0005Ool01000Oomoo`0017oo000POol00`00Oomoo`0NOol00`00Ool0000:Ool00`00Oomoo`0FOol0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`0IOol2000POol70003Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool20005Ool2000FOol00`00Oomoo`0DOol20002Ool00`00Oomoo`030003Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo000087oo0P004Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`03001oogoo01eoo`03001oogoo00Qoo`03001oo`00011oo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`01Ool0021oo`03001oogoo01ioo`03001o
o`0000Yoo`03001oogoo01Moo`03001oogoo00=oo`03001oogoo009oo`03001oogoo01Qoo`03001o
o`00021oo`8000=oo`03001oogoo009oo`06001oo`00001oo`0017oo00<007oo00000goo00@007oo
Ool001Eoo`03001oogoo01=oo`09001oogoo001oo`00Ool007oo008000=oo`03001oogoo00<000Ao
o`03001oogoo009oo`03001oogoo01ioo`03001oo`00015oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`0MOol00`00Oomoo`08Ool00`00Ool0000@Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo000POol00`00Oomoo`0NOol00`00Ool0000:
Ool00`00Oomoo`0HOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00Ool0000P
Ool00`00Ool00002Ool20003Ool2000017oo001oo`000goo00L007ooOomoo`00Ool00003Ool00`00
Oomoo`0COol00`00Oomoo`0COol01000Oomoogoo0`000goo00D007ooOomoo`00009oo`03001oo`00
00=oo`8000Aoo`03001oogoo01ioo`03001oo`00019oo`@000Aoo`03001oogoo009oo`03001oogoo
01eoo`03001oogoo00Qoo`03001oo`00011oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool0021oo`8001moo`03001oo`0000Uoo`8001Yoo`8000=oo`03001o
ogoo009oo`03001oogoo01Qoo`03001oo`0001moo`08001oogooOol007oo001oo`800007Ool007oo
Ool007oo00000goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol04Goo00<007oo00004goo
00<007ooOol00goo00<007oo00000`000goo00<007oo00000Woo0P0000=oo`00Ool01Woo00<007oo
Ool07Goo00<007oo00004Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo01Qoo`8000Uoo`03001oo`00011oo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool0021oo`03001oogoo01Moo`03001oogoo00Aoo`03001oo`0000Uo
o`03001oo`0001Uoo`8000=oo`03001oogoo009oo`03001oogoo01Qoo`03001oo`0001moo`07001o
ogooOol007oo00000goo0P000goo0P000goo00<007ooOol027oo00<007ooOol04Goo00<007oo0000
4goo00<007ooOol017oo00D007ooOomoo`0000=oo`03001oo`00009oo`03001oo`0000Qoo`03001o
ogoo01eoo`03001oo`00015oo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`02Ool0
0`00Oomoo`0HOol20009Ool00`00Ool00006Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol00Goo000POol00`00Oomoo`0GOol00`00Oomoo`04
Ool00`00Ool00009Ool00`00Ool0000EOol01P00Oomoo`00Ool000Aoo`04001oogoo000KOol01000
Oomoo`007Woo00<007ooOol00Woo0P001Goo00@007ooOol000=oo`03001oogoo00Yoo`03001oogoo
011oo`03001oo`00019oo`03001oogoo00Eoo`8000=oo`04001oogooOol200000goo001oo`0:Ool0
0`00Oomoo`0LOol01000Oomoo`004Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol000Eo
o`8001Qoo`03001oo`0000Uoo`03001oo`0000Ioo`03001oogoo00Eoo`<000Ioo`04001oogoo0005
Ool01000Oomoo`0017oo000POol00`00Oomoo`0GOol00`00Oomoo`03Ool01@00Oomoogoo000027oo
00<007oo00005Woo1@001Goo0P006goo00D007ooOomoo`0001ioo`03001oogoo00=oo`03001oogoo
00Aoo`<000=oo`03001oogoo00Yoo`03001oogoo011oo`03001oo`00019oo`03001oogoo00Moo`@0
00=oo`<000aoo`03001oogoo01aoo`05001oogooOol0000AOol40006Ool20005Ool00`00Ool0000H
Ool00`00Ool00008Ool01@00Oomoogoo00001Goo00<007ooOol01Woo0P001goo0P001goo0P001Goo
000POol00`00Oomoo`0GOol20004Ool01@00Oomoogoo000027oo00<007oo00005goo00@007ooOol0
029oo`05001oogooOol0000=Ool00`00Oomoo`0>Ool00`00Oomoo`0<Ool01@00Oomoogoo00003Goo
0`003goo00<007oo000047oo0P003Goo00D007ooOomoo`0000ioo`03001oogoo00ioo`03001oogoo
00]oo`05001oogooOol0000ROol01000Oomoo`005goo00<007oo000027oo00D007ooOomoo`0000Ao
o`03001oo`00021oo`0087oo00<007ooOol05Woo00<007oo000017oo00D007ooOomoo`0000Moo`04
001oogoo000FOol00`00Oomoo`02Ool00`00Oomoo`0OOol01@00Oomoogoo00003Goo00<007ooOol0
3Woo00<007ooOol03Goo00@007ooOol0011oo`8000eoo`03001oo`0000ioo`8000moo`05001oogoo
Ool0000>Ool00`00Oomoo`0>Ool00`00Oomoo`0;Ool01@00Oomoogoo00008Woo00D007ooOomoo`00
01Ioo`04001oogoo0007Ool01@00Oomoogoo000017oo00<007oo000087oo000POol00`00Oomoo`0F
Ool00`00Ool00004Ool01@00Oomoogoo00001goo00@007ooOol001Ioo`03001oogoo009oo`03001o
ogoo01moo`03001oogoo009oo`03001oogoo00Yoo`8000moo`03001oogoo00eoo`03001oo`00019o
o`03001oogoo00]oo`03001oo`0000ioo`03001oogoo00moo`03001oo`0000moo`03001oogoo00eo
o`8000aoo`03001oogoo009oo`03001oogoo01moo`03001oogoo009oo`03001oogoo01Aoo`04001o
ogoo0007Ool01@00Oomoogoo000017oo00<007oo000087oo000POol00`00Oomoo`0FOol00`00Ool0
0004Ool01@00Oomoogoo00001goo00D007ooOomoo`0001Aoo`03001oogoo00Aoo`03001oogoo01io
o`03001oogoo009oo`03001oogoo00Uoo`04001oogoo000>Ool00`00Oomoo`0=Ool00`00Ool0000C
Ool00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007ooOol047oo00<007oo00003goo00<007oo
Ool03Goo00<007oo00002goo00<007ooOol00Woo00<007ooOol07goo00<007ooOol00goo00<007oo
Ool04goo00@007ooOol000Moo`05001oogooOol00004Ool00`00Ool0000POol0021oo`03001oogoo
01Ioo`04001oogoo0003Ool01@00Oomoogoo00001goo00D007ooOomoo`0001Aoo`03001oogoo00Ao
o`03001oogoo00Uoo`03001oogoo015oo`03001oogoo00=oo`03001oogoo00Uoo`04001oogoo000=
Ool00`00Oomoo`0>Ool00`00Ool0000COol00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007oo
Ool047oo00<007oo000047oo00<007ooOol02goo00@007ooOol000]oo`03001oogoo00=oo`03001o
ogoo015oo`03001oogoo00Yoo`03001oogoo00=oo`03001oogoo01=oo`04001oogoo0007Ool01@00
Oomoogoo00000goo00@007ooOol0021oo`0087oo00<007ooOol05Woo00@007ooOol0009oo`03001o
ogoo00=oo`03001oogoo00Aoo`05001oogooOol0000DOol00`00Oomoo`04Ool00`00Oomoo`09Ool0
0`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`09Ool01@00Oomoogoo000037oo00<007ooOol0
3goo00<007ooOol04Woo00<007ooOol02Goo00D007ooOomoo`0000aoo`03001oogoo015oo`03001o
ogoo00moo`03001oogoo00]oo`04001oogoo000;Ool00`00Oomoo`03Ool00`00Oomoo`0AOol00`00
Oomoo`09Ool00`00Oomoo`04Ool00`00Oomoo`0COol01000Oomoo`001Woo00<007ooOol00goo00@0
07ooOol000=oo`03001oogoo01eoo`006Wooo`00T`0017oo000POol00`00Oomoo`0<Ool20002Ool0
0`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol00goo0P0017oo00<007ooOol00Woo00<0
07ooOol01Woo00<007ooOol027oo00<007ooOol01Woo00<007ooOol01goo00<007oo00001Woo00<0
07ooOol02Goo00<007ooOol017oo00<007ooOol01goo00<007ooOol00goo00@007ooOol000Qoo`03
001oogoo00Qoo`03001oogoo011oo`03001oogoo00Moo`03001oogoo009oo`07001oogooOol007oo
00000goo00<007ooOol00goo00<007ooOol00goo00<007oo00004Woo00<007ooOol03goo0P002goo
00<007ooOol00Woo00<007oo00001goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol02goo
00<007oo00000Woo00<007ooOol01Goo00<007ooOol01Goo00@007ooOol0011oo`03001oo`00009o
o`03001oogoo00=oo`03001oogoo00=oo`08001oogoo001oo`00Ool000Aoo`03001oogoo008000Mo
o`03001oogoo00aoo`0087oo00<007ooOol037oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oo`0000Eoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00Ioo`04001oogoo000:Ool50003Ool00`00Oomoo`04Ool00`00Oomo
o`07Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0JOol01000Oomo
ogoo0P001Goo00D007ooOomoo`0000Eoo`8000Aoo`03001oogoo019oo`03001oogoo00moo`03001o
ogoo00Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`04001oogooOol5000:Ool0
1P00Oomoo`00Ool000Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00=oo`03001oo`0000Aoo`03001oogoo009oo`05001oogoo
Ool00007Ool00`00Oomoo`0<Ool0021oo`03001oogoo00]oo`03001oogoo00=oo`05001oogooOol0
0004Ool00`00Ool00005Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomo
o`03Ool00`00Oomoo`07Ool00`00Oomoo`05Ool01@00Oomoogoo00002Woo00<007ooOol00Woo00<0
07oo00001goo00<007ooOol01goo00<007ooOol017oo00<007ooOol027oo00<007ooOol09Woo00H0
07ooOol007oo0004Ool01@00Oomoogoo000017oo00@007ooOol0009oo`03001oogoo02Eoo`03001o
ogoo00Uoo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Eoo`03001oo`0000Aoo`03001o
ogoo00Qoo`05001oogooOol00008Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Ool00004Ool01@00Oomoogoo0000
1Goo00<007ooOol04goo000POol00`00Oomoo`0;Ool00`00Oomoo`03Ool01@00Oomoogoo000017oo
00<007oo00001Goo00<007ooOol00goo00<007ooOol00goo00<007ooOol027oo00<007oo000017oo
00<007ooOol01goo00<007ooOol01Goo00D007ooOomoo`0000Uoo`03001oogoo00Aoo`8000Moo`03
001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo02Ioo`03001oo`00009oo`05
001oogooOol00005Ool01@00Oomoogoo00000Woo00@007ooOol002Moo`03001oogoo00Uoo`03001o
ogoo00Aoo`03001oogoo00Ioo`03001oogoo00Eoo`8000Ioo`03001oogoo00Moo`05001oogooOol0
0008Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Ool0000;Ool00`00Oomoo`02Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Ool00005Ool01000Oomoo`001Goo00<007ooOol04goo000POol0
0`00Oomoo`0:Ool00`00Oomoo`05Ool01000Oomoo`0017oo0P001goo00D007ooOomoo`0000Ioo`03
001oogoo00Qoo`03001oo`0000Aoo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo00Ioo`03001oogoo00Eoo`03001oogoo00Eoo`03
001oogoo00Qoo`03001oogoo02Ioo`03001oo`00009oo`05001oogooOol00005Ool01@00Oomoogoo
00000goo00<007oo00009goo00<007ooOol027oo00<007ooOol01Goo00<007ooOol01Goo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol01goo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool01Woo00<007ooOol00Woo00<007oo00002goo00<007ooOol00goo00D007ooOomoo`0000Moo`80
00Eoo`04001oogoo0006Ool00`00Oomoo`0BOol0021oo`03001oogoo00Uoo`03001oogoo00Ioo`04
001oogoo0005Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo00<007ooOol01goo00D007ooOomo
o`0000=oo`03001oogoo00Moo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo00moo`03001oogoo00Eoo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo02Qoo`03001o
ogoo009oo`04001oogoo0005Ool01000Oomoo`001Goo00<007ooOol09goo00<007ooOol01goo00<0
07ooOol01Goo00<007ooOol01Goo00<007ooOol03goo00<007ooOol01Goo00<007ooOol00goo00<0
07ooOol01Goo00<007ooOol01Woo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo00=o
o`05001oogooOol00007Ool00`00Oomoo`04Ool00`00Ool00008Ool00`00Oomoo`0AOol0021oo`03
001oogoo00Uoo`03001oogoo00Moo`03001oo`0000Eoo`03001oogoo00Eoo`D000Ioo`03001oogoo
00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool00`00Oomoo`0@Ool00`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00
Oomoo`0]Ool01000Oomoo`001Goo00@007ooOol002moo`03001oogoo00Moo`03001oogoo00Eoo`03
001oogoo00Eoo`03001oogoo011oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Eoo`03
001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`08Ool00`00Oomoo`03Ool50007Ool00`00Oomo
o`04Ool00`00Ool00008Ool00`00Oomoo`0AOol0021oo`03001oogoo00Qoo`03001oogoo00Qoo`80
01Uoo`03001oogoo00Moo`05001oogooOol00002Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`0AOol00`00Oomoo`03Ool00`00Oomoo`07Ool00`00
Oomoo`06Ool00`00Oomoo`0]Ool01000Oomoo`001Goo00@007ooOol002moo`03001oogoo00Ioo`03
001oogoo00Moo`03001oogoo00=oo`03001oogoo015oo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Eoo`03001oogoo00Moo`04001oogoo0003Ool00`00Oomoo`07Ool00`00Oomoo`0GOol0
0`00Ool00009Ool00`00Oomoo`0@Ool0021oo`8000Uoo`03001oogoo00Qoo`8001Yoo`03001oogoo
00Eoo`03001oogoo00=oo`03001oo`0000Yoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`<0031oo`03
001oo`0000Eoo`03001oo`00031oo`<000Ioo`03001oogoo00Moo`03001oogoo00=oo`03001oogoo
019oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Moo`03001oo`00
00Eoo`03001oogoo00Ioo`03001oogoo01Qoo`03001oogoo00Qoo`03001oogoo011oo`0087oo00<0
07ooOol01goo00<007ooOol02Woo00<007ooOol067oo00<007ooOol01Goo00<007ooOol00goo0P00
2goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol04Woo00<007ooOol0
0goo00<007ooOol01goo00@007ooOomoo`<003=oo`03001oo`0000Eoo`03001oo`0003=oo`<000=o
o`03001oogoo00Moo`03001oogoo00=oo`03001oogoo019oo`03001oogoo00=oo`03001oogoo00=o
o`03001oogoo00Eoo`03001oogoo00Qoo`8000Eoo`03001oogoo00Ioo`03001oogoo01Qoo`03001o
ogoo00Uoo`03001oogoo00moo`0087oo00<007ooOol01goo00<007ooOol09Goo0P0017oo0P001goo
00<007ooOol02Goo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`0001Ioo`05001oogoo
Ool0000;Ool3000fOol20007Ool2000fOol3000;Ool01@00Oomoogoo00005Woo00D007ooOomoo`00
00Ioo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo00Eoo`8000Eoo`8002Ioo`03001oogoo
00moo`0087oo00<007ooOol01Woo00<007ooOol0:7oo00@007oo000001Eoo`03001oogoo00Aoo`03
001oogoo00Aoo`05001oogooOol0000FOol01000Oomoo`0037oo00<007ooOol0=goo00<007ooOol0
1Goo00<007ooOol0=goo00<007ooOol02Woo00@007ooOol001Ioo`05001oogooOol00006Ool00`00
Oomoo`05Ool00`00Oomoo`0BOol200000goo0000000YOol00`00Oomoo`0>Ool0021oo`03001oogoo
00Ioo`03001oogoo02Uoo`03001oogoo01Eoo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo
000GOol01000Oomoo`00AWoo00<007ooOol01Goo00<007ooOol0A7oo00@007ooOol001Moo`04001o
ogoo0006Ool00`00Oomoo`05Ool00`00Oomoo`0DOol00`00Oomoo`0YOol00`00Oomoo`0>Ool0021o
o`03001oogoo00Eoo`03001oogoo049oo`03001oogoo00Aoo`03001oogoo00Aoo`04001oogoo000H
Ool2002GOol2000HOol01000Oomoo`001Woo00<007ooOol01Goo00<007ooOol0@Goo00<007ooOol0
3Goo000POol00`00Oomoo`05Ool00`00Oomoo`12Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Ool0000IOol00`00Oomoo`2GOol00`00Oomoo`0GOol00`00Ool00006Ool00`00Oomoo`05Ool00`00
Oomoo`11Ool00`00Oomoo`0=Ool0021oo`03001oogoo00Aoo`03001oogoo04=oo`03001oogoo00Ao
o`03001oogoo00Eoo`800<eoo`8000Moo`03001oogoo00Eoo`03001oogoo049oo`03001oogoo00ao
o`0087oo00<007ooOol017oo00<007ooOol0@goo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool0cGoo00<007ooOol01Goo00<007ooOol01Goo00<007ooOol0DGoo000POol20004Ool00`00Oomo
o`14Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00Oomoo`05Ool00`00Oomoo`1AOol0021oo`03
001oogoo00=oo`03001oogoo04Aoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00Eoo`03
001oogoo055oo`0087oo00<007ooOol00Woo00<007ooOol0AGoo00<007ooOol017oo00<007ooOol0
gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol01@00Oomoogoo0000B7oo00<007ooOol017oo
00<007ooOol0gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol01@00Oomoogoo0000B7oo00<0
07ooOol017oo00<007ooOol0gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol01000Oomoo`00
BGoo00<007ooOol017oo00<007ooOol0gGoo00<007ooOol01Goo00<007ooOol0DGoo000POol00`00
Oomoo`1:Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00Oomoo`05Ool00`00Oomoo`1AOol0021o
o`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00Eoo`03001oogoo055o
o`0087oo00<007ooOol0BWoo00<007ooOol017oo00<007ooOol0gGoo00<007ooOol01Goo00<007oo
Ool0DGoo000POol2001;Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00Oomoo`05Ool00`00Oomo
o`1AOol0021oo`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo0=eoo`03001oogoo00Aoo`03
001oogoo059oo`0087oo00<007ooOol0BWoo00<007ooOol017oo00<007ooOol0gGoo00<007ooOol0
17oo00<007ooOol0DWoo000POol00`00Oomoo`1:Ool00`00Oomoo`04Ool00`00Oomoo`3MOol00`00
Oomoo`04Ool00`00Oomoo`1BOol0021oo`03001oogoo04Yoo`03001oogoo00Aoo`03001oogoo0=eo
o`03001oogoo00Aoo`03001oogoo059oo`0087oo00<007ooOol0BWoo00<007ooOol00goo00<007oo
Ool0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1:Ool00`00Oomoo`03Ool0
0`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04Yoo`03001oogoo
00=oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0BWoo00<0
07ooOol00goo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol2001<Ool00`00
Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]o
o`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007oo
Ool0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol0
0`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0
021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo
059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<0
07ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03
Ool00`00Oomoo`1BOol000=oo`8000Moo`<000Eoo`D000Moo`03001oogoo04]oo`03001oogoo009o
o`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`000Woo00@007ooOol000Ioo`<000Mo
o`03001oogoo00Moo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=o
o`03001oogoo059oo`0000=oo`00Ool00goo00<007ooOol00goo0`001goo00<007ooOol01goo00<0
07ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo0000
0goo001oo`03Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool3001;Ool00`00Oomoo`02Ool00`00Oomo
o`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol00003Ool007oo00=oo`03001oogoo00eoo`03001o
ogoo00Moo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001o
ogoo059oo`0000=oo`00Ool00goo00<007ooOol03Goo00<007ooOol01goo00<007ooOol0Bgoo00<0
07ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo00000goo001oo`03Ool0
0`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol0
0`00Oomoo`03Ool00`00Oomoo`1BOol0009oo`04001oogoo000>Ool30009Ool00`00Oomoo`1;Ool0
0`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol000=oo`80011oo`80
00Uoo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo
059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<0
07ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03
Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001o
ogoo00=oo`03001oogoo059oo`0087oo0P00C7oo00<007ooOol00Woo00<007ooOol0ggoo00<007oo
Ool00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol0
0`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo
0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<0
07ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02
Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001o
ogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0Bgoo
00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomo
o`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03
001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`00
87oo0P00C7oo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000P
Ool00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1B
Ool0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001o
ogoo059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo
00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomo
o`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03
001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0
ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00
Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009o
o`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo0P00C7oo00<007ooOol00Woo
00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00Oomoo`1;Ool00`00Oomo
o`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021oo`03001oogoo04]oo`03
001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059oo`0087oo00<007ooOol0
Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007ooOol0DWoo000POol00`00
Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool00`00Oomoo`1BOol0021o
o`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo00=oo`03001oogoo059o
o`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<007ooOol00goo00<007oo
Ool0DWoo000POol00`00Oomoo`1;Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00Oomoo`03Ool0
0`00Oomoo`1BOol0021oo`03001oogoo04]oo`03001oogoo009oo`03001oogoo0=moo`03001oogoo
009oo`03001oogoo05=oo`0087oo00<007ooOol0Bgoo00<007ooOol00Woo00<007ooOol0ggoo00<0
07ooOol00Woo00<007ooOol0Dgoo000POol2001<Ool00`00Oomoo`02Ool00`00Oomoo`3OOol00`00
Oomoo`02Ool00`00Oomoo`1COol0021oo`03001oogoo04]oo`05001oogooOol0003SOol01@00Oomo
ogoo0000EGoo000POol00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`00
87oo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001EOol0021oo`03001oogoo
04]oo`05001oogooOol0003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1;Ool01@00Oomo
ogoo0000hgoo00D007ooOomoo`0005Eoo`000goo0P001goo0`0017oo1P001goo00<007ooOol0Bgoo
00D007ooOomoo`000>=oo`05001oogooOol0001EOol0009oo`04001oogoo0006Ool30005Ool01@00
Oomoogoo00001goo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001EOol00003
Ool007oo00=oo`03001oogoo00=oo`<000Ioo`03001oogoo00Qoo`03001oogoo04]oo`05001oogoo
Ool0003SOol01@00Oomoogoo0000EGoo00000goo001oo`03Ool00`00Oomoo`0=Ool00`00Oomoo`07
Ool3001;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`0000=oo`00Ool00goo00<007oo
Ool03Woo00<007ooOol01Woo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001E
Ool00003Ool007oo00=oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo04]oo`05001oogoo
Ool0003SOol01@00Oomoogoo0000EGoo00000goo001oo`03Ool00`00Oomoo`0?Ool00`00Oomoo`05
Ool00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`000Woo00@007ooOol0
00eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo04]oo`05001oogooOol0003SOol01@00
Oomoogoo0000EGoo0003Ool2000?Ool40008Ool00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D0
07ooOomoo`0005Eoo`0087oo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001E
Ool0021oo`03001oogoo04]oo`05001oogooOol0003SOol01@00Oomoogoo0000EGoo000POol00`00
Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`0087oo0P00C7oo00D007ooOomo
o`000>=oo`05001oogooOol0001EOol0021oo`03001oogoo04]oo`05001oogooOol0003SOol01@00
Oomoogoo0000EGoo000POol00`00Oomoo`1;Ool01@00Oomoogoo0000hgoo00D007ooOomoo`0005Eo
o`0087oo00<007ooOol0Bgoo00D007ooOomoo`000>=oo`05001oogooOol0001EOol0021oo`03001o
ogoo04]oo`05001oogooOol0003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1;Ool01@00
Oomoogoo0000hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05
001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo
000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo0P00CGoo00@0
07ooOol00>=oo`05001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00
Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`00
87oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogooOol0001EOol0021oo`03001oogoo04ao
o`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo
00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogooOol0001E
Ool0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomo
o`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo0P00CGoo00@007ooOol00>=oo`05
001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo
000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0
C7oo00@007ooOol00>=oo`05001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003S
Ool01@00Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`00
05Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogooOol0001EOol0021oo`03001o
ogoo04aoo`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomoo`1<Ool01000Oomo
o`00hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol00>=oo`05001oogoo
Ool0001EOol0021oo`8004eoo`04001oogoo003SOol01@00Oomoogoo0000EGoo000POol00`00Oomo
o`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo00<007ooOol0C7oo00@007ooOol0
0>=oo`05001oogooOol0001EOol0021oo`03001oogoo04aoo`04001oogoo003SOol01@00Oomoogoo
0000EGoo000POol00`00Oomoo`1<Ool01000Oomoo`00hgoo00D007ooOomoo`0005Eoo`0087oo00<0
07ooOol0C7oo00@007ooOol00>=oo`04001oogoo001FOol000=oo`8000Moo`<000Eoo`@000Qoo`03
001oogoo04aoo`04001oogoo003SOol01000Oomoo`00EWoo0002Ool01000Oomoo`001Woo0`0017oo
00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo
00000goo001oo`03Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool00`00
Ool0003UOol00`00Ool0001FOol00003Ool007oo00=oo`03001oogoo00moo`03001oogoo00Eoo`<0
04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0000=oo`00Ool00goo00<007ooOol037oo0`0027oo
00<007ooOol0C7oo00<007oo0000iGoo00<007oo0000EWoo00000goo001oo`03Ool00`00Oomoo`0?
Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol00003Ool007oo
00=oo`03001oogoo00moo`03001oogoo00Eoo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`00
05Ioo`000Woo00@007ooOol000eoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo04aoo`03
001oo`000>Eoo`03001oo`0005Ioo`000goo0P003goo100027oo00<007ooOol0C7oo00<007oo0000
iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021o
o`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo
0000iGoo00<007oo0000EWoo000POol2001=Ool00`00Ool0003UOol00`00Ool0001FOol0021oo`03
001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo0000
iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0021o
o`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo
0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0
021oo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<0
07oo0000iGoo00<007oo0000EWoo000POol2001=Ool00`00Ool0003UOol00`00Ool0001FOol0021o
o`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<007oo
0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001FOol0
021oo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<0
07oo0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001F
Ool0021oo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo
00<007oo0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0
001FOol0021oo`8004eoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo00<0
07oo0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0001F
Ool0021oo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo
00<007oo0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0
001FOol0021oo`03001oogoo04aoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0
C7oo00<007oo0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00
Ool0001FOol0021oo`8004eoo`03001oo`000>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0C7oo
00<007oo0000iGoo00<007oo0000EWoo000POol00`00Oomoo`1<Ool00`00Ool0003UOol00`00Ool0
001FOol0021oo`03001oogoo04eoo`800>Eoo`03001oo`0005Ioo`0087oo00<007ooOol0CGoo0P00
iGoo00<007oo0000EWoo000POol00`00Oomoo`1=Ool2003UOol00`00Ool0001FOol000=oo`8000Mo
o`<000Moo`<000Moo`03001oogoo04eoo`800>Eoo`03001oo`0005Ioo`000Woo00@007ooOol000Io
o`<000Qoo`03001oogoo00Ioo`03001oogoo04eoo`800>Eoo`03001oo`0005Ioo`0000=oo`00Ool0
0goo00<007ooOol00goo0`0017oo1P001goo00<007ooOol0CGoo0P00iGoo00<007oo0000EWoo0000
0goo001oo`03Ool00`00Oomoo`0:Ool01@00Oomoogoo000027oo0`00CGoo0P00iGoo00<007oo0000
EWoo00000goo001oo`03Ool00`00Oomoo`0;Ool01000Oomoo`0027oo00<007ooOol0CGoo0P00iGoo
00<007oo0000EWoo00000goo001oo`03Ool00`00Oomoo`0<Ool00`00Ool00008Ool00`00Oomoo`1=
Ool2003UOol00`00Ool0001FOol00003Ool007oo00=oo`03001oogoo00aoo`03001oo`0000Qoo`03
001oogoo04eoo`800>Eoo`8005Moo`000Woo00@007ooOol0011oo`8000Qoo`03001oogoo04eoo`03
001oogoo0>Eoo`03001oogoo05Eoo`000goo0P004Woo00<007ooOol01Woo00<007ooOol0CGoo00<0
07ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1E
Ool0021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo
00<007ooOol0iGoo00<007ooOol0EGoo000POol2001>Ool00`00Oomoo`3UOol00`00Oomoo`1EOol0
021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo00<0
07ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomoo`1E
Ool0021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo
00<007ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomo
o`1EOol0021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0
CGoo00<007ooOol0iGoo00<007ooOol0EGoo000POol2001>Ool00`00Oomoo`3UOol00`00Oomoo`1E
Ool0021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0CGoo
00<007ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00Oomo
o`1EOol0021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0
CGoo00<007ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol00`00
Oomoo`1EOol0021oo`03001oogoo04eoo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007oo
Ool0CGoo00<007ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`1=Ool00`00Oomoo`3UOol0
0`00Oomoo`1EOol0021oo`8004ioo`03001oogoo0>Eoo`03001oogoo05Eoo`0087oo00<007ooOol0
CGoo00<007ooOol0iGoo00<007ooOol0EGoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo
0?moohioo`0087oo00<007ooOol0ogooSWoo000POol00`00Oomoo`3oOon>Ool0021oo`03001oogoo
0?moohioo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.812, 0}} -> {-8, 0, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0141895 0.00962001 0.309017 1.44702 [
[.20659 .29652 -6 -9 ]
[.20659 .29652 6 0 ]
[.39899 .29652 -6 -9 ]
[.39899 .29652 6 0 ]
[.59139 .29652 -6 -9 ]
[.59139 .29652 6 0 ]
[.78379 .29652 -6 -9 ]
[.78379 .29652 6 0 ]
[.97619 .29652 -9 -9 ]
[.97619 .29652 9 0 ]
[.00169 .01961 -24 -4.5 ]
[.00169 .01961 0 4.5 ]
[.00169 .16431 -24 -4.5 ]
[.00169 .16431 0 4.5 ]
[.00169 .45372 -18 -4.5 ]
[.00169 .45372 0 4.5 ]
[.00169 .59842 -18 -4.5 ]
[.00169 .59842 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.20659 .30902 m
.20659 .31527 L
s
[(20)] .20659 .29652 0 1 Mshowa
.39899 .30902 m
.39899 .31527 L
s
[(40)] .39899 .29652 0 1 Mshowa
.59139 .30902 m
.59139 .31527 L
s
[(60)] .59139 .29652 0 1 Mshowa
.78379 .30902 m
.78379 .31527 L
s
[(80)] .78379 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(100)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.06229 .30902 m
.06229 .31277 L
s
.11039 .30902 m
.11039 .31277 L
s
.15849 .30902 m
.15849 .31277 L
s
.25469 .30902 m
.25469 .31277 L
s
.30279 .30902 m
.30279 .31277 L
s
.35089 .30902 m
.35089 .31277 L
s
.44709 .30902 m
.44709 .31277 L
s
.49519 .30902 m
.49519 .31277 L
s
.54329 .30902 m
.54329 .31277 L
s
.63949 .30902 m
.63949 .31277 L
s
.68759 .30902 m
.68759 .31277 L
s
.73569 .30902 m
.73569 .31277 L
s
.83189 .30902 m
.83189 .31277 L
s
.87999 .30902 m
.87999 .31277 L
s
.92809 .30902 m
.92809 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
.01419 .01961 m
.02044 .01961 L
s
[(-0.2)] .00169 .01961 1 0 Mshowa
.01419 .16431 m
.02044 .16431 L
s
[(-0.1)] .00169 .16431 1 0 Mshowa
.01419 .45372 m
.02044 .45372 L
s
[(0.1)] .00169 .45372 1 0 Mshowa
.01419 .59842 m
.02044 .59842 L
s
[(0.2)] .00169 .59842 1 0 Mshowa
.125 Mabswid
.01419 .04855 m
.01794 .04855 L
s
.01419 .07749 m
.01794 .07749 L
s
.01419 .10643 m
.01794 .10643 L
s
.01419 .13537 m
.01794 .13537 L
s
.01419 .19326 m
.01794 .19326 L
s
.01419 .2222 m
.01794 .2222 L
s
.01419 .25114 m
.01794 .25114 L
s
.01419 .28008 m
.01794 .28008 L
s
.01419 .33796 m
.01794 .33796 L
s
.01419 .3669 m
.01794 .3669 L
s
.01419 .39584 m
.01794 .39584 L
s
.01419 .42478 m
.01794 .42478 L
s
.01419 .48266 m
.01794 .48266 L
s
.01419 .5116 m
.01794 .5116 L
s
.01419 .54054 m
.01794 .54054 L
s
.01419 .56948 m
.01794 .56948 L
s
.25 Mabswid
.01419 0 m
.01419 .61803 L
s
.5 Mabswid
.02381 .30902 m
.03343 .33293 L
.04305 .3258 L
.05267 .29552 L
.06229 .30764 L
.07191 .2931 L
.08153 .31667 L
.09115 .29103 L
.10077 .27861 L
.11039 .30877 L
.12001 .26786 L
.12963 .30184 L
.13925 .30263 L
.14887 .28545 L
.15849 .23725 L
.16811 .34568 L
.17773 .27583 L
.18735 .3371 L
.19697 .29224 L
.20659 .31728 L
.21621 .60332 L
.22583 .29194 L
.23545 .29732 L
.24507 .28846 L
.25469 .32653 L
.26431 .3064 L
.27393 .27911 L
.28355 .31295 L
.29317 .38391 L
.30279 .31985 L
.31241 .30754 L
.32203 .29941 L
.33165 .31397 L
.34127 .35471 L
.35089 .33204 L
.36051 .30595 L
.37013 .30426 L
.37975 .32938 L
.38937 .29328 L
.39899 .27284 L
.40861 .27985 L
.41823 .33827 L
.42785 .30942 L
.43747 .31987 L
.44709 .31116 L
.45671 .28679 L
.46633 .27935 L
.47595 .33048 L
.48557 .3535 L
.49519 .32496 L
Mistroke
.50481 .30902 L
.51443 .29307 L
.52405 .26453 L
.53367 .28756 L
.54329 .33868 L
.55291 .33124 L
.56253 .30688 L
.57215 .29816 L
.58177 .30861 L
.59139 .27977 L
.60101 .33819 L
.61063 .34519 L
.62025 .32475 L
.62987 .28865 L
.63949 .31377 L
.64911 .31209 L
.65873 .286 L
.66835 .26332 L
.67797 .30406 L
.68759 .31863 L
.69721 .31049 L
.70683 .29818 L
.71645 .23412 L
.72607 .30508 L
.73569 .33892 L
.74531 .31164 L
.75493 .2915 L
.76455 .32957 L
.77417 .32072 L
.78379 .3261 L
.79341 .01472 L
.80303 .30076 L
.81265 .32579 L
.82227 .28093 L
.83189 .3422 L
.84151 .27236 L
.85113 .38078 L
.86075 .33258 L
.87037 .3154 L
.87999 .31619 L
.88961 .35017 L
.89923 .30927 L
.90885 .33942 L
.91847 .327 L
.92809 .30136 L
.93771 .32494 L
.94733 .3104 L
.95695 .32252 L
.96657 .29223 L
.97619 .28511 L
Mistroke
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6
Ool002Qoo`03001oogoo0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6
Ool000aoo`8000Moo`<000Aoo`H000Ioo`03001oogoo0?moobmoo`03001oogoo05Aoo`002goo00@0
07ooOol000Ioo`<000Eoo`05001oogooOol00006Ool00`00Oomoo`3oOol_Ool00`00Oomoo`1DOol0
00Yoo`03001oogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Moo`@00?moobioo`03001o
ogoo05Aoo`0000=oo`0000001@000Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo
00<007ooOol0ogoo;goo00<007ooOol0E7oo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00
Oomoo`05Ool00`00Oomoo`3oOol_Ool00`00Oomoo`1DOol000Yoo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Aoo`03001oogoo0?moobmoo`03001oogoo05Aoo`002Woo00<007ooOol00Woo
00<007ooOol03goo00<007ooOol017oo00<007ooOol0ogoo;goo00<007ooOol0E7oo000;Ool01000
Oomoo`003Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0ogoo;goo00<007ooOol0E7oo
000<Ool2000?Ool40007Ool00`00Oomoo`3oOol_Ool00`00Oomoo`1DOol002Qoo`03001oogoo0?mo
obmoo`03001oogoo05Aoo`00:7oo00<007ooOol0ogoo;goo00<007ooOol0E7oo000XOol00`00Oomo
o`3oOol_Ool00`00Oomoo`1DOol002Qoo`03001oogoo0?moobmoo`03001oogoo05Aoo`00:7oo00<0
07ooOol0ogoo;goo00<007ooOol0E7oo000XOol3003oOol_Ool00`00Oomoo`1DOol002Qoo`03001o
ogoo0?moobmoo`8005Eoo`00:7oo00<007ooOol0ogoo;goo0P00EGoo000XOol00`00Oomoo`3oOol_
Ool2001EOol002Qoo`03001oogoo0?moobmoo`8005Eoo`00:7oo00<007ooOol0ogoo;goo0P00EGoo
000XOol00`00Oomoo`3oOol_Ool2001EOol002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00
:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00Ool0001E
Ool002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00:7oo0`00ogoo;Woo00<007oo0000EGoo
000XOol00`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001oogoo0?moobioo`03001oo`00
05Eoo`00:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00
Ool0001EOol002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00:7oo00<007ooOol0ogoo;Woo
00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001oogoo0?mo
obioo`03001oo`0005Eoo`00:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol00`00Oomo
o`3oOol^Ool00`00Ool0001EOol002Qoo`<00?moobioo`03001oo`0005Eoo`00:7oo00<007ooOol0
ogoo;Woo00<007oo0000EGoo000XOol00`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001o
ogoo0?moobioo`03001oo`0005Eoo`00:7oo00<007ooOol0ogoo;Woo00<007oo0000EGoo000XOol0
0`00Oomoo`3oOol^Ool00`00Ool0001EOol002Qoo`03001oogoo0?moobioo`03001oo`0005Eoo`00
:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol0
05Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@0
07ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo0`00ogoo;Woo00@0
07ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo
;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007oo
Ool0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo
00<007ooOol0ogoo;Woo00@007ooOol005Aoo`00:7oo00<007ooOol0ogoo;Woo00@007ooOol005Ao
o`0037oo0P001goo0`001Goo1@001Woo00<007ooOol0ogoo;Woo00@007ooOol005Aoo`002goo00@0
07ooOol000Ioo`<000Moo`03001oogoo00Ioo`03001oogoo0?moobioo`04001oogoo001DOol000Yo
o`03001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Ioo`03001oogoo0?moobioo`04
001oogoo001DOol00003Ool0000000D0009oo`03001oogoo009oo`03001oogoo00eoo`03001oogoo
00Ioo`@00?moobeoo`04001oogoo001DOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001o
ogoo00Ioo`03001oogoo0?moobioo`04001oogoo001DOol000Yoo`03001oogoo009oo`03001oogoo
00eoo`03001oogoo00Ioo`03001oogoo0?moobioo`04001oogoo001DOol000Yoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo0?moobeoo`05001oogooOol0001DOol000]o
o`04001oogoo000>Ool30008Ool00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000<Ool2000@
Ool20008Ool00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool0
1@00Oomoogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol00`00
Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool01@00Oomoogoo0000
E7oo000XOol00`00Oomoo`3oOol]Ool01@00Oomoogoo0000E7oo000XOol3003oOol]Ool01@00Oomo
ogoo0000E7oo000XOol00`00Oomoo`3oOol]Ool00`00Oomoo`02Ool00`00Oomoo`1AOol002Qoo`03
001oogoo0?moobeoo`03001oogoo009oo`03001oogoo055oo`00:7oo00<007ooOol0ogoo;Goo00<0
07ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`3oOol]Ool00`00Oomoo`02Ool00`00Oomo
o`1AOol002Qoo`03001oogoo0?moobeoo`03001oogoo009oo`03001oogoo055oo`00:7oo00<007oo
Ool0ogoo;Goo00<007ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`3oOol]Ool00`00Oomo
o`02Ool00`00Oomoo`1AOol002Qoo`03001oogoo0?moobeoo`03001oogoo009oo`03001oogoo055o
o`00:7oo00<007ooOol0ogoo;Goo00<007ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`3o
Ool]Ool00`00Oomoo`02Ool00`00Oomoo`1AOol002Qoo`03001oogoo0?moobeoo`03001oogoo009o
o`03001oogoo055oo`00:7oo0`00ogoo;Goo00<007ooOol00Woo00<007ooOol0DGoo000XOol00`00
Oomoo`3oOol]Ool00`00Oomoo`02Ool00`00Oomoo`1AOol002Qoo`03001oogoo0?moobeoo`03001o
ogoo009oo`03001oogoo055oo`00:7oo00<007ooOol0ogoo;Goo00<007ooOol00Woo00<007ooOol0
DGoo000XOol00`00Oomoo`3oOolAOol00`00Oomoo`0IOol00`00Oomoo`02Ool00`00Oomoo`1AOol0
02Qoo`03001oogoo03Ioo`03001oogoo0=Moo`03001oogoo01Uoo`03001oogoo009oo`03001oogoo
055oo`00:7oo00<007ooOol0=Woo00<007ooOol0egoo00<007ooOol06Goo00<007ooOol00Woo00<0
07ooOol0DGoo000XOol00`00Oomoo`0fOol00`00Oomoo`3GOol00`00Oomoo`0IOol00`00Oomoo`02
Ool00`00Oomoo`1AOol002Qoo`03001oogoo03Eoo`800=Uoo`8001Yoo`03001oogoo009oo`03001o
ogoo055oo`00:7oo00<007ooOol0=Goo0P00f7oo00<007oo00006Woo00<007ooOol00Woo00<007oo
Ool0DGoo000XOol00`00Oomoo`0eOol2003HOol00`00Ool0000JOol00`00Oomoo`02Ool00`00Oomo
o`1AOol002Qoo`<003Eoo`03001oo`000=Moo`03001oo`0001Yoo`03001oogoo009oo`03001oogoo
055oo`00:7oo00<007ooOol0=Goo00<007oo0000egoo00<007oo00006Woo00<007ooOol00Woo00<0
07ooOol0DGoo000XOol00`00Oomoo`0dOol01000Oomoo`00egoo00<007oo00006Woo00<007ooOol0
0Woo00<007ooOol0DGoo000XOol00`00Oomoo`0dOol01000Oomoo`00egoo00<007oo00006Woo00<0
07ooOol00Woo00<007ooOol0DGoo000XOol00`00Oomoo`0dOol01000Oomoo`00egoo00@007ooOol0
01Uoo`03001oogoo009oo`03001oogoo055oo`00:7oo00<007ooOol0=7oo00@007ooOol008eoo`03
001oogoo03Eoo`03001oogoo00moo`04001oogoo000IOol00`00Oomoo`02Ool00`00Oomoo`1AOol0
02Qoo`03001oogoo02Moo`03001oogoo00Yoo`04001oogoo002=Ool00`00Oomoo`0eOol00`00Oomo
o`0>Ool01@00Oomoogoo00006Goo00<007ooOol00goo00<007ooOol0D7oo000XOol00`00Oomoo`0W
Ool00`00Oomoo`09Ool01@00Oomoogoo0000S7oo00<007oo0000=Goo0P0047oo00D007ooOomoo`00
01Uoo`03001oogoo00=oo`03001oogoo051oo`00:7oo00<007ooOol09goo00<007ooOol02Goo00D0
07ooOomoo`0000Uoo`H000Eoo`80045oo`<0009oo`800003Ool0000002]oo`03001oo`00015oo`@0
00Ioo`8001Qoo`03001oo`0000moo`05001oogooOol0000AOol40004Ool01000Ool000000Woo00<0
07ooOol037oo00<007ooOol09goo1@001Goo0P001goo0P001Goo000XOol00`00Oomoo`0VOol00`00
Ool0000:Ool01@00Oomoogoo00002Woo00D007ooOomoo`0000Aoo`04001oogoo0011Ool01`00Oomo
ogoo001oo`00009oo`03001oogoo02Qoo`04001oogoo000?Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool01000Oomoo`005goo00<007oo00003goo00D007ooOomoo`00011oo`03001oogoo009oo`04001o
ogooOol20002Ool00`00Ool0000>Ool00`00Oomoo`0YOol00`00Oomoo`04Ool01000Oomoo`001Goo
00@007ooOol000Aoo`00:7oo00<007ooOol09Woo00<007oo00002Woo00D007ooOomoo`0000Eoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo03Yoo`H00006Ool007oo001o
o`000Woo00<007ooOol09Woo00D007ooOomoo`0000moo`03001oogoo009oo`05001oogooOol00004
Ool00`00Oomoo`0COol01000Oomoo`003goo00D007ooOomoo`00011oo`03001oogoo009oo`03001o
ogoo008000Aoo`8000ioo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool002Qoo`<001moo`03001oogoo00Aoo`03001oo`0000Yoo`03001o
ogoo009oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001o
ogoo015oo`03001oogoo02Ioo`05001oogooOol00002Ool00`00Ool00002Ool00`00Ool0000COol0
0`00Oomoo`0BOol01@00Oomoogoo00003goo00<007ooOol00Woo00<007ooOol00P0017oo00<007oo
Ool04goo00@007ooOol000moo`03001oogoo009oo`03001oogoo00eoo`03001oogoo009oo`03001o
ogoo008000Aoo`8000ioo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`01Ool002Qoo`03001oogoo01moo`03001oogoo00Aoo`04001oogoo0008
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol00`00Oomoo`0WOol01P00Oomoo`00Ool0009oo`06001oogoo001oo`004Woo
0P0057oo00<007ooOol00Woo00<007ooOol037oo0P000goo00<007ooOol00P0017oo00<007ooOol0
4goo00D007ooOomoo`0000ioo`03001oogoo009oo`03001oogoo00ioo`@000=oo`8000Aoo`8000Mo
o`03001oogoo00Aoo`03001oogoo02Uoo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol0
0004Ool00`00Oomoo`01Ool002Qoo`03001oogoo01ioo`03001oo`0000Aoo`05001oogooOol00008
Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo000017oo00<007oo
Ool047oo0P00:Woo00D007oo001oo`00009oo`06001oogoo001oo`004Goo00<007oo00004goo00<0
07ooOol00goo00<007ooOol037oo00<007oo00000P000goo0P0017oo00<007ooOol04Woo00<007oo
Ool00Woo00<007ooOol037oo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol00Woo00<007oo
Ool00P0017oo0P001goo00<007ooOol017oo00<007ooOol0:Goo00<007ooOol00goo00H007oo0000
07oo0003Ool00`00Oomoo`02Ool00`00Oomoo`01Ool002Qoo`03001oogoo01eoo`04001oogoo0004
Ool01@00Oomoogoo000027oo00<007ooOol00goo00<007ooOol00Woo0P001goo00D007ooOomoo`00
00Aoo`03001oogoo011oo`03001oo`0002Uoo`04001oo`000003Ool01P00Oomoo`00Ool0011oo`05
001oogooOol0000BOol00`00Oomoo`04Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool30004Ool00`00
Oomoo`0BOol00`00Oomoo`02Ool00`00Oomoo`0<Ool00`00Oomoo`02Ool00`00Oomoo`0=Ool00`00
Oomoo`02Ool00`00Oomoo`020004Ool20007Ool00`00Oomoo`03Ool00`00Ool0000ZOol00`00Oomo
o`03Ool20003Ool01@00Oomoogoo000017oo00<007ooOol00Goo000XOol00`00Oomoo`0MOol01000
Oomoo`0017oo00D007ooOomoo`0000Moo`03001oogoo00Aoo`07001oogooOol007oo00000Woo00<0
07ooOol00Woo00<007ooOol00Woo00@007ooOol000Qoo`8000Uoo`03001oo`0002Yoo`<000Aoo`04
001oogoo000AOol01@00Oomoogoo00004Woo00<007ooOol017oo00<007ooOol037oo0P0017oo00@0
07oo0000009oo`03001oogoo00Moo`03001oogoo00Uoo`03001oogoo009oo`03001oogoo00]oo`03
001oogoo00=oo`03001oogoo00eoo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo0000
1Woo0P001Goo00<007oo0000:7oo0`001Goo0P000Woo00<007ooOol00goo00@007ooOol000Aoo`00
:7oo00<007ooOol057oo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001o
ogoo00Aoo`03001oogoo00Aoo`07001oogooOol007oo00000goo10001Woo0P000Woo0P0017oo00<0
07oo000027oo00@007ooOol002]oo`03001oogoo00Aoo`<0011oo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Eoo`03001oogoo00ioo`<00005Ool007oo001oo`02000:Ool00`00Oomoo`08
Ool00`00Oomoo`04Ool00`00Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`02
Ool40003Ool00`00Oomoo`020002Ool00`00Oomoo`04Ool00`00Ool00004Ool00`00Ool0000YOol2
0004Ool00`00Oomoo`020007Ool20005Ool002Qoo`03001oogoo00aoo`03001oogoo00Eoo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogoo0005Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01`00
Oomoogoo001oo`0000Ioo`03001oogoo00Qoo`06001oo`00001oo`000Woo00<007ooOol01Woo00D0
07ooOomoo`0002Yoo`03001oogoo00Ioo`03001oogoo00ioo`03001oogoo009oo`03001oogoo00mo
o`03001oogoo00Ioo`03001oogoo011oo`04001oogoo000=Ool20009Ool00`00Oomoo`04Ool00`00
Oomoo`0:Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`09Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool00`00Ool00004Ool00`00Ool0000_Ool00`00Oomoo`0@Ool002Qoo`03001oogoo00ao
o`03001oogoo00Aoo`03001oo`0000Eoo`03001oogoo00=oo`04001oogoo0005Ool00`00Oomoo`02
Ool00`00Oomoo`06Ool01`00Oomoogoo001oo`0000Ioo`8000Uoo`05001oogooOol00004Ool00`00
Oomoo`05Ool01@00Oomoogoo0000:Woo00<007ooOol01Woo00<007ooOol03Goo00<007ooOol00goo
00<007ooOol03Woo00<007ooOol01goo00<007ooOol02goo00<007ooOol00Woo00@007ooOol000ao
o`03001oo`0000Uoo`03001oogoo00Aoo`03001oogoo00Yoo`03001oogoo00Aoo`03001oogoo00Mo
o`8000]oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oo`0000Aoo`03001oo`0002ioo`03001o
ogoo015oo`00:7oo00<007ooOol037oo0P0017oo00@007ooOol000Eoo`03001oogoo00Aoo`03001o
o`0000Ioo`05001oogooOol00008Ool01`00Oomoogoo001oo`0000Eoo`03001oo`0000Uoo`03001o
ogoo00Ioo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00eoo`8001Qoo`03001oogoo00Mo
o`03001oogoo00eoo`03001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo00Yo
o`03001oo`0000=oo`04001oogoo000<Ool01000Oomoo`001goo00<007ooOol01Goo00<007ooOol0
2Woo00<007ooOol017oo00<007ooOol01goo00<007oo00002Woo00<007ooOol017oo00<007ooOol0
0goo00@007ooOol000Aoo`03001oo`0002ioo`03001oogoo015oo`00:7oo00<007ooOol02goo00@0
07ooOol000=oo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Ool00006Ool40009Ool01@00Oomo
ogoo00000Woo00<007ooOol00Woo00<007oo00002Goo00<007ooOol01Woo00<007ooOol017oo00<0
07ooOol00goo00<007ooOol02goo00<007oo000067oo00<007ooOol01goo00<007ooOol03Goo00<0
07ooOol017oo00<007ooOol037oo00<007ooOol027oo00<007ooOol02Goo00D007ooOomoo`00009o
o`04001oogoo000<Ool01000Oomoo`001goo00<007ooOol01Woo00<007ooOol027oo00<007ooOol0
1Goo00<007ooOol01goo00<007oo00002Woo00<007ooOol017oo00<007ooOol00goo00@007ooOol0
00Aoo`03001oo`00021oo`03001oogoo00]oo`03001oogoo015oo`00:7oo00<007ooOol02goo00L0
07ooOomoo`00Ool00004Ool01@00Oomoogoo00001goo0P0057oo00D007ooOomoo`00009oo`03001o
ogoo009oo`04001oogoo0008Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00
Oomoo`0:Ool01@00Oomoogoo00003Goo1@001Goo00<007ooOol027oo00<007ooOol02goo00<007oo
Ool01Goo00<007ooOol02goo00<007ooOol02Goo00<007ooOol027oo00<007ooOol00goo0P0017oo
00<007ooOol02Goo00@007ooOol000Ioo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo00Ioo`04001oogoo000:Ool00`00Oomoo`05Ool00`00Oomoo`02Ool01000Oomoo`00
17oo00<007oo000087oo00<007ooOol02Woo00<007ooOol04Woo000XOol00`00Oomoo`0;Ool00`00
Oomoo`02Ool00`00Oomoo`03Ool01@00Oomoogoo000027oo00<007ooOol04goo00@007ooOol0009o
o`03001oogoo009oo`04001oogoo0008Ool00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`04
Ool00`00Oomoo`09Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool01@00Oomoogoo00001Goo00<007oo
Ool027oo00<007ooOol02goo00<007ooOol01Goo00<007ooOol02goo00<007ooOol02Woo00<007oo
Ool01Woo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol02Goo00D007ooOomoo`0000Eoo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Ioo`04001oogoo000:Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool01@00Oomoogoo00000goo00<007oo00007goo00<007oo0000
2goo00<007ooOol04Woo000SOooo00290005Ool002Qoo`05001oogooOol00008Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool00`00Ool00009Ool00`00Oomoo`0@Ool01P00Oomoo`00Ool000=oo`05001o
ogooOol00004Ool20006Ool00`00Oomoo`07Ool01@00Ool007oo000027oo00<007ooOol017oo00@0
07ooOol000Moo`03001oogoo00Eoo`04001oogoo0005Ool01@00Oomoogoo00001Goo00<007ooOol0
0goo00<007ooOol00Woo0P001Goo0P002Goo00<007ooOol01Woo00@007ooOol000eoo`03001oo`00
00Eoo`03001oogoo00Uoo`03001oo`0000Yoo`03001oogoo00=oo`D000aoo`05001oo`00Ool0000=
Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol01Woo00@007ooOol0
00Aoo`04001oo`000002Ool00`00Oomoo`0;Ool00`00Oomoo`05Ool00`00Oomoo`07Ool200000goo
001oo`04Ool01@00Oomoogoo00001Woo00<007ooOol037oo000XOol00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`0:Ool00`00Ool0000OOol00`00Ool00003Ool01@00Oomoogoo000017oo0P00
1Woo00<007ooOol027oo00@007ooOol000Qoo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo
00Moo`03001oogoo00=oo`05001oogooOol00005Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Ool00003Ool00`00Oomoo`09Ool00`00Oomoo`08Ool00`00Oomoo`0<Ool00`00Oomoo`05Ool00`00
Oomoo`09Ool00`00Ool0000:Ool00`00Oomoo`0EOol00`00Ool0000>Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`06Ool01000Oomoo`0017oo00@007ooOol000=oo`03
001oogoo00Moo`@000Moo`8000Moo`05001oogooOol00004Ool00`00Ool00002Ool00`00Oomoo`04
Ool00`00Oomoo`0<Ool002Qoo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo00]oo`03001o
ogoo01ioo`03001oo`0000Aoo`04001oogoo0005Ool00`00Oomoo`04Ool00`00Oomoo`08Ool00`00
Ool00009Ool00`00Oomoo`05Ool00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`05Ool01000
Oomoo`0037oo00@007ooOol000=oo`03001oo`0000aoo`03001oogoo00Qoo`03001oogoo00aoo`03
001oogoo00Aoo`03001oogoo00eoo`03001oogoo00Moo`03001oogoo01Ioo`03001oogoo00eoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Ioo`03001oogoo00Moo`03001oo`0000Aoo`04
001oogoo0003Ool00`00Oomoo`07Ool01000Oomoo`001Woo00<007oo00001goo00D007ooOomoo`00
00=oo`07001oogooOol007oo00005Goo000XOol00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`0/Ool00`00Ool00004Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol027oo00<007oo
00002Goo00<007ooOol017oo00<007ooOol02Goo00<007ooOol01Woo00<007ooOol01Goo00@007oo
Ool000aoo`04001oogoo0004Ool00`00Oomoo`0;Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00
Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`07Ool00`00Oomoo`0WOol00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`07Ool00`00Ool00004Ool01000Oomoo`00
0goo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001oo`0000Ioo`03001oogoo00=oo`04001o
ogoo0003Ool2000FOol002Qoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo02eoo`03001o
o`0000Aoo`03001oo`0000Ioo`03001oogoo00Aoo`03001oogoo00Uoo`8000Yoo`03001oogoo00=o
o`03001oogoo00Yoo`03001oogoo00Eoo`03001oogoo00Ioo`03001oo`0000aoo`04001oogoo000B
Ool00`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`03Ool00`00Oomoo`0=Ool00`00Oomoo`06
Ool00`00Oomoo`0XOol00`00Oomoo`02Ool00`00Oomoo`04Ool01@00Oomoogoo00000Woo0`002Goo
0P001Woo00<007oo00000goo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo00@007oo
Ool000Eoo`03001oogoo00=oo`03001oo`0000Eoo`03001oogoo01Aoo`00:7oo00<007ooOol00goo
00<007ooOol00Woo0P00;goo00<007oo000017oo00<007oo00001Woo00<007ooOol017oo00<007oo
Ool02Goo00<007ooOol02Goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol017oo00<007oo
Ool01goo0P003Goo00<007oo000057oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol00Woo
00<007ooOol03Woo00<007ooOol01Woo00<007ooOol0:7oo00D007ooOomoo`0000Moo`04001oogoo
0005Ool00`00Oomoo`08Ool00`00Oomoo`04Ool00`00Ool00003Ool00`00Oomoo`05Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol017oo00<007ooOol06goo000XOol0
0`00Oomoo`04Ool01000Oomoo`00<Goo00<007oo000017oo00<007oo00001Woo00<007ooOol017oo
00<007ooOol05Goo00<007ooOol00goo00<007ooOol02Woo00<007ooOol017oo00<007ooOol01goo
0P003Goo00<007oo000057oo00<007ooOol01Goo00<007ooOol03goo00<007ooOol00Woo00<007oo
Ool03Woo00<007ooOol01Woo00<007ooOol0:Goo00@007ooOol000Qoo`8001Qoo`03001oo`0000=o
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`0SOol002Qoo`03001oogoo00Aoo`03001oo`00039oo`03001oo`0000Aoo`03001oo`0000Ioo`03
001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00=oo`03001oogoo00Yoo`03001oogoo00Aoo`03
001oogoo00Qoo`03001oogoo00]oo`03001oo`0001Aoo`03001oogoo00Aoo`03001oogoo011oo`05
001oogooOol0000AOol00`00Oomoo`05Ool00`00Oomoo`0ZOol00`00Ool00009Ool00`00Oomoo`0G
Ool00`00Ool00003Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01@00Oomoogoo000017oo00D007oo
Oomoo`0002Eoo`00:7oo00<007ooOol01Goo00<007ooOol0<Goo00<007oo00001Goo0P001Woo00<0
07ooOol00goo00<007ooOol05Woo00<007ooOol00Woo00<007ooOol02goo00<007ooOol00goo00<0
07ooOol067oo0P0057oo00<007ooOol017oo00<007ooOol04Goo00<007oo00004goo00<007ooOol0
17oo00<007ooOol0:Woo00<007oo00008goo0P0017oo00<007ooOol00goo00<007ooOol01Woo00D0
07ooOomoo`0000Aoo`04001oogoo000VOol002Qoo`03001oogoo03Yoo`03001oogoo00Aoo`03001o
ogoo00Eoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo00aoo`03001o
ogoo009oo`03001oogoo01Qoo`03001oogoo01Aoo`03001oogoo00=oo`03001oogoo015oo`8001Ao
o`03001oogoo00=oo`03001oogoo02aoo`8002=oo`8000Aoo`03001oogoo00=oo`03001oogoo00Io
o`05001oogooOol00004Ool00`00Ool0000WOol002Qoo`<003Yoo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo00=oo`03001oogoo01Ioo`03001oogoo009oo`03001oogoo00aoo`05001oogoo
Ool0000KOol00`00Oomoo`0DOol00`00Oomoo`02Ool00`00Oomoo`0BOol00`00Oomoo`0COol20004
Ool00`00Oomoo`0/Ool00`00Oomoo`0SOol00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`06
Ool01000Oomoo`001Woo00<007ooOol09Woo000XOol00`00Oomoo`0jOol00`00Oomoo`0<Ool00`00
Oomoo`03Ool00`00Oomoo`0GOol01@00Oomoogoo00003Woo00D007ooOomoo`0003=oo`05001oogoo
Ool0000/Ool01000Oomoo`00EGoo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<0
07oo0000;goo000XOol00`00Oomoo`0jOol00`00Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0G
Ool01@00Oomoogoo00003Woo00@007ooOol003Aoo`05001oogooOol0000]Ool00`00Ool0001EOol0
0`00Oomoo`03Ool01@00Oomoogoo00002Woo00<007oo0000;goo000XOol00`00Oomoo`0jOol00`00
Oomoo`0<Ool00`00Oomoo`03Ool00`00Oomoo`0GOol01@00Oomoogoo00003Woo00@007ooOol003Ao
o`04001oogoo000_Ool00`00Oomoo`1JOol01@00Oomoogoo00002Woo00<007oo0000;goo000XOol0
0`00Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0GOol01@00Oomoogoo00003goo0P00=Woo00<0
07oo0000S7oo00D007ooOomoo`0000]oo`03001oogoo02ioo`00:7oo00<007ooOol0BGoo00<007oo
Ool00goo00<007ooOol05goo00D007ooOomoo`0000moo`8003Ioo`03001oo`0008aoo`05001oogoo
Ool0000;Ool00`00Oomoo`0^Ool002Qoo`03001oogoo04Uoo`03001oogoo00=oo`03001oogoo01Mo
o`04001oogoo000@Ool00`00Oomoo`0fOol00`00Oomoo`2;Ool01000Oomoo`00?Goo000XOol00`00
Oomoo`19Ool00`00Oomoo`03Ool00`00Oomoo`0GOol01000Oomoo`00egoo00@007ooOol003eoo`00
:7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000egoo00@007ooOol0
03eoo`00:7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000egoo00@0
07ooOol003eoo`00:7oo00<007ooOol0BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000
egoo00@007ooOol003eoo`00:7oo0`00BGoo00<007ooOol00goo00<007ooOol067oo00<007oo0000
egoo00<007oo0000?Woo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`0HOol00`00
Ool0003GOol00`00Ool0000nOol002Qoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo01Qo
o`03001oo`000=Qoo`8003ioo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007ooOol067oo
00<007oo0000f7oo0P00?Woo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`0IOol0
0`00Oomoo`3GOol2000nOol002Qoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo01Uoo`03
001oogoo0=Moo`03001oogoo03eoo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007ooOol0
6Goo00<007ooOol0egoo00<007ooOol0?Goo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00
Oomoo`0IOol00`00Oomoo`3oOolHOol002Qoo`03001oogoo04Yoo`03001oogoo009oo`03001oogoo
0?moocAoo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007ooOol0ogoo=7oo000XOol00`00
Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`3oOoldOol002Qoo`03001oogoo04Yoo`03001oogoo
009oo`03001oogoo0?moocAoo`00:7oo0`00BWoo00<007ooOol00Woo00<007ooOol0ogoo=7oo000X
Ool00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`3oOoldOol002Qoo`03001oogoo04Yoo`03
001oogoo009oo`03001oogoo0?moocAoo`00:7oo00<007ooOol0BWoo00<007ooOol00Woo00<007oo
Ool0ogoo=7oo000XOol00`00Oomoo`1:Ool00`00Oomoo`02Ool00`00Oomoo`3oOoldOol002Qoo`03
001oogoo04Yoo`03001oogoo009oo`03001oogoo0?moocAoo`00:7oo00<007ooOol0BWoo00D007oo
Oomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007oo
Ool0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMo
o`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo0`00BWoo00D007ooOomoo`00
0?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo
00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo
00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`00
0?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo
00D007ooOomoo`000?moocMoo`00:7oo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`0037oo
0P001goo0`001Goo1@001Woo00<007ooOol0BWoo00D007ooOomoo`000?moocMoo`002goo00@007oo
Ool000Ioo`<000Moo`03001oogoo00Ioo`03001oogoo04Yoo`05001oogooOol0003oOolgOol000Yo
o`03001oogoo009oo`03001oogoo00=oo`<000Moo`03001oogoo00Ioo`@004Uoo`05001oogooOol0
003oOolgOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo04Yo
o`05001oogooOol0003oOolgOol000Yoo`03001oogoo009oo`03001oogoo00eoo`03001oogoo00Io
o`03001oogoo04Yoo`05001oogooOol0003oOolgOol000Yoo`03001oogoo009oo`03001oogoo00eo
o`03001oogoo00Ioo`03001oogoo04Yoo`05001oogooOol0003oOolgOol000Yoo`03001oogoo009o
o`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo04]oo`04001oogoo003oOolgOol000]oo`04
001oogoo000>Ool30008Ool00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000<Ool2000@Ool20008
Ool00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool01000Oomoo`00ogoo
=goo000XOol00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool01000Oomo
o`00ogoo=goo000XOol00`00Oomoo`1;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool0
1000Oomoo`00ogoo=goo000XOol3001;Ool01000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool0
1000Oomoo`00ogoo=goo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo
04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00
Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo
00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol0
02Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo
>7oo000XOol3001;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQo
o`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003o
OolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo
0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03
001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;
Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo0`00Bgoo
00<007oo0000ogoo>7oo000XOol00`00Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo
04]oo`03001oo`000?moocQoo`00:7oo00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00
Oomoo`1;Ool00`00Ool0003oOolhOol002Qoo`03001oogoo04]oo`03001oo`000?moocQoo`00:7oo
00<007ooOol0Bgoo00<007oo0000ogoo>7oo000XOol00`00Oomoo`1<Ool2003oOolhOol002Qoo`03
001oogoo04aoo`800?moocQoo`00:7oo00<007ooOol0C7oo0P00ogoo>7oo000XOol00`00Oomoo`1<
Ool2003oOolhOol002Qoo`03001oogoo04aoo`03001oogoo0?moocMoo`00:7oo0`00C7oo00<007oo
Ool0ogoo=goo000XOol00`00Oomoo`1<Ool00`00Oomoo`3oOolgOol002Qoo`03001oogoo04aoo`03
001oogoo0?moocMoo`00:7oo00<007ooOol0C7oo00<007ooOol0ogoo=goo000XOol00`00Oomoo`1<
Ool00`00Oomoo`3oOolgOol002Qoo`03001oogoo04aoo`03001oogoo0?moocMoo`00:7oo00<007oo
Ool0C7oo00<007ooOol0ogoo=goo000XOol00`00Oomoo`1<Ool00`00Oomoo`3oOolgOol000aoo`80
00Moo`<000Aoo`H000Ioo`03001oogoo04aoo`03001oogoo0?moocMoo`002goo00@007ooOol000Io
o`<000Eoo`05001oogooOol00006Ool00`00Oomoo`1<Ool00`00Oomoo`3oOolgOol000Yoo`03001o
ogoo009oo`03001oogoo00=oo`<000Ioo`03001oogoo00Moo`03001oogoo04aoo`03001oogoo0?mo
ocMoo`002Woo00<007ooOol00Woo00<007ooOol03Goo00<007ooOol01Woo1000Bgoo00<007ooOol0
ogoo=goo000:Ool00`00Oomoo`02Ool00`00Oomoo`0>Ool00`00Oomoo`05Ool00`00Oomoo`1<Ool0
0`00Oomoo`3oOolgOol000Yoo`03001oogoo009oo`03001oogoo00moo`03001oogoo00Aoo`03001o
ogoo04aoo`03001oogoo0?moocMoo`002Woo00<007ooOol00Woo00<007ooOol03goo00<007ooOol0
17oo00<007ooOol0ogooQWoo000;Ool01000Oomoo`003Goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol0ogooQWoo000<Ool2000?Ool40007Ool00`00Oomoo`3oOon6Ool002Qoo`03001oogoo
0?moohIoo`00:7oo00<007ooOol0ogooQWoo000XOol00`00Oomoo`3oOon6Ool00?mook5oo`00ogoo
/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol0
0?mook5oo`00ogoo/Goo0000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.812, 0}} -> {-10, 0, 0, 0}}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Comparing these plots with those generated in Cells ",
  ButtonBox["2.64",
    ButtonData:>"Cell 2.64",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["2.65",
    ButtonData:>"Cell 2.65",
    ButtonStyle->"Hyperlink"],
  " using the discrete Fourier transform method, one can see that they are \
identical."
}], "Text"],

Cell[TextData[{
  "\tLet's apply Fourier analysis to a real data signal. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has the ability to read various types of audio files, such as AIFF \
format, \[Mu] law encoding, or Microsoft WAV format. These sound files can be \
read using the intrinsic function ",
  StyleBox["Import",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". To read the following sound file of my voice, named ",
  StyleBox["ah.AIFF",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", first determine the current working directory on the hard disk with the \
command"
}], "Text",
  CellTags->{"i:98", "i:102"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Directory[]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.67"],

Cell[BoxData[
    \("/Users/dubin"\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then either copy the file into this directory from the cd on which this \
book came, or if that is not possible, set the working directory to another \
hard disk location using the ",
  StyleBox["SetDirectory",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. Once the file is in the current working directory, the file can \
be read:"
}], "Text",
  CellTags->"i:103"],

Cell[CellGroupData[{

Cell[BoxData[
    \(snd\  = Import["\<ah.AIFF\>", "\<AIFF\>"]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.68"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "As with any other sound in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", this sound can be played using the ",
  StyleBox["Show ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "command:"
}], "Text",
  CellTags->"i:114"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[snd]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.69"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
22050. 36864 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00Oo`00J@0000000`00
Oomoo`3oOomUOol100000003001oogoo09Uoo`03001oogoo035oo`03001oogoo00Aoo`06001oo`00
001oo`00RWoo0@0000000`00Oomoo`2:Ool200000goo00000004000017oo000007oo0P002Woo00<0
07ooOol00goo0P000goo00<007ooOol00P0000Aoo`00Ool000=oo`03001oogoo00Yoo`03001oogoo
009oo`04001oo`00Ool8000017oo000007oo0P001Woo00@007oo000000Moo`04001oogoo0004Ool0
0`00Oomoo`1ZOol100000003001oogoo07aoo`8000Aoof/00003Ool0000001<00003Ool0000000@0
0004Ool00000Ool20003Ool01@00Ool00000Ool00P0000Eoo`00001oo`0003ioo`03001oogoo00Ao
o`40000000<007ooOol0LWoo0P0027oo0P0000=oo`000000Z`0000Aoo`00000002eoo`8000Eoo`40
000000<007ooOol0ogooIGoo0@0000000`00Ool0003o001T0001Ool100000003001oo`000?l006@0
005oo`40000000<007oo0000o`00I0000Goo0@0000000`00Oomoo`3oOomUOol100000003001oogoo
079oo`03001oogoo00Ioo`<00003Ool0000004H00003Ool0000006P002]oo`8000Eoo`40000000<0
07ooOol0O7oo0P000Woo0P0000=oo`000000F00000=oo`000000800000=oo`000000500000=oo`00
00000`0000Aoo`00001oo`800004Ool00000000mOol100000003001oogoo07aoo`05001oogooOol0
0003Ool00`00Ool00002000017oo000007oo4`0000=oo`0000007`0000=oo`0000004`0000=oo`00
00002P0000=oo`000000600000=oo`0000000Woo0P0000Eoo`00001oo`00009oo`06001oogooOol0
07oo0`0000Aoo`00001oo`800005Ool00000Ool00012Ool100000003001oogoo0?moofEoo`400000
00<007ooOol0QWoo00@007oo001oo`800004Ool00000Ool3000017oo000007oo0P0000=oo`00Ool0
2Goo00H007oo000007oo0002Ool20004Ool2000017oo000007oo0P0000Aoo`00001oo`<00003Ool0
0000009oo`05001oo`00001oo`0200000goo00000002Ool2000017oo000007oo0P0000Aoo`00001o
o`<00004Ool00000Ool20004Ool00`00Oomoo`1eOol100000003001oogoo08]oo`03001oogoo02=o
o`03001oogoo01Qoo`80009oo`800004Ool00000Ool2000017oo000007oo0P0000=oo`000000Pgoo
0@0000000`00Oomoo`3?Ool30002Ool01@00Ool00000Ool00P00RGoo0@0000000`00Oomoo`3oOomU
Ool100000?l006T0000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
o`000?moofEoo`40000000<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001o
ogoo0?moofEoo`40000000<007ooOol0d7oo0P0000Aoo`00001oo`800003Ool0000008Uoo`400000
00<007ooOol0cWoo00D007oo000007oo00800004Ool00000Ool20029Ool100000003001oogoo099o
o`03001oogoo03Qoo`03001oogoo008000Aoo`800005Ool00000Ool00027Ool100000003001oogoo
08]oo`05001oo`00001oo`0300001Goo000007oo0000=7oo0`0000Aoo`00001oo`8000Aoo`03001o
ogoo00<00005Ool00000Ool00020Ool100000003001oogoo08eoo`800005Ool007oo001oo`020000
17oo000007oo0`009goo00<007ooOol00Woo0P001Woo00<007oo00000Woo0P0000=oo`0000000Woo
00@007ooOol0009oo`8007moo`40000000<007ooOol0RWoo0P000Woo00<007oo00000P000Woo00P0
07oo000007oo001oo`004Goo00<007ooOol02Goo00D007ooOomoo`00009oo`04001oogoo0002Ool0
0`00Oomoo`04Ool00`00Ool00005Ool20008Ool2000017oo001oogoo0P00O7oo0@0000000`00Oomo
o`2:Ool00`00Oomoo`0200000goo00000002Ool20002Ool200000goo0000000AOol00`00Oomoo`05
Ool200001Woo00000000Ool0009oo`800004Ool00000Ool2000017oo000007oo0P000Woo00@007oo
Ool000Eoo`03001oogoo00<00003Ool00000009oo`04001oogoo000^Ool00`00Oomoo`1;Ool10000
0003001oogoo08Aoo`06001oo`00Ool007oo0P0000=oo`00Ool03P0000=oo`00Ool00goo0P000Woo
1@0000Aoo`00001oo`800004Ool00000Ool200001Goo00000000Ool00P0000Aoo`00001oo`/00003
Ool0000000`000=oo`04001oogoo0002Ool200001Goo000007oo00005Goo00<007ooOol00P0000Ao
o`00001oo`800003Ool0000000=oo`05001oo`00001oo`0200001Goo000007oo0000AGoo0@000000
0`00Oomoo`23Ool200001Goo001oo`00Ool00P0000Aoo`00001oo`D00004Ool000000002Ool20000
0goo001oo`03Ool:000017oo001oo`000Woo0P0000Aoo`00Oomoo`<00003Ool0000000D00006Ool0
0000Ool007oo1`0000Eoo`00001oo`00009oo`<00003Ool0000000@0009oo`05001oo`00001oo`02
00000goo001oo`0;Ool00`00Oomoo`04Ool01@00Ool00000Ool00P0000=oo`00Ool00Woo00<007oo
00000P0000Aoo`00001oo`800004Ool00000Ool200000goo000000020012Ool100000003001oogoo
07aoo`03001oogoo00Aoo`800006Ool00000001oo`000Woo00<007oo00000P000Woo00<007ooOol0
20000goo300000=oo`000000100000Aoo`00001oo`800003Ool00000009oo`P00003Ool0000000<0
0004Ool00000Ool200000goo0000000300000goo00000004000017oo001oogoo0P0000Aoo`00Oomo
o`<00005Ool007ooOol00002Ool200001Goo00000000Ool00P0000=oo`0000000`0000=oo`000000
0Woo00@007oo0000009oo`D00004Ool00000Ool2000017oo000007oo1P0000=oo`00Ool0?Goo0@00
00000`00Oomoo`1lOol01000Oomoogoo0P0000Aoo`00001oo`<00003Ool0000001@00003Ool00000
02/00003Ool0000001<00003Ool0000000d00003Ool0000002d00003Ool0000003eoo`40000000<0
07ooOol0O7oo00@007ooOomoo`D00003Ool0000000d00003Ool0000000/00003Ool0000001h00004
Ool00000OolO000017oo000007oo0P0000=oo`0000001`0000=oo`0000006P0000=oo`00Ool02@00
00=oo`000000100000=oo`00Ool0>Woo0@0000000`00Oomoo`1lOol01000Oomoogoo10000Woo0P00
00=oo`0000003@0000=oo`0000003@0000=oo`000000700000=oo`000000@P000Woo7P0000Aoo`00
000003Aoo`40000000<007ooOol0O7oo0P000Woo200000Aoo`00001oob000003Ool0000000`00003
Ool0000001H00003Ool0000001H00003Ool0000002000003Ool0000000d00003Ool0000000l0039o
o`40000000<007ooOol0O7oo0P0000=oo`000000/@00<Woo0@0000000`00Oomoo`1lOol@00000goo
0000000300000goo0000000700000goo0000000e00000goo001oo`020002OomH000aOol100000003
001oogoo079oo`8000Ioob400003Ool0000003D00003Ool0000000T00003Ool007oo05<002moo`40
000000<007ooOol0LWoo0`000goo``000goo00<007ooOol077oo0P001Goo0@0000000`00Ool0002b
00000goo0000000H00000goo0000002C0001Ool100000003001oo`000?l006@0005oo`40000000<0
07ooOol0LWoo0`0017oo8@0000=oo`000000W@0017oo00<007ooOol077oo0P001Goo0@0000000`00
Oomoo`1bOol20006Oonj00001Goo000007oo0000:goo0@0000000`00Oomoo`1bOol00`00Oomoo`07
OomF00000goo0000001N000aOol100000003001oogoo079oo`03001oogoo00Moo`800003Ool00000
04P00003Ool0000002H00003Ool0000002T00003Ool000000140039oo`40000000<007ooOol0O7oo
0P000Woo7`0000=oo`000000RP0000Eoo`00001oo`0003=oo`40000000<007ooOol0O7oo0P000Woo
00@007ooOomoo`<0009oo`<00003Ool0000000P00003Ool007oo02/00003Ool0000000d00005Ool0
0000001oo`0A000017oo001oogoo2`0000=oo`0000000`0000=oo`0000000Woo7`000goo00<007oo
Ool0>Woo0@0000000`00Oomoo`1lOol20002Ool40002Ool2000017oo000007oo1@000Woo3`0000=o
o`00Ool0100000Aoo`00001oo`800003Ool0000000H00003Ool0000000d00003Ool007oo009oo`P0
0003Ool0000000@00003Ool0000000800003Ool0000000@00003Ool007oo00800005Ool00000Ool0
0003Ool=0002Ool00`00Oomoo`020004Ool200001Goo00000000Ool01@0000=oo`0000001@00@goo
0@0000000`00Oomoo`1lOol00`00Oomoo`04Ool20002Ool01@00Ool00000Ool00P000Woo0P000Woo
00<007ooOol01@0000Aoo`00001oo`80009oo`03001oo`00009oo`800003Ool0000000@00003Ool0
000000H00004Ool00000Ool300001Woo001oogoo001oo`T00003Ool0000000L00003Ool0000000D0
0003Ool007oo00<0009oo`800004Ool00000Ool2000017oo000007oo0P0000=oo`0000000Woo1@00
00Aoo`00001oo`800004Ool00000Ool200000goo00000002Ool5001;Ool100000003001oogoo07ao
o`03001oogoo00Aoo`800003Ool00000009ooaD0009oo`05001oo`00001oo`02000017oo000007oo
200000=oo`0000007P0000=oo`0000002@0000=oo`0000001P0000Aoo`00001oo`800004Ool00000
Ool2000017oo000007oo0P0000=oo`000000100000=oo`0000000Woo00D007oo000007oo008005Eo
o`40000000<007ooOol0RGoo0P0000Moo`00001oo`00Ool00002Ool500001Goo001oogoo00001Goo
0P0000Eoo`00001oo`00009oo`800004Ool00000Ool2000017oo000007oo0P0000=oo`0000000Woo
00H007ooOomoo`00Ool2000017oo001oogoo1P0000=oo`0000000`0000=oo`0000000Woo1`0000Io
o`00000007oo0003Ool01@00Oomoo`00Ool00P0000Eoo`00001oo`00009oo`03001oogoo06Moo`40
000000<007ooOol0RGoo00<007oo00002P0000Eoo`00000007oo00<000Eoo`800004Ool00000Ool2
00001Goo000007oo00000Woo0P000Woo00D007oo000007oo00800005Ool00000001oo`0200000goo
00000002Ool01@00Ool00000Ool00`0000Eoo`00000007oo00/0015oo`03001oogoo06moo`400000
00<007ooOol0RWoo0P0000=oo`0000003P001Woo00@007ooOol0009oo`8000]oo`05001oo`00001o
o`03000017oo000007oo0P0000Aoo`00001oo`800003Ool00000010008Moo`40000000<007ooOol0
Rgoo00D007oo000007oo0080009oo`05001oogoo001oo`02000eOol01P00Ool007oo001oo`800003
Ool007oo08Uoo`40000000<007ooOol0Rgoo00<007oo00000Woo0`00dGoo0@0000000`00Oomoo`2;
Ool01000Oomoo`00eGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000003001oogoo0?moofEoo`400000
00<007ooOol0ogooIGoo0@0000000`00Oomoo`3oOomUOol100000?l006T00000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 359}, {221.375, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000002@05HR000000000000000lOgmoOh20
P7moOgmoOgmoOgmoOgmoOgn0P820P820P7n0Ogn0OgmoOgmoP81oOgn0P7moOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0Ogn0OgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOh20OgmoOgmoOh20OgmoOgmoP820P7moOgn0P820OgmoOgmo
OgmoOgmoP7n0P81oOgmoOgmoOgmoOgn0P820Ogn0OgmoP7moOgmoOgmoOgmoP81o
OgmoOh1oOgmoOgmoOgmoP7n0P820OgmoOgmoOgmoOgmoP820OgmoOgmoOgmoOgn0
P820Oh20P820P820P820P820P820P820P7moOgmoOh20Oh20P820P820P81oP820
P820OgmoP820P7moOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgn0
P7moOgmoOgmoOgmoOgmoOh20OgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P81oOh20
P81oOgmoP7moOgmoOgmoOgmoOgn0Oh20P7moOgmoOgmoOgmoOgn0P820P820P81o
P820P820OgmoOgmoOgmoOgmoOgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P820OgmoOh1oOgmoOgmo
Oh20P820P820OgmoOgn0P820OgmoOgmoOgmoOgn0P7moOgn0P820P820P820Ogmo
P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P81oOgmoOgmoOgn0
P7moOgmoOgmoOgmoOgmoP820P820P820P81oOgmoP820P7moOgn0P820P820Oh20
P820P820P7moP820P820Ogn0P820OgmoP820P820P820P820P7moP820P820P820
P820P7moOh20P820OgmoOgn0P7n0OgmoP820P820P820OgmoOgmoOgmoP820P820
P7moOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgn0P7moP820P820Ogn0P7moOgmoOgmo
OgmoP7moOgmoP820OgmoOgmoOgmoOgmoOh20P81oOgmoOgmoOgn0P7moOgmoOgn0
P820OgmoOgmoOh1oOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOh1oP7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20OgmoOgmoOgmo
Ogn0P820P7moP820Ogn0P81oP7moOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoP820P820P820P820P81oOgmoOgmoOgn0P820P81oOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgn0P820P820Oh20P81oOgmoOgmoOgmoOgmoOgmoOgn0P820P7mo
OgmoOgmoOgmoOgmoP820P820P7moP820P820P7n0OgmoOgn0P820P7moOgn0Ogmo
Ogn0P820P820P820P7moOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmo
Oh1oOgmoOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820Ogmo
OgmoP820P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7moOgmoOgmoOgmoP820
P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P820P81oOgmoP820P820P820P820
OgmoOgn0P820P820P820P81oP820P820P820P7moOgn0P820P81oOgmoOgmoOgmo
OgmoOgmoOh20P820P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P820
P820Oh20Oh20P7moOgmoP7moP820P820P820Oh1oOgmoOgn0P820P820P820P81o
OgmoP820P81oOgmoOh20P81oOgmoOh20P81oOgmoOgn0P820P820P820P81oOgmo
P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P7moOgn0P81o
OgmoOgmoOgmoOgmoOgmoOgn0P820P7moOh20P81oOgmoP820OgmoP820P7moOgmo
Ogn0P820OgmoOgmoOgn0P820P820Ogn0P81oOgmoOgn0P820P7moOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P7moOgmoP820Ogn0P81o
OgmoOgmoP820P820P7n0P7moOgmoOgmoOh20P820P820P820P81oOgmoOgmoOgn0
P820OgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgn0OgmoOgmoOh20P7moOgmoP820OgmoP820P7moOgmoP7moOgmoOgmoP7n0
P7moOh20Ogn0P81oOgn0P820OgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoP81o
OgmoOgmoOgmoOgn0P7moOgmoOh20P820OgmoOgn0P7moOgmoOgmoOh20OgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoP820OgmoOgmoOh20P81oOgn0P81oOgmoOgmoOgn0Oh20P7moOgmoOgmoOgmo
OgmoOgmoOgn0P820P820OgmoOgmoOh20P7moOh20P820P820P820P820OgmoOgn0
P820P820P820P820P820P820P820P820P820P7moOgmoOgmoOgmoP81oOgmoOgmo
OgmoOgmoOgn0P820P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoP820P81oP81oOgmoP7moOgmoOgn0
P7moOgmoP820P7n0P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20
P7moOgmoOh20OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P7n0P820P820
OgmoOgmoOgmoOgmoP7moOgmoOgmoOh1oOgmoOgmoOgmoOgmoP820P820P820P820
P820P81oOgn0P820OgmoOgmoP81oOgmoP820P820OgmoOgn0P7moOgmoOgmoOgmo
OgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoP81oOgmoOh1oOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoP820OgmoOgmoOgmoP820P820P81oP820P820P7moOgmoP820
Oh20P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P7moOgmoOgmoOgmoOgmoOgmoP820
P81oOgmoOh20P7moOgmoP7n0P820Oh20P81oOh1oOgmoOgn0P820P820P7moP820
P7moOgmoOh20OgmoOgmoOgmoOgn0OgmoOgmoP81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P7n0P820OgmoOh20P7moOgmoOgmoOgn0
P820P820P820P81oP820P81oOh20P820P81oP820P820P820P820P820P820P820
P7n0P820P81oOgmoP820P820P820P820P81oP820P820P81oOgn0OgmoOgmoOh1o
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P820P820OgmoOgmoOgmo
OgmoOgmoOgmoOh1oOh1oP7n0OgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgn0P820P7n0P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOh20P7moOgn0P81oOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Oh20P820P820P820P820OgmoOgmoOgmoOgmoP7moOgmoP820P81oOgmoOgmoOgmo
OgmoOh1oOgmoOgn0P820OgmoOgmoOgmoOgmoOgmoOgmoP7n0OgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoP81oP820OgmoOgn0P7moP7moOgmoP820P7moOgn0P820
P820P820P820P820P820Oh20Oh20P81oOgn0P820P7moOgn0P81oOgmoP820P820
P820P820OgmoOgmoOgmoOgn0P820OgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P81oOgn0P820P81o
Ogn0P820P7n0P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20Oh20P7moOgmo
Ogn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P820P7moP7moOgmoOgmoP820
P7moOh20P7moOh20P820P81oOgmoOgmoP820P81oOgn0P820P81oOgn0P820Ogmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7mo
Ogn0OgmoOgmoOgmoP820P7moOgmoOgn0P820P820Ogn0OgmoOgmoOgn0P7moOgmo
Ogn0P820P81oOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOh20
P820P7moOgn0P81oP81oP820P820Ogn0P820OgmoOgmoOh20P81oOgmoP7moOh20
P820P7n0Oh20P820P81oOh20P820P820P820P820P820P820OgmoOh20P820P7mo
OgmoOgmoP820P820OgmoOh20P820OgmoOgn0P820P81oP7moOgmoOgmoOgmoOgn0
P81oOgmoOgmoP820P81oP81oOgmoOh20P81oOgn0P820P7moOgmoOgmoOh20P820
OgmoOh20P820P820P820P820P81oOgmoOh20P820OgmoP820P820P81oOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0
P820OgmoP820P820OgmoP7n0P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Ogn0P81oP820P7moP820P820P81oOgmoOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmo
OgmoP81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoP820P820
P820P820P81oOgmoOh20P81oOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmoOgmoOgn0
P7n0P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmo
OgmoP820P820Oh20P7moOgmoOgmoOgmoOgmoP820P820P7moOh1oP820P820P820
P820P7moOh20P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P820P820P7mo
Oh1oP81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoOh20OgmoOgmo
P81oOgmoOgmoOgmoOgmoOgmoP7moOgn0P820OgmoP820P81oOgmoP7n0OgmoOgmo
Oh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoP81oOgmoOgmoOgmoOgmo
OgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmoOgn0P820P81oOgmoOh1oOgmoOgn0
P820P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Oh20OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoP7moP820P820Oh20P820P7moOgmoOgmoOgmo
Oh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOh20P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Oh1oOgmoOgmoP820P820P820P81oP7moOgn0P820P7moP81oOgmoOgmoOh1oOgmo
OgmoOgn0P820P820P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOh20OgmoOgmoOgmoOgmoP7moOh20P820
P820Ogn0P820P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1o
OgmoOh20P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoP820P820
P820P7n0P820P81oOgmoOgmoOgmoOgmoOgmoP81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoP820P7moOgn0P820OgmoOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoP820
P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgn0P820P81oOgmoP820P81oOh20
P820P820P820P820P820OgmoOh20P7moOgmoOgmoOgmoOgn0P820P820P7n0P820
P81oOgmoOh1oOgmoP820P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoP81oOgmoOgn0P81oOgmoP7moOgmoOh20P820P820Ogn0P820P820P820P820
Oh1oOgmoOgn0P820P820P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20
OgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P7moOgn0P820P7moOh20
P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P7moOgmoOgmoOgmoOgmo
OgmoP820P820P7n0P820P820OgmoP820P820P820P820P820P81oOh20P820P7mo
OgmoOgmoOgn0OgmoOgmoOgmoOh20P820Ogn0P820P81oOh1oOgmoOgmoOgmoOgmo
Oh1oP7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20
P7moOgmoOgn0OgmoOh20P820OgmoOgn0P820P81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoP7moOgn0Oh1oOgn0P820P820P820Oh20Oh20P820P81oOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Oh1oP81oOh20P820P820Oh20OgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20OgmoOgmo
Oh20Oh20P7moOgn0P820P81oOgn0P81oOgmoOgmoP820P820P7moOgmoOh20Ogmo
OgmoOgmoP7n0P7moP820P820P820P81oP820P820P7moOgmoOh20P820P820P820
P820P820Ogn0P7moOgmoOgmoOgmoOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoOgmo
Oh20OgmoP820P820P820P81oOh20P820P81oOgmoP81oOgmoOgmoOgmoOgmoP7n0
Ogn0P820P820P820P81oP81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P7moOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0
P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgn0P7n0
OgmoOgmoP81oOgmoOgmoOgmoOgmoOgn0P820P820P820P820P820P820P820P820
P81oOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P820P820P820P81o
OgmoOh20OgmoOgmoOgmoP820Oh1oOgmoP820P820P81oOgn0P820P7moOgmoOgmo
OgmoOgmoP820P820Oh20P820P81oOgmoP7n0P820P820P820P81oOgmoOgmoOh1o
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P7mo
OgmoOgmoOgmoOgmoOh20OgmoOgmoOh20P7moOgn0P7moP820OgmoOgmoOgmoOgmo
P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgn0P7moOgn0OgmoP820P81oOgmo
OgmoOgmoP81oOgmoOh20OgmoOgmoOgn0P7moOgmoOgmoOgmoP81oP7moOgmoOgmo
OgmoP820OgmoOgmoOgmoOh20P7moOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmoP820
P820P820P820P820P820P7moOh20P820P7moOgn0P820P820P820P7moP7moOgn0
P820P7moOgmoOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOh20P81oOgmoOgmoOh1oOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgn0P81oOgmoOh20P7moOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOh20P7mo
OgmoOgmoOgmoOgn0OgmoOh20P7moOh20P81oOgmoOgmoOgmoP7moOgmoP81oOgmo
OgmoOgmoOh1oP7moOgmoOgmoOgmoOgmoOgmoOgmoOh20OgmoOgmoOgmoOgmoOgmo
P820P81oOgmoOgn0P7moOgmoOgmoOgmoOgmoOgn0P820OgmoOgmoP820P7moP820
P820P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P7moOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmo
P820P7moOgmoOgmoOgmoOgmoOgmoOh20P7moOgmoP81oOgmoOgn0P820OgmoOh20
P7moOgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Ogn0P7moOgn0P820P7moOgmoP820P820P820P820P820P820Oh1oP820OgmoOgmo
OgmoP820P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P7moOgn0Ogn0OgmoOgmo
P81oOgn0P7moOgmoOgmoOh20Oh1oOh1oOh20P820P820P820P820P820P820P81o
Oh1oOgmoOh1oP820P81oOgmoOgmoP81oOgmoOh20P820P7moOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOh20P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7mo
OgmoOgmoOgmoOgmoOgmoOgmoOh20P820P820P7moOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoP7moOgmoOgmoOh20P81oOgmoP820P7moOgmoP820P7moOgmoOgmo
OgmoOh20OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOh20P820P7moP820P820P820P820P7moP820P820P820P820OgmoOgn0P820
P820OgmoP820P820P820P820P820P81oOgmoOgmoOgmoOgmoP81oOgmoOgmoP81o
OgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P7mo
P820P820P81oP81oP7moOh1oOgmoOgmoOh1oOgmoOgmoOgmoOh20P820P7moP7n0
P81oOgmoP820P81oOh20P81oOgmoOgn0P7moOh20P7moOgmoOgn0P7moOgmoOh20
P820P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20Ogmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOh20
P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820OgmoP820P7mo
OgmoP820P820OgmoOgmoOh20Oh1oOgmoP7n0P7n0P820P7moOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P81oOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoP820OgmoOgmoOgmoOh1oOgmoOgmoOgmoOgmoOh1oOgmoOgmo
OgmoOgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P7moOgmoP820P7mo
OgmoOgmoOgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820OgmoOgmo
Oh20P820OgmoOgmoOgmoOgmoOgmoOh20P820P820P81oOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoP820P820OgmoOgn0P820P820P820Oh20P820P820
Ogn0P820OgmoOgmoOgmoOgn0P820P820P820P81oOgmoP820P820P7moOh1oOgmo
Oh20P81oOh20P81oP7n0OgmoP81oOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgn0P820P7moOgmoOh20OgmoOgmo
OgmoP820P7moP820P7moOgmoP820P820P81oP7moOgmoOgmoOgmoOgmoOgmoOgmo
OgmoP820Oh20P820P7n0P820P820P7moOh20P81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoP820P820P820P820P7moOh20P820P81oOgmoOh20P820P820OgmoOgmoOgmo
Ogn0Oh20P7moOgmoOh1oOgmoP820P7moOgmoOh20P7moOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoP820P81oOh20P820P7moOgmoOgmoOgmoP820P7moOgmoOgn0P81o
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP81oOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoP820OgmoOgn0P820P820P820P820
P820P820P820P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0
Ogn0P820P7moP820OgmoOgmoOgmoOgmoOgmoOgmoOh20OgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgn0Ogn0OgmoP81oP7moOgmoOgn0P820P820P7moOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20
P820P81oOgmoOh20OgmoOgmoOgmoOgmoOgmoOgmoP7n0P81oOgmoP820P820P7mo
Oh20P820P820P820Oh20Oh20P81oOgmoP820P81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmo
P7moOgmoOgmoP820OgmoOgmoOh20P820OgmoP81oP820OgmoP820P81oOh20Ogmo
OgmoOgn0P820P81oOgmoOgmoP820P7moOgmoOgmoOgn0P820OgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P81oOgmoOgn0Ogmo
OgmoOh20OgmoOgmoOgmoOgmoOgmoOgn0P7moOgmoOh20P820P81oOgmoOgmoP81o
OgmoOgmoOgmoP820OgmoP820OgmoOgmoOgn0P7moOgmoOgmoOgn0P820OgmoOgmo
OgmoOgmoOgmoOh20P820P820P820Ogn0P820P820OgmoP820OgmoOgmoOgmoOgmo
OgmoOgmoOh1oP7moOgmoOgmoP820P7moOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmo
OgmoOh20OgmoOgmoOh20P7moP820OgmoOh20P7moOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmo
OgmoOgmoOh20P7moOgmoOgmoOgn0P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Ogn0OgmoOgmoP820P820OgmoP81oOgmoOgmoP820OgmoOh1oOgmoOgmoOgmoOh20
P820P820P820P820P81oP820P820P820OgmoOh20Ogn0P820P81oOgmoP820P81o
OgmoP81oOgmoP820P820P81oOh1oOgn0P820OgmoOgmoOgmoOgmoP820P7moOgn0
P820P820P7moP81oOgmoOh20P820P7moOgmoP820P820P820P820P820P7moP820
P820P820P820Oh20P7moOgmoOgmoP820OgmoOgmoOgmoOgn0P820OgmoOgmoOh1o
P7moP7moOgn0P81oOgmoOgmoP820P7moOgmoP81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoOgmo
Ogn0P7moOgmoOgmoOgmoOgn0P820OgmoOgmoOh20P7moOgmoOgmoOgmoOgn0P820
P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P7moOh20P820P820
Oh20P81oOgmoOgmoOgmoOh20P7moOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOh20P820P820OgmoP820P81oOgmo
P820OgmoOh20P820OgmoOgmoOgmoP81oP81oOh20OgmoOgn0P820OgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgn0P7n0P7moP820P820P7moOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoP81oOgmoOgmoOgmoOgmoOgn0P7moOgmoOgmo
Oh1oOgmoOgmoOgmoOgmoOgmoP820P7moOgn0P820OgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOgmo
OgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgn0P7n0OgmoOgmoOh20P81oOgmoOgmoOgmoOgn0P81oOgmo
Oh20Oh1oOgn0Ogn0P820P820P820P820P820OgmoOgn0P820P820P7moOgmoOgn0
P81oOgmoOgmoOgn0P81oP7moOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOh20P820OgmoOgmoOgn0P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoP820P7n0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820
OgmoOgmoOgmoOgmoOgmoOh1oOgmoOgmoOgmoOgmoOgmoOh20P7moOgmoOgmoP7mo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P820
P7moOgn0P820P820P820P820P820OgmoOgmoOgmoOgmoP7n0P820Oh1oOgn0Ogmo
OgmoOgmoOgmoOh20P7moOgmoOgmoOgmoOgmoOgmoOgilO7anP8:2P7moPH>5QHB2
P7moP81oOWelO7amOWn0P820P821PH:1PGmnOWioP820P820P861PX61P7mnOWin
OGelO7enOh20P861PH:1PH20OgmoOWinOgmoP820P820P7moOgmoOgmnOWioP861
PX62PX:1PH20OgmnOWinOWioOgn0P820PH61P81oOgmoOgmoOgmoP821PH60P820
P7moOWinOWinOWmoP820P820P820P7moOWmoOgmoOgn0P820P820P81oOgmoOgmo
OgmoP820P820P820P7moOgmoOgmoOh20P820P820P81oOgmoOgmoOgmoP820P820
P820P81oOgmoOgmoOgmoOgmoP820P81oOh20OgmoOgmoOgmoOgmoP820P820P820
P81oOgmoOgmoP820OgmoOh20P7moOgmoP820P7moP820P820P820P7moOh20Ogmo
Ogn0P820OgmoP820P7moOgn0P820P820P820P81oOgmoOgmoOgmoOgn0P820P820
P81oOgmoOgmoOgmoOgmoOgmoP820P81oOgmoOgmoOgmoOgmoOh1oOgmoOgmoOgmo
OgmoP820P820P820P820P7moOgmoOgmoOgmoP820P820P820P81oOgmoOgn0P820
P820P820P81oOgmoOgmoOgmoOgn0P81oOgmoP820OgmoOgmoOgmoOgmoOgmoOgn0
P7moOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P820P820P81oP820P820P820Oh20
P81oOgmoOgmoOgmoOgmoOh20P7moOh20P820OgmoOgmoP820P7moOh20P7moOWio
OgmoOgmnOWmoP820OgmnOgn0P7moOgmoOh20P7moOgmoOgmoOgmoOWmoOgmoOgmo
Ogn0P820OgmoOh20P820P821PH61PH61PH20P820OgmoOgmoOgn0P7moOh20P820
Oh20P820P820P820P821P820OgmoOgn0OgmoOWinOWinOGelO7emOGinOWmoP861
PX:2PH61P81oOWimOGalO7emOGemOWinOgmoOgmoOgmoP820PH61PX:2PX:2PX:2
PH61PH61P820P861PH1oOgn0PH61PH20PH:3PX60PH:2PH1oOgn0P7moOgmoOgmo
OgmnOGalO7emOGemOGenOh21PH61PH61PH1oOWimOGamOGemOGemOWmoOginOGem
OGemOGinOWn0P8:2Ph:2PX:2PH61P820P820PH61PX61PH61PH60P820P821PX:2
PX>3Ph>2PX1oOGYhMWMhNWanP8:4QhV;S8^:R8J4PGmlNWQgMgMhNGamP8:3Q8>3
Ph5oOGYgM7=cMGQlOGn0PXF9Rh^:QhB1OgekN7MeMGEfN7YmOh62Ph>2PX61P7il
NWYkOGn1PX>3Q8B5QHF4PWmmNgYjNW]kO7ioPH>6QhR9QhJ4PX60OgimOGenOh63
Q8F6QXJ5QH>2PH1nO7]jNgamOh21PH:2Ph>3Ph:0OW]jN7QhN7UjNWYkOGn1PX>2
PX:1PH61P7mnOGalOGinOWimOGemOWinOGalNg]lOGenOWn0PH:2PhB4Ph>2PX61
P7moOWimOGinOgmoP820PH61PH61PH61PH62PX:2Ph>3Ph>3Ph:2PH20P820P820
PH62Ph>4Ph>2PH20OgmoOWemO7enOh21P81oOGelO7akNWUiNGUkO7ioP862PhB5
QHB3PGmnOGalNgYjNGYjNgenOWinOWimOWinOWinOWioP8:3Ph>4Q8B4Ph:1Ogim
O7alO7emOWioP862PX>2PX:1PH61PH61PH62PX>4Q8B4Ph>2PH20OgmmOGeoP8:3
Ph:3Q8F5Q8>2PH1oOGalOGioOgmnOWinOWelNWUgMWMiNgemOGj0Q8N9RHR6Q8>2
P7ilNWQfMGEfN7UkO7enOh20PH60OgelNgamOWn0P862PhB5QXF4PX1nOGelNg]j
NW]lOWn1PH:2PX62PH61P7moOh21PX>4Q8F5QHF4Q8>2PGmnOGemOWn0PH62Q8F7
QhN6QH>2PH1oOWemO7amOh21PX61P7imO7]iMgIeM7IhNWanP8:5QhV9RHV7QX>1
OWakNGQgMWIgNGYlOGinOgmoOWimO7]kNg]lO7ioPH>5QXJ7QhJ5Q8:0OWelNgYi
NWYkOGioPH62PX>3PX:1PH20P821PH:3PhB4Q8F5Q8>2PH20OgmoOgn1PX>4QHF6
QXN6QXB3PH20OgmnOWioOh21P81nO7]iN7IeLg9cM7MjO7n1Q8N:Rhb<RhV7QH9o
OGYhMgIfMWMhNGYlO7emOGemO7]jNWYjNganP863QHF6QXJ6QHB2P7ilNgYjNW]l
O7eoP862Ph>2PH1oOginOWioOh21PXB5QXJ5Q8B3PX60OgimOGenOh62PhB5QhN8
R8R8QXF3PX:1PH60P820P820PH5oOG]hMWEeM7=bLG9eNGf0PhB6R8Z;S8b:R8J3
P7imO7]jNGQhN7UjNg]kNgYiNGUiNGUhN7UkOGn2PhF6QhN7QhJ5Ph5nOG]jNGUi
NGYlOGj0PH:2PX:1PH20OginOWmoP862PhB4Q8B4Q8>2PH1oOginOgn0PH:4QHJ7
QhR8R8N6QHB3PX61P861PX:1PH61PX60OW]hMWEdMGAcLW5cMgb1PhB5QXV;S8b;
R8J3PGmmOGakNWUiNGUjNgalNgUhMgMhN7QhMgQiNgj1PhF6QXN7R8R7QH>0OWak
NWUiNGYkO7enOh21PH60OgmoOWimOWioP822PhB5QHF4Q8>3PX60P7moP822PhB4
QHJ6QhN7QXF4Q8>2PX:1PH61PX>3Q8>2PH20P7ilNGIdM7AdM7=cM7MkOh:3Q8F7
RHZ;RXV7QH>0OgimO7]jNGQhNGUjNWYiN7QgN7QhN7QhNGYlOX62Q8F6QXN7QhJ4
PX1nOGalNg]jNW]lOWn0P820P820OginOWinOWioPH:3Q8F5QHF5QHB3PX:1PH61
PH62PhB5QHJ6QXJ6QHB3PX:2PX:1PH62PX:2PX:2PH5oO7UfM7=cLg5`L79fNgn2
PhB7RXf>SXf:QhF2PGmmNgYhMgMgN7UiNWYjNGQhN7QgMgIfMgQjO7n2Q8F7R8V:
RXZ8QH>0OWekNWUiN7UjNgeoP821PH61P81oOginOWioP863Q8F5QXJ6QXJ6QHB2
PH61PH61PX:3PhB5QHJ5QHB3Ph>3Ph:2PX:2PX>3Ph>3PX60OW]hMG=bLG5_KVma
MW]oPX>6RHb?Shn=RhR6Ph1nO7YiN7MgMgMhNW]kNgUhMgMgMgIfMGIgNGaoPXF7
R8Z;S8b;RHJ2OgekNGQgMgIgNG]mOh62PX:2PX61P7mnOGemOWn0PXB5QXJ7QhN7
QXF3PH20P820P861PXB5QXJ6QXF5Q8>2PX:1PH61PH62Ph>3Ph:1OW]gM79aL6i/
JfaaMgaoPH>6RhnBTi6>RhR5Ph5oO7UgMWIfN7UiNWYjNWUhN7MfMGAdM7EgNGao
PXF7RH^=SXj<RXN4PGilNWQhMgMgMgUlOX21P820P861P7mnOGenOX22Q8F5QXJ6
QXN7QXB3PH20P862PX:2PhB5QXJ6QXF4Ph:3Ph>2PX62PX>4Q8B4Ph:1OgahMG9a
Kfm]K6e`MGYnPH>6RXjATY:@SHZ7Q8:0OW]iMgIgN7UiNWYjNWUhMgMfMG=cLW=e
N7]nPHB7RHb>Shn>RhR5PWmmNWUgMWEeMgUkOWn0P820P860P7mnOGemOX21PhB5
QHJ6QhR7QhF3PX61PH:2PH:2PhB5QHF6QHF3PX61PX:2PH20PH>4QHB4Ph>1Ogai
MWAbKfe[JfibMgYlOh:6Ri2CTi6>RhV7QH:0O7UgMWIhNGYkNg]jNWYiN7MfM79a
LG=eN7]nP8>6RHf?T92>RhR4PGilNWQfM7AeMgUlOX21PH:2PX:1P7mmO7alOGn0
PX>4Q8F6R8R8QhF4Ph:2PX:2PH62PX>4QHF5Q8B3Ph>3Ph:2PH20PH>4Q8B3PX:2
P7eiMW=aKfe/K6ibMGUkOX:7S92BTI2>S8Z8QX>0O7YhMgMhNGYjNWYjNWYiN7Me
Lg5aLG=eMgYmP8>6RXb?Shn>RhV6Ph1mNgQgMWEfMgUlOWn0PH61PH60OgimO7am
OWn0PX>4QHJ7R8V8QhJ4Ph:2PX:2PX:2PhB5QXJ6QHB3PX:2Ph:1P820PX>4Q8B3
Ph>1OgahMG=aKVa[JfmbMWUkOh>8SI6BTI2>S8Z7QH9oO7UhMgMhNGYjNWYjNWUi
MgIdLW5`LG9eN7]nPHB7Rhj@T8n>RhR6PgmlNWQhMgIgN7YlOWmoP7moOginOGem
OGamOX23Q8J7QhR8R8R7QXF3PH60PH62PX>3Q8F6QXN6QH>1PH21PH20P821PXB5
QHJ5QHB3PGeiMG9`KVaZJVeaMWUlOX:7S92BTY2>S8V7QH:0OGYhMgMhNGYkNg]k
NWUhMgIdLW1`L75dMgUlP8>6RHb?T92>RhR6Ph5nO7YhMgMgN7UkOGioOgmoOgmo
OWimOGemOX21PhF6QXJ7QhR8QhF3PX:1PX:3Ph>3PhB5QHJ5Q8:1P821PH61P821
PXB5QHF5Q8B3PGmlN7EbKfe/Jfe`LgMiNgj3R8f@TI2>S8^:R8J3OgajN7QiNGYj
NW]kNWYiNGQgMG9aL71bM7MjOH23QXZ=Si2@SXb9QX>1OWaiMgIeMWQjO7emOGio
P820OginOGalOGn0PX>4Q8F7R8V9R8N5Q8>3Ph>3Ph:2PX>4QHF4Q8:1P820PH61
P820PXB5QXJ5QHB4Ph5nNgMdLFm^K6a]L7AgNWaoQ8V=T92?SXb;RHN4PGmlNWUh
NGUjNg]lNg]jNGQgMWAbL71`LWAgNWf0Q8N;SHn@Shf;R8J4PGikNGMfMGIgNG]m
OWinOgn0P7mnOGalOGioP8:3Q8F6QhR9RHR7QHB3Ph:2PX:2PH62PhB5Q8>2PH61
PH61PH61PH:2PhF6QXF5Ph:1OgaiMW=`KVa/KG1cMgUlOX:7S92AT8j<RhV7QH:0
O7YhN7QiNW]kO7]kNWYiN7MeLg5`LG9dMWUmP8B7RXf?T92?S8V6Ph1nNgQfMGEf
MgUkOGn0P820P820OgilO7alOGn1PhB5QXN9RXZ:R8J4Ph>2PH61PH61PH:3Q8B4
Ph:2PH61PH:1PX:2PhB5QHF5QHF4PX5oO7UeLVm]KFe^L7=fN7]nPhR<Shn>SHb;
RXR5PX1mNgUiNGYkNg]kNg]kNWUhMWAbL71aLWAgNGb0PhN;SY2AT8j;RHJ4PGik
N7IeMGIhNW]mOWioP861P7mnOGalO7enP8:3Q8J7RHZ:RXV7QXB3PX61P7moOh21
PX>3Ph>3Ph>3Ph>2PX61PX>4Q8F5Q8F5Q8B3PX1nNgIcL6m^KFe^L7AgNGaoQ8V<
Shn?SHb;RHN4PWmlNWUhNGUjNWYjNWYjNGQgMG=aL71aLgEhNgj2QHV<Si6AShf;
R8F2OgaiMgIeMGIhNW]lOGioP820OginOGemOWn0PX>5QXR9RXZ:RHN6Q8:1P7mo
OWinOh21PX>3Ph>3Ph>3Ph:2PX:3Q8F5QHF5QXJ6QHB2PGmnNgUfLg5_KFe]L7=f
NG]mP8B8S8j>SXb:RHR6QH>0OG]iNGUjNWYjNGUhN7QgMWEdLW9bLgEgNWf0PhJ8
Rhj?Shj;R8J3PGmlNWQfMGEfN7YlOGinOWn0PH60OginOWn0PXB5QXJ7R8V9RHR6
Q8:0OginOWimOGioPH>4QHB4Q8B4Q8B3Ph>3Ph>4QHJ7QhJ5QHB3PX1oO7YgMG9`
Kfi]KW1cMgYlOH24R8b=SXf<RhV8QXF3P7ilNWUiNGUjNWUiN7MgMgMgMGAcLgAf
N7YmP8>5QhZ<SHj=S8V7Q89oOG]hMWEdMGIhNW]lOWn0PH62PX:1PH61PX:3Q8F5
QHJ6QXJ5Q8:1OgmnOWinOWioP862PhB4Q8B3Q8B4Q8B4PhB4QHJ6QXJ6QHB3PX5o
OWajNWUhMWAcLW5bLWAgNG]lOGj1QHR;RhZ9R8R7QXF3PGilNWQhN7UiNGQhN7Qi
NGYjNGMfMWIgNGYlOWn2Q8J8RXb;RXV6Q8:0OWaiMgEeMWMiNgeoP862PhB5QHB3
PH20P861PH62PX:3Q8F5Q8>1P820P81oOgmoP862PhB4QHF5QHF5QHF5Q8B3Ph>4
Q8B4Ph:1P7mnOWelO7]jNGQgMGAdM7EfN7YjNg]nPHB8RHV8QhN6QXJ4PX1mNgUi
NWYjNWYiNW]kO7alNgUhMWIfMgQiNWanP8>5R8Z:RXV7QXF3PGilNWUhNGUjNgeo
P862Ph>4Ph>2P81oOginOgn0PH:3Q8B5QHB4Ph:2PH1oOgmoP861PX>4QHJ6QXJ6
QHF5Q8B3Ph:2PH62PX:1P7moOgmoOWimOGakNGMeM7AeMgQiNGQhNWj2QHN7QXJ6
QhN7QH>1OWakNW]kNg]kNg]lO7emO7]iMgEdM7EeMWQiNgj1Q8N:Rh^;RXV8QhB1
OW]jNGQhNGYlOGn0PH:2Ph>2PX1oOginOWioP821PX>5QHF5Q8>3PX60OgmoOgn0
PH:3Q8F5QHJ6QXJ5Q8>3PX61PH62PX:1PH61PX:1P7moOgmnO7YgMGAcLgAeMWIf
MWQlP8B7QhR7QhN8R8N6Ph1nO7]lO7emOGelO7alOGakN7EcLG5aLW=eMgYmP8B8
S8j?Shj=RhV7Ph1lNGQgMgQiNW]mOWn0PX>3Ph:0OginOWioOgn0PH:3QHJ6QXF4
Ph:2PH1oOginOX21PhB5QHF5QXJ6QXF4Ph:1PH:2PX:1PH61PX61PH20OgmoOWel
NWMeM7=cM7EfMWIfN7b0Q8N7QhN7R8R8QhJ3P7imO7emOGelO7]kNg]kNWQfM79a
LG=dMWQjO7n3QXZ<SXj=S8Z8QXB1OW]hMgIgNGYkO7ioP862PX:2PH1nOWenOh20
P821PXB5QXJ6Q8>2PH60P7moOWioP8:3QHF5QHF6QXJ6QXF4Ph:2PX:2PX60P820
P820OgmoOWinOWejN7EcLW=dMGIfMGIhO865R8R8R8V:RXZ9QX>0OGakNg]kNgYj
NWYkNg]kNGMeLg9bLgEfN7UlOh>6RXb>Shj=RhR6Q85nNgQfMWIgNGYlOGj0PH:2
Ph>2PH1oOWioOh20PH62Q8F6QXJ5Ph:1PH20OginOWn0PX>5QXJ6QXJ6QXJ5Q8>2
PX61PX:1PH20PH61P820OgmoOWelNWQeLg5bM7IgMgIfNGf2QXV9R8R8R8V9R8J3
P7ekNW]kO7alNg]kO7amO7YhMG=bLW=dMGMiNgj2QXV<SXj>SH^9QhB1OW]hMWIf
N7UkO7enP862PX:2PX5oOWenOWn0P862PhF6QhN6QHB3PX60OginOWioP862Q8F5
QHF6QXJ6QXB3PX61PH:2PX61PH61PH61PH60OgimO7YhMG9aLG=eMWIeMWQmPXJ9
RHV9R8V9RHR5Ph1mNgYjNgalO7alO7amOGajMgEbLG5bLgAfN7]nPXJ:SHn?Shj<
RXJ3P7ekN7IdM7EgNG]mOh22PX:2Ph>2P7mmOGioP862PhB4QHJ7QhN5Q8:0Ogmn
OWioOgn0PH>4QHJ5QHF5QHF4Q8>2PX:2PhB4Ph>2PH61P820OgekNGQfMG=aLG9d
MWMgMgUlPHF8RXV8R8R8R8N6Q85oO7]kO7alO7akNg]kNg]jN7EcLG5bLgEgNG]m
PHF9S8j?SXj<RXR6PgmlNWMfMGEfN7UkO7enOh21PX:2PH60P821PX>3Q8B4QHJ6
QXF4Ph60OgmoOWinOgn0PH:3PhB4Q8B4Q8B5Q8B4Q8F5QXF5QHB3PX20OginOGaj
NWQfMG9bLG=eMgQhN7QkOh>7RHV9R8V9RHV7QH>0OG]kNg]kNg]jNWYjNg]kNWMe
M79cM7EgNGYlOh>6RXf>SXf<RXR6Ph5nNgUgMGEfMgUjO7anOh21PX:2PX60P821
PX>3Q8B4QHJ6QXF4Ph:1OgmnOWinOWioPH:2PhB4Q8B4QHF6QHF4Q8F5QHF5QHB3
PX60OgmnOG]jN7MeLg5`L7=eMgQhNG]nPXN9Rh^:RHV8R8N5PX1mNgYjNWYjNW]j
Ng]kNg]jN7IeLg=dMGMhNWanPHF8Rhf>SHb:R8J3P7ekNGMfM7AfN7]mOWn0PH:2
PX:2PX60Ogn0PH:3PhB4QHF5QHF4Ph:0OginOWinOgn0PH62PhB5QHF5Q8F5QXJ6
QHF5QHF6QHF3PX1oOWemO7]hMWAaKfi_LWEgNGUiNgn3R8^<RhZ9R8R8QhJ3Ogaj
NGYkNg]jNWYjNW]kNgYhMWAcLgAfN7UkOGj1QHR<SHj=S8Z8QX>0OW]iMgIeMGMi
NgamOWmoP861PH61P820P863Q8B4Q8B5QHF4Ph:1P81oOgmoOgmoP862PX>3Ph>3
Ph>3PhB4QHF5QHJ7QhR7QhF3PX1oOGelNgYgMGAbLW5aLgEgNGYjNgj2QXV:RXV9
RHR8QhJ4PGilNWYjNgYjNWUiNWYkNgYiMgEdM7EfN7UkOGj1Q8N;SHf=S8Z9QhF2
OgaiMgIfMWMgN7YkOGioP861PX61PX:2PX:2PX>3Ph>3Ph>3PX61PH61P820P821
PX:2PX:2PX:2PX:2PX>4QHF6QXJ7R8R7QXB2PH1oOWakNWUiMgEcLG1`LgIiNGQh
NWf3QhZ;RXV8R8R9R8N4P7ejNGYjNW]jNWUiNWYkNg]iMgEdLgAfN7UkOGj1QHR;
SHj=S8^9QhB2OWaiN7IeMGEgNGYlO7enP862PX:2PX:2PX>3Q8B4Ph>3Ph>2PH60
P820P820PH62PX>3Ph:2PX:2PX:2PX>4Q8J6QhN7QhN6QXB2PGmnOGalNgYiN7Id
LW5aLgIiNGUhNGb1QXV:RXV8RHV9R8N4PGikNWUiNWYjNWYjNWYkO7ajN7IdLgAe
MgQjO7f0Q8N;SHj>S8^9QhF2P7ejN7IgMgQiNW]lOGenOgn0P820Oh21PX>4QHF5
QHJ6QXF4Ph60OgmoOgmoOh21PX>3Q8B3Ph:2PX:2PX:3Q8F6QXN7R8R8QhJ4PX1n
OGakNWUhMgIdLW9aLgIhNWUhN7]oQ8R9RHR8R8V:RXR6PgmmNgYjNWYiNGQhN7Uj
Ng]jN7IeM7EfMgUjO7f0PhN:S8f=S8^9QhF3P7ejNGMgMgMhNWYkO7enOh20P820
P821PH:4Q8F5QHF5QXF4Ph:1P81oOgmoOh20PH:3Ph>2PX:2PX:2Ph>4Q8B5QXN8
R8N6QXF4PX1nOGakNWUgMWAbL6m`LgIiNGQhNGj3R8Z;RhV9RHV9RHN4P7ejNGYj
NWYjNGUiNGYkNgYiMWEcLgAfN7YkOGn2QHV=SXn>S8Z8QX>0OW]iMgIfMWMiNW]l
OGioP820P820P821PH>4QHJ6QXF5QHF4Ph60OginOWmoOh21PX:3Ph>3Ph:2PX:2
PX:3Q8F6QhR8RHV8QhJ4PX1nOGakNWQfMG=aKfm`LgMiNGQhNWn4R8Z;RXV9RHV:
RHN4PGikNgYkNgYjNGQhNGUiNWUgMWAcLgAfNGYlOX23QXZ=SXn>S8Z8QH>0OG]h
MgEeMWMiNWamOWioP861PH61PH20PH:3Q8F5Q8B5QHB4Ph:1P7moOgn0P861PX:3
Ph>2PX:2PX:2PX>4Q8F5QXN7R8N7QXB3PH1oOWekNWQfMG9aKfmaM7MhN7QiOH66
RH^;RXZ9RHV9QhF2OgajNWYjNWYjNGUiNGYjNGQfMG=bLgAfNG]mOh65R8b>Shn=
RhV6Ph5nO7YhMWEeMWQjO7enOgn0P821PH60P7moP8:3QHF5QHF5QHF4Ph:1Ogmn
OWmoP862PX>3Ph>3Ph:2PH:2Ph>4Q8F6QhN8R8N7QHB2PGmnOGajNGIdLFm^KW5d
MgQhN7UmPXN;S8b:RHV9RHV7QH9nO7YjNg]kNgYiNGUiNGUiMgEdLW9cMGMiNgeo
PXF9S8j?Shf;R8F3P7ilNGMeM7EfNG]mOWioOh21PH61P7moOgn0PXB5QHF5QHF6
QHB3PH1oOgn0P820PH62PhB4Q8>3PX61PH:2PhB4QHF6QhR9R8N6Q8:1OgimNgYi
MgEdLW1_L79fN7UiNGYnPXN:RXZ8R8R8R8R7Q85nO7]kNg]kNgYiNGUiNGUhMgEd
Lg=dMGQjO7j0PhJ9SHj?SXb:QhF2OgekN7MeMGIgNG]mOWn0P861PH61P81oOgn0
PH>4Q8B4Q8F5Q8B3PX60P820P861PX:3Ph>3Ph>2PX61PH63Q8B5QHJ6QhR8R8N5
Ph60OgimNgYhMgEcLFm_LGAgN7UiNGb0QHV:RhZ8R8R9R8N5PWmmNg]kNg]kNWYi
NGUiNGQgMGAbLW9dMWUkOGn2QHV<Si2?SX^9QX>0OW]iMgEdMGIiNgenOgn0PH:1
PH60P7moOh21PhB4QHF5QXJ5QH>2PH20P820P862Ph>4Q8>3Ph>2PX61PH:2PhB5
QHJ7R8V9R8J4Ph5oOWakNGQfMG9`KViaM7QjNWYjO825RHZ:RHR8QhR7QhF2P7ek
Ng]lO7akNWUiNGUiNGQfM79bLWAfNG]mOh64Qh^>Shn=RhR6Ph5oO7UgMGAeMgUk
O7enP862PX:2PH1oOgmoP862Ph>3Q8F5QXF4Ph:1P820P820P862Ph>4Q8>2PX:2
PX61PX:3Q8F5QXN8R8R7QHB2PH1oOGajN7MeLg5_Kg1cMWQiNGUkP8F9RXZ9RHV9
RHR7QH:0OGakNg]kNgYjNGUiNWUiMgEdLW9bLgEhNWaoPHB8Rhj?Shj<RHJ4PGil
NGMfMWIgN7YkOGioOh20P820OgmoP821PX>4QHF6QXJ6QH>2PH1oOgmoOgn0PX>4
QHF5Q8>2PX:1PH20P8:3Q8F6QhR9RHV8QX>1OgimNgUgMG=bL6m^L7=gNGYjNWb0
QHV:RhZ8R8N8R8N6Ph1nO7akNgakNgYiN7QiNGQgMGAbLW=dMWUkOGn2QHR;SXn?
SXb9QhB1OgaiMgIeMGEgNG]mOWmoOh22PX:1P820P861PX>4Q8F5QHF5Q8>1PH1o
Oh20PH61PX>3Q8B3PX:2PH60P862PhB4QHJ7R8V9R8N5Ph60OgilNWQfM7=bL6m_
LWEhNWYiNgj3QhZ;RXV8R8R8R8J4PGilNg]kNg]kNWYiNGUjNGQfM79bLW=dMgUl
OX64Qh^>T92?SH^8QH9oO7YgMGAdMGIiNgenOh21PX>3PX60OgmoOh21PX:3Q8F5
QXJ5Q8>1PH20P820P821PX>3Ph>3Ph:2PX:2PX:3Q8B5QHJ7QhR8QhF3PGmoOWaj
N7EcLFm]KW1cMgUiNGYmPXN;S8^9R8N7R8R6Q85nO7]kO7alO7]jNWUjNWYhMgAb
LG5bLgIhNWeoPXJ9SHn@T8j<RHJ3PGikN7IdLgAeN7YmOWn0P862Ph>2PGmnOWn0
PH:3Ph>4Q8F6QXF4PX20P820PH20PH62PhB5Q8>2PX61PX:2PX>4Q8F6QhR8RHR6
Q8:0OginO7YgMG=aL6m_LWAgNGYjNgj2QXZ:RXV8R8R8QhJ4PGilNg]kNgakNgYj
NGUjNWQgMG=bLG9dMWQjO7j1QHR<SXn?SHZ8QXB2OgaiMgIeMWMiNganOWn0P861
PH5oOginOh21PX>3Q8F6QXJ6QH>2PH1oP820P821PX>4QHF5Q8>2PX:2PX62Ph>4
QHF6QhR8R8J5PX60OgilNWQeLg5_KViaMGQiNGUjOhB8Rh^;RHR8QhN7QXB0OG]j
NW]lO7]kNWYiNWYjNGMdLW5aLWAfN7YlOh:6RXf?T8n=RhR5Ph1mNgQfMGAeMWUl
OWn0P861PX:2PH1oOWenOh62PhB4QHJ6QXJ5Q8:1P7moP820PH62PhB4QHF4Q8>2
PX62PX:3PhB5QXJ7R8R8QXB2P7mnOG]iMWAaKfe]Kg=gNGUjNgf2QhZ<RhZ8QhN7
QhJ4PGilNg]lOGelNgYjNWYjNWUgMG=aLG5cMGQjO7j0Q8N;SXn?SX^9QXB2Ogej
N7IeMWMiNganOh20P861PH60OginOWn0PX:3Q8B5QXJ6QHB2PH20Ogn0P862PX>4
Q8F5Q8>3PX:2PX62PX>4Q8F6QXN7QhJ5Ph:0OgilNWQfM79_KFe`LgMiNWYkOhB8
Rhb;RXR7QhJ6QH>0OG]jNW]lOGalNgYjNW]jNGMeLg5aLW=fN7]mOh65R8b>Shn=
RXR5Ph5oO7UgMGEfN7YkOGn0P861PX:2PH1oOWinOh21PX:3Q8F6QXJ4Ph:1PH20
P821PH62PhB5QHB3Ph>2PX:2PX:2PX>4QXJ6QhJ6QHB3PH1oOG]hMW9_K6]/Kg=f
N7QiNh26Rhj>SH^:R8N7QXB1OW]hN7UjO7elO7]jNW]lNgUgM79`L75cMGQkOGn2
QXZ=Si2?SH^8QH:0OG]hMWEeMWQjO7eoP862PX:2PH60OWinOh21PX:3Q8F6QhN6
Q8>1PH20P820P862PhB5QHF5Q8>2PX:2PX61PH>4QHJ7R8R8QhJ5Ph60OWejMgA_
K6YZK71dMWMhNWj3RHf?Shf;RXR7QXF3P7ejN7QiNWamOGakNWYkNg]iMW=aL71b
M7MiNgf0PhJ:SHn?SXb9QhB2P7ikNGMfMgQiO7eoOh20P861P81oOWemOWn0PX>3
Q8F6QhN7QXB2PH20P820P821PH>4QHJ5QH>2PX:2PX:1PH62PhF6QXN8R8R6QH>1
P7ilNWIbKV]YJFaaM7IgN7YoQX^?T8n=RhZ9R8J4PGikNGQhNGYkO7alNgYjNg]j
N7EcLG1`LWEhNWeoPXF8S8j?Shf;R8F2P7ekNGQgMgMhNWanOh20P820P81oOWim
OWj0PH>4QHF6QXN7QXF3PH1oOgmoP820PH:4QHJ6QHB3PX61PH61PX:2PhB6QhV9
RHR7QXB3PGmmNWIcKfaYJ6Y^LWEgMgUmQ8Z?TI2?SHb;RXR6PgmlNGQgN7UjNW]k
NWYjNWYjN7IdLW5aLWAgNWaoPHF8Rhj?Shj;RHJ3PGikN7MeMGIgNG]mOh21PH:2
PH60OgimOGinP863Q8B5QXN7QhJ4PX60P7moOgn0P862Q8F6QHB3PX:2PX:2PH62
PhF6QhR7R8R7QXB2PGmnO7UeLFeZJ6U/L7AfMgQkOhJ<T96@Shf;RXV8QX=oNgQg
MgQiNWYjNGUiNWYjNGMeLg9aLWAfNG]mP8:6RXf?Shj<RXN5PWmmNgUgMWIgN7Yl
OWn0P820P820OgimOGioP8:3QHF6QXJ7QhJ5Ph5oOWinOWmoP862PhF6QXJ5Ph:2
PH61PH61PX>5QXR9RHZ9QhJ4Ph:0OGYfLfm/JFQYKG5eMgQjOH>9SY2@Shf<RhZ8
QXB0OGYiN7QiNW]kNWUiNGUjNGQeLg9aLW=fN7]mOh:5R8^>Shn>RhV5PX1mNgUg
MGEeMgUlOWn0PH:2PX:1PH1nOGenOh21PX>4QHF6QXJ6Q8>1P7moOgmoP821PXB5
QHF4Ph:2PH62PX:2PhB5QXN8RHV9R8J4Ph5oOWaiMG5/JFMYK71dMWIgNWn6S92A
T8j=S8^:RHJ3Og]iN7QiNWYjNWUhN7UiNWUgM79aLG=eMgYlOX63QhZ=T92?SHZ7
Q85nNgUgMGAdMWQjOGj0PH:2PX:2PX5oOWemOWn0PX>4Q8F6QhN7QXB2PH20Ogmo
Ogn0PH:4QHF4Ph:2PX:2PX:2PX:3QHJ8RHV9RHR6QH>1OgejMW=^JVMWJFeaM7Ef
NGf3RXnATI2>SHb;RHN4P7ajN7QhNGYjNWYiN7UiNGUgMG=aL75cMWUlOX23QXV<
Si2@SX^8Q85oO7YhMWEdMGMjO7j0PH61PH:2PH5oOWelOGn1PXB4QHF6QhR7QXB2
P7moOgmoOgmoP8:3QHF5Q8>2PX:1PH:2Ph>4QHJ8RHZ:RXR6Q8:1OgikMg=^JVQW
JFeaM7EfN7b2RHjATI2>S8b;RXV6PWikN7QiNWYjNWUhN7QhNGQgMG=aLG9dMWUl
OX23QXV<SXn?SH^8QH:0OG]hMWEeMGMiO7enOh20PH:2PX60OWinOh21PhB4Q8F5
QXN6QH>1P7mnOh20P820PH:4QHJ5Q8:1PH61PH:2PX>4QHN8RX^;RXV7QH>1Ogil
NGIbKFYXJF]_LgEfMWUnQ8^?TI2?SHb<S8^9QH5mNWQhNGYjNWUhMgMgN7UhMgEb
LG5cMGQjO7n1PhN:SHn?SXb9QhB1OgajN7IeMGIhNWanOh20PH62PX60OginOWn0
PH>3Q8F5QXJ7QXF3PH1oOgmoP820P862Q8F5Q8>2PX:2PX:2PX>3QHJ7QhR9RXZ9
QhB2P7mnO7UeLFeZJ6U]LGAfMWMjOhJ<Si2?SXb<Rh^:R8B0O7UhN7UjNWYiN7Mg
N7UiN7IdLW5aLgIhNgeoPHB8Rhj?Shj<RHJ3P7ekN7IdLg=eMgYmOh21PH:3Ph>3
PX1oOWioP8:2Ph>3Q8F6QXJ4Ph60Oh20P820P821PXB5Q8B3PX61PH62PX:3Q8F6
QhV9RHV8QhF3PH1nO7YgM71/JVY/Kg9dMGIhO867S8j?SXf;RhZ:R8J2OgajNGUj
Ng]jNGQhN7QiNGMeLg9aLWAfNGanP8:5R8^=Shj=RhR5PX1mNgUgMWEfMgUkOGn0
P821PH61PH1oOgioP8:3Q8B5QHF6QXJ5Ph:0OgioOh20P821PX>4QHF4Ph:2PH61
PX:3PhB5QXN8RHZ:R8J4PX60OgejMW=_KF][KFmcMGIfN7b1Qh^=SXf<Rh^;RXR6
PWmlNgYjNWYjNWUhMgMhNGQgMGAbLW=eMgUkOGn1Q8N;SHj>SH^9QXB1OW]hMWEd
MGIhNG]mOX21PX:3Ph:2PH20P862PX:3Ph>4Q8F4Ph:0P820P820P820PH:3Q8B4
Ph:1PH:2PX:3PhB5QHJ8RHZ:RHN5Ph:0OgelNWMeLVm/Jfa_LgIgN7QjOXB9S8j=
S8^:RXV8QhB1OW]jNGYjNWYiN7MgN7UiNGMeLg9cM7MiNgenP8:5RH^=SXf;RHJ4
PGmmNgQfMGEfN7YkOGj0P861PX>3PX60Oh21PX:3Ph>3Q8B5QHB3PH20P820P820
P861PX>4Q8>3PX:2PX:2PhB4QHF5QhR9RHV7QXB2PGmnO7]iMgEbKfe/KW5dMgQh
NG]oQHZ<SHf;RXV9RHR6Ph1mNWUiNGYjNWUhN7QiNW]jN7IdLg=eMgUkO7ioPXF8
Rhf>SH^9QXB2P7ejMgEeMGIgNG]mOh21PX:3Ph>2PH20P861PX:2PX>3Q8B4Ph:2
PH20P820P820PH63PhB4Ph>2PX:2PX:3Ph>4QHJ7R8R8QhN6Q8>1OgekNWUgMG9_
K6a^LWIhNGUjOH66RXf=S8Z9R8R7QhF2OgajNGUjNg]jNGQhN7UjNWUgMGAcM7Ih
NW]mOX23QHV;SHf;RHN5Ph5oOGYhMWIgN7YkOGioOh21PX:3PX60Oh20PH:2PX:2
PhB4Q8B3PX60P820P820P821PX>4Q8B3PX:2Ph>3Ph:2PhB6QhR8QhN6QHF4PX1m
NgYiN7MdLFi/KG5eN7UiNG]oQ8R;S8b;RHR7QhN6Q85nNgUiNW]kNgYhN7QiNW]k
NWQfM7AeMgUjO7enP8>6RH^<S8^9QhF3PGilNWQgMgMhNWanOh20PH62PX:1P81o
Ogn0PH62PX>3Q8F5Q8>3PX61P820P820PH62PhB4Ph>3Ph>3Ph>2PX>4QHJ6QXN7
QhN6Q8:0OgilNgYhMW9_KFe_LWIhNGUjO866RXb=RhZ9R8R7QhF2OgajNGUjNg]k
NWQhNGYkNgYhMWAcM7EgNGYlOGn2QHR;SHf=RhV6Q89oO7UgMGEfMgQiNgioPH:3
Q8B4Ph:1P820P820P861PX>4Q8B3Ph:2PX:1PH20P821PX>4Q8>2PX:3Q8>3PX:2
Q8B5QHJ6QXJ6QXF4PWmnOGelNWQeLW1^KW1cMWQiNGYlP8F9S8b;RHN6QXN6QH9n
NgUiNW]lO7]jNGUjNgalNgUfM7=cM7IhNW]lOX64R8Z<SHb:R8J4PX1nNgUgMWMh
NW]mOWn0PH62PX:1P7mnOWmoP861PX:3Q8F5QHF4Ph:1P820Ogn0P862PhB4Q8B4
Q8>3Ph:2PX:3Q8B4Q8F6QhN7QH>2P7mnOGajN7EbKfi^LGAgNGUiNWf1QXZ;RhV8
QhN7QhJ5PGikNGUjNgalNgYiNGYkO7akN7IdLgAeMgUjNganPHF8Rhf=S8Z8QXB2
P7ikN7IfMgQjO7enOh20PH:3Ph:1OgmoOh21PH61PX>4QHJ5Q8>2PH60P820Ogn0
PH:3Q8B4Q8>3Ph>3Ph>3Ph>4Q8F6QXN7QhF4PX5oOWelNWYhMgIdLW5bM7MiNWYj
Ngf1QHR9RHR7QhN7QhJ4PGilNgYjNg]jNGUiNGYlOGakNGMeM7EfMgUjNganPHF8
Rhb<RhV8QXB2P7ejN7MfMgQjO7ioOh21PX:2PX5oOWinOWmoP862PhB5QXJ6QHB3
PX60OgmnOgn0PH:3Q8B4QHF5Q8B3PX:2PX>3Ph>4QHJ7QXF4Ph60OgelNgYhMgAb
L75bMGQjNWUjO7n3QhR8QhJ6QXJ6QXB2OgilNg]lO7akNgYjNW]lO7]iMgEcLgAf
N7UjNgf0PhN:S8b;RXV7QXB1OW]iMgIgN7UkO7enOh61PX>2PH1oOgmoP820PH62
PhB5QHF4Q8>2PH60OgmoP821PH:3Q8B4Q8B4Q8>2PX:3Ph>3Q8B5QXJ6QHB3PH1o
OWelNgYhMgAbL75cMWUjNGUjO865R8V8QhJ6QhN7QH>1OWakNg]kO7akNgYkNgam
O7YhMG=cM7EgN7UjO7n2QXZ<SHf;RXV7QH>0OGYhMgMhNG]lOGioP861PX:1P7mn
OWioP862PX>4QHF6QXF4Ph60OgmoOgmoOh21PX>5QHF5Q8B3Ph:2PX:2PX:3Q8F6
QhN6QH>2PH1nOGakNWUiNGMeM7=eMgUkNWUiNGb0PhF6QXF6QXN7QhJ4PX1nO7]k
Ng]kNWYjNW]kO7]iMgEdM7EfMgQiNWf0PhN9Rhb<RhZ9QhJ3P7ejN7MgN7YkO7am
OWn0PH:1PH1nOWioP862PX:3PhB6QXJ5Ph:0P7moOgmoOgn0PH>4QHF4Q8>2PX>3
PX:1PH62PhB6QhN6QH>2PH60OgelNg]kNgYhMWAdMWMiNWUhN7UlOh:5QHJ6QXJ7
QhN6Q8:0OGalO7alO7]jNWYkNg]kNGMeLg=dMWMhNW]nPHB8Rhb=S8b:RHN5Ph1l
NGQgMgQiNW]kO7enOh21PH60OgmoP862Ph>3PhB5QHF5Q8:1P820OgmoP820PH:3
Q8B5Q8>3PX:3Ph>3Ph>3PhB5QXJ6QHB2PH1oOgemO7alO7]jNGMeMGIhNGUhMgMi
O823QHJ6QXJ7R8R7QX>1OWakNg]lO7]jNWYjNgalNgUgMGAdM7IgN7YkOX65R8^<
SHf<RXV7Q85nNgUgMgMhN7UkO7enOh21PX:1P7moP821PH62PX>4Q8F5Q8>2PX61
P7moOgn0P861PX>3Q8B4Ph>3Ph:2PX>3Ph>4Q8F5QHB3PX:1P7mnOWinOWelNWQf
M7AfMgQhMgIgNGf1Q8J6QXN7R8R8R8J3P7ilNg]lO7akNWYjNW]lO7YhMG=cLgAf
MgQjO7n2QXZ<SHj=RhZ8QXB1OGYhMgMgN7UjNgamOWn0PH61P7mnOWn0PH:2PX>3
Q8F6QXF4Ph:1P81oOgmoOgn0PX>4Q8B3Ph>3Ph>2PX:2PX>3Q8F5QHF5Q8>2P81o
OgimOGakNgUgMGAeMWMhMgMfMgYnPHB5QXJ7R8R8R8N5Ph1nO7akO7akNWUiNW]l
O7]jMgEdM7AfMgQiNgf0Q8N;SHf=S8^:R8J3P7ejN7IfMgQiNW]lOGn0PH:2PH60
P820P861PX:3PhB4QHF5Ph:2PH60P81oOgn0PH:2Ph>3Ph>3Ph>2PX:3Ph>3Q8B5
QHF5Q8>3PX60OginOWemOG]jMgEdM7EgN7MfMGIiOH64QXN7QhR8RHV8QX>1OWak
Ng]kNgYjNWYkO7akNWQeM7=dMGIgNGYlP8>7RXb=SHf<RXR5Ph1mNWQgMWMhNG]l
OGioP861PH20OginOgn0PH62PX>4QHJ6QXF4Ph:1P7moOgmoOh21PX:3Ph>3Ph>2
PX:3PX:2PX>4Q8F5QHB4Ph:1PH1oOWimOGajN7IdLg=eMWMgMWIgNWj2QHN8QhR8
R8V8QhF2P7elNg]kNg]kNWYjNW]kNgUgMGAcM7EgN7YlOX64R8^=SHf<RXV7QH9n
NgUgMgMhN7UjNgenOh61PH60P7moOh20P861PX>4QHJ6QXF4Ph>2PH1oOgmoOgn0
PH:3Ph>3Ph>3PX:2PX:2PX>4QHJ6QXJ5Q8>3PX60OWemO7akNGMeM7=dMGMhMgIf
MgYnPXF6QXJ7QhR8R8N5Ph1nO7akNg]kNWUiNGYkNg]iMgIdM7EfMgUjNgj0Q8N:
S8b<RhZ9QhF2OgajN7MgN7QiNW]lOWn1PH61P820P820P861PH:3Q8F6QXF5Q8>2
PX60OgmnOWioP862PX>3Ph>3Ph>3Ph>2PX:3Q8B5QHF5Q8B3PX:1P7mnOWemO7Yh
MW=bLgAeMWMfMWMjOX:6QhR8R8R8RHR7QH:0OG]kNg]lNg]jNWYkO7akNWMeM7=d
MGIhNG]mP8>7RXb=SHb;RHN5PWmlNWUhMgMhNWamOWioP861PH1oOgmoOgn0PH:3
Q8F5QXJ6QXF4Ph60OginOWinOh21PX:3PhB3Ph>3PX:2PX:2PhB4QHF6QXJ5Q8>2
P81oOWemO7]jN7IdLg=eMWMgMWIgNWf1Q8J7QhN8R8V9R8J4PGimO7]kNg]jNGUj
NW]lNgYhMWEdMGEgN7UkOGn2QXV;S8b<RXV7QH>0OW]iN7MhNGYkO7enOh20P820
P81oOgn0PH62PhB4QHJ6QXJ5Q8>1P7moOWinOWioP862Ph>3Ph>4Q8>3Ph>3Ph>4
Q8F6QXJ5Q8>2PX60OgimOGakNWQfM7=cM7IgMgIfMgYnPXF7QhN7R8R9R8R6Ph5n
O7]kNgakNgYjNW]kO7]jN7IdM7AeMWMiNWaoPXJ8Rhb<S8^9R8F3P7ekNGQgN7Uj
NgamOWn0P860P820OgmoP821PX>3Q8F6QXJ5QHB3PX1oOginOWinP862PX>3PhB4
Q8>3Ph>3Ph>4Q8B5QHJ6QHF4PX60OginOGelNgUfM7=cM7EgMgMfMgQlP8B6QhN7
QhR8R8R6Q89oOGalO7alO7]jNW]kO7akNWMfM7AdMGIhNG]mP8>7RH^<S8b:RHN5
Ph1mNWUhN7QiNW]lOGioP821PH60P7moP821PH:3PhB5QHJ6QHF3Ph:1P7moOWin
Oh21PH:3Ph>3Ph>3Ph>3Ph>3PhB5QXJ6QHF4Ph:1P7mnOGalNg]jN7EdLgAfMgQh
MgMhNgn3QHN7QhN7QhR7QXB2OgelNg]lO7akNg]kO7amO7YhMWEdM7EfN7UjOH23
QXV:Rh^;RXV7QH>0OW]iN7QiNWYkO7enOh20P820P7moOgn0PH:2Ph>4QHJ6QXF5
Q8:1P7moOWinOWioP862PX>3PhB4Q8B4Q8B3Ph>4QHF5QHF4Ph:2PH1oOWimO7]j
N7IdLg9cMGMhMgMhNWj2QHN8QhN7QhN7QXB2P7ilNg]kO7alO7]kNgalO7]iMWAc
LgAeMgQjO7j1QHR:Rh^;RXV8QX>1OWajNGQhNGYkO7amOWn0P820OgmoOgn0PH:3
PhB5QHJ6QXJ5Q8>1P81oOWimOWioP862PX>3Ph>3Ph>3Ph>3Q8B4QHF5QXJ6QH>2
PH1oOWelNgYhMW=bLG9dMWMhN7QjOH64QXR8QhN7QhN6QH>1OgelO7alO7alNg]k
Ng]kNgUgMWAdM7EgN7YkOH23QXR:Rh^:R8N6Q8:0OWajNGUiNgamOGemOWmoOgmo
OginOWn0PX>3Q8B5QHJ6QXF4Ph:1P820OgmnOWn0PH62PX:2PX:2PX:3Ph>4Q8F6
QXJ7QhJ5Q8>1P7imOGakNWQfM7=bLWAfMgQhNGYlOh:5QhN7QhN7QhN6Q8:0OWak
NgalO7]kNW]kNgakNWUgMGEeMWMhNW]lOX64QhV;RhZ9QhJ4Ph5nO7YiNGUjNgam
OGinOWmoOgmoOWinOh21PX>4Q8F5QXJ6QXF4Ph:1P820OgmoOh21PH:2PX:2PX:2
PX:2Ph>4Q8F5QXN7QhN5Q8:0P7mnOGajN7IdLW5aLgEgN7QiNWf0Q8N8R8N7QhN7
QhJ4PGmmO7alO7alNg]jNg]lO7]jN7IeMGEfMgUjNgeoPXF8RX^:RXR7QXB2P7il
NgYiNGYkOGenOWmoOh1oOginOWmoOh21Ph>4QHF6QXJ5Q8>2PX61PH20Oh20PH:2
PX61PH61PH61PH62PhB5QXN7QhN7QhJ4Ph60OgilNgQfM7=bLG9cMGMhNGYkOh:5
R8R8R8N7QhN6QH>1OWelO7alO7]kNWYjNg]kNWUgMWEeMWMhNWamOh64QhV:RXZ8
QhJ4Ph5nO7]jNWYkNgamOWinOgmoOgmnOGenOWn0PH:3Q8F6QXN6QXF3PX:1PH61
P820P862Ph>2PX60P820P821PH:2PhF6QhN7QhN6QH>2P7mnOG]iMgEbLG1aLWEg
N7QiNgj2QXR9RHR7QhN7QhF3PGmmO7alO7akNgYiNGYjNWYhMgEeMGIgNG]lOX22
QHN9RX^:RHN5Q8:0OWakNGUiNW]lOGinOWmoP820OgimOWioP8:2PhB4QHJ7QXJ5
Ph:1PH20P820P862PhB4Q8>2PH20Oh20P820PH:4QXN7R8R8QhJ4PX60OgekN7Ic
LG1`LG=eMgQiNWaoPhJ8R8R7QXJ6QXJ5Ph5oOWemOGemO7]jNGUiNWUiMgIeM7Ef
N7YlOGn0PXF8RX^:RXR7QHB2P7imNgYiNGYkO7enOWinOWmoOgmoOWioP862PhB4
Q8B5QXJ5Q8>2PH20PH61PH61PX>4Q8B4Ph60P7moP820P862Q8F6QhR8R8N6QH>1
P7mmNgQfLg5`L75cMGMhNGYlP8B7R8R8QhJ6QXJ6Q8:0OWemOGenOGakNWUiNGUi
N7IdLg=dMGMiO7eoPH>6R8Z;RhZ8QXB3PH1nO7YiNGYkO7enOWinOGinOginOGem
OX21PX>4QHF5QXJ7QXF3PH20P820P820PH:3Q8F5Q8>1P820P820P820PX>5QhR8
QhN6QXF3PH1nOG]hMW=bLG5bM7IhNGUjOH23QXN8QhJ6QXJ5QHB3PGmnOGemOGem
O7YiNGUiNGQfMGAdM7IhNWanOh63QHR9RX^:RHN5Ph:0OgekNWYjNW]lO7emOGem
OWioOWinOh21PX>4Q8F5QHF5QHF4PX60P820PH60PH62PhB4Q8>2PX60P820P821
PH>4QXN8R8N7QXF4PX5oOWekNGMdLW5aLWAeMgUiNWanPXF7R8R7QXJ6QXJ5Ph60
OWemOGemO7ajNGUiNWYiN7IdM7AeMgUjO7j0PXB7RHZ;RXV7QXB2PGmmNgYiNGYk
O7emOWinOWioOgmnOGenOh62PhB4Q8F5QXJ6QH>2PH20P820Ogn0P8:3Q8B4Ph:2
PH61PH61PH62PhB6QhN7QXF4Ph:1P7mnNgUgMG=bLG9cMGMhNGYlOh:5QhR8QhN7
QXJ5Q8:0OgimO7alO7alNgYjNWYjNGQfMGAdMGIhNWamOh64QXR:RXZ9QhJ4Ph5o
OWakNWYkNgamOGemOGinOginOGenOh21PX>4Q8F5QHF6QHB3PH60P820P820PH:3
Q8B5Q8>2PH61PH61PH61PX>5QhN7QhJ5Q8>2PH1nOG]iMgIdLg9bLgEgNGUjO7j1
Q8N8R8N7QXJ6QHB3PGmnOGalO7alNg]jNWYjNWYiMgIeMGEfN7UkO7j0PXF7RHV:
RHR7QHB2PGmmO7]kNg]lOGemOGemOWioOginOWn0PH:3Q8B5QHF5QXJ5Q8:1P820
P820P821PX>4Q8B3Ph:1P861PH61PH62Q8J7QhN6QHB3PX60OgelNWQfM7=bLW9d
MWQiNW]mP8B6QhR7QhJ6QXF4Ph5oOWelO7alO7]kNWYjNWYjNGQgMWEfMgQiNgam
Oh63QXN8RHR7QXF4PX60OWelO7]lO7enOWinOWioOgmnOWinOh20PX>3Q8B4QHF6
QHB3PX61PH61PH60PH62Ph>3Ph:2PX62PX:2PX:3PhB5QHF5QHF4Ph:0OgmnO7Yh
MW=aL75bMGMhNGUkOX:6RHZ:R8N7QXJ5Q8:0OWakNg]lO7alNgYjNW]kNWUgMGAd
MGMhNWamOh63QHN9RHR7QXF3PX1oOWelO7alOGioOgmoOWinOWimOGemOWn0PX>4
QHF6QXJ6QXF3PX60P820P821PH:3PhB4Q8B3PX61PH61PH62PhB5QXJ7QhJ6Q8>2
PH1nO7YgM79`L71aLgEgN7YlOh>7RHZ:RHR8QhN6Q8:0OWelO7alO7akNgYjNWYj
NGQfMGAdMGMiNWanP8:4QXR9RHV8QXF3PGmnOGelO7]lOGmoP820OgmoOWemOGem
OGioPH:4QHF6QXJ6QHB3PX60P820P820PH:3Q8B4Q8B3PX60P820PH62PX>4QXN8
R8N6QH>2PH1oO7YgM79`KfmaLgEgN7UkOX:6RHZ:R8R7QhN7QH>1OgelO7alO7ak
NWYiNGUiN7MfMGAdMGIhNWanP8:4QXR9RXV8QXB3PH1nOGakNW]lOGinOgmoOgmo
OginOGemOGioPH:3Q8F5QXJ6QHB4PX60P820P861PH:2PhB4Q8>2PH60P820P861
PX>4QXN8R8R7QH>2PH1oOWajMgEcLW5bLgAeMgQiNgf0Q8N8R8R8QhR8QhJ4PX1n
OGelO7akNWYjNGUiNGUhMgEeMGIgN7YkOGn1PhJ8RHZ:RHR7QH>1OgilNgYjNW]l
OGinOWmoOgmoOgmoOgmoP862PhB4Q8F5QHF4Q8>2PH60P820PH61PX:3Ph>3PX60
P821PH62PX>4QHJ7QhR7QXF4PX60OgilNgQfM79aLG9cMGIgNGYlOh>6QhR8R8R8
R8N6Q8>1OgemO7akNg]jNGUiNGUiN7MfMGEeMgQiNgenP8:5QhR9RHV8QhF3PX1n
OGakNWYkO7amOWinOWmoOgmnOWinOh20PX>4Q8F5QHF5QHB3PX61PH20P820PH:2
PX>2PX:1PH61PH61PX>3Q8F5QXN7QhJ5Q8:1OginOGajMgEcLG5bLgEfMgQiNgj1
QHN8R8R7R8R7QhF3PGmnOGalO7]kNWUiNGUiNWUhMWEeMGIhNG]lOGn1PhF7R8V9
R8N5Q8:1P7mnO7]kNgamOGinOWinOWinOWinOWn0PH:3Q8F5QXJ6QXF5Q8:1PH20
P820P861PX:2PX:2PX61P821PX:3PhB5QHJ6QhN7QXB3PH1oOWelNWMeLg9aLG9d
MWMhNG]mPHB7RHV8R8R8QhN6Q8:0OWalO7]kNgYjNGUiNGYiN7MfMGEfMgUkO7io
PH>5QhR9R8R7QXB2P7mnOGakNg]lOGinOWmoOgmoOWinOWioOh21PX>4QHF6QHF5
Q8>2PH60P820P821PH:2Ph>3PX:2PH61PH61PX>4QHJ6QhN7QXJ5Ph:0OginO7Yh
MG=bLG9bM7EgN7UjOH24QXR9R8R7QhN7QXB2P7imO7]kNg]jNWUiNGYjNGUgMWIf
MWMiNWamOX22Q8J7R8V8QhJ4Ph60OWelNg]kO7amOWioOgmoOgmnOWioOgn0PH:3
Q8B4QHF5Q8B3PX:1PH20P820PH62PX:3Ph:2PX:1PH61PH:2PhB5QXJ6QXJ5QHB3
PH1oOWekNGMeLg9bLW=eMWQiNgeoPhJ8RHV8R8N7QXF4PX1nOGalO7alNg]jNWYj
NWYiN7MfMWIgN7YkOGn0PXB6QhR9R8N6Q8>1OgimO7akNgamOGioOh20P7moOWin
OWioOh21PX>4Q8F5QHF4Q8>2PX61P820P861PX>3Ph>3Ph:2PX61PH61PX:3Q8F6
QXJ5QHB4Ph60OgimNgUgMG=bLW9cMGMhNGYlOh:6QhR8QhN7QXJ5Q8:0OWelO7al
O7]kNWYjNWYjNGQgMWIfMgQjNgenP863QHJ7R8R7QXB2PH1oOWelO7]lO7enOWmo
OgmnOWinOgmoOgn0PH:4Q8F5QHF4Q8>3PX61PH20P821PX:3Ph>3Ph:2PX61P861
PX:3PhB5QHJ6QXJ5Q8:1P7mnOGakNGMeM7=cLgEfN7QiNWf0PhF7R8N7QhN6QXF4
PX1nOGakNg]kNgYjNWYjNWYjNGQgMWIgN7YkOGj0PH>5QXN8R8N6Q8:0OgmnOGak
NgalOGioP81oOginOgmoOgmoOh21PXB5QHF5Q8B4Q8>3PX60P820P862PX:2PX>3
Ph:2PH61PH62PX>4Q8F5QHF6QHF3PX1oOginO7YhMWEdLg=dMGMhNGYlOX64QXN7
QhN7QXJ5Q8:0OgelO7alO7]kNWYjNg]kNWUhMgMfMgQiNWamOh22Q8F6QhN7QXF3
PH1oOWimO7alOGinOgn0P7moOWinOWinOWmoPH:3Q8F5QHF5QHB4Ph:1P81oOgn0
PH:2PX:3Ph>3Ph:2PH61PH:2PhB4QHF5QHF4Ph>2PH1oOWekNGMfM7=cM7EfMgQi
Ngf0PXF6QhN7QhJ6QXB3PH1nOGalO7]kNg]jNWYjNgYjNGQgMgMhNGYkOGj0PH>5
QXJ7QhJ5Q8:0OgmnOGalO7emOWmoP81oOginOWinOWinOh21PX>4QHF5QHF4Q8>2
PH60OgmoP821PX:3Ph>3PX:2PX61PH61PX>4Q8F5QHF5QHB3PX5oOgimOG]jN7Mf
MGEeMGIhN7UjO7j0PhF6QXJ6QXJ6QXB3PGmnO7akNg]kNWYjNg]kNg]jNGQgMgMh
NGYkOGj0PXB6QhR8QhJ4Ph60OgimO7]lO7enOh20P820OgmoOginOGinOh21PhB4
QHF5QHF5Q8>2PH1oOgn0P861PX:3Ph>3Ph:2PH61PH62PX>3Q8B5QHF5Q8>2P7mn
OWimO7YhMgMfMWIfMgQiNW]lOX22Q8F5QXJ6QXJ5Q8>1P7imO7]kNg]kNg]kNg]k
Ng]jNGQgN7QiNW]lOGn1PhB6QXJ6QHB3PX60OgimOGemOWmoP820OgmoOWinOGem
OGioP862PhB5QHF6QHF4Ph:1P81oOgn0P861PX:3Ph>3Ph:2PH61PX:2PX>3Q8B4
Q8B4Ph:0OgmnOWemO7]jNGQhMgMgMgQiNGYkO7j0PXB5QHF6QXJ5Q8>1P7imO7]k
NW]kNg]lO7alO7]jNGQhMgQhNGYkOGj0PXB6QhN7QXF4Ph:1P7imOGemOWioP820
OgmnOWinOWemOGenP862PhB5QHF5QHF4Ph:1P820P821PH61PX:3Ph>3PX:1PH61
PH:2PX:3PhB4QHB4Ph60P7moOginOGakNg]jNGQhN7QiNGUjNganP8:3Q8F5QHF5
Q8>2PGmnOGakNg]lO7alOGemO7akNGUhMgMgN7UjNgenP8:4QXJ7QXJ5QHB3PH1o
OWimOWioOgmoOgmnOWinOGemOGenP862PhB4QHF5QHF4Ph:1PH20P821PH61PX>3
Ph>3PX:1PH61PH61PH62Ph>4Q8B3Ph:1P81oOginOWemO7akNgYiN7QhNGUiNGYk
OGn1PX>4Q8F5Q8B3PX60OWelO7alO7emOGemO7akNgYiN7QgMgQiNW]lOX22Q8F6
QXJ6QHF4PX60OginOWinOgmoOgmnOWinOGemOGenOh21PX>4Q8B5QHB4Ph>2PH61
PH20PH61PX:2PX:2PX:1PH60P820PH61PX:3Ph>3Ph:2PH20OgmoOgmoP81oOWem
O7ajNGQgMgMgN7UkOGn1PX>4QHF5QHB3PH1oOWimOGamOGemOGemO7akNWUhN7Mg
MgQiNgeoPH:4QHJ7QhN7QXB3PX20OgmnOWinOWmoOgmnOWinOGemOWioP861PX>4
Q8F5Q8B4Ph>2PX60P820PH61PH:2PX:2PH61PH20P820P861PX:2PX:2PX:1PH20
OgmoOgn0P81oOWimO7]jN7MgMgMhN7UkOGn0PH:3Q8F5Q8>2PH20OgimOGemOGem
OGemO7akNWUhN7QiNGYkO7j0PH>4QHJ6QXJ5Q8>2PH1oOWinOWinOgmoOgmoOgmn
OWinOWmoP862PX>3Q8B4QHF4Ph:2PH20P81oOh20P861PH61PH61PH60P820P861
PH:2PX:2PX61PH60P81oOgmoOgmoOWemO7akNWUhN7QiNW]kO7ioP862Ph>3Ph>2
PH20OgmnOGemOGemOGelO7]kNWYjNWYjNW]lOWn1PX>3Q8F5QHF4Ph:1P81oOgmo
OWinOgmoOh20OgmoOgmoOh20PH61PX>4Q8B4Q8>3Ph:2PH1oOgmoOh20P861PH61
PH61PH60P820P861PH61PH62PX:1PH60P7moOgmnOWinOWimOGalO7akNg]kNg]k
O7emOWmoP820PH60P820P7moOgmoOWinOWimOGelO7alO7alO7emOWn0P861PX:2
PX:2PX61PH20P81oOh20P820P820P820P820P821PH62PX:3PX:2PX:1PH61P820
P820P820P820P820P820P820PH61PH61PH61PH61P820OgmnOWinOWinOWinOWin
OWinOGemO7alO7alOGemOWinOWmoOgmoOgmoOgmoOgmoOgmoOgmnOWemOGemOGem
OWinOgn0P820P820P820P820P820P820P820P820P820PH20PH61PH61PH:2PX61
PH61PH20P820P820P820P820P820P820P820P861PH62PH61PH61P81oOgmnOWin
OWinOWinOgmoOginOWinOWinOWinOWinOWinOWinOWinOWinOWinOWioOgn0P81o
OgmoOgmoOginOWinOWmoOgmoOgmoP820P820P820P820P820P820P820P820P821
PH62PX:2PX:2PX:1PH20P7moOgmoOgn0P820P820P820P820P821PH61PH61PH61
PH61P81oOgmoOWinOWinOWinOgmoOgmoOWioOginOWioOgmoOgmoOginOWinOWin
OWinOWmoOgmoP820P7moOgmoOWinOWinOWioOgmoOgn0P820P820P820P81oOh20
P81oOgn0P820P820P861PH:2PX:1PH61P820P7moOgmoOgmoOgn0P81oOgn0P820
P820P861PH61PH61P820P7moOgmoOgmnOgmoOgmoOgmoOgmoOgmnOWinOWioOgmo
OgmoOgmoOgmoOWioOgmoOgmoP820P820P81oOgmoOginOWioOgmoOgmoOgn0P820
P81oOgmoP820P820P820P820P820P820P820P821P820P820P7moOgmoOgmoOgmo
P820P820P820P820P820P820P820P820P820P7moOgmoOgmoOgmoP820P820P81o
OgmoOginOgmoOgmoOgmoOh20P820OgmoOgmoP820P820P820P81oOgmoOgmoOgmo
Ogn0P820P820P7moOgmoOgmoP820P820P820P820P820P820P820P820P820P81o
OgmoOgmoOgmoOgn0P820P820P820P7moOgmoOgn0P820P820OgmoOgmoOgmoOgmo
Ogn0P820P820OgmoOgmoOgmoOgmoOgmoOh20P820P820P820P820Oh20P820P820
OgmoOgmoOgmoOgn0P820P820P7moOgmoOgmoOh20P820P820P820P820Ogn0P820
OgmoP820P7moOgmoOgmoOgmoOgmoP820P820P820P820P7moOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgn0P820P820P820P7moOgmoOgmoOgmoOgmoP820P820P820P81o
OgmoP820P820P820P820OgmoOgmoOgmoP820P820P7moOgmoOgmoP820P820P820
P820P7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P820P820P820P81oOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOh1oP820P820P7n0P820Ogn0OgmnOh1oOgn0Ogmo
P820PH1oOh20Oh1oP7n0P7n0P820OgmoP7n0P7moOgmoOh1oOgmoP81oOh20Ogn0
P7n0Oh20Oh20P820P820P7n0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P820
P820P81oP81oOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P820P820P820P7moOgmo
OgmoOgmoOgmoOgn0P820P820P81oP820P820P7n0P820OgmoOgmoOgmoOgmoOgmo
OgmoOgmoP7moOgmoOgmoP81oP7n0Ogn0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOh20P820P81oOh1oOgmoOgmoOgmoOgmoOgmoOgmoOh20P820P7n0P820
P820P820P820P81oP7n0P820P820P820P820P820P820P820P820P820P81oOgmo
OgmoOgmoOgmoOgmoOgmoOgn0P820P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgn0OgmoP820P820OgmoOh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP81o
OgmoOgn0Oh20P820P820P820P820P820P820P7n0P820P820P820P820P820P820
P820P820P81oOgmoOgmoOgmoOgmoOh1oP820P820Oh1oP820P7n0Ogn0P820P81o
OgmoOgmoOgmoOgmoOgmoOgn0P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P820P820Oh20P820P7n0P820P81oP7mo
Ogn0Oh20P820P820P820P820P7moOgmoOgmoOgmoOgmoP820P820P820P820P820
P820P81oOgmoOgmoOgmoOgmoOgmoOgmoOh1oP820P820P820P820P81oOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P7n0P7n0Oh20P81oP7mo
OgmoOgmoOgmoOgmoOgmoOh20P820P820P820P820P820P7moP820P7moP7n0P820
P820P820P820P820P820P820P7moOgmoOgmoOgmoOgmoOgmoOh1oP7moOgn0Ogmo
OgmoP820P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P81oOgn0P820P820
P820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P820P81oP820OgmoOgmo
OgmoOgmoOgmoP7moP7moOgmoOh20P820P820P820P820P81oP81oOgmoOh20P820
P820P820P820P820P820P820P820Oh1oOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmo
Ogn0P7moOgmoOh20P820OgmoP820P81oOgmoOgmoOgmoP7moOgmoOh20P820P820
P820Ogn0OgmoP81oOh20Oh20OgmoOgmoOh20P7moOgmoP7n0P81oOgmoOgn0P820
P81oOgmoOgmoOgmoOh1oP820P820P820P820P820P820P820P81oOgmoOgmoOgmo
Ogn0P7n0P820P820P820OgmoOgmoOgmoOgmoOgmoOgmoP7moOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOh20P81oOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
Ogn0P820P820P7n0OgmoOgmoOgmoOgmoOgmoOgmoOh1oOh20P7moOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOh20OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgn0OgmoOgmoOgmoOgmoOh1oOh1oOgmoOgmoOgmoOgmoOgmoP81oOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoP820OgmoOh20
P81oOgmoOgn0P820OgmoOgmoOgmoOgmoOh20P820P820P820OgmoOgn0P81oOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P820P7moOgmo
OgmoOgmoOgmoP820P820P820P7n0P820OgmoOgmoOh20P81oOgmoOgmoOh20Oh20
P820P820P820P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7n0P820P820P820P81o
Oh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgn0P820OgmoOh20P81oOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmo
Oh1oP7moP7moOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7n0P7moOgmoP820P81oOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P820P7moOgmoOgmoOgmo
OgmoOh1oP81oOh20P820P820P820P820P820P820P7moOgmoOgn0P7moOgmoP820
P820Ogn0P820P81oP7moP820P820P820P820P7moOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh20P81oOgn0P7mo
Oh1oP7moOgmoOh20Oh20P820P820P820P820P7moP7n0P820P81oOgmoOgmoOgmo
OgmoOgmoOgn0OgmoOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P7moOgmoOgmoOgmo
OgmoOh1oOgn0P820P820P820P820OgmoOgn0P820P7moOgmoOh20P820P7moOgmo
OgmoOh20P81oOgmoP7moOgmoOgmoOh1oP820OgmoOgmoOh1oP820OgmoOgmoOgn0
P820P7moOh20P820P820P820P820P820P820P820P820P820P820P81oOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgn0P820P7moOgmoOgmoOgmoOh1oP820P7moOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7moOgmoOgmoOh1oOgmoP820
P820P7moP7n0P7moOgmoOgmoP820OgmoOgmoOgmoOgmoOgmoOgmoOh20P820Ogmo
Oh1oOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOh1oOh20
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P7n0P7moP820OgmoOgn0P81o
OgmoOgmoOgmoOgn0P81oOgmoP820P820P820P820P820Ogn0P820P7moOgmoOgmo
OgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP820OgmoOgmoP7moOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P820P820Ogn0P820P820P81oOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0OgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOh20P7moOh20P820OgmoOh20P7moOgmoP820OgmoOgmoOgmo
Oh1oOgmoOgn0P820P81oOgmoOh20P7moOgmoOh20OgmoOgmoOgmoOgn0P7n0Ogmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P81oOgmoOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoP820P7moOh20OgmoOgmoOgmoOgmoP81oOgmo
Ogn0P820OgmoOgmoOgmoOgn0P7moOgn0P820P7moOgmoOgmoOgmoOgmoOgmoOgmo
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgn0P820P7n0P820P820OgmoOgmoOgmoOgmo
OgmoOgmoOgn0P820Oh1oOh1oP81oPGmoP7j0Ogn0Oh5nOgmoPGioP7n0Oh1oP7mo
P7moOgn0P7n0P81oOh1oPGmoP7ioP7moP81oP7moPGmoP7n0P7moP81oP7moOgn0
P81oP81oOgmoP820Oh20Oh1oP81oP81oOgmoOgmoP7n0P7n0Ogn0OgmoP820Oh1o
OgmoOgmoOgmoOgmoOh1oOgmoOgn0OgmoOgn0OgmoOgmoP81oOgmoOgmoP7moP820
Ogn0P81oOgn0OgmoP820Oh1oOgn0P7n0P820P7moOgn0Oh20P81oP820P7n0Oh20
P820P7n0P820P820P820P7n0Oh20Oh1oP820P81oOh1oOh20P820OgmoOgmoP820
P820P820Oh20Oh20P7moOgmoOh1oOgmoP7n0Oh1oOh1oP7n0P7moOh1oOh1oP7mo
Ogn0Oh20P7moOgmoOgmoP7n0P7moOh1oOh1oP7moP7n0Oh20Oh1oP820P820Ogn0
P820P820P81oP820P820Oh20Oh1oP7n0P7n0Oh1oOgmoP7moOgn0Oh20P7moP7mo
P7moOgmoOgmoP7moOgmoOgmoOgmoOgmoOgmoP81oP81oOgmoOh1oP81oP7moOgn0
OgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoOgmoP7moOgmoOgmo\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Let's take a look at what is contained in ",
  StyleBox["snd",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " by looking at the internal form of the data:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Shallow[InputForm[snd]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.70"],

Cell[BoxData[
    InterpretationBox[
      StyleBox[\(Sound[SampledSoundList[\(<< 2\)\(>>\)]]\),
        ShowStringCharacters->True,
        NumberMarks->True],
      InputForm[ 
        Sound[ 
          SampledSoundList[ 
            Skeleton[ 2]]]],
      Editable->True,
      AutoDelete->True]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This data contains a",
  StyleBox[" SampledSoundList",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is a set of sound data in the form {{",
  Cell[BoxData[
      \(TraditionalForm\`f\_o\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`f\_2\)]],
  ",...},",
  StyleBox["samplerate",
    FontSlant->"Italic"],
  "}. The data ",
  Cell[BoxData[
      FormBox[
        RowBox[{"{", 
          RowBox[{
            FormBox[\(f\_o\),
              "TraditionalForm"], ",", 
            FormBox[\(f\_1\),
              "TraditionalForm"], ",", 
            FormBox[\(f\_2\),
              "TraditionalForm"], ",", "..."}], "}"}], TraditionalForm]]],
  " provides a list of sound levels, which are played consecutively at a rate \
given by ",
  StyleBox["samplerate",
    FontSlant->"Italic"],
  ".  (We applied the command ",
  StyleBox["Shallow",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " so that we didn't have to print out the full data list, just the higher \
levels of the data structure. ) We can extract the sample rate using"
}], "Text",
  CellTags->"i:99"],

Cell[CellGroupData[{

Cell[BoxData[
    \(samplerate = \(\(\(InputForm[
              snd]\)[\([1]\)]\)[\([1]\)]\)[\([2]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.71"],

Cell[BoxData[
    \(22050.`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "which means the sample rate is 22,050 hertz, a common value used in \
digitized recordings.  The time between samples, \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  ", is just the reciprocal of the sample rate:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]t = 1/samplerate\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.72"],

Cell[BoxData[
    \(0.000045351473922902495`\)], "Output"]
}, Open  ]],

Cell["The data itself can be extracted using", "Text"],

Cell[BoxData[
    \(\(f\  = \ \(\(\(InputForm[
                snd]\)[\([1]\)]\)[\([1]\)]\)[\([1]\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.73"],

Cell["The length of this data list is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(nn = \ Length[f]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.74"],

Cell[BoxData[
    \(36864\)], "Output"]
}, Open  ]],

Cell["\<\
Let's look at some of this data over a region where something is \
happening:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[f[\([n]\)], {n, 25000, 25000 + 40}]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.75"],

Cell[BoxData[
    \({0.03125`, 0.015625`, 0.0078125`, 0, 0, 
      0, \(-0.0078125`\), \(-0.0078125`\), \(-0.0078125`\), 0, 0, 0, 
      0.0078125`, 0.015625`, 0.0234375`, 0.03125`, 0.03125`, 0.0390625`, 
      0.03125`, 0.0234375`, 0.0234375`, 0.015625`, 0.015625`, 0.0234375`, 
      0.0234375`, 0.0234375`, 0.0234375`, 0.0234375`, 0.0234375`, 0.0234375`, 
      0.0234375`, 0.03125`, 0.0390625`, 0.046875`, 0.046875`, 0.046875`, 
      0.0390625`, 0.03125`, 0.015625`, 0.0078125`, 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The numbers  giving the sound levels are discretized in units of \
0.0078125.  This is because the sound has been digitized, so that amplitude \
levels are given by discrete levels rather than by continuous real numbers. \
Note that 1/0.0078125 = 128 = ",
  Cell[BoxData[
      \(TraditionalForm\`2\^7\)]],
  ". This corresponds to 8-bit digitization: the other bit is the sign of the \
data, \[PlusMinus]. (In base two, integers running from 0 to 127 require 7 \
base two digits, or bits, for their representation.)  Because there are only \
128 different possible sound levels in this data file, the sound is not very \
high quality, as you can tell from the playback above. There is quite a bit \
of high-frequency hiss, due at least in part to the rather large steps \
between amplitude levels that create high frequencies in the sound. \n\tWe \
can see this in the Fourier transform of the data:"
}], "Text"],

Cell[BoxData[
    \(\(f\&~ = Fourier[f]/Sqrt[nn];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.76"],

Cell[TextData[{
  "A plot of this Fourier transform (Cell ",
  ButtonBox["2.77",
    ButtonData:>"Cell 2.77",
    ButtonStyle->"Hyperlink"],
  ") shows considerable structure at low frequencies, along with a low level \
high frequency background."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Abs[f\&~], PlotRange \[Rule] All];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.77"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0237837 2.58357e-05 0.0147013 99.8399 [
[.15296 .0022 -12 -9 ]
[.15296 .0022 12 0 ]
[.28214 .0022 -15 -9 ]
[.28214 .0022 15 0 ]
[.41132 .0022 -15 -9 ]
[.41132 .0022 15 0 ]
[.5405 .0022 -15 -9 ]
[.5405 .0022 15 0 ]
[.66968 .0022 -15 -9 ]
[.66968 .0022 15 0 ]
[.79885 .0022 -15 -9 ]
[.79885 .0022 15 0 ]
[.92803 .0022 -15 -9 ]
[.92803 .0022 15 0 ]
[.01128 .11454 -30 -4.5 ]
[.01128 .11454 0 4.5 ]
[.01128 .21438 -30 -4.5 ]
[.01128 .21438 0 4.5 ]
[.01128 .31422 -30 -4.5 ]
[.01128 .31422 0 4.5 ]
[.01128 .41406 -30 -4.5 ]
[.01128 .41406 0 4.5 ]
[.01128 .5139 -30 -4.5 ]
[.01128 .5139 0 4.5 ]
[.01128 .61374 -30 -4.5 ]
[.01128 .61374 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15296 .0147 m
.15296 .02095 L
s
[(5000)] .15296 .0022 0 1 Mshowa
.28214 .0147 m
.28214 .02095 L
s
[(10000)] .28214 .0022 0 1 Mshowa
.41132 .0147 m
.41132 .02095 L
s
[(15000)] .41132 .0022 0 1 Mshowa
.5405 .0147 m
.5405 .02095 L
s
[(20000)] .5405 .0022 0 1 Mshowa
.66968 .0147 m
.66968 .02095 L
s
[(25000)] .66968 .0022 0 1 Mshowa
.79885 .0147 m
.79885 .02095 L
s
[(30000)] .79885 .0022 0 1 Mshowa
.92803 .0147 m
.92803 .02095 L
s
[(35000)] .92803 .0022 0 1 Mshowa
.125 Mabswid
.04962 .0147 m
.04962 .01845 L
s
.07546 .0147 m
.07546 .01845 L
s
.10129 .0147 m
.10129 .01845 L
s
.12713 .0147 m
.12713 .01845 L
s
.1788 .0147 m
.1788 .01845 L
s
.20463 .0147 m
.20463 .01845 L
s
.23047 .0147 m
.23047 .01845 L
s
.2563 .0147 m
.2563 .01845 L
s
.30798 .0147 m
.30798 .01845 L
s
.33381 .0147 m
.33381 .01845 L
s
.35965 .0147 m
.35965 .01845 L
s
.38548 .0147 m
.38548 .01845 L
s
.43715 .0147 m
.43715 .01845 L
s
.46299 .0147 m
.46299 .01845 L
s
.48883 .0147 m
.48883 .01845 L
s
.51466 .0147 m
.51466 .01845 L
s
.56633 .0147 m
.56633 .01845 L
s
.59217 .0147 m
.59217 .01845 L
s
.618 .0147 m
.618 .01845 L
s
.64384 .0147 m
.64384 .01845 L
s
.69551 .0147 m
.69551 .01845 L
s
.72135 .0147 m
.72135 .01845 L
s
.74718 .0147 m
.74718 .01845 L
s
.77302 .0147 m
.77302 .01845 L
s
.82469 .0147 m
.82469 .01845 L
s
.85053 .0147 m
.85053 .01845 L
s
.87636 .0147 m
.87636 .01845 L
s
.9022 .0147 m
.9022 .01845 L
s
.95387 .0147 m
.95387 .01845 L
s
.9797 .0147 m
.9797 .01845 L
s
.25 Mabswid
0 .0147 m
1 .0147 L
s
.02378 .11454 m
.03003 .11454 L
s
[(0.001)] .01128 .11454 1 0 Mshowa
.02378 .21438 m
.03003 .21438 L
s
[(0.002)] .01128 .21438 1 0 Mshowa
.02378 .31422 m
.03003 .31422 L
s
[(0.003)] .01128 .31422 1 0 Mshowa
.02378 .41406 m
.03003 .41406 L
s
[(0.004)] .01128 .41406 1 0 Mshowa
.02378 .5139 m
.03003 .5139 L
s
[(0.005)] .01128 .5139 1 0 Mshowa
.02378 .61374 m
.03003 .61374 L
s
[(0.006)] .01128 .61374 1 0 Mshowa
.125 Mabswid
.02378 .03467 m
.02753 .03467 L
s
.02378 .05464 m
.02753 .05464 L
s
.02378 .07461 m
.02753 .07461 L
s
.02378 .09457 m
.02753 .09457 L
s
.02378 .13451 m
.02753 .13451 L
s
.02378 .15448 m
.02753 .15448 L
s
.02378 .17445 m
.02753 .17445 L
s
.02378 .19441 m
.02753 .19441 L
s
.02378 .23435 m
.02753 .23435 L
s
.02378 .25432 m
.02753 .25432 L
s
.02378 .27429 m
.02753 .27429 L
s
.02378 .29425 m
.02753 .29425 L
s
.02378 .33419 m
.02753 .33419 L
s
.02378 .35416 m
.02753 .35416 L
s
.02378 .37412 m
.02753 .37412 L
s
.02378 .39409 m
.02753 .39409 L
s
.02378 .43403 m
.02753 .43403 L
s
.02378 .454 m
.02753 .454 L
s
.02378 .47396 m
.02753 .47396 L
s
.02378 .49393 m
.02753 .49393 L
s
.02378 .53387 m
.02753 .53387 L
s
.02378 .55384 m
.02753 .55384 L
s
.02378 .5738 m
.02753 .5738 L
s
.02378 .59377 m
.02753 .59377 L
s
.25 Mabswid
.02378 0 m
.02378 .61803 L
s
.008 w
.02381 .50364 Mdot
.02384 .05576 Mdot
.02386 .02819 Mdot
.02389 .0239 Mdot
.02391 .02275 Mdot
.02394 .01594 Mdot
.02396 .02235 Mdot
.02399 .01801 Mdot
.02402 .02044 Mdot
.02404 .0199 Mdot
.02407 .01542 Mdot
.02409 .02118 Mdot
.02412 .01913 Mdot
.02415 .01705 Mdot
.02417 .01693 Mdot
.0242 .01633 Mdot
.02422 .01861 Mdot
.02425 .01931 Mdot
.02427 .0183 Mdot
.0243 .01624 Mdot
.02433 .01527 Mdot
.02435 .01718 Mdot
.02438 .01813 Mdot
.0244 .01795 Mdot
.02443 .0208 Mdot
.02446 .01938 Mdot
.02448 .01758 Mdot
.02451 .02088 Mdot
.02453 .02134 Mdot
.02456 .02762 Mdot
.02458 .02446 Mdot
.02461 .01844 Mdot
.02464 .01963 Mdot
.02466 .0202 Mdot
.02469 .01588 Mdot
.02471 .01543 Mdot
.02474 .01621 Mdot
.02477 .01694 Mdot
.02479 .01846 Mdot
.02482 .0204 Mdot
.02484 .01813 Mdot
.02487 .01705 Mdot
.02489 .01733 Mdot
.02492 .01992 Mdot
.02495 .01882 Mdot
.02497 .01688 Mdot
.025 .01643 Mdot
.02502 .01874 Mdot
.02505 .01693 Mdot
.02508 .01758 Mdot
.0251 .01843 Mdot
.02513 .01796 Mdot
.02515 .02097 Mdot
.02518 .02028 Mdot
.0252 .01681 Mdot
.02523 .01585 Mdot
.02526 .0178 Mdot
.02528 .01626 Mdot
.02531 .01738 Mdot
.02533 .01888 Mdot
.02536 .01741 Mdot
.02539 .01645 Mdot
.02541 .01572 Mdot
.02544 .01667 Mdot
.02546 .01879 Mdot
.02549 .01528 Mdot
.02551 .02127 Mdot
.02554 .01688 Mdot
.02557 .01678 Mdot
.02559 .01796 Mdot
.02562 .01936 Mdot
.02564 .02038 Mdot
.02567 .01709 Mdot
.0257 .01642 Mdot
.02572 .01883 Mdot
.02575 .02092 Mdot
.02577 .02169 Mdot
.0258 .02111 Mdot
.02582 .01637 Mdot
.02585 .01762 Mdot
.02588 .02046 Mdot
.0259 .02027 Mdot
.02593 .01965 Mdot
.02595 .0178 Mdot
.02598 .01867 Mdot
.02601 .02033 Mdot
.02603 .01876 Mdot
.02606 .01987 Mdot
.02608 .02367 Mdot
.02611 .02124 Mdot
.02613 .0185 Mdot
.02616 .02206 Mdot
.02619 .02445 Mdot
.02621 .0198 Mdot
.02624 .03166 Mdot
.02626 .02626 Mdot
.02629 .02812 Mdot
.02632 .02087 Mdot
.02634 .02041 Mdot
.02637 .01648 Mdot
.02639 .02212 Mdot
.02642 .02067 Mdot
.02644 .01601 Mdot
.02647 .01737 Mdot
.0265 .01591 Mdot
.02652 .01763 Mdot
.02655 .01875 Mdot
.02657 .01756 Mdot
.0266 .01648 Mdot
.02663 .01557 Mdot
.02665 .01608 Mdot
.02668 .01564 Mdot
.0267 .01873 Mdot
.02673 .01779 Mdot
.02675 .01653 Mdot
.02678 .01763 Mdot
.02681 .01644 Mdot
.02683 .01631 Mdot
.02686 .01829 Mdot
.02688 .01792 Mdot
.02691 .0158 Mdot
.02694 .01951 Mdot
.02696 .01821 Mdot
.02699 .0164 Mdot
.02701 .01615 Mdot
.02704 .01659 Mdot
.02706 .01689 Mdot
.02709 .01652 Mdot
.02712 .01766 Mdot
.02714 .0165 Mdot
.02717 .01634 Mdot
.02719 .01649 Mdot
.02722 .01692 Mdot
.02725 .01847 Mdot
.02727 .01554 Mdot
.0273 .01647 Mdot
.02732 .01667 Mdot
.02735 .01527 Mdot
.02737 .01666 Mdot
.0274 .01855 Mdot
.02743 .01912 Mdot
.02745 .01901 Mdot
.02748 .01622 Mdot
.0275 .01742 Mdot
.02753 .01677 Mdot
.02756 .01878 Mdot
.02758 .01825 Mdot
.02761 .01504 Mdot
.02763 .01794 Mdot
.02766 .01846 Mdot
.02768 .01664 Mdot
.02771 .01683 Mdot
.02774 .01641 Mdot
.02776 .01543 Mdot
.02779 .01566 Mdot
.02781 .01569 Mdot
.02784 .01636 Mdot
.02787 .0175 Mdot
.02789 .01706 Mdot
.02792 .01808 Mdot
.02794 .01775 Mdot
.02797 .0179 Mdot
.02799 .01731 Mdot
.02802 .01778 Mdot
.02805 .01721 Mdot
.02807 .01822 Mdot
.0281 .01805 Mdot
.02812 .01722 Mdot
.02815 .0169 Mdot
.02818 .01758 Mdot
.0282 .01751 Mdot
.02823 .01862 Mdot
.02825 .02246 Mdot
.02828 .01961 Mdot
.0283 .01747 Mdot
.02833 .01666 Mdot
.02836 .01736 Mdot
.02838 .01795 Mdot
.02841 .01945 Mdot
.02843 .01767 Mdot
.02846 .01761 Mdot
.02849 .01624 Mdot
.02851 .0158 Mdot
.02854 .01739 Mdot
.02856 .01784 Mdot
.02859 .01617 Mdot
.02861 .01816 Mdot
.02864 .01828 Mdot
.02867 .01616 Mdot
.02869 .01884 Mdot
.02872 .01812 Mdot
.02874 .01733 Mdot
.02877 .01601 Mdot
.0288 .01733 Mdot
.02882 .01659 Mdot
.02885 .01886 Mdot
.02887 .01592 Mdot
.0289 .01907 Mdot
.02892 .022 Mdot
.02895 .01995 Mdot
.02898 .01728 Mdot
.029 .03301 Mdot
.02903 .02141 Mdot
.02905 .01564 Mdot
.02908 .01959 Mdot
.02911 .01846 Mdot
.02913 .01807 Mdot
.02916 .02059 Mdot
.02918 .01712 Mdot
.02921 .0169 Mdot
.02924 .01654 Mdot
.02926 .01565 Mdot
.02929 .01599 Mdot
.02931 .01855 Mdot
.02934 .01995 Mdot
.02936 .0191 Mdot
.02939 .01655 Mdot
.02942 .01705 Mdot
.02944 .0194 Mdot
.02947 .0182 Mdot
.02949 .01943 Mdot
.02952 .0157 Mdot
.02955 .02444 Mdot
.02957 .02819 Mdot
.0296 .02688 Mdot
.02962 .02627 Mdot
.02965 .02053 Mdot
.02967 .03343 Mdot
.0297 .02717 Mdot
.02973 .03839 Mdot
.02975 .03801 Mdot
.02978 .01942 Mdot
.0298 .03866 Mdot
.02983 .02543 Mdot
.02986 .06387 Mdot
.02988 .05156 Mdot
.02991 .08207 Mdot
.02993 .12729 Mdot
.02996 .08385 Mdot
.02998 .09771 Mdot
.03001 .05043 Mdot
.03004 .18502 Mdot
.03006 .40482 Mdot
.03009 .42945 Mdot
.03011 .18456 Mdot
.03014 .1048 Mdot
.03017 .09655 Mdot
.03019 .11484 Mdot
.03022 .18766 Mdot
.03024 .11992 Mdot
.03027 .0906 Mdot
.03029 .10649 Mdot
.03032 .09067 Mdot
.03035 .0998 Mdot
.03037 .09003 Mdot
.0304 .07076 Mdot
.03042 .06731 Mdot
.03045 .05668 Mdot
.03048 .04829 Mdot
.0305 .03921 Mdot
.03053 .03598 Mdot
.03055 .03376 Mdot
.03058 .03024 Mdot
.0306 .0316 Mdot
.03063 .02535 Mdot
.03066 .03203 Mdot
.03068 .02365 Mdot
.03071 .01943 Mdot
.03073 .0336 Mdot
.03076 .03064 Mdot
.03079 .0282 Mdot
.03081 .02686 Mdot
.03084 .02533 Mdot
.03086 .02946 Mdot
.03089 .02722 Mdot
.03091 .02468 Mdot
.03094 .02851 Mdot
.03097 .02703 Mdot
.03099 .02059 Mdot
.03102 .02821 Mdot
.03104 .02797 Mdot
.03107 .02108 Mdot
.0311 .02138 Mdot
.03112 .02737 Mdot
.03115 .02701 Mdot
.03117 .02484 Mdot
.0312 .02829 Mdot
.03122 .02646 Mdot
.03125 .0226 Mdot
.03128 .02596 Mdot
.0313 .02278 Mdot
.03133 .02271 Mdot
.03135 .02418 Mdot
.03138 .02267 Mdot
.03141 .01966 Mdot
.03143 .02212 Mdot
.03146 .0217 Mdot
.03148 .02077 Mdot
.03151 .02171 Mdot
.03153 .02367 Mdot
.03156 .02425 Mdot
.03159 .0265 Mdot
.03161 .02133 Mdot
.03164 .01779 Mdot
.03166 .01894 Mdot
.03169 .02291 Mdot
.03172 .02449 Mdot
.03174 .0197 Mdot
.03177 .01685 Mdot
.03179 .02237 Mdot
.03182 .02175 Mdot
.03184 .02144 Mdot
.03187 .02119 Mdot
.0319 .02158 Mdot
.03192 .01892 Mdot
.03195 .01931 Mdot
.03197 .01966 Mdot
.032 .01672 Mdot
.03203 .01676 Mdot
.03205 .01678 Mdot
.03208 .02011 Mdot
.0321 .02077 Mdot
.03213 .01721 Mdot
.03215 .01663 Mdot
.03218 .01762 Mdot
.03221 .01708 Mdot
.03223 .01597 Mdot
.03226 .01795 Mdot
.03228 .01612 Mdot
.03231 .01704 Mdot
.03234 .01795 Mdot
.03236 .01877 Mdot
.03239 .0173 Mdot
.03241 .01598 Mdot
.03244 .0163 Mdot
.03246 .01602 Mdot
.03249 .01543 Mdot
.03252 .01699 Mdot
.03254 .01575 Mdot
.03257 .01849 Mdot
.03259 .01781 Mdot
.03262 .0181 Mdot
.03265 .01789 Mdot
.03267 .02102 Mdot
.0327 .01768 Mdot
.03272 .01515 Mdot
.03275 .01835 Mdot
.03277 .01878 Mdot
.0328 .01662 Mdot
.03283 .01769 Mdot
.03285 .01814 Mdot
.03288 .01701 Mdot
.0329 .01625 Mdot
.03293 .02049 Mdot
.03296 .01933 Mdot
.03298 .01743 Mdot
.03301 .01584 Mdot
.03303 .0174 Mdot
.03306 .01759 Mdot
.03308 .0177 Mdot
.03311 .01837 Mdot
.03314 .01818 Mdot
.03316 .01676 Mdot
.03319 .01958 Mdot
.03321 .01861 Mdot
.03324 .01714 Mdot
.03327 .01972 Mdot
.03329 .01706 Mdot
.03332 .01962 Mdot
.03334 .01693 Mdot
.03337 .01957 Mdot
.03339 .0197 Mdot
.03342 .01703 Mdot
.03345 .01719 Mdot
.03347 .0192 Mdot
.0335 .01698 Mdot
.03352 .01741 Mdot
.03355 .01731 Mdot
.03358 .01854 Mdot
.0336 .01791 Mdot
.03363 .01864 Mdot
.03365 .01812 Mdot
.03368 .01578 Mdot
.0337 .01747 Mdot
.03373 .01564 Mdot
.03376 .01692 Mdot
.03378 .01697 Mdot
.03381 .01807 Mdot
.03383 .01776 Mdot
.03386 .01552 Mdot
.03389 .01685 Mdot
.03391 .01781 Mdot
.03394 .01743 Mdot
.03396 .01503 Mdot
.03399 .01677 Mdot
.03401 .01528 Mdot
.03404 .01649 Mdot
.03407 .01765 Mdot
.03409 .01553 Mdot
.03412 .01661 Mdot
.03414 .02283 Mdot
.03417 .02657 Mdot
.0342 .01846 Mdot
.03422 .01812 Mdot
.03425 .01681 Mdot
.03427 .0161 Mdot
.0343 .01992 Mdot
.03432 .01914 Mdot
.03435 .01583 Mdot
.03438 .01728 Mdot
.0344 .01581 Mdot
.03443 .0188 Mdot
.03445 .01679 Mdot
.03448 .0154 Mdot
.03451 .01618 Mdot
.03453 .01654 Mdot
.03456 .01733 Mdot
.03458 .01678 Mdot
.03461 .01784 Mdot
.03463 .01601 Mdot
.03466 .01663 Mdot
.03469 .01678 Mdot
.03471 .0191 Mdot
.03474 .01913 Mdot
.03476 .01549 Mdot
.03479 .01712 Mdot
.03482 .01663 Mdot
.03484 .01959 Mdot
.03487 .01662 Mdot
.03489 .01866 Mdot
.03492 .01881 Mdot
.03494 .01513 Mdot
.03497 .01604 Mdot
.035 .01629 Mdot
.03502 .01577 Mdot
.03505 .01711 Mdot
.03507 .01588 Mdot
.0351 .01573 Mdot
.03513 .01609 Mdot
.03515 .01786 Mdot
.03518 .01626 Mdot
.0352 .0167 Mdot
.03523 .01639 Mdot
.03525 .01626 Mdot
.03528 .01666 Mdot
.03531 .01893 Mdot
.03533 .01731 Mdot
.03536 .01713 Mdot
.03538 .01553 Mdot
.03541 .02135 Mdot
.03544 .01938 Mdot
.03546 .01634 Mdot
.03549 .01909 Mdot
.03551 .01701 Mdot
.03554 .01582 Mdot
.03556 .01709 Mdot
.03559 .01796 Mdot
.03562 .01826 Mdot
.03564 .01645 Mdot
.03567 .01976 Mdot
.03569 .01602 Mdot
.03572 .02102 Mdot
.03575 .0175 Mdot
.03577 .0196 Mdot
.0358 .02162 Mdot
.03582 .02269 Mdot
.03585 .02276 Mdot
.03587 .02179 Mdot
.0359 .0185 Mdot
.03593 .0213 Mdot
.03595 .02087 Mdot
.03598 .03149 Mdot
.036 .03059 Mdot
.03603 .02298 Mdot
.03606 .02421 Mdot
.03608 .02885 Mdot
.03611 .04598 Mdot
.03613 .03533 Mdot
.03616 .04072 Mdot
.03618 .07765 Mdot
.03621 .08203 Mdot
.03624 .06537 Mdot
.03626 .04503 Mdot
.03629 .04558 Mdot
.03631 .11323 Mdot
.03634 .12878 Mdot
.03637 .08464 Mdot
.03639 .02971 Mdot
.03642 .04298 Mdot
.03644 .06444 Mdot
.03647 .07817 Mdot
.03649 .06579 Mdot
.03652 .02745 Mdot
.03655 .03318 Mdot
.03657 .02806 Mdot
.0366 .04122 Mdot
.03662 .04609 Mdot
.03665 .04813 Mdot
.03668 .0395 Mdot
.0367 .04127 Mdot
.03673 .04766 Mdot
.03675 .04501 Mdot
.03678 .04807 Mdot
.0368 .05053 Mdot
.03683 .04709 Mdot
.03686 .04181 Mdot
.03688 .04019 Mdot
.03691 .03767 Mdot
.03693 .03484 Mdot
.03696 .03213 Mdot
.03699 .02783 Mdot
.03701 .02575 Mdot
.03704 .02574 Mdot
.03706 .02383 Mdot
.03709 .02221 Mdot
.03711 .01759 Mdot
.03714 .01804 Mdot
.03717 .01632 Mdot
.03719 .01895 Mdot
.03722 .02043 Mdot
.03724 .01742 Mdot
.03727 .01947 Mdot
.0373 .01595 Mdot
.03732 .02251 Mdot
.03735 .02166 Mdot
.03737 .01906 Mdot
.0374 .02043 Mdot
.03742 .01771 Mdot
.03745 .01905 Mdot
.03748 .01762 Mdot
.0375 .01758 Mdot
.03753 .01565 Mdot
.03755 .02119 Mdot
.03758 .01897 Mdot
.03761 .01841 Mdot
.03763 .01831 Mdot
.03766 .01839 Mdot
.03768 .01892 Mdot
.03771 .01987 Mdot
.03773 .0168 Mdot
.03776 .01612 Mdot
.03779 .01743 Mdot
.03781 .01742 Mdot
.03784 .01725 Mdot
.03786 .01622 Mdot
.03789 .01889 Mdot
.03792 .01699 Mdot
.03794 .01614 Mdot
.03797 .0155 Mdot
.03799 .01668 Mdot
.03802 .01666 Mdot
.03804 .01973 Mdot
.03807 .0152 Mdot
.0381 .0163 Mdot
.03812 .01645 Mdot
.03815 .01909 Mdot
.03817 .01697 Mdot
.0382 .01531 Mdot
.03823 .01587 Mdot
.03825 .01763 Mdot
.03828 .01685 Mdot
.0383 .0162 Mdot
.03833 .0165 Mdot
.03836 .01672 Mdot
.03838 .0153 Mdot
.03841 .01675 Mdot
.03843 .01731 Mdot
.03846 .01741 Mdot
.03848 .01545 Mdot
.03851 .01649 Mdot
.03854 .01734 Mdot
.03856 .01716 Mdot
.03859 .01549 Mdot
.03861 .01691 Mdot
.03864 .0171 Mdot
.03867 .01653 Mdot
.03869 .01704 Mdot
.03872 .01673 Mdot
.03874 .01713 Mdot
.03877 .01859 Mdot
.03879 .01829 Mdot
.03882 .01965 Mdot
.03885 .01613 Mdot
.03887 .01514 Mdot
.0389 .0157 Mdot
.03892 .01559 Mdot
.03895 .01826 Mdot
.03898 .01866 Mdot
.039 .01816 Mdot
.03903 .01612 Mdot
.03905 .01545 Mdot
.03908 .01555 Mdot
.0391 .01885 Mdot
.03913 .01805 Mdot
.03916 .01741 Mdot
.03918 .0168 Mdot
.03921 .01525 Mdot
.03923 .01876 Mdot
.03926 .01663 Mdot
.03929 .01638 Mdot
.03931 .0198 Mdot
.03934 .02117 Mdot
.03936 .02751 Mdot
.03939 .02082 Mdot
.03941 .01839 Mdot
.03944 .01546 Mdot
.03947 .01588 Mdot
.03949 .01538 Mdot
.03952 .01582 Mdot
.03954 .01676 Mdot
.03957 .01533 Mdot
.0396 .01664 Mdot
.03962 .01793 Mdot
.03965 .01777 Mdot
.03967 .01786 Mdot
.0397 .01519 Mdot
.03972 .01719 Mdot
.03975 .01595 Mdot
.03978 .01853 Mdot
.0398 .01862 Mdot
.03983 .01517 Mdot
.03985 .01802 Mdot
.03988 .01671 Mdot
.03991 .01743 Mdot
.03993 .01505 Mdot
.03996 .01761 Mdot
.03998 .01814 Mdot
.04001 .01779 Mdot
.04003 .01559 Mdot
.04006 .01647 Mdot
.04009 .01667 Mdot
.04011 .01558 Mdot
.04014 .01646 Mdot
.04016 .01776 Mdot
.04019 .01809 Mdot
.04022 .01569 Mdot
.04024 .0186 Mdot
.04027 .01794 Mdot
.04029 .01716 Mdot
.04032 .0166 Mdot
.04034 .01709 Mdot
.04037 .01695 Mdot
.0404 .01794 Mdot
.04042 .0153 Mdot
.04045 .01567 Mdot
.04047 .01629 Mdot
.0405 .01594 Mdot
.04053 .01642 Mdot
.04055 .01727 Mdot
.04058 .01864 Mdot
.0406 .01807 Mdot
.04063 .01541 Mdot
.04065 .01895 Mdot
.04068 .01642 Mdot
.04071 .01691 Mdot
.04073 .01653 Mdot
.04076 .01659 Mdot
.04078 .01661 Mdot
.04081 .01727 Mdot
.04084 .01728 Mdot
.04086 .01695 Mdot
.04089 .01782 Mdot
.04091 .01898 Mdot
.04094 .01832 Mdot
.04096 .01675 Mdot
.04099 .01976 Mdot
.04102 .0156 Mdot
.04104 .01803 Mdot
.04107 .01649 Mdot
.04109 .01773 Mdot
.04112 .01746 Mdot
.04115 .01864 Mdot
.04117 .01705 Mdot
.0412 .01859 Mdot
.04122 .01696 Mdot
.04125 .01599 Mdot
.04127 .01507 Mdot
.0413 .01837 Mdot
.04133 .01619 Mdot
.04135 .01629 Mdot
.04138 .01783 Mdot
.0414 .01835 Mdot
.04143 .01615 Mdot
.04146 .01829 Mdot
.04148 .01799 Mdot
.04151 .0175 Mdot
.04153 .01936 Mdot
.04156 .01788 Mdot
.04158 .01939 Mdot
.04161 .01994 Mdot
.04164 .0211 Mdot
.04166 .02236 Mdot
.04169 .02203 Mdot
.04171 .02264 Mdot
.04174 .02286 Mdot
.04177 .0181 Mdot
.04179 .02776 Mdot
.04182 .01763 Mdot
.04184 .03053 Mdot
.04187 .0295 Mdot
.04189 .02425 Mdot
.04192 .03363 Mdot
.04195 .01774 Mdot
.04197 .03244 Mdot
.042 .03727 Mdot
.04202 .02531 Mdot
.04205 .05814 Mdot
.04208 .03339 Mdot
.0421 .04814 Mdot
.04213 .0549 Mdot
.04215 .03628 Mdot
.04218 .04387 Mdot
.0422 .02573 Mdot
.04223 .08321 Mdot
.04226 .10494 Mdot
.04228 .03925 Mdot
.04231 .06622 Mdot
.04233 .09505 Mdot
.04236 .13037 Mdot
.04239 .11335 Mdot
.04241 .0484 Mdot
.04244 .17815 Mdot
.04246 .2208 Mdot
.04249 .17972 Mdot
.04251 .13629 Mdot
.04254 .05915 Mdot
.04257 .15095 Mdot
.04259 .25091 Mdot
.04262 .21509 Mdot
.04264 .08889 Mdot
.04267 .08553 Mdot
.0427 .22385 Mdot
.04272 .29397 Mdot
.04275 .23252 Mdot
.04277 .09665 Mdot
.0428 .02896 Mdot
.04282 .0593 Mdot
.04285 .09685 Mdot
.04288 .12269 Mdot
.0429 .09844 Mdot
.04293 .06055 Mdot
.04295 .06043 Mdot
.04298 .05889 Mdot
.04301 .07686 Mdot
.04303 .10149 Mdot
.04306 .10763 Mdot
.04308 .10426 Mdot
.04311 .0954 Mdot
.04313 .10254 Mdot
.04316 .11525 Mdot
.04319 .1213 Mdot
.04321 .12083 Mdot
.04324 .11548 Mdot
.04326 .10648 Mdot
.04329 .1149 Mdot
.04332 .10222 Mdot
.04334 .08967 Mdot
.04337 .09168 Mdot
.04339 .07375 Mdot
.04342 .07348 Mdot
.04344 .06677 Mdot
.04347 .05282 Mdot
.0435 .05524 Mdot
.04352 .04692 Mdot
.04355 .03355 Mdot
.04357 .02764 Mdot
.0436 .01979 Mdot
.04363 .02483 Mdot
.04365 .01832 Mdot
.04368 .02406 Mdot
.0437 .01923 Mdot
.04373 .02113 Mdot
.04375 .02352 Mdot
.04378 .02424 Mdot
.04381 .02658 Mdot
.04383 .02224 Mdot
.04386 .02382 Mdot
.04388 .02474 Mdot
.04391 .02325 Mdot
.04394 .02545 Mdot
.04396 .02622 Mdot
.04399 .02644 Mdot
.04401 .02106 Mdot
.04404 .02298 Mdot
.04406 .02272 Mdot
.04409 .02482 Mdot
.04412 .02317 Mdot
.04414 .02158 Mdot
.04417 .02205 Mdot
.04419 .02101 Mdot
.04422 .02204 Mdot
.04425 .02318 Mdot
.04427 .02201 Mdot
.0443 .02338 Mdot
.04432 .01691 Mdot
.04435 .02079 Mdot
.04437 .02242 Mdot
.0444 .02013 Mdot
.04443 .02353 Mdot
.04445 .02409 Mdot
.04448 .01855 Mdot
.0445 .02325 Mdot
.04453 .03033 Mdot
.04456 .02267 Mdot
.04458 .02822 Mdot
.04461 .02671 Mdot
.04463 .0219 Mdot
.04466 .0176 Mdot
.04468 .02096 Mdot
.04471 .01889 Mdot
.04474 .01841 Mdot
.04476 .02143 Mdot
.04479 .01838 Mdot
.04481 .02004 Mdot
.04484 .02002 Mdot
.04487 .02157 Mdot
.04489 .02371 Mdot
.04492 .02583 Mdot
.04494 .01977 Mdot
.04497 .01888 Mdot
.04499 .01973 Mdot
.04502 .01855 Mdot
.04505 .02226 Mdot
.04507 .02127 Mdot
.0451 .01871 Mdot
.04512 .0205 Mdot
.04515 .01832 Mdot
.04518 .01697 Mdot
.0452 .01743 Mdot
.04523 .01752 Mdot
.04525 .01975 Mdot
.04528 .02009 Mdot
.0453 .02577 Mdot
.04533 .02265 Mdot
.04536 .02454 Mdot
.04538 .01886 Mdot
.04541 .02192 Mdot
.04543 .02468 Mdot
.04546 .02215 Mdot
.04549 .02114 Mdot
.04551 .02067 Mdot
.04554 .01783 Mdot
.04556 .01975 Mdot
.04559 .02092 Mdot
.04561 .02186 Mdot
.04564 .0187 Mdot
.04567 .01941 Mdot
.04569 .0185 Mdot
.04572 .02203 Mdot
.04574 .02159 Mdot
.04577 .02274 Mdot
.0458 .02102 Mdot
.04582 .01622 Mdot
.04585 .01894 Mdot
.04587 .02263 Mdot
.0459 .02629 Mdot
.04592 .0205 Mdot
.04595 .0204 Mdot
.04598 .02513 Mdot
.046 .02293 Mdot
.04603 .02371 Mdot
.04605 .01883 Mdot
.04608 .01823 Mdot
.04611 .02192 Mdot
.04613 .02015 Mdot
.04616 .01691 Mdot
.04618 .02306 Mdot
.04621 .02352 Mdot
.04623 .0223 Mdot
.04626 .01928 Mdot
.04629 .02462 Mdot
.04631 .02208 Mdot
.04634 .02439 Mdot
.04636 .0233 Mdot
.04639 .02744 Mdot
.04642 .02114 Mdot
.04644 .01476 Mdot
.04647 .01896 Mdot
.04649 .02219 Mdot
.04652 .02128 Mdot
.04654 .01864 Mdot
.04657 .01821 Mdot
.0466 .01555 Mdot
.04662 .01729 Mdot
.04665 .01777 Mdot
.04667 .02323 Mdot
.0467 .02393 Mdot
.04673 .02274 Mdot
.04675 .01948 Mdot
.04678 .02137 Mdot
.0468 .02281 Mdot
.04683 .02328 Mdot
.04685 .01921 Mdot
.04688 .02464 Mdot
.04691 .01829 Mdot
.04693 .01991 Mdot
.04696 .0199 Mdot
.04698 .01728 Mdot
.04701 .023 Mdot
.04704 .01929 Mdot
.04706 .02308 Mdot
.04709 .01823 Mdot
.04711 .02412 Mdot
.04714 .01706 Mdot
.04716 .01541 Mdot
.04719 .01987 Mdot
.04722 .02363 Mdot
.04724 .02226 Mdot
.04727 .02445 Mdot
.04729 .01755 Mdot
.04732 .02068 Mdot
.04735 .02148 Mdot
.04737 .02535 Mdot
.0474 .0233 Mdot
.04742 .02411 Mdot
.04745 .01862 Mdot
.04748 .02507 Mdot
.0475 .02128 Mdot
.04753 .02734 Mdot
.04755 .02714 Mdot
.04758 .02002 Mdot
.0476 .02313 Mdot
.04763 .02952 Mdot
.04766 .02249 Mdot
.04768 .02745 Mdot
.04771 .01696 Mdot
.04773 .02411 Mdot
.04776 .02591 Mdot
.04779 .03315 Mdot
.04781 .02345 Mdot
.04784 .03364 Mdot
.04786 .02863 Mdot
.04789 .02833 Mdot
.04791 .03876 Mdot
.04794 .03107 Mdot
.04797 .04142 Mdot
.04799 .04678 Mdot
.04802 .0169 Mdot
.04804 .05227 Mdot
.04807 .03037 Mdot
.0481 .05172 Mdot
.04812 .04935 Mdot
.04815 .02522 Mdot
.04817 .0725 Mdot
.0482 .05443 Mdot
.04822 .04207 Mdot
.04825 .07487 Mdot
.04828 .03019 Mdot
.0483 .11966 Mdot
.04833 .09935 Mdot
.04835 .09377 Mdot
.04838 .1424 Mdot
.04841 .09525 Mdot
.04843 .06186 Mdot
.04846 .04553 Mdot
.04848 .19049 Mdot
.04851 .25035 Mdot
.04853 .13269 Mdot
.04856 .13281 Mdot
.04859 .23734 Mdot
.04861 .3123 Mdot
.04864 .33288 Mdot
.04866 .10742 Mdot
.04869 .31933 Mdot
.04872 .5222 Mdot
.04874 .44203 Mdot
.04877 .31076 Mdot
.04879 .2257 Mdot
.04882 .0731 Mdot
.04884 .20904 Mdot
.04887 .28353 Mdot
.0489 .17661 Mdot
.04892 .10501 Mdot
.04895 .39093 Mdot
.04897 .60332 Mdot
.049 .5559 Mdot
.04903 .26742 Mdot
.04905 .03078 Mdot
.04908 .15561 Mdot
.0491 .36608 Mdot
.04913 .44396 Mdot
.04915 .29748 Mdot
.04918 .08863 Mdot
.04921 .05511 Mdot
.04923 .05226 Mdot
.04926 .12131 Mdot
.04928 .17031 Mdot
.04931 .17626 Mdot
.04934 .14576 Mdot
.04936 .09236 Mdot
.04939 .09118 Mdot
.04941 .13212 Mdot
.04944 .16856 Mdot
.04946 .17976 Mdot
.04949 .17144 Mdot
.04952 .15538 Mdot
.04954 .18479 Mdot
.04957 .21375 Mdot
.04959 .20725 Mdot
.04962 .20424 Mdot
.04965 .19001 Mdot
.04967 .16569 Mdot
.0497 .16511 Mdot
.04972 .13792 Mdot
.04975 .12631 Mdot
.04977 .11874 Mdot
.0498 .0986 Mdot
.04983 .09235 Mdot
.04985 .07869 Mdot
.04988 .06766 Mdot
.0499 .07113 Mdot
.04993 .05625 Mdot
.04996 .04754 Mdot
.04998 .0455 Mdot
.05001 .03343 Mdot
.05003 .0362 Mdot
.05006 .02879 Mdot
.05008 .01988 Mdot
.05011 .02076 Mdot
.05014 .0241 Mdot
.05016 .02421 Mdot
.05019 .02958 Mdot
.05021 .03125 Mdot
.05024 .03518 Mdot
.05027 .04067 Mdot
.05029 .02685 Mdot
.05032 .03671 Mdot
.05034 .03776 Mdot
.05037 .03084 Mdot
.05039 .03411 Mdot
.05042 .02782 Mdot
.05045 .03148 Mdot
.05047 .03951 Mdot
.0505 .02633 Mdot
.05052 .03161 Mdot
.05055 .03664 Mdot
.05058 .041 Mdot
.0506 .03907 Mdot
.05063 .03805 Mdot
.05065 .0386 Mdot
.05068 .03889 Mdot
.0507 .04186 Mdot
.05073 .04035 Mdot
.05076 .04323 Mdot
.05078 .04245 Mdot
.05081 .03459 Mdot
.05083 .03595 Mdot
.05086 .04082 Mdot
.05089 .04391 Mdot
.05091 .03874 Mdot
.05094 .03784 Mdot
.05096 .03899 Mdot
.05099 .03173 Mdot
.05101 .0368 Mdot
.05104 .04039 Mdot
.05107 .02901 Mdot
.05109 .03138 Mdot
.05112 .03505 Mdot
.05114 .02877 Mdot
.05117 .02297 Mdot
.0512 .02801 Mdot
.05122 .02755 Mdot
.05125 .02685 Mdot
.05127 .03636 Mdot
.0513 .0282 Mdot
.05132 .02441 Mdot
.05135 .02841 Mdot
.05138 .03035 Mdot
.0514 .02556 Mdot
.05143 .0232 Mdot
.05145 .0275 Mdot
.05148 .02562 Mdot
.05151 .02977 Mdot
.05153 .03307 Mdot
.05156 .02691 Mdot
.05158 .02158 Mdot
.05161 .02698 Mdot
.05163 .02697 Mdot
.05166 .0238 Mdot
.05169 .02067 Mdot
.05171 .02267 Mdot
.05174 .03002 Mdot
.05176 .02514 Mdot
.05179 .02761 Mdot
.05182 .02867 Mdot
.05184 .02287 Mdot
.05187 .02063 Mdot
.05189 .02338 Mdot
.05192 .02323 Mdot
.05194 .02057 Mdot
.05197 .0201 Mdot
.052 .02126 Mdot
.05202 .01708 Mdot
.05205 .02151 Mdot
.05207 .01897 Mdot
.0521 .01998 Mdot
.05213 .01927 Mdot
.05215 .02543 Mdot
.05218 .02188 Mdot
.0522 .02273 Mdot
.05223 .02307 Mdot
.05225 .02363 Mdot
.05228 .02352 Mdot
.05231 .02192 Mdot
.05233 .02428 Mdot
.05236 .0196 Mdot
.05238 .01587 Mdot
.05241 .02386 Mdot
.05244 .02674 Mdot
.05246 .02297 Mdot
.05249 .02265 Mdot
.05251 .02679 Mdot
.05254 .02329 Mdot
.05256 .01952 Mdot
.05259 .02343 Mdot
.05262 .02358 Mdot
.05264 .01706 Mdot
.05267 .01958 Mdot
.05269 .0214 Mdot
.05272 .02172 Mdot
.05275 .01984 Mdot
.05277 .0192 Mdot
.0528 .02182 Mdot
.05282 .01608 Mdot
.05285 .02213 Mdot
.05287 .01945 Mdot
.0529 .02114 Mdot
.05293 .01577 Mdot
.05295 .01496 Mdot
.05298 .01893 Mdot
.053 .01478 Mdot
.05303 .01985 Mdot
.05306 .02405 Mdot
.05308 .0193 Mdot
.05311 .01659 Mdot
.05313 .01941 Mdot
.05316 .01698 Mdot
.05318 .01728 Mdot
.05321 .0176 Mdot
.05324 .01521 Mdot
.05326 .01862 Mdot
.05329 .01786 Mdot
.05331 .01978 Mdot
.05334 .01921 Mdot
.05337 .01857 Mdot
.05339 .01627 Mdot
.05342 .01836 Mdot
.05344 .02243 Mdot
.05347 .02617 Mdot
.05349 .01868 Mdot
.05352 .0242 Mdot
.05355 .01769 Mdot
.05357 .0188 Mdot
.0536 .01965 Mdot
.05362 .02095 Mdot
.05365 .02232 Mdot
.05368 .02769 Mdot
.0537 .0183 Mdot
.05373 .01566 Mdot
.05375 .02203 Mdot
.05378 .02048 Mdot
.0538 .03008 Mdot
.05383 .02334 Mdot
.05386 .02693 Mdot
.05388 .0238 Mdot
.05391 .03136 Mdot
.05393 .02503 Mdot
.05396 .02972 Mdot
.05399 .021 Mdot
.05401 .02667 Mdot
.05404 .03394 Mdot
.05406 .02034 Mdot
.05409 .02596 Mdot
.05411 .03076 Mdot
.05414 .02693 Mdot
.05417 .04557 Mdot
.05419 .03008 Mdot
.05422 .04064 Mdot
.05424 .05363 Mdot
.05427 .01999 Mdot
.0543 .04042 Mdot
.05432 .03995 Mdot
.05435 .02896 Mdot
.05437 .05014 Mdot
.0544 .02482 Mdot
.05442 .06067 Mdot
.05445 .0566 Mdot
.05448 .02892 Mdot
.0545 .04533 Mdot
.05453 .05138 Mdot
.05455 .0667 Mdot
.05458 .05757 Mdot
.05461 .04945 Mdot
.05463 .09464 Mdot
.05466 .08635 Mdot
.05468 .04599 Mdot
.05471 .03118 Mdot
.05473 .0711 Mdot
.05476 .09023 Mdot
.05479 .06881 Mdot
.05481 .02659 Mdot
.05484 .07385 Mdot
.05486 .10519 Mdot
.05489 .10353 Mdot
.05492 .07739 Mdot
.05494 .03179 Mdot
.05497 .11819 Mdot
.05499 .1433 Mdot
.05502 .11102 Mdot
.05504 .07856 Mdot
.05507 .0751 Mdot
.0551 .06194 Mdot
.05512 .04101 Mdot
.05515 .04799 Mdot
.05517 .0342 Mdot
.0552 .05679 Mdot
.05523 .11814 Mdot
.05525 .15027 Mdot
.05528 .13021 Mdot
.0553 .06118 Mdot
.05533 .06038 Mdot
.05535 .14013 Mdot
.05538 .19552 Mdot
.05541 .17132 Mdot
.05543 .08495 Mdot
.05546 .02564 Mdot
.05548 .04592 Mdot
.05551 .08734 Mdot
.05554 .09976 Mdot
.05556 .0738 Mdot
.05559 .04603 Mdot
.05561 .02505 Mdot
.05564 .02709 Mdot
.05566 .04252 Mdot
.05569 .05142 Mdot
.05572 .05255 Mdot
.05574 .04346 Mdot
.05577 .0349 Mdot
.05579 .02797 Mdot
.05582 .04158 Mdot
.05585 .05887 Mdot
.05587 .05972 Mdot
.0559 .064 Mdot
.05592 .05748 Mdot
.05595 .0585 Mdot
.05597 .06882 Mdot
.056 .06837 Mdot
.05603 .06786 Mdot
.05605 .07165 Mdot
.05608 .06499 Mdot
.0561 .06879 Mdot
.05613 .06556 Mdot
.05616 .05815 Mdot
.05618 .06449 Mdot
.05621 .06097 Mdot
.05623 .05815 Mdot
.05626 .05802 Mdot
.05628 .04773 Mdot
.05631 .04783 Mdot
.05634 .04462 Mdot
.05636 .03889 Mdot
.05639 .03621 Mdot
.05641 .02928 Mdot
.05644 .02556 Mdot
.05647 .02586 Mdot
.05649 .02463 Mdot
.05652 .02032 Mdot
.05654 .01765 Mdot
.05657 .01567 Mdot
.0566 .01544 Mdot
.05662 .0169 Mdot
.05665 .01947 Mdot
.05667 .01639 Mdot
.0567 .01621 Mdot
.05672 .01825 Mdot
.05675 .01985 Mdot
.05678 .0161 Mdot
.0568 .01969 Mdot
.05683 .02155 Mdot
.05685 .01574 Mdot
.05688 .021 Mdot
.05691 .02023 Mdot
.05693 .0209 Mdot
.05696 .01983 Mdot
.05698 .01839 Mdot
.05701 .02147 Mdot
.05703 .0219 Mdot
.05706 .01913 Mdot
.05709 .02012 Mdot
.05711 .01905 Mdot
.05714 .01979 Mdot
.05716 .01706 Mdot
.05719 .02102 Mdot
.05722 .01718 Mdot
.05724 .02348 Mdot
.05727 .02112 Mdot
.05729 .01621 Mdot
.05732 .02 Mdot
.05734 .01699 Mdot
.05737 .02021 Mdot
.0574 .0217 Mdot
.05742 .02099 Mdot
.05745 .02292 Mdot
.05747 .02564 Mdot
.0575 .01871 Mdot
.05753 .02094 Mdot
.05755 .02415 Mdot
.05758 .02118 Mdot
.0576 .0214 Mdot
.05763 .01836 Mdot
.05765 .0226 Mdot
.05768 .01982 Mdot
.05771 .01759 Mdot
.05773 .01861 Mdot
.05776 .01828 Mdot
.05778 .01842 Mdot
.05781 .01699 Mdot
.05784 .02085 Mdot
.05786 .01953 Mdot
.05789 .01792 Mdot
.05791 .02007 Mdot
.05794 .0207 Mdot
.05796 .01906 Mdot
.05799 .01781 Mdot
.05802 .02097 Mdot
.05804 .02277 Mdot
.05807 .01586 Mdot
.05809 .02247 Mdot
.05812 .02362 Mdot
.05815 .02075 Mdot
.05817 .01777 Mdot
.0582 .0202 Mdot
.05822 .01867 Mdot
.05825 .01668 Mdot
.05827 .01701 Mdot
.0583 .01619 Mdot
.05833 .01726 Mdot
.05835 .01754 Mdot
.05838 .01829 Mdot
.0584 .01733 Mdot
.05843 .01536 Mdot
.05846 .01671 Mdot
.05848 .01871 Mdot
.05851 .017 Mdot
.05853 .01803 Mdot
.05856 .01925 Mdot
.05858 .01694 Mdot
.05861 .01744 Mdot
.05864 .01999 Mdot
.05866 .02047 Mdot
.05869 .01817 Mdot
.05871 .01671 Mdot
.05874 .01762 Mdot
.05877 .02054 Mdot
.05879 .01882 Mdot
.05882 .02127 Mdot
.05884 .02155 Mdot
.05887 .01755 Mdot
.05889 .01819 Mdot
.05892 .01577 Mdot
.05895 .01733 Mdot
.05897 .01703 Mdot
.059 .01842 Mdot
.05902 .01793 Mdot
.05905 .0213 Mdot
.05908 .01708 Mdot
.0591 .0196 Mdot
.05913 .01748 Mdot
.05915 .01768 Mdot
.05918 .01719 Mdot
.0592 .01643 Mdot
.05923 .01902 Mdot
.05926 .01612 Mdot
.05928 .01774 Mdot
.05931 .01587 Mdot
.05933 .01971 Mdot
.05936 .01877 Mdot
.05939 .02247 Mdot
.05941 .01687 Mdot
.05944 .02105 Mdot
.05946 .02297 Mdot
.05949 .02652 Mdot
.05951 .01669 Mdot
.05954 .02358 Mdot
.05957 .01668 Mdot
.05959 .01854 Mdot
.05962 .02462 Mdot
.05964 .02577 Mdot
.05967 .01928 Mdot
.0597 .02683 Mdot
.05972 .02054 Mdot
.05975 .02349 Mdot
.05977 .02174 Mdot
.0598 .01801 Mdot
.05982 .02416 Mdot
.05985 .02688 Mdot
.05988 .02248 Mdot
.0599 .02684 Mdot
.05993 .02057 Mdot
.05995 .01969 Mdot
.05998 .0239 Mdot
.06001 .02759 Mdot
.06003 .0219 Mdot
.06006 .02986 Mdot
.06008 .02619 Mdot
.06011 .01832 Mdot
.06013 .02187 Mdot
.06016 .02081 Mdot
.06019 .01669 Mdot
.06021 .01961 Mdot
.06024 .02247 Mdot
.06026 .02373 Mdot
.06029 .01694 Mdot
.06032 .01964 Mdot
.06034 .0229 Mdot
.06037 .0259 Mdot
.06039 .01988 Mdot
.06042 .03247 Mdot
.06044 .0187 Mdot
.06047 .0215 Mdot
.0605 .0298 Mdot
.06052 .02391 Mdot
.06055 .02589 Mdot
.06057 .02787 Mdot
.0606 .02214 Mdot
.06063 .02478 Mdot
.06065 .01922 Mdot
.06068 .0283 Mdot
.0607 .04169 Mdot
.06073 .02771 Mdot
.06075 .02499 Mdot
.06078 .0347 Mdot
.06081 .0532 Mdot
.06083 .03902 Mdot
.06086 .05154 Mdot
.06088 .07523 Mdot
.06091 .06913 Mdot
.06094 .0422 Mdot
.06096 .02416 Mdot
.06099 .07046 Mdot
.06101 .11518 Mdot
.06104 .09545 Mdot
.06106 .02612 Mdot
.06109 .06663 Mdot
.06112 .09706 Mdot
.06114 .11339 Mdot
.06117 .11005 Mdot
.06119 .04841 Mdot
.06122 .06447 Mdot
.06125 .10549 Mdot
.06127 .08974 Mdot
.0613 .0896 Mdot
.06132 .13625 Mdot
.06135 .15523 Mdot
.06137 .13399 Mdot
.0614 .11081 Mdot
.06143 .07922 Mdot
.06145 .04313 Mdot
.06148 .12423 Mdot
.0615 .17016 Mdot
.06153 .12878 Mdot
.06156 .05332 Mdot
.06158 .0579 Mdot
.06161 .15994 Mdot
.06163 .23281 Mdot
.06166 .21283 Mdot
.06168 .1221 Mdot
.06171 .0481 Mdot
.06174 .06649 Mdot
.06176 .10491 Mdot
.06179 .13483 Mdot
.06181 .12143 Mdot
.06184 .07089 Mdot
.06187 .03426 Mdot
.06189 .03301 Mdot
.06192 .06482 Mdot
.06194 .08256 Mdot
.06197 .07292 Mdot
.06199 .04926 Mdot
.06202 .02051 Mdot
.06205 .03084 Mdot
.06207 .04507 Mdot
.0621 .0506 Mdot
.06212 .05464 Mdot
.06215 .04941 Mdot
.06218 .04415 Mdot
.0622 .03127 Mdot
.06223 .0551 Mdot
.06225 .06206 Mdot
.06228 .0584 Mdot
.0623 .06784 Mdot
.06233 .0583 Mdot
.06236 .05774 Mdot
.06238 .06444 Mdot
.06241 .05711 Mdot
.06243 .05958 Mdot
.06246 .06982 Mdot
.06249 .07093 Mdot
.06251 .07684 Mdot
.06254 .07577 Mdot
.06256 .07172 Mdot
.06259 .0879 Mdot
.06261 .07958 Mdot
.06264 .07946 Mdot
.06267 .08458 Mdot
.06269 .07501 Mdot
.06272 .07851 Mdot
.06274 .07169 Mdot
.06277 .06694 Mdot
.0628 .06925 Mdot
.06282 .06091 Mdot
.06285 .06114 Mdot
.06287 .05201 Mdot
.0629 .04883 Mdot
.06292 .04402 Mdot
.06295 .02917 Mdot
.06298 .03188 Mdot
.063 .02784 Mdot
.06303 .02607 Mdot
.06305 .02313 Mdot
.06308 .02595 Mdot
.06311 .01993 Mdot
.06313 .02053 Mdot
.06316 .01789 Mdot
.06318 .02163 Mdot
.06321 .01894 Mdot
.06323 .01951 Mdot
.06326 .01839 Mdot
.06329 .02696 Mdot
.06331 .02383 Mdot
.06334 .0215 Mdot
.06336 .02026 Mdot
.06339 .02015 Mdot
.06342 .03212 Mdot
.06344 .02858 Mdot
.06347 .02026 Mdot
.06349 .02411 Mdot
.06352 .02321 Mdot
.06354 .02892 Mdot
.06357 .03641 Mdot
.0636 .0336 Mdot
.06362 .03225 Mdot
.06365 .03753 Mdot
.06367 .03322 Mdot
.0637 .03183 Mdot
.06373 .03342 Mdot
.06375 .02728 Mdot
.06378 .03028 Mdot
.0638 .0302 Mdot
.06383 .02875 Mdot
.06385 .03141 Mdot
.06388 .02738 Mdot
.06391 .03219 Mdot
.06393 .03281 Mdot
.06396 .02476 Mdot
.06398 .02307 Mdot
.06401 .02625 Mdot
.06404 .03167 Mdot
.06406 .03163 Mdot
.06409 .02677 Mdot
.06411 .02952 Mdot
.06414 .0237 Mdot
.06416 .0329 Mdot
.06419 .03286 Mdot
.06422 .02637 Mdot
.06424 .02114 Mdot
.06427 .0279 Mdot
.06429 .0312 Mdot
.06432 .02332 Mdot
.06435 .01904 Mdot
.06437 .02061 Mdot
.0644 .02358 Mdot
.06442 .01756 Mdot
.06445 .01695 Mdot
.06447 .01956 Mdot
.0645 .01865 Mdot
.06453 .01768 Mdot
.06455 .01646 Mdot
.06458 .01951 Mdot
.0646 .02082 Mdot
.06463 .01864 Mdot
.06466 .01907 Mdot
.06468 .01895 Mdot
.06471 .01674 Mdot
.06473 .01682 Mdot
.06476 .01697 Mdot
.06478 .01746 Mdot
.06481 .01815 Mdot
.06484 .02096 Mdot
.06486 .01839 Mdot
.06489 .02111 Mdot
.06491 .02192 Mdot
.06494 .01951 Mdot
.06497 .01644 Mdot
.06499 .01819 Mdot
.06502 .0197 Mdot
.06504 .02138 Mdot
.06507 .01652 Mdot
.06509 .02657 Mdot
.06512 .02414 Mdot
.06515 .01618 Mdot
.06517 .01866 Mdot
.0652 .02442 Mdot
.06522 .02419 Mdot
.06525 .01816 Mdot
.06528 .02173 Mdot
.0653 .0243 Mdot
.06533 .02842 Mdot
.06535 .02249 Mdot
.06538 .02218 Mdot
.0654 .01848 Mdot
.06543 .02024 Mdot
.06546 .02042 Mdot
.06548 .02248 Mdot
.06551 .02211 Mdot
.06553 .02115 Mdot
.06556 .02265 Mdot
.06559 .01905 Mdot
.06561 .01897 Mdot
.06564 .01912 Mdot
.06566 .01929 Mdot
.06569 .01622 Mdot
.06572 .01816 Mdot
.06574 .01638 Mdot
.06577 .01951 Mdot
.06579 .01686 Mdot
.06582 .01802 Mdot
.06584 .01722 Mdot
.06587 .01647 Mdot
.0659 .01953 Mdot
.06592 .01791 Mdot
.06595 .01505 Mdot
.06597 .02368 Mdot
.066 .01913 Mdot
.06603 .01872 Mdot
.06605 .01586 Mdot
.06608 .0215 Mdot
.0661 .01809 Mdot
.06613 .02308 Mdot
.06615 .01611 Mdot
.06618 .02425 Mdot
.06621 .01802 Mdot
.06623 .02373 Mdot
.06626 .02133 Mdot
.06628 .03368 Mdot
.06631 .02538 Mdot
.06634 .02406 Mdot
.06636 .02346 Mdot
.06639 .02214 Mdot
.06641 .03209 Mdot
.06644 .03801 Mdot
.06646 .03124 Mdot
.06649 .04313 Mdot
.06652 .03228 Mdot
.06654 .04497 Mdot
.06657 .03811 Mdot
.06659 .02586 Mdot
.06662 .04471 Mdot
.06665 .04089 Mdot
.06667 .04455 Mdot
.0667 .05801 Mdot
.06672 .04522 Mdot
.06675 .07038 Mdot
.06677 .04915 Mdot
.0668 .05579 Mdot
.06683 .08244 Mdot
.06685 .05879 Mdot
.06688 .04918 Mdot
.0669 .05516 Mdot
.06693 .09257 Mdot
.06696 .12008 Mdot
.06698 .06612 Mdot
.06701 .06722 Mdot
.06703 .12225 Mdot
.06706 .1244 Mdot
.06708 .10475 Mdot
.06711 .03788 Mdot
.06714 .12844 Mdot
.06716 .20666 Mdot
.06719 .15841 Mdot
.06721 .03836 Mdot
.06724 .10716 Mdot
.06727 .17201 Mdot
.06729 .17983 Mdot
.06732 .10115 Mdot
.06734 .05471 Mdot
.06737 .14194 Mdot
.06739 .1481 Mdot
.06742 .13318 Mdot
.06745 .11015 Mdot
.06747 .05311 Mdot
.0675 .05692 Mdot
.06752 .08155 Mdot
.06755 .06488 Mdot
.06758 .09997 Mdot
.0676 .18481 Mdot
.06763 .21221 Mdot
.06765 .16479 Mdot
.06768 .108 Mdot
.0677 .0714 Mdot
.06773 .02836 Mdot
.06776 .09071 Mdot
.06778 .08607 Mdot
.06781 .08815 Mdot
.06783 .05764 Mdot
.06786 .11457 Mdot
.06789 .26467 Mdot
.06791 .30992 Mdot
.06794 .23334 Mdot
.06796 .09786 Mdot
.06799 .04259 Mdot
.06801 .13559 Mdot
.06804 .22437 Mdot
.06807 .20434 Mdot
.06809 .11693 Mdot
.06812 .06914 Mdot
.06814 .07168 Mdot
.06817 .10687 Mdot
.0682 .1349 Mdot
.06822 .14337 Mdot
.06825 .123 Mdot
.06827 .07578 Mdot
.0683 .02042 Mdot
.06832 .08123 Mdot
.06835 .12583 Mdot
.06838 .11973 Mdot
.0684 .08585 Mdot
.06843 .04507 Mdot
.06845 .0524 Mdot
.06848 .0809 Mdot
.06851 .07264 Mdot
.06853 .05332 Mdot
.06856 .05379 Mdot
.06858 .0518 Mdot
.06861 .03249 Mdot
.06863 .06963 Mdot
.06866 .08163 Mdot
.06869 .06723 Mdot
.06871 .08627 Mdot
.06874 .09169 Mdot
.06876 .0839 Mdot
.06879 .10309 Mdot
.06882 .08963 Mdot
.06884 .08096 Mdot
.06887 .11895 Mdot
.06889 .11265 Mdot
.06892 .1087 Mdot
.06894 .13119 Mdot
.06897 .12647 Mdot
.069 .14171 Mdot
.06902 .15208 Mdot
.06905 .15505 Mdot
.06907 .16221 Mdot
.0691 .13536 Mdot
.06913 .12436 Mdot
.06915 .12027 Mdot
.06918 .11352 Mdot
.0692 .10805 Mdot
.06923 .09131 Mdot
.06925 .09547 Mdot
.06928 .07456 Mdot
.06931 .05963 Mdot
.06933 .06585 Mdot
.06936 .05561 Mdot
.06938 .03949 Mdot
.06941 .04503 Mdot
.06944 .0372 Mdot
.06946 .03611 Mdot
.06949 .04046 Mdot
.06951 .02872 Mdot
.06954 .03084 Mdot
.06956 .03461 Mdot
.06959 .0422 Mdot
.06962 .04812 Mdot
.06964 .03217 Mdot
.06967 .02792 Mdot
.06969 .04528 Mdot
.06972 .03722 Mdot
.06975 .01768 Mdot
.06977 .02703 Mdot
.0698 .0223 Mdot
.06982 .02719 Mdot
.06985 .03093 Mdot
.06987 .03269 Mdot
.0699 .03781 Mdot
.06993 .03997 Mdot
.06995 .05626 Mdot
.06998 .0581 Mdot
.07 .05121 Mdot
.07003 .04594 Mdot
.07006 .0545 Mdot
.07008 .06109 Mdot
.07011 .06424 Mdot
.07013 .04932 Mdot
.07016 .04914 Mdot
.07018 .05248 Mdot
.07021 .06132 Mdot
.07024 .06114 Mdot
.07026 .05574 Mdot
.07029 .05721 Mdot
.07031 .04921 Mdot
.07034 .05967 Mdot
.07037 .06174 Mdot
.07039 .06428 Mdot
.07042 .06386 Mdot
.07044 .05402 Mdot
.07047 .05195 Mdot
.07049 .05751 Mdot
.07052 .05507 Mdot
.07055 .046 Mdot
.07057 .05151 Mdot
.0706 .04291 Mdot
.07062 .05205 Mdot
.07065 .05114 Mdot
.07068 .0431 Mdot
.0707 .04854 Mdot
.07073 .04949 Mdot
.07075 .04351 Mdot
.07078 .04022 Mdot
.0708 .04034 Mdot
.07083 .03742 Mdot
.07086 .03381 Mdot
.07088 .04391 Mdot
.07091 .04234 Mdot
.07093 .04151 Mdot
.07096 .04662 Mdot
.07099 .03801 Mdot
.07101 .02649 Mdot
.07104 .02944 Mdot
.07106 .03363 Mdot
.07109 .02999 Mdot
.07111 .0226 Mdot
.07114 .02237 Mdot
.07117 .025 Mdot
.07119 .02378 Mdot
.07122 .02344 Mdot
.07124 .01684 Mdot
.07127 .01762 Mdot
.0713 .01631 Mdot
.07132 .02147 Mdot
.07135 .03003 Mdot
.07137 .02072 Mdot
.0714 .01945 Mdot
.07142 .02007 Mdot
.07145 .02156 Mdot
.07148 .02097 Mdot
.0715 .03365 Mdot
.07153 .01683 Mdot
.07155 .02616 Mdot
.07158 .01616 Mdot
.07161 .02337 Mdot
.07163 .01924 Mdot
.07166 .02108 Mdot
.07168 .02187 Mdot
.07171 .02808 Mdot
.07173 .01928 Mdot
.07176 .0276 Mdot
.07179 .02462 Mdot
.07181 .02488 Mdot
.07184 .01778 Mdot
.07186 .03457 Mdot
.07189 .0217 Mdot
.07192 .02805 Mdot
.07194 .02171 Mdot
.07197 .02946 Mdot
.07199 .02233 Mdot
.07202 .03862 Mdot
.07204 .02955 Mdot
.07207 .0358 Mdot
.0721 .0277 Mdot
.07212 .04416 Mdot
.07215 .02067 Mdot
.07217 .04526 Mdot
.0722 .02171 Mdot
.07223 .03721 Mdot
.07225 .01954 Mdot
.07228 .03759 Mdot
.0723 .01875 Mdot
.07233 .02452 Mdot
.07235 .02105 Mdot
.07238 .03296 Mdot
.07241 .02074 Mdot
.07243 .03177 Mdot
.07246 .01695 Mdot
.07248 .02416 Mdot
.07251 .02367 Mdot
.07254 .02922 Mdot
.07256 .01944 Mdot
.07259 .02526 Mdot
.07261 .02596 Mdot
.07264 .02874 Mdot
.07266 .02955 Mdot
.07269 .04395 Mdot
.07272 .016 Mdot
.07274 .04021 Mdot
.07277 .02691 Mdot
.07279 .03125 Mdot
.07282 .03846 Mdot
.07285 .03754 Mdot
.07287 .05237 Mdot
.0729 .06783 Mdot
.07292 .02416 Mdot
.07295 .06535 Mdot
.07297 .03632 Mdot
.073 .03674 Mdot
.07303 .0487 Mdot
.07305 .03135 Mdot
.07308 .0758 Mdot
.0731 .08198 Mdot
.07313 .0262 Mdot
.07316 .04322 Mdot
.07318 .05715 Mdot
.07321 .0821 Mdot
.07323 .07203 Mdot
.07326 .05864 Mdot
.07328 .08143 Mdot
.07331 .08503 Mdot
.07334 .06737 Mdot
.07336 .0402 Mdot
.07339 .08133 Mdot
.07341 .13917 Mdot
.07344 .11207 Mdot
.07347 .04183 Mdot
.07349 .06009 Mdot
.07352 .0835 Mdot
.07354 .09794 Mdot
.07357 .0901 Mdot
.07359 .02957 Mdot
.07362 .07343 Mdot
.07365 .08904 Mdot
.07367 .06736 Mdot
.0737 .07753 Mdot
.07372 .09192 Mdot
.07375 .07692 Mdot
.07378 .06534 Mdot
.0738 .06404 Mdot
.07383 .03036 Mdot
.07385 .08226 Mdot
.07388 .13575 Mdot
.0739 .12223 Mdot
.07393 .06272 Mdot
.07396 .04223 Mdot
.07398 .05119 Mdot
.07401 .04558 Mdot
.07403 .01977 Mdot
.07406 .03684 Mdot
.07409 .04065 Mdot
.07411 .02766 Mdot
.07414 .07724 Mdot
.07416 .10293 Mdot
.07419 .09009 Mdot
.07421 .05598 Mdot
.07424 .01807 Mdot
.07427 .06356 Mdot
.07429 .09318 Mdot
.07432 .09176 Mdot
.07434 .06575 Mdot
.07437 .02973 Mdot
.0744 .02396 Mdot
.07442 .05283 Mdot
.07445 .06825 Mdot
.07447 .06047 Mdot
.0745 .03606 Mdot
.07452 .02236 Mdot
.07455 .02244 Mdot
.07458 .03742 Mdot
.0746 .03952 Mdot
.07463 .02907 Mdot
.07465 .02367 Mdot
.07468 .02557 Mdot
.07471 .02017 Mdot
.07473 .02296 Mdot
.07476 .02937 Mdot
.07478 .02793 Mdot
.07481 .02683 Mdot
.07484 .02548 Mdot
.07486 .02355 Mdot
.07489 .0292 Mdot
.07491 .02598 Mdot
.07494 .02138 Mdot
.07496 .02313 Mdot
.07499 .01999 Mdot
.07502 .01693 Mdot
.07504 .02272 Mdot
.07507 .01719 Mdot
.07509 .01528 Mdot
.07512 .01923 Mdot
.07515 .02086 Mdot
.07517 .02137 Mdot
.0752 .02173 Mdot
.07522 .01913 Mdot
.07525 .02535 Mdot
.07527 .02485 Mdot
.0753 .02333 Mdot
.07533 .02375 Mdot
.07535 .02201 Mdot
.07538 .02156 Mdot
.0754 .02257 Mdot
.07543 .02224 Mdot
.07546 .02387 Mdot
.07548 .02387 Mdot
.07551 .02253 Mdot
.07553 .02081 Mdot
.07556 .02527 Mdot
.07558 .02252 Mdot
.07561 .02309 Mdot
.07564 .01801 Mdot
.07566 .02013 Mdot
.07569 .01868 Mdot
.07571 .01857 Mdot
.07574 .01956 Mdot
.07577 .01919 Mdot
.07579 .01744 Mdot
.07582 .01617 Mdot
.07584 .01869 Mdot
.07587 .01567 Mdot
.07589 .015 Mdot
.07592 .01615 Mdot
.07595 .01662 Mdot
.07597 .01753 Mdot
.076 .01587 Mdot
.07602 .01603 Mdot
.07605 .01592 Mdot
.07608 .01657 Mdot
.0761 .01552 Mdot
.07613 .01641 Mdot
.07615 .01749 Mdot
.07618 .01543 Mdot
.0762 .01644 Mdot
.07623 .01868 Mdot
.07626 .01718 Mdot
.07628 .01704 Mdot
.07631 .01748 Mdot
.07633 .01683 Mdot
.07636 .01498 Mdot
.07639 .01726 Mdot
.07641 .01649 Mdot
.07644 .01667 Mdot
.07646 .01502 Mdot
.07649 .01587 Mdot
.07651 .01623 Mdot
.07654 .01642 Mdot
.07657 .01551 Mdot
.07659 .01534 Mdot
.07662 .01492 Mdot
.07664 .0157 Mdot
.07667 .01626 Mdot
.0767 .0151 Mdot
.07672 .01565 Mdot
.07675 .0171 Mdot
.07677 .01714 Mdot
.0768 .01628 Mdot
.07682 .01554 Mdot
.07685 .01738 Mdot
.07688 .01745 Mdot
.0769 .01604 Mdot
.07693 .021 Mdot
.07695 .01809 Mdot
.07698 .01827 Mdot
.07701 .01845 Mdot
.07703 .01678 Mdot
.07706 .01654 Mdot
.07708 .01854 Mdot
.07711 .01701 Mdot
.07713 .01626 Mdot
.07716 .01941 Mdot
.07719 .01534 Mdot
.07721 .01643 Mdot
.07724 .01855 Mdot
.07726 .0165 Mdot
.07729 .01616 Mdot
.07732 .01566 Mdot
.07734 .0163 Mdot
.07737 .01507 Mdot
.07739 .01681 Mdot
.07742 .01644 Mdot
.07744 .01835 Mdot
.07747 .01507 Mdot
.0775 .01644 Mdot
.07752 .01695 Mdot
.07755 .01565 Mdot
.07757 .01621 Mdot
.0776 .0171 Mdot
.07763 .01555 Mdot
.07765 .01705 Mdot
.07768 .0155 Mdot
.0777 .01549 Mdot
.07773 .01627 Mdot
.07775 .01601 Mdot
.07778 .01529 Mdot
.07781 .01604 Mdot
.07783 .01695 Mdot
.07786 .01616 Mdot
.07788 .01498 Mdot
.07791 .01599 Mdot
.07794 .01697 Mdot
.07796 .01718 Mdot
.07799 .01656 Mdot
.07801 .01688 Mdot
.07804 .0164 Mdot
.07806 .01492 Mdot
.07809 .01513 Mdot
.07812 .01772 Mdot
.07814 .01648 Mdot
.07817 .01618 Mdot
.07819 .01612 Mdot
.07822 .01571 Mdot
.07825 .01634 Mdot
.07827 .01532 Mdot
.0783 .01736 Mdot
.07832 .01619 Mdot
.07835 .01596 Mdot
.07837 .01557 Mdot
.0784 .01575 Mdot
.07843 .01594 Mdot
.07845 .01571 Mdot
.07848 .01666 Mdot
.0785 .0157 Mdot
.07853 .01592 Mdot
.07856 .01747 Mdot
.07858 .0164 Mdot
.07861 .01652 Mdot
.07863 .01699 Mdot
.07866 .01694 Mdot
.07868 .01599 Mdot
.07871 .01848 Mdot
.07874 .01557 Mdot
.07876 .01601 Mdot
.07879 .01553 Mdot
.07881 .01627 Mdot
.07884 .01653 Mdot
.07887 .018 Mdot
.07889 .01606 Mdot
.07892 .01637 Mdot
.07894 .01849 Mdot
.07897 .0166 Mdot
.07899 .01805 Mdot
.07902 .01593 Mdot
.07905 .01601 Mdot
.07907 .01716 Mdot
.0791 .01584 Mdot
.07912 .01617 Mdot
.07915 .01829 Mdot
.07918 .0149 Mdot
.0792 .0161 Mdot
.07923 .01815 Mdot
.07925 .01826 Mdot
.07928 .01776 Mdot
.0793 .01525 Mdot
.07933 .01937 Mdot
.07936 .01968 Mdot
.07938 .01745 Mdot
.07941 .01775 Mdot
.07943 .01889 Mdot
.07946 .01985 Mdot
.07949 .01824 Mdot
.07951 .01556 Mdot
.07954 .01722 Mdot
.07956 .01673 Mdot
.07959 .01874 Mdot
.07961 .01682 Mdot
.07964 .01995 Mdot
.07967 .02007 Mdot
.07969 .02078 Mdot
.07972 .01789 Mdot
.07974 .0167 Mdot
.07977 .0204 Mdot
.0798 .02115 Mdot
.07982 .02286 Mdot
.07985 .01752 Mdot
.07987 .01748 Mdot
.0799 .01882 Mdot
.07992 .01853 Mdot
.07995 .01792 Mdot
.07998 .02296 Mdot
.08 .02633 Mdot
.08003 .02488 Mdot
.08005 .02628 Mdot
.08008 .02374 Mdot
.08011 .01728 Mdot
.08013 .02529 Mdot
.08016 .02826 Mdot
.08018 .0226 Mdot
.08021 .01767 Mdot
.08023 .02398 Mdot
.08026 .02756 Mdot
.08029 .02588 Mdot
.08031 .0225 Mdot
.08034 .02172 Mdot
.08036 .02172 Mdot
.08039 .01837 Mdot
.08042 .02619 Mdot
.08044 .0266 Mdot
.08047 .02596 Mdot
.08049 .01681 Mdot
.08052 .02558 Mdot
.08054 .03607 Mdot
.08057 .03787 Mdot
.0806 .03122 Mdot
.08062 .02421 Mdot
.08065 .01747 Mdot
.08067 .02633 Mdot
.0807 .03185 Mdot
.08073 .03035 Mdot
.08075 .02507 Mdot
.08078 .01996 Mdot
.0808 .01905 Mdot
.08083 .02524 Mdot
.08085 .02192 Mdot
.08088 .02281 Mdot
.08091 .019 Mdot
.08093 .01874 Mdot
.08096 .01652 Mdot
.08098 .01867 Mdot
.08101 .0195 Mdot
.08104 .01815 Mdot
.08106 .01627 Mdot
.08109 .01691 Mdot
.08111 .01584 Mdot
.08114 .01724 Mdot
.08116 .01837 Mdot
.08119 .0183 Mdot
.08122 .01809 Mdot
.08124 .01839 Mdot
.08127 .01606 Mdot
.08129 .01841 Mdot
.08132 .01513 Mdot
.08135 .01572 Mdot
.08137 .01692 Mdot
.0814 .01786 Mdot
.08142 .01614 Mdot
.08145 .01919 Mdot
.08147 .0161 Mdot
.0815 .01731 Mdot
.08153 .01667 Mdot
.08155 .01699 Mdot
.08158 .01696 Mdot
.0816 .01903 Mdot
.08163 .01839 Mdot
.08166 .01814 Mdot
.08168 .01776 Mdot
.08171 .01907 Mdot
.08173 .01795 Mdot
.08176 .01928 Mdot
.08178 .0192 Mdot
.08181 .01734 Mdot
.08184 .02018 Mdot
.08186 .02057 Mdot
.08189 .02182 Mdot
.08191 .02012 Mdot
.08194 .02048 Mdot
.08197 .02099 Mdot
.08199 .0198 Mdot
.08202 .01934 Mdot
.08204 .01899 Mdot
.08207 .01723 Mdot
.08209 .02045 Mdot
.08212 .01723 Mdot
.08215 .02032 Mdot
.08217 .02011 Mdot
.0822 .01796 Mdot
.08222 .01776 Mdot
.08225 .0174 Mdot
.08228 .01845 Mdot
.0823 .01663 Mdot
.08233 .01653 Mdot
.08235 .01623 Mdot
.08238 .01863 Mdot
.0824 .01597 Mdot
.08243 .01685 Mdot
.08246 .01673 Mdot
.08248 .01597 Mdot
.08251 .01631 Mdot
.08253 .01594 Mdot
.08256 .01622 Mdot
.08259 .01673 Mdot
.08261 .0155 Mdot
.08264 .01548 Mdot
.08266 .01663 Mdot
.08269 .01844 Mdot
.08271 .01837 Mdot
.08274 .01537 Mdot
.08277 .01642 Mdot
.08279 .01615 Mdot
.08282 .01771 Mdot
.08284 .01758 Mdot
.08287 .0171 Mdot
.0829 .01632 Mdot
.08292 .01612 Mdot
.08295 .01676 Mdot
.08297 .01619 Mdot
.083 .01662 Mdot
.08302 .01697 Mdot
.08305 .01557 Mdot
.08308 .01649 Mdot
.0831 .01599 Mdot
.08313 .01702 Mdot
.08315 .01752 Mdot
.08318 .01519 Mdot
.08321 .01619 Mdot
.08323 .01717 Mdot
.08326 .01755 Mdot
.08328 .01805 Mdot
.08331 .01736 Mdot
.08333 .01678 Mdot
.08336 .01587 Mdot
.08339 .01778 Mdot
.08341 .01649 Mdot
.08344 .01572 Mdot
.08346 .01677 Mdot
.08349 .01736 Mdot
.08352 .01821 Mdot
.08354 .0151 Mdot
.08357 .01553 Mdot
.08359 .01841 Mdot
.08362 .01965 Mdot
.08364 .01827 Mdot
.08367 .01605 Mdot
.0837 .01688 Mdot
.08372 .01684 Mdot
.08375 .0168 Mdot
.08377 .0153 Mdot
.0838 .01554 Mdot
.08383 .01589 Mdot
.08385 .01552 Mdot
.08388 .01531 Mdot
.0839 .01778 Mdot
.08393 .01845 Mdot
.08396 .01793 Mdot
.08398 .01736 Mdot
.08401 .01484 Mdot
.08403 .01559 Mdot
.08406 .01735 Mdot
.08408 .01773 Mdot
.08411 .01591 Mdot
.08414 .01629 Mdot
.08416 .01687 Mdot
.08419 .01606 Mdot
.08421 .01833 Mdot
.08424 .01527 Mdot
.08427 .01668 Mdot
.08429 .01531 Mdot
.08432 .01607 Mdot
.08434 .01602 Mdot
.08437 .01556 Mdot
.08439 .01566 Mdot
.08442 .01547 Mdot
.08445 .01579 Mdot
.08447 .01642 Mdot
.0845 .0158 Mdot
.08452 .01584 Mdot
.08455 .01553 Mdot
.08458 .01709 Mdot
.0846 .01729 Mdot
.08463 .01547 Mdot
.08465 .01718 Mdot
.08468 .01624 Mdot
.0847 .01621 Mdot
.08473 .015 Mdot
.08476 .01658 Mdot
.08478 .01993 Mdot
.08481 .01594 Mdot
.08483 .01495 Mdot
.08486 .01834 Mdot
.08489 .01715 Mdot
.08491 .01594 Mdot
.08494 .01644 Mdot
.08496 .01648 Mdot
.08499 .01475 Mdot
.08501 .01732 Mdot
.08504 .01765 Mdot
.08507 .01517 Mdot
.08509 .01532 Mdot
.08512 .01649 Mdot
.08514 .01572 Mdot
.08517 .0153 Mdot
.0852 .01849 Mdot
.08522 .01532 Mdot
.08525 .01644 Mdot
.08527 .01799 Mdot
.0853 .01622 Mdot
.08532 .01706 Mdot
.08535 .0155 Mdot
.08538 .01729 Mdot
.0854 .01902 Mdot
.08543 .01593 Mdot
.08545 .01574 Mdot
.08548 .01848 Mdot
.08551 .01932 Mdot
.08553 .01965 Mdot
.08556 .0179 Mdot
.08558 .022 Mdot
.08561 .02267 Mdot
.08563 .02179 Mdot
.08566 .01735 Mdot
.08569 .02045 Mdot
.08571 .02353 Mdot
.08574 .01974 Mdot
.08576 .02012 Mdot
.08579 .02586 Mdot
.08582 .02 Mdot
.08584 .02078 Mdot
.08587 .0164 Mdot
.08589 .01731 Mdot
.08592 .02243 Mdot
.08594 .02422 Mdot
.08597 .02186 Mdot
.086 .02489 Mdot
.08602 .02118 Mdot
.08605 .0155 Mdot
.08607 .01829 Mdot
.0861 .01655 Mdot
.08613 .0216 Mdot
.08615 .01544 Mdot
.08618 .01877 Mdot
.0862 .01533 Mdot
.08623 .01877 Mdot
.08625 .02486 Mdot
.08628 .02502 Mdot
.08631 .02185 Mdot
.08633 .02152 Mdot
.08636 .01562 Mdot
.08638 .01741 Mdot
.08641 .02078 Mdot
.08644 .02161 Mdot
.08646 .01739 Mdot
.08649 .01895 Mdot
.08651 .02551 Mdot
.08654 .02851 Mdot
.08656 .02428 Mdot
.08659 .01903 Mdot
.08662 .0151 Mdot
.08664 .0169 Mdot
.08667 .01667 Mdot
.08669 .02302 Mdot
.08672 .02078 Mdot
.08675 .01875 Mdot
.08677 .02132 Mdot
.0868 .03089 Mdot
.08682 .03103 Mdot
.08685 .02564 Mdot
.08687 .02323 Mdot
.0869 .01612 Mdot
.08693 .02496 Mdot
.08695 .02611 Mdot
.08698 .02455 Mdot
.087 .02086 Mdot
.08703 .01595 Mdot
.08706 .01672 Mdot
.08708 .01992 Mdot
.08711 .02261 Mdot
.08713 .02145 Mdot
.08716 .01836 Mdot
.08718 .01618 Mdot
.08721 .01712 Mdot
.08724 .02033 Mdot
.08726 .01847 Mdot
.08729 .01709 Mdot
.08731 .01811 Mdot
.08734 .01664 Mdot
.08737 .01843 Mdot
.08739 .0188 Mdot
.08742 .01901 Mdot
.08744 .01773 Mdot
.08747 .01671 Mdot
.08749 .01737 Mdot
.08752 .01659 Mdot
.08755 .01754 Mdot
.08757 .01807 Mdot
.0876 .01541 Mdot
.08762 .01752 Mdot
.08765 .01598 Mdot
.08768 .01617 Mdot
.0877 .0185 Mdot
.08773 .0162 Mdot
.08775 .01795 Mdot
.08778 .01654 Mdot
.0878 .01973 Mdot
.08783 .01735 Mdot
.08786 .0185 Mdot
.08788 .01994 Mdot
.08791 .01693 Mdot
.08793 .01734 Mdot
.08796 .0163 Mdot
.08799 .01503 Mdot
.08801 .01679 Mdot
.08804 .01784 Mdot
.08806 .01632 Mdot
.08809 .01713 Mdot
.08811 .01689 Mdot
.08814 .01705 Mdot
.08817 .01727 Mdot
.08819 .01526 Mdot
.08822 .01781 Mdot
.08824 .01591 Mdot
.08827 .01732 Mdot
.0883 .01658 Mdot
.08832 .01669 Mdot
.08835 .0157 Mdot
.08837 .01717 Mdot
.0884 .01646 Mdot
.08842 .01658 Mdot
.08845 .01825 Mdot
.08848 .01955 Mdot
.0885 .01686 Mdot
.08853 .01766 Mdot
.08855 .01947 Mdot
.08858 .02047 Mdot
.08861 .01966 Mdot
.08863 .01808 Mdot
.08866 .01573 Mdot
.08868 .01697 Mdot
.08871 .01652 Mdot
.08873 .01517 Mdot
.08876 .01563 Mdot
.08879 .01633 Mdot
.08881 .01808 Mdot
.08884 .01715 Mdot
.08886 .01537 Mdot
.08889 .0153 Mdot
.08892 .01607 Mdot
.08894 .01674 Mdot
.08897 .01567 Mdot
.08899 .01558 Mdot
.08902 .01614 Mdot
.08904 .01624 Mdot
.08907 .01501 Mdot
.0891 .01545 Mdot
.08912 .01606 Mdot
.08915 .01622 Mdot
.08917 .01547 Mdot
.0892 .01697 Mdot
.08923 .01542 Mdot
.08925 .01594 Mdot
.08928 .01494 Mdot
.0893 .01568 Mdot
.08933 .01566 Mdot
.08935 .01654 Mdot
.08938 .01633 Mdot
.08941 .0163 Mdot
.08943 .01577 Mdot
.08946 .01582 Mdot
.08948 .01782 Mdot
.08951 .01544 Mdot
.08954 .01647 Mdot
.08956 .01642 Mdot
.08959 .01543 Mdot
.08961 .01744 Mdot
.08964 .01695 Mdot
.08966 .01682 Mdot
.08969 .01569 Mdot
.08972 .01543 Mdot
.08974 .01642 Mdot
.08977 .01631 Mdot
.08979 .01624 Mdot
.08982 .01499 Mdot
.08985 .01657 Mdot
.08987 .01617 Mdot
.0899 .01582 Mdot
.08992 .01719 Mdot
.08995 .0169 Mdot
.08997 .01749 Mdot
.09 .01755 Mdot
.09003 .01514 Mdot
.09005 .01529 Mdot
.09008 .01781 Mdot
.0901 .01586 Mdot
.09013 .01566 Mdot
.09016 .01845 Mdot
.09018 .01495 Mdot
.09021 .01667 Mdot
.09023 .01617 Mdot
.09026 .01547 Mdot
.09028 .01713 Mdot
.09031 .01537 Mdot
.09034 .01599 Mdot
.09036 .01592 Mdot
.09039 .01576 Mdot
.09041 .01605 Mdot
.09044 .0162 Mdot
.09047 .01668 Mdot
.09049 .01538 Mdot
.09052 .01517 Mdot
.09054 .01517 Mdot
.09057 .01745 Mdot
.09059 .01796 Mdot
.09062 .01703 Mdot
.09065 .01601 Mdot
.09067 .01692 Mdot
.0907 .01796 Mdot
.09072 .01613 Mdot
.09075 .01737 Mdot
.09078 .015 Mdot
.0908 .01547 Mdot
.09083 .017 Mdot
.09085 .01601 Mdot
.09088 .01549 Mdot
.0909 .01799 Mdot
.09093 .01778 Mdot
.09096 .01515 Mdot
.09098 .01504 Mdot
.09101 .01563 Mdot
.09103 .0179 Mdot
.09106 .01609 Mdot
.09109 .01631 Mdot
.09111 .01709 Mdot
.09114 .01827 Mdot
.09116 .01754 Mdot
.09119 .02243 Mdot
.09121 .01846 Mdot
.09124 .01726 Mdot
.09127 .01569 Mdot
.09129 .01609 Mdot
.09132 .01637 Mdot
.09134 .01648 Mdot
.09137 .01503 Mdot
.0914 .01679 Mdot
.09142 .01706 Mdot
.09145 .01711 Mdot
.09147 .01622 Mdot
.0915 .01556 Mdot
.09152 .01759 Mdot
.09155 .01576 Mdot
.09158 .01624 Mdot
.0916 .0176 Mdot
.09163 .01563 Mdot
.09165 .01735 Mdot
.09168 .01681 Mdot
.09171 .01613 Mdot
.09173 .01803 Mdot
.09176 .01788 Mdot
.09178 .0175 Mdot
.09181 .01716 Mdot
.09183 .0189 Mdot
.09186 .02047 Mdot
.09189 .01867 Mdot
.09191 .01593 Mdot
.09194 .0175 Mdot
.09196 .02161 Mdot
.09199 .02074 Mdot
.09202 .0179 Mdot
.09204 .0185 Mdot
.09207 .0216 Mdot
.09209 .02173 Mdot
.09212 .0178 Mdot
.09214 .01757 Mdot
.09217 .01775 Mdot
.0922 .01793 Mdot
.09222 .01882 Mdot
.09225 .01603 Mdot
.09227 .01701 Mdot
.0923 .02019 Mdot
.09233 .01618 Mdot
.09235 .01776 Mdot
.09238 .0204 Mdot
.0924 .01733 Mdot
.09243 .01986 Mdot
.09245 .01782 Mdot
.09248 .01704 Mdot
.09251 .02007 Mdot
.09253 .02251 Mdot
.09256 .01846 Mdot
.09258 .02299 Mdot
.09261 .02105 Mdot
.09264 .01783 Mdot
.09266 .01621 Mdot
.09269 .01602 Mdot
.09271 .01822 Mdot
.09274 .01764 Mdot
.09276 .02149 Mdot
.09279 .02282 Mdot
.09282 .02144 Mdot
.09284 .01818 Mdot
.09287 .01606 Mdot
.09289 .02031 Mdot
.09292 .01767 Mdot
.09295 .01566 Mdot
.09297 .01518 Mdot
.093 .01973 Mdot
.09302 .01531 Mdot
.09305 .02425 Mdot
.09308 .02318 Mdot
.0931 .0218 Mdot
.09313 .02034 Mdot
.09315 .01841 Mdot
.09318 .01932 Mdot
.0932 .02469 Mdot
.09323 .02555 Mdot
.09326 .02305 Mdot
.09328 .01731 Mdot
.09331 .01702 Mdot
.09333 .02068 Mdot
.09336 .02221 Mdot
.09339 .01944 Mdot
.09341 .01781 Mdot
.09344 .01667 Mdot
.09346 .02012 Mdot
.09349 .01646 Mdot
.09351 .01923 Mdot
.09354 .01754 Mdot
.09357 .01874 Mdot
.09359 .0153 Mdot
.09362 .01703 Mdot
.09364 .01849 Mdot
.09367 .0186 Mdot
.0937 .01746 Mdot
.09372 .01671 Mdot
.09375 .01521 Mdot
.09377 .01783 Mdot
.0938 .01586 Mdot
.09382 .01616 Mdot
.09385 .01773 Mdot
.09388 .01678 Mdot
.0939 .01701 Mdot
.09393 .01705 Mdot
.09395 .01601 Mdot
.09398 .01592 Mdot
.09401 .01699 Mdot
.09403 .01697 Mdot
.09406 .01792 Mdot
.09408 .01711 Mdot
.09411 .01664 Mdot
.09413 .01716 Mdot
.09416 .01582 Mdot
.09419 .01535 Mdot
.09421 .01684 Mdot
.09424 .01642 Mdot
.09426 .01499 Mdot
.09429 .01679 Mdot
.09432 .01856 Mdot
.09434 .01526 Mdot
.09437 .01617 Mdot
.09439 .01532 Mdot
.09442 .01497 Mdot
.09444 .01593 Mdot
.09447 .0167 Mdot
.0945 .01624 Mdot
.09452 .01688 Mdot
.09455 .01522 Mdot
.09457 .02486 Mdot
.0946 .01806 Mdot
.09463 .01878 Mdot
.09465 .01617 Mdot
.09468 .01836 Mdot
.0947 .01726 Mdot
.09473 .01806 Mdot
.09475 .01643 Mdot
.09478 .01643 Mdot
.09481 .017 Mdot
.09483 .01593 Mdot
.09486 .01631 Mdot
.09488 .01656 Mdot
.09491 .01705 Mdot
.09494 .01573 Mdot
.09496 .01748 Mdot
.09499 .01795 Mdot
.09501 .01716 Mdot
.09504 .01698 Mdot
.09506 .01731 Mdot
.09509 .01672 Mdot
.09512 .0177 Mdot
.09514 .01927 Mdot
.09517 .01816 Mdot
.09519 .01672 Mdot
.09522 .01658 Mdot
.09525 .01667 Mdot
.09527 .01593 Mdot
.0953 .01584 Mdot
.09532 .0157 Mdot
.09535 .01579 Mdot
.09537 .01519 Mdot
.0954 .01658 Mdot
.09543 .01592 Mdot
.09545 .01552 Mdot
.09548 .01636 Mdot
.0955 .01524 Mdot
.09553 .01617 Mdot
.09556 .01595 Mdot
.09558 .0157 Mdot
.09561 .01655 Mdot
.09563 .01648 Mdot
.09566 .01535 Mdot
.09568 .01571 Mdot
.09571 .01625 Mdot
.09574 .01735 Mdot
.09576 .01653 Mdot
.09579 .01583 Mdot
.09581 .01572 Mdot
.09584 .01578 Mdot
.09587 .01658 Mdot
.09589 .01627 Mdot
.09592 .01575 Mdot
.09594 .0165 Mdot
.09597 .01609 Mdot
.09599 .01619 Mdot
.09602 .01569 Mdot
.09605 .01549 Mdot
.09607 .01681 Mdot
.0961 .01532 Mdot
.09612 .01648 Mdot
.09615 .0164 Mdot
.09618 .01592 Mdot
.0962 .01529 Mdot
.09623 .01612 Mdot
.09625 .01784 Mdot
.09628 .01609 Mdot
.0963 .01594 Mdot
.09633 .01985 Mdot
.09636 .02224 Mdot
.09638 .01873 Mdot
.09641 .01889 Mdot
.09643 .0165 Mdot
.09646 .0158 Mdot
.09649 .01695 Mdot
.09651 .016 Mdot
.09654 .01649 Mdot
.09656 .01634 Mdot
.09659 .01619 Mdot
.09661 .0162 Mdot
.09664 .01506 Mdot
.09667 .01701 Mdot
.09669 .01524 Mdot
.09672 .01568 Mdot
.09674 .01547 Mdot
.09677 .0163 Mdot
.0968 .01736 Mdot
.09682 .01833 Mdot
.09685 .01607 Mdot
.09687 .01662 Mdot
.0969 .01512 Mdot
.09692 .01675 Mdot
.09695 .01712 Mdot
.09698 .01607 Mdot
.097 .01626 Mdot
.09703 .0152 Mdot
.09705 .01574 Mdot
.09708 .01622 Mdot
.09711 .01502 Mdot
.09713 .01543 Mdot
.09716 .01624 Mdot
.09718 .01589 Mdot
.09721 .01687 Mdot
.09723 .01652 Mdot
.09726 .01713 Mdot
.09729 .01574 Mdot
.09731 .0153 Mdot
.09734 .01544 Mdot
.09736 .01683 Mdot
.09739 .01678 Mdot
.09742 .01602 Mdot
.09744 .01709 Mdot
.09747 .0151 Mdot
.09749 .01628 Mdot
.09752 .0165 Mdot
.09754 .0152 Mdot
.09757 .01962 Mdot
.0976 .01643 Mdot
.09762 .01643 Mdot
.09765 .01568 Mdot
.09767 .01799 Mdot
.0977 .01567 Mdot
.09773 .01579 Mdot
.09775 .01652 Mdot
.09778 .01615 Mdot
.0978 .0177 Mdot
.09783 .01547 Mdot
.09785 .01815 Mdot
.09788 .01677 Mdot
.09791 .01641 Mdot
.09793 .01513 Mdot
.09796 .01731 Mdot
.09798 .01597 Mdot
.09801 .01619 Mdot
.09804 .0159 Mdot
.09806 .01729 Mdot
.09809 .01592 Mdot
.09811 .0186 Mdot
.09814 .01817 Mdot
.09816 .01524 Mdot
.09819 .01737 Mdot
.09822 .01733 Mdot
.09824 .01705 Mdot
.09827 .01738 Mdot
.09829 .01782 Mdot
.09832 .01643 Mdot
.09835 .01857 Mdot
.09837 .01728 Mdot
.0984 .01527 Mdot
.09842 .01547 Mdot
.09845 .01562 Mdot
.09847 .01917 Mdot
.0985 .0173 Mdot
.09853 .01621 Mdot
.09855 .01843 Mdot
.09858 .01747 Mdot
.0986 .01538 Mdot
.09863 .01879 Mdot
.09866 .02019 Mdot
.09868 .02039 Mdot
.09871 .01902 Mdot
.09873 .01691 Mdot
.09876 .01636 Mdot
.09878 .01897 Mdot
.09881 .01993 Mdot
.09884 .0169 Mdot
.09886 .02028 Mdot
.09889 .01786 Mdot
.09891 .01751 Mdot
.09894 .01801 Mdot
.09897 .01736 Mdot
.09899 .01596 Mdot
.09902 .01517 Mdot
.09904 .01902 Mdot
.09907 .01685 Mdot
.09909 .01775 Mdot
.09912 .01736 Mdot
.09915 .01588 Mdot
.09917 .0168 Mdot
.0992 .01721 Mdot
.09922 .01651 Mdot
.09925 .01629 Mdot
.09928 .01548 Mdot
.0993 .01717 Mdot
.09933 .01657 Mdot
.09935 .01879 Mdot
.09938 .01808 Mdot
.0994 .01607 Mdot
.09943 .01567 Mdot
.09946 .02086 Mdot
.09948 .02036 Mdot
.09951 .01893 Mdot
.09953 .01748 Mdot
.09956 .01759 Mdot
.09959 .01943 Mdot
.09961 .01891 Mdot
.09964 .01905 Mdot
.09966 .01922 Mdot
.09969 .01566 Mdot
.09971 .01888 Mdot
.09974 .01784 Mdot
.09977 .01764 Mdot
.09979 .01486 Mdot
.09982 .01693 Mdot
.09984 .01621 Mdot
.09987 .01567 Mdot
.0999 .01733 Mdot
.09992 .01816 Mdot
.09995 .01549 Mdot
.09997 .01652 Mdot
.1 .01558 Mdot
.10002 .01668 Mdot
.10005 .01686 Mdot
.10008 .01718 Mdot
.1001 .01601 Mdot
.10013 .01585 Mdot
.10015 .01547 Mdot
.10018 .01622 Mdot
.10021 .01737 Mdot
.10023 .01622 Mdot
.10026 .01717 Mdot
.10028 .01765 Mdot
.10031 .01746 Mdot
.10033 .01601 Mdot
.10036 .01565 Mdot
.10039 .01577 Mdot
.10041 .0157 Mdot
.10044 .01722 Mdot
.10046 .01717 Mdot
.10049 .01586 Mdot
.10052 .01708 Mdot
.10054 .01622 Mdot
.10057 .0157 Mdot
.10059 .01636 Mdot
.10062 .01636 Mdot
.10064 .01741 Mdot
.10067 .01474 Mdot
.1007 .01532 Mdot
.10072 .01737 Mdot
.10075 .0161 Mdot
.10077 .01582 Mdot
.1008 .01592 Mdot
.10083 .0163 Mdot
.10085 .01698 Mdot
.10088 .0165 Mdot
.1009 .0152 Mdot
.10093 .01672 Mdot
.10095 .01592 Mdot
.10098 .01604 Mdot
.10101 .01529 Mdot
.10103 .01711 Mdot
.10106 .01584 Mdot
.10108 .0176 Mdot
.10111 .01578 Mdot
.10114 .01691 Mdot
.10116 .01667 Mdot
.10119 .01849 Mdot
.10121 .01605 Mdot
.10124 .01772 Mdot
.10126 .01574 Mdot
.10129 .01628 Mdot
.10132 .01644 Mdot
.10134 .01605 Mdot
.10137 .0162 Mdot
.10139 .01646 Mdot
.10142 .01657 Mdot
.10145 .0169 Mdot
.10147 .01603 Mdot
.1015 .01538 Mdot
.10152 .01477 Mdot
.10155 .02396 Mdot
.10157 .01837 Mdot
.1016 .01647 Mdot
.10163 .01841 Mdot
.10165 .01633 Mdot
.10168 .01544 Mdot
.1017 .01537 Mdot
.10173 .0157 Mdot
.10176 .01774 Mdot
.10178 .01669 Mdot
.10181 .01507 Mdot
.10183 .01633 Mdot
.10186 .01549 Mdot
.10188 .01636 Mdot
.10191 .01609 Mdot
.10194 .0154 Mdot
.10196 .01583 Mdot
.10199 .01488 Mdot
.10201 .01511 Mdot
.10204 .01561 Mdot
.10207 .01593 Mdot
.10209 .01592 Mdot
.10212 .01513 Mdot
.10214 .01542 Mdot
.10217 .01564 Mdot
.1022 .01662 Mdot
.10222 .01653 Mdot
.10225 .01641 Mdot
.10227 .01488 Mdot
.1023 .01566 Mdot
.10232 .01554 Mdot
.10235 .01597 Mdot
.10238 .01579 Mdot
.1024 .01522 Mdot
.10243 .01549 Mdot
.10245 .01519 Mdot
.10248 .0162 Mdot
.10251 .01673 Mdot
.10253 .01521 Mdot
.10256 .01517 Mdot
.10258 .0157 Mdot
.10261 .01543 Mdot
.10263 .01579 Mdot
.10266 .0174 Mdot
.10269 .01631 Mdot
.10271 .01547 Mdot
.10274 .01699 Mdot
.10276 .01556 Mdot
.10279 .01715 Mdot
.10282 .0154 Mdot
.10284 .01496 Mdot
.10287 .01674 Mdot
.10289 .01536 Mdot
.10292 .0156 Mdot
.10294 .0185 Mdot
.10297 .01701 Mdot
.103 .01561 Mdot
.10302 .01675 Mdot
.10305 .01601 Mdot
.10307 .01675 Mdot
.1031 .0178 Mdot
.10313 .01687 Mdot
.10315 .01538 Mdot
.10318 .01634 Mdot
.1032 .01622 Mdot
.10323 .01578 Mdot
.10325 .01529 Mdot
.10328 .01507 Mdot
.10331 .01593 Mdot
.10333 .01652 Mdot
.10336 .01606 Mdot
.10338 .01728 Mdot
.10341 .01615 Mdot
.10344 .0163 Mdot
.10346 .01676 Mdot
.10349 .01584 Mdot
.10351 .01539 Mdot
.10354 .01631 Mdot
.10356 .01677 Mdot
.10359 .01496 Mdot
.10362 .01687 Mdot
.10364 .01686 Mdot
.10367 .01752 Mdot
.10369 .0152 Mdot
.10372 .01642 Mdot
.10375 .01665 Mdot
.10377 .01662 Mdot
.1038 .01681 Mdot
.10382 .01773 Mdot
.10385 .01671 Mdot
.10387 .0157 Mdot
.1039 .01555 Mdot
.10393 .01763 Mdot
.10395 .01657 Mdot
.10398 .01595 Mdot
.104 .01531 Mdot
.10403 .01844 Mdot
.10406 .01947 Mdot
.10408 .0184 Mdot
.10411 .01585 Mdot
.10413 .01859 Mdot
.10416 .02227 Mdot
.10418 .01864 Mdot
.10421 .01627 Mdot
.10424 .01955 Mdot
.10426 .02254 Mdot
.10429 .02154 Mdot
.10431 .01626 Mdot
.10434 .01876 Mdot
.10437 .02022 Mdot
.10439 .0213 Mdot
.10442 .01861 Mdot
.10444 .01875 Mdot
.10447 .02099 Mdot
.10449 .01864 Mdot
.10452 .01957 Mdot
.10455 .01652 Mdot
.10457 .01566 Mdot
.1046 .01835 Mdot
.10462 .01486 Mdot
.10465 .01737 Mdot
.10468 .01739 Mdot
.1047 .01716 Mdot
.10473 .01712 Mdot
.10475 .01482 Mdot
.10478 .01681 Mdot
.1048 .01818 Mdot
.10483 .02177 Mdot
.10486 .01943 Mdot
.10488 .01566 Mdot
.10491 .02147 Mdot
.10493 .02088 Mdot
.10496 .01798 Mdot
.10499 .0199 Mdot
.10501 .02034 Mdot
.10504 .01609 Mdot
.10506 .01691 Mdot
.10509 .01655 Mdot
.10511 .01644 Mdot
.10514 .01774 Mdot
.10517 .01964 Mdot
.10519 .02091 Mdot
.10522 .01932 Mdot
.10524 .01963 Mdot
.10527 .01795 Mdot
.1053 .015 Mdot
.10532 .01708 Mdot
.10535 .01827 Mdot
.10537 .01756 Mdot
.1054 .01593 Mdot
.10542 .01929 Mdot
.10545 .02341 Mdot
.10548 .02159 Mdot
.1055 .01666 Mdot
.10553 .01975 Mdot
.10555 .01618 Mdot
.10558 .01725 Mdot
.10561 .01577 Mdot
.10563 .01788 Mdot
.10566 .01726 Mdot
.10568 .01626 Mdot
.10571 .01746 Mdot
.10573 .02032 Mdot
.10576 .02125 Mdot
.10579 .02113 Mdot
.10581 .01647 Mdot
.10584 .01663 Mdot
.10586 .0215 Mdot
.10589 .02228 Mdot
.10592 .02077 Mdot
.10594 .0172 Mdot
.10597 .01608 Mdot
.10599 .01663 Mdot
.10602 .02237 Mdot
.10604 .02087 Mdot
.10607 .01916 Mdot
.1061 .01657 Mdot
.10612 .01899 Mdot
.10615 .01814 Mdot
.10617 .01898 Mdot
.1062 .01801 Mdot
.10623 .01997 Mdot
.10625 .016 Mdot
.10628 .01667 Mdot
.1063 .01617 Mdot
.10633 .01548 Mdot
.10635 .016 Mdot
.10638 .01571 Mdot
.10641 .0164 Mdot
.10643 .01604 Mdot
.10646 .01761 Mdot
.10648 .01679 Mdot
.10651 .01659 Mdot
.10654 .01584 Mdot
.10656 .01657 Mdot
.10659 .01617 Mdot
.10661 .0158 Mdot
.10664 .01527 Mdot
.10666 .01601 Mdot
.10669 .01665 Mdot
.10672 .01872 Mdot
.10674 .01864 Mdot
.10677 .01889 Mdot
.10679 .0166 Mdot
.10682 .01598 Mdot
.10685 .01493 Mdot
.10687 .01771 Mdot
.1069 .01804 Mdot
.10692 .01649 Mdot
.10695 .01674 Mdot
.10697 .01537 Mdot
.107 .0189 Mdot
.10703 .01936 Mdot
.10705 .01532 Mdot
.10708 .01655 Mdot
.1071 .01698 Mdot
.10713 .01538 Mdot
.10716 .01765 Mdot
.10718 .01624 Mdot
.10721 .01782 Mdot
.10723 .01665 Mdot
.10726 .01524 Mdot
.10728 .01524 Mdot
.10731 .01514 Mdot
.10734 .0163 Mdot
.10736 .0162 Mdot
.10739 .01492 Mdot
.10741 .01772 Mdot
.10744 .01592 Mdot
.10747 .0151 Mdot
.10749 .01515 Mdot
.10752 .01558 Mdot
.10754 .01576 Mdot
.10757 .01666 Mdot
.10759 .01552 Mdot
.10762 .01666 Mdot
.10765 .01586 Mdot
.10767 .01768 Mdot
.1077 .01603 Mdot
.10772 .01563 Mdot
.10775 .01642 Mdot
.10778 .01592 Mdot
.1078 .01666 Mdot
.10783 .01644 Mdot
.10785 .0176 Mdot
.10788 .01686 Mdot
.1079 .01658 Mdot
.10793 .0177 Mdot
.10796 .01867 Mdot
.10798 .01877 Mdot
.10801 .01707 Mdot
.10803 .01658 Mdot
.10806 .01774 Mdot
.10809 .01612 Mdot
.10811 .01669 Mdot
.10814 .01658 Mdot
.10816 .01607 Mdot
.10819 .01741 Mdot
.10821 .0161 Mdot
.10824 .01777 Mdot
.10827 .01697 Mdot
.10829 .01584 Mdot
.10832 .01795 Mdot
.10834 .01568 Mdot
.10837 .01539 Mdot
.1084 .0156 Mdot
.10842 .01619 Mdot
.10845 .01508 Mdot
.10847 .01535 Mdot
.1085 .01663 Mdot
.10852 .01684 Mdot
.10855 .01526 Mdot
.10858 .01584 Mdot
.1086 .01682 Mdot
.10863 .0174 Mdot
.10865 .01653 Mdot
.10868 .0157 Mdot
.10871 .01677 Mdot
.10873 .01606 Mdot
.10876 .01622 Mdot
.10878 .0168 Mdot
.10881 .01643 Mdot
.10883 .01596 Mdot
.10886 .01507 Mdot
.10889 .01509 Mdot
.10891 .01619 Mdot
.10894 .01683 Mdot
.10896 .01516 Mdot
.10899 .01658 Mdot
.10902 .01604 Mdot
.10904 .01564 Mdot
.10907 .01643 Mdot
.10909 .01568 Mdot
.10912 .01526 Mdot
.10914 .01716 Mdot
.10917 .01742 Mdot
.1092 .01488 Mdot
.10922 .01774 Mdot
.10925 .01726 Mdot
.10927 .01593 Mdot
.1093 .01761 Mdot
.10933 .01687 Mdot
.10935 .01623 Mdot
.10938 .01617 Mdot
.1094 .01821 Mdot
.10943 .01943 Mdot
.10945 .01526 Mdot
.10948 .01614 Mdot
.10951 .01703 Mdot
.10953 .01777 Mdot
.10956 .01661 Mdot
.10958 .01486 Mdot
.10961 .01509 Mdot
.10964 .01533 Mdot
.10966 .01603 Mdot
.10969 .01522 Mdot
.10971 .01631 Mdot
.10974 .01699 Mdot
.10976 .01597 Mdot
.10979 .01749 Mdot
.10982 .01629 Mdot
.10984 .01633 Mdot
.10987 .01629 Mdot
.10989 .01788 Mdot
.10992 .01842 Mdot
.10995 .01561 Mdot
.10997 .01574 Mdot
.11 .01504 Mdot
.11002 .01649 Mdot
.11005 .01534 Mdot
.11007 .01697 Mdot
.1101 .01786 Mdot
.11013 .01539 Mdot
.11015 .01657 Mdot
.11018 .01712 Mdot
.1102 .02158 Mdot
.11023 .01507 Mdot
.11026 .01774 Mdot
.11028 .01813 Mdot
.11031 .02066 Mdot
.11033 .01984 Mdot
.11036 .01744 Mdot
.11038 .01976 Mdot
.11041 .02246 Mdot
.11044 .01881 Mdot
.11046 .01852 Mdot
.11049 .02281 Mdot
.11051 .02397 Mdot
.11054 .01762 Mdot
.11057 .01931 Mdot
.11059 .01864 Mdot
.11062 .0224 Mdot
.11064 .02381 Mdot
.11067 .0186 Mdot
.11069 .02142 Mdot
.11072 .02233 Mdot
.11075 .01852 Mdot
.11077 .02251 Mdot
.1108 .01925 Mdot
.11082 .01828 Mdot
.11085 .01713 Mdot
.11088 .01686 Mdot
.1109 .01793 Mdot
.11093 .01826 Mdot
.11095 .02017 Mdot
.11098 .01901 Mdot
.111 .01711 Mdot
.11103 .01906 Mdot
.11106 .02294 Mdot
.11108 .02346 Mdot
.11111 .02264 Mdot
.11113 .01842 Mdot
.11116 .01765 Mdot
.11119 .02517 Mdot
.11121 .01962 Mdot
.11124 .02213 Mdot
.11126 .02151 Mdot
.11129 .01919 Mdot
.11131 .01985 Mdot
.11134 .0174 Mdot
.11137 .01644 Mdot
.11139 .01994 Mdot
.11142 .02221 Mdot
.11144 .02413 Mdot
.11147 .02132 Mdot
.1115 .02545 Mdot
.11152 .02205 Mdot
.11155 .02112 Mdot
.11157 .01925 Mdot
.1116 .01889 Mdot
.11163 .01803 Mdot
.11165 .01652 Mdot
.11168 .02257 Mdot
.1117 .02443 Mdot
.11173 .02464 Mdot
.11175 .01956 Mdot
.11178 .0204 Mdot
.11181 .01731 Mdot
.11183 .01875 Mdot
.11186 .0188 Mdot
.11188 .01647 Mdot
.11191 .02307 Mdot
.11194 .01705 Mdot
.11196 .0197 Mdot
.11199 .02101 Mdot
.11201 .02367 Mdot
.11204 .02357 Mdot
.11206 .01836 Mdot
.11209 .01901 Mdot
.11212 .0258 Mdot
.11214 .02756 Mdot
.11217 .0227 Mdot
.11219 .01831 Mdot
.11222 .01719 Mdot
.11225 .02148 Mdot
.11227 .02213 Mdot
.1123 .02205 Mdot
.11232 .02142 Mdot
.11235 .02306 Mdot
.11237 .01766 Mdot
.1124 .02138 Mdot
.11243 .02002 Mdot
.11245 .01987 Mdot
.11248 .01616 Mdot
.1125 .02001 Mdot
.11253 .02067 Mdot
.11256 .019 Mdot
.11258 .01918 Mdot
.11261 .01708 Mdot
.11263 .01602 Mdot
.11266 .01753 Mdot
.11268 .0166 Mdot
.11271 .01743 Mdot
.11274 .01559 Mdot
.11276 .01684 Mdot
.11279 .01486 Mdot
.11281 .01795 Mdot
.11284 .01643 Mdot
.11287 .01569 Mdot
.11289 .01583 Mdot
.11292 .01583 Mdot
.11294 .01547 Mdot
.11297 .01523 Mdot
.11299 .01681 Mdot
.11302 .01544 Mdot
.11305 .01719 Mdot
.11307 .01597 Mdot
.1131 .0162 Mdot
.11312 .01565 Mdot
.11315 .01542 Mdot
.11318 .01845 Mdot
.1132 .01637 Mdot
.11323 .01544 Mdot
.11325 .01622 Mdot
.11328 .01631 Mdot
.1133 .01571 Mdot
.11333 .01704 Mdot
.11336 .01536 Mdot
.11338 .01602 Mdot
.11341 .01845 Mdot
.11343 .01594 Mdot
.11346 .01756 Mdot
.11349 .01525 Mdot
.11351 .01729 Mdot
.11354 .016 Mdot
.11356 .01609 Mdot
.11359 .01582 Mdot
.11361 .01628 Mdot
.11364 .01623 Mdot
.11367 .01694 Mdot
.11369 .01689 Mdot
.11372 .01582 Mdot
.11374 .01724 Mdot
.11377 .01565 Mdot
.1138 .01608 Mdot
.11382 .01702 Mdot
.11385 .01634 Mdot
.11387 .01739 Mdot
.1139 .01715 Mdot
.11392 .01494 Mdot
.11395 .01637 Mdot
.11398 .01651 Mdot
.114 .01641 Mdot
.11403 .01731 Mdot
.11405 .01827 Mdot
.11408 .01548 Mdot
.11411 .01567 Mdot
.11413 .01603 Mdot
.11416 .01814 Mdot
.11418 .01665 Mdot
.11421 .01657 Mdot
.11423 .0179 Mdot
.11426 .01586 Mdot
.11429 .01723 Mdot
.11431 .01508 Mdot
.11434 .01684 Mdot
.11436 .01751 Mdot
.11439 .01665 Mdot
.11442 .01601 Mdot
.11444 .01795 Mdot
.11447 .01745 Mdot
.11449 .01495 Mdot
.11452 .0189 Mdot
.11454 .01833 Mdot
.11457 .0213 Mdot
.1146 .01792 Mdot
.11462 .01909 Mdot
.11465 .01744 Mdot
.11467 .02124 Mdot
.1147 .01685 Mdot
.11473 .01533 Mdot
.11475 .01697 Mdot
.11478 .01608 Mdot
.1148 .01694 Mdot
.11483 .01609 Mdot
.11485 .01492 Mdot
.11488 .01554 Mdot
.11491 .01671 Mdot
.11493 .0165 Mdot
.11496 .01605 Mdot
.11498 .01546 Mdot
.11501 .01612 Mdot
.11504 .01566 Mdot
.11506 .01594 Mdot
.11509 .01595 Mdot
.11511 .01666 Mdot
.11514 .01685 Mdot
.11516 .01723 Mdot
.11519 .01558 Mdot
.11522 .01774 Mdot
.11524 .01629 Mdot
.11527 .01559 Mdot
.11529 .01652 Mdot
.11532 .01475 Mdot
.11535 .01539 Mdot
.11537 .01672 Mdot
.1154 .01541 Mdot
.11542 .01658 Mdot
.11545 .01643 Mdot
.11547 .01634 Mdot
.1155 .0166 Mdot
.11553 .01643 Mdot
.11555 .01653 Mdot
.11558 .015 Mdot
.1156 .016 Mdot
.11563 .01623 Mdot
.11566 .01698 Mdot
.11568 .01613 Mdot
.11571 .01663 Mdot
.11573 .01524 Mdot
.11576 .01793 Mdot
.11578 .01639 Mdot
.11581 .01648 Mdot
.11584 .01685 Mdot
.11586 .01645 Mdot
.11589 .01781 Mdot
.11591 .01634 Mdot
.11594 .01512 Mdot
.11597 .01685 Mdot
.11599 .01611 Mdot
.11602 .01588 Mdot
.11604 .0157 Mdot
.11607 .0152 Mdot
.11609 .01517 Mdot
.11612 .01517 Mdot
.11615 .01671 Mdot
.11617 .01488 Mdot
.1162 .01658 Mdot
.11622 .01947 Mdot
.11625 .01552 Mdot
.11628 .01755 Mdot
.1163 .01709 Mdot
.11633 .01865 Mdot
.11635 .01786 Mdot
.11638 .0187 Mdot
.1164 .01563 Mdot
.11643 .01708 Mdot
.11646 .01954 Mdot
.11648 .01627 Mdot
.11651 .01772 Mdot
.11653 .02039 Mdot
.11656 .02135 Mdot
.11659 .02331 Mdot
.11661 .01723 Mdot
.11664 .02122 Mdot
.11666 .02251 Mdot
.11669 .01897 Mdot
.11671 .0182 Mdot
.11674 .01794 Mdot
.11677 .02248 Mdot
.11679 .02374 Mdot
.11682 .02087 Mdot
.11684 .01685 Mdot
.11687 .0182 Mdot
.1169 .02028 Mdot
.11692 .01802 Mdot
.11695 .02499 Mdot
.11697 .01672 Mdot
.117 .01709 Mdot
.11702 .01666 Mdot
.11705 .01659 Mdot
.11708 .02337 Mdot
.1171 .0219 Mdot
.11713 .01791 Mdot
.11715 .01732 Mdot
.11718 .0153 Mdot
.11721 .02449 Mdot
.11723 .02442 Mdot
.11726 .02061 Mdot
.11728 .01918 Mdot
.11731 .02074 Mdot
.11733 .02172 Mdot
.11736 .02531 Mdot
.11739 .02258 Mdot
.11741 .01992 Mdot
.11744 .02383 Mdot
.11746 .02082 Mdot
.11749 .01868 Mdot
.11752 .01876 Mdot
.11754 .02382 Mdot
.11757 .02252 Mdot
.11759 .02149 Mdot
.11762 .01971 Mdot
.11764 .01714 Mdot
.11767 .01825 Mdot
.1177 .02383 Mdot
.11772 .02364 Mdot
.11775 .02134 Mdot
.11777 .01969 Mdot
.1178 .02358 Mdot
.11783 .02126 Mdot
.11785 .01983 Mdot
.11788 .01926 Mdot
.1179 .01978 Mdot
.11793 .01563 Mdot
.11795 .01843 Mdot
.11798 .02105 Mdot
.11801 .02054 Mdot
.11803 .01935 Mdot
.11806 .01613 Mdot
.11808 .02144 Mdot
.11811 .02318 Mdot
.11814 .01831 Mdot
.11816 .01898 Mdot
.11819 .01943 Mdot
.11821 .01908 Mdot
.11824 .02097 Mdot
.11826 .01747 Mdot
.11829 .01795 Mdot
.11832 .02041 Mdot
.11834 .01529 Mdot
.11837 .02236 Mdot
.11839 .02352 Mdot
.11842 .02583 Mdot
.11845 .0224 Mdot
.11847 .01837 Mdot
.1185 .01804 Mdot
.11852 .02097 Mdot
.11855 .02552 Mdot
.11857 .02219 Mdot
.1186 .02035 Mdot
.11863 .01934 Mdot
.11865 .01872 Mdot
.11868 .02152 Mdot
.1187 .02036 Mdot
.11873 .0205 Mdot
.11876 .0168 Mdot
.11878 .0182 Mdot
.11881 .01902 Mdot
.11883 .01856 Mdot
.11886 .0198 Mdot
.11888 .01965 Mdot
.11891 .0163 Mdot
.11894 .01604 Mdot
.11896 .01765 Mdot
.11899 .01989 Mdot
.11901 .01551 Mdot
.11904 .0185 Mdot
.11907 .01507 Mdot
.11909 .01625 Mdot
.11912 .01764 Mdot
.11914 .01992 Mdot
.11917 .01683 Mdot
.11919 .01566 Mdot
.11922 .01518 Mdot
.11925 .01547 Mdot
.11927 .01672 Mdot
.1193 .01519 Mdot
.11932 .01608 Mdot
.11935 .01498 Mdot
.11938 .01593 Mdot
.1194 .01694 Mdot
.11943 .01598 Mdot
.11945 .01762 Mdot
.11948 .01599 Mdot
.1195 .01564 Mdot
.11953 .01585 Mdot
.11956 .01573 Mdot
.11958 .01596 Mdot
.11961 .01651 Mdot
.11963 .01703 Mdot
.11966 .01672 Mdot
.11969 .01946 Mdot
.11971 .01709 Mdot
.11974 .01931 Mdot
.11976 .018 Mdot
.11979 .01876 Mdot
.11981 .01744 Mdot
.11984 .01842 Mdot
.11987 .01633 Mdot
.11989 .01587 Mdot
.11992 .01628 Mdot
.11994 .01642 Mdot
.11997 .01641 Mdot
.12 .01558 Mdot
.12002 .01574 Mdot
.12005 .01636 Mdot
.12007 .01555 Mdot
.1201 .01759 Mdot
.12012 .0169 Mdot
.12015 .01586 Mdot
.12018 .01618 Mdot
.1202 .01686 Mdot
.12023 .01697 Mdot
.12025 .01548 Mdot
.12028 .01544 Mdot
.12031 .01677 Mdot
.12033 .01615 Mdot
.12036 .01508 Mdot
.12038 .01574 Mdot
.12041 .01617 Mdot
.12043 .01547 Mdot
.12046 .01672 Mdot
.12049 .01832 Mdot
.12051 .01708 Mdot
.12054 .01578 Mdot
.12056 .01677 Mdot
.12059 .01528 Mdot
.12062 .01672 Mdot
.12064 .01563 Mdot
.12067 .01634 Mdot
.12069 .01623 Mdot
.12072 .01585 Mdot
.12075 .01709 Mdot
.12077 .0173 Mdot
.1208 .01626 Mdot
.12082 .01574 Mdot
.12085 .0178 Mdot
.12087 .01592 Mdot
.1209 .01538 Mdot
.12093 .01608 Mdot
.12095 .01507 Mdot
.12098 .01762 Mdot
.121 .01655 Mdot
.12103 .01645 Mdot
.12106 .01639 Mdot
.12108 .01528 Mdot
.12111 .0161 Mdot
.12113 .01597 Mdot
.12116 .01653 Mdot
.12118 .0176 Mdot
.12121 .01602 Mdot
.12124 .0172 Mdot
.12126 .01742 Mdot
.12129 .01778 Mdot
.12131 .01613 Mdot
.12134 .01628 Mdot
.12137 .01697 Mdot
.12139 .01601 Mdot
.12142 .0163 Mdot
.12144 .01535 Mdot
.12147 .01539 Mdot
.12149 .01554 Mdot
.12152 .0157 Mdot
.12155 .01567 Mdot
.12157 .01651 Mdot
.1216 .01525 Mdot
.12162 .01841 Mdot
.12165 .01667 Mdot
.12168 .01767 Mdot
.1217 .01875 Mdot
.12173 .01573 Mdot
.12175 .01607 Mdot
.12178 .01694 Mdot
.1218 .01672 Mdot
.12183 .01621 Mdot
.12186 .01598 Mdot
.12188 .01618 Mdot
.12191 .01686 Mdot
.12193 .01548 Mdot
.12196 .01586 Mdot
.12199 .01694 Mdot
.12201 .01562 Mdot
.12204 .01716 Mdot
.12206 .01598 Mdot
.12209 .01589 Mdot
.12211 .01667 Mdot
.12214 .01838 Mdot
.12217 .01829 Mdot
.12219 .01604 Mdot
.12222 .01829 Mdot
.12224 .01531 Mdot
.12227 .01894 Mdot
.1223 .02054 Mdot
.12232 .01851 Mdot
.12235 .01619 Mdot
.12237 .01882 Mdot
.1224 .01585 Mdot
.12242 .01681 Mdot
.12245 .01905 Mdot
.12248 .02226 Mdot
.1225 .02119 Mdot
.12253 .01756 Mdot
.12255 .01721 Mdot
.12258 .02242 Mdot
.12261 .0225 Mdot
.12263 .02288 Mdot
.12266 .01565 Mdot
.12268 .02417 Mdot
.12271 .02482 Mdot
.12273 .02043 Mdot
.12276 .0188 Mdot
.12279 .02212 Mdot
.12281 .02412 Mdot
.12284 .02431 Mdot
.12286 .02367 Mdot
.12289 .02387 Mdot
.12292 .02526 Mdot
.12294 .02168 Mdot
.12297 .01836 Mdot
.12299 .02202 Mdot
.12302 .02198 Mdot
.12304 .02355 Mdot
.12307 .02024 Mdot
.1231 .01556 Mdot
.12312 .02147 Mdot
.12315 .02169 Mdot
.12317 .0223 Mdot
.1232 .02047 Mdot
.12323 .01675 Mdot
.12325 .01718 Mdot
.12328 .01771 Mdot
.1233 .02104 Mdot
.12333 .02229 Mdot
.12335 .02433 Mdot
.12338 .01878 Mdot
.12341 .01984 Mdot
.12343 .01811 Mdot
.12346 .02379 Mdot
.12348 .02759 Mdot
.12351 .02279 Mdot
.12354 .02338 Mdot
.12356 .02055 Mdot
.12359 .02211 Mdot
.12361 .02448 Mdot
.12364 .02779 Mdot
.12366 .02391 Mdot
.12369 .02184 Mdot
.12372 .02465 Mdot
.12374 .01788 Mdot
.12377 .01693 Mdot
.12379 .02419 Mdot
.12382 .03067 Mdot
.12385 .02743 Mdot
.12387 .02538 Mdot
.1239 .02269 Mdot
.12392 .01877 Mdot
.12395 .01763 Mdot
.12397 .01876 Mdot
.124 .01843 Mdot
.12403 .02079 Mdot
.12405 .02457 Mdot
.12408 .02781 Mdot
.1241 .0287 Mdot
.12413 .02804 Mdot
.12416 .02824 Mdot
.12418 .02149 Mdot
.12421 .01922 Mdot
.12423 .02436 Mdot
.12426 .0228 Mdot
.12428 .01834 Mdot
.12431 .01793 Mdot
.12434 .03053 Mdot
.12436 .03566 Mdot
.12439 .03482 Mdot
.12441 .03108 Mdot
.12444 .02442 Mdot
.12447 .02501 Mdot
.12449 .02438 Mdot
.12452 .0197 Mdot
.12454 .02215 Mdot
.12457 .02516 Mdot
.12459 .02257 Mdot
.12462 .02635 Mdot
.12465 .03346 Mdot
.12467 .03577 Mdot
.1247 .03238 Mdot
.12472 .02171 Mdot
.12475 .0174 Mdot
.12478 .03242 Mdot
.1248 .03798 Mdot
.12483 .03607 Mdot
.12485 .03132 Mdot
.12488 .02161 Mdot
.1249 .02732 Mdot
.12493 .02873 Mdot
.12496 .03503 Mdot
.12498 .03031 Mdot
.12501 .02763 Mdot
.12503 .02699 Mdot
.12506 .02762 Mdot
.12509 .0288 Mdot
.12511 .02978 Mdot
.12514 .02739 Mdot
.12516 .02629 Mdot
.12519 .02351 Mdot
.12521 .02614 Mdot
.12524 .0252 Mdot
.12527 .02394 Mdot
.12529 .02234 Mdot
.12532 .02151 Mdot
.12534 .02237 Mdot
.12537 .02163 Mdot
.1254 .02004 Mdot
.12542 .01952 Mdot
.12545 .01563 Mdot
.12547 .01891 Mdot
.1255 .02054 Mdot
.12552 .01926 Mdot
.12555 .01575 Mdot
.12558 .01612 Mdot
.1256 .01779 Mdot
.12563 .01772 Mdot
.12565 .01722 Mdot
.12568 .01692 Mdot
.12571 .0192 Mdot
.12573 .01653 Mdot
.12576 .01594 Mdot
.12578 .01856 Mdot
.12581 .01706 Mdot
.12583 .01701 Mdot
.12586 .01729 Mdot
.12589 .01683 Mdot
.12591 .01841 Mdot
.12594 .01587 Mdot
.12596 .01687 Mdot
.12599 .01807 Mdot
.12602 .01695 Mdot
.12604 .01553 Mdot
.12607 .01546 Mdot
.12609 .01793 Mdot
.12612 .01981 Mdot
.12614 .0161 Mdot
.12617 .01543 Mdot
.1262 .01719 Mdot
.12622 .01588 Mdot
.12625 .01802 Mdot
.12627 .02134 Mdot
.1263 .01634 Mdot
.12633 .01646 Mdot
.12635 .01714 Mdot
.12638 .0164 Mdot
.1264 .01594 Mdot
.12643 .01614 Mdot
.12645 .01561 Mdot
.12648 .01588 Mdot
.12651 .01689 Mdot
.12653 .01738 Mdot
.12656 .01582 Mdot
.12658 .018 Mdot
.12661 .01532 Mdot
.12664 .01578 Mdot
.12666 .01553 Mdot
.12669 .01815 Mdot
.12671 .01861 Mdot
.12674 .01816 Mdot
.12676 .01735 Mdot
.12679 .01591 Mdot
.12682 .01653 Mdot
.12684 .01762 Mdot
.12687 .01716 Mdot
.12689 .01994 Mdot
.12692 .01822 Mdot
.12695 .01834 Mdot
.12697 .02053 Mdot
.127 .01986 Mdot
.12702 .01701 Mdot
.12705 .01711 Mdot
.12707 .01901 Mdot
.1271 .01772 Mdot
.12713 .01787 Mdot
.12715 .01715 Mdot
.12718 .01618 Mdot
.1272 .01589 Mdot
.12723 .01546 Mdot
.12726 .01673 Mdot
.12728 .01653 Mdot
.12731 .0163 Mdot
.12733 .01589 Mdot
.12736 .01553 Mdot
.12738 .01631 Mdot
.12741 .01765 Mdot
.12744 .01888 Mdot
.12746 .01595 Mdot
.12749 .01758 Mdot
.12751 .0152 Mdot
.12754 .01602 Mdot
.12757 .01891 Mdot
.12759 .01727 Mdot
.12762 .01894 Mdot
.12764 .01763 Mdot
.12767 .01573 Mdot
.12769 .01593 Mdot
.12772 .0173 Mdot
.12775 .01528 Mdot
.12777 .01479 Mdot
.1278 .01668 Mdot
.12782 .01673 Mdot
.12785 .01787 Mdot
.12788 .01726 Mdot
.1279 .01587 Mdot
.12793 .01702 Mdot
.12795 .01895 Mdot
.12798 .01677 Mdot
.128 .01603 Mdot
.12803 .01668 Mdot
.12806 .01852 Mdot
.12808 .01863 Mdot
.12811 .01848 Mdot
.12813 .01518 Mdot
.12816 .01741 Mdot
.12819 .01782 Mdot
.12821 .01685 Mdot
.12824 .01825 Mdot
.12826 .01709 Mdot
.12829 .01769 Mdot
.12831 .01544 Mdot
.12834 .02032 Mdot
.12837 .02194 Mdot
.12839 .01695 Mdot
.12842 .0177 Mdot
.12844 .01934 Mdot
.12847 .01583 Mdot
.1285 .01987 Mdot
.12852 .02239 Mdot
.12855 .02147 Mdot
.12857 .01689 Mdot
.1286 .02023 Mdot
.12862 .02629 Mdot
.12865 .02068 Mdot
.12868 .01851 Mdot
.1287 .01979 Mdot
.12873 .0257 Mdot
.12875 .02647 Mdot
.12878 .02377 Mdot
.12881 .01955 Mdot
.12883 .02962 Mdot
.12886 .03038 Mdot
.12888 .02767 Mdot
.12891 .0175 Mdot
.12893 .02682 Mdot
.12896 .0292 Mdot
.12899 .02656 Mdot
.12901 .02092 Mdot
.12904 .02502 Mdot
.12906 .02756 Mdot
.12909 .02867 Mdot
.12912 .02554 Mdot
.12914 .02396 Mdot
.12917 .03182 Mdot
.12919 .02548 Mdot
.12922 .02165 Mdot
.12924 .02091 Mdot
.12927 .02558 Mdot
.1293 .02856 Mdot
.12932 .02837 Mdot
.12935 .01944 Mdot
.12937 .01521 Mdot
.1294 .01675 Mdot
.12943 .0186 Mdot
.12945 .02451 Mdot
.12948 .02523 Mdot
.1295 .02544 Mdot
.12953 .02488 Mdot
.12955 .01804 Mdot
.12958 .02502 Mdot
.12961 .03816 Mdot
.12963 .04231 Mdot
.12966 .03514 Mdot
.12968 .02935 Mdot
.12971 .03242 Mdot
.12974 .04026 Mdot
.12976 .04152 Mdot
.12979 .03214 Mdot
.12981 .03372 Mdot
.12984 .03316 Mdot
.12987 .02572 Mdot
.12989 .028 Mdot
.12992 .03647 Mdot
.12994 .03142 Mdot
.12997 .03458 Mdot
.12999 .03157 Mdot
.13002 .02582 Mdot
.13005 .01607 Mdot
.13007 .03422 Mdot
.1301 .03573 Mdot
.13012 .03685 Mdot
.13015 .03507 Mdot
.13018 .0375 Mdot
.1302 .03031 Mdot
.13023 .02723 Mdot
.13025 .02695 Mdot
.13028 .02124 Mdot
.1303 .02639 Mdot
.13033 .04798 Mdot
.13036 .05066 Mdot
.13038 .04758 Mdot
.13041 .0472 Mdot
.13043 .04506 Mdot
.13046 .03927 Mdot
.13049 .02456 Mdot
.13051 .02181 Mdot
.13054 .02384 Mdot
.13056 .01968 Mdot
.13059 .03344 Mdot
.13061 .04534 Mdot
.13064 .05035 Mdot
.13067 .03887 Mdot
.13069 .03315 Mdot
.13072 .03404 Mdot
.13074 .04102 Mdot
.13077 .03781 Mdot
.1308 .0307 Mdot
.13082 .03763 Mdot
.13085 .03358 Mdot
.13087 .03638 Mdot
.1309 .0302 Mdot
.13092 .02991 Mdot
.13095 .03394 Mdot
.13098 .02959 Mdot
.131 .02069 Mdot
.13103 .03307 Mdot
.13105 .04484 Mdot
.13108 .04657 Mdot
.13111 .0412 Mdot
.13113 .035 Mdot
.13116 .02832 Mdot
.13118 .03711 Mdot
.13121 .04339 Mdot
.13123 .04498 Mdot
.13126 .0365 Mdot
.13129 .02984 Mdot
.13131 .03578 Mdot
.13134 .04374 Mdot
.13136 .04563 Mdot
.13139 .04396 Mdot
.13142 .03855 Mdot
.13144 .03853 Mdot
.13147 .03606 Mdot
.13149 .03853 Mdot
.13152 .03569 Mdot
.13154 .03427 Mdot
.13157 .03064 Mdot
.1316 .0344 Mdot
.13162 .03733 Mdot
.13165 .03352 Mdot
.13167 .02824 Mdot
.1317 .02319 Mdot
.13173 .02195 Mdot
.13175 .02002 Mdot
.13178 .02276 Mdot
.1318 .0228 Mdot
.13183 .02016 Mdot
.13185 .01727 Mdot
.13188 .02004 Mdot
.13191 .02089 Mdot
.13193 .01665 Mdot
.13196 .02389 Mdot
.13198 .02082 Mdot
.13201 .01793 Mdot
.13204 .02001 Mdot
.13206 .02464 Mdot
.13209 .0274 Mdot
.13211 .01948 Mdot
.13214 .01688 Mdot
.13216 .02206 Mdot
.13219 .02362 Mdot
.13222 .01832 Mdot
.13224 .01949 Mdot
.13227 .01793 Mdot
.13229 .0192 Mdot
.13232 .01952 Mdot
.13235 .01809 Mdot
.13237 .02495 Mdot
.1324 .02046 Mdot
.13242 .01816 Mdot
.13245 .02111 Mdot
.13247 .01895 Mdot
.1325 .0188 Mdot
.13253 .0189 Mdot
.13255 .02182 Mdot
.13258 .01925 Mdot
.1326 .02246 Mdot
.13263 .0189 Mdot
.13266 .01828 Mdot
.13268 .02113 Mdot
.13271 .02203 Mdot
.13273 .02022 Mdot
.13276 .02524 Mdot
.13278 .01542 Mdot
.13281 .0241 Mdot
.13284 .02011 Mdot
.13286 .02195 Mdot
.13289 .01938 Mdot
.13291 .01956 Mdot
.13294 .02005 Mdot
.13297 .02244 Mdot
.13299 .02458 Mdot
.13302 .02359 Mdot
.13304 .01653 Mdot
.13307 .0212 Mdot
.13309 .02273 Mdot
.13312 .01902 Mdot
.13315 .01665 Mdot
.13317 .01588 Mdot
.1332 .01771 Mdot
.13322 .02336 Mdot
.13325 .02187 Mdot
.13328 .02357 Mdot
.1333 .02328 Mdot
.13333 .02521 Mdot
.13335 .02347 Mdot
.13338 .02125 Mdot
.1334 .02464 Mdot
.13343 .0228 Mdot
.13346 .02452 Mdot
.13348 .0213 Mdot
.13351 .02206 Mdot
.13353 .01759 Mdot
.13356 .01698 Mdot
.13359 .01974 Mdot
.13361 .02096 Mdot
.13364 .02122 Mdot
.13366 .02789 Mdot
.13369 .03475 Mdot
.13371 .03808 Mdot
.13374 .0304 Mdot
.13377 .03484 Mdot
.13379 .0355 Mdot
.13382 .02823 Mdot
.13384 .02846 Mdot
.13387 .02731 Mdot
.1339 .02943 Mdot
.13392 .02618 Mdot
.13395 .02198 Mdot
.13397 .02551 Mdot
.134 .02427 Mdot
.13402 .02049 Mdot
.13405 .02529 Mdot
.13408 .02566 Mdot
.1341 .02859 Mdot
.13413 .02617 Mdot
.13415 .02272 Mdot
.13418 .02511 Mdot
.13421 .02541 Mdot
.13423 .02077 Mdot
.13426 .01918 Mdot
.13428 .02415 Mdot
.13431 .01923 Mdot
.13433 .01974 Mdot
.13436 .02266 Mdot
.13439 .02607 Mdot
.13441 .03031 Mdot
.13444 .02871 Mdot
.13446 .0279 Mdot
.13449 .0266 Mdot
.13452 .02187 Mdot
.13454 .02666 Mdot
.13457 .02761 Mdot
.13459 .02498 Mdot
.13462 .02541 Mdot
.13464 .02312 Mdot
.13467 .02415 Mdot
.1347 .02746 Mdot
.13472 .02411 Mdot
.13475 .01897 Mdot
.13477 .01847 Mdot
.1348 .0221 Mdot
.13483 .02398 Mdot
.13485 .02436 Mdot
.13488 .03757 Mdot
.1349 .03557 Mdot
.13493 .02559 Mdot
.13495 .02513 Mdot
.13498 .03023 Mdot
.13501 .03246 Mdot
.13503 .03011 Mdot
.13506 .02342 Mdot
.13508 .02702 Mdot
.13511 .03911 Mdot
.13514 .0435 Mdot
.13516 .03653 Mdot
.13519 .02265 Mdot
.13521 .04262 Mdot
.13524 .04122 Mdot
.13526 .029 Mdot
.13529 .02738 Mdot
.13532 .0349 Mdot
.13534 .03485 Mdot
.13537 .03484 Mdot
.13539 .02733 Mdot
.13542 .03202 Mdot
.13545 .02868 Mdot
.13547 .0231 Mdot
.1355 .01775 Mdot
.13552 .02647 Mdot
.13555 .03199 Mdot
.13557 .02603 Mdot
.1356 .02209 Mdot
.13563 .02331 Mdot
.13565 .02431 Mdot
.13568 .01838 Mdot
.1357 .03313 Mdot
.13573 .0345 Mdot
.13576 .02861 Mdot
.13578 .02665 Mdot
.13581 .02871 Mdot
.13583 .01927 Mdot
.13586 .03078 Mdot
.13588 .03918 Mdot
.13591 .03542 Mdot
.13594 .02689 Mdot
.13596 .02443 Mdot
.13599 .02756 Mdot
.13601 .03127 Mdot
.13604 .03411 Mdot
.13607 .0311 Mdot
.13609 .0314 Mdot
.13612 .0222 Mdot
.13614 .01579 Mdot
.13617 .02131 Mdot
.13619 .02604 Mdot
.13622 .03584 Mdot
.13625 .03968 Mdot
.13627 .03025 Mdot
.1363 .02321 Mdot
.13632 .02149 Mdot
.13635 .0229 Mdot
.13638 .02575 Mdot
.1364 .03089 Mdot
.13643 .03151 Mdot
.13645 .02578 Mdot
.13648 .02892 Mdot
.1365 .03331 Mdot
.13653 .03073 Mdot
.13656 .01907 Mdot
.13658 .02038 Mdot
.13661 .02446 Mdot
.13663 .03276 Mdot
.13666 .03556 Mdot
.13669 .03162 Mdot
.13671 .02938 Mdot
.13674 .02955 Mdot
.13676 .03708 Mdot
.13679 .03541 Mdot
.13681 .02664 Mdot
.13684 .02412 Mdot
.13687 .03181 Mdot
.13689 .03288 Mdot
.13692 .03082 Mdot
.13694 .02742 Mdot
.13697 .01841 Mdot
.137 .02479 Mdot
.13702 .03691 Mdot
.13705 .04447 Mdot
.13707 .04046 Mdot
.1371 .02361 Mdot
.13712 .02353 Mdot
.13715 .02498 Mdot
.13718 .02007 Mdot
.1372 .0188 Mdot
.13723 .02176 Mdot
.13725 .02149 Mdot
.13728 .02598 Mdot
.13731 .02986 Mdot
.13733 .02436 Mdot
.13736 .02799 Mdot
.13738 .02549 Mdot
.13741 .01906 Mdot
.13743 .02827 Mdot
.13746 .0305 Mdot
.13749 .03408 Mdot
.13751 .02857 Mdot
.13754 .01891 Mdot
.13756 .02115 Mdot
.13759 .02834 Mdot
.13762 .02902 Mdot
.13764 .02157 Mdot
.13767 .01958 Mdot
.13769 .01936 Mdot
.13772 .02224 Mdot
.13774 .02374 Mdot
.13777 .02561 Mdot
.1378 .02862 Mdot
.13782 .02208 Mdot
.13785 .02333 Mdot
.13787 .02378 Mdot
.1379 .02544 Mdot
.13793 .02206 Mdot
.13795 .0206 Mdot
.13798 .01872 Mdot
.138 .01805 Mdot
.13803 .02248 Mdot
.13805 .0219 Mdot
.13808 .02083 Mdot
.13811 .01766 Mdot
.13813 .0184 Mdot
.13816 .01645 Mdot
.13818 .01623 Mdot
.13821 .01768 Mdot
.13824 .01573 Mdot
.13826 .01951 Mdot
.13829 .01937 Mdot
.13831 .01623 Mdot
.13834 .01913 Mdot
.13836 .01697 Mdot
.13839 .0208 Mdot
.13842 .01671 Mdot
.13844 .01753 Mdot
.13847 .01896 Mdot
.13849 .02023 Mdot
.13852 .01964 Mdot
.13855 .01636 Mdot
.13857 .01644 Mdot
.1386 .01697 Mdot
.13862 .01543 Mdot
.13865 .01632 Mdot
.13867 .01789 Mdot
.1387 .01754 Mdot
.13873 .0176 Mdot
.13875 .01659 Mdot
.13878 .01856 Mdot
.1388 .01696 Mdot
.13883 .01579 Mdot
.13886 .0164 Mdot
.13888 .01775 Mdot
.13891 .02065 Mdot
.13893 .01965 Mdot
.13896 .02062 Mdot
.13899 .02014 Mdot
.13901 .02519 Mdot
.13904 .0201 Mdot
.13906 .01869 Mdot
.13909 .01708 Mdot
.13911 .01909 Mdot
.13914 .01937 Mdot
.13917 .02064 Mdot
.13919 .01735 Mdot
.13922 .01534 Mdot
.13924 .01544 Mdot
.13927 .01655 Mdot
.1393 .01657 Mdot
.13932 .01595 Mdot
.13935 .01736 Mdot
.13937 .01694 Mdot
.1394 .01703 Mdot
.13942 .01847 Mdot
.13945 .02074 Mdot
.13948 .02069 Mdot
.1395 .01675 Mdot
.13953 .01879 Mdot
.13955 .02071 Mdot
.13958 .01846 Mdot
.13961 .02213 Mdot
.13963 .02086 Mdot
.13966 .01693 Mdot
.13968 .01988 Mdot
.13971 .01895 Mdot
.13973 .01946 Mdot
.13976 .0188 Mdot
.13979 .01731 Mdot
.13981 .01647 Mdot
.13984 .01712 Mdot
.13986 .01884 Mdot
.13989 .01925 Mdot
.13992 .01982 Mdot
.13994 .02008 Mdot
.13997 .0181 Mdot
.13999 .01651 Mdot
.14002 .01826 Mdot
.14004 .01872 Mdot
.14007 .01826 Mdot
.1401 .02032 Mdot
.14012 .01709 Mdot
.14015 .01885 Mdot
.14017 .01733 Mdot
.1402 .0193 Mdot
.14023 .02089 Mdot
.14025 .0209 Mdot
.14028 .02018 Mdot
.1403 .02023 Mdot
.14033 .01694 Mdot
.14035 .01947 Mdot
.14038 .02207 Mdot
.14041 .02043 Mdot
.14043 .01686 Mdot
.14046 .02111 Mdot
.14048 .01703 Mdot
.14051 .01846 Mdot
.14054 .01777 Mdot
.14056 .01798 Mdot
.14059 .01626 Mdot
.14061 .01728 Mdot
.14064 .01672 Mdot
.14066 .01634 Mdot
.14069 .01645 Mdot
.14072 .01545 Mdot
.14074 .01743 Mdot
.14077 .02022 Mdot
.14079 .01947 Mdot
.14082 .02163 Mdot
.14085 .02291 Mdot
.14087 .02139 Mdot
.1409 .02187 Mdot
.14092 .01861 Mdot
.14095 .02056 Mdot
.14097 .0186 Mdot
.141 .01943 Mdot
.14103 .01703 Mdot
.14105 .01924 Mdot
.14108 .02023 Mdot
.1411 .0155 Mdot
.14113 .02216 Mdot
.14116 .02399 Mdot
.14118 .02074 Mdot
.14121 .01889 Mdot
.14123 .02194 Mdot
.14126 .02509 Mdot
.14128 .02645 Mdot
.14131 .01718 Mdot
.14134 .02485 Mdot
.14136 .02665 Mdot
.14139 .02202 Mdot
.14141 .01751 Mdot
.14144 .0206 Mdot
.14147 .02094 Mdot
.14149 .02228 Mdot
.14152 .0206 Mdot
.14154 .01912 Mdot
.14157 .02166 Mdot
.14159 .02106 Mdot
.14162 .02086 Mdot
.14165 .01853 Mdot
.14167 .01649 Mdot
.1417 .01776 Mdot
.14172 .01695 Mdot
.14175 .01793 Mdot
.14178 .01601 Mdot
.1418 .01706 Mdot
.14183 .01981 Mdot
.14185 .01806 Mdot
.14188 .01694 Mdot
.1419 .01757 Mdot
.14193 .01781 Mdot
.14196 .01856 Mdot
.14198 .0197 Mdot
.14201 .02081 Mdot
.14203 .02332 Mdot
.14206 .01849 Mdot
.14209 .01873 Mdot
.14211 .01973 Mdot
.14214 .02371 Mdot
.14216 .02222 Mdot
.14219 .02495 Mdot
.14221 .02325 Mdot
.14224 .02292 Mdot
.14227 .022 Mdot
.14229 .02188 Mdot
.14232 .02207 Mdot
.14234 .02167 Mdot
.14237 .01959 Mdot
.1424 .02121 Mdot
.14242 .0186 Mdot
.14245 .01967 Mdot
.14247 .02328 Mdot
.1425 .02074 Mdot
.14252 .02175 Mdot
.14255 .02059 Mdot
.14258 .01913 Mdot
.1426 .01926 Mdot
.14263 .0187 Mdot
.14265 .01605 Mdot
.14268 .01922 Mdot
.14271 .02287 Mdot
.14273 .02245 Mdot
.14276 .02502 Mdot
.14278 .02434 Mdot
.14281 .01986 Mdot
.14283 .0164 Mdot
.14286 .0185 Mdot
.14289 .0206 Mdot
.14291 .0222 Mdot
.14294 .01981 Mdot
.14296 .02187 Mdot
.14299 .02695 Mdot
.14302 .01879 Mdot
.14304 .02299 Mdot
.14307 .02024 Mdot
.14309 .0231 Mdot
.14312 .01908 Mdot
.14314 .01828 Mdot
.14317 .02128 Mdot
.1432 .01591 Mdot
.14322 .02 Mdot
.14325 .0212 Mdot
.14327 .02612 Mdot
.1433 .02481 Mdot
.14333 .02562 Mdot
.14335 .02468 Mdot
.14338 .02653 Mdot
.1434 .02337 Mdot
.14343 .02084 Mdot
.14345 .02005 Mdot
.14348 .02305 Mdot
.14351 .02063 Mdot
.14353 .0223 Mdot
.14356 .02197 Mdot
.14358 .02351 Mdot
.14361 .02161 Mdot
.14364 .02128 Mdot
.14366 .01979 Mdot
.14369 .02686 Mdot
.14371 .02561 Mdot
.14374 .02027 Mdot
.14376 .02383 Mdot
.14379 .02313 Mdot
.14382 .0225 Mdot
.14384 .02165 Mdot
.14387 .02553 Mdot
.14389 .02756 Mdot
.14392 .02392 Mdot
.14395 .0211 Mdot
.14397 .0216 Mdot
.144 .02351 Mdot
.14402 .02288 Mdot
.14405 .02519 Mdot
.14407 .0235 Mdot
.1441 .02315 Mdot
.14413 .02516 Mdot
.14415 .02496 Mdot
.14418 .02375 Mdot
.1442 .02482 Mdot
.14423 .0225 Mdot
.14426 .02148 Mdot
.14428 .02021 Mdot
.14431 .02505 Mdot
.14433 .02146 Mdot
.14436 .02164 Mdot
.14438 .01983 Mdot
.14441 .01825 Mdot
.14444 .01899 Mdot
.14446 .01895 Mdot
.14449 .01735 Mdot
.14451 .01757 Mdot
.14454 .01648 Mdot
.14457 .01834 Mdot
.14459 .02025 Mdot
.14462 .01916 Mdot
.14464 .01616 Mdot
.14467 .01544 Mdot
.14469 .01556 Mdot
.14472 .0179 Mdot
.14475 .016 Mdot
.14477 .01777 Mdot
.1448 .0179 Mdot
.14482 .0164 Mdot
.14485 .01586 Mdot
.14488 .01607 Mdot
.1449 .01663 Mdot
.14493 .01788 Mdot
.14495 .01631 Mdot
.14498 .0185 Mdot
.145 .01966 Mdot
.14503 .01696 Mdot
.14506 .01915 Mdot
.14508 .019 Mdot
.14511 .01541 Mdot
.14513 .01691 Mdot
.14516 .0177 Mdot
.14519 .01854 Mdot
.14521 .01742 Mdot
.14524 .01661 Mdot
.14526 .01585 Mdot
.14529 .01756 Mdot
.14531 .01741 Mdot
.14534 .01754 Mdot
.14537 .01541 Mdot
.14539 .01593 Mdot
.14542 .01932 Mdot
.14544 .0173 Mdot
.14547 .0168 Mdot
.1455 .0182 Mdot
.14552 .01669 Mdot
.14555 .01588 Mdot
.14557 .01679 Mdot
.1456 .0183 Mdot
.14562 .0173 Mdot
.14565 .01659 Mdot
.14568 .01826 Mdot
.1457 .01547 Mdot
.14573 .01727 Mdot
.14575 .01582 Mdot
.14578 .01644 Mdot
.14581 .01576 Mdot
.14583 .0166 Mdot
.14586 .01674 Mdot
.14588 .01657 Mdot
.14591 .01679 Mdot
.14593 .01668 Mdot
.14596 .01725 Mdot
.14599 .01644 Mdot
.14601 .01606 Mdot
.14604 .01496 Mdot
.14606 .01578 Mdot
.14609 .01554 Mdot
.14612 .0168 Mdot
.14614 .01595 Mdot
.14617 .01496 Mdot
.14619 .01807 Mdot
.14622 .01591 Mdot
.14624 .01549 Mdot
.14627 .01633 Mdot
.1463 .01686 Mdot
.14632 .01618 Mdot
.14635 .01678 Mdot
.14637 .01644 Mdot
.1464 .01671 Mdot
.14643 .01569 Mdot
.14645 .01758 Mdot
.14648 .01678 Mdot
.1465 .01995 Mdot
.14653 .02038 Mdot
.14655 .01933 Mdot
.14658 .01925 Mdot
.14661 .01776 Mdot
.14663 .01767 Mdot
.14666 .02087 Mdot
.14668 .01896 Mdot
.14671 .01853 Mdot
.14674 .01908 Mdot
.14676 .02028 Mdot
.14679 .02235 Mdot
.14681 .01912 Mdot
.14684 .02132 Mdot
.14686 .01942 Mdot
.14689 .02108 Mdot
.14692 .01842 Mdot
.14694 .01847 Mdot
.14697 .01874 Mdot
.14699 .01684 Mdot
.14702 .01776 Mdot
.14705 .01677 Mdot
.14707 .01649 Mdot
.1471 .01996 Mdot
.14712 .01748 Mdot
.14715 .01868 Mdot
.14717 .0178 Mdot
.1472 .01643 Mdot
.14723 .01863 Mdot
.14725 .01845 Mdot
.14728 .01813 Mdot
.1473 .01834 Mdot
.14733 .0173 Mdot
.14736 .01536 Mdot
.14738 .01814 Mdot
.14741 .01961 Mdot
.14743 .0186 Mdot
.14746 .01565 Mdot
.14748 .01582 Mdot
.14751 .01999 Mdot
.14754 .02027 Mdot
.14756 .02026 Mdot
.14759 .01526 Mdot
.14761 .02073 Mdot
.14764 .02044 Mdot
.14767 .0181 Mdot
.14769 .0171 Mdot
.14772 .02196 Mdot
.14774 .01829 Mdot
.14777 .01941 Mdot
.14779 .01824 Mdot
.14782 .0177 Mdot
.14785 .0193 Mdot
.14787 .01578 Mdot
.1479 .01696 Mdot
.14792 .01734 Mdot
.14795 .01571 Mdot
.14798 .01538 Mdot
.148 .0177 Mdot
.14803 .01607 Mdot
.14805 .01924 Mdot
.14808 .01599 Mdot
.14811 .01731 Mdot
.14813 .01717 Mdot
.14816 .01828 Mdot
.14818 .02316 Mdot
.14821 .01698 Mdot
.14823 .01871 Mdot
.14826 .01797 Mdot
.14829 .01925 Mdot
.14831 .01913 Mdot
.14834 .0166 Mdot
.14836 .01736 Mdot
.14839 .02123 Mdot
.14842 .01822 Mdot
.14844 .01807 Mdot
.14847 .02107 Mdot
.14849 .02123 Mdot
.14852 .0227 Mdot
.14854 .01822 Mdot
.14857 .02032 Mdot
.1486 .02169 Mdot
.14862 .02016 Mdot
.14865 .02235 Mdot
.14867 .02286 Mdot
.1487 .02092 Mdot
.14873 .01862 Mdot
.14875 .01817 Mdot
.14878 .02116 Mdot
.1488 .02123 Mdot
.14883 .01975 Mdot
.14885 .01844 Mdot
.14888 .01841 Mdot
.14891 .01578 Mdot
.14893 .01621 Mdot
.14896 .01799 Mdot
.14898 .01699 Mdot
.14901 .02018 Mdot
.14904 .02164 Mdot
.14906 .01995 Mdot
.14909 .02034 Mdot
.14911 .01825 Mdot
.14914 .01922 Mdot
.14916 .01921 Mdot
.14919 .01541 Mdot
.14922 .01612 Mdot
.14924 .01823 Mdot
.14927 .01708 Mdot
.14929 .01836 Mdot
.14932 .0209 Mdot
.14935 .01949 Mdot
.14937 .01959 Mdot
.1494 .01816 Mdot
.14942 .01665 Mdot
.14945 .01698 Mdot
.14947 .01529 Mdot
.1495 .01689 Mdot
.14953 .01794 Mdot
.14955 .0159 Mdot
.14958 .01621 Mdot
.1496 .01714 Mdot
.14963 .01898 Mdot
.14966 .01542 Mdot
.14968 .01976 Mdot
.14971 .01749 Mdot
.14973 .01985 Mdot
.14976 .01817 Mdot
.14978 .01755 Mdot
.14981 .01964 Mdot
.14984 .01541 Mdot
.14986 .01612 Mdot
.14989 .01823 Mdot
.14991 .01808 Mdot
.14994 .01536 Mdot
.14997 .0195 Mdot
.14999 .01979 Mdot
.15002 .01845 Mdot
.15004 .01794 Mdot
.15007 .01887 Mdot
.15009 .02163 Mdot
.15012 .02196 Mdot
.15015 .02217 Mdot
.15017 .01956 Mdot
.1502 .0196 Mdot
.15022 .01987 Mdot
.15025 .02034 Mdot
.15028 .01882 Mdot
.1503 .01848 Mdot
.15033 .01995 Mdot
.15035 .01921 Mdot
.15038 .01936 Mdot
.1504 .02305 Mdot
.15043 .02195 Mdot
.15046 .02163 Mdot
.15048 .0177 Mdot
.15051 .02173 Mdot
.15053 .02259 Mdot
.15056 .02016 Mdot
.15059 .0217 Mdot
.15061 .02038 Mdot
.15064 .021 Mdot
.15066 .02122 Mdot
.15069 .01999 Mdot
.15071 .0193 Mdot
.15074 .01504 Mdot
.15077 .01883 Mdot
.15079 .02029 Mdot
.15082 .01568 Mdot
.15084 .01856 Mdot
.15087 .01981 Mdot
.1509 .01603 Mdot
.15092 .01692 Mdot
.15095 .0178 Mdot
.15097 .01676 Mdot
.151 .01602 Mdot
.15102 .01559 Mdot
.15105 .01665 Mdot
.15108 .01791 Mdot
.1511 .01631 Mdot
.15113 .01622 Mdot
.15115 .01681 Mdot
.15118 .01544 Mdot
.15121 .01669 Mdot
.15123 .01703 Mdot
.15126 .01636 Mdot
.15128 .017 Mdot
.15131 .01845 Mdot
.15133 .01681 Mdot
.15136 .01753 Mdot
.15139 .01691 Mdot
.15141 .01619 Mdot
.15144 .01667 Mdot
.15146 .01693 Mdot
.15149 .01693 Mdot
.15152 .016 Mdot
.15154 .01608 Mdot
.15157 .01557 Mdot
.15159 .01589 Mdot
.15162 .01663 Mdot
.15164 .01601 Mdot
.15167 .0158 Mdot
.1517 .01614 Mdot
.15172 .01648 Mdot
.15175 .01635 Mdot
.15177 .01553 Mdot
.1518 .01693 Mdot
.15183 .01595 Mdot
.15185 .01648 Mdot
.15188 .01565 Mdot
.1519 .01585 Mdot
.15193 .01759 Mdot
.15195 .01749 Mdot
.15198 .0156 Mdot
.15201 .01543 Mdot
.15203 .01566 Mdot
.15206 .01653 Mdot
.15208 .01742 Mdot
.15211 .01681 Mdot
.15214 .01617 Mdot
.15216 .01605 Mdot
.15219 .01727 Mdot
.15221 .01674 Mdot
.15224 .01566 Mdot
.15226 .01698 Mdot
.15229 .01843 Mdot
.15232 .01645 Mdot
.15234 .01698 Mdot
.15237 .0194 Mdot
.15239 .02129 Mdot
.15242 .02049 Mdot
.15245 .02021 Mdot
.15247 .0191 Mdot
.1525 .0199 Mdot
.15252 .01859 Mdot
.15255 .01679 Mdot
.15257 .01674 Mdot
.1526 .01583 Mdot
.15263 .01529 Mdot
.15265 .0184 Mdot
.15268 .01816 Mdot
.1527 .01618 Mdot
.15273 .0177 Mdot
.15276 .01515 Mdot
.15278 .01657 Mdot
.15281 .01872 Mdot
.15283 .01782 Mdot
.15286 .01885 Mdot
.15288 .01559 Mdot
.15291 .0181 Mdot
.15294 .01513 Mdot
.15296 .01767 Mdot
.15299 .01713 Mdot
.15301 .01958 Mdot
.15304 .01894 Mdot
.15307 .0199 Mdot
.15309 .02341 Mdot
.15312 .02136 Mdot
.15314 .0234 Mdot
.15317 .02158 Mdot
.15319 .0225 Mdot
.15322 .02125 Mdot
.15325 .02061 Mdot
.15327 .01894 Mdot
.1533 .01904 Mdot
.15332 .01552 Mdot
.15335 .016 Mdot
.15338 .02142 Mdot
.1534 .01549 Mdot
.15343 .01656 Mdot
.15345 .02013 Mdot
.15348 .02165 Mdot
.1535 .01737 Mdot
.15353 .02177 Mdot
.15356 .02382 Mdot
.15358 .02239 Mdot
.15361 .01673 Mdot
.15363 .01996 Mdot
.15366 .0223 Mdot
.15369 .02015 Mdot
.15371 .01634 Mdot
.15374 .01913 Mdot
.15376 .0205 Mdot
.15379 .02116 Mdot
.15381 .02415 Mdot
.15384 .02064 Mdot
.15387 .01751 Mdot
.15389 .02111 Mdot
.15392 .01992 Mdot
.15394 .01874 Mdot
.15397 .01896 Mdot
.154 .02016 Mdot
.15402 .01925 Mdot
.15405 .01735 Mdot
.15407 .01535 Mdot
.1541 .02089 Mdot
.15412 .01957 Mdot
.15415 .01711 Mdot
.15418 .01895 Mdot
.1542 .02003 Mdot
.15423 .01747 Mdot
.15425 .01778 Mdot
.15428 .02029 Mdot
.15431 .01948 Mdot
.15433 .02221 Mdot
.15436 .01866 Mdot
.15438 .02001 Mdot
.15441 .02112 Mdot
.15443 .02535 Mdot
.15446 .02074 Mdot
.15449 .01946 Mdot
.15451 .01741 Mdot
.15454 .02145 Mdot
.15456 .02165 Mdot
.15459 .02235 Mdot
.15462 .0212 Mdot
.15464 .02196 Mdot
.15467 .01854 Mdot
.15469 .01685 Mdot
.15472 .02184 Mdot
.15474 .02643 Mdot
.15477 .02492 Mdot
.1548 .01935 Mdot
.15482 .01962 Mdot
.15485 .02085 Mdot
.15487 .02007 Mdot
.1549 .02343 Mdot
.15493 .02373 Mdot
.15495 .02145 Mdot
.15498 .02149 Mdot
.155 .0185 Mdot
.15503 .01733 Mdot
.15505 .01965 Mdot
.15508 .02265 Mdot
.15511 .02195 Mdot
.15513 .01987 Mdot
.15516 .01986 Mdot
.15518 .02143 Mdot
.15521 .01738 Mdot
.15524 .01914 Mdot
.15526 .02186 Mdot
.15529 .01954 Mdot
.15531 .02277 Mdot
.15534 .02369 Mdot
.15536 .02321 Mdot
.15539 .02544 Mdot
.15542 .02251 Mdot
.15544 .02154 Mdot
.15547 .01685 Mdot
.15549 .01516 Mdot
.15552 .01725 Mdot
.15555 .02036 Mdot
.15557 .01902 Mdot
.1556 .01853 Mdot
.15562 .02141 Mdot
.15565 .0196 Mdot
.15567 .01971 Mdot
.1557 .01756 Mdot
.15573 .01966 Mdot
.15575 .02006 Mdot
.15578 .01569 Mdot
.1558 .01678 Mdot
.15583 .01528 Mdot
.15586 .01716 Mdot
.15588 .01554 Mdot
.15591 .01746 Mdot
.15593 .01679 Mdot
.15596 .0169 Mdot
.15598 .01949 Mdot
.15601 .01885 Mdot
.15604 .01903 Mdot
.15606 .01768 Mdot
.15609 .01805 Mdot
.15611 .01945 Mdot
.15614 .01775 Mdot
.15617 .01961 Mdot
.15619 .01927 Mdot
.15622 .01939 Mdot
.15624 .01863 Mdot
.15627 .01773 Mdot
.15629 .01779 Mdot
.15632 .01568 Mdot
.15635 .01756 Mdot
.15637 .02113 Mdot
.1564 .02354 Mdot
.15642 .01856 Mdot
.15645 .0186 Mdot
.15648 .01694 Mdot
.1565 .02112 Mdot
.15653 .02236 Mdot
.15655 .02109 Mdot
.15658 .01984 Mdot
.1566 .01815 Mdot
.15663 .01694 Mdot
.15666 .01809 Mdot
.15668 .01818 Mdot
.15671 .01888 Mdot
.15673 .01623 Mdot
.15676 .01905 Mdot
.15679 .01832 Mdot
.15681 .01749 Mdot
.15684 .01872 Mdot
.15686 .01731 Mdot
.15689 .02031 Mdot
.15691 .02104 Mdot
.15694 .01815 Mdot
.15697 .01901 Mdot
.15699 .017 Mdot
.15702 .01609 Mdot
.15704 .0172 Mdot
.15707 .01683 Mdot
.1571 .01913 Mdot
.15712 .01582 Mdot
.15715 .01982 Mdot
.15717 .01978 Mdot
.1572 .01735 Mdot
.15723 .01711 Mdot
.15725 .01589 Mdot
.15728 .0167 Mdot
.1573 .0179 Mdot
.15733 .01648 Mdot
.15735 .01681 Mdot
.15738 .01558 Mdot
.15741 .016 Mdot
.15743 .0166 Mdot
.15746 .01646 Mdot
.15748 .01614 Mdot
.15751 .01789 Mdot
.15754 .01643 Mdot
.15756 .01561 Mdot
.15759 .01629 Mdot
.15761 .01797 Mdot
.15764 .01685 Mdot
.15766 .0163 Mdot
.15769 .01505 Mdot
.15772 .01655 Mdot
.15774 .01658 Mdot
.15777 .01724 Mdot
.15779 .01553 Mdot
.15782 .01631 Mdot
.15785 .01777 Mdot
.15787 .01645 Mdot
.1579 .01714 Mdot
.15792 .01834 Mdot
.15795 .01596 Mdot
.15797 .0169 Mdot
.158 .01572 Mdot
.15803 .01869 Mdot
.15805 .01661 Mdot
.15808 .0188 Mdot
.1581 .01725 Mdot
.15813 .01634 Mdot
.15816 .01709 Mdot
.15818 .01556 Mdot
.15821 .0172 Mdot
.15823 .01596 Mdot
.15826 .01674 Mdot
.15828 .01599 Mdot
.15831 .0174 Mdot
.15834 .0164 Mdot
.15836 .01593 Mdot
.15839 .01643 Mdot
.15841 .01694 Mdot
.15844 .01491 Mdot
.15847 .01724 Mdot
.15849 .01759 Mdot
.15852 .01672 Mdot
.15854 .01781 Mdot
.15857 .01643 Mdot
.15859 .01704 Mdot
.15862 .01642 Mdot
.15865 .01545 Mdot
.15867 .01749 Mdot
.1587 .01695 Mdot
.15872 .01659 Mdot
.15875 .01558 Mdot
.15878 .01769 Mdot
.1588 .01868 Mdot
.15883 .01729 Mdot
.15885 .01851 Mdot
.15888 .01921 Mdot
.1589 .01961 Mdot
.15893 .01909 Mdot
.15896 .02102 Mdot
.15898 .01977 Mdot
.15901 .0177 Mdot
.15903 .01786 Mdot
.15906 .0177 Mdot
.15909 .01694 Mdot
.15911 .01604 Mdot
.15914 .01661 Mdot
.15916 .01688 Mdot
.15919 .01811 Mdot
.15921 .01666 Mdot
.15924 .01851 Mdot
.15927 .01686 Mdot
.15929 .01617 Mdot
.15932 .01576 Mdot
.15934 .0183 Mdot
.15937 .01636 Mdot
.1594 .01703 Mdot
.15942 .01694 Mdot
.15945 .01843 Mdot
.15947 .01773 Mdot
.1595 .01891 Mdot
.15952 .02143 Mdot
.15955 .01794 Mdot
.15958 .01721 Mdot
.1596 .01758 Mdot
.15963 .01701 Mdot
.15965 .0202 Mdot
.15968 .02034 Mdot
.15971 .01754 Mdot
.15973 .02342 Mdot
.15976 .02177 Mdot
.15978 .02014 Mdot
.15981 .02298 Mdot
.15983 .02329 Mdot
.15986 .01886 Mdot
.15989 .01877 Mdot
.15991 .02163 Mdot
.15994 .02281 Mdot
.15996 .01616 Mdot
.15999 .01692 Mdot
.16002 .02071 Mdot
.16004 .01764 Mdot
.16007 .01834 Mdot
.16009 .02142 Mdot
.16012 .02006 Mdot
.16014 .01687 Mdot
.16017 .02121 Mdot
.1602 .01985 Mdot
.16022 .01799 Mdot
.16025 .01754 Mdot
.16027 .01833 Mdot
.1603 .01847 Mdot
.16033 .01571 Mdot
.16035 .01592 Mdot
.16038 .01784 Mdot
.1604 .01865 Mdot
.16043 .01658 Mdot
.16045 .01694 Mdot
.16048 .017 Mdot
.16051 .01795 Mdot
.16053 .0153 Mdot
.16056 .01943 Mdot
.16058 .01954 Mdot
.16061 .01887 Mdot
.16064 .01548 Mdot
.16066 .01752 Mdot
.16069 .01662 Mdot
.16071 .02009 Mdot
.16074 .01709 Mdot
.16076 .01934 Mdot
.16079 .0148 Mdot
.16082 .01669 Mdot
.16084 .02101 Mdot
.16087 .01612 Mdot
.16089 .01773 Mdot
.16092 .01692 Mdot
.16095 .01876 Mdot
.16097 .01768 Mdot
.161 .01747 Mdot
.16102 .01926 Mdot
.16105 .01976 Mdot
.16107 .01758 Mdot
.1611 .02058 Mdot
.16113 .01797 Mdot
.16115 .0182 Mdot
.16118 .02031 Mdot
.1612 .02036 Mdot
.16123 .01949 Mdot
.16126 .02199 Mdot
.16128 .01829 Mdot
.16131 .01604 Mdot
.16133 .0176 Mdot
.16136 .02169 Mdot
.16138 .02257 Mdot
.16141 .02151 Mdot
.16144 .02158 Mdot
.16146 .01962 Mdot
.16149 .01753 Mdot
.16151 .01786 Mdot
.16154 .01849 Mdot
.16157 .01877 Mdot
.16159 .0193 Mdot
.16162 .02223 Mdot
.16164 .02091 Mdot
.16167 .02271 Mdot
.16169 .02107 Mdot
.16172 .01703 Mdot
.16175 .01599 Mdot
.16177 .01559 Mdot
.1618 .01832 Mdot
.16182 .01546 Mdot
.16185 .01574 Mdot
.16188 .01618 Mdot
.1619 .01601 Mdot
.16193 .01663 Mdot
.16195 .01693 Mdot
.16198 .0199 Mdot
.162 .01689 Mdot
.16203 .0164 Mdot
.16206 .01565 Mdot
.16208 .0156 Mdot
.16211 .01755 Mdot
.16213 .01556 Mdot
.16216 .01506 Mdot
.16219 .01723 Mdot
.16221 .01764 Mdot
.16224 .01646 Mdot
.16226 .01709 Mdot
.16229 .01604 Mdot
.16231 .01728 Mdot
.16234 .01962 Mdot
.16237 .01803 Mdot
.16239 .01764 Mdot
.16242 .01736 Mdot
.16244 .01885 Mdot
.16247 .01495 Mdot
.1625 .0183 Mdot
.16252 .01628 Mdot
.16255 .01916 Mdot
.16257 .01585 Mdot
.1626 .01943 Mdot
.16262 .0216 Mdot
.16265 .01642 Mdot
.16268 .01882 Mdot
.1627 .01873 Mdot
.16273 .01881 Mdot
.16275 .01969 Mdot
.16278 .02276 Mdot
.16281 .02181 Mdot
.16283 .01743 Mdot
.16286 .01569 Mdot
.16288 .01749 Mdot
.16291 .02097 Mdot
.16293 .01999 Mdot
.16296 .01854 Mdot
.16299 .01634 Mdot
.16301 .01834 Mdot
.16304 .0168 Mdot
.16306 .01958 Mdot
.16309 .0179 Mdot
.16312 .01735 Mdot
.16314 .01663 Mdot
.16317 .01696 Mdot
.16319 .01894 Mdot
.16322 .01646 Mdot
.16324 .01591 Mdot
.16327 .01495 Mdot
.1633 .01645 Mdot
.16332 .01596 Mdot
.16335 .0152 Mdot
.16337 .01529 Mdot
.1634 .01532 Mdot
.16343 .01648 Mdot
.16345 .0151 Mdot
.16348 .01655 Mdot
.1635 .01727 Mdot
.16353 .01682 Mdot
.16355 .01531 Mdot
.16358 .01549 Mdot
.16361 .01688 Mdot
.16363 .01537 Mdot
.16366 .01748 Mdot
.16368 .01675 Mdot
.16371 .01599 Mdot
.16374 .01951 Mdot
.16376 .01651 Mdot
.16379 .01563 Mdot
.16381 .01875 Mdot
.16384 .01635 Mdot
.16386 .01685 Mdot
.16389 .01613 Mdot
.16392 .01644 Mdot
.16394 .01625 Mdot
.16397 .01584 Mdot
.16399 .01513 Mdot
.16402 .01782 Mdot
.16405 .01574 Mdot
.16407 .01744 Mdot
.1641 .01535 Mdot
.16412 .01767 Mdot
.16415 .01568 Mdot
.16417 .01673 Mdot
.1642 .01607 Mdot
.16423 .01493 Mdot
.16425 .0157 Mdot
.16428 .01711 Mdot
.1643 .0161 Mdot
.16433 .01734 Mdot
.16436 .01726 Mdot
.16438 .01663 Mdot
.16441 .01588 Mdot
.16443 .01763 Mdot
.16446 .01628 Mdot
.16448 .01491 Mdot
.16451 .01556 Mdot
.16454 .0158 Mdot
.16456 .01653 Mdot
.16459 .01498 Mdot
.16461 .01705 Mdot
.16464 .01745 Mdot
.16467 .01623 Mdot
.16469 .01543 Mdot
.16472 .0159 Mdot
.16474 .01619 Mdot
.16477 .01576 Mdot
.16479 .01718 Mdot
.16482 .01696 Mdot
.16485 .01689 Mdot
.16487 .0167 Mdot
.1649 .01972 Mdot
.16492 .01888 Mdot
.16495 .01692 Mdot
.16498 .01728 Mdot
.165 .01773 Mdot
.16503 .01823 Mdot
.16505 .01539 Mdot
.16508 .01666 Mdot
.1651 .0166 Mdot
.16513 .01646 Mdot
.16516 .01697 Mdot
.16518 .01675 Mdot
.16521 .01842 Mdot
.16523 .01798 Mdot
.16526 .02057 Mdot
.16529 .01763 Mdot
.16531 .01972 Mdot
.16534 .01727 Mdot
.16536 .01742 Mdot
.16539 .0171 Mdot
.16541 .01678 Mdot
.16544 .01837 Mdot
.16547 .01814 Mdot
.16549 .01973 Mdot
.16552 .01991 Mdot
.16554 .01917 Mdot
.16557 .01988 Mdot
.1656 .01675 Mdot
.16562 .01599 Mdot
.16565 .01619 Mdot
.16567 .01714 Mdot
.1657 .01705 Mdot
.16572 .0168 Mdot
.16575 .01706 Mdot
.16578 .01653 Mdot
.1658 .01622 Mdot
.16583 .01735 Mdot
.16585 .01962 Mdot
.16588 .01802 Mdot
.16591 .01617 Mdot
.16593 .01867 Mdot
.16596 .01878 Mdot
.16598 .01754 Mdot
.16601 .01918 Mdot
.16603 .01769 Mdot
.16606 .01909 Mdot
.16609 .02175 Mdot
.16611 .02165 Mdot
.16614 .01968 Mdot
.16616 .02131 Mdot
.16619 .02233 Mdot
.16622 .02109 Mdot
.16624 .01501 Mdot
.16627 .01975 Mdot
.16629 .02001 Mdot
.16632 .01681 Mdot
.16635 .01679 Mdot
.16637 .02035 Mdot
.1664 .01872 Mdot
.16642 .01668 Mdot
.16645 .01924 Mdot
.16647 .0205 Mdot
.1665 .01903 Mdot
.16653 .01773 Mdot
.16655 .01777 Mdot
.16658 .01746 Mdot
.1666 .01825 Mdot
.16663 .01584 Mdot
.16666 .01798 Mdot
.16668 .01895 Mdot
.16671 .01578 Mdot
.16673 .01606 Mdot
.16676 .01563 Mdot
.16678 .01744 Mdot
.16681 .01539 Mdot
.16684 .01685 Mdot
.16686 .02064 Mdot
.16689 .01981 Mdot
.16691 .01847 Mdot
.16694 .01901 Mdot
.16697 .01862 Mdot
.16699 .01768 Mdot
.16702 .01511 Mdot
.16704 .01593 Mdot
.16707 .01795 Mdot
.16709 .01587 Mdot
.16712 .01716 Mdot
.16715 .01847 Mdot
.16717 .01688 Mdot
.1672 .01653 Mdot
.16722 .01529 Mdot
.16725 .01738 Mdot
.16728 .01668 Mdot
.1673 .01664 Mdot
.16733 .01761 Mdot
.16735 .01592 Mdot
.16738 .01765 Mdot
.1674 .01717 Mdot
.16743 .01634 Mdot
.16746 .01524 Mdot
.16748 .0161 Mdot
.16751 .01728 Mdot
.16753 .01592 Mdot
.16756 .01765 Mdot
.16759 .0166 Mdot
.16761 .01768 Mdot
.16764 .01605 Mdot
.16766 .01796 Mdot
.16769 .01778 Mdot
.16771 .02113 Mdot
.16774 .0171 Mdot
.16777 .01771 Mdot
.16779 .01807 Mdot
.16782 .01672 Mdot
.16784 .017 Mdot
.16787 .01847 Mdot
.1679 .01772 Mdot
.16792 .01865 Mdot
.16795 .02029 Mdot
.16797 .02308 Mdot
.168 .01945 Mdot
.16802 .01501 Mdot
.16805 .01706 Mdot
.16808 .01775 Mdot
.1681 .01631 Mdot
.16813 .01757 Mdot
.16815 .01672 Mdot
.16818 .01683 Mdot
.16821 .01958 Mdot
.16823 .02089 Mdot
.16826 .02102 Mdot
.16828 .01915 Mdot
.16831 .01804 Mdot
.16833 .01912 Mdot
.16836 .02093 Mdot
.16839 .01751 Mdot
.16841 .01598 Mdot
.16844 .01811 Mdot
.16846 .01631 Mdot
.16849 .01509 Mdot
.16852 .01679 Mdot
.16854 .01863 Mdot
.16857 .01733 Mdot
.16859 .0168 Mdot
.16862 .01786 Mdot
.16864 .01911 Mdot
.16867 .01748 Mdot
.1687 .01688 Mdot
.16872 .01766 Mdot
.16875 .01584 Mdot
.16877 .01876 Mdot
.1688 .01879 Mdot
.16883 .01704 Mdot
.16885 .01638 Mdot
.16888 .01769 Mdot
.1689 .01738 Mdot
.16893 .01769 Mdot
.16895 .01632 Mdot
.16898 .01571 Mdot
.16901 .01667 Mdot
.16903 .0167 Mdot
.16906 .01885 Mdot
.16908 .01693 Mdot
.16911 .01766 Mdot
.16914 .01879 Mdot
.16916 .01831 Mdot
.16919 .01709 Mdot
.16921 .01915 Mdot
.16924 .01887 Mdot
.16926 .01613 Mdot
.16929 .01484 Mdot
.16932 .01885 Mdot
.16934 .01743 Mdot
.16937 .01893 Mdot
.16939 .01554 Mdot
.16942 .01883 Mdot
.16945 .01703 Mdot
.16947 .01716 Mdot
.1695 .01615 Mdot
.16952 .01717 Mdot
.16955 .01601 Mdot
.16957 .01658 Mdot
.1696 .01545 Mdot
.16963 .01801 Mdot
.16965 .01645 Mdot
.16968 .01797 Mdot
.1697 .01905 Mdot
.16973 .01733 Mdot
.16976 .01564 Mdot
.16978 .01589 Mdot
.16981 .01722 Mdot
.16983 .01522 Mdot
.16986 .01801 Mdot
.16988 .01581 Mdot
.16991 .01657 Mdot
.16994 .01693 Mdot
.16996 .01596 Mdot
.16999 .01626 Mdot
.17001 .01674 Mdot
.17004 .01572 Mdot
.17007 .01598 Mdot
.17009 .01645 Mdot
.17012 .01658 Mdot
.17014 .01765 Mdot
.17017 .01609 Mdot
.17019 .01812 Mdot
.17022 .01685 Mdot
.17025 .01569 Mdot
.17027 .01686 Mdot
.1703 .01685 Mdot
.17032 .01606 Mdot
.17035 .01532 Mdot
.17038 .01691 Mdot
.1704 .01527 Mdot
.17043 .01798 Mdot
.17045 .01811 Mdot
.17048 .01565 Mdot
.1705 .01632 Mdot
.17053 .01736 Mdot
.17056 .01586 Mdot
.17058 .01734 Mdot
.17061 .01593 Mdot
.17063 .01703 Mdot
.17066 .01585 Mdot
.17069 .01679 Mdot
.17071 .01634 Mdot
.17074 .0163 Mdot
.17076 .01672 Mdot
.17079 .01699 Mdot
.17081 .01656 Mdot
.17084 .01641 Mdot
.17087 .0152 Mdot
.17089 .01671 Mdot
.17092 .01605 Mdot
.17094 .01592 Mdot
.17097 .01596 Mdot
.171 .01633 Mdot
.17102 .01682 Mdot
.17105 .01739 Mdot
.17107 .01648 Mdot
.1711 .01535 Mdot
.17112 .01541 Mdot
.17115 .01692 Mdot
.17118 .01834 Mdot
.1712 .01885 Mdot
.17123 .0167 Mdot
.17125 .01499 Mdot
.17128 .01573 Mdot
.17131 .01653 Mdot
.17133 .01638 Mdot
.17136 .01601 Mdot
.17138 .01682 Mdot
.17141 .01669 Mdot
.17143 .01631 Mdot
.17146 .01569 Mdot
.17149 .01555 Mdot
.17151 .01687 Mdot
.17154 .01657 Mdot
.17156 .01703 Mdot
.17159 .01501 Mdot
.17162 .01542 Mdot
.17164 .01639 Mdot
.17167 .0172 Mdot
.17169 .01544 Mdot
.17172 .01662 Mdot
.17174 .01627 Mdot
.17177 .01641 Mdot
.1718 .0165 Mdot
.17182 .0202 Mdot
.17185 .01682 Mdot
.17187 .01805 Mdot
.1719 .01647 Mdot
.17193 .01645 Mdot
.17195 .01801 Mdot
.17198 .01828 Mdot
.172 .01561 Mdot
.17203 .0161 Mdot
.17205 .01501 Mdot
.17208 .01724 Mdot
.17211 .01606 Mdot
.17213 .01702 Mdot
.17216 .01601 Mdot
.17218 .01558 Mdot
.17221 .01523 Mdot
.17224 .01696 Mdot
.17226 .01735 Mdot
.17229 .01626 Mdot
.17231 .01548 Mdot
.17234 .01824 Mdot
.17236 .01639 Mdot
.17239 .01493 Mdot
.17242 .01744 Mdot
.17244 .01909 Mdot
.17247 .01718 Mdot
.17249 .01623 Mdot
.17252 .01781 Mdot
.17255 .01826 Mdot
.17257 .01786 Mdot
.1726 .01627 Mdot
.17262 .01803 Mdot
.17265 .0181 Mdot
.17267 .01658 Mdot
.1727 .01902 Mdot
.17273 .01599 Mdot
.17275 .01731 Mdot
.17278 .01515 Mdot
.1728 .01535 Mdot
.17283 .01719 Mdot
.17286 .01682 Mdot
.17288 .01647 Mdot
.17291 .01661 Mdot
.17293 .01683 Mdot
.17296 .01888 Mdot
.17298 .01645 Mdot
.17301 .01634 Mdot
.17304 .01802 Mdot
.17306 .01793 Mdot
.17309 .01838 Mdot
.17311 .01998 Mdot
.17314 .0193 Mdot
.17317 .0204 Mdot
.17319 .01718 Mdot
.17322 .01758 Mdot
.17324 .01737 Mdot
.17327 .01583 Mdot
.17329 .01656 Mdot
.17332 .01664 Mdot
.17335 .01787 Mdot
.17337 .01561 Mdot
.1734 .01839 Mdot
.17342 .01919 Mdot
.17345 .01971 Mdot
.17348 .02018 Mdot
.1735 .01665 Mdot
.17353 .01876 Mdot
.17355 .01774 Mdot
.17358 .01613 Mdot
.1736 .01703 Mdot
.17363 .02349 Mdot
.17366 .02096 Mdot
.17368 .01657 Mdot
.17371 .0169 Mdot
.17373 .01565 Mdot
.17376 .01794 Mdot
.17379 .01875 Mdot
.17381 .01899 Mdot
.17384 .01919 Mdot
.17386 .01663 Mdot
.17389 .01754 Mdot
.17391 .01724 Mdot
.17394 .01822 Mdot
.17397 .01748 Mdot
.17399 .01793 Mdot
.17402 .01792 Mdot
.17404 .01514 Mdot
.17407 .0175 Mdot
.1741 .01551 Mdot
.17412 .01716 Mdot
.17415 .01611 Mdot
.17417 .0169 Mdot
.1742 .01857 Mdot
.17422 .01821 Mdot
.17425 .01619 Mdot
.17428 .01956 Mdot
.1743 .01624 Mdot
.17433 .01567 Mdot
.17435 .01743 Mdot
.17438 .01523 Mdot
.17441 .01724 Mdot
.17443 .0179 Mdot
.17446 .01812 Mdot
.17448 .01757 Mdot
.17451 .0165 Mdot
.17453 .01592 Mdot
.17456 .01618 Mdot
.17459 .01519 Mdot
.17461 .01764 Mdot
.17464 .01899 Mdot
.17466 .01806 Mdot
.17469 .01512 Mdot
.17472 .01561 Mdot
.17474 .01585 Mdot
.17477 .01924 Mdot
.17479 .01706 Mdot
.17482 .01655 Mdot
.17484 .01857 Mdot
.17487 .01841 Mdot
.1749 .01664 Mdot
.17492 .01683 Mdot
.17495 .0166 Mdot
.17497 .01661 Mdot
.175 .01648 Mdot
.17503 .01894 Mdot
.17505 .01954 Mdot
.17508 .01738 Mdot
.1751 .01691 Mdot
.17513 .01627 Mdot
.17515 .01905 Mdot
.17518 .01973 Mdot
.17521 .0175 Mdot
.17523 .01719 Mdot
.17526 .01931 Mdot
.17528 .021 Mdot
.17531 .01713 Mdot
.17534 .01767 Mdot
.17536 .01552 Mdot
.17539 .0165 Mdot
.17541 .01922 Mdot
.17544 .01701 Mdot
.17547 .01733 Mdot
.17549 .01519 Mdot
.17552 .01599 Mdot
.17554 .01644 Mdot
.17557 .01736 Mdot
.17559 .01785 Mdot
.17562 .01556 Mdot
.17565 .01777 Mdot
.17567 .01669 Mdot
.1757 .02051 Mdot
.17572 .0192 Mdot
.17575 .01779 Mdot
.17578 .0168 Mdot
.1758 .01727 Mdot
.17583 .01807 Mdot
.17585 .01742 Mdot
.17588 .01796 Mdot
.1759 .0166 Mdot
.17593 .01642 Mdot
.17596 .01583 Mdot
.17598 .01582 Mdot
.17601 .01781 Mdot
.17603 .01674 Mdot
.17606 .01569 Mdot
.17609 .01518 Mdot
.17611 .01705 Mdot
.17614 .01597 Mdot
.17616 .01596 Mdot
.17619 .0158 Mdot
.17621 .01505 Mdot
.17624 .01571 Mdot
.17627 .01887 Mdot
.17629 .01905 Mdot
.17632 .01742 Mdot
.17634 .01799 Mdot
.17637 .01622 Mdot
.1764 .01822 Mdot
.17642 .01777 Mdot
.17645 .0173 Mdot
.17647 .01556 Mdot
.1765 .01841 Mdot
.17652 .0161 Mdot
.17655 .01742 Mdot
.17658 .01602 Mdot
.1766 .01656 Mdot
.17663 .01661 Mdot
.17665 .0165 Mdot
.17668 .01606 Mdot
.17671 .01575 Mdot
.17673 .01611 Mdot
.17676 .01776 Mdot
.17678 .01541 Mdot
.17681 .01626 Mdot
.17683 .01729 Mdot
.17686 .01541 Mdot
.17689 .01563 Mdot
.17691 .01507 Mdot
.17694 .01619 Mdot
.17696 .01609 Mdot
.17699 .01561 Mdot
.17702 .0169 Mdot
.17704 .01647 Mdot
.17707 .01775 Mdot
.17709 .01578 Mdot
.17712 .01711 Mdot
.17714 .01634 Mdot
.17717 .01515 Mdot
.1772 .01695 Mdot
.17722 .01617 Mdot
.17725 .01734 Mdot
.17727 .01534 Mdot
.1773 .01668 Mdot
.17733 .01538 Mdot
.17735 .01643 Mdot
.17738 .0163 Mdot
.1774 .01531 Mdot
.17743 .01585 Mdot
.17745 .01682 Mdot
.17748 .01562 Mdot
.17751 .01523 Mdot
.17753 .01587 Mdot
.17756 .0162 Mdot
.17758 .01732 Mdot
.17761 .01509 Mdot
.17764 .0161 Mdot
.17766 .01784 Mdot
.17769 .01745 Mdot
.17771 .01736 Mdot
.17774 .01579 Mdot
.17776 .0157 Mdot
.17779 .01601 Mdot
.17782 .01587 Mdot
.17784 .01671 Mdot
.17787 .01556 Mdot
.17789 .01512 Mdot
.17792 .01515 Mdot
.17795 .01603 Mdot
.17797 .01633 Mdot
.178 .01571 Mdot
.17802 .01609 Mdot
.17805 .01657 Mdot
.17807 .01702 Mdot
.1781 .01513 Mdot
.17813 .01556 Mdot
.17815 .01757 Mdot
.17818 .01613 Mdot
.1782 .01555 Mdot
.17823 .01922 Mdot
.17826 .0181 Mdot
.17828 .0196 Mdot
.17831 .01693 Mdot
.17833 .01743 Mdot
.17836 .01952 Mdot
.17838 .01491 Mdot
.17841 .016 Mdot
.17844 .01645 Mdot
.17846 .01672 Mdot
.17849 .01661 Mdot
.17851 .01749 Mdot
.17854 .01575 Mdot
.17857 .01669 Mdot
.17859 .01802 Mdot
.17862 .01758 Mdot
.17864 .01562 Mdot
.17867 .01656 Mdot
.17869 .01666 Mdot
.17872 .01687 Mdot
.17875 .01771 Mdot
.17877 .01655 Mdot
.1788 .0175 Mdot
.17882 .01698 Mdot
.17885 .01556 Mdot
.17888 .01603 Mdot
.1789 .01514 Mdot
.17893 .01592 Mdot
.17895 .0165 Mdot
.17898 .01587 Mdot
.179 .01565 Mdot
.17903 .01702 Mdot
.17906 .01615 Mdot
.17908 .01562 Mdot
.17911 .01658 Mdot
.17913 .01611 Mdot
.17916 .01621 Mdot
.17919 .01682 Mdot
.17921 .01762 Mdot
.17924 .01629 Mdot
.17926 .01545 Mdot
.17929 .01799 Mdot
.17931 .01523 Mdot
.17934 .0154 Mdot
.17937 .01855 Mdot
.17939 .01627 Mdot
.17942 .01735 Mdot
.17944 .01753 Mdot
.17947 .01731 Mdot
.1795 .01585 Mdot
.17952 .01659 Mdot
.17955 .01577 Mdot
.17957 .017 Mdot
.1796 .01681 Mdot
.17962 .01687 Mdot
.17965 .01695 Mdot
.17968 .01579 Mdot
.1797 .0167 Mdot
.17973 .01826 Mdot
.17975 .01737 Mdot
.17978 .01517 Mdot
.17981 .01635 Mdot
.17983 .01781 Mdot
.17986 .01624 Mdot
.17988 .01731 Mdot
.17991 .01535 Mdot
.17993 .01735 Mdot
.17996 .01639 Mdot
.17999 .01511 Mdot
.18001 .01561 Mdot
.18004 .0154 Mdot
.18006 .01652 Mdot
.18009 .01773 Mdot
.18012 .01727 Mdot
.18014 .01588 Mdot
.18017 .01554 Mdot
.18019 .01508 Mdot
.18022 .01703 Mdot
.18024 .0152 Mdot
.18027 .016 Mdot
.1803 .01674 Mdot
.18032 .01617 Mdot
.18035 .01615 Mdot
.18037 .01627 Mdot
.1804 .01564 Mdot
.18043 .01585 Mdot
.18045 .01572 Mdot
.18048 .01612 Mdot
.1805 .01635 Mdot
.18053 .01799 Mdot
.18055 .01639 Mdot
.18058 .01559 Mdot
.18061 .0179 Mdot
.18063 .01776 Mdot
.18066 .01546 Mdot
.18068 .01723 Mdot
.18071 .01676 Mdot
.18074 .01566 Mdot
.18076 .01602 Mdot
.18079 .01724 Mdot
.18081 .01628 Mdot
.18084 .01578 Mdot
.18086 .01633 Mdot
.18089 .01862 Mdot
.18092 .01822 Mdot
.18094 .01838 Mdot
.18097 .015 Mdot
.18099 .01644 Mdot
.18102 .0166 Mdot
.18105 .01713 Mdot
.18107 .01515 Mdot
.1811 .01661 Mdot
.18112 .01694 Mdot
.18115 .01553 Mdot
.18117 .01721 Mdot
.1812 .01585 Mdot
.18123 .01592 Mdot
.18125 .01613 Mdot
.18128 .01519 Mdot
.1813 .01721 Mdot
.18133 .01809 Mdot
.18136 .01649 Mdot
.18138 .01693 Mdot
.18141 .01621 Mdot
.18143 .01524 Mdot
.18146 .01689 Mdot
.18148 .017 Mdot
.18151 .01647 Mdot
.18154 .01535 Mdot
.18156 .01663 Mdot
.18159 .01652 Mdot
.18161 .01509 Mdot
.18164 .01563 Mdot
.18167 .0159 Mdot
.18169 .01582 Mdot
.18172 .01619 Mdot
.18174 .01791 Mdot
.18177 .01681 Mdot
.18179 .01863 Mdot
.18182 .01549 Mdot
.18185 .01541 Mdot
.18187 .01687 Mdot
.1819 .01589 Mdot
.18192 .01574 Mdot
.18195 .01573 Mdot
.18198 .01587 Mdot
.182 .01702 Mdot
.18203 .01637 Mdot
.18205 .01642 Mdot
.18208 .0152 Mdot
.1821 .01555 Mdot
.18213 .01777 Mdot
.18216 .01717 Mdot
.18218 .01738 Mdot
.18221 .01643 Mdot
.18223 .0171 Mdot
.18226 .01718 Mdot
.18229 .01672 Mdot
.18231 .01649 Mdot
.18234 .01648 Mdot
.18236 .01583 Mdot
.18239 .01525 Mdot
.18241 .01532 Mdot
.18244 .01524 Mdot
.18247 .01737 Mdot
.18249 .01555 Mdot
.18252 .01734 Mdot
.18254 .01686 Mdot
.18257 .01545 Mdot
.1826 .01571 Mdot
.18262 .01482 Mdot
.18265 .0167 Mdot
.18267 .01599 Mdot
.1827 .01583 Mdot
.18272 .01514 Mdot
.18275 .01551 Mdot
.18278 .01761 Mdot
.1828 .01733 Mdot
.18283 .01671 Mdot
.18285 .01854 Mdot
.18288 .01796 Mdot
.18291 .01694 Mdot
.18293 .01567 Mdot
.18296 .01549 Mdot
.18298 .01578 Mdot
.18301 .01567 Mdot
.18303 .01656 Mdot
.18306 .01616 Mdot
.18309 .0153 Mdot
.18311 .01538 Mdot
.18314 .01581 Mdot
.18316 .0154 Mdot
.18319 .01506 Mdot
.18322 .01651 Mdot
.18324 .01536 Mdot
.18327 .01532 Mdot
.18329 .01548 Mdot
.18332 .01653 Mdot
.18334 .01581 Mdot
.18337 .0159 Mdot
.1834 .01535 Mdot
.18342 .01552 Mdot
.18345 .01581 Mdot
.18347 .0152 Mdot
.1835 .01622 Mdot
.18353 .01578 Mdot
.18355 .0151 Mdot
.18358 .01654 Mdot
.1836 .01613 Mdot
.18363 .01726 Mdot
.18365 .01517 Mdot
.18368 .01613 Mdot
.18371 .01646 Mdot
.18373 .01546 Mdot
.18376 .01567 Mdot
.18378 .01532 Mdot
.18381 .01558 Mdot
.18384 .01561 Mdot
.18386 .01643 Mdot
.18389 .0165 Mdot
.18391 .01632 Mdot
.18394 .01572 Mdot
.18396 .01546 Mdot
.18399 .01535 Mdot
.18402 .01545 Mdot
.18404 .01546 Mdot
.18407 .01494 Mdot
.18409 .0155 Mdot
.18412 .01628 Mdot
.18415 .0162 Mdot
.18417 .01527 Mdot
.1842 .01561 Mdot
.18422 .01577 Mdot
.18425 .01554 Mdot
.18427 .01707 Mdot
.1843 .01551 Mdot
.18433 .0156 Mdot
.18435 .01672 Mdot
.18438 .01658 Mdot
.1844 .01729 Mdot
.18443 .0165 Mdot
.18446 .01644 Mdot
.18448 .01599 Mdot
.18451 .01628 Mdot
.18453 .01603 Mdot
.18456 .01488 Mdot
.18459 .01561 Mdot
.18461 .01549 Mdot
.18464 .01505 Mdot
.18466 .01683 Mdot
.18469 .01573 Mdot
.18471 .01667 Mdot
.18474 .01747 Mdot
.18477 .01727 Mdot
.18479 .01635 Mdot
.18482 .0169 Mdot
.18484 .01572 Mdot
.18487 .01749 Mdot
.1849 .01558 Mdot
.18492 .01564 Mdot
.18495 .01859 Mdot
.18497 .01971 Mdot
.185 .0175 Mdot
.18502 .01729 Mdot
.18505 .01825 Mdot
.18508 .01753 Mdot
.1851 .01568 Mdot
.18513 .01645 Mdot
.18515 .0174 Mdot
.18518 .01757 Mdot
.18521 .01641 Mdot
.18523 .01553 Mdot
.18526 .01556 Mdot
.18528 .01705 Mdot
.18531 .01758 Mdot
.18533 .0156 Mdot
.18536 .01826 Mdot
.18539 .01769 Mdot
.18541 .01717 Mdot
.18544 .01717 Mdot
.18546 .01762 Mdot
.18549 .01604 Mdot
.18552 .01876 Mdot
.18554 .01659 Mdot
.18557 .01773 Mdot
.18559 .01706 Mdot
.18562 .01786 Mdot
.18564 .01831 Mdot
.18567 .01697 Mdot
.1857 .01672 Mdot
.18572 .01885 Mdot
.18575 .01884 Mdot
.18577 .01679 Mdot
.1858 .01549 Mdot
.18583 .01641 Mdot
.18585 .01611 Mdot
.18588 .01596 Mdot
.1859 .01507 Mdot
.18593 .01701 Mdot
.18595 .01866 Mdot
.18598 .01816 Mdot
.18601 .01597 Mdot
.18603 .01897 Mdot
.18606 .01611 Mdot
.18608 .01702 Mdot
.18611 .01501 Mdot
.18614 .01668 Mdot
.18616 .0162 Mdot
.18619 .0183 Mdot
.18621 .01729 Mdot
.18624 .01663 Mdot
.18626 .01517 Mdot
.18629 .01617 Mdot
.18632 .01586 Mdot
.18634 .01645 Mdot
.18637 .01593 Mdot
.18639 .01778 Mdot
.18642 .01742 Mdot
.18645 .01594 Mdot
.18647 .01636 Mdot
.1865 .0154 Mdot
.18652 .01598 Mdot
.18655 .01731 Mdot
.18657 .01921 Mdot
.1866 .02135 Mdot
.18663 .01657 Mdot
.18665 .01522 Mdot
.18668 .0165 Mdot
.1867 .01666 Mdot
.18673 .01621 Mdot
.18676 .01643 Mdot
.18678 .01529 Mdot
.18681 .016 Mdot
.18683 .01781 Mdot
.18686 .01636 Mdot
.18688 .01653 Mdot
.18691 .01604 Mdot
.18694 .01641 Mdot
.18696 .01601 Mdot
.18699 .01638 Mdot
.18701 .01634 Mdot
.18704 .01579 Mdot
.18707 .0154 Mdot
.18709 .01516 Mdot
.18712 .01705 Mdot
.18714 .01587 Mdot
.18717 .01672 Mdot
.18719 .0159 Mdot
.18722 .01543 Mdot
.18725 .0165 Mdot
.18727 .01643 Mdot
.1873 .01705 Mdot
.18732 .01563 Mdot
.18735 .01598 Mdot
.18738 .01575 Mdot
.1874 .01718 Mdot
.18743 .01565 Mdot
.18745 .01549 Mdot
.18748 .01614 Mdot
.1875 .01637 Mdot
.18753 .01678 Mdot
.18756 .01588 Mdot
.18758 .01819 Mdot
.18761 .01695 Mdot
.18763 .01695 Mdot
.18766 .01507 Mdot
.18769 .01517 Mdot
.18771 .01636 Mdot
.18774 .01578 Mdot
.18776 .01594 Mdot
.18779 .01749 Mdot
.18781 .0161 Mdot
.18784 .01588 Mdot
.18787 .01653 Mdot
.18789 .01602 Mdot
.18792 .01501 Mdot
.18794 .01481 Mdot
.18797 .01555 Mdot
.188 .01519 Mdot
.18802 .01605 Mdot
.18805 .01606 Mdot
.18807 .01871 Mdot
.1881 .01791 Mdot
.18812 .01543 Mdot
.18815 .01513 Mdot
.18818 .01567 Mdot
.1882 .01787 Mdot
.18823 .01762 Mdot
.18825 .01785 Mdot
.18828 .01661 Mdot
.18831 .01576 Mdot
.18833 .01683 Mdot
.18836 .01824 Mdot
.18838 .0174 Mdot
.18841 .01727 Mdot
.18843 .01792 Mdot
.18846 .01622 Mdot
.18849 .01625 Mdot
.18851 .01614 Mdot
.18854 .01837 Mdot
.18856 .01767 Mdot
.18859 .01598 Mdot
.18862 .01571 Mdot
.18864 .01727 Mdot
.18867 .01549 Mdot
.18869 .01586 Mdot
.18872 .01696 Mdot
.18874 .01539 Mdot
.18877 .01556 Mdot
.1888 .01573 Mdot
.18882 .0162 Mdot
.18885 .01746 Mdot
.18887 .01591 Mdot
.1889 .01721 Mdot
.18893 .01555 Mdot
.18895 .01577 Mdot
.18898 .01612 Mdot
.189 .01682 Mdot
.18903 .0152 Mdot
.18905 .01562 Mdot
.18908 .01615 Mdot
.18911 .01706 Mdot
.18913 .01779 Mdot
.18916 .01905 Mdot
.18918 .01645 Mdot
.18921 .01814 Mdot
.18924 .01676 Mdot
.18926 .0178 Mdot
.18929 .01599 Mdot
.18931 .01523 Mdot
.18934 .01516 Mdot
.18936 .01556 Mdot
.18939 .01653 Mdot
.18942 .01526 Mdot
.18944 .01566 Mdot
.18947 .01592 Mdot
.18949 .01673 Mdot
.18952 .01655 Mdot
.18955 .01531 Mdot
.18957 .01573 Mdot
.1896 .01803 Mdot
.18962 .01571 Mdot
.18965 .0167 Mdot
.18967 .01705 Mdot
.1897 .01631 Mdot
.18973 .01674 Mdot
.18975 .01685 Mdot
.18978 .01675 Mdot
.1898 .01577 Mdot
.18983 .01523 Mdot
.18986 .01692 Mdot
.18988 .01523 Mdot
.18991 .01595 Mdot
.18993 .01656 Mdot
.18996 .01728 Mdot
.18998 .01515 Mdot
.19001 .0162 Mdot
.19004 .01684 Mdot
.19006 .01515 Mdot
.19009 .01675 Mdot
.19011 .01667 Mdot
.19014 .0157 Mdot
.19017 .0168 Mdot
.19019 .01755 Mdot
.19022 .01577 Mdot
.19024 .01547 Mdot
.19027 .01535 Mdot
.19029 .01712 Mdot
.19032 .01599 Mdot
.19035 .0159 Mdot
.19037 .01608 Mdot
.1904 .01641 Mdot
.19042 .01513 Mdot
.19045 .01616 Mdot
.19048 .01592 Mdot
.1905 .01529 Mdot
.19053 .01583 Mdot
.19055 .01733 Mdot
.19058 .0151 Mdot
.1906 .01738 Mdot
.19063 .01654 Mdot
.19066 .01599 Mdot
.19068 .01728 Mdot
.19071 .01695 Mdot
.19073 .01782 Mdot
.19076 .01861 Mdot
.19079 .01827 Mdot
.19081 .0167 Mdot
.19084 .01825 Mdot
.19086 .01778 Mdot
.19089 .01651 Mdot
.19091 .01713 Mdot
.19094 .01726 Mdot
.19097 .01708 Mdot
.19099 .01523 Mdot
.19102 .01536 Mdot
.19104 .0164 Mdot
.19107 .01693 Mdot
.1911 .0167 Mdot
.19112 .01676 Mdot
.19115 .01547 Mdot
.19117 .01601 Mdot
.1912 .01824 Mdot
.19122 .01519 Mdot
.19125 .01638 Mdot
.19128 .01685 Mdot
.1913 .01662 Mdot
.19133 .01554 Mdot
.19135 .01676 Mdot
.19138 .01634 Mdot
.19141 .01636 Mdot
.19143 .01629 Mdot
.19146 .01752 Mdot
.19148 .01715 Mdot
.19151 .01727 Mdot
.19153 .01768 Mdot
.19156 .01755 Mdot
.19159 .01568 Mdot
.19161 .01614 Mdot
.19164 .01694 Mdot
.19166 .01532 Mdot
.19169 .01658 Mdot
.19172 .01562 Mdot
.19174 .01598 Mdot
.19177 .01595 Mdot
.19179 .01611 Mdot
.19182 .01584 Mdot
.19184 .01558 Mdot
.19187 .0164 Mdot
.1919 .01589 Mdot
.19192 .01678 Mdot
.19195 .01601 Mdot
.19197 .01586 Mdot
.192 .01621 Mdot
.19203 .01603 Mdot
.19205 .01821 Mdot
.19208 .01659 Mdot
.1921 .01768 Mdot
.19213 .01512 Mdot
.19215 .01554 Mdot
.19218 .01887 Mdot
.19221 .01844 Mdot
.19223 .01541 Mdot
.19226 .01582 Mdot
.19228 .01737 Mdot
.19231 .01786 Mdot
.19234 .01644 Mdot
.19236 .0149 Mdot
.19239 .01531 Mdot
.19241 .01517 Mdot
.19244 .01514 Mdot
.19246 .01683 Mdot
.19249 .01636 Mdot
.19252 .01705 Mdot
.19254 .01674 Mdot
.19257 .01732 Mdot
.19259 .01626 Mdot
.19262 .01512 Mdot
.19265 .01513 Mdot
.19267 .01567 Mdot
.1927 .01618 Mdot
.19272 .0152 Mdot
.19275 .01523 Mdot
.19277 .01613 Mdot
.1928 .0151 Mdot
.19283 .01525 Mdot
.19285 .01596 Mdot
.19288 .01835 Mdot
.1929 .01623 Mdot
.19293 .01548 Mdot
.19296 .01548 Mdot
.19298 .01498 Mdot
.19301 .01531 Mdot
.19303 .0168 Mdot
.19306 .01531 Mdot
.19308 .01758 Mdot
.19311 .01675 Mdot
.19314 .01576 Mdot
.19316 .01756 Mdot
.19319 .01586 Mdot
.19321 .0166 Mdot
.19324 .01606 Mdot
.19327 .01725 Mdot
.19329 .01598 Mdot
.19332 .01679 Mdot
.19334 .01548 Mdot
.19337 .01662 Mdot
.19339 .01654 Mdot
.19342 .01584 Mdot
.19345 .01631 Mdot
.19347 .0174 Mdot
.1935 .01643 Mdot
.19352 .01643 Mdot
.19355 .01738 Mdot
.19358 .01669 Mdot
.1936 .01771 Mdot
.19363 .0168 Mdot
.19365 .01664 Mdot
.19368 .01598 Mdot
.19371 .01691 Mdot
.19373 .01487 Mdot
.19376 .01565 Mdot
.19378 .01537 Mdot
.19381 .01773 Mdot
.19383 .01747 Mdot
.19386 .01708 Mdot
.19389 .01554 Mdot
.19391 .01511 Mdot
.19394 .01709 Mdot
.19396 .01641 Mdot
.19399 .01757 Mdot
.19402 .01804 Mdot
.19404 .01621 Mdot
.19407 .01636 Mdot
.19409 .01556 Mdot
.19412 .01777 Mdot
.19414 .0163 Mdot
.19417 .01652 Mdot
.1942 .01694 Mdot
.19422 .01495 Mdot
.19425 .01544 Mdot
.19427 .01753 Mdot
.1943 .01677 Mdot
.19433 .01712 Mdot
.19435 .01673 Mdot
.19438 .01699 Mdot
.1944 .01648 Mdot
.19443 .01719 Mdot
.19445 .01841 Mdot
.19448 .01824 Mdot
.19451 .01793 Mdot
.19453 .01705 Mdot
.19456 .01676 Mdot
.19458 .0179 Mdot
.19461 .01594 Mdot
.19464 .01676 Mdot
.19466 .01771 Mdot
.19469 .0162 Mdot
.19471 .01793 Mdot
.19474 .01835 Mdot
.19476 .01657 Mdot
.19479 .01711 Mdot
.19482 .01611 Mdot
.19484 .01671 Mdot
.19487 .01654 Mdot
.19489 .01719 Mdot
.19492 .01596 Mdot
.19495 .01534 Mdot
.19497 .0154 Mdot
.195 .01615 Mdot
.19502 .01661 Mdot
.19505 .01654 Mdot
.19507 .01498 Mdot
.1951 .01629 Mdot
.19513 .01625 Mdot
.19515 .01561 Mdot
.19518 .01565 Mdot
.1952 .01632 Mdot
.19523 .01509 Mdot
.19526 .01626 Mdot
.19528 .01573 Mdot
.19531 .01657 Mdot
.19533 .0171 Mdot
.19536 .0159 Mdot
.19538 .01696 Mdot
.19541 .01599 Mdot
.19544 .01499 Mdot
.19546 .01576 Mdot
.19549 .01663 Mdot
.19551 .01631 Mdot
.19554 .01694 Mdot
.19557 .01754 Mdot
.19559 .01717 Mdot
.19562 .01547 Mdot
.19564 .01567 Mdot
.19567 .01849 Mdot
.19569 .01599 Mdot
.19572 .01499 Mdot
.19575 .016 Mdot
.19577 .01807 Mdot
.1958 .01588 Mdot
.19582 .01617 Mdot
.19585 .0158 Mdot
.19588 .01544 Mdot
.1959 .01517 Mdot
.19593 .01675 Mdot
.19595 .01602 Mdot
.19598 .01519 Mdot
.196 .01605 Mdot
.19603 .01604 Mdot
.19606 .01704 Mdot
.19608 .01725 Mdot
.19611 .01513 Mdot
.19613 .01679 Mdot
.19616 .01569 Mdot
.19619 .01631 Mdot
.19621 .01707 Mdot
.19624 .01795 Mdot
.19626 .01727 Mdot
.19629 .01538 Mdot
.19631 .01653 Mdot
.19634 .01538 Mdot
.19637 .01611 Mdot
.19639 .01622 Mdot
.19642 .01547 Mdot
.19644 .0157 Mdot
.19647 .0164 Mdot
.1965 .01622 Mdot
.19652 .01629 Mdot
.19655 .01524 Mdot
.19657 .01649 Mdot
.1966 .01644 Mdot
.19662 .01598 Mdot
.19665 .01533 Mdot
.19668 .01491 Mdot
.1967 .01722 Mdot
.19673 .01568 Mdot
.19675 .01657 Mdot
.19678 .01637 Mdot
.19681 .01644 Mdot
.19683 .0157 Mdot
.19686 .01722 Mdot
.19688 .01624 Mdot
.19691 .01838 Mdot
.19693 .01746 Mdot
.19696 .01598 Mdot
.19699 .0156 Mdot
.19701 .01544 Mdot
.19704 .01717 Mdot
.19706 .01616 Mdot
.19709 .01723 Mdot
.19712 .01611 Mdot
.19714 .01557 Mdot
.19717 .01579 Mdot
.19719 .01608 Mdot
.19722 .01559 Mdot
.19724 .0168 Mdot
.19727 .0166 Mdot
.1973 .01629 Mdot
.19732 .01725 Mdot
.19735 .01523 Mdot
.19737 .01521 Mdot
.1974 .01673 Mdot
.19743 .01656 Mdot
.19745 .01513 Mdot
.19748 .01529 Mdot
.1975 .01621 Mdot
.19753 .01627 Mdot
.19755 .01769 Mdot
.19758 .01632 Mdot
.19761 .01688 Mdot
.19763 .01579 Mdot
.19766 .01579 Mdot
.19768 .01698 Mdot
.19771 .01592 Mdot
.19774 .01605 Mdot
.19776 .0156 Mdot
.19779 .01572 Mdot
.19781 .01545 Mdot
.19784 .01598 Mdot
.19786 .01596 Mdot
.19789 .01608 Mdot
.19792 .01539 Mdot
.19794 .01619 Mdot
.19797 .01618 Mdot
.19799 .01539 Mdot
.19802 .0155 Mdot
.19805 .01512 Mdot
.19807 .01605 Mdot
.1981 .01675 Mdot
.19812 .01576 Mdot
.19815 .01614 Mdot
.19817 .01637 Mdot
.1982 .01524 Mdot
.19823 .01792 Mdot
.19825 .0164 Mdot
.19828 .01698 Mdot
.1983 .01485 Mdot
.19833 .01628 Mdot
.19836 .01643 Mdot
.19838 .01647 Mdot
.19841 .01577 Mdot
.19843 .01543 Mdot
.19846 .01513 Mdot
.19848 .0182 Mdot
.19851 .01594 Mdot
.19854 .01523 Mdot
.19856 .01632 Mdot
.19859 .01811 Mdot
.19861 .01553 Mdot
.19864 .01485 Mdot
.19867 .01555 Mdot
.19869 .01654 Mdot
.19872 .01642 Mdot
.19874 .01563 Mdot
.19877 .015 Mdot
.19879 .01652 Mdot
.19882 .01614 Mdot
.19885 .01663 Mdot
.19887 .01643 Mdot
.1989 .01613 Mdot
.19892 .01496 Mdot
.19895 .01563 Mdot
.19898 .01507 Mdot
.199 .01569 Mdot
.19903 .017 Mdot
.19905 .01488 Mdot
.19908 .01569 Mdot
.1991 .01532 Mdot
.19913 .01504 Mdot
.19916 .01573 Mdot
.19918 .01528 Mdot
.19921 .01632 Mdot
.19923 .015 Mdot
.19926 .01689 Mdot
.19929 .01644 Mdot
.19931 .01526 Mdot
.19934 .01565 Mdot
.19936 .01544 Mdot
.19939 .01496 Mdot
.19941 .01607 Mdot
.19944 .01566 Mdot
.19947 .01634 Mdot
.19949 .01553 Mdot
.19952 .01664 Mdot
.19954 .01548 Mdot
.19957 .01527 Mdot
.1996 .01707 Mdot
.19962 .01696 Mdot
.19965 .01648 Mdot
.19967 .01542 Mdot
.1997 .01599 Mdot
.19972 .01561 Mdot
.19975 .01561 Mdot
.19978 .01603 Mdot
.1998 .01595 Mdot
.19983 .01644 Mdot
.19985 .01541 Mdot
.19988 .01631 Mdot
.19991 .01619 Mdot
.19993 .01615 Mdot
.19996 .01511 Mdot
.19998 .0158 Mdot
.20001 .01574 Mdot
.20003 .01608 Mdot
.20006 .01502 Mdot
.20009 .01581 Mdot
.20011 .01564 Mdot
.20014 .01527 Mdot
.20016 .01748 Mdot
.20019 .01601 Mdot
.20022 .01644 Mdot
.20024 .01562 Mdot
.20027 .01508 Mdot
.20029 .01506 Mdot
.20032 .01532 Mdot
.20034 .0148 Mdot
.20037 .01541 Mdot
.2004 .01554 Mdot
.20042 .01579 Mdot
.20045 .01568 Mdot
.20047 .01597 Mdot
.2005 .01478 Mdot
.20053 .01654 Mdot
.20055 .01565 Mdot
.20058 .01615 Mdot
.2006 .01523 Mdot
.20063 .01522 Mdot
.20065 .01529 Mdot
.20068 .01526 Mdot
.20071 .01487 Mdot
.20073 .01581 Mdot
.20076 .01486 Mdot
.20078 .01594 Mdot
.20081 .01675 Mdot
.20084 .01555 Mdot
.20086 .01537 Mdot
.20089 .01517 Mdot
.20091 .01598 Mdot
.20094 .01611 Mdot
.20096 .01555 Mdot
.20099 .0156 Mdot
.20102 .01572 Mdot
.20104 .01589 Mdot
.20107 .01577 Mdot
.20109 .01533 Mdot
.20112 .0164 Mdot
.20115 .01548 Mdot
.20117 .01587 Mdot
.2012 .01525 Mdot
.20122 .01541 Mdot
.20125 .01499 Mdot
.20127 .01696 Mdot
.2013 .0163 Mdot
.20133 .01571 Mdot
.20135 .0155 Mdot
.20138 .01632 Mdot
.2014 .01626 Mdot
.20143 .01533 Mdot
.20146 .01592 Mdot
.20148 .01594 Mdot
.20151 .01584 Mdot
.20153 .01624 Mdot
.20156 .01623 Mdot
.20158 .01605 Mdot
.20161 .01615 Mdot
.20164 .01622 Mdot
.20166 .01605 Mdot
.20169 .01588 Mdot
.20171 .01745 Mdot
.20174 .01531 Mdot
.20177 .01596 Mdot
.20179 .01573 Mdot
.20182 .01566 Mdot
.20184 .01622 Mdot
.20187 .0165 Mdot
.20189 .0152 Mdot
.20192 .01635 Mdot
.20195 .01549 Mdot
.20197 .01533 Mdot
.202 .01571 Mdot
.20202 .01603 Mdot
.20205 .01672 Mdot
.20208 .01602 Mdot
.2021 .01725 Mdot
.20213 .01583 Mdot
.20215 .01559 Mdot
.20218 .01596 Mdot
.2022 .01506 Mdot
.20223 .01656 Mdot
.20226 .01595 Mdot
.20228 .01642 Mdot
.20231 .01589 Mdot
.20233 .01582 Mdot
.20236 .01553 Mdot
.20239 .0163 Mdot
.20241 .0149 Mdot
.20244 .01568 Mdot
.20246 .0163 Mdot
.20249 .01604 Mdot
.20251 .01484 Mdot
.20254 .01511 Mdot
.20257 .0152 Mdot
.20259 .01526 Mdot
.20262 .01513 Mdot
.20264 .01801 Mdot
.20267 .01607 Mdot
.2027 .0161 Mdot
.20272 .01492 Mdot
.20275 .01608 Mdot
.20277 .01501 Mdot
.2028 .01755 Mdot
.20283 .01537 Mdot
.20285 .01547 Mdot
.20288 .01643 Mdot
.2029 .01583 Mdot
.20293 .01532 Mdot
.20295 .01539 Mdot
.20298 .0156 Mdot
.20301 .01504 Mdot
.20303 .01597 Mdot
.20306 .0158 Mdot
.20308 .01509 Mdot
.20311 .01635 Mdot
.20314 .01493 Mdot
.20316 .01596 Mdot
.20319 .01506 Mdot
.20321 .01492 Mdot
.20324 .01585 Mdot
.20326 .01599 Mdot
.20329 .01485 Mdot
.20332 .01656 Mdot
.20334 .01604 Mdot
.20337 .01626 Mdot
.20339 .01514 Mdot
.20342 .01615 Mdot
.20345 .01582 Mdot
.20347 .01532 Mdot
.2035 .01522 Mdot
.20352 .01602 Mdot
.20355 .01615 Mdot
.20357 .01476 Mdot
.2036 .01518 Mdot
.20363 .01562 Mdot
.20365 .01534 Mdot
.20368 .0154 Mdot
.2037 .01639 Mdot
.20373 .01551 Mdot
.20376 .01544 Mdot
.20378 .01702 Mdot
.20381 .01556 Mdot
.20383 .01566 Mdot
.20386 .01525 Mdot
.20388 .01655 Mdot
.20391 .01606 Mdot
.20394 .01538 Mdot
.20396 .01621 Mdot
.20399 .01564 Mdot
.20401 .01586 Mdot
.20404 .01629 Mdot
.20407 .01577 Mdot
.20409 .01609 Mdot
.20412 .01553 Mdot
.20414 .01658 Mdot
.20417 .01548 Mdot
.20419 .01563 Mdot
.20422 .01652 Mdot
.20425 .01646 Mdot
.20427 .01486 Mdot
.2043 .01656 Mdot
.20432 .01632 Mdot
.20435 .01744 Mdot
.20438 .01591 Mdot
.2044 .01647 Mdot
.20443 .01506 Mdot
.20445 .0159 Mdot
.20448 .01505 Mdot
.2045 .0162 Mdot
.20453 .01581 Mdot
.20456 .01515 Mdot
.20458 .01709 Mdot
.20461 .01568 Mdot
.20463 .01548 Mdot
.20466 .01558 Mdot
.20469 .0151 Mdot
.20471 .01602 Mdot
.20474 .01541 Mdot
.20476 .01557 Mdot
.20479 .01523 Mdot
.20481 .01605 Mdot
.20484 .01533 Mdot
.20487 .01592 Mdot
.20489 .01616 Mdot
.20492 .016 Mdot
.20494 .01518 Mdot
.20497 .01516 Mdot
.205 .01525 Mdot
.20502 .01541 Mdot
.20505 .01554 Mdot
.20507 .01572 Mdot
.2051 .01611 Mdot
.20512 .01526 Mdot
.20515 .01536 Mdot
.20518 .01539 Mdot
.2052 .016 Mdot
.20523 .0153 Mdot
.20525 .01474 Mdot
.20528 .01568 Mdot
.20531 .01582 Mdot
.20533 .01519 Mdot
.20536 .01525 Mdot
.20538 .01514 Mdot
.20541 .01676 Mdot
.20543 .0157 Mdot
.20546 .01659 Mdot
.20549 .016 Mdot
.20551 .01586 Mdot
.20554 .01656 Mdot
.20556 .01508 Mdot
.20559 .01498 Mdot
.20562 .0163 Mdot
.20564 .016 Mdot
.20567 .01535 Mdot
.20569 .01557 Mdot
.20572 .01501 Mdot
.20574 .01546 Mdot
.20577 .01582 Mdot
.2058 .01562 Mdot
.20582 .0156 Mdot
.20585 .01573 Mdot
.20587 .01576 Mdot
.2059 .0153 Mdot
.20593 .01593 Mdot
.20595 .01521 Mdot
.20598 .01693 Mdot
.206 .01536 Mdot
.20603 .01527 Mdot
.20605 .0156 Mdot
.20608 .01522 Mdot
.20611 .01595 Mdot
.20613 .01703 Mdot
.20616 .01595 Mdot
.20618 .0149 Mdot
.20621 .01591 Mdot
.20624 .0151 Mdot
.20626 .0166 Mdot
.20629 .01523 Mdot
.20631 .01583 Mdot
.20634 .01521 Mdot
.20636 .01541 Mdot
.20639 .01688 Mdot
.20642 .0151 Mdot
.20644 .01548 Mdot
.20647 .01546 Mdot
.20649 .01648 Mdot
.20652 .01644 Mdot
.20655 .01675 Mdot
.20657 .01537 Mdot
.2066 .01537 Mdot
.20662 .01527 Mdot
.20665 .01578 Mdot
.20667 .01555 Mdot
.2067 .01574 Mdot
.20673 .01602 Mdot
.20675 .01557 Mdot
.20678 .01604 Mdot
.2068 .01529 Mdot
.20683 .01577 Mdot
.20686 .0159 Mdot
.20688 .01677 Mdot
.20691 .01648 Mdot
.20693 .01533 Mdot
.20696 .01515 Mdot
.20698 .01538 Mdot
.20701 .01492 Mdot
.20704 .01567 Mdot
.20706 .01569 Mdot
.20709 .01645 Mdot
.20711 .01649 Mdot
.20714 .01578 Mdot
.20717 .01605 Mdot
.20719 .01564 Mdot
.20722 .01621 Mdot
.20724 .01596 Mdot
.20727 .01539 Mdot
.20729 .01573 Mdot
.20732 .01526 Mdot
.20735 .01639 Mdot
.20737 .01574 Mdot
.2074 .01629 Mdot
.20742 .01547 Mdot
.20745 .0156 Mdot
.20748 .01555 Mdot
.2075 .01522 Mdot
.20753 .01578 Mdot
.20755 .01555 Mdot
.20758 .01611 Mdot
.2076 .01604 Mdot
.20763 .01659 Mdot
.20766 .01523 Mdot
.20768 .01601 Mdot
.20771 .01499 Mdot
.20773 .01475 Mdot
.20776 .01684 Mdot
.20779 .01649 Mdot
.20781 .01571 Mdot
.20784 .01587 Mdot
.20786 .01574 Mdot
.20789 .01545 Mdot
.20791 .01496 Mdot
.20794 .01629 Mdot
.20797 .01577 Mdot
.20799 .01612 Mdot
.20802 .0157 Mdot
.20804 .01517 Mdot
.20807 .0159 Mdot
.2081 .01505 Mdot
.20812 .01607 Mdot
.20815 .01576 Mdot
.20817 .01586 Mdot
.2082 .01581 Mdot
.20822 .01597 Mdot
.20825 .01558 Mdot
.20828 .0154 Mdot
.2083 .01496 Mdot
.20833 .01511 Mdot
.20835 .01585 Mdot
.20838 .01559 Mdot
.20841 .0153 Mdot
.20843 .01527 Mdot
.20846 .01558 Mdot
.20848 .01607 Mdot
.20851 .01617 Mdot
.20853 .01589 Mdot
.20856 .01605 Mdot
.20859 .01494 Mdot
.20861 .0153 Mdot
.20864 .0162 Mdot
.20866 .01585 Mdot
.20869 .01501 Mdot
.20872 .01681 Mdot
.20874 .01575 Mdot
.20877 .01546 Mdot
.20879 .01624 Mdot
.20882 .01524 Mdot
.20884 .01515 Mdot
.20887 .01645 Mdot
.2089 .01579 Mdot
.20892 .01492 Mdot
.20895 .01653 Mdot
.20897 .01514 Mdot
.209 .01539 Mdot
.20903 .01639 Mdot
.20905 .01489 Mdot
.20908 .016 Mdot
.2091 .0163 Mdot
.20913 .01581 Mdot
.20915 .01624 Mdot
.20918 .01552 Mdot
.20921 .01544 Mdot
.20923 .0158 Mdot
.20926 .01525 Mdot
.20928 .01526 Mdot
.20931 .01589 Mdot
.20934 .01591 Mdot
.20936 .01582 Mdot
.20939 .01499 Mdot
.20941 .01623 Mdot
.20944 .01553 Mdot
.20946 .01596 Mdot
.20949 .01712 Mdot
.20952 .01507 Mdot
.20954 .016 Mdot
.20957 .01603 Mdot
.20959 .01563 Mdot
.20962 .01479 Mdot
.20965 .01611 Mdot
.20967 .01612 Mdot
.2097 .01587 Mdot
.20972 .01544 Mdot
.20975 .01531 Mdot
.20977 .01624 Mdot
.2098 .01476 Mdot
.20983 .01514 Mdot
.20985 .01604 Mdot
.20988 .01519 Mdot
.2099 .01535 Mdot
.20993 .01636 Mdot
.20996 .01648 Mdot
.20998 .01581 Mdot
.21001 .01587 Mdot
.21003 .0166 Mdot
.21006 .01566 Mdot
.21008 .01532 Mdot
.21011 .01544 Mdot
.21014 .01615 Mdot
.21016 .01565 Mdot
.21019 .01546 Mdot
.21021 .01561 Mdot
.21024 .01632 Mdot
.21027 .01806 Mdot
.21029 .01501 Mdot
.21032 .01536 Mdot
.21034 .01616 Mdot
.21037 .01633 Mdot
.21039 .01563 Mdot
.21042 .0159 Mdot
.21045 .01611 Mdot
.21047 .01621 Mdot
.2105 .01602 Mdot
.21052 .01619 Mdot
.21055 .01555 Mdot
.21058 .01504 Mdot
.2106 .01591 Mdot
.21063 .0172 Mdot
.21065 .01663 Mdot
.21068 .01505 Mdot
.2107 .01664 Mdot
.21073 .01507 Mdot
.21076 .01589 Mdot
.21078 .01538 Mdot
.21081 .0165 Mdot
.21083 .01498 Mdot
.21086 .01675 Mdot
.21089 .01585 Mdot
.21091 .01531 Mdot
.21094 .01558 Mdot
.21096 .01605 Mdot
.21099 .01487 Mdot
.21101 .0153 Mdot
.21104 .01653 Mdot
.21107 .01566 Mdot
.21109 .01518 Mdot
.21112 .01777 Mdot
.21114 .01537 Mdot
.21117 .01701 Mdot
.2112 .01559 Mdot
.21122 .01504 Mdot
.21125 .0161 Mdot
.21127 .01497 Mdot
.2113 .01517 Mdot
.21132 .01612 Mdot
.21135 .01667 Mdot
.21138 .01551 Mdot
.2114 .01652 Mdot
.21143 .0159 Mdot
.21145 .01617 Mdot
.21148 .01557 Mdot
.21151 .01495 Mdot
.21153 .01573 Mdot
.21156 .01714 Mdot
.21158 .01523 Mdot
.21161 .01639 Mdot
.21163 .0158 Mdot
.21166 .01657 Mdot
.21169 .01668 Mdot
.21171 .01607 Mdot
.21174 .01543 Mdot
.21176 .01501 Mdot
.21179 .01584 Mdot
.21182 .01637 Mdot
.21184 .01483 Mdot
.21187 .01687 Mdot
.21189 .01527 Mdot
.21192 .01517 Mdot
.21195 .01535 Mdot
.21197 .01489 Mdot
.212 .01615 Mdot
.21202 .01535 Mdot
.21205 .01551 Mdot
.21207 .01526 Mdot
.2121 .0153 Mdot
.21213 .01622 Mdot
.21215 .01613 Mdot
.21218 .01535 Mdot
.2122 .01563 Mdot
.21223 .01559 Mdot
.21226 .01619 Mdot
.21228 .01543 Mdot
.21231 .01542 Mdot
.21233 .01493 Mdot
.21236 .01516 Mdot
.21238 .01667 Mdot
.21241 .01513 Mdot
.21244 .01506 Mdot
.21246 .01586 Mdot
.21249 .01554 Mdot
.21251 .01587 Mdot
.21254 .01659 Mdot
.21257 .01563 Mdot
.21259 .01608 Mdot
.21262 .01556 Mdot
.21264 .01554 Mdot
.21267 .0167 Mdot
.21269 .01591 Mdot
.21272 .01518 Mdot
.21275 .01641 Mdot
.21277 .01483 Mdot
.2128 .0155 Mdot
.21282 .01509 Mdot
.21285 .01522 Mdot
.21288 .01559 Mdot
.2129 .01541 Mdot
.21293 .01532 Mdot
.21295 .01491 Mdot
.21298 .01616 Mdot
.213 .01653 Mdot
.21303 .01533 Mdot
.21306 .01589 Mdot
.21308 .0156 Mdot
.21311 .01618 Mdot
.21313 .01633 Mdot
.21316 .01628 Mdot
.21319 .01486 Mdot
.21321 .01586 Mdot
.21324 .01737 Mdot
.21326 .0155 Mdot
.21329 .01541 Mdot
.21331 .01639 Mdot
.21334 .01542 Mdot
.21337 .01624 Mdot
.21339 .01539 Mdot
.21342 .01521 Mdot
.21344 .01513 Mdot
.21347 .01591 Mdot
.2135 .01624 Mdot
.21352 .01642 Mdot
.21355 .01563 Mdot
.21357 .01539 Mdot
.2136 .01511 Mdot
.21362 .01644 Mdot
.21365 .01672 Mdot
.21368 .01616 Mdot
.2137 .01483 Mdot
.21373 .01594 Mdot
.21375 .01506 Mdot
.21378 .01548 Mdot
.21381 .01488 Mdot
.21383 .01575 Mdot
.21386 .01523 Mdot
.21388 .01551 Mdot
.21391 .01509 Mdot
.21393 .0159 Mdot
.21396 .01547 Mdot
.21399 .01551 Mdot
.21401 .0152 Mdot
.21404 .01581 Mdot
.21406 .01629 Mdot
.21409 .01708 Mdot
.21412 .01504 Mdot
.21414 .01484 Mdot
.21417 .01541 Mdot
.21419 .01548 Mdot
.21422 .01558 Mdot
.21424 .01525 Mdot
.21427 .01499 Mdot
.2143 .01596 Mdot
.21432 .01535 Mdot
.21435 .01559 Mdot
.21437 .01504 Mdot
.2144 .0162 Mdot
.21443 .01585 Mdot
.21445 .0162 Mdot
.21448 .01606 Mdot
.2145 .0165 Mdot
.21453 .01531 Mdot
.21455 .01547 Mdot
.21458 .01606 Mdot
.21461 .01513 Mdot
.21463 .01502 Mdot
.21466 .01519 Mdot
.21468 .01663 Mdot
.21471 .01592 Mdot
.21474 .0159 Mdot
.21476 .0164 Mdot
.21479 .01589 Mdot
.21481 .0148 Mdot
.21484 .01523 Mdot
.21486 .01556 Mdot
.21489 .01643 Mdot
.21492 .0155 Mdot
.21494 .01507 Mdot
.21497 .01568 Mdot
.21499 .01635 Mdot
.21502 .01629 Mdot
.21505 .01545 Mdot
.21507 .01609 Mdot
.2151 .01588 Mdot
.21512 .01591 Mdot
.21515 .01545 Mdot
.21517 .015 Mdot
.2152 .01613 Mdot
.21523 .01595 Mdot
.21525 .01556 Mdot
.21528 .01615 Mdot
.2153 .0161 Mdot
.21533 .01537 Mdot
.21536 .01607 Mdot
.21538 .01674 Mdot
.21541 .01612 Mdot
.21543 .01573 Mdot
.21546 .0156 Mdot
.21548 .01518 Mdot
.21551 .01574 Mdot
.21554 .01626 Mdot
.21556 .01655 Mdot
.21559 .01622 Mdot
.21561 .01615 Mdot
.21564 .0152 Mdot
.21567 .01645 Mdot
.21569 .01602 Mdot
.21572 .01579 Mdot
.21574 .01564 Mdot
.21577 .01519 Mdot
.21579 .01522 Mdot
.21582 .01665 Mdot
.21585 .01586 Mdot
.21587 .01586 Mdot
.2159 .01545 Mdot
.21592 .01584 Mdot
.21595 .01508 Mdot
.21598 .01543 Mdot
.216 .01478 Mdot
.21603 .01673 Mdot
.21605 .01492 Mdot
.21608 .0168 Mdot
.2161 .01632 Mdot
.21613 .01513 Mdot
.21616 .01558 Mdot
.21618 .01701 Mdot
.21621 .01549 Mdot
.21623 .01565 Mdot
.21626 .01556 Mdot
.21629 .01588 Mdot
.21631 .01584 Mdot
.21634 .01527 Mdot
.21636 .01552 Mdot
.21639 .01528 Mdot
.21641 .01601 Mdot
.21644 .01521 Mdot
.21647 .01573 Mdot
.21649 .01555 Mdot
.21652 .01626 Mdot
.21654 .01656 Mdot
.21657 .01517 Mdot
.2166 .01516 Mdot
.21662 .01519 Mdot
.21665 .01591 Mdot
.21667 .01497 Mdot
.2167 .01531 Mdot
.21672 .01542 Mdot
.21675 .01568 Mdot
.21678 .01598 Mdot
.2168 .01571 Mdot
.21683 .0155 Mdot
.21685 .0156 Mdot
.21688 .01519 Mdot
.21691 .01637 Mdot
.21693 .01583 Mdot
.21696 .01606 Mdot
.21698 .01588 Mdot
.21701 .01485 Mdot
.21703 .01554 Mdot
.21706 .01598 Mdot
.21709 .01656 Mdot
.21711 .0149 Mdot
.21714 .01536 Mdot
.21716 .01516 Mdot
.21719 .01494 Mdot
.21722 .01587 Mdot
.21724 .01565 Mdot
.21727 .01627 Mdot
.21729 .01555 Mdot
.21732 .01583 Mdot
.21734 .01629 Mdot
.21737 .01538 Mdot
.2174 .01699 Mdot
.21742 .01632 Mdot
.21745 .01573 Mdot
.21747 .01632 Mdot
.2175 .01602 Mdot
.21753 .01581 Mdot
.21755 .01548 Mdot
.21758 .01559 Mdot
.2176 .01655 Mdot
.21763 .01579 Mdot
.21765 .01534 Mdot
.21768 .01664 Mdot
.21771 .01591 Mdot
.21773 .01533 Mdot
.21776 .01574 Mdot
.21778 .01525 Mdot
.21781 .01578 Mdot
.21784 .015 Mdot
.21786 .01683 Mdot
.21789 .01624 Mdot
.21791 .0153 Mdot
.21794 .01614 Mdot
.21796 .01549 Mdot
.21799 .01493 Mdot
.21802 .01509 Mdot
.21804 .016 Mdot
.21807 .01546 Mdot
.21809 .01529 Mdot
.21812 .01538 Mdot
.21815 .01665 Mdot
.21817 .01583 Mdot
.2182 .01534 Mdot
.21822 .0158 Mdot
.21825 .0164 Mdot
.21827 .01516 Mdot
.2183 .01692 Mdot
.21833 .01579 Mdot
.21835 .01522 Mdot
.21838 .01601 Mdot
.2184 .01512 Mdot
.21843 .01544 Mdot
.21846 .01531 Mdot
.21848 .01493 Mdot
.21851 .01678 Mdot
.21853 .01552 Mdot
.21856 .01585 Mdot
.21858 .01544 Mdot
.21861 .01588 Mdot
.21864 .01502 Mdot
.21866 .01536 Mdot
.21869 .0152 Mdot
.21871 .01508 Mdot
.21874 .01608 Mdot
.21877 .01634 Mdot
.21879 .01506 Mdot
.21882 .01475 Mdot
.21884 .01554 Mdot
.21887 .01483 Mdot
.21889 .01654 Mdot
.21892 .01524 Mdot
.21895 .01703 Mdot
.21897 .01622 Mdot
.219 .01651 Mdot
.21902 .01555 Mdot
.21905 .0157 Mdot
.21908 .01614 Mdot
.2191 .01543 Mdot
.21913 .0164 Mdot
.21915 .01534 Mdot
.21918 .01513 Mdot
.2192 .01484 Mdot
.21923 .01576 Mdot
.21926 .01643 Mdot
.21928 .01479 Mdot
.21931 .01512 Mdot
.21933 .01583 Mdot
.21936 .01551 Mdot
.21939 .01572 Mdot
.21941 .01605 Mdot
.21944 .01591 Mdot
.21946 .01584 Mdot
.21949 .01592 Mdot
.21951 .0159 Mdot
.21954 .01632 Mdot
.21957 .01524 Mdot
.21959 .01599 Mdot
.21962 .01744 Mdot
.21964 .01501 Mdot
.21967 .01641 Mdot
.2197 .01575 Mdot
.21972 .01591 Mdot
.21975 .01531 Mdot
.21977 .01562 Mdot
.2198 .01539 Mdot
.21982 .01497 Mdot
.21985 .01685 Mdot
.21988 .01539 Mdot
.2199 .01561 Mdot
.21993 .01538 Mdot
.21995 .01527 Mdot
.21998 .01492 Mdot
.22001 .01502 Mdot
.22003 .01572 Mdot
.22006 .01567 Mdot
.22008 .01521 Mdot
.22011 .0156 Mdot
.22013 .01511 Mdot
.22016 .01549 Mdot
.22019 .0154 Mdot
.22021 .01541 Mdot
.22024 .01608 Mdot
.22026 .01499 Mdot
.22029 .01551 Mdot
.22032 .01688 Mdot
.22034 .0153 Mdot
.22037 .01551 Mdot
.22039 .01613 Mdot
.22042 .01538 Mdot
.22044 .01627 Mdot
.22047 .01539 Mdot
.2205 .01565 Mdot
.22052 .01563 Mdot
.22055 .01531 Mdot
.22057 .01648 Mdot
.2206 .01542 Mdot
.22063 .01601 Mdot
.22065 .01514 Mdot
.22068 .01506 Mdot
.2207 .0155 Mdot
.22073 .016 Mdot
.22075 .01587 Mdot
.22078 .01631 Mdot
.22081 .01517 Mdot
.22083 .01482 Mdot
.22086 .01504 Mdot
.22088 .01601 Mdot
.22091 .01512 Mdot
.22094 .01487 Mdot
.22096 .016 Mdot
.22099 .01534 Mdot
.22101 .01639 Mdot
.22104 .01617 Mdot
.22106 .01608 Mdot
.22109 .0154 Mdot
.22112 .01606 Mdot
.22114 .01615 Mdot
.22117 .01531 Mdot
.22119 .01561 Mdot
.22122 .01566 Mdot
.22125 .01533 Mdot
.22127 .01611 Mdot
.2213 .01533 Mdot
.22132 .01574 Mdot
.22135 .016 Mdot
.22138 .01503 Mdot
.2214 .01582 Mdot
.22143 .01632 Mdot
.22145 .01612 Mdot
.22148 .01567 Mdot
.2215 .01553 Mdot
.22153 .01643 Mdot
.22156 .01499 Mdot
.22158 .01616 Mdot
.22161 .01555 Mdot
.22163 .01536 Mdot
.22166 .01561 Mdot
.22169 .01535 Mdot
.22171 .01604 Mdot
.22174 .0179 Mdot
.22176 .01672 Mdot
.22179 .01645 Mdot
.22181 .01557 Mdot
.22184 .01585 Mdot
.22187 .01499 Mdot
.22189 .01586 Mdot
.22192 .0153 Mdot
.22194 .01523 Mdot
.22197 .01539 Mdot
.222 .01588 Mdot
.22202 .01662 Mdot
.22205 .01605 Mdot
.22207 .01653 Mdot
.2221 .01493 Mdot
.22212 .01662 Mdot
.22215 .01498 Mdot
.22218 .0163 Mdot
.2222 .01555 Mdot
.22223 .01596 Mdot
.22225 .01585 Mdot
.22228 .01605 Mdot
.22231 .01676 Mdot
.22233 .0162 Mdot
.22236 .01662 Mdot
.22238 .01503 Mdot
.22241 .01491 Mdot
.22243 .01543 Mdot
.22246 .01641 Mdot
.22249 .01525 Mdot
.22251 .0157 Mdot
.22254 .01584 Mdot
.22256 .01607 Mdot
.22259 .01614 Mdot
.22262 .01547 Mdot
.22264 .01505 Mdot
.22267 .01651 Mdot
.22269 .01602 Mdot
.22272 .01546 Mdot
.22274 .015 Mdot
.22277 .01685 Mdot
.2228 .01546 Mdot
.22282 .01675 Mdot
.22285 .01681 Mdot
.22287 .01652 Mdot
.2229 .01537 Mdot
.22293 .01549 Mdot
.22295 .01607 Mdot
.22298 .01578 Mdot
.223 .01588 Mdot
.22303 .01611 Mdot
.22305 .01638 Mdot
.22308 .0148 Mdot
.22311 .01509 Mdot
.22313 .01539 Mdot
.22316 .01554 Mdot
.22318 .01554 Mdot
.22321 .01617 Mdot
.22324 .01537 Mdot
.22326 .01547 Mdot
.22329 .0157 Mdot
.22331 .01581 Mdot
.22334 .01569 Mdot
.22336 .01569 Mdot
.22339 .01556 Mdot
.22342 .01627 Mdot
.22344 .01629 Mdot
.22347 .01588 Mdot
.22349 .01608 Mdot
.22352 .01573 Mdot
.22355 .01566 Mdot
.22357 .01608 Mdot
.2236 .01534 Mdot
.22362 .01512 Mdot
.22365 .01635 Mdot
.22367 .01538 Mdot
.2237 .01585 Mdot
.22373 .01511 Mdot
.22375 .0157 Mdot
.22378 .01536 Mdot
.2238 .01552 Mdot
.22383 .0152 Mdot
.22386 .01552 Mdot
.22388 .01586 Mdot
.22391 .01552 Mdot
.22393 .01552 Mdot
.22396 .0155 Mdot
.22398 .01582 Mdot
.22401 .01733 Mdot
.22404 .01566 Mdot
.22406 .01516 Mdot
.22409 .01601 Mdot
.22411 .01599 Mdot
.22414 .01521 Mdot
.22417 .0164 Mdot
.22419 .01635 Mdot
.22422 .01553 Mdot
.22424 .01573 Mdot
.22427 .0165 Mdot
.22429 .01524 Mdot
.22432 .01495 Mdot
.22435 .01519 Mdot
.22437 .01587 Mdot
.2244 .01559 Mdot
.22442 .01599 Mdot
.22445 .01616 Mdot
.22448 .0165 Mdot
.2245 .01574 Mdot
.22453 .01592 Mdot
.22455 .01581 Mdot
.22458 .01589 Mdot
.2246 .01503 Mdot
.22463 .01637 Mdot
.22466 .01562 Mdot
.22468 .01509 Mdot
.22471 .01559 Mdot
.22473 .01515 Mdot
.22476 .01599 Mdot
.22479 .0151 Mdot
.22481 .01614 Mdot
.22484 .01834 Mdot
.22486 .0155 Mdot
.22489 .01609 Mdot
.22491 .01583 Mdot
.22494 .0161 Mdot
.22497 .01562 Mdot
.22499 .01527 Mdot
.22502 .01614 Mdot
.22504 .0157 Mdot
.22507 .01634 Mdot
.2251 .01551 Mdot
.22512 .01544 Mdot
.22515 .01506 Mdot
.22517 .01563 Mdot
.2252 .01535 Mdot
.22522 .01634 Mdot
.22525 .01543 Mdot
.22528 .01578 Mdot
.2253 .01545 Mdot
.22533 .01519 Mdot
.22535 .01588 Mdot
.22538 .01517 Mdot
.22541 .01551 Mdot
.22543 .01545 Mdot
.22546 .01587 Mdot
.22548 .0167 Mdot
.22551 .0157 Mdot
.22553 .01645 Mdot
.22556 .01652 Mdot
.22559 .01542 Mdot
.22561 .01683 Mdot
.22564 .01601 Mdot
.22566 .01591 Mdot
.22569 .01581 Mdot
.22572 .0162 Mdot
.22574 .0164 Mdot
.22577 .01526 Mdot
.22579 .01569 Mdot
.22582 .01723 Mdot
.22584 .01585 Mdot
.22587 .0152 Mdot
.2259 .01569 Mdot
.22592 .01564 Mdot
.22595 .01558 Mdot
.22597 .01569 Mdot
.226 .01628 Mdot
.22603 .01583 Mdot
.22605 .0154 Mdot
.22608 .01608 Mdot
.2261 .01579 Mdot
.22613 .01536 Mdot
.22615 .01623 Mdot
.22618 .01526 Mdot
.22621 .01571 Mdot
.22623 .0168 Mdot
.22626 .01557 Mdot
.22628 .01504 Mdot
.22631 .01481 Mdot
.22634 .01505 Mdot
.22636 .0162 Mdot
.22639 .01629 Mdot
.22641 .01651 Mdot
.22644 .015 Mdot
.22646 .01486 Mdot
.22649 .01591 Mdot
.22652 .01603 Mdot
.22654 .01644 Mdot
.22657 .01573 Mdot
.22659 .01591 Mdot
.22662 .01587 Mdot
.22665 .01677 Mdot
.22667 .01714 Mdot
.2267 .01645 Mdot
.22672 .01657 Mdot
.22675 .0151 Mdot
.22677 .0154 Mdot
.2268 .01634 Mdot
.22683 .01584 Mdot
.22685 .01671 Mdot
.22688 .01543 Mdot
.2269 .01546 Mdot
.22693 .0158 Mdot
.22696 .01628 Mdot
.22698 .0155 Mdot
.22701 .01544 Mdot
.22703 .01552 Mdot
.22706 .01575 Mdot
.22708 .01495 Mdot
.22711 .01599 Mdot
.22714 .01522 Mdot
.22716 .01503 Mdot
.22719 .01552 Mdot
.22721 .01585 Mdot
.22724 .0161 Mdot
.22727 .01681 Mdot
.22729 .01779 Mdot
.22732 .0152 Mdot
.22734 .01576 Mdot
.22737 .01565 Mdot
.22739 .01536 Mdot
.22742 .01552 Mdot
.22745 .01553 Mdot
.22747 .01544 Mdot
.2275 .01549 Mdot
.22752 .01586 Mdot
.22755 .01604 Mdot
.22758 .01517 Mdot
.2276 .01533 Mdot
.22763 .01577 Mdot
.22765 .01649 Mdot
.22768 .01569 Mdot
.2277 .01553 Mdot
.22773 .01598 Mdot
.22776 .01516 Mdot
.22778 .01577 Mdot
.22781 .01657 Mdot
.22783 .01595 Mdot
.22786 .01576 Mdot
.22789 .01548 Mdot
.22791 .01609 Mdot
.22794 .01521 Mdot
.22796 .01621 Mdot
.22799 .01523 Mdot
.22801 .01531 Mdot
.22804 .01502 Mdot
.22807 .01689 Mdot
.22809 .01611 Mdot
.22812 .01541 Mdot
.22814 .01479 Mdot
.22817 .01517 Mdot
.2282 .01485 Mdot
.22822 .01607 Mdot
.22825 .01566 Mdot
.22827 .01665 Mdot
.2283 .01549 Mdot
.22832 .01654 Mdot
.22835 .01533 Mdot
.22838 .01566 Mdot
.2284 .01601 Mdot
.22843 .01495 Mdot
.22845 .01636 Mdot
.22848 .016 Mdot
.22851 .01568 Mdot
.22853 .01501 Mdot
.22856 .01522 Mdot
.22858 .01684 Mdot
.22861 .01542 Mdot
.22863 .01582 Mdot
.22866 .01654 Mdot
.22869 .01538 Mdot
.22871 .01661 Mdot
.22874 .01538 Mdot
.22876 .01653 Mdot
.22879 .0159 Mdot
.22882 .01571 Mdot
.22884 .01527 Mdot
.22887 .01662 Mdot
.22889 .01582 Mdot
.22892 .01572 Mdot
.22894 .01584 Mdot
.22897 .01587 Mdot
.229 .01579 Mdot
.22902 .01513 Mdot
.22905 .01678 Mdot
.22907 .01514 Mdot
.2291 .01542 Mdot
.22913 .01569 Mdot
.22915 .0151 Mdot
.22918 .015 Mdot
.2292 .01515 Mdot
.22923 .01565 Mdot
.22925 .01611 Mdot
.22928 .01686 Mdot
.22931 .01647 Mdot
.22933 .01606 Mdot
.22936 .01543 Mdot
.22938 .01525 Mdot
.22941 .0157 Mdot
.22944 .01561 Mdot
.22946 .01582 Mdot
.22949 .01649 Mdot
.22951 .01576 Mdot
.22954 .01664 Mdot
.22956 .01528 Mdot
.22959 .01533 Mdot
.22962 .01713 Mdot
.22964 .01747 Mdot
.22967 .01594 Mdot
.22969 .01593 Mdot
.22972 .01566 Mdot
.22975 .01535 Mdot
.22977 .0167 Mdot
.2298 .01609 Mdot
.22982 .01562 Mdot
.22985 .01496 Mdot
.22987 .0167 Mdot
.2299 .01578 Mdot
.22993 .01561 Mdot
.22995 .01564 Mdot
.22998 .01533 Mdot
.23 .01533 Mdot
.23003 .01554 Mdot
.23006 .01651 Mdot
.23008 .0156 Mdot
.23011 .01517 Mdot
.23013 .01582 Mdot
.23016 .01632 Mdot
.23018 .01696 Mdot
.23021 .01648 Mdot
.23024 .01486 Mdot
.23026 .01601 Mdot
.23029 .01542 Mdot
.23031 .01561 Mdot
.23034 .01586 Mdot
.23037 .01588 Mdot
.23039 .0154 Mdot
.23042 .0157 Mdot
.23044 .01634 Mdot
.23047 .01525 Mdot
.2305 .0156 Mdot
.23052 .01528 Mdot
.23055 .01543 Mdot
.23057 .01664 Mdot
.2306 .01536 Mdot
.23062 .01587 Mdot
.23065 .01521 Mdot
.23068 .01573 Mdot
.2307 .01577 Mdot
.23073 .01706 Mdot
.23075 .01515 Mdot
.23078 .01536 Mdot
.23081 .0155 Mdot
.23083 .01559 Mdot
.23086 .01546 Mdot
.23088 .01521 Mdot
.23091 .01473 Mdot
.23093 .01501 Mdot
.23096 .01595 Mdot
.23099 .01653 Mdot
.23101 .01697 Mdot
.23104 .01567 Mdot
.23106 .01629 Mdot
.23109 .01592 Mdot
.23112 .01583 Mdot
.23114 .01612 Mdot
.23117 .01686 Mdot
.23119 .01543 Mdot
.23122 .01694 Mdot
.23124 .01536 Mdot
.23127 .01616 Mdot
.2313 .01678 Mdot
.23132 .01602 Mdot
.23135 .01566 Mdot
.23137 .01529 Mdot
.2314 .01556 Mdot
.23143 .01572 Mdot
.23145 .01564 Mdot
.23148 .01606 Mdot
.2315 .01612 Mdot
.23153 .01575 Mdot
.23155 .01731 Mdot
.23158 .01556 Mdot
.23161 .01491 Mdot
.23163 .01552 Mdot
.23166 .01577 Mdot
.23168 .01601 Mdot
.23171 .01608 Mdot
.23174 .01486 Mdot
.23176 .0153 Mdot
.23179 .01628 Mdot
.23181 .0154 Mdot
.23184 .01617 Mdot
.23186 .01536 Mdot
.23189 .01495 Mdot
.23192 .01547 Mdot
.23194 .01632 Mdot
.23197 .01516 Mdot
.23199 .01601 Mdot
.23202 .01733 Mdot
.23205 .01628 Mdot
.23207 .01516 Mdot
.2321 .01606 Mdot
.23212 .01605 Mdot
.23215 .0154 Mdot
.23217 .01506 Mdot
.2322 .01639 Mdot
.23223 .01607 Mdot
.23225 .01539 Mdot
.23228 .0152 Mdot
.2323 .01633 Mdot
.23233 .01513 Mdot
.23236 .015 Mdot
.23238 .01547 Mdot
.23241 .01548 Mdot
.23243 .01568 Mdot
.23246 .01598 Mdot
.23248 .015 Mdot
.23251 .01549 Mdot
.23254 .01575 Mdot
.23256 .01698 Mdot
.23259 .01521 Mdot
.23261 .0153 Mdot
.23264 .0165 Mdot
.23267 .0165 Mdot
.23269 .01561 Mdot
.23272 .01554 Mdot
.23274 .01665 Mdot
.23277 .01583 Mdot
.23279 .01531 Mdot
.23282 .01567 Mdot
.23285 .01584 Mdot
.23287 .0168 Mdot
.2329 .0175 Mdot
.23292 .01497 Mdot
.23295 .01623 Mdot
.23298 .01531 Mdot
.233 .0164 Mdot
.23303 .01532 Mdot
.23305 .01563 Mdot
.23308 .01502 Mdot
.2331 .01515 Mdot
.23313 .01637 Mdot
.23316 .01537 Mdot
.23318 .01578 Mdot
.23321 .01492 Mdot
.23323 .01486 Mdot
.23326 .01598 Mdot
.23329 .01511 Mdot
.23331 .01575 Mdot
.23334 .01662 Mdot
.23336 .01571 Mdot
.23339 .01512 Mdot
.23341 .01544 Mdot
.23344 .01505 Mdot
.23347 .0155 Mdot
.23349 .01541 Mdot
.23352 .01603 Mdot
.23354 .01576 Mdot
.23357 .01513 Mdot
.2336 .01531 Mdot
.23362 .01516 Mdot
.23365 .01637 Mdot
.23367 .01616 Mdot
.2337 .01518 Mdot
.23372 .01733 Mdot
.23375 .01611 Mdot
.23378 .01571 Mdot
.2338 .01591 Mdot
.23383 .01585 Mdot
.23385 .01633 Mdot
.23388 .01562 Mdot
.23391 .01675 Mdot
.23393 .01563 Mdot
.23396 .01678 Mdot
.23398 .01668 Mdot
.23401 .01552 Mdot
.23403 .01551 Mdot
.23406 .01567 Mdot
.23409 .01512 Mdot
.23411 .01564 Mdot
.23414 .01501 Mdot
.23416 .01525 Mdot
.23419 .01643 Mdot
.23422 .01564 Mdot
.23424 .01619 Mdot
.23427 .01521 Mdot
.23429 .01526 Mdot
.23432 .01584 Mdot
.23434 .0163 Mdot
.23437 .015 Mdot
.2344 .0153 Mdot
.23442 .0151 Mdot
.23445 .01568 Mdot
.23447 .0155 Mdot
.2345 .01611 Mdot
.23453 .01627 Mdot
.23455 .01552 Mdot
.23458 .01566 Mdot
.2346 .0157 Mdot
.23463 .01588 Mdot
.23465 .01636 Mdot
.23468 .01502 Mdot
.23471 .01499 Mdot
.23473 .0155 Mdot
.23476 .01587 Mdot
.23478 .01545 Mdot
.23481 .01619 Mdot
.23484 .01591 Mdot
.23486 .01632 Mdot
.23489 .01556 Mdot
.23491 .01506 Mdot
.23494 .01704 Mdot
.23496 .01515 Mdot
.23499 .01575 Mdot
.23502 .01514 Mdot
.23504 .01628 Mdot
.23507 .01527 Mdot
.23509 .01629 Mdot
.23512 .01609 Mdot
.23515 .0157 Mdot
.23517 .01504 Mdot
.2352 .01619 Mdot
.23522 .01517 Mdot
.23525 .01494 Mdot
.23527 .01579 Mdot
.2353 .01582 Mdot
.23533 .01582 Mdot
.23535 .0158 Mdot
.23538 .01571 Mdot
.2354 .01672 Mdot
.23543 .01576 Mdot
.23546 .01614 Mdot
.23548 .01574 Mdot
.23551 .01569 Mdot
.23553 .01533 Mdot
.23556 .0163 Mdot
.23558 .01667 Mdot
.23561 .01606 Mdot
.23564 .01511 Mdot
.23566 .0153 Mdot
.23569 .01473 Mdot
.23571 .015 Mdot
.23574 .01575 Mdot
.23577 .01641 Mdot
.23579 .0163 Mdot
.23582 .01521 Mdot
.23584 .01761 Mdot
.23587 .01569 Mdot
.23589 .01592 Mdot
.23592 .01572 Mdot
.23595 .01558 Mdot
.23597 .01631 Mdot
.236 .01617 Mdot
.23602 .01517 Mdot
.23605 .01557 Mdot
.23608 .01529 Mdot
.2361 .01493 Mdot
.23613 .01597 Mdot
.23615 .0155 Mdot
.23618 .01578 Mdot
.2362 .01506 Mdot
.23623 .01545 Mdot
.23626 .01528 Mdot
.23628 .01509 Mdot
.23631 .01559 Mdot
.23633 .0154 Mdot
.23636 .01554 Mdot
.23639 .01511 Mdot
.23641 .01662 Mdot
.23644 .01539 Mdot
.23646 .01573 Mdot
.23649 .01524 Mdot
.23651 .01562 Mdot
.23654 .01614 Mdot
.23657 .01522 Mdot
.23659 .01585 Mdot
.23662 .0151 Mdot
.23664 .01517 Mdot
.23667 .01505 Mdot
.2367 .01599 Mdot
.23672 .01595 Mdot
.23675 .0154 Mdot
.23677 .01522 Mdot
.2368 .01596 Mdot
.23682 .01601 Mdot
.23685 .01583 Mdot
.23688 .01766 Mdot
.2369 .01532 Mdot
.23693 .015 Mdot
.23695 .01603 Mdot
.23698 .01633 Mdot
.23701 .01689 Mdot
.23703 .017 Mdot
.23706 .01573 Mdot
.23708 .01547 Mdot
.23711 .01642 Mdot
.23713 .01528 Mdot
.23716 .01572 Mdot
.23719 .01609 Mdot
.23721 .01509 Mdot
.23724 .0154 Mdot
.23726 .01504 Mdot
.23729 .01562 Mdot
.23732 .01576 Mdot
.23734 .01625 Mdot
.23737 .01526 Mdot
.23739 .01547 Mdot
.23742 .01704 Mdot
.23744 .01643 Mdot
.23747 .01552 Mdot
.2375 .01523 Mdot
.23752 .01558 Mdot
.23755 .0156 Mdot
.23757 .01586 Mdot
.2376 .01662 Mdot
.23763 .01565 Mdot
.23765 .01504 Mdot
.23768 .0155 Mdot
.2377 .01545 Mdot
.23773 .01574 Mdot
.23775 .01579 Mdot
.23778 .01529 Mdot
.23781 .01547 Mdot
.23783 .01557 Mdot
.23786 .01579 Mdot
.23788 .01519 Mdot
.23791 .01632 Mdot
.23794 .01527 Mdot
.23796 .01591 Mdot
.23799 .01558 Mdot
.23801 .01579 Mdot
.23804 .01498 Mdot
.23806 .0158 Mdot
.23809 .01492 Mdot
.23812 .0161 Mdot
.23814 .0151 Mdot
.23817 .01622 Mdot
.23819 .01555 Mdot
.23822 .01652 Mdot
.23825 .01548 Mdot
.23827 .0155 Mdot
.2383 .01662 Mdot
.23832 .01554 Mdot
.23835 .01537 Mdot
.23837 .01618 Mdot
.2384 .01569 Mdot
.23843 .01624 Mdot
.23845 .01683 Mdot
.23848 .01528 Mdot
.2385 .01628 Mdot
.23853 .01592 Mdot
.23856 .01564 Mdot
.23858 .01634 Mdot
.23861 .0158 Mdot
.23863 .01539 Mdot
.23866 .01528 Mdot
.23868 .01564 Mdot
.23871 .01575 Mdot
.23874 .01575 Mdot
.23876 .01554 Mdot
.23879 .01683 Mdot
.23881 .0158 Mdot
.23884 .01624 Mdot
.23887 .01629 Mdot
.23889 .01515 Mdot
.23892 .01527 Mdot
.23894 .01575 Mdot
.23897 .01509 Mdot
.23899 .01508 Mdot
.23902 .01478 Mdot
.23905 .01571 Mdot
.23907 .01646 Mdot
.2391 .01584 Mdot
.23912 .01648 Mdot
.23915 .01538 Mdot
.23918 .01589 Mdot
.2392 .01547 Mdot
.23923 .0151 Mdot
.23925 .01522 Mdot
.23928 .01597 Mdot
.2393 .01525 Mdot
.23933 .01662 Mdot
.23936 .01558 Mdot
.23938 .01639 Mdot
.23941 .01562 Mdot
.23943 .01606 Mdot
.23946 .01514 Mdot
.23949 .01583 Mdot
.23951 .01568 Mdot
.23954 .01683 Mdot
.23956 .01539 Mdot
.23959 .01484 Mdot
.23962 .01554 Mdot
.23964 .01562 Mdot
.23967 .01624 Mdot
.23969 .01509 Mdot
.23972 .01541 Mdot
.23974 .0158 Mdot
.23977 .01484 Mdot
.2398 .01596 Mdot
.23982 .01494 Mdot
.23985 .01517 Mdot
.23987 .01589 Mdot
.2399 .0159 Mdot
.23993 .01567 Mdot
.23995 .01521 Mdot
.23998 .01671 Mdot
.24 .01596 Mdot
.24003 .01525 Mdot
.24005 .01589 Mdot
.24008 .01578 Mdot
.24011 .01474 Mdot
.24013 .01516 Mdot
.24016 .01619 Mdot
.24018 .01516 Mdot
.24021 .01552 Mdot
.24024 .0166 Mdot
.24026 .01579 Mdot
.24029 .01649 Mdot
.24031 .01536 Mdot
.24034 .01548 Mdot
.24036 .01741 Mdot
.24039 .01721 Mdot
.24042 .01513 Mdot
.24044 .01631 Mdot
.24047 .0154 Mdot
.24049 .01527 Mdot
.24052 .01541 Mdot
.24055 .01506 Mdot
.24057 .016 Mdot
.2406 .01554 Mdot
.24062 .01603 Mdot
.24065 .01584 Mdot
.24067 .01529 Mdot
.2407 .01569 Mdot
.24073 .01607 Mdot
.24075 .01529 Mdot
.24078 .01549 Mdot
.2408 .01504 Mdot
.24083 .01509 Mdot
.24086 .01514 Mdot
.24088 .01747 Mdot
.24091 .0161 Mdot
.24093 .01618 Mdot
.24096 .01682 Mdot
.24098 .01555 Mdot
.24101 .0158 Mdot
.24104 .01566 Mdot
.24106 .01548 Mdot
.24109 .01614 Mdot
.24111 .01584 Mdot
.24114 .01606 Mdot
.24117 .01558 Mdot
.24119 .01486 Mdot
.24122 .01513 Mdot
.24124 .01513 Mdot
.24127 .01627 Mdot
.24129 .01654 Mdot
.24132 .01475 Mdot
.24135 .01578 Mdot
.24137 .01636 Mdot
.2414 .01516 Mdot
.24142 .01524 Mdot
.24145 .01537 Mdot
.24148 .0162 Mdot
.2415 .01489 Mdot
.24153 .01619 Mdot
.24155 .016 Mdot
.24158 .01505 Mdot
.2416 .01567 Mdot
.24163 .01595 Mdot
.24166 .01495 Mdot
.24168 .01579 Mdot
.24171 .01495 Mdot
.24173 .0152 Mdot
.24176 .01661 Mdot
.24179 .01638 Mdot
.24181 .01527 Mdot
.24184 .01522 Mdot
.24186 .01533 Mdot
.24189 .01515 Mdot
.24191 .01607 Mdot
.24194 .01649 Mdot
.24197 .01607 Mdot
.24199 .01498 Mdot
.24202 .01513 Mdot
.24204 .01548 Mdot
.24207 .01477 Mdot
.2421 .01557 Mdot
.24212 .01487 Mdot
.24215 .01638 Mdot
.24217 .01535 Mdot
.2422 .0153 Mdot
.24222 .0164 Mdot
.24225 .01529 Mdot
.24228 .01551 Mdot
.2423 .01548 Mdot
.24233 .01625 Mdot
.24235 .01586 Mdot
.24238 .01559 Mdot
.24241 .01501 Mdot
.24243 .01613 Mdot
.24246 .01551 Mdot
.24248 .01513 Mdot
.24251 .01632 Mdot
.24253 .0161 Mdot
.24256 .0154 Mdot
.24259 .01604 Mdot
.24261 .0154 Mdot
.24264 .01605 Mdot
.24266 .01658 Mdot
.24269 .01583 Mdot
.24272 .01501 Mdot
.24274 .01566 Mdot
.24277 .01507 Mdot
.24279 .0167 Mdot
.24282 .01522 Mdot
.24284 .0155 Mdot
.24287 .01554 Mdot
.2429 .01549 Mdot
.24292 .01602 Mdot
.24295 .01482 Mdot
.24297 .01531 Mdot
.243 .01495 Mdot
.24303 .01729 Mdot
.24305 .01689 Mdot
.24308 .01557 Mdot
.2431 .0159 Mdot
.24313 .01654 Mdot
.24315 .01521 Mdot
.24318 .01555 Mdot
.24321 .01546 Mdot
.24323 .01632 Mdot
.24326 .01536 Mdot
.24328 .01581 Mdot
.24331 .01528 Mdot
.24334 .01659 Mdot
.24336 .01592 Mdot
.24339 .01667 Mdot
.24341 .01511 Mdot
.24344 .01568 Mdot
.24346 .01564 Mdot
.24349 .01562 Mdot
.24352 .01495 Mdot
.24354 .01581 Mdot
.24357 .01565 Mdot
.24359 .01501 Mdot
.24362 .01583 Mdot
.24365 .01591 Mdot
.24367 .01541 Mdot
.2437 .01483 Mdot
.24372 .01483 Mdot
.24375 .01547 Mdot
.24377 .01503 Mdot
.2438 .01632 Mdot
.24383 .01643 Mdot
.24385 .01519 Mdot
.24388 .0162 Mdot
.2439 .01501 Mdot
.24393 .01532 Mdot
.24396 .01548 Mdot
.24398 .01519 Mdot
.24401 .01554 Mdot
.24403 .01645 Mdot
.24406 .01576 Mdot
.24408 .01505 Mdot
.24411 .0154 Mdot
.24414 .01699 Mdot
.24416 .01601 Mdot
.24419 .01623 Mdot
.24421 .01517 Mdot
.24424 .01506 Mdot
.24427 .0151 Mdot
.24429 .01634 Mdot
.24432 .01543 Mdot
.24434 .01602 Mdot
.24437 .01601 Mdot
.24439 .0154 Mdot
.24442 .01637 Mdot
.24445 .01515 Mdot
.24447 .01529 Mdot
.2445 .01535 Mdot
.24452 .01717 Mdot
.24455 .01598 Mdot
.24458 .01664 Mdot
.2446 .01635 Mdot
.24463 .01503 Mdot
.24465 .01524 Mdot
.24468 .0183 Mdot
.2447 .01516 Mdot
.24473 .01589 Mdot
.24476 .01575 Mdot
.24478 .01766 Mdot
.24481 .0158 Mdot
.24483 .01521 Mdot
.24486 .01633 Mdot
.24489 .01577 Mdot
.24491 .01591 Mdot
.24494 .01618 Mdot
.24496 .01581 Mdot
.24499 .01509 Mdot
.24501 .01592 Mdot
.24504 .01659 Mdot
.24507 .01568 Mdot
.24509 .01552 Mdot
.24512 .01684 Mdot
.24514 .01588 Mdot
.24517 .01556 Mdot
.2452 .01569 Mdot
.24522 .01504 Mdot
.24525 .01582 Mdot
.24527 .01703 Mdot
.2453 .0166 Mdot
.24532 .01519 Mdot
.24535 .01522 Mdot
.24538 .01574 Mdot
.2454 .01599 Mdot
.24543 .01589 Mdot
.24545 .01556 Mdot
.24548 .01552 Mdot
.24551 .01587 Mdot
.24553 .01622 Mdot
.24556 .01525 Mdot
.24558 .01669 Mdot
.24561 .01605 Mdot
.24563 .01629 Mdot
.24566 .0153 Mdot
.24569 .01569 Mdot
.24571 .01597 Mdot
.24574 .01588 Mdot
.24576 .01499 Mdot
.24579 .01494 Mdot
.24582 .01513 Mdot
.24584 .01569 Mdot
.24587 .01603 Mdot
.24589 .01526 Mdot
.24592 .01597 Mdot
.24594 .01571 Mdot
.24597 .01651 Mdot
.246 .01544 Mdot
.24602 .01482 Mdot
.24605 .01597 Mdot
.24607 .01526 Mdot
.2461 .01513 Mdot
.24613 .01509 Mdot
.24615 .01539 Mdot
.24618 .01607 Mdot
.2462 .01578 Mdot
.24623 .01602 Mdot
.24625 .015 Mdot
.24628 .0162 Mdot
.24631 .01576 Mdot
.24633 .01607 Mdot
.24636 .01577 Mdot
.24638 .01582 Mdot
.24641 .01485 Mdot
.24644 .01568 Mdot
.24646 .01654 Mdot
.24649 .01604 Mdot
.24651 .0154 Mdot
.24654 .01569 Mdot
.24656 .01626 Mdot
.24659 .01627 Mdot
.24662 .01559 Mdot
.24664 .01499 Mdot
.24667 .01484 Mdot
.24669 .01514 Mdot
.24672 .01588 Mdot
.24675 .01592 Mdot
.24677 .01547 Mdot
.2468 .0152 Mdot
.24682 .01546 Mdot
.24685 .01658 Mdot
.24687 .01563 Mdot
.2469 .01508 Mdot
.24693 .01549 Mdot
.24695 .0168 Mdot
.24698 .01708 Mdot
.247 .01678 Mdot
.24703 .01604 Mdot
.24706 .01582 Mdot
.24708 .01635 Mdot
.24711 .01559 Mdot
.24713 .01547 Mdot
.24716 .01525 Mdot
.24718 .01566 Mdot
.24721 .01561 Mdot
.24724 .01581 Mdot
.24726 .01567 Mdot
.24729 .01645 Mdot
.24731 .01651 Mdot
.24734 .01498 Mdot
.24737 .01537 Mdot
.24739 .01681 Mdot
.24742 .01559 Mdot
.24744 .01518 Mdot
.24747 .01614 Mdot
.24749 .01528 Mdot
.24752 .01543 Mdot
.24755 .01584 Mdot
.24757 .01569 Mdot
.2476 .01605 Mdot
.24762 .0159 Mdot
.24765 .01615 Mdot
.24768 .01512 Mdot
.2477 .01519 Mdot
.24773 .01499 Mdot
.24775 .01501 Mdot
.24778 .01584 Mdot
.2478 .01565 Mdot
.24783 .01509 Mdot
.24786 .01587 Mdot
.24788 .01562 Mdot
.24791 .01627 Mdot
.24793 .0151 Mdot
.24796 .01565 Mdot
.24799 .01569 Mdot
.24801 .01588 Mdot
.24804 .01507 Mdot
.24806 .01572 Mdot
.24809 .01502 Mdot
.24811 .0149 Mdot
.24814 .01661 Mdot
.24817 .01536 Mdot
.24819 .01624 Mdot
.24822 .01524 Mdot
.24824 .01573 Mdot
.24827 .01585 Mdot
.2483 .01565 Mdot
.24832 .01548 Mdot
.24835 .01615 Mdot
.24837 .01513 Mdot
.2484 .01616 Mdot
.24842 .01548 Mdot
.24845 .01508 Mdot
.24848 .01572 Mdot
.2485 .01516 Mdot
.24853 .01543 Mdot
.24855 .01543 Mdot
.24858 .01498 Mdot
.24861 .01565 Mdot
.24863 .01646 Mdot
.24866 .01532 Mdot
.24868 .01568 Mdot
.24871 .01614 Mdot
.24874 .01632 Mdot
.24876 .01657 Mdot
.24879 .01582 Mdot
.24881 .01727 Mdot
.24884 .01628 Mdot
.24886 .01554 Mdot
.24889 .01567 Mdot
.24892 .01577 Mdot
.24894 .01514 Mdot
.24897 .01585 Mdot
.24899 .01695 Mdot
.24902 .01569 Mdot
.24905 .01545 Mdot
.24907 .01493 Mdot
.2491 .01612 Mdot
.24912 .01628 Mdot
.24915 .01492 Mdot
.24917 .0161 Mdot
.2492 .01565 Mdot
.24923 .01658 Mdot
.24925 .01644 Mdot
.24928 .01568 Mdot
.2493 .01609 Mdot
.24933 .01593 Mdot
.24936 .01494 Mdot
.24938 .01554 Mdot
.24941 .01532 Mdot
.24943 .01643 Mdot
.24946 .01589 Mdot
.24948 .01495 Mdot
.24951 .01617 Mdot
.24954 .01485 Mdot
.24956 .01718 Mdot
.24959 .01624 Mdot
.24961 .01554 Mdot
.24964 .01528 Mdot
.24967 .01583 Mdot
.24969 .01575 Mdot
.24972 .01733 Mdot
.24974 .01579 Mdot
.24977 .0161 Mdot
.24979 .01585 Mdot
.24982 .01581 Mdot
.24985 .01501 Mdot
.24987 .01563 Mdot
.2499 .01548 Mdot
.24992 .0151 Mdot
.24995 .01608 Mdot
.24998 .01583 Mdot
.25 .01616 Mdot
.25003 .01578 Mdot
.25005 .01509 Mdot
.25008 .01526 Mdot
.2501 .01505 Mdot
.25013 .01693 Mdot
.25016 .01564 Mdot
.25018 .01506 Mdot
.25021 .0153 Mdot
.25023 .01606 Mdot
.25026 .01617 Mdot
.25029 .0159 Mdot
.25031 .01541 Mdot
.25034 .016 Mdot
.25036 .01655 Mdot
.25039 .01571 Mdot
.25041 .01542 Mdot
.25044 .01662 Mdot
.25047 .01611 Mdot
.25049 .01639 Mdot
.25052 .01498 Mdot
.25054 .01583 Mdot
.25057 .01547 Mdot
.2506 .01497 Mdot
.25062 .01505 Mdot
.25065 .01485 Mdot
.25067 .01553 Mdot
.2507 .01564 Mdot
.25072 .01494 Mdot
.25075 .01554 Mdot
.25078 .01576 Mdot
.2508 .01474 Mdot
.25083 .01529 Mdot
.25085 .01573 Mdot
.25088 .01503 Mdot
.25091 .0164 Mdot
.25093 .01641 Mdot
.25096 .0154 Mdot
.25098 .01518 Mdot
.25101 .01623 Mdot
.25103 .01561 Mdot
.25106 .01556 Mdot
.25109 .01513 Mdot
.25111 .01583 Mdot
.25114 .0151 Mdot
.25116 .01617 Mdot
.25119 .01521 Mdot
.25122 .01477 Mdot
.25124 .01582 Mdot
.25127 .01688 Mdot
.25129 .01552 Mdot
.25132 .01656 Mdot
.25134 .01581 Mdot
.25137 .01561 Mdot
.2514 .01523 Mdot
.25142 .0153 Mdot
.25145 .01488 Mdot
.25147 .01576 Mdot
.2515 .01542 Mdot
.25153 .0154 Mdot
.25155 .01532 Mdot
.25158 .01588 Mdot
.2516 .01658 Mdot
.25163 .01645 Mdot
.25165 .01557 Mdot
.25168 .01516 Mdot
.25171 .01666 Mdot
.25173 .01552 Mdot
.25176 .01499 Mdot
.25178 .01555 Mdot
.25181 .01542 Mdot
.25184 .01528 Mdot
.25186 .01555 Mdot
.25189 .01515 Mdot
.25191 .01505 Mdot
.25194 .01536 Mdot
.25196 .01639 Mdot
.25199 .01666 Mdot
.25202 .01596 Mdot
.25204 .01674 Mdot
.25207 .01675 Mdot
.25209 .01503 Mdot
.25212 .01533 Mdot
.25215 .0153 Mdot
.25217 .0151 Mdot
.2522 .01617 Mdot
.25222 .01519 Mdot
.25225 .01569 Mdot
.25227 .01501 Mdot
.2523 .01696 Mdot
.25233 .0155 Mdot
.25235 .01619 Mdot
.25238 .01538 Mdot
.2524 .01542 Mdot
.25243 .01683 Mdot
.25246 .01652 Mdot
.25248 .01565 Mdot
.25251 .01484 Mdot
.25253 .01637 Mdot
.25256 .01602 Mdot
.25258 .01557 Mdot
.25261 .01564 Mdot
.25264 .01596 Mdot
.25266 .01568 Mdot
.25269 .01599 Mdot
.25271 .01563 Mdot
.25274 .01537 Mdot
.25277 .01687 Mdot
.25279 .01601 Mdot
.25282 .01544 Mdot
.25284 .01553 Mdot
.25287 .01597 Mdot
.25289 .01624 Mdot
.25292 .01657 Mdot
.25295 .01581 Mdot
.25297 .01605 Mdot
.253 .01564 Mdot
.25302 .01515 Mdot
.25305 .0152 Mdot
.25308 .01542 Mdot
.2531 .01545 Mdot
.25313 .0157 Mdot
.25315 .01627 Mdot
.25318 .01536 Mdot
.2532 .01527 Mdot
.25323 .01555 Mdot
.25326 .01608 Mdot
.25328 .01589 Mdot
.25331 .01565 Mdot
.25333 .01654 Mdot
.25336 .01567 Mdot
.25339 .01539 Mdot
.25341 .01593 Mdot
.25344 .01545 Mdot
.25346 .01625 Mdot
.25349 .01545 Mdot
.25351 .01656 Mdot
.25354 .01553 Mdot
.25357 .01547 Mdot
.25359 .01529 Mdot
.25362 .01582 Mdot
.25364 .0156 Mdot
.25367 .01564 Mdot
.2537 .01612 Mdot
.25372 .01597 Mdot
.25375 .01636 Mdot
.25377 .01557 Mdot
.2538 .01655 Mdot
.25382 .01574 Mdot
.25385 .01555 Mdot
.25388 .01535 Mdot
.2539 .01612 Mdot
.25393 .01494 Mdot
.25395 .01545 Mdot
.25398 .01597 Mdot
.25401 .0154 Mdot
.25403 .01537 Mdot
.25406 .01591 Mdot
.25408 .01636 Mdot
.25411 .01542 Mdot
.25413 .01561 Mdot
.25416 .01476 Mdot
.25419 .01555 Mdot
.25421 .01665 Mdot
.25424 .01569 Mdot
.25426 .01481 Mdot
.25429 .01555 Mdot
.25432 .01601 Mdot
.25434 .01654 Mdot
.25437 .0159 Mdot
.25439 .01543 Mdot
.25442 .01557 Mdot
.25444 .0164 Mdot
.25447 .0161 Mdot
.2545 .01562 Mdot
.25452 .01657 Mdot
.25455 .01603 Mdot
.25457 .01569 Mdot
.2546 .01537 Mdot
.25463 .01563 Mdot
.25465 .01525 Mdot
.25468 .01543 Mdot
.2547 .01586 Mdot
.25473 .01546 Mdot
.25475 .01505 Mdot
.25478 .01613 Mdot
.25481 .01525 Mdot
.25483 .01536 Mdot
.25486 .01563 Mdot
.25488 .01582 Mdot
.25491 .01556 Mdot
.25494 .01628 Mdot
.25496 .01517 Mdot
.25499 .01587 Mdot
.25501 .01578 Mdot
.25504 .01617 Mdot
.25506 .015 Mdot
.25509 .01544 Mdot
.25512 .01547 Mdot
.25514 .01653 Mdot
.25517 .01592 Mdot
.25519 .01595 Mdot
.25522 .01532 Mdot
.25525 .01507 Mdot
.25527 .01565 Mdot
.2553 .01595 Mdot
.25532 .01507 Mdot
.25535 .01563 Mdot
.25537 .01581 Mdot
.2554 .01509 Mdot
.25543 .01573 Mdot
.25545 .01517 Mdot
.25548 .01588 Mdot
.2555 .0161 Mdot
.25553 .01588 Mdot
.25556 .01558 Mdot
.25558 .0152 Mdot
.25561 .01597 Mdot
.25563 .01544 Mdot
.25566 .01552 Mdot
.25568 .0153 Mdot
.25571 .01608 Mdot
.25574 .01595 Mdot
.25576 .01538 Mdot
.25579 .01685 Mdot
.25581 .01505 Mdot
.25584 .01619 Mdot
.25587 .01561 Mdot
.25589 .01582 Mdot
.25592 .01558 Mdot
.25594 .01523 Mdot
.25597 .01536 Mdot
.25599 .01503 Mdot
.25602 .01654 Mdot
.25605 .01678 Mdot
.25607 .01635 Mdot
.2561 .01581 Mdot
.25612 .01499 Mdot
.25615 .0156 Mdot
.25618 .01614 Mdot
.2562 .01582 Mdot
.25623 .01602 Mdot
.25625 .01564 Mdot
.25628 .01574 Mdot
.2563 .01556 Mdot
.25633 .01595 Mdot
.25636 .016 Mdot
.25638 .01573 Mdot
.25641 .01509 Mdot
.25643 .0149 Mdot
.25646 .01574 Mdot
.25649 .01556 Mdot
.25651 .01593 Mdot
.25654 .0159 Mdot
.25656 .01533 Mdot
.25659 .01535 Mdot
.25661 .01506 Mdot
.25664 .0153 Mdot
.25667 .0161 Mdot
.25669 .01618 Mdot
.25672 .01648 Mdot
.25674 .01524 Mdot
.25677 .01532 Mdot
.2568 .0163 Mdot
.25682 .01582 Mdot
.25685 .01533 Mdot
.25687 .01517 Mdot
.2569 .01492 Mdot
.25692 .01643 Mdot
.25695 .01567 Mdot
.25698 .01585 Mdot
.257 .0164 Mdot
.25703 .01724 Mdot
.25705 .01584 Mdot
.25708 .01549 Mdot
.25711 .01622 Mdot
.25713 .0155 Mdot
.25716 .01579 Mdot
.25718 .0154 Mdot
.25721 .01525 Mdot
.25723 .01654 Mdot
.25726 .01585 Mdot
.25729 .01587 Mdot
.25731 .01558 Mdot
.25734 .01595 Mdot
.25736 .01522 Mdot
.25739 .01563 Mdot
.25742 .01594 Mdot
.25744 .01674 Mdot
.25747 .0154 Mdot
.25749 .01582 Mdot
.25752 .01527 Mdot
.25754 .01557 Mdot
.25757 .01597 Mdot
.2576 .01509 Mdot
.25762 .0171 Mdot
.25765 .01575 Mdot
.25767 .01583 Mdot
.2577 .01544 Mdot
.25773 .01727 Mdot
.25775 .01511 Mdot
.25778 .01573 Mdot
.2578 .01537 Mdot
.25783 .01551 Mdot
.25786 .01659 Mdot
.25788 .01526 Mdot
.25791 .01624 Mdot
.25793 .01507 Mdot
.25796 .01532 Mdot
.25798 .01648 Mdot
.25801 .01674 Mdot
.25804 .01636 Mdot
.25806 .01606 Mdot
.25809 .01525 Mdot
.25811 .01524 Mdot
.25814 .01534 Mdot
.25817 .01584 Mdot
.25819 .01537 Mdot
.25822 .01555 Mdot
.25824 .01653 Mdot
.25827 .01538 Mdot
.25829 .01567 Mdot
.25832 .01595 Mdot
.25835 .01584 Mdot
.25837 .01576 Mdot
.2584 .01554 Mdot
.25842 .01539 Mdot
.25845 .01609 Mdot
.25848 .0153 Mdot
.2585 .0154 Mdot
.25853 .01569 Mdot
.25855 .01534 Mdot
.25858 .01542 Mdot
.2586 .0153 Mdot
.25863 .01607 Mdot
.25866 .01569 Mdot
.25868 .01621 Mdot
.25871 .01545 Mdot
.25873 .01633 Mdot
.25876 .01543 Mdot
.25879 .01701 Mdot
.25881 .01576 Mdot
.25884 .01589 Mdot
.25886 .01569 Mdot
.25889 .01605 Mdot
.25891 .01593 Mdot
.25894 .01532 Mdot
.25897 .01539 Mdot
.25899 .01504 Mdot
.25902 .01531 Mdot
.25904 .01495 Mdot
.25907 .01477 Mdot
.2591 .0161 Mdot
.25912 .0151 Mdot
.25915 .01591 Mdot
.25917 .0152 Mdot
.2592 .01522 Mdot
.25922 .01703 Mdot
.25925 .01557 Mdot
.25928 .01582 Mdot
.2593 .01534 Mdot
.25933 .0155 Mdot
.25935 .01483 Mdot
.25938 .0162 Mdot
.25941 .01571 Mdot
.25943 .01519 Mdot
.25946 .01587 Mdot
.25948 .01519 Mdot
.25951 .01505 Mdot
.25953 .01558 Mdot
.25956 .01521 Mdot
.25959 .01541 Mdot
.25961 .01641 Mdot
.25964 .01566 Mdot
.25966 .01608 Mdot
.25969 .01653 Mdot
.25972 .0152 Mdot
.25974 .01577 Mdot
.25977 .01633 Mdot
.25979 .01623 Mdot
.25982 .01543 Mdot
.25984 .01649 Mdot
.25987 .01514 Mdot
.2599 .01679 Mdot
.25992 .01556 Mdot
.25995 .01513 Mdot
.25997 .01633 Mdot
.26 .01548 Mdot
.26003 .01547 Mdot
.26005 .0155 Mdot
.26008 .0168 Mdot
.2601 .01507 Mdot
.26013 .01611 Mdot
.26015 .01622 Mdot
.26018 .01578 Mdot
.26021 .01595 Mdot
.26023 .01633 Mdot
.26026 .01579 Mdot
.26028 .01556 Mdot
.26031 .01572 Mdot
.26034 .01526 Mdot
.26036 .01567 Mdot
.26039 .01649 Mdot
.26041 .01552 Mdot
.26044 .01605 Mdot
.26046 .01628 Mdot
.26049 .01595 Mdot
.26052 .01641 Mdot
.26054 .01623 Mdot
.26057 .01647 Mdot
.26059 .01527 Mdot
.26062 .01605 Mdot
.26065 .01585 Mdot
.26067 .01684 Mdot
.2607 .01568 Mdot
.26072 .01611 Mdot
.26075 .01573 Mdot
.26077 .01484 Mdot
.2608 .01693 Mdot
.26083 .01575 Mdot
.26085 .01514 Mdot
.26088 .016 Mdot
.2609 .01597 Mdot
.26093 .01522 Mdot
.26096 .0161 Mdot
.26098 .01523 Mdot
.26101 .01551 Mdot
.26103 .01593 Mdot
.26106 .01535 Mdot
.26108 .01563 Mdot
.26111 .01513 Mdot
.26114 .01527 Mdot
.26116 .01512 Mdot
.26119 .01602 Mdot
.26121 .01581 Mdot
.26124 .01606 Mdot
.26127 .01579 Mdot
.26129 .01649 Mdot
.26132 .01596 Mdot
.26134 .0162 Mdot
.26137 .01562 Mdot
.26139 .01599 Mdot
.26142 .01511 Mdot
.26145 .01493 Mdot
.26147 .01527 Mdot
.2615 .01768 Mdot
.26152 .01581 Mdot
.26155 .01512 Mdot
.26158 .01508 Mdot
.2616 .01556 Mdot
.26163 .01504 Mdot
.26165 .01538 Mdot
.26168 .01581 Mdot
.2617 .01636 Mdot
.26173 .01629 Mdot
.26176 .01604 Mdot
.26178 .01581 Mdot
.26181 .01493 Mdot
.26183 .01604 Mdot
.26186 .01482 Mdot
.26189 .01499 Mdot
.26191 .01488 Mdot
.26194 .01633 Mdot
.26196 .01523 Mdot
.26199 .0154 Mdot
.26201 .01578 Mdot
.26204 .01514 Mdot
.26207 .01529 Mdot
.26209 .01478 Mdot
.26212 .01615 Mdot
.26214 .01549 Mdot
.26217 .01556 Mdot
.2622 .01658 Mdot
.26222 .01544 Mdot
.26225 .01559 Mdot
.26227 .01502 Mdot
.2623 .01555 Mdot
.26232 .01579 Mdot
.26235 .01707 Mdot
.26238 .01536 Mdot
.2624 .01601 Mdot
.26243 .01505 Mdot
.26245 .01629 Mdot
.26248 .01528 Mdot
.26251 .01799 Mdot
.26253 .01549 Mdot
.26256 .01597 Mdot
.26258 .01533 Mdot
.26261 .01556 Mdot
.26263 .0158 Mdot
.26266 .01621 Mdot
.26269 .01514 Mdot
.26271 .01497 Mdot
.26274 .01609 Mdot
.26276 .01601 Mdot
.26279 .01501 Mdot
.26282 .01753 Mdot
.26284 .01571 Mdot
.26287 .01548 Mdot
.26289 .01556 Mdot
.26292 .01572 Mdot
.26294 .01576 Mdot
.26297 .01602 Mdot
.263 .01508 Mdot
.26302 .01588 Mdot
.26305 .01509 Mdot
.26307 .01546 Mdot
.2631 .01571 Mdot
.26313 .01512 Mdot
.26315 .01587 Mdot
.26318 .01603 Mdot
.2632 .01539 Mdot
.26323 .01634 Mdot
.26325 .0155 Mdot
.26328 .01543 Mdot
.26331 .0148 Mdot
.26333 .01549 Mdot
.26336 .01582 Mdot
.26338 .0161 Mdot
.26341 .01504 Mdot
.26344 .01546 Mdot
.26346 .01562 Mdot
.26349 .01517 Mdot
.26351 .01583 Mdot
.26354 .01527 Mdot
.26356 .01575 Mdot
.26359 .01541 Mdot
.26362 .01592 Mdot
.26364 .01619 Mdot
.26367 .01619 Mdot
.26369 .01501 Mdot
.26372 .01631 Mdot
.26375 .01499 Mdot
.26377 .01536 Mdot
.2638 .01517 Mdot
.26382 .01626 Mdot
.26385 .01521 Mdot
.26387 .0156 Mdot
.2639 .01518 Mdot
.26393 .0151 Mdot
.26395 .01594 Mdot
.26398 .01531 Mdot
.264 .01713 Mdot
.26403 .01707 Mdot
.26406 .01573 Mdot
.26408 .01568 Mdot
.26411 .01559 Mdot
.26413 .01555 Mdot
.26416 .01608 Mdot
.26418 .01492 Mdot
.26421 .01507 Mdot
.26424 .01534 Mdot
.26426 .01503 Mdot
.26429 .01643 Mdot
.26431 .0164 Mdot
.26434 .01517 Mdot
.26437 .01487 Mdot
.26439 .01571 Mdot
.26442 .01637 Mdot
.26444 .01522 Mdot
.26447 .01586 Mdot
.26449 .01578 Mdot
.26452 .01548 Mdot
.26455 .01489 Mdot
.26457 .01548 Mdot
.2646 .01646 Mdot
.26462 .01641 Mdot
.26465 .01593 Mdot
.26468 .0149 Mdot
.2647 .01544 Mdot
.26473 .0151 Mdot
.26475 .01723 Mdot
.26478 .0149 Mdot
.2648 .01593 Mdot
.26483 .01575 Mdot
.26486 .01508 Mdot
.26488 .01605 Mdot
.26491 .01538 Mdot
.26493 .01501 Mdot
.26496 .01577 Mdot
.26499 .01538 Mdot
.26501 .01617 Mdot
.26504 .01644 Mdot
.26506 .01578 Mdot
.26509 .01516 Mdot
.26511 .01586 Mdot
.26514 .01574 Mdot
.26517 .01538 Mdot
.26519 .01516 Mdot
.26522 .01551 Mdot
.26524 .01601 Mdot
.26527 .01528 Mdot
.2653 .01532 Mdot
.26532 .01569 Mdot
.26535 .01604 Mdot
.26537 .0149 Mdot
.2654 .01493 Mdot
.26542 .01576 Mdot
.26545 .01613 Mdot
.26548 .01617 Mdot
.2655 .01547 Mdot
.26553 .01572 Mdot
.26555 .01517 Mdot
.26558 .01528 Mdot
.26561 .01536 Mdot
.26563 .01502 Mdot
.26566 .01532 Mdot
.26568 .01671 Mdot
.26571 .01628 Mdot
.26573 .01582 Mdot
.26576 .0157 Mdot
.26579 .01504 Mdot
.26581 .01596 Mdot
.26584 .01588 Mdot
.26586 .01618 Mdot
.26589 .0148 Mdot
.26592 .016 Mdot
.26594 .01495 Mdot
.26597 .01523 Mdot
.26599 .01544 Mdot
.26602 .0152 Mdot
.26604 .01516 Mdot
.26607 .01587 Mdot
.2661 .01538 Mdot
.26612 .01627 Mdot
.26615 .01552 Mdot
.26617 .01587 Mdot
.2662 .01561 Mdot
.26623 .01527 Mdot
.26625 .01567 Mdot
.26628 .01633 Mdot
.2663 .01534 Mdot
.26633 .01669 Mdot
.26635 .01586 Mdot
.26638 .01633 Mdot
.26641 .01509 Mdot
.26643 .01624 Mdot
.26646 .0154 Mdot
.26648 .01561 Mdot
.26651 .01564 Mdot
.26654 .01601 Mdot
.26656 .0157 Mdot
.26659 .01666 Mdot
.26661 .01575 Mdot
.26664 .01651 Mdot
.26666 .01556 Mdot
.26669 .01697 Mdot
.26672 .01546 Mdot
.26674 .0152 Mdot
.26677 .0156 Mdot
.26679 .01491 Mdot
.26682 .01531 Mdot
.26685 .01604 Mdot
.26687 .01564 Mdot
.2669 .01527 Mdot
.26692 .01521 Mdot
.26695 .01537 Mdot
.26698 .01717 Mdot
.267 .01553 Mdot
.26703 .01604 Mdot
.26705 .01541 Mdot
.26708 .01492 Mdot
.2671 .01563 Mdot
.26713 .01629 Mdot
.26716 .01554 Mdot
.26718 .01531 Mdot
.26721 .01519 Mdot
.26723 .01537 Mdot
.26726 .01567 Mdot
.26729 .01776 Mdot
.26731 .0159 Mdot
.26734 .01535 Mdot
.26736 .01671 Mdot
.26739 .01526 Mdot
.26741 .01559 Mdot
.26744 .01617 Mdot
.26747 .01511 Mdot
.26749 .0156 Mdot
.26752 .015 Mdot
.26754 .01507 Mdot
.26757 .01599 Mdot
.2676 .01508 Mdot
.26762 .01529 Mdot
.26765 .01625 Mdot
.26767 .01584 Mdot
.2677 .01672 Mdot
.26772 .0156 Mdot
.26775 .01566 Mdot
.26778 .0155 Mdot
.2678 .0158 Mdot
.26783 .01518 Mdot
.26785 .01522 Mdot
.26788 .01611 Mdot
.26791 .01519 Mdot
.26793 .01576 Mdot
.26796 .01516 Mdot
.26798 .01525 Mdot
.26801 .01492 Mdot
.26803 .01585 Mdot
.26806 .01618 Mdot
.26809 .01561 Mdot
.26811 .0153 Mdot
.26814 .01631 Mdot
.26816 .01596 Mdot
.26819 .01664 Mdot
.26822 .01555 Mdot
.26824 .01559 Mdot
.26827 .01615 Mdot
.26829 .01628 Mdot
.26832 .01585 Mdot
.26834 .01534 Mdot
.26837 .01569 Mdot
.2684 .01523 Mdot
.26842 .01642 Mdot
.26845 .0155 Mdot
.26847 .01499 Mdot
.2685 .0164 Mdot
.26853 .01524 Mdot
.26855 .01734 Mdot
.26858 .01529 Mdot
.2686 .0148 Mdot
.26863 .01623 Mdot
.26865 .01595 Mdot
.26868 .01574 Mdot
.26871 .01644 Mdot
.26873 .01605 Mdot
.26876 .0161 Mdot
.26878 .01636 Mdot
.26881 .01629 Mdot
.26884 .01617 Mdot
.26886 .01599 Mdot
.26889 .01558 Mdot
.26891 .01627 Mdot
.26894 .01543 Mdot
.26896 .01573 Mdot
.26899 .0158 Mdot
.26902 .01559 Mdot
.26904 .01635 Mdot
.26907 .01571 Mdot
.26909 .01597 Mdot
.26912 .01608 Mdot
.26915 .01598 Mdot
.26917 .01539 Mdot
.2692 .01533 Mdot
.26922 .01542 Mdot
.26925 .015 Mdot
.26927 .01594 Mdot
.2693 .01513 Mdot
.26933 .01501 Mdot
.26935 .01557 Mdot
.26938 .01558 Mdot
.2694 .01672 Mdot
.26943 .01595 Mdot
.26946 .01602 Mdot
.26948 .01563 Mdot
.26951 .01527 Mdot
.26953 .01531 Mdot
.26956 .01587 Mdot
.26958 .01616 Mdot
.26961 .01474 Mdot
.26964 .01539 Mdot
.26966 .0161 Mdot
.26969 .01548 Mdot
.26971 .01566 Mdot
.26974 .01763 Mdot
.26977 .01523 Mdot
.26979 .01516 Mdot
.26982 .01549 Mdot
.26984 .01532 Mdot
.26987 .01552 Mdot
.26989 .01496 Mdot
.26992 .01532 Mdot
.26995 .01563 Mdot
.26997 .01632 Mdot
.27 .01673 Mdot
.27002 .01624 Mdot
.27005 .01609 Mdot
.27008 .01591 Mdot
.2701 .01549 Mdot
.27013 .01544 Mdot
.27015 .01675 Mdot
.27018 .01612 Mdot
.2702 .01529 Mdot
.27023 .01503 Mdot
.27026 .01576 Mdot
.27028 .01484 Mdot
.27031 .0164 Mdot
.27033 .01564 Mdot
.27036 .01735 Mdot
.27039 .01607 Mdot
.27041 .01505 Mdot
.27044 .01545 Mdot
.27046 .01601 Mdot
.27049 .01563 Mdot
.27051 .01674 Mdot
.27054 .01551 Mdot
.27057 .01647 Mdot
.27059 .01586 Mdot
.27062 .01552 Mdot
.27064 .01667 Mdot
.27067 .0165 Mdot
.2707 .01621 Mdot
.27072 .01713 Mdot
.27075 .01487 Mdot
.27077 .01582 Mdot
.2708 .01546 Mdot
.27082 .01598 Mdot
.27085 .01663 Mdot
.27088 .01553 Mdot
.2709 .01536 Mdot
.27093 .01515 Mdot
.27095 .01516 Mdot
.27098 .01586 Mdot
.27101 .01525 Mdot
.27103 .01493 Mdot
.27106 .01532 Mdot
.27108 .01516 Mdot
.27111 .01718 Mdot
.27113 .0164 Mdot
.27116 .01558 Mdot
.27119 .01601 Mdot
.27121 .01559 Mdot
.27124 .01525 Mdot
.27126 .01519 Mdot
.27129 .01532 Mdot
.27132 .01504 Mdot
.27134 .01622 Mdot
.27137 .0155 Mdot
.27139 .01576 Mdot
.27142 .01602 Mdot
.27144 .01491 Mdot
.27147 .01714 Mdot
.2715 .01588 Mdot
.27152 .01563 Mdot
.27155 .01515 Mdot
.27157 .01596 Mdot
.2716 .01579 Mdot
.27163 .01618 Mdot
.27165 .01629 Mdot
.27168 .01512 Mdot
.2717 .01512 Mdot
.27173 .01507 Mdot
.27175 .01513 Mdot
.27178 .01546 Mdot
.27181 .01508 Mdot
.27183 .01629 Mdot
.27186 .0158 Mdot
.27188 .01599 Mdot
.27191 .01522 Mdot
.27194 .0157 Mdot
.27196 .01702 Mdot
.27199 .01607 Mdot
.27201 .01589 Mdot
.27204 .01627 Mdot
.27206 .01552 Mdot
.27209 .01581 Mdot
.27212 .01561 Mdot
.27214 .01544 Mdot
.27217 .01496 Mdot
.27219 .0151 Mdot
.27222 .01534 Mdot
.27225 .01559 Mdot
.27227 .0163 Mdot
.2723 .01594 Mdot
.27232 .01566 Mdot
.27235 .01621 Mdot
.27237 .01577 Mdot
.2724 .01595 Mdot
.27243 .01581 Mdot
.27245 .01526 Mdot
.27248 .01532 Mdot
.2725 .015 Mdot
.27253 .01537 Mdot
.27256 .01546 Mdot
.27258 .01554 Mdot
.27261 .01497 Mdot
.27263 .01546 Mdot
.27266 .01606 Mdot
.27268 .01531 Mdot
.27271 .01508 Mdot
.27274 .0156 Mdot
.27276 .01627 Mdot
.27279 .01539 Mdot
.27281 .01577 Mdot
.27284 .01576 Mdot
.27287 .01555 Mdot
.27289 .01551 Mdot
.27292 .01578 Mdot
.27294 .01609 Mdot
.27297 .0158 Mdot
.27299 .01656 Mdot
.27302 .01525 Mdot
.27305 .01548 Mdot
.27307 .01493 Mdot
.2731 .01526 Mdot
.27312 .01653 Mdot
.27315 .01538 Mdot
.27318 .01535 Mdot
.2732 .01516 Mdot
.27323 .01561 Mdot
.27325 .01637 Mdot
.27328 .01577 Mdot
.2733 .01528 Mdot
.27333 .01655 Mdot
.27336 .01511 Mdot
.27338 .01539 Mdot
.27341 .0151 Mdot
.27343 .01513 Mdot
.27346 .01507 Mdot
.27349 .0154 Mdot
.27351 .01566 Mdot
.27354 .01495 Mdot
.27356 .01541 Mdot
.27359 .01523 Mdot
.27361 .01597 Mdot
.27364 .01633 Mdot
.27367 .01616 Mdot
.27369 .01576 Mdot
.27372 .01594 Mdot
.27374 .01598 Mdot
.27377 .01508 Mdot
.2738 .01606 Mdot
.27382 .01546 Mdot
.27385 .01488 Mdot
.27387 .01546 Mdot
.2739 .01577 Mdot
.27392 .0151 Mdot
.27395 .01551 Mdot
.27398 .01504 Mdot
.274 .01571 Mdot
.27403 .01487 Mdot
.27405 .01508 Mdot
.27408 .01568 Mdot
.27411 .01558 Mdot
.27413 .01538 Mdot
.27416 .01508 Mdot
.27418 .01553 Mdot
.27421 .01506 Mdot
.27423 .01633 Mdot
.27426 .01621 Mdot
.27429 .0159 Mdot
.27431 .01521 Mdot
.27434 .01562 Mdot
.27436 .0156 Mdot
.27439 .01536 Mdot
.27442 .01641 Mdot
.27444 .01546 Mdot
.27447 .01608 Mdot
.27449 .01527 Mdot
.27452 .01641 Mdot
.27454 .01559 Mdot
.27457 .015 Mdot
.2746 .0166 Mdot
.27462 .01546 Mdot
.27465 .01689 Mdot
.27467 .01564 Mdot
.2747 .0167 Mdot
.27473 .0166 Mdot
.27475 .01531 Mdot
.27478 .01633 Mdot
.2748 .01502 Mdot
.27483 .01602 Mdot
.27485 .01615 Mdot
.27488 .01568 Mdot
.27491 .01655 Mdot
.27493 .0163 Mdot
.27496 .0155 Mdot
.27498 .01537 Mdot
.27501 .01545 Mdot
.27504 .01544 Mdot
.27506 .0176 Mdot
.27509 .017 Mdot
.27511 .01543 Mdot
.27514 .01505 Mdot
.27516 .01574 Mdot
.27519 .01601 Mdot
.27522 .01502 Mdot
.27524 .01543 Mdot
.27527 .01502 Mdot
.27529 .0163 Mdot
.27532 .01523 Mdot
.27535 .01608 Mdot
.27537 .01518 Mdot
.2754 .01582 Mdot
.27542 .01564 Mdot
.27545 .01582 Mdot
.27547 .01631 Mdot
.2755 .01559 Mdot
.27553 .01626 Mdot
.27555 .01498 Mdot
.27558 .01506 Mdot
.2756 .01504 Mdot
.27563 .01693 Mdot
.27566 .01511 Mdot
.27568 .01582 Mdot
.27571 .01532 Mdot
.27573 .0153 Mdot
.27576 .0153 Mdot
.27578 .01515 Mdot
.27581 .01579 Mdot
.27584 .0161 Mdot
.27586 .0153 Mdot
.27589 .01554 Mdot
.27591 .01562 Mdot
.27594 .015 Mdot
.27597 .01525 Mdot
.27599 .01556 Mdot
.27602 .01675 Mdot
.27604 .0152 Mdot
.27607 .01584 Mdot
.2761 .01548 Mdot
.27612 .0161 Mdot
.27615 .01626 Mdot
.27617 .01581 Mdot
.2762 .01649 Mdot
.27622 .01596 Mdot
.27625 .01602 Mdot
.27628 .01517 Mdot
.2763 .01548 Mdot
.27633 .01539 Mdot
.27635 .0166 Mdot
.27638 .01674 Mdot
.27641 .0153 Mdot
.27643 .01522 Mdot
.27646 .0154 Mdot
.27648 .01552 Mdot
.27651 .01738 Mdot
.27653 .01589 Mdot
.27656 .01517 Mdot
.27659 .01575 Mdot
.27661 .01525 Mdot
.27664 .01672 Mdot
.27666 .01646 Mdot
.27669 .01588 Mdot
.27672 .01491 Mdot
.27674 .01633 Mdot
.27677 .01644 Mdot
.27679 .01505 Mdot
.27682 .01595 Mdot
.27684 .01591 Mdot
.27687 .01512 Mdot
.2769 .01601 Mdot
.27692 .01687 Mdot
.27695 .01587 Mdot
.27697 .0154 Mdot
.277 .01508 Mdot
.27703 .01597 Mdot
.27705 .01567 Mdot
.27708 .01644 Mdot
.2771 .01528 Mdot
.27713 .01691 Mdot
.27715 .01639 Mdot
.27718 .01512 Mdot
.27721 .01618 Mdot
.27723 .01545 Mdot
.27726 .01496 Mdot
.27728 .01555 Mdot
.27731 .01531 Mdot
.27734 .01616 Mdot
.27736 .01593 Mdot
.27739 .01591 Mdot
.27741 .01591 Mdot
.27744 .01486 Mdot
.27746 .0154 Mdot
.27749 .01624 Mdot
.27752 .01487 Mdot
.27754 .01645 Mdot
.27757 .01545 Mdot
.27759 .01583 Mdot
.27762 .0148 Mdot
.27765 .01478 Mdot
.27767 .0154 Mdot
.2777 .01515 Mdot
.27772 .01575 Mdot
.27775 .01614 Mdot
.27777 .01535 Mdot
.2778 .01522 Mdot
.27783 .01601 Mdot
.27785 .01521 Mdot
.27788 .01631 Mdot
.2779 .01584 Mdot
.27793 .01596 Mdot
.27796 .01511 Mdot
.27798 .01514 Mdot
.27801 .0156 Mdot
.27803 .01558 Mdot
.27806 .01587 Mdot
.27808 .01553 Mdot
.27811 .01551 Mdot
.27814 .0152 Mdot
.27816 .01581 Mdot
.27819 .01545 Mdot
.27821 .0164 Mdot
.27824 .01607 Mdot
.27827 .01593 Mdot
.27829 .01524 Mdot
.27832 .01576 Mdot
.27834 .01594 Mdot
.27837 .01499 Mdot
.27839 .01625 Mdot
.27842 .01579 Mdot
.27845 .01523 Mdot
.27847 .01569 Mdot
.2785 .01657 Mdot
.27852 .01578 Mdot
.27855 .0151 Mdot
.27858 .01546 Mdot
.2786 .01515 Mdot
.27863 .01548 Mdot
.27865 .0158 Mdot
.27868 .01652 Mdot
.2787 .0157 Mdot
.27873 .0152 Mdot
.27876 .01554 Mdot
.27878 .01566 Mdot
.27881 .01591 Mdot
.27883 .01648 Mdot
.27886 .01511 Mdot
.27889 .0152 Mdot
.27891 .01504 Mdot
.27894 .0149 Mdot
.27896 .01516 Mdot
.27899 .01681 Mdot
.27901 .01514 Mdot
.27904 .01587 Mdot
.27907 .0155 Mdot
.27909 .01516 Mdot
.27912 .01523 Mdot
.27914 .0151 Mdot
.27917 .01476 Mdot
.2792 .01584 Mdot
.27922 .01536 Mdot
.27925 .01558 Mdot
.27927 .0152 Mdot
.2793 .01605 Mdot
.27932 .01521 Mdot
.27935 .0155 Mdot
.27938 .01525 Mdot
.2794 .01604 Mdot
.27943 .01547 Mdot
.27945 .01614 Mdot
.27948 .01534 Mdot
.27951 .01554 Mdot
.27953 .01545 Mdot
.27956 .01612 Mdot
.27958 .01495 Mdot
.27961 .01634 Mdot
.27963 .0152 Mdot
.27966 .01567 Mdot
.27969 .01533 Mdot
.27971 .01652 Mdot
.27974 .01543 Mdot
.27976 .01504 Mdot
.27979 .01629 Mdot
.27982 .01553 Mdot
.27984 .01629 Mdot
.27987 .01614 Mdot
.27989 .01564 Mdot
.27992 .01509 Mdot
.27994 .01616 Mdot
.27997 .01625 Mdot
.28 .01651 Mdot
.28002 .01541 Mdot
.28005 .01702 Mdot
.28007 .01655 Mdot
.2801 .01566 Mdot
.28013 .01546 Mdot
.28015 .01496 Mdot
.28018 .0155 Mdot
.2802 .01601 Mdot
.28023 .01668 Mdot
.28025 .01537 Mdot
.28028 .01644 Mdot
.28031 .01567 Mdot
.28033 .01542 Mdot
.28036 .01559 Mdot
.28038 .01648 Mdot
.28041 .01535 Mdot
.28044 .01565 Mdot
.28046 .01559 Mdot
.28049 .01529 Mdot
.28051 .01559 Mdot
.28054 .01545 Mdot
.28056 .01569 Mdot
.28059 .01527 Mdot
.28062 .01495 Mdot
.28064 .01509 Mdot
.28067 .01543 Mdot
.28069 .01628 Mdot
.28072 .01613 Mdot
.28075 .0162 Mdot
.28077 .01506 Mdot
.2808 .01617 Mdot
.28082 .01569 Mdot
.28085 .01614 Mdot
.28087 .01635 Mdot
.2809 .01636 Mdot
.28093 .0176 Mdot
.28095 .01653 Mdot
.28098 .01537 Mdot
.281 .01655 Mdot
.28103 .01646 Mdot
.28106 .01567 Mdot
.28108 .01635 Mdot
.28111 .01573 Mdot
.28113 .01532 Mdot
.28116 .01657 Mdot
.28118 .01523 Mdot
.28121 .01626 Mdot
.28124 .01575 Mdot
.28126 .01558 Mdot
.28129 .01574 Mdot
.28131 .01531 Mdot
.28134 .01555 Mdot
.28137 .01526 Mdot
.28139 .0157 Mdot
.28142 .01521 Mdot
.28144 .01599 Mdot
.28147 .01655 Mdot
.28149 .01542 Mdot
.28152 .01517 Mdot
.28155 .01557 Mdot
.28157 .01631 Mdot
.2816 .01655 Mdot
.28162 .0163 Mdot
.28165 .01569 Mdot
.28168 .0162 Mdot
.2817 .01578 Mdot
.28173 .01545 Mdot
.28175 .01647 Mdot
.28178 .01604 Mdot
.2818 .01516 Mdot
.28183 .01483 Mdot
.28186 .01507 Mdot
.28188 .01667 Mdot
.28191 .0152 Mdot
.28193 .0153 Mdot
.28196 .01518 Mdot
.28199 .01588 Mdot
.28201 .01608 Mdot
.28204 .01561 Mdot
.28206 .01607 Mdot
.28209 .01554 Mdot
.28211 .01578 Mdot
.28214 .01641 Mdot
.28217 .01619 Mdot
.28219 .01488 Mdot
.28222 .01521 Mdot
.28224 .01606 Mdot
.28227 .01524 Mdot
.2823 .01617 Mdot
.28232 .01539 Mdot
.28235 .01579 Mdot
.28237 .01616 Mdot
.2824 .01642 Mdot
.28242 .01519 Mdot
.28245 .01655 Mdot
.28248 .01596 Mdot
.2825 .0152 Mdot
.28253 .01562 Mdot
.28255 .01623 Mdot
.28258 .01573 Mdot
.28261 .01572 Mdot
.28263 .015 Mdot
.28266 .01541 Mdot
.28268 .01592 Mdot
.28271 .01517 Mdot
.28273 .01508 Mdot
.28276 .01558 Mdot
.28279 .01553 Mdot
.28281 .01479 Mdot
.28284 .01563 Mdot
.28286 .01558 Mdot
.28289 .01525 Mdot
.28292 .01583 Mdot
.28294 .01523 Mdot
.28297 .0151 Mdot
.28299 .01559 Mdot
.28302 .01488 Mdot
.28304 .01573 Mdot
.28307 .01566 Mdot
.2831 .01508 Mdot
.28312 .01611 Mdot
.28315 .01625 Mdot
.28317 .01549 Mdot
.2832 .01549 Mdot
.28323 .01587 Mdot
.28325 .01617 Mdot
.28328 .01776 Mdot
.2833 .01541 Mdot
.28333 .01555 Mdot
.28335 .01533 Mdot
.28338 .0157 Mdot
.28341 .01538 Mdot
.28343 .01551 Mdot
.28346 .01602 Mdot
.28348 .01685 Mdot
.28351 .01532 Mdot
.28354 .01525 Mdot
.28356 .01543 Mdot
.28359 .01495 Mdot
.28361 .0154 Mdot
.28364 .01587 Mdot
.28366 .01706 Mdot
.28369 .01577 Mdot
.28372 .01579 Mdot
.28374 .01643 Mdot
.28377 .0156 Mdot
.28379 .01608 Mdot
.28382 .01511 Mdot
.28385 .01605 Mdot
.28387 .017 Mdot
.2839 .01532 Mdot
.28392 .01562 Mdot
.28395 .01501 Mdot
.28397 .01514 Mdot
.284 .01481 Mdot
.28403 .01538 Mdot
.28405 .01541 Mdot
.28408 .01642 Mdot
.2841 .01583 Mdot
.28413 .01579 Mdot
.28416 .0157 Mdot
.28418 .01528 Mdot
.28421 .01595 Mdot
.28423 .01555 Mdot
.28426 .01502 Mdot
.28428 .01589 Mdot
.28431 .01496 Mdot
.28434 .01627 Mdot
.28436 .01555 Mdot
.28439 .01689 Mdot
.28441 .01502 Mdot
.28444 .01511 Mdot
.28447 .01584 Mdot
.28449 .01602 Mdot
.28452 .0159 Mdot
.28454 .01537 Mdot
.28457 .0159 Mdot
.28459 .01529 Mdot
.28462 .01629 Mdot
.28465 .01602 Mdot
.28467 .01586 Mdot
.2847 .01581 Mdot
.28472 .0162 Mdot
.28475 .0159 Mdot
.28478 .01571 Mdot
.2848 .0159 Mdot
.28483 .01538 Mdot
.28485 .01595 Mdot
.28488 .01607 Mdot
.2849 .01486 Mdot
.28493 .01509 Mdot
.28496 .01575 Mdot
.28498 .01574 Mdot
.28501 .01548 Mdot
.28503 .01604 Mdot
.28506 .01588 Mdot
.28509 .01622 Mdot
.28511 .01589 Mdot
.28514 .0156 Mdot
.28516 .01508 Mdot
.28519 .01496 Mdot
.28522 .01563 Mdot
.28524 .01529 Mdot
.28527 .01687 Mdot
.28529 .01546 Mdot
.28532 .01542 Mdot
.28534 .01589 Mdot
.28537 .01788 Mdot
.2854 .01705 Mdot
.28542 .01506 Mdot
.28545 .01666 Mdot
.28547 .0149 Mdot
.2855 .01619 Mdot
.28553 .01573 Mdot
.28555 .01589 Mdot
.28558 .01636 Mdot
.2856 .01561 Mdot
.28563 .01668 Mdot
.28565 .01614 Mdot
.28568 .0159 Mdot
.28571 .0156 Mdot
.28573 .01585 Mdot
.28576 .01591 Mdot
.28578 .01554 Mdot
.28581 .01545 Mdot
.28584 .01516 Mdot
.28586 .01576 Mdot
.28589 .01577 Mdot
.28591 .01601 Mdot
.28594 .01668 Mdot
.28596 .01503 Mdot
.28599 .01698 Mdot
.28602 .01551 Mdot
.28604 .01719 Mdot
.28607 .01595 Mdot
.28609 .01627 Mdot
.28612 .0156 Mdot
.28615 .01511 Mdot
.28617 .0159 Mdot
.2862 .01575 Mdot
.28622 .01546 Mdot
.28625 .01549 Mdot
.28627 .01498 Mdot
.2863 .01575 Mdot
.28633 .01551 Mdot
.28635 .01672 Mdot
.28638 .01585 Mdot
.2864 .01542 Mdot
.28643 .01483 Mdot
.28646 .01552 Mdot
.28648 .01548 Mdot
.28651 .01574 Mdot
.28653 .01527 Mdot
.28656 .0159 Mdot
.28658 .01536 Mdot
.28661 .01591 Mdot
.28664 .01677 Mdot
.28666 .0157 Mdot
.28669 .0161 Mdot
.28671 .01694 Mdot
.28674 .01533 Mdot
.28677 .0153 Mdot
.28679 .01482 Mdot
.28682 .01552 Mdot
.28684 .01617 Mdot
.28687 .01567 Mdot
.28689 .01518 Mdot
.28692 .01521 Mdot
.28695 .01631 Mdot
.28697 .01578 Mdot
.287 .01524 Mdot
.28702 .01626 Mdot
.28705 .01563 Mdot
.28708 .01573 Mdot
.2871 .01612 Mdot
.28713 .01511 Mdot
.28715 .01542 Mdot
.28718 .01604 Mdot
.2872 .01541 Mdot
.28723 .0162 Mdot
.28726 .01577 Mdot
.28728 .01524 Mdot
.28731 .01492 Mdot
.28733 .01538 Mdot
.28736 .01579 Mdot
.28739 .01634 Mdot
.28741 .01639 Mdot
.28744 .01547 Mdot
.28746 .0149 Mdot
.28749 .01554 Mdot
.28751 .01542 Mdot
.28754 .01568 Mdot
.28757 .01571 Mdot
.28759 .01488 Mdot
.28762 .01493 Mdot
.28764 .01547 Mdot
.28767 .01536 Mdot
.2877 .01557 Mdot
.28772 .01565 Mdot
.28775 .01537 Mdot
.28777 .01586 Mdot
.2878 .01551 Mdot
.28782 .01707 Mdot
.28785 .01541 Mdot
.28788 .01532 Mdot
.2879 .01551 Mdot
.28793 .01633 Mdot
.28795 .0155 Mdot
.28798 .01579 Mdot
.28801 .01589 Mdot
.28803 .01532 Mdot
.28806 .01576 Mdot
.28808 .01549 Mdot
.28811 .01529 Mdot
.28813 .0157 Mdot
.28816 .01624 Mdot
.28819 .01588 Mdot
.28821 .01554 Mdot
.28824 .01638 Mdot
.28826 .01535 Mdot
.28829 .01611 Mdot
.28832 .01542 Mdot
.28834 .01623 Mdot
.28837 .01554 Mdot
.28839 .01517 Mdot
.28842 .01597 Mdot
.28844 .01573 Mdot
.28847 .01535 Mdot
.2885 .01546 Mdot
.28852 .01588 Mdot
.28855 .01497 Mdot
.28857 .01569 Mdot
.2886 .0149 Mdot
.28863 .01525 Mdot
.28865 .01543 Mdot
.28868 .01603 Mdot
.2887 .01617 Mdot
.28873 .01599 Mdot
.28875 .01652 Mdot
.28878 .01524 Mdot
.28881 .01632 Mdot
.28883 .0158 Mdot
.28886 .01586 Mdot
.28888 .01553 Mdot
.28891 .01488 Mdot
.28894 .01491 Mdot
.28896 .01602 Mdot
.28899 .01483 Mdot
.28901 .01556 Mdot
.28904 .01616 Mdot
.28906 .01631 Mdot
.28909 .01573 Mdot
.28912 .01494 Mdot
.28914 .01587 Mdot
.28917 .01489 Mdot
.28919 .01516 Mdot
.28922 .01611 Mdot
.28925 .01548 Mdot
.28927 .01608 Mdot
.2893 .0152 Mdot
.28932 .01528 Mdot
.28935 .01638 Mdot
.28937 .01526 Mdot
.2894 .01618 Mdot
.28943 .01583 Mdot
.28945 .01526 Mdot
.28948 .01589 Mdot
.2895 .01513 Mdot
.28953 .01662 Mdot
.28956 .01615 Mdot
.28958 .0152 Mdot
.28961 .01523 Mdot
.28963 .01567 Mdot
.28966 .01508 Mdot
.28968 .0155 Mdot
.28971 .01601 Mdot
.28974 .01479 Mdot
.28976 .01652 Mdot
.28979 .01492 Mdot
.28981 .01639 Mdot
.28984 .01519 Mdot
.28987 .01548 Mdot
.28989 .01634 Mdot
.28992 .01532 Mdot
.28994 .01604 Mdot
.28997 .015 Mdot
.28999 .01583 Mdot
.29002 .01569 Mdot
.29005 .01625 Mdot
.29007 .01599 Mdot
.2901 .01491 Mdot
.29012 .01536 Mdot
.29015 .01522 Mdot
.29018 .01714 Mdot
.2902 .0157 Mdot
.29023 .01492 Mdot
.29025 .01635 Mdot
.29028 .01546 Mdot
.2903 .01591 Mdot
.29033 .01503 Mdot
.29036 .01548 Mdot
.29038 .01618 Mdot
.29041 .01644 Mdot
.29043 .01536 Mdot
.29046 .01592 Mdot
.29049 .01526 Mdot
.29051 .01526 Mdot
.29054 .0161 Mdot
.29056 .01546 Mdot
.29059 .01488 Mdot
.29061 .01591 Mdot
.29064 .01548 Mdot
.29067 .01624 Mdot
.29069 .01616 Mdot
.29072 .01548 Mdot
.29074 .01558 Mdot
.29077 .01641 Mdot
.2908 .01613 Mdot
.29082 .01588 Mdot
.29085 .01541 Mdot
.29087 .01567 Mdot
.2909 .0162 Mdot
.29092 .0173 Mdot
.29095 .01712 Mdot
.29098 .01593 Mdot
.291 .01526 Mdot
.29103 .01565 Mdot
.29105 .01524 Mdot
.29108 .0159 Mdot
.29111 .0153 Mdot
.29113 .01538 Mdot
.29116 .01512 Mdot
.29118 .01541 Mdot
.29121 .0165 Mdot
.29123 .01582 Mdot
.29126 .0153 Mdot
.29129 .0165 Mdot
.29131 .01566 Mdot
.29134 .01492 Mdot
.29136 .01557 Mdot
.29139 .01607 Mdot
.29142 .01599 Mdot
.29144 .01509 Mdot
.29147 .01523 Mdot
.29149 .0154 Mdot
.29152 .01535 Mdot
.29154 .01502 Mdot
.29157 .01628 Mdot
.2916 .01496 Mdot
.29162 .01732 Mdot
.29165 .01571 Mdot
.29167 .01539 Mdot
.2917 .01583 Mdot
.29173 .01583 Mdot
.29175 .01569 Mdot
.29178 .0155 Mdot
.2918 .01611 Mdot
.29183 .01632 Mdot
.29185 .01625 Mdot
.29188 .01661 Mdot
.29191 .01617 Mdot
.29193 .01612 Mdot
.29196 .01565 Mdot
.29198 .01571 Mdot
.29201 .01564 Mdot
.29204 .01544 Mdot
.29206 .01553 Mdot
.29209 .01634 Mdot
.29211 .01654 Mdot
.29214 .01558 Mdot
.29216 .01531 Mdot
.29219 .01535 Mdot
.29222 .01573 Mdot
.29224 .01548 Mdot
.29227 .01561 Mdot
.29229 .01554 Mdot
.29232 .01611 Mdot
.29235 .01529 Mdot
.29237 .01524 Mdot
.2924 .01504 Mdot
.29242 .01523 Mdot
.29245 .01645 Mdot
.29247 .01562 Mdot
.2925 .01502 Mdot
.29253 .01652 Mdot
.29255 .01515 Mdot
.29258 .01649 Mdot
.2926 .01589 Mdot
.29263 .01527 Mdot
.29266 .01569 Mdot
.29268 .01547 Mdot
.29271 .0151 Mdot
.29273 .01527 Mdot
.29276 .01611 Mdot
.29278 .01536 Mdot
.29281 .0162 Mdot
.29284 .01548 Mdot
.29286 .0157 Mdot
.29289 .0161 Mdot
.29291 .01556 Mdot
.29294 .0155 Mdot
.29297 .01538 Mdot
.29299 .01597 Mdot
.29302 .01491 Mdot
.29304 .01536 Mdot
.29307 .01541 Mdot
.29309 .01565 Mdot
.29312 .0155 Mdot
.29315 .01543 Mdot
.29317 .01524 Mdot
.2932 .01673 Mdot
.29322 .01495 Mdot
.29325 .01631 Mdot
.29328 .01528 Mdot
.2933 .01518 Mdot
.29333 .01516 Mdot
.29335 .0156 Mdot
.29338 .0154 Mdot
.2934 .01601 Mdot
.29343 .01493 Mdot
.29346 .0165 Mdot
.29348 .01493 Mdot
.29351 .01632 Mdot
.29353 .01522 Mdot
.29356 .01686 Mdot
.29359 .01521 Mdot
.29361 .01531 Mdot
.29364 .01594 Mdot
.29366 .01609 Mdot
.29369 .01613 Mdot
.29371 .01566 Mdot
.29374 .01537 Mdot
.29377 .01603 Mdot
.29379 .01547 Mdot
.29382 .01536 Mdot
.29384 .01581 Mdot
.29387 .01565 Mdot
.2939 .01547 Mdot
.29392 .01612 Mdot
.29395 .01656 Mdot
.29397 .01577 Mdot
.294 .01551 Mdot
.29402 .01531 Mdot
.29405 .01558 Mdot
.29408 .01642 Mdot
.2941 .01623 Mdot
.29413 .01596 Mdot
.29415 .01542 Mdot
.29418 .01663 Mdot
.29421 .01503 Mdot
.29423 .0156 Mdot
.29426 .01609 Mdot
.29428 .01601 Mdot
.29431 .01534 Mdot
.29434 .01592 Mdot
.29436 .01564 Mdot
.29439 .01524 Mdot
.29441 .01593 Mdot
.29444 .0159 Mdot
.29446 .01581 Mdot
.29449 .01607 Mdot
.29452 .01547 Mdot
.29454 .01536 Mdot
.29457 .01606 Mdot
.29459 .01569 Mdot
.29462 .01502 Mdot
.29465 .01572 Mdot
.29467 .01499 Mdot
.2947 .01512 Mdot
.29472 .01561 Mdot
.29475 .01709 Mdot
.29477 .01501 Mdot
.2948 .01584 Mdot
.29483 .01605 Mdot
.29485 .01569 Mdot
.29488 .01549 Mdot
.2949 .0161 Mdot
.29493 .01561 Mdot
.29496 .0156 Mdot
.29498 .01592 Mdot
.29501 .01631 Mdot
.29503 .01501 Mdot
.29506 .01535 Mdot
.29508 .01573 Mdot
.29511 .01609 Mdot
.29514 .01559 Mdot
.29516 .01488 Mdot
.29519 .01684 Mdot
.29521 .01592 Mdot
.29524 .01627 Mdot
.29527 .01606 Mdot
.29529 .01717 Mdot
.29532 .01591 Mdot
.29534 .01533 Mdot
.29537 .01501 Mdot
.29539 .01539 Mdot
.29542 .01531 Mdot
.29545 .01629 Mdot
.29547 .01599 Mdot
.2955 .01666 Mdot
.29552 .01557 Mdot
.29555 .01552 Mdot
.29558 .01577 Mdot
.2956 .01541 Mdot
.29563 .01612 Mdot
.29565 .01633 Mdot
.29568 .01502 Mdot
.2957 .0162 Mdot
.29573 .01651 Mdot
.29576 .0148 Mdot
.29578 .01665 Mdot
.29581 .01572 Mdot
.29583 .01615 Mdot
.29586 .0153 Mdot
.29589 .01503 Mdot
.29591 .01602 Mdot
.29594 .0165 Mdot
.29596 .01623 Mdot
.29599 .01604 Mdot
.29601 .01554 Mdot
.29604 .0171 Mdot
.29607 .01625 Mdot
.29609 .01505 Mdot
.29612 .01534 Mdot
.29614 .01557 Mdot
.29617 .01595 Mdot
.2962 .01627 Mdot
.29622 .01512 Mdot
.29625 .01692 Mdot
.29627 .01673 Mdot
.2963 .01716 Mdot
.29632 .01534 Mdot
.29635 .01504 Mdot
.29638 .01633 Mdot
.2964 .01527 Mdot
.29643 .01651 Mdot
.29645 .01553 Mdot
.29648 .01497 Mdot
.29651 .01541 Mdot
.29653 .0159 Mdot
.29656 .01555 Mdot
.29658 .01551 Mdot
.29661 .01833 Mdot
.29663 .0156 Mdot
.29666 .01492 Mdot
.29669 .01579 Mdot
.29671 .01633 Mdot
.29674 .01503 Mdot
.29676 .01516 Mdot
.29679 .0159 Mdot
.29682 .0152 Mdot
.29684 .01523 Mdot
.29687 .01717 Mdot
.29689 .01501 Mdot
.29692 .01555 Mdot
.29694 .01608 Mdot
.29697 .01625 Mdot
.297 .01639 Mdot
.29702 .01541 Mdot
.29705 .01592 Mdot
.29707 .01629 Mdot
.2971 .01576 Mdot
.29713 .01516 Mdot
.29715 .01561 Mdot
.29718 .01607 Mdot
.2972 .01515 Mdot
.29723 .01571 Mdot
.29725 .01521 Mdot
.29728 .01566 Mdot
.29731 .01523 Mdot
.29733 .01598 Mdot
.29736 .01617 Mdot
.29738 .01717 Mdot
.29741 .01488 Mdot
.29744 .01497 Mdot
.29746 .01541 Mdot
.29749 .01605 Mdot
.29751 .01575 Mdot
.29754 .01537 Mdot
.29756 .01535 Mdot
.29759 .0158 Mdot
.29762 .01501 Mdot
.29764 .01633 Mdot
.29767 .01567 Mdot
.29769 .01499 Mdot
.29772 .01552 Mdot
.29775 .01548 Mdot
.29777 .01604 Mdot
.2978 .01606 Mdot
.29782 .0171 Mdot
.29785 .01698 Mdot
.29787 .01666 Mdot
.2979 .0163 Mdot
.29793 .01664 Mdot
.29795 .01508 Mdot
.29798 .0156 Mdot
.298 .01641 Mdot
.29803 .0157 Mdot
.29806 .01668 Mdot
.29808 .0154 Mdot
.29811 .01587 Mdot
.29813 .01578 Mdot
.29816 .01557 Mdot
.29818 .01561 Mdot
.29821 .01574 Mdot
.29824 .01616 Mdot
.29826 .01598 Mdot
.29829 .01506 Mdot
.29831 .01556 Mdot
.29834 .01517 Mdot
.29837 .01509 Mdot
.29839 .015 Mdot
.29842 .01565 Mdot
.29844 .01622 Mdot
.29847 .01611 Mdot
.29849 .01508 Mdot
.29852 .01585 Mdot
.29855 .01603 Mdot
.29857 .01548 Mdot
.2986 .01633 Mdot
.29862 .01603 Mdot
.29865 .01533 Mdot
.29868 .01542 Mdot
.2987 .0155 Mdot
.29873 .01524 Mdot
.29875 .01556 Mdot
.29878 .01595 Mdot
.2988 .01589 Mdot
.29883 .01579 Mdot
.29886 .0152 Mdot
.29888 .01553 Mdot
.29891 .01489 Mdot
.29893 .01686 Mdot
.29896 .01616 Mdot
.29899 .01521 Mdot
.29901 .01573 Mdot
.29904 .01517 Mdot
.29906 .01515 Mdot
.29909 .01583 Mdot
.29911 .01497 Mdot
.29914 .01569 Mdot
.29917 .01579 Mdot
.29919 .01548 Mdot
.29922 .0163 Mdot
.29924 .01662 Mdot
.29927 .01505 Mdot
.2993 .01532 Mdot
.29932 .01566 Mdot
.29935 .01651 Mdot
.29937 .01526 Mdot
.2994 .01582 Mdot
.29942 .01575 Mdot
.29945 .01536 Mdot
.29948 .0159 Mdot
.2995 .01558 Mdot
.29953 .01545 Mdot
.29955 .01525 Mdot
.29958 .0151 Mdot
.29961 .0155 Mdot
.29963 .01586 Mdot
.29966 .01583 Mdot
.29968 .01566 Mdot
.29971 .01558 Mdot
.29973 .01543 Mdot
.29976 .01548 Mdot
.29979 .01593 Mdot
.29981 .0162 Mdot
.29984 .01493 Mdot
.29986 .01515 Mdot
.29989 .01633 Mdot
.29992 .01586 Mdot
.29994 .01587 Mdot
.29997 .01641 Mdot
.29999 .01579 Mdot
.30002 .01531 Mdot
.30004 .01592 Mdot
.30007 .01564 Mdot
.3001 .01568 Mdot
.30012 .01522 Mdot
.30015 .015 Mdot
.30017 .0167 Mdot
.3002 .01582 Mdot
.30023 .01588 Mdot
.30025 .01558 Mdot
.30028 .0166 Mdot
.3003 .01536 Mdot
.30033 .01509 Mdot
.30035 .01554 Mdot
.30038 .0162 Mdot
.30041 .01634 Mdot
.30043 .0157 Mdot
.30046 .0162 Mdot
.30048 .01562 Mdot
.30051 .01596 Mdot
.30054 .01497 Mdot
.30056 .01499 Mdot
.30059 .01627 Mdot
.30061 .01614 Mdot
.30064 .01548 Mdot
.30066 .0166 Mdot
.30069 .01634 Mdot
.30072 .01556 Mdot
.30074 .01615 Mdot
.30077 .0149 Mdot
.30079 .01599 Mdot
.30082 .01617 Mdot
.30085 .01535 Mdot
.30087 .01552 Mdot
.3009 .01619 Mdot
.30092 .01475 Mdot
.30095 .01541 Mdot
.30097 .01516 Mdot
.301 .01568 Mdot
.30103 .0151 Mdot
.30105 .01527 Mdot
.30108 .01598 Mdot
.3011 .01648 Mdot
.30113 .01608 Mdot
.30116 .01524 Mdot
.30118 .01579 Mdot
.30121 .01673 Mdot
.30123 .01563 Mdot
.30126 .01509 Mdot
.30128 .01543 Mdot
.30131 .01535 Mdot
.30134 .0151 Mdot
.30136 .01673 Mdot
.30139 .01638 Mdot
.30141 .01564 Mdot
.30144 .01577 Mdot
.30147 .01527 Mdot
.30149 .01723 Mdot
.30152 .01594 Mdot
.30154 .01532 Mdot
.30157 .0155 Mdot
.30159 .01664 Mdot
.30162 .01555 Mdot
.30165 .01532 Mdot
.30167 .01531 Mdot
.3017 .01645 Mdot
.30172 .01498 Mdot
.30175 .01557 Mdot
.30178 .01582 Mdot
.3018 .01549 Mdot
.30183 .01501 Mdot
.30185 .01592 Mdot
.30188 .01582 Mdot
.3019 .01569 Mdot
.30193 .0165 Mdot
.30196 .01478 Mdot
.30198 .01585 Mdot
.30201 .01512 Mdot
.30203 .01639 Mdot
.30206 .0158 Mdot
.30209 .01636 Mdot
.30211 .015 Mdot
.30214 .01607 Mdot
.30216 .01591 Mdot
.30219 .01578 Mdot
.30221 .01525 Mdot
.30224 .01507 Mdot
.30227 .01524 Mdot
.30229 .0159 Mdot
.30232 .01494 Mdot
.30234 .0154 Mdot
.30237 .017 Mdot
.3024 .01525 Mdot
.30242 .01732 Mdot
.30245 .01664 Mdot
.30247 .01563 Mdot
.3025 .01547 Mdot
.30252 .0165 Mdot
.30255 .01605 Mdot
.30258 .01586 Mdot
.3026 .01577 Mdot
.30263 .01542 Mdot
.30265 .01536 Mdot
.30268 .01621 Mdot
.30271 .01547 Mdot
.30273 .01565 Mdot
.30276 .01576 Mdot
.30278 .01501 Mdot
.30281 .01552 Mdot
.30283 .01661 Mdot
.30286 .01548 Mdot
.30289 .01662 Mdot
.30291 .01704 Mdot
.30294 .01576 Mdot
.30296 .01533 Mdot
.30299 .01538 Mdot
.30302 .01654 Mdot
.30304 .01542 Mdot
.30307 .01563 Mdot
.30309 .01523 Mdot
.30312 .01676 Mdot
.30314 .01617 Mdot
.30317 .01609 Mdot
.3032 .01582 Mdot
.30322 .0149 Mdot
.30325 .01614 Mdot
.30327 .01598 Mdot
.3033 .01612 Mdot
.30333 .01621 Mdot
.30335 .01559 Mdot
.30338 .01596 Mdot
.3034 .01477 Mdot
.30343 .01545 Mdot
.30346 .01556 Mdot
.30348 .01573 Mdot
.30351 .01565 Mdot
.30353 .01509 Mdot
.30356 .01505 Mdot
.30358 .0158 Mdot
.30361 .0152 Mdot
.30364 .01515 Mdot
.30366 .01595 Mdot
.30369 .01613 Mdot
.30371 .01532 Mdot
.30374 .0154 Mdot
.30377 .01514 Mdot
.30379 .01502 Mdot
.30382 .01625 Mdot
.30384 .01588 Mdot
.30387 .01636 Mdot
.30389 .01624 Mdot
.30392 .01634 Mdot
.30395 .01586 Mdot
.30397 .01515 Mdot
.304 .01579 Mdot
.30402 .01555 Mdot
.30405 .01599 Mdot
.30408 .01579 Mdot
.3041 .01709 Mdot
.30413 .01636 Mdot
.30415 .01566 Mdot
.30418 .016 Mdot
.3042 .01605 Mdot
.30423 .01585 Mdot
.30426 .01583 Mdot
.30428 .01625 Mdot
.30431 .01606 Mdot
.30433 .01604 Mdot
.30436 .01568 Mdot
.30439 .01533 Mdot
.30441 .01618 Mdot
.30444 .01545 Mdot
.30446 .01522 Mdot
.30449 .01593 Mdot
.30451 .01526 Mdot
.30454 .01564 Mdot
.30457 .01559 Mdot
.30459 .01577 Mdot
.30462 .01644 Mdot
.30464 .01559 Mdot
.30467 .01607 Mdot
.3047 .015 Mdot
.30472 .01621 Mdot
.30475 .01535 Mdot
.30477 .01577 Mdot
.3048 .01604 Mdot
.30482 .01521 Mdot
.30485 .01512 Mdot
.30488 .01592 Mdot
.3049 .01542 Mdot
.30493 .01634 Mdot
.30495 .01575 Mdot
.30498 .01545 Mdot
.30501 .01531 Mdot
.30503 .01501 Mdot
.30506 .01554 Mdot
.30508 .01535 Mdot
.30511 .01623 Mdot
.30513 .01634 Mdot
.30516 .01531 Mdot
.30519 .01568 Mdot
.30521 .01556 Mdot
.30524 .01581 Mdot
.30526 .01531 Mdot
.30529 .01549 Mdot
.30532 .01588 Mdot
.30534 .01506 Mdot
.30537 .01572 Mdot
.30539 .01576 Mdot
.30542 .01639 Mdot
.30544 .01511 Mdot
.30547 .01538 Mdot
.3055 .0161 Mdot
.30552 .01507 Mdot
.30555 .01539 Mdot
.30557 .01585 Mdot
.3056 .01568 Mdot
.30563 .01526 Mdot
.30565 .01551 Mdot
.30568 .01513 Mdot
.3057 .01543 Mdot
.30573 .01618 Mdot
.30575 .01481 Mdot
.30578 .01502 Mdot
.30581 .01644 Mdot
.30583 .0165 Mdot
.30586 .01515 Mdot
.30588 .01479 Mdot
.30591 .01609 Mdot
.30594 .016 Mdot
.30596 .01555 Mdot
.30599 .01542 Mdot
.30601 .01702 Mdot
.30604 .01559 Mdot
.30606 .01545 Mdot
.30609 .01555 Mdot
.30612 .01582 Mdot
.30614 .01683 Mdot
.30617 .01594 Mdot
.30619 .01672 Mdot
.30622 .01613 Mdot
.30625 .01579 Mdot
.30627 .0158 Mdot
.3063 .01568 Mdot
.30632 .01591 Mdot
.30635 .01526 Mdot
.30637 .01607 Mdot
.3064 .01619 Mdot
.30643 .0152 Mdot
.30645 .01502 Mdot
.30648 .01514 Mdot
.3065 .01576 Mdot
.30653 .01493 Mdot
.30656 .01501 Mdot
.30658 .01536 Mdot
.30661 .01528 Mdot
.30663 .01537 Mdot
.30666 .0155 Mdot
.30668 .0151 Mdot
.30671 .01641 Mdot
.30674 .01577 Mdot
.30676 .01486 Mdot
.30679 .01568 Mdot
.30681 .01509 Mdot
.30684 .01506 Mdot
.30687 .01593 Mdot
.30689 .01552 Mdot
.30692 .01553 Mdot
.30694 .01545 Mdot
.30697 .01548 Mdot
.30699 .01609 Mdot
.30702 .01499 Mdot
.30705 .01558 Mdot
.30707 .01616 Mdot
.3071 .01578 Mdot
.30712 .01594 Mdot
.30715 .01631 Mdot
.30718 .01516 Mdot
.3072 .01542 Mdot
.30723 .01579 Mdot
.30725 .015 Mdot
.30728 .01524 Mdot
.3073 .01586 Mdot
.30733 .01474 Mdot
.30736 .01626 Mdot
.30738 .01597 Mdot
.30741 .01522 Mdot
.30743 .01572 Mdot
.30746 .0159 Mdot
.30749 .01517 Mdot
.30751 .0151 Mdot
.30754 .01574 Mdot
.30756 .01579 Mdot
.30759 .01612 Mdot
.30761 .01589 Mdot
.30764 .0153 Mdot
.30767 .01515 Mdot
.30769 .01637 Mdot
.30772 .01592 Mdot
.30774 .01559 Mdot
.30777 .01515 Mdot
.3078 .01517 Mdot
.30782 .0155 Mdot
.30785 .01538 Mdot
.30787 .01547 Mdot
.3079 .01612 Mdot
.30792 .01549 Mdot
.30795 .01577 Mdot
.30798 .0149 Mdot
.308 .01515 Mdot
.30803 .01537 Mdot
.30805 .01514 Mdot
.30808 .01517 Mdot
.30811 .01539 Mdot
.30813 .01603 Mdot
.30816 .01498 Mdot
.30818 .01523 Mdot
.30821 .0148 Mdot
.30823 .01549 Mdot
.30826 .01562 Mdot
.30829 .01563 Mdot
.30831 .0154 Mdot
.30834 .01552 Mdot
.30836 .01511 Mdot
.30839 .01549 Mdot
.30842 .01538 Mdot
.30844 .01581 Mdot
.30847 .01555 Mdot
.30849 .01567 Mdot
.30852 .01483 Mdot
.30854 .01593 Mdot
.30857 .01587 Mdot
.3086 .01621 Mdot
.30862 .0152 Mdot
.30865 .01567 Mdot
.30867 .01506 Mdot
.3087 .01584 Mdot
.30873 .0151 Mdot
.30875 .01516 Mdot
.30878 .01555 Mdot
.3088 .01548 Mdot
.30883 .0149 Mdot
.30885 .01547 Mdot
.30888 .0151 Mdot
.30891 .01506 Mdot
.30893 .0158 Mdot
.30896 .01599 Mdot
.30898 .01597 Mdot
.30901 .01706 Mdot
.30904 .01618 Mdot
.30906 .01588 Mdot
.30909 .01487 Mdot
.30911 .0157 Mdot
.30914 .01499 Mdot
.30916 .01523 Mdot
.30919 .01614 Mdot
.30922 .01621 Mdot
.30924 .01537 Mdot
.30927 .01484 Mdot
.30929 .01526 Mdot
.30932 .01512 Mdot
.30935 .01486 Mdot
.30937 .01527 Mdot
.3094 .01604 Mdot
.30942 .01516 Mdot
.30945 .01569 Mdot
.30947 .0162 Mdot
.3095 .01621 Mdot
.30953 .01554 Mdot
.30955 .01574 Mdot
.30958 .01639 Mdot
.3096 .01561 Mdot
.30963 .01638 Mdot
.30966 .01511 Mdot
.30968 .01556 Mdot
.30971 .01611 Mdot
.30973 .01636 Mdot
.30976 .01547 Mdot
.30978 .0155 Mdot
.30981 .01583 Mdot
.30984 .0155 Mdot
.30986 .01513 Mdot
.30989 .01616 Mdot
.30991 .01593 Mdot
.30994 .01526 Mdot
.30997 .01591 Mdot
.30999 .01509 Mdot
.31002 .01583 Mdot
.31004 .0161 Mdot
.31007 .01544 Mdot
.31009 .01519 Mdot
.31012 .01619 Mdot
.31015 .0163 Mdot
.31017 .01547 Mdot
.3102 .01617 Mdot
.31022 .01572 Mdot
.31025 .01511 Mdot
.31028 .0152 Mdot
.3103 .01526 Mdot
.31033 .01533 Mdot
.31035 .01564 Mdot
.31038 .01626 Mdot
.3104 .01532 Mdot
.31043 .01637 Mdot
.31046 .01631 Mdot
.31048 .01527 Mdot
.31051 .0154 Mdot
.31053 .0151 Mdot
.31056 .01626 Mdot
.31059 .01567 Mdot
.31061 .01555 Mdot
.31064 .01586 Mdot
.31066 .01595 Mdot
.31069 .01549 Mdot
.31071 .01633 Mdot
.31074 .01567 Mdot
.31077 .0153 Mdot
.31079 .01533 Mdot
.31082 .01509 Mdot
.31084 .01597 Mdot
.31087 .01644 Mdot
.3109 .01594 Mdot
.31092 .01624 Mdot
.31095 .01552 Mdot
.31097 .01508 Mdot
.311 .0151 Mdot
.31102 .01599 Mdot
.31105 .01515 Mdot
.31108 .01591 Mdot
.3111 .01509 Mdot
.31113 .01541 Mdot
.31115 .01566 Mdot
.31118 .01608 Mdot
.31121 .01523 Mdot
.31123 .01496 Mdot
.31126 .01562 Mdot
.31128 .01482 Mdot
.31131 .01582 Mdot
.31133 .01504 Mdot
.31136 .01515 Mdot
.31139 .01565 Mdot
.31141 .01551 Mdot
.31144 .01521 Mdot
.31146 .01626 Mdot
.31149 .01603 Mdot
.31152 .01531 Mdot
.31154 .0157 Mdot
.31157 .01592 Mdot
.31159 .01576 Mdot
.31162 .01543 Mdot
.31164 .01539 Mdot
.31167 .01512 Mdot
.3117 .01517 Mdot
.31172 .0157 Mdot
.31175 .01527 Mdot
.31177 .01612 Mdot
.3118 .0156 Mdot
.31183 .01517 Mdot
.31185 .01499 Mdot
.31188 .01541 Mdot
.3119 .01573 Mdot
.31193 .01532 Mdot
.31195 .01516 Mdot
.31198 .01548 Mdot
.31201 .01637 Mdot
.31203 .01509 Mdot
.31206 .01559 Mdot
.31208 .01563 Mdot
.31211 .01675 Mdot
.31214 .01558 Mdot
.31216 .01598 Mdot
.31219 .01564 Mdot
.31221 .01548 Mdot
.31224 .015 Mdot
.31226 .01551 Mdot
.31229 .01574 Mdot
.31232 .01577 Mdot
.31234 .01499 Mdot
.31237 .01624 Mdot
.31239 .0152 Mdot
.31242 .01523 Mdot
.31245 .01499 Mdot
.31247 .01482 Mdot
.3125 .01557 Mdot
.31252 .01584 Mdot
.31255 .01647 Mdot
.31258 .01507 Mdot
.3126 .01568 Mdot
.31263 .01573 Mdot
.31265 .01653 Mdot
.31268 .01494 Mdot
.3127 .01587 Mdot
.31273 .01593 Mdot
.31276 .01525 Mdot
.31278 .01499 Mdot
.31281 .01549 Mdot
.31283 .01553 Mdot
.31286 .0162 Mdot
.31289 .01606 Mdot
.31291 .01613 Mdot
.31294 .01528 Mdot
.31296 .01596 Mdot
.31299 .01493 Mdot
.31301 .01562 Mdot
.31304 .01584 Mdot
.31307 .01539 Mdot
.31309 .01563 Mdot
.31312 .0156 Mdot
.31314 .01668 Mdot
.31317 .01592 Mdot
.3132 .01548 Mdot
.31322 .01638 Mdot
.31325 .01561 Mdot
.31327 .01604 Mdot
.3133 .01609 Mdot
.31332 .01593 Mdot
.31335 .01535 Mdot
.31338 .01621 Mdot
.3134 .01534 Mdot
.31343 .01613 Mdot
.31345 .01719 Mdot
.31348 .01623 Mdot
.31351 .0154 Mdot
.31353 .01566 Mdot
.31356 .01578 Mdot
.31358 .01609 Mdot
.31361 .01618 Mdot
.31363 .01658 Mdot
.31366 .01535 Mdot
.31369 .01491 Mdot
.31371 .01587 Mdot
.31374 .01651 Mdot
.31376 .0148 Mdot
.31379 .01564 Mdot
.31382 .01591 Mdot
.31384 .01552 Mdot
.31387 .01513 Mdot
.31389 .01499 Mdot
.31392 .01577 Mdot
.31394 .01535 Mdot
.31397 .01495 Mdot
.314 .01501 Mdot
.31402 .01517 Mdot
.31405 .0162 Mdot
.31407 .01579 Mdot
.3141 .01512 Mdot
.31413 .01565 Mdot
.31415 .01518 Mdot
.31418 .01694 Mdot
.3142 .0159 Mdot
.31423 .01609 Mdot
.31425 .01496 Mdot
.31428 .01555 Mdot
.31431 .01537 Mdot
.31433 .01605 Mdot
.31436 .01493 Mdot
.31438 .01594 Mdot
.31441 .01625 Mdot
.31444 .01677 Mdot
.31446 .01522 Mdot
.31449 .01564 Mdot
.31451 .01499 Mdot
.31454 .01492 Mdot
.31456 .01623 Mdot
.31459 .01623 Mdot
.31462 .01575 Mdot
.31464 .016 Mdot
.31467 .01542 Mdot
.31469 .01547 Mdot
.31472 .01527 Mdot
.31475 .01555 Mdot
.31477 .01631 Mdot
.3148 .0151 Mdot
.31482 .01539 Mdot
.31485 .01575 Mdot
.31487 .01525 Mdot
.3149 .01618 Mdot
.31493 .01548 Mdot
.31495 .0154 Mdot
.31498 .01528 Mdot
.315 .01492 Mdot
.31503 .01478 Mdot
.31506 .01644 Mdot
.31508 .01479 Mdot
.31511 .0157 Mdot
.31513 .01544 Mdot
.31516 .01554 Mdot
.31518 .01503 Mdot
.31521 .01511 Mdot
.31524 .01512 Mdot
.31526 .01618 Mdot
.31529 .01546 Mdot
.31531 .01538 Mdot
.31534 .01495 Mdot
.31537 .01568 Mdot
.31539 .01533 Mdot
.31542 .01524 Mdot
.31544 .01599 Mdot
.31547 .01658 Mdot
.31549 .01523 Mdot
.31552 .01589 Mdot
.31555 .01507 Mdot
.31557 .01486 Mdot
.3156 .01569 Mdot
.31562 .01587 Mdot
.31565 .01545 Mdot
.31568 .01598 Mdot
.3157 .0149 Mdot
.31573 .01539 Mdot
.31575 .01498 Mdot
.31578 .01603 Mdot
.3158 .01573 Mdot
.31583 .0157 Mdot
.31586 .01604 Mdot
.31588 .01701 Mdot
.31591 .01622 Mdot
.31593 .01552 Mdot
.31596 .01554 Mdot
.31599 .01476 Mdot
.31601 .01494 Mdot
.31604 .01603 Mdot
.31606 .01548 Mdot
.31609 .01541 Mdot
.31611 .01629 Mdot
.31614 .01578 Mdot
.31617 .01555 Mdot
.31619 .01566 Mdot
.31622 .01651 Mdot
.31624 .01513 Mdot
.31627 .01582 Mdot
.3163 .01608 Mdot
.31632 .01529 Mdot
.31635 .01562 Mdot
.31637 .01582 Mdot
.3164 .0158 Mdot
.31642 .01524 Mdot
.31645 .01553 Mdot
.31648 .015 Mdot
.3165 .01502 Mdot
.31653 .01583 Mdot
.31655 .01532 Mdot
.31658 .0148 Mdot
.31661 .01553 Mdot
.31663 .01589 Mdot
.31666 .01629 Mdot
.31668 .01491 Mdot
.31671 .01584 Mdot
.31673 .01512 Mdot
.31676 .01549 Mdot
.31679 .01633 Mdot
.31681 .01577 Mdot
.31684 .01531 Mdot
.31686 .0151 Mdot
.31689 .01551 Mdot
.31692 .01546 Mdot
.31694 .01589 Mdot
.31697 .01645 Mdot
.31699 .0153 Mdot
.31702 .01473 Mdot
.31704 .016 Mdot
.31707 .01472 Mdot
.3171 .01596 Mdot
.31712 .0154 Mdot
.31715 .01489 Mdot
.31717 .01569 Mdot
.3172 .01513 Mdot
.31723 .01485 Mdot
.31725 .01577 Mdot
.31728 .01501 Mdot
.3173 .01542 Mdot
.31733 .01554 Mdot
.31735 .01548 Mdot
.31738 .01576 Mdot
.31741 .01556 Mdot
.31743 .01676 Mdot
.31746 .0149 Mdot
.31748 .01598 Mdot
.31751 .01574 Mdot
.31754 .01528 Mdot
.31756 .01482 Mdot
.31759 .01473 Mdot
.31761 .01576 Mdot
.31764 .0155 Mdot
.31766 .01515 Mdot
.31769 .01592 Mdot
.31772 .01566 Mdot
.31774 .01753 Mdot
.31777 .0154 Mdot
.31779 .01566 Mdot
.31782 .01502 Mdot
.31785 .01512 Mdot
.31787 .01639 Mdot
.3179 .01558 Mdot
.31792 .01496 Mdot
.31795 .01566 Mdot
.31797 .0156 Mdot
.318 .01532 Mdot
.31803 .01609 Mdot
.31805 .01592 Mdot
.31808 .01514 Mdot
.3181 .01497 Mdot
.31813 .01548 Mdot
.31816 .01579 Mdot
.31818 .01685 Mdot
.31821 .01644 Mdot
.31823 .01531 Mdot
.31826 .01518 Mdot
.31828 .01559 Mdot
.31831 .01534 Mdot
.31834 .01578 Mdot
.31836 .01559 Mdot
.31839 .01623 Mdot
.31841 .01562 Mdot
.31844 .01565 Mdot
.31847 .01655 Mdot
.31849 .01602 Mdot
.31852 .01542 Mdot
.31854 .01496 Mdot
.31857 .01616 Mdot
.31859 .01572 Mdot
.31862 .01528 Mdot
.31865 .01507 Mdot
.31867 .01516 Mdot
.3187 .01514 Mdot
.31872 .01511 Mdot
.31875 .01519 Mdot
.31878 .01496 Mdot
.3188 .01568 Mdot
.31883 .01547 Mdot
.31885 .01613 Mdot
.31888 .01623 Mdot
.3189 .01595 Mdot
.31893 .01534 Mdot
.31896 .01615 Mdot
.31898 .01529 Mdot
.31901 .01608 Mdot
.31903 .01553 Mdot
.31906 .01552 Mdot
.31909 .01641 Mdot
.31911 .01632 Mdot
.31914 .01525 Mdot
.31916 .01558 Mdot
.31919 .01524 Mdot
.31921 .01664 Mdot
.31924 .01565 Mdot
.31927 .01547 Mdot
.31929 .01515 Mdot
.31932 .01568 Mdot
.31934 .01533 Mdot
.31937 .01627 Mdot
.3194 .01539 Mdot
.31942 .01544 Mdot
.31945 .01624 Mdot
.31947 .01544 Mdot
.3195 .01532 Mdot
.31952 .01632 Mdot
.31955 .01665 Mdot
.31958 .01484 Mdot
.3196 .01541 Mdot
.31963 .01493 Mdot
.31965 .0154 Mdot
.31968 .01574 Mdot
.31971 .01597 Mdot
.31973 .01613 Mdot
.31976 .0156 Mdot
.31978 .01641 Mdot
.31981 .01519 Mdot
.31983 .01487 Mdot
.31986 .01592 Mdot
.31989 .01629 Mdot
.31991 .01501 Mdot
.31994 .01497 Mdot
.31996 .01534 Mdot
.31999 .01555 Mdot
.32002 .0152 Mdot
.32004 .01542 Mdot
.32007 .01523 Mdot
.32009 .01611 Mdot
.32012 .01617 Mdot
.32014 .01545 Mdot
.32017 .01585 Mdot
.3202 .01578 Mdot
.32022 .01521 Mdot
.32025 .01502 Mdot
.32027 .01515 Mdot
.3203 .01565 Mdot
.32033 .01499 Mdot
.32035 .01547 Mdot
.32038 .01592 Mdot
.3204 .01542 Mdot
.32043 .01627 Mdot
.32045 .01585 Mdot
.32048 .01572 Mdot
.32051 .01509 Mdot
.32053 .016 Mdot
.32056 .01484 Mdot
.32058 .01612 Mdot
.32061 .0156 Mdot
.32064 .01541 Mdot
.32066 .01619 Mdot
.32069 .01669 Mdot
.32071 .01729 Mdot
.32074 .01673 Mdot
.32076 .01597 Mdot
.32079 .01626 Mdot
.32082 .01557 Mdot
.32084 .01511 Mdot
.32087 .01508 Mdot
.32089 .01606 Mdot
.32092 .01547 Mdot
.32095 .0158 Mdot
.32097 .01626 Mdot
.321 .01618 Mdot
.32102 .01587 Mdot
.32105 .01515 Mdot
.32107 .01488 Mdot
.3211 .01501 Mdot
.32113 .01653 Mdot
.32115 .01593 Mdot
.32118 .01551 Mdot
.3212 .015 Mdot
.32123 .01494 Mdot
.32126 .01569 Mdot
.32128 .01555 Mdot
.32131 .01515 Mdot
.32133 .01486 Mdot
.32136 .01537 Mdot
.32138 .01534 Mdot
.32141 .01516 Mdot
.32144 .01663 Mdot
.32146 .01587 Mdot
.32149 .01617 Mdot
.32151 .01576 Mdot
.32154 .01617 Mdot
.32157 .01541 Mdot
.32159 .01576 Mdot
.32162 .01529 Mdot
.32164 .01505 Mdot
.32167 .01698 Mdot
.3217 .01603 Mdot
.32172 .01615 Mdot
.32175 .01498 Mdot
.32177 .01566 Mdot
.3218 .01597 Mdot
.32182 .01634 Mdot
.32185 .01664 Mdot
.32188 .01543 Mdot
.3219 .01557 Mdot
.32193 .01567 Mdot
.32195 .01559 Mdot
.32198 .01582 Mdot
.32201 .01556 Mdot
.32203 .01517 Mdot
.32206 .01538 Mdot
.32208 .01583 Mdot
.32211 .0159 Mdot
.32213 .01659 Mdot
.32216 .01514 Mdot
.32219 .01565 Mdot
.32221 .01567 Mdot
.32224 .01581 Mdot
.32226 .0158 Mdot
.32229 .01549 Mdot
.32232 .01498 Mdot
.32234 .01545 Mdot
.32237 .01529 Mdot
.32239 .01578 Mdot
.32242 .01634 Mdot
.32244 .01578 Mdot
.32247 .016 Mdot
.3225 .01482 Mdot
.32252 .0152 Mdot
.32255 .01511 Mdot
.32257 .01569 Mdot
.3226 .01706 Mdot
.32263 .01537 Mdot
.32265 .01565 Mdot
.32268 .01563 Mdot
.3227 .01604 Mdot
.32273 .01509 Mdot
.32275 .01614 Mdot
.32278 .0153 Mdot
.32281 .01553 Mdot
.32283 .01569 Mdot
.32286 .01568 Mdot
.32288 .01564 Mdot
.32291 .01612 Mdot
.32294 .01633 Mdot
.32296 .01636 Mdot
.32299 .01563 Mdot
.32301 .0156 Mdot
.32304 .01542 Mdot
.32306 .01476 Mdot
.32309 .01583 Mdot
.32312 .01497 Mdot
.32314 .01565 Mdot
.32317 .01642 Mdot
.32319 .01553 Mdot
.32322 .01581 Mdot
.32325 .0162 Mdot
.32327 .01572 Mdot
.3233 .01544 Mdot
.32332 .01636 Mdot
.32335 .0162 Mdot
.32337 .0154 Mdot
.3234 .01658 Mdot
.32343 .01611 Mdot
.32345 .01678 Mdot
.32348 .01546 Mdot
.3235 .01516 Mdot
.32353 .01554 Mdot
.32356 .01598 Mdot
.32358 .01556 Mdot
.32361 .01598 Mdot
.32363 .01643 Mdot
.32366 .01568 Mdot
.32368 .01548 Mdot
.32371 .01542 Mdot
.32374 .01601 Mdot
.32376 .01519 Mdot
.32379 .01498 Mdot
.32381 .01565 Mdot
.32384 .01574 Mdot
.32387 .01556 Mdot
.32389 .0163 Mdot
.32392 .015 Mdot
.32394 .01646 Mdot
.32397 .01671 Mdot
.32399 .01604 Mdot
.32402 .01561 Mdot
.32405 .01531 Mdot
.32407 .01627 Mdot
.3241 .01601 Mdot
.32412 .01543 Mdot
.32415 .01525 Mdot
.32418 .01567 Mdot
.3242 .01521 Mdot
.32423 .01601 Mdot
.32425 .01594 Mdot
.32428 .01553 Mdot
.3243 .01519 Mdot
.32433 .01516 Mdot
.32436 .01503 Mdot
.32438 .01531 Mdot
.32441 .01539 Mdot
.32443 .01498 Mdot
.32446 .01503 Mdot
.32449 .01625 Mdot
.32451 .01497 Mdot
.32454 .01497 Mdot
.32456 .01527 Mdot
.32459 .01506 Mdot
.32461 .01516 Mdot
.32464 .01517 Mdot
.32467 .01571 Mdot
.32469 .0153 Mdot
.32472 .01617 Mdot
.32474 .01582 Mdot
.32477 .01608 Mdot
.3248 .01553 Mdot
.32482 .01599 Mdot
.32485 .01687 Mdot
.32487 .0162 Mdot
.3249 .01528 Mdot
.32492 .01589 Mdot
.32495 .01542 Mdot
.32498 .01537 Mdot
.325 .01514 Mdot
.32503 .01488 Mdot
.32505 .01517 Mdot
.32508 .01595 Mdot
.32511 .01529 Mdot
.32513 .0153 Mdot
.32516 .01483 Mdot
.32518 .01559 Mdot
.32521 .01559 Mdot
.32523 .01572 Mdot
.32526 .01551 Mdot
.32529 .01623 Mdot
.32531 .01571 Mdot
.32534 .01617 Mdot
.32536 .01559 Mdot
.32539 .01641 Mdot
.32542 .01579 Mdot
.32544 .01635 Mdot
.32547 .01517 Mdot
.32549 .01536 Mdot
.32552 .01637 Mdot
.32554 .01503 Mdot
.32557 .01497 Mdot
.3256 .01668 Mdot
.32562 .01612 Mdot
.32565 .01598 Mdot
.32567 .01555 Mdot
.3257 .01517 Mdot
.32573 .01559 Mdot
.32575 .01557 Mdot
.32578 .01494 Mdot
.3258 .01534 Mdot
.32583 .01603 Mdot
.32585 .0164 Mdot
.32588 .01534 Mdot
.32591 .01634 Mdot
.32593 .0154 Mdot
.32596 .01506 Mdot
.32598 .01562 Mdot
.32601 .01613 Mdot
.32604 .0151 Mdot
.32606 .01547 Mdot
.32609 .01547 Mdot
.32611 .01564 Mdot
.32614 .01653 Mdot
.32616 .01685 Mdot
.32619 .01597 Mdot
.32622 .0149 Mdot
.32624 .01645 Mdot
.32627 .01489 Mdot
.32629 .01568 Mdot
.32632 .01561 Mdot
.32635 .0148 Mdot
.32637 .01508 Mdot
.3264 .01637 Mdot
.32642 .0158 Mdot
.32645 .01579 Mdot
.32647 .01536 Mdot
.3265 .01658 Mdot
.32653 .01635 Mdot
.32655 .01512 Mdot
.32658 .0152 Mdot
.3266 .01594 Mdot
.32663 .01562 Mdot
.32666 .01538 Mdot
.32668 .01622 Mdot
.32671 .01508 Mdot
.32673 .01635 Mdot
.32676 .01589 Mdot
.32678 .01575 Mdot
.32681 .01483 Mdot
.32684 .01649 Mdot
.32686 .01515 Mdot
.32689 .01549 Mdot
.32691 .01477 Mdot
.32694 .0153 Mdot
.32697 .01662 Mdot
.32699 .01522 Mdot
.32702 .01672 Mdot
.32704 .01511 Mdot
.32707 .0152 Mdot
.32709 .01504 Mdot
.32712 .01532 Mdot
.32715 .01585 Mdot
.32717 .01535 Mdot
.3272 .01555 Mdot
.32722 .01509 Mdot
.32725 .01548 Mdot
.32728 .0152 Mdot
.3273 .01517 Mdot
.32733 .01492 Mdot
.32735 .01476 Mdot
.32738 .01607 Mdot
.3274 .01575 Mdot
.32743 .01586 Mdot
.32746 .0157 Mdot
.32748 .01581 Mdot
.32751 .0156 Mdot
.32753 .01585 Mdot
.32756 .01589 Mdot
.32759 .01631 Mdot
.32761 .01493 Mdot
.32764 .01506 Mdot
.32766 .01624 Mdot
.32769 .01607 Mdot
.32771 .01528 Mdot
.32774 .01583 Mdot
.32777 .01562 Mdot
.32779 .01647 Mdot
.32782 .01604 Mdot
.32784 .01503 Mdot
.32787 .0153 Mdot
.3279 .0154 Mdot
.32792 .01557 Mdot
.32795 .0153 Mdot
.32797 .01586 Mdot
.328 .01682 Mdot
.32802 .01562 Mdot
.32805 .0154 Mdot
.32808 .01543 Mdot
.3281 .01577 Mdot
.32813 .01582 Mdot
.32815 .01493 Mdot
.32818 .01514 Mdot
.32821 .01505 Mdot
.32823 .01534 Mdot
.32826 .01514 Mdot
.32828 .01501 Mdot
.32831 .01538 Mdot
.32833 .01521 Mdot
.32836 .01581 Mdot
.32839 .01534 Mdot
.32841 .01485 Mdot
.32844 .01593 Mdot
.32846 .01551 Mdot
.32849 .01594 Mdot
.32852 .01547 Mdot
.32854 .01552 Mdot
.32857 .01529 Mdot
.32859 .01624 Mdot
.32862 .01531 Mdot
.32864 .01545 Mdot
.32867 .01525 Mdot
.3287 .01555 Mdot
.32872 .01506 Mdot
.32875 .01564 Mdot
.32877 .01539 Mdot
.3288 .0161 Mdot
.32883 .01559 Mdot
.32885 .01572 Mdot
.32888 .01581 Mdot
.3289 .01595 Mdot
.32893 .01528 Mdot
.32895 .01507 Mdot
.32898 .01515 Mdot
.32901 .01596 Mdot
.32903 .01651 Mdot
.32906 .01568 Mdot
.32908 .01581 Mdot
.32911 .01506 Mdot
.32914 .01563 Mdot
.32916 .01592 Mdot
.32919 .01566 Mdot
.32921 .01543 Mdot
.32924 .01555 Mdot
.32926 .01537 Mdot
.32929 .01549 Mdot
.32932 .01565 Mdot
.32934 .01571 Mdot
.32937 .01525 Mdot
.32939 .01584 Mdot
.32942 .01513 Mdot
.32945 .0155 Mdot
.32947 .01478 Mdot
.3295 .01495 Mdot
.32952 .01565 Mdot
.32955 .01651 Mdot
.32957 .0157 Mdot
.3296 .01605 Mdot
.32963 .01558 Mdot
.32965 .01623 Mdot
.32968 .0154 Mdot
.3297 .0158 Mdot
.32973 .01695 Mdot
.32976 .01587 Mdot
.32978 .01602 Mdot
.32981 .01553 Mdot
.32983 .0158 Mdot
.32986 .01545 Mdot
.32988 .0168 Mdot
.32991 .01584 Mdot
.32994 .01594 Mdot
.32996 .01575 Mdot
.32999 .01521 Mdot
.33001 .01613 Mdot
.33004 .01576 Mdot
.33007 .01539 Mdot
.33009 .01487 Mdot
.33012 .01636 Mdot
.33014 .01529 Mdot
.33017 .01531 Mdot
.33019 .01535 Mdot
.33022 .01547 Mdot
.33025 .01528 Mdot
.33027 .01553 Mdot
.3303 .01603 Mdot
.33032 .01528 Mdot
.33035 .01496 Mdot
.33038 .01563 Mdot
.3304 .01532 Mdot
.33043 .01599 Mdot
.33045 .01601 Mdot
.33048 .01569 Mdot
.3305 .01554 Mdot
.33053 .01529 Mdot
.33056 .01614 Mdot
.33058 .01518 Mdot
.33061 .01506 Mdot
.33063 .01488 Mdot
.33066 .01544 Mdot
.33069 .01591 Mdot
.33071 .01552 Mdot
.33074 .01498 Mdot
.33076 .01688 Mdot
.33079 .01623 Mdot
.33081 .01539 Mdot
.33084 .01623 Mdot
.33087 .01519 Mdot
.33089 .01638 Mdot
.33092 .0162 Mdot
.33094 .01504 Mdot
.33097 .0155 Mdot
.331 .01547 Mdot
.33102 .01668 Mdot
.33105 .0152 Mdot
.33107 .01561 Mdot
.3311 .01581 Mdot
.33113 .01534 Mdot
.33115 .01588 Mdot
.33118 .01554 Mdot
.3312 .01647 Mdot
.33123 .01486 Mdot
.33125 .01566 Mdot
.33128 .01592 Mdot
.33131 .01565 Mdot
.33133 .01652 Mdot
.33136 .0155 Mdot
.33138 .0149 Mdot
.33141 .01557 Mdot
.33144 .01591 Mdot
.33146 .01525 Mdot
.33149 .01566 Mdot
.33151 .01494 Mdot
.33154 .01581 Mdot
.33156 .01548 Mdot
.33159 .01611 Mdot
.33162 .01652 Mdot
.33164 .01534 Mdot
.33167 .01592 Mdot
.33169 .01593 Mdot
.33172 .01493 Mdot
.33175 .01529 Mdot
.33177 .01593 Mdot
.3318 .01665 Mdot
.33182 .01545 Mdot
.33185 .01569 Mdot
.33187 .01631 Mdot
.3319 .01576 Mdot
.33193 .01533 Mdot
.33195 .0153 Mdot
.33198 .01536 Mdot
.332 .01536 Mdot
.33203 .01561 Mdot
.33206 .01518 Mdot
.33208 .0154 Mdot
.33211 .0151 Mdot
.33213 .01563 Mdot
.33216 .01554 Mdot
.33218 .01508 Mdot
.33221 .01527 Mdot
.33224 .01591 Mdot
.33226 .01506 Mdot
.33229 .01516 Mdot
.33231 .01567 Mdot
.33234 .016 Mdot
.33237 .01611 Mdot
.33239 .01545 Mdot
.33242 .01566 Mdot
.33244 .01541 Mdot
.33247 .0163 Mdot
.33249 .01546 Mdot
.33252 .01556 Mdot
.33255 .01603 Mdot
.33257 .0157 Mdot
.3326 .01562 Mdot
.33262 .01514 Mdot
.33265 .01568 Mdot
.33268 .01621 Mdot
.3327 .016 Mdot
.33273 .01635 Mdot
.33275 .01566 Mdot
.33278 .01523 Mdot
.3328 .01545 Mdot
.33283 .01604 Mdot
.33286 .0156 Mdot
.33288 .01554 Mdot
.33291 .0154 Mdot
.33293 .01529 Mdot
.33296 .0156 Mdot
.33299 .01554 Mdot
.33301 .01602 Mdot
.33304 .01527 Mdot
.33306 .01595 Mdot
.33309 .01541 Mdot
.33311 .01634 Mdot
.33314 .01684 Mdot
.33317 .01577 Mdot
.33319 .01511 Mdot
.33322 .01506 Mdot
.33324 .0163 Mdot
.33327 .01534 Mdot
.3333 .01545 Mdot
.33332 .01671 Mdot
.33335 .01595 Mdot
.33337 .01507 Mdot
.3334 .01576 Mdot
.33342 .01642 Mdot
.33345 .01616 Mdot
.33348 .01517 Mdot
.3335 .01695 Mdot
.33353 .01584 Mdot
.33355 .01619 Mdot
.33358 .01519 Mdot
.33361 .01529 Mdot
.33363 .01543 Mdot
.33366 .01698 Mdot
.33368 .01534 Mdot
.33371 .01485 Mdot
.33373 .01481 Mdot
.33376 .01566 Mdot
.33379 .01527 Mdot
.33381 .01638 Mdot
.33384 .01583 Mdot
.33386 .01694 Mdot
.33389 .01494 Mdot
.33392 .01655 Mdot
.33394 .01679 Mdot
.33397 .01587 Mdot
.33399 .01614 Mdot
.33402 .01528 Mdot
.33404 .01523 Mdot
.33407 .01661 Mdot
.3341 .01501 Mdot
.33412 .01575 Mdot
.33415 .01577 Mdot
.33417 .01548 Mdot
.3342 .01555 Mdot
.33423 .01523 Mdot
.33425 .01598 Mdot
.33428 .01658 Mdot
.3343 .01556 Mdot
.33433 .01618 Mdot
.33435 .01545 Mdot
.33438 .01482 Mdot
.33441 .01538 Mdot
.33443 .01568 Mdot
.33446 .01502 Mdot
.33448 .01524 Mdot
.33451 .01523 Mdot
.33454 .01503 Mdot
.33456 .01594 Mdot
.33459 .01529 Mdot
.33461 .01568 Mdot
.33464 .01545 Mdot
.33466 .01692 Mdot
.33469 .01496 Mdot
.33472 .01505 Mdot
.33474 .0157 Mdot
.33477 .01554 Mdot
.33479 .01594 Mdot
.33482 .01614 Mdot
.33485 .01556 Mdot
.33487 .0149 Mdot
.3349 .01574 Mdot
.33492 .01564 Mdot
.33495 .01574 Mdot
.33497 .01579 Mdot
.335 .01505 Mdot
.33503 .01555 Mdot
.33505 .01578 Mdot
.33508 .01627 Mdot
.3351 .01528 Mdot
.33513 .01624 Mdot
.33516 .01548 Mdot
.33518 .01608 Mdot
.33521 .01608 Mdot
.33523 .01499 Mdot
.33526 .0162 Mdot
.33528 .01566 Mdot
.33531 .01535 Mdot
.33534 .01517 Mdot
.33536 .01577 Mdot
.33539 .01585 Mdot
.33541 .01587 Mdot
.33544 .01652 Mdot
.33547 .01491 Mdot
.33549 .01512 Mdot
.33552 .01546 Mdot
.33554 .01598 Mdot
.33557 .01527 Mdot
.33559 .01614 Mdot
.33562 .01592 Mdot
.33565 .01566 Mdot
.33567 .01518 Mdot
.3357 .01546 Mdot
.33572 .01627 Mdot
.33575 .01576 Mdot
.33578 .01603 Mdot
.3358 .01542 Mdot
.33583 .01522 Mdot
.33585 .01585 Mdot
.33588 .01556 Mdot
.3359 .01592 Mdot
.33593 .01536 Mdot
.33596 .01521 Mdot
.33598 .01609 Mdot
.33601 .01636 Mdot
.33603 .01526 Mdot
.33606 .01598 Mdot
.33609 .01535 Mdot
.33611 .01545 Mdot
.33614 .01582 Mdot
.33616 .01519 Mdot
.33619 .01568 Mdot
.33621 .01586 Mdot
.33624 .01653 Mdot
.33627 .0155 Mdot
.33629 .01506 Mdot
.33632 .01629 Mdot
.33634 .01487 Mdot
.33637 .0151 Mdot
.3364 .01625 Mdot
.33642 .01571 Mdot
.33645 .01515 Mdot
.33647 .01667 Mdot
.3365 .0151 Mdot
.33652 .01625 Mdot
.33655 .0158 Mdot
.33658 .01564 Mdot
.3366 .01592 Mdot
.33663 .01557 Mdot
.33665 .01584 Mdot
.33668 .01548 Mdot
.33671 .01692 Mdot
.33673 .01554 Mdot
.33676 .01572 Mdot
.33678 .0153 Mdot
.33681 .01585 Mdot
.33683 .01611 Mdot
.33686 .0152 Mdot
.33689 .01562 Mdot
.33691 .01505 Mdot
.33694 .0153 Mdot
.33696 .01669 Mdot
.33699 .0154 Mdot
.33702 .01539 Mdot
.33704 .01565 Mdot
.33707 .01662 Mdot
.33709 .01537 Mdot
.33712 .01556 Mdot
.33714 .01554 Mdot
.33717 .01598 Mdot
.3372 .01547 Mdot
.33722 .01569 Mdot
.33725 .01566 Mdot
.33727 .01554 Mdot
.3373 .01552 Mdot
.33733 .0156 Mdot
.33735 .01535 Mdot
.33738 .01517 Mdot
.3374 .01561 Mdot
.33743 .0153 Mdot
.33745 .01478 Mdot
.33748 .01556 Mdot
.33751 .01681 Mdot
.33753 .01626 Mdot
.33756 .01587 Mdot
.33758 .01529 Mdot
.33761 .0167 Mdot
.33764 .01497 Mdot
.33766 .01591 Mdot
.33769 .01497 Mdot
.33771 .01519 Mdot
.33774 .01504 Mdot
.33776 .01572 Mdot
.33779 .01526 Mdot
.33782 .01496 Mdot
.33784 .01508 Mdot
.33787 .01512 Mdot
.33789 .01538 Mdot
.33792 .01681 Mdot
.33795 .01639 Mdot
.33797 .01519 Mdot
.338 .01542 Mdot
.33802 .01561 Mdot
.33805 .01502 Mdot
.33807 .01574 Mdot
.3381 .01588 Mdot
.33813 .01567 Mdot
.33815 .01583 Mdot
.33818 .01592 Mdot
.3382 .01527 Mdot
.33823 .01531 Mdot
.33826 .01557 Mdot
.33828 .01543 Mdot
.33831 .01618 Mdot
.33833 .01647 Mdot
.33836 .01556 Mdot
.33838 .01568 Mdot
.33841 .01527 Mdot
.33844 .01563 Mdot
.33846 .01675 Mdot
.33849 .01537 Mdot
.33851 .01551 Mdot
.33854 .01651 Mdot
.33857 .01472 Mdot
.33859 .01656 Mdot
.33862 .01534 Mdot
.33864 .01625 Mdot
.33867 .01582 Mdot
.33869 .01559 Mdot
.33872 .01545 Mdot
.33875 .01559 Mdot
.33877 .01475 Mdot
.3388 .01602 Mdot
.33882 .01596 Mdot
.33885 .01575 Mdot
.33888 .01553 Mdot
.3389 .01537 Mdot
.33893 .01576 Mdot
.33895 .01614 Mdot
.33898 .01546 Mdot
.339 .01553 Mdot
.33903 .01579 Mdot
.33906 .01607 Mdot
.33908 .01513 Mdot
.33911 .01613 Mdot
.33913 .01516 Mdot
.33916 .01615 Mdot
.33919 .01533 Mdot
.33921 .01572 Mdot
.33924 .01575 Mdot
.33926 .01741 Mdot
.33929 .01538 Mdot
.33931 .01552 Mdot
.33934 .01591 Mdot
.33937 .01584 Mdot
.33939 .01545 Mdot
.33942 .01572 Mdot
.33944 .01594 Mdot
.33947 .01477 Mdot
.3395 .01519 Mdot
.33952 .01537 Mdot
.33955 .01647 Mdot
.33957 .01615 Mdot
.3396 .01587 Mdot
.33962 .01661 Mdot
.33965 .01584 Mdot
.33968 .01601 Mdot
.3397 .01602 Mdot
.33973 .0158 Mdot
.33975 .01542 Mdot
.33978 .01627 Mdot
.33981 .01604 Mdot
.33983 .01606 Mdot
.33986 .01492 Mdot
.33988 .01483 Mdot
.33991 .01483 Mdot
.33993 .01565 Mdot
.33996 .01492 Mdot
.33999 .01565 Mdot
.34001 .01515 Mdot
.34004 .01672 Mdot
.34006 .01682 Mdot
.34009 .01507 Mdot
.34012 .01518 Mdot
.34014 .01618 Mdot
.34017 .01531 Mdot
.34019 .01559 Mdot
.34022 .01496 Mdot
.34025 .01612 Mdot
.34027 .01547 Mdot
.3403 .01494 Mdot
.34032 .01552 Mdot
.34035 .01636 Mdot
.34037 .01542 Mdot
.3404 .01505 Mdot
.34043 .01617 Mdot
.34045 .01599 Mdot
.34048 .01562 Mdot
.3405 .01496 Mdot
.34053 .01637 Mdot
.34056 .01572 Mdot
.34058 .01626 Mdot
.34061 .01525 Mdot
.34063 .01569 Mdot
.34066 .01528 Mdot
.34068 .01664 Mdot
.34071 .01535 Mdot
.34074 .01515 Mdot
.34076 .01686 Mdot
.34079 .01597 Mdot
.34081 .01608 Mdot
.34084 .0161 Mdot
.34087 .01528 Mdot
.34089 .01637 Mdot
.34092 .01575 Mdot
.34094 .01546 Mdot
.34097 .01613 Mdot
.34099 .01614 Mdot
.34102 .01521 Mdot
.34105 .01504 Mdot
.34107 .01605 Mdot
.3411 .0155 Mdot
.34112 .01586 Mdot
.34115 .01525 Mdot
.34118 .01568 Mdot
.3412 .0156 Mdot
.34123 .01696 Mdot
.34125 .01554 Mdot
.34128 .015 Mdot
.3413 .01566 Mdot
.34133 .0153 Mdot
.34136 .01648 Mdot
.34138 .01619 Mdot
.34141 .01537 Mdot
.34143 .01599 Mdot
.34146 .0152 Mdot
.34149 .01579 Mdot
.34151 .01603 Mdot
.34154 .01604 Mdot
.34156 .0151 Mdot
.34159 .01575 Mdot
.34161 .01502 Mdot
.34164 .01538 Mdot
.34167 .01528 Mdot
.34169 .01619 Mdot
.34172 .01555 Mdot
.34174 .01521 Mdot
.34177 .01722 Mdot
.3418 .01558 Mdot
.34182 .01533 Mdot
.34185 .01535 Mdot
.34187 .01564 Mdot
.3419 .01606 Mdot
.34192 .01559 Mdot
.34195 .01505 Mdot
.34198 .01501 Mdot
.342 .01637 Mdot
.34203 .01536 Mdot
.34205 .01524 Mdot
.34208 .01548 Mdot
.34211 .01539 Mdot
.34213 .01671 Mdot
.34216 .01598 Mdot
.34218 .01596 Mdot
.34221 .01509 Mdot
.34223 .016 Mdot
.34226 .01502 Mdot
.34229 .01672 Mdot
.34231 .01574 Mdot
.34234 .01537 Mdot
.34236 .01564 Mdot
.34239 .01528 Mdot
.34242 .01529 Mdot
.34244 .01555 Mdot
.34247 .01576 Mdot
.34249 .0157 Mdot
.34252 .01572 Mdot
.34254 .0157 Mdot
.34257 .01515 Mdot
.3426 .01496 Mdot
.34262 .01675 Mdot
.34265 .01586 Mdot
.34267 .01657 Mdot
.3427 .01634 Mdot
.34273 .0156 Mdot
.34275 .01586 Mdot
.34278 .01654 Mdot
.3428 .01588 Mdot
.34283 .01591 Mdot
.34285 .01623 Mdot
.34288 .01529 Mdot
.34291 .01571 Mdot
.34293 .0149 Mdot
.34296 .01739 Mdot
.34298 .01541 Mdot
.34301 .0166 Mdot
.34304 .01717 Mdot
.34306 .01702 Mdot
.34309 .01582 Mdot
.34311 .01559 Mdot
.34314 .0163 Mdot
.34316 .0164 Mdot
.34319 .01612 Mdot
.34322 .01568 Mdot
.34324 .01599 Mdot
.34327 .0154 Mdot
.34329 .01539 Mdot
.34332 .01575 Mdot
.34335 .01571 Mdot
.34337 .0166 Mdot
.3434 .01557 Mdot
.34342 .01511 Mdot
.34345 .01533 Mdot
.34347 .01607 Mdot
.3435 .01601 Mdot
.34353 .01547 Mdot
.34355 .01622 Mdot
.34358 .0165 Mdot
.3436 .01597 Mdot
.34363 .01638 Mdot
.34366 .01505 Mdot
.34368 .01487 Mdot
.34371 .01665 Mdot
.34373 .01578 Mdot
.34376 .01571 Mdot
.34378 .01557 Mdot
.34381 .01572 Mdot
.34384 .01563 Mdot
.34386 .01644 Mdot
.34389 .01597 Mdot
.34391 .01564 Mdot
.34394 .01512 Mdot
.34397 .0161 Mdot
.34399 .01637 Mdot
.34402 .01756 Mdot
.34404 .01629 Mdot
.34407 .01512 Mdot
.34409 .01502 Mdot
.34412 .01532 Mdot
.34415 .01535 Mdot
.34417 .01561 Mdot
.3442 .01635 Mdot
.34422 .01488 Mdot
.34425 .01519 Mdot
.34428 .01515 Mdot
.3443 .01649 Mdot
.34433 .01507 Mdot
.34435 .01632 Mdot
.34438 .01524 Mdot
.3444 .01575 Mdot
.34443 .01549 Mdot
.34446 .01615 Mdot
.34448 .01661 Mdot
.34451 .0153 Mdot
.34453 .01484 Mdot
.34456 .01512 Mdot
.34459 .01665 Mdot
.34461 .01546 Mdot
.34464 .01547 Mdot
.34466 .01557 Mdot
.34469 .01571 Mdot
.34471 .01586 Mdot
.34474 .01494 Mdot
.34477 .01595 Mdot
.34479 .01604 Mdot
.34482 .0156 Mdot
.34484 .01555 Mdot
.34487 .01568 Mdot
.3449 .01535 Mdot
.34492 .01504 Mdot
.34495 .01489 Mdot
.34497 .01497 Mdot
.345 .01499 Mdot
.34502 .01557 Mdot
.34505 .01582 Mdot
.34508 .01543 Mdot
.3451 .01548 Mdot
.34513 .01535 Mdot
.34515 .01532 Mdot
.34518 .01613 Mdot
.34521 .01542 Mdot
.34523 .0157 Mdot
.34526 .01539 Mdot
.34528 .01672 Mdot
.34531 .01559 Mdot
.34533 .01504 Mdot
.34536 .01564 Mdot
.34539 .01603 Mdot
.34541 .01513 Mdot
.34544 .01497 Mdot
.34546 .01654 Mdot
.34549 .01503 Mdot
.34552 .01511 Mdot
.34554 .01571 Mdot
.34557 .01536 Mdot
.34559 .01662 Mdot
.34562 .01627 Mdot
.34564 .01497 Mdot
.34567 .01698 Mdot
.3457 .01486 Mdot
.34572 .0163 Mdot
.34575 .01546 Mdot
.34577 .01594 Mdot
.3458 .01481 Mdot
.34583 .01523 Mdot
.34585 .01531 Mdot
.34588 .01588 Mdot
.3459 .01623 Mdot
.34593 .01629 Mdot
.34595 .01539 Mdot
.34598 .01529 Mdot
.34601 .01598 Mdot
.34603 .01516 Mdot
.34606 .0154 Mdot
.34608 .01506 Mdot
.34611 .01609 Mdot
.34614 .01572 Mdot
.34616 .01581 Mdot
.34619 .01496 Mdot
.34621 .01619 Mdot
.34624 .01554 Mdot
.34626 .01641 Mdot
.34629 .01576 Mdot
.34632 .01494 Mdot
.34634 .01569 Mdot
.34637 .01552 Mdot
.34639 .01572 Mdot
.34642 .0167 Mdot
.34645 .01652 Mdot
.34647 .01537 Mdot
.3465 .01575 Mdot
.34652 .0156 Mdot
.34655 .01508 Mdot
.34657 .01567 Mdot
.3466 .01493 Mdot
.34663 .01523 Mdot
.34665 .01543 Mdot
.34668 .01521 Mdot
.3467 .01617 Mdot
.34673 .01553 Mdot
.34676 .01562 Mdot
.34678 .01592 Mdot
.34681 .01578 Mdot
.34683 .01617 Mdot
.34686 .01629 Mdot
.34688 .01513 Mdot
.34691 .01498 Mdot
.34694 .01606 Mdot
.34696 .01547 Mdot
.34699 .01552 Mdot
.34701 .01513 Mdot
.34704 .01568 Mdot
.34707 .01589 Mdot
.34709 .01566 Mdot
.34712 .01625 Mdot
.34714 .01731 Mdot
.34717 .01531 Mdot
.34719 .01567 Mdot
.34722 .01524 Mdot
.34725 .01479 Mdot
.34727 .01492 Mdot
.3473 .01661 Mdot
.34732 .01563 Mdot
.34735 .01527 Mdot
.34738 .0156 Mdot
.3474 .01539 Mdot
.34743 .01586 Mdot
.34745 .01627 Mdot
.34748 .0155 Mdot
.3475 .01535 Mdot
.34753 .01559 Mdot
.34756 .01592 Mdot
.34758 .01634 Mdot
.34761 .015 Mdot
.34763 .01516 Mdot
.34766 .0149 Mdot
.34769 .01604 Mdot
.34771 .01568 Mdot
.34774 .01579 Mdot
.34776 .01671 Mdot
.34779 .01654 Mdot
.34781 .0155 Mdot
.34784 .01617 Mdot
.34787 .01522 Mdot
.34789 .01548 Mdot
.34792 .0155 Mdot
.34794 .0156 Mdot
.34797 .01516 Mdot
.348 .01552 Mdot
.34802 .01595 Mdot
.34805 .01547 Mdot
.34807 .01519 Mdot
.3481 .01609 Mdot
.34812 .01604 Mdot
.34815 .01574 Mdot
.34818 .01662 Mdot
.3482 .01507 Mdot
.34823 .01556 Mdot
.34825 .01571 Mdot
.34828 .01576 Mdot
.34831 .01578 Mdot
.34833 .01509 Mdot
.34836 .01529 Mdot
.34838 .01524 Mdot
.34841 .01528 Mdot
.34843 .01494 Mdot
.34846 .0153 Mdot
.34849 .01538 Mdot
.34851 .01519 Mdot
.34854 .01541 Mdot
.34856 .01621 Mdot
.34859 .01646 Mdot
.34862 .01507 Mdot
.34864 .01524 Mdot
.34867 .01601 Mdot
.34869 .01586 Mdot
.34872 .01605 Mdot
.34874 .01531 Mdot
.34877 .01682 Mdot
.3488 .01571 Mdot
.34882 .01511 Mdot
.34885 .01557 Mdot
.34887 .01576 Mdot
.3489 .01548 Mdot
.34893 .01558 Mdot
.34895 .0154 Mdot
.34898 .01627 Mdot
.349 .01563 Mdot
.34903 .01543 Mdot
.34905 .01549 Mdot
.34908 .01506 Mdot
.34911 .01597 Mdot
.34913 .01664 Mdot
.34916 .01631 Mdot
.34918 .01615 Mdot
.34921 .0151 Mdot
.34924 .01549 Mdot
.34926 .0152 Mdot
.34929 .01556 Mdot
.34931 .01601 Mdot
.34934 .01615 Mdot
.34937 .01519 Mdot
.34939 .01537 Mdot
.34942 .01586 Mdot
.34944 .01564 Mdot
.34947 .0157 Mdot
.34949 .01638 Mdot
.34952 .01478 Mdot
.34955 .0154 Mdot
.34957 .01569 Mdot
.3496 .01541 Mdot
.34962 .01556 Mdot
.34965 .01584 Mdot
.34968 .01641 Mdot
.3497 .01586 Mdot
.34973 .01493 Mdot
.34975 .01561 Mdot
.34978 .01623 Mdot
.3498 .01624 Mdot
.34983 .01619 Mdot
.34986 .01533 Mdot
.34988 .01527 Mdot
.34991 .01529 Mdot
.34993 .01698 Mdot
.34996 .01612 Mdot
.34999 .0158 Mdot
.35001 .01514 Mdot
.35004 .01664 Mdot
.35006 .0167 Mdot
.35009 .01524 Mdot
.35011 .01598 Mdot
.35014 .01668 Mdot
.35017 .01564 Mdot
.35019 .01527 Mdot
.35022 .01617 Mdot
.35024 .01551 Mdot
.35027 .01537 Mdot
.3503 .01537 Mdot
.35032 .01522 Mdot
.35035 .01627 Mdot
.35037 .01578 Mdot
.3504 .01571 Mdot
.35042 .01518 Mdot
.35045 .01576 Mdot
.35048 .01542 Mdot
.3505 .01531 Mdot
.35053 .01519 Mdot
.35055 .01542 Mdot
.35058 .01528 Mdot
.35061 .01504 Mdot
.35063 .01567 Mdot
.35066 .01521 Mdot
.35068 .01681 Mdot
.35071 .01607 Mdot
.35073 .01548 Mdot
.35076 .01576 Mdot
.35079 .01576 Mdot
.35081 .01551 Mdot
.35084 .01588 Mdot
.35086 .01538 Mdot
.35089 .01668 Mdot
.35092 .01678 Mdot
.35094 .01542 Mdot
.35097 .01495 Mdot
.35099 .01677 Mdot
.35102 .01478 Mdot
.35104 .01591 Mdot
.35107 .01648 Mdot
.3511 .01688 Mdot
.35112 .01518 Mdot
.35115 .01565 Mdot
.35117 .01582 Mdot
.3512 .01503 Mdot
.35123 .01581 Mdot
.35125 .01611 Mdot
.35128 .01493 Mdot
.3513 .01521 Mdot
.35133 .01571 Mdot
.35135 .01578 Mdot
.35138 .01492 Mdot
.35141 .01485 Mdot
.35143 .01627 Mdot
.35146 .01536 Mdot
.35148 .01598 Mdot
.35151 .01631 Mdot
.35154 .0159 Mdot
.35156 .01591 Mdot
.35159 .01536 Mdot
.35161 .01596 Mdot
.35164 .0158 Mdot
.35166 .01555 Mdot
.35169 .01583 Mdot
.35172 .01581 Mdot
.35174 .01588 Mdot
.35177 .01592 Mdot
.35179 .015 Mdot
.35182 .01566 Mdot
.35185 .01541 Mdot
.35187 .01488 Mdot
.3519 .01656 Mdot
.35192 .01494 Mdot
.35195 .01652 Mdot
.35197 .01503 Mdot
.352 .0151 Mdot
.35203 .01554 Mdot
.35205 .01546 Mdot
.35208 .01524 Mdot
.3521 .0159 Mdot
.35213 .01615 Mdot
.35216 .01578 Mdot
.35218 .01536 Mdot
.35221 .01501 Mdot
.35223 .0148 Mdot
.35226 .01578 Mdot
.35228 .01617 Mdot
.35231 .01485 Mdot
.35234 .01601 Mdot
.35236 .01521 Mdot
.35239 .01709 Mdot
.35241 .01547 Mdot
.35244 .01567 Mdot
.35247 .01547 Mdot
.35249 .01511 Mdot
.35252 .01539 Mdot
.35254 .0155 Mdot
.35257 .01545 Mdot
.35259 .01531 Mdot
.35262 .01594 Mdot
.35265 .01583 Mdot
.35267 .01531 Mdot
.3527 .01497 Mdot
.35272 .01616 Mdot
.35275 .01582 Mdot
.35278 .01504 Mdot
.3528 .01537 Mdot
.35283 .01535 Mdot
.35285 .01633 Mdot
.35288 .01638 Mdot
.3529 .01543 Mdot
.35293 .01503 Mdot
.35296 .016 Mdot
.35298 .01657 Mdot
.35301 .01535 Mdot
.35303 .0156 Mdot
.35306 .01536 Mdot
.35309 .01509 Mdot
.35311 .01552 Mdot
.35314 .01548 Mdot
.35316 .0161 Mdot
.35319 .01603 Mdot
.35321 .01655 Mdot
.35324 .01629 Mdot
.35327 .01527 Mdot
.35329 .01546 Mdot
.35332 .01559 Mdot
.35334 .0164 Mdot
.35337 .01556 Mdot
.3534 .01538 Mdot
.35342 .01609 Mdot
.35345 .01617 Mdot
.35347 .01497 Mdot
.3535 .01605 Mdot
.35352 .01584 Mdot
.35355 .01526 Mdot
.35358 .01582 Mdot
.3536 .01526 Mdot
.35363 .01543 Mdot
.35365 .01522 Mdot
.35368 .0155 Mdot
.35371 .01591 Mdot
.35373 .01491 Mdot
.35376 .01598 Mdot
.35378 .01571 Mdot
.35381 .01522 Mdot
.35383 .01588 Mdot
.35386 .01568 Mdot
.35389 .01585 Mdot
.35391 .01588 Mdot
.35394 .01623 Mdot
.35396 .01523 Mdot
.35399 .01508 Mdot
.35402 .01503 Mdot
.35404 .01544 Mdot
.35407 .01594 Mdot
.35409 .01542 Mdot
.35412 .01588 Mdot
.35414 .01706 Mdot
.35417 .01599 Mdot
.3542 .01578 Mdot
.35422 .01497 Mdot
.35425 .0148 Mdot
.35427 .01636 Mdot
.3543 .0156 Mdot
.35433 .01623 Mdot
.35435 .01587 Mdot
.35438 .01514 Mdot
.3544 .01499 Mdot
.35443 .0168 Mdot
.35445 .01517 Mdot
.35448 .01558 Mdot
.35451 .01639 Mdot
.35453 .01481 Mdot
.35456 .01499 Mdot
.35458 .01566 Mdot
.35461 .01533 Mdot
.35464 .01623 Mdot
.35466 .01547 Mdot
.35469 .0158 Mdot
.35471 .01642 Mdot
.35474 .01501 Mdot
.35476 .01496 Mdot
.35479 .01506 Mdot
.35482 .0157 Mdot
.35484 .01512 Mdot
.35487 .01498 Mdot
.35489 .01565 Mdot
.35492 .01588 Mdot
.35495 .01538 Mdot
.35497 .01512 Mdot
.355 .01604 Mdot
.35502 .0149 Mdot
.35505 .01527 Mdot
.35507 .01753 Mdot
.3551 .01544 Mdot
.35513 .0157 Mdot
.35515 .01513 Mdot
.35518 .01541 Mdot
.3552 .01553 Mdot
.35523 .01503 Mdot
.35526 .01537 Mdot
.35528 .01598 Mdot
.35531 .01606 Mdot
.35533 .01548 Mdot
.35536 .0152 Mdot
.35538 .01501 Mdot
.35541 .0157 Mdot
.35544 .01557 Mdot
.35546 .01489 Mdot
.35549 .01535 Mdot
.35551 .0163 Mdot
.35554 .01537 Mdot
.35557 .01527 Mdot
.35559 .01613 Mdot
.35562 .01616 Mdot
.35564 .01584 Mdot
.35567 .01524 Mdot
.35569 .01573 Mdot
.35572 .01577 Mdot
.35575 .0153 Mdot
.35577 .01543 Mdot
.3558 .01601 Mdot
.35582 .01541 Mdot
.35585 .0149 Mdot
.35588 .0164 Mdot
.3559 .01563 Mdot
.35593 .01565 Mdot
.35595 .01624 Mdot
.35598 .01505 Mdot
.356 .01553 Mdot
.35603 .01706 Mdot
.35606 .01539 Mdot
.35608 .01523 Mdot
.35611 .01668 Mdot
.35613 .01495 Mdot
.35616 .01536 Mdot
.35619 .01512 Mdot
.35621 .01568 Mdot
.35624 .01565 Mdot
.35626 .01506 Mdot
.35629 .01578 Mdot
.35631 .01509 Mdot
.35634 .01523 Mdot
.35637 .01503 Mdot
.35639 .01523 Mdot
.35642 .01565 Mdot
.35644 .01656 Mdot
.35647 .01502 Mdot
.3565 .01614 Mdot
.35652 .01566 Mdot
.35655 .01687 Mdot
.35657 .01651 Mdot
.3566 .01601 Mdot
.35662 .01608 Mdot
.35665 .01541 Mdot
.35668 .01541 Mdot
.3567 .01562 Mdot
.35673 .01633 Mdot
.35675 .01495 Mdot
.35678 .01546 Mdot
.35681 .01572 Mdot
.35683 .01632 Mdot
.35686 .01615 Mdot
.35688 .01608 Mdot
.35691 .01606 Mdot
.35693 .01567 Mdot
.35696 .0152 Mdot
.35699 .0157 Mdot
.35701 .01546 Mdot
.35704 .01653 Mdot
.35706 .01582 Mdot
.35709 .0159 Mdot
.35712 .01516 Mdot
.35714 .01489 Mdot
.35717 .01602 Mdot
.35719 .01574 Mdot
.35722 .01601 Mdot
.35724 .01522 Mdot
.35727 .01507 Mdot
.3573 .01529 Mdot
.35732 .01559 Mdot
.35735 .01501 Mdot
.35737 .01557 Mdot
.3574 .01523 Mdot
.35743 .01526 Mdot
.35745 .01478 Mdot
.35748 .01527 Mdot
.3575 .01524 Mdot
.35753 .01556 Mdot
.35755 .0161 Mdot
.35758 .01531 Mdot
.35761 .0153 Mdot
.35763 .0164 Mdot
.35766 .0154 Mdot
.35768 .01495 Mdot
.35771 .01546 Mdot
.35774 .01519 Mdot
.35776 .01523 Mdot
.35779 .01565 Mdot
.35781 .01591 Mdot
.35784 .01632 Mdot
.35786 .01604 Mdot
.35789 .0161 Mdot
.35792 .01656 Mdot
.35794 .01549 Mdot
.35797 .01585 Mdot
.35799 .01585 Mdot
.35802 .01623 Mdot
.35805 .01517 Mdot
.35807 .01578 Mdot
.3581 .01566 Mdot
.35812 .01544 Mdot
.35815 .01565 Mdot
.35817 .01506 Mdot
.3582 .01634 Mdot
.35823 .0162 Mdot
.35825 .01711 Mdot
.35828 .01549 Mdot
.3583 .01549 Mdot
.35833 .01521 Mdot
.35836 .01608 Mdot
.35838 .01585 Mdot
.35841 .0149 Mdot
.35843 .01546 Mdot
.35846 .01537 Mdot
.35849 .01561 Mdot
.35851 .01518 Mdot
.35854 .01572 Mdot
.35856 .01556 Mdot
.35859 .01587 Mdot
.35861 .0151 Mdot
.35864 .01545 Mdot
.35867 .0153 Mdot
.35869 .01525 Mdot
.35872 .01694 Mdot
.35874 .01637 Mdot
.35877 .01565 Mdot
.3588 .01602 Mdot
.35882 .01532 Mdot
.35885 .01573 Mdot
.35887 .01532 Mdot
.3589 .01592 Mdot
.35892 .01571 Mdot
.35895 .01521 Mdot
.35898 .01629 Mdot
.359 .01561 Mdot
.35903 .01534 Mdot
.35905 .01554 Mdot
.35908 .0153 Mdot
.35911 .0151 Mdot
.35913 .0157 Mdot
.35916 .01487 Mdot
.35918 .01588 Mdot
.35921 .01628 Mdot
.35923 .01574 Mdot
.35926 .01585 Mdot
.35929 .01714 Mdot
.35931 .01511 Mdot
.35934 .01557 Mdot
.35936 .01643 Mdot
.35939 .01533 Mdot
.35942 .01516 Mdot
.35944 .01597 Mdot
.35947 .01577 Mdot
.35949 .01652 Mdot
.35952 .01532 Mdot
.35954 .01545 Mdot
.35957 .01631 Mdot
.3596 .01696 Mdot
.35962 .01491 Mdot
.35965 .01581 Mdot
.35967 .01652 Mdot
.3597 .01553 Mdot
.35973 .01535 Mdot
.35975 .0149 Mdot
.35978 .01657 Mdot
.3598 .0157 Mdot
.35983 .01625 Mdot
.35985 .01579 Mdot
.35988 .01637 Mdot
.35991 .01545 Mdot
.35993 .01495 Mdot
.35996 .01532 Mdot
.35998 .0153 Mdot
.36001 .01566 Mdot
.36004 .01555 Mdot
.36006 .01517 Mdot
.36009 .01531 Mdot
.36011 .01571 Mdot
.36014 .01567 Mdot
.36016 .01504 Mdot
.36019 .01626 Mdot
.36022 .01656 Mdot
.36024 .01599 Mdot
.36027 .01689 Mdot
.36029 .01551 Mdot
.36032 .01575 Mdot
.36035 .01654 Mdot
.36037 .01597 Mdot
.3604 .01559 Mdot
.36042 .01524 Mdot
.36045 .01708 Mdot
.36047 .01545 Mdot
.3605 .0154 Mdot
.36053 .01508 Mdot
.36055 .01576 Mdot
.36058 .01509 Mdot
.3606 .01514 Mdot
.36063 .01672 Mdot
.36066 .01527 Mdot
.36068 .01658 Mdot
.36071 .01488 Mdot
.36073 .01611 Mdot
.36076 .01559 Mdot
.36078 .01558 Mdot
.36081 .01528 Mdot
.36084 .01592 Mdot
.36086 .01575 Mdot
.36089 .01521 Mdot
.36091 .01533 Mdot
.36094 .01559 Mdot
.36097 .01565 Mdot
.36099 .01481 Mdot
.36102 .01528 Mdot
.36104 .01508 Mdot
.36107 .01645 Mdot
.36109 .01525 Mdot
.36112 .01626 Mdot
.36115 .01625 Mdot
.36117 .01522 Mdot
.3612 .01591 Mdot
.36122 .01599 Mdot
.36125 .01523 Mdot
.36128 .01549 Mdot
.3613 .01664 Mdot
.36133 .01583 Mdot
.36135 .01604 Mdot
.36138 .01588 Mdot
.3614 .01532 Mdot
.36143 .01551 Mdot
.36146 .01488 Mdot
.36148 .01556 Mdot
.36151 .01527 Mdot
.36153 .01583 Mdot
.36156 .01636 Mdot
.36159 .01592 Mdot
.36161 .01535 Mdot
.36164 .01636 Mdot
.36166 .01624 Mdot
.36169 .01536 Mdot
.36171 .01576 Mdot
.36174 .01558 Mdot
.36177 .01575 Mdot
.36179 .01689 Mdot
.36182 .01578 Mdot
.36184 .01567 Mdot
.36187 .0153 Mdot
.3619 .01588 Mdot
.36192 .01542 Mdot
.36195 .01491 Mdot
.36197 .01568 Mdot
.362 .01566 Mdot
.36202 .01486 Mdot
.36205 .01596 Mdot
.36208 .01606 Mdot
.3621 .01503 Mdot
.36213 .01623 Mdot
.36215 .01542 Mdot
.36218 .01627 Mdot
.36221 .01567 Mdot
.36223 .01523 Mdot
.36226 .01522 Mdot
.36228 .01502 Mdot
.36231 .01581 Mdot
.36233 .01532 Mdot
.36236 .01531 Mdot
.36239 .0162 Mdot
.36241 .01659 Mdot
.36244 .0166 Mdot
.36246 .01532 Mdot
.36249 .01562 Mdot
.36252 .01569 Mdot
.36254 .01513 Mdot
.36257 .01526 Mdot
.36259 .01518 Mdot
.36262 .0157 Mdot
.36264 .01626 Mdot
.36267 .01492 Mdot
.3627 .01555 Mdot
.36272 .01566 Mdot
.36275 .01551 Mdot
.36277 .01526 Mdot
.3628 .01527 Mdot
.36283 .01505 Mdot
.36285 .01522 Mdot
.36288 .0151 Mdot
.3629 .01621 Mdot
.36293 .01511 Mdot
.36295 .01551 Mdot
.36298 .01616 Mdot
.36301 .01584 Mdot
.36303 .01548 Mdot
.36306 .01583 Mdot
.36308 .01514 Mdot
.36311 .0156 Mdot
.36314 .0168 Mdot
.36316 .01523 Mdot
.36319 .0153 Mdot
.36321 .01596 Mdot
.36324 .01512 Mdot
.36326 .01558 Mdot
.36329 .01607 Mdot
.36332 .01518 Mdot
.36334 .01608 Mdot
.36337 .01511 Mdot
.36339 .01637 Mdot
.36342 .01584 Mdot
.36345 .0158 Mdot
.36347 .018 Mdot
.3635 .01673 Mdot
.36352 .01617 Mdot
.36355 .01557 Mdot
.36357 .01574 Mdot
.3636 .01592 Mdot
.36363 .01571 Mdot
.36365 .01503 Mdot
.36368 .01536 Mdot
.3637 .01516 Mdot
.36373 .01529 Mdot
.36376 .01553 Mdot
.36378 .01484 Mdot
.36381 .01571 Mdot
.36383 .01541 Mdot
.36386 .01568 Mdot
.36388 .01627 Mdot
.36391 .01505 Mdot
.36394 .01619 Mdot
.36396 .016 Mdot
.36399 .01598 Mdot
.36401 .01504 Mdot
.36404 .01571 Mdot
.36407 .01592 Mdot
.36409 .01637 Mdot
.36412 .01545 Mdot
.36414 .01546 Mdot
.36417 .01524 Mdot
.36419 .01578 Mdot
.36422 .01542 Mdot
.36425 .01613 Mdot
.36427 .01572 Mdot
.3643 .01515 Mdot
.36432 .01538 Mdot
.36435 .01687 Mdot
.36438 .01509 Mdot
.3644 .01636 Mdot
.36443 .01549 Mdot
.36445 .01499 Mdot
.36448 .01592 Mdot
.3645 .01533 Mdot
.36453 .0154 Mdot
.36456 .01524 Mdot
.36458 .0158 Mdot
.36461 .0156 Mdot
.36463 .01491 Mdot
.36466 .01583 Mdot
.36469 .0161 Mdot
.36471 .01582 Mdot
.36474 .01522 Mdot
.36476 .01529 Mdot
.36479 .01532 Mdot
.36481 .01552 Mdot
.36484 .01625 Mdot
.36487 .01583 Mdot
.36489 .01612 Mdot
.36492 .01614 Mdot
.36494 .01618 Mdot
.36497 .01634 Mdot
.365 .01549 Mdot
.36502 .01559 Mdot
.36505 .01548 Mdot
.36507 .01558 Mdot
.3651 .01562 Mdot
.36512 .01583 Mdot
.36515 .01511 Mdot
.36518 .01513 Mdot
.3652 .01557 Mdot
.36523 .01571 Mdot
.36525 .01611 Mdot
.36528 .01546 Mdot
.36531 .01557 Mdot
.36533 .0161 Mdot
.36536 .01545 Mdot
.36538 .01648 Mdot
.36541 .01672 Mdot
.36543 .01571 Mdot
.36546 .01602 Mdot
.36549 .01576 Mdot
.36551 .01508 Mdot
.36554 .01519 Mdot
.36556 .01597 Mdot
.36559 .01529 Mdot
.36562 .01546 Mdot
.36564 .01627 Mdot
.36567 .01543 Mdot
.36569 .01625 Mdot
.36572 .01541 Mdot
.36574 .01592 Mdot
.36577 .01543 Mdot
.3658 .0157 Mdot
.36582 .01608 Mdot
.36585 .01574 Mdot
.36587 .01543 Mdot
.3659 .01535 Mdot
.36593 .01532 Mdot
.36595 .01579 Mdot
.36598 .01584 Mdot
.366 .01535 Mdot
.36603 .01567 Mdot
.36605 .01513 Mdot
.36608 .01633 Mdot
.36611 .0162 Mdot
.36613 .01501 Mdot
.36616 .01526 Mdot
.36618 .0152 Mdot
.36621 .01592 Mdot
.36624 .01665 Mdot
.36626 .01557 Mdot
.36629 .01532 Mdot
.36631 .01588 Mdot
.36634 .01586 Mdot
.36636 .01582 Mdot
.36639 .01592 Mdot
.36642 .01522 Mdot
.36644 .01559 Mdot
.36647 .01537 Mdot
.36649 .01544 Mdot
.36652 .01497 Mdot
.36655 .01542 Mdot
.36657 .01555 Mdot
.3666 .01498 Mdot
.36662 .01588 Mdot
.36665 .01491 Mdot
.36667 .01497 Mdot
.3667 .01665 Mdot
.36673 .01576 Mdot
.36675 .01568 Mdot
.36678 .01484 Mdot
.3668 .01561 Mdot
.36683 .01538 Mdot
.36686 .01604 Mdot
.36688 .01528 Mdot
.36691 .01496 Mdot
.36693 .01614 Mdot
.36696 .01543 Mdot
.36698 .01624 Mdot
.36701 .01534 Mdot
.36704 .01551 Mdot
.36706 .01607 Mdot
.36709 .01515 Mdot
.36711 .01522 Mdot
.36714 .01588 Mdot
.36717 .01517 Mdot
.36719 .01591 Mdot
.36722 .01489 Mdot
.36724 .01533 Mdot
.36727 .01595 Mdot
.36729 .015 Mdot
.36732 .01583 Mdot
.36735 .01513 Mdot
.36737 .01567 Mdot
.3674 .01575 Mdot
.36742 .01638 Mdot
.36745 .01591 Mdot
.36748 .01621 Mdot
.3675 .01598 Mdot
.36753 .01583 Mdot
.36755 .01585 Mdot
.36758 .01603 Mdot
.36761 .01578 Mdot
.36763 .01687 Mdot
.36766 .01552 Mdot
.36768 .01595 Mdot
.36771 .01582 Mdot
.36773 .01538 Mdot
.36776 .01584 Mdot
.36779 .01563 Mdot
.36781 .01588 Mdot
.36784 .01548 Mdot
.36786 .01535 Mdot
.36789 .01656 Mdot
.36792 .01582 Mdot
.36794 .01482 Mdot
.36797 .01567 Mdot
.36799 .01485 Mdot
.36802 .01582 Mdot
.36804 .0164 Mdot
.36807 .01525 Mdot
.3681 .01599 Mdot
.36812 .01507 Mdot
.36815 .01558 Mdot
.36817 .01606 Mdot
.3682 .01592 Mdot
.36823 .01621 Mdot
.36825 .01652 Mdot
.36828 .01595 Mdot
.3683 .01582 Mdot
.36833 .01545 Mdot
.36835 .01565 Mdot
.36838 .01556 Mdot
.36841 .01529 Mdot
.36843 .01613 Mdot
.36846 .01535 Mdot
.36848 .01599 Mdot
.36851 .01479 Mdot
.36854 .01484 Mdot
.36856 .01548 Mdot
.36859 .01577 Mdot
.36861 .01515 Mdot
.36864 .01584 Mdot
.36866 .01577 Mdot
.36869 .01618 Mdot
.36872 .01546 Mdot
.36874 .01743 Mdot
.36877 .01559 Mdot
.36879 .01533 Mdot
.36882 .01522 Mdot
.36885 .01533 Mdot
.36887 .01646 Mdot
.3689 .0149 Mdot
.36892 .0154 Mdot
.36895 .01603 Mdot
.36897 .01656 Mdot
.369 .01511 Mdot
.36903 .01574 Mdot
.36905 .01603 Mdot
.36908 .01553 Mdot
.3691 .016 Mdot
.36913 .01557 Mdot
.36916 .01548 Mdot
.36918 .01487 Mdot
.36921 .01526 Mdot
.36923 .01524 Mdot
.36926 .01658 Mdot
.36928 .01607 Mdot
.36931 .01616 Mdot
.36934 .0152 Mdot
.36936 .01522 Mdot
.36939 .0152 Mdot
.36941 .01483 Mdot
.36944 .01569 Mdot
.36947 .01531 Mdot
.36949 .01569 Mdot
.36952 .01617 Mdot
.36954 .0153 Mdot
.36957 .01577 Mdot
.36959 .01565 Mdot
.36962 .01565 Mdot
.36965 .01551 Mdot
.36967 .01572 Mdot
.3697 .01622 Mdot
.36972 .01557 Mdot
.36975 .01511 Mdot
.36978 .01567 Mdot
.3698 .01534 Mdot
.36983 .01567 Mdot
.36985 .01627 Mdot
.36988 .01611 Mdot
.3699 .01662 Mdot
.36993 .01543 Mdot
.36996 .01493 Mdot
.36998 .01521 Mdot
.37001 .01681 Mdot
.37003 .01595 Mdot
.37006 .01627 Mdot
.37009 .01595 Mdot
.37011 .0167 Mdot
.37014 .01558 Mdot
.37016 .01567 Mdot
.37019 .01535 Mdot
.37021 .01574 Mdot
.37024 .01609 Mdot
.37027 .01553 Mdot
.37029 .01528 Mdot
.37032 .01601 Mdot
.37034 .01574 Mdot
.37037 .01545 Mdot
.3704 .01511 Mdot
.37042 .01571 Mdot
.37045 .01549 Mdot
.37047 .0158 Mdot
.3705 .01641 Mdot
.37052 .01588 Mdot
.37055 .01613 Mdot
.37058 .01513 Mdot
.3706 .01538 Mdot
.37063 .01622 Mdot
.37065 .01492 Mdot
.37068 .01494 Mdot
.37071 .01525 Mdot
.37073 .01525 Mdot
.37076 .01601 Mdot
.37078 .01518 Mdot
.37081 .01526 Mdot
.37083 .01554 Mdot
.37086 .01588 Mdot
.37089 .01672 Mdot
.37091 .0159 Mdot
.37094 .016 Mdot
.37096 .0154 Mdot
.37099 .01526 Mdot
.37102 .01551 Mdot
.37104 .01614 Mdot
.37107 .01535 Mdot
.37109 .0159 Mdot
.37112 .0158 Mdot
.37114 .01572 Mdot
.37117 .01585 Mdot
.3712 .01577 Mdot
.37122 .01527 Mdot
.37125 .01496 Mdot
.37127 .01481 Mdot
.3713 .01564 Mdot
.37133 .01563 Mdot
.37135 .01522 Mdot
.37138 .01616 Mdot
.3714 .01563 Mdot
.37143 .01651 Mdot
.37145 .01642 Mdot
.37148 .01513 Mdot
.37151 .0162 Mdot
.37153 .01645 Mdot
.37156 .0157 Mdot
.37158 .01516 Mdot
.37161 .01543 Mdot
.37164 .01528 Mdot
.37166 .01639 Mdot
.37169 .01615 Mdot
.37171 .01555 Mdot
.37174 .01607 Mdot
.37176 .01614 Mdot
.37179 .01654 Mdot
.37182 .01558 Mdot
.37184 .01573 Mdot
.37187 .01489 Mdot
.37189 .0161 Mdot
.37192 .01521 Mdot
.37195 .01524 Mdot
.37197 .01673 Mdot
.372 .01636 Mdot
.37202 .01541 Mdot
.37205 .01534 Mdot
.37207 .01496 Mdot
.3721 .01518 Mdot
.37213 .01502 Mdot
.37215 .01546 Mdot
.37218 .01644 Mdot
.3722 .01584 Mdot
.37223 .01542 Mdot
.37226 .01537 Mdot
.37228 .0163 Mdot
.37231 .01613 Mdot
.37233 .01551 Mdot
.37236 .01528 Mdot
.37238 .01564 Mdot
.37241 .01581 Mdot
.37244 .01515 Mdot
.37246 .01595 Mdot
.37249 .01564 Mdot
.37251 .01586 Mdot
.37254 .0151 Mdot
.37257 .01623 Mdot
.37259 .01601 Mdot
.37262 .01709 Mdot
.37264 .01602 Mdot
.37267 .0167 Mdot
.37269 .01493 Mdot
.37272 .01543 Mdot
.37275 .01591 Mdot
.37277 .01557 Mdot
.3728 .01583 Mdot
.37282 .01522 Mdot
.37285 .01534 Mdot
.37288 .0166 Mdot
.3729 .01531 Mdot
.37293 .01645 Mdot
.37295 .01541 Mdot
.37298 .01579 Mdot
.373 .01676 Mdot
.37303 .01551 Mdot
.37306 .01527 Mdot
.37308 .01537 Mdot
.37311 .01654 Mdot
.37313 .01717 Mdot
.37316 .0157 Mdot
.37319 .01578 Mdot
.37321 .01595 Mdot
.37324 .0157 Mdot
.37326 .01542 Mdot
.37329 .01661 Mdot
.37331 .01598 Mdot
.37334 .01582 Mdot
.37337 .01552 Mdot
.37339 .01557 Mdot
.37342 .01621 Mdot
.37344 .01535 Mdot
.37347 .01616 Mdot
.3735 .01479 Mdot
.37352 .01503 Mdot
.37355 .01537 Mdot
.37357 .01536 Mdot
.3736 .01509 Mdot
.37362 .01655 Mdot
.37365 .01551 Mdot
.37368 .01615 Mdot
.3737 .01635 Mdot
.37373 .0161 Mdot
.37375 .01602 Mdot
.37378 .01528 Mdot
.37381 .01605 Mdot
.37383 .0161 Mdot
.37386 .0161 Mdot
.37388 .01549 Mdot
.37391 .01577 Mdot
.37393 .01525 Mdot
.37396 .01594 Mdot
.37399 .01618 Mdot
.37401 .01515 Mdot
.37404 .01599 Mdot
.37406 .01578 Mdot
.37409 .01586 Mdot
.37412 .01627 Mdot
.37414 .01688 Mdot
.37417 .01563 Mdot
.37419 .0155 Mdot
.37422 .01533 Mdot
.37424 .01621 Mdot
.37427 .01503 Mdot
.3743 .01525 Mdot
.37432 .01623 Mdot
.37435 .015 Mdot
.37437 .01654 Mdot
.3744 .0154 Mdot
.37443 .01532 Mdot
.37445 .01609 Mdot
.37448 .01558 Mdot
.3745 .01655 Mdot
.37453 .01583 Mdot
.37455 .01553 Mdot
.37458 .01638 Mdot
.37461 .01505 Mdot
.37463 .01525 Mdot
.37466 .01562 Mdot
.37468 .01558 Mdot
.37471 .01603 Mdot
.37474 .01625 Mdot
.37476 .01548 Mdot
.37479 .01524 Mdot
.37481 .01574 Mdot
.37484 .01524 Mdot
.37486 .0156 Mdot
.37489 .01565 Mdot
.37492 .01566 Mdot
.37494 .01577 Mdot
.37497 .01549 Mdot
.37499 .01547 Mdot
.37502 .01492 Mdot
.37505 .01538 Mdot
.37507 .01614 Mdot
.3751 .01596 Mdot
.37512 .01611 Mdot
.37515 .01606 Mdot
.37517 .01559 Mdot
.3752 .01506 Mdot
.37523 .01507 Mdot
.37525 .01542 Mdot
.37528 .01585 Mdot
.3753 .01544 Mdot
.37533 .01514 Mdot
.37536 .01597 Mdot
.37538 .01534 Mdot
.37541 .01591 Mdot
.37543 .01569 Mdot
.37546 .01563 Mdot
.37548 .0154 Mdot
.37551 .01548 Mdot
.37554 .01594 Mdot
.37556 .01559 Mdot
.37559 .01612 Mdot
.37561 .01556 Mdot
.37564 .01514 Mdot
.37567 .01511 Mdot
.37569 .01513 Mdot
.37572 .0159 Mdot
.37574 .01559 Mdot
.37577 .01614 Mdot
.37579 .01536 Mdot
.37582 .01517 Mdot
.37585 .01617 Mdot
.37587 .01675 Mdot
.3759 .01488 Mdot
.37592 .01482 Mdot
.37595 .01654 Mdot
.37598 .01612 Mdot
.376 .01509 Mdot
.37603 .01517 Mdot
.37605 .01535 Mdot
.37608 .0156 Mdot
.3761 .01576 Mdot
.37613 .01629 Mdot
.37616 .01535 Mdot
.37618 .01483 Mdot
.37621 .01559 Mdot
.37623 .01649 Mdot
.37626 .01581 Mdot
.37629 .01516 Mdot
.37631 .01537 Mdot
.37634 .01502 Mdot
.37636 .01518 Mdot
.37639 .01622 Mdot
.37641 .01608 Mdot
.37644 .01639 Mdot
.37647 .01666 Mdot
.37649 .01546 Mdot
.37652 .01626 Mdot
.37654 .01547 Mdot
.37657 .01548 Mdot
.3766 .01503 Mdot
.37662 .01521 Mdot
.37665 .01571 Mdot
.37667 .01558 Mdot
.3767 .01623 Mdot
.37673 .01745 Mdot
.37675 .01544 Mdot
.37678 .01533 Mdot
.3768 .01484 Mdot
.37683 .01647 Mdot
.37685 .01627 Mdot
.37688 .01562 Mdot
.37691 .01511 Mdot
.37693 .0152 Mdot
.37696 .01535 Mdot
.37698 .01556 Mdot
.37701 .0151 Mdot
.37704 .01671 Mdot
.37706 .01534 Mdot
.37709 .01596 Mdot
.37711 .01547 Mdot
.37714 .0165 Mdot
.37716 .01541 Mdot
.37719 .01741 Mdot
.37722 .01564 Mdot
.37724 .01524 Mdot
.37727 .0166 Mdot
.37729 .0156 Mdot
.37732 .0155 Mdot
.37735 .01549 Mdot
.37737 .01516 Mdot
.3774 .01573 Mdot
.37742 .01538 Mdot
.37745 .01543 Mdot
.37747 .01508 Mdot
.3775 .01576 Mdot
.37753 .01686 Mdot
.37755 .01531 Mdot
.37758 .01557 Mdot
.3776 .01622 Mdot
.37763 .01565 Mdot
.37766 .01524 Mdot
.37768 .01567 Mdot
.37771 .01567 Mdot
.37773 .01494 Mdot
.37776 .01591 Mdot
.37778 .01489 Mdot
.37781 .01528 Mdot
.37784 .01563 Mdot
.37786 .01543 Mdot
.37789 .01531 Mdot
.37791 .01515 Mdot
.37794 .0153 Mdot
.37797 .01597 Mdot
.37799 .01589 Mdot
.37802 .01655 Mdot
.37804 .01607 Mdot
.37807 .01507 Mdot
.37809 .0162 Mdot
.37812 .01513 Mdot
.37815 .01565 Mdot
.37817 .01667 Mdot
.3782 .01651 Mdot
.37822 .01563 Mdot
.37825 .01608 Mdot
.37828 .01482 Mdot
.3783 .01647 Mdot
.37833 .01654 Mdot
.37835 .01712 Mdot
.37838 .01541 Mdot
.3784 .01514 Mdot
.37843 .01524 Mdot
.37846 .01536 Mdot
.37848 .01506 Mdot
.37851 .01575 Mdot
.37853 .01629 Mdot
.37856 .01525 Mdot
.37859 .01587 Mdot
.37861 .01529 Mdot
.37864 .01509 Mdot
.37866 .01536 Mdot
.37869 .01609 Mdot
.37871 .01613 Mdot
.37874 .01515 Mdot
.37877 .01613 Mdot
.37879 .0155 Mdot
.37882 .01542 Mdot
.37884 .01542 Mdot
.37887 .01572 Mdot
.3789 .01504 Mdot
.37892 .01611 Mdot
.37895 .01562 Mdot
.37897 .01525 Mdot
.379 .01536 Mdot
.37902 .01536 Mdot
.37905 .01563 Mdot
.37908 .01516 Mdot
.3791 .01671 Mdot
.37913 .01491 Mdot
.37915 .01558 Mdot
.37918 .01597 Mdot
.37921 .01574 Mdot
.37923 .01647 Mdot
.37926 .01554 Mdot
.37928 .01515 Mdot
.37931 .01561 Mdot
.37933 .01512 Mdot
.37936 .01514 Mdot
.37939 .01581 Mdot
.37941 .0162 Mdot
.37944 .01492 Mdot
.37946 .01563 Mdot
.37949 .01605 Mdot
.37952 .01655 Mdot
.37954 .01633 Mdot
.37957 .01631 Mdot
.37959 .01509 Mdot
.37962 .01689 Mdot
.37964 .01658 Mdot
.37967 .01611 Mdot
.3797 .01507 Mdot
.37972 .01575 Mdot
.37975 .01523 Mdot
.37977 .01501 Mdot
.3798 .01563 Mdot
.37983 .01588 Mdot
.37985 .01579 Mdot
.37988 .01572 Mdot
.3799 .0152 Mdot
.37993 .01629 Mdot
.37995 .01574 Mdot
.37998 .01545 Mdot
.38001 .01574 Mdot
.38003 .01553 Mdot
.38006 .01536 Mdot
.38008 .01553 Mdot
.38011 .01567 Mdot
.38014 .0158 Mdot
.38016 .0154 Mdot
.38019 .01509 Mdot
.38021 .01563 Mdot
.38024 .01528 Mdot
.38026 .01492 Mdot
.38029 .01577 Mdot
.38032 .0152 Mdot
.38034 .0152 Mdot
.38037 .01551 Mdot
.38039 .01529 Mdot
.38042 .01564 Mdot
.38045 .01517 Mdot
.38047 .01612 Mdot
.3805 .0154 Mdot
.38052 .01544 Mdot
.38055 .01582 Mdot
.38057 .01555 Mdot
.3806 .01586 Mdot
.38063 .01555 Mdot
.38065 .01592 Mdot
.38068 .01516 Mdot
.3807 .01599 Mdot
.38073 .01524 Mdot
.38076 .0157 Mdot
.38078 .01506 Mdot
.38081 .01555 Mdot
.38083 .01599 Mdot
.38086 .01548 Mdot
.38088 .01527 Mdot
.38091 .01563 Mdot
.38094 .01524 Mdot
.38096 .01609 Mdot
.38099 .01557 Mdot
.38101 .01579 Mdot
.38104 .01706 Mdot
.38107 .01494 Mdot
.38109 .01498 Mdot
.38112 .01527 Mdot
.38114 .01524 Mdot
.38117 .01536 Mdot
.38119 .01522 Mdot
.38122 .01666 Mdot
.38125 .01504 Mdot
.38127 .0155 Mdot
.3813 .01586 Mdot
.38132 .01554 Mdot
.38135 .01594 Mdot
.38138 .01538 Mdot
.3814 .01605 Mdot
.38143 .01516 Mdot
.38145 .01555 Mdot
.38148 .01517 Mdot
.3815 .01596 Mdot
.38153 .01588 Mdot
.38156 .01663 Mdot
.38158 .01606 Mdot
.38161 .01589 Mdot
.38163 .01572 Mdot
.38166 .016 Mdot
.38169 .01564 Mdot
.38171 .01565 Mdot
.38174 .01587 Mdot
.38176 .01537 Mdot
.38179 .01576 Mdot
.38181 .01589 Mdot
.38184 .01588 Mdot
.38187 .01521 Mdot
.38189 .01529 Mdot
.38192 .01548 Mdot
.38194 .01549 Mdot
.38197 .01498 Mdot
.382 .01614 Mdot
.38202 .01533 Mdot
.38205 .01517 Mdot
.38207 .01543 Mdot
.3821 .01594 Mdot
.38212 .01543 Mdot
.38215 .01483 Mdot
.38218 .01686 Mdot
.3822 .01714 Mdot
.38223 .01514 Mdot
.38225 .0155 Mdot
.38228 .01534 Mdot
.38231 .01566 Mdot
.38233 .0151 Mdot
.38236 .01608 Mdot
.38238 .01528 Mdot
.38241 .01577 Mdot
.38243 .01564 Mdot
.38246 .016 Mdot
.38249 .01679 Mdot
.38251 .01515 Mdot
.38254 .01698 Mdot
.38256 .01523 Mdot
.38259 .01549 Mdot
.38262 .01594 Mdot
.38264 .01551 Mdot
.38267 .01527 Mdot
.38269 .016 Mdot
.38272 .01528 Mdot
.38274 .01555 Mdot
.38277 .01658 Mdot
.3828 .01576 Mdot
.38282 .01523 Mdot
.38285 .01574 Mdot
.38287 .01616 Mdot
.3829 .01605 Mdot
.38293 .01581 Mdot
.38295 .01558 Mdot
.38298 .01554 Mdot
.383 .01518 Mdot
.38303 .01538 Mdot
.38305 .01552 Mdot
.38308 .0151 Mdot
.38311 .01528 Mdot
.38313 .01528 Mdot
.38316 .01598 Mdot
.38318 .01569 Mdot
.38321 .01601 Mdot
.38324 .01513 Mdot
.38326 .01552 Mdot
.38329 .01575 Mdot
.38331 .01576 Mdot
.38334 .01621 Mdot
.38336 .01594 Mdot
.38339 .01622 Mdot
.38342 .01514 Mdot
.38344 .01546 Mdot
.38347 .01525 Mdot
.38349 .01546 Mdot
.38352 .01555 Mdot
.38355 .01517 Mdot
.38357 .01572 Mdot
.3836 .01537 Mdot
.38362 .01553 Mdot
.38365 .01586 Mdot
.38367 .01654 Mdot
.3837 .01516 Mdot
.38373 .01636 Mdot
.38375 .01634 Mdot
.38378 .01616 Mdot
.3838 .0154 Mdot
.38383 .01618 Mdot
.38386 .01618 Mdot
.38388 .01566 Mdot
.38391 .01553 Mdot
.38393 .01556 Mdot
.38396 .01557 Mdot
.38398 .01581 Mdot
.38401 .0154 Mdot
.38404 .01635 Mdot
.38406 .01557 Mdot
.38409 .01707 Mdot
.38411 .01586 Mdot
.38414 .01606 Mdot
.38417 .0156 Mdot
.38419 .01575 Mdot
.38422 .01556 Mdot
.38424 .01558 Mdot
.38427 .01532 Mdot
.38429 .01564 Mdot
.38432 .01595 Mdot
.38435 .01527 Mdot
.38437 .01512 Mdot
.3844 .01547 Mdot
.38442 .01559 Mdot
.38445 .01651 Mdot
.38448 .01648 Mdot
.3845 .0149 Mdot
.38453 .01485 Mdot
.38455 .01579 Mdot
.38458 .01604 Mdot
.3846 .01524 Mdot
.38463 .0157 Mdot
.38466 .016 Mdot
.38468 .01582 Mdot
.38471 .01562 Mdot
.38473 .01486 Mdot
.38476 .01596 Mdot
.38479 .01531 Mdot
.38481 .01561 Mdot
.38484 .01527 Mdot
.38486 .01598 Mdot
.38489 .01525 Mdot
.38491 .01511 Mdot
.38494 .01709 Mdot
.38497 .01508 Mdot
.38499 .01558 Mdot
.38502 .0152 Mdot
.38504 .01536 Mdot
.38507 .01575 Mdot
.3851 .01529 Mdot
.38512 .01559 Mdot
.38515 .01647 Mdot
.38517 .01617 Mdot
.3852 .0162 Mdot
.38522 .01579 Mdot
.38525 .01531 Mdot
.38528 .01498 Mdot
.3853 .01584 Mdot
.38533 .01577 Mdot
.38535 .0167 Mdot
.38538 .01579 Mdot
.38541 .01683 Mdot
.38543 .01519 Mdot
.38546 .01479 Mdot
.38548 .01591 Mdot
.38551 .01496 Mdot
.38553 .01653 Mdot
.38556 .01514 Mdot
.38559 .01568 Mdot
.38561 .016 Mdot
.38564 .01539 Mdot
.38566 .01504 Mdot
.38569 .01553 Mdot
.38572 .01541 Mdot
.38574 .01504 Mdot
.38577 .01664 Mdot
.38579 .01524 Mdot
.38582 .01591 Mdot
.38585 .01529 Mdot
.38587 .01611 Mdot
.3859 .01502 Mdot
.38592 .01537 Mdot
.38595 .01693 Mdot
.38597 .01552 Mdot
.386 .01606 Mdot
.38603 .01546 Mdot
.38605 .01676 Mdot
.38608 .0153 Mdot
.3861 .01671 Mdot
.38613 .01552 Mdot
.38616 .01484 Mdot
.38618 .01586 Mdot
.38621 .01581 Mdot
.38623 .01472 Mdot
.38626 .01663 Mdot
.38628 .01614 Mdot
.38631 .01533 Mdot
.38634 .01564 Mdot
.38636 .01509 Mdot
.38639 .01513 Mdot
.38641 .01491 Mdot
.38644 .01657 Mdot
.38647 .01543 Mdot
.38649 .01541 Mdot
.38652 .01639 Mdot
.38654 .0149 Mdot
.38657 .01537 Mdot
.38659 .01603 Mdot
.38662 .01549 Mdot
.38665 .01698 Mdot
.38667 .01541 Mdot
.3867 .01585 Mdot
.38672 .01561 Mdot
.38675 .01516 Mdot
.38678 .01558 Mdot
.3868 .01503 Mdot
.38683 .01559 Mdot
.38685 .01581 Mdot
.38688 .01505 Mdot
.3869 .0161 Mdot
.38693 .01552 Mdot
.38696 .01597 Mdot
.38698 .01524 Mdot
.38701 .01601 Mdot
.38703 .01558 Mdot
.38706 .0155 Mdot
.38709 .01512 Mdot
.38711 .01505 Mdot
.38714 .01601 Mdot
.38716 .01555 Mdot
.38719 .01529 Mdot
.38721 .01564 Mdot
.38724 .01559 Mdot
.38727 .0151 Mdot
.38729 .0167 Mdot
.38732 .01548 Mdot
.38734 .01482 Mdot
.38737 .01654 Mdot
.3874 .01623 Mdot
.38742 .01625 Mdot
.38745 .01521 Mdot
.38747 .01534 Mdot
.3875 .0164 Mdot
.38752 .01674 Mdot
.38755 .01567 Mdot
.38758 .01492 Mdot
.3876 .01541 Mdot
.38763 .01684 Mdot
.38765 .01778 Mdot
.38768 .01494 Mdot
.38771 .01568 Mdot
.38773 .01617 Mdot
.38776 .01614 Mdot
.38778 .01551 Mdot
.38781 .01563 Mdot
.38783 .01498 Mdot
.38786 .01689 Mdot
.38789 .01609 Mdot
.38791 .01723 Mdot
.38794 .01595 Mdot
.38796 .01647 Mdot
.38799 .01531 Mdot
.38802 .01601 Mdot
.38804 .01524 Mdot
.38807 .01593 Mdot
.38809 .01576 Mdot
.38812 .01682 Mdot
.38814 .01489 Mdot
.38817 .01568 Mdot
.3882 .01536 Mdot
.38822 .01555 Mdot
.38825 .01636 Mdot
.38827 .01582 Mdot
.3883 .01533 Mdot
.38833 .01527 Mdot
.38835 .01593 Mdot
.38838 .01536 Mdot
.3884 .01524 Mdot
.38843 .01646 Mdot
.38845 .01524 Mdot
.38848 .01588 Mdot
.38851 .0159 Mdot
.38853 .01568 Mdot
.38856 .01624 Mdot
.38858 .01556 Mdot
.38861 .01526 Mdot
.38864 .01543 Mdot
.38866 .01593 Mdot
.38869 .01635 Mdot
.38871 .01564 Mdot
.38874 .01512 Mdot
.38876 .01652 Mdot
.38879 .01568 Mdot
.38882 .01557 Mdot
.38884 .01493 Mdot
.38887 .01566 Mdot
.38889 .01644 Mdot
.38892 .01602 Mdot
.38895 .01518 Mdot
.38897 .01503 Mdot
.389 .01513 Mdot
.38902 .01519 Mdot
.38905 .01519 Mdot
.38907 .01591 Mdot
.3891 .01621 Mdot
.38913 .01589 Mdot
.38915 .01482 Mdot
.38918 .01499 Mdot
.3892 .01565 Mdot
.38923 .01587 Mdot
.38926 .01503 Mdot
.38928 .01589 Mdot
.38931 .01578 Mdot
.38933 .01535 Mdot
.38936 .0158 Mdot
.38938 .01574 Mdot
.38941 .01567 Mdot
.38944 .01495 Mdot
.38946 .01576 Mdot
.38949 .01538 Mdot
.38951 .01612 Mdot
.38954 .01579 Mdot
.38957 .01564 Mdot
.38959 .01591 Mdot
.38962 .01652 Mdot
.38964 .01536 Mdot
.38967 .0158 Mdot
.38969 .01528 Mdot
.38972 .01595 Mdot
.38975 .01559 Mdot
.38977 .0168 Mdot
.3898 .01605 Mdot
.38982 .01657 Mdot
.38985 .01699 Mdot
.38988 .01584 Mdot
.3899 .01767 Mdot
.38993 .01573 Mdot
.38995 .01525 Mdot
.38998 .01524 Mdot
.39 .01521 Mdot
.39003 .01546 Mdot
.39006 .01486 Mdot
.39008 .01663 Mdot
.39011 .01562 Mdot
.39013 .01595 Mdot
.39016 .01659 Mdot
.39019 .01511 Mdot
.39021 .01556 Mdot
.39024 .01533 Mdot
.39026 .01513 Mdot
.39029 .0156 Mdot
.39031 .01549 Mdot
.39034 .01655 Mdot
.39037 .01528 Mdot
.39039 .01575 Mdot
.39042 .01508 Mdot
.39044 .01565 Mdot
.39047 .01534 Mdot
.3905 .01549 Mdot
.39052 .01597 Mdot
.39055 .01549 Mdot
.39057 .01567 Mdot
.3906 .0169 Mdot
.39062 .01606 Mdot
.39065 .01511 Mdot
.39068 .01584 Mdot
.3907 .01551 Mdot
.39073 .01561 Mdot
.39075 .01556 Mdot
.39078 .01594 Mdot
.39081 .01597 Mdot
.39083 .01515 Mdot
.39086 .01626 Mdot
.39088 .0167 Mdot
.39091 .01533 Mdot
.39093 .0152 Mdot
.39096 .01541 Mdot
.39099 .01588 Mdot
.39101 .01489 Mdot
.39104 .01635 Mdot
.39106 .01536 Mdot
.39109 .01645 Mdot
.39112 .01569 Mdot
.39114 .01557 Mdot
.39117 .0149 Mdot
.39119 .01631 Mdot
.39122 .01612 Mdot
.39124 .01586 Mdot
.39127 .01496 Mdot
.3913 .01537 Mdot
.39132 .01589 Mdot
.39135 .01573 Mdot
.39137 .01572 Mdot
.3914 .01573 Mdot
.39143 .01541 Mdot
.39145 .01568 Mdot
.39148 .01589 Mdot
.3915 .01569 Mdot
.39153 .01583 Mdot
.39155 .01533 Mdot
.39158 .01539 Mdot
.39161 .01511 Mdot
.39163 .01616 Mdot
.39166 .01723 Mdot
.39168 .01566 Mdot
.39171 .0175 Mdot
.39174 .01719 Mdot
.39176 .01574 Mdot
.39179 .01602 Mdot
.39181 .01524 Mdot
.39184 .01562 Mdot
.39186 .01572 Mdot
.39189 .01544 Mdot
.39192 .01481 Mdot
.39194 .01569 Mdot
.39197 .01638 Mdot
.39199 .01596 Mdot
.39202 .01609 Mdot
.39205 .01599 Mdot
.39207 .01497 Mdot
.3921 .01694 Mdot
.39212 .01627 Mdot
.39215 .01574 Mdot
.39217 .01551 Mdot
.3922 .01501 Mdot
.39223 .01558 Mdot
.39225 .01491 Mdot
.39228 .01492 Mdot
.3923 .01536 Mdot
.39233 .01629 Mdot
.39236 .01535 Mdot
.39238 .01572 Mdot
.39241 .01495 Mdot
.39243 .01556 Mdot
.39246 .01531 Mdot
.39248 .01509 Mdot
.39251 .0161 Mdot
.39254 .01562 Mdot
.39256 .01556 Mdot
.39259 .01543 Mdot
.39261 .01498 Mdot
.39264 .01708 Mdot
.39267 .01651 Mdot
.39269 .01604 Mdot
.39272 .01605 Mdot
.39274 .0154 Mdot
.39277 .01498 Mdot
.39279 .01556 Mdot
.39282 .01642 Mdot
.39285 .01576 Mdot
.39287 .01552 Mdot
.3929 .01579 Mdot
.39292 .01518 Mdot
.39295 .01504 Mdot
.39298 .01548 Mdot
.393 .01505 Mdot
.39303 .01625 Mdot
.39305 .01607 Mdot
.39308 .0159 Mdot
.3931 .01706 Mdot
.39313 .01754 Mdot
.39316 .01568 Mdot
.39318 .01529 Mdot
.39321 .01529 Mdot
.39323 .01581 Mdot
.39326 .01611 Mdot
.39329 .01491 Mdot
.39331 .01589 Mdot
.39334 .01557 Mdot
.39336 .0151 Mdot
.39339 .01548 Mdot
.39341 .01576 Mdot
.39344 .01594 Mdot
.39347 .01525 Mdot
.39349 .01565 Mdot
.39352 .01611 Mdot
.39354 .01573 Mdot
.39357 .01648 Mdot
.3936 .01554 Mdot
.39362 .01607 Mdot
.39365 .01735 Mdot
.39367 .01535 Mdot
.3937 .01579 Mdot
.39372 .01612 Mdot
.39375 .01534 Mdot
.39378 .01507 Mdot
.3938 .01638 Mdot
.39383 .01503 Mdot
.39385 .01641 Mdot
.39388 .01557 Mdot
.39391 .01587 Mdot
.39393 .01541 Mdot
.39396 .01541 Mdot
.39398 .01604 Mdot
.39401 .01617 Mdot
.39403 .01632 Mdot
.39406 .01528 Mdot
.39409 .01536 Mdot
.39411 .01545 Mdot
.39414 .01494 Mdot
.39416 .0163 Mdot
.39419 .01675 Mdot
.39422 .01542 Mdot
.39424 .01633 Mdot
.39427 .01626 Mdot
.39429 .01516 Mdot
.39432 .01712 Mdot
.39434 .01485 Mdot
.39437 .01603 Mdot
.3944 .01666 Mdot
.39442 .01534 Mdot
.39445 .01577 Mdot
.39447 .0151 Mdot
.3945 .01515 Mdot
.39453 .01587 Mdot
.39455 .01652 Mdot
.39458 .01626 Mdot
.3946 .01591 Mdot
.39463 .01721 Mdot
.39465 .01566 Mdot
.39468 .01612 Mdot
.39471 .01586 Mdot
.39473 .0159 Mdot
.39476 .01518 Mdot
.39478 .01648 Mdot
.39481 .01555 Mdot
.39484 .01524 Mdot
.39486 .01605 Mdot
.39489 .01546 Mdot
.39491 .01543 Mdot
.39494 .01545 Mdot
.39497 .01612 Mdot
.39499 .01641 Mdot
.39502 .01498 Mdot
.39504 .01498 Mdot
.39507 .01575 Mdot
.39509 .01594 Mdot
.39512 .01546 Mdot
.39515 .01614 Mdot
.39517 .0161 Mdot
.3952 .01579 Mdot
.39522 .01661 Mdot
.39525 .01569 Mdot
.39528 .01533 Mdot
.3953 .01598 Mdot
.39533 .01527 Mdot
.39535 .01576 Mdot
.39538 .01606 Mdot
.3954 .01488 Mdot
.39543 .01509 Mdot
.39546 .01528 Mdot
.39548 .01554 Mdot
.39551 .01551 Mdot
.39553 .01498 Mdot
.39556 .01617 Mdot
.39559 .0164 Mdot
.39561 .01553 Mdot
.39564 .01715 Mdot
.39566 .0155 Mdot
.39569 .01515 Mdot
.39571 .01579 Mdot
.39574 .01656 Mdot
.39577 .01555 Mdot
.39579 .01612 Mdot
.39582 .01621 Mdot
.39584 .0159 Mdot
.39587 .01509 Mdot
.3959 .01629 Mdot
.39592 .01536 Mdot
.39595 .01512 Mdot
.39597 .01576 Mdot
.396 .01527 Mdot
.39602 .0153 Mdot
.39605 .01526 Mdot
.39608 .01587 Mdot
.3961 .01488 Mdot
.39613 .01586 Mdot
.39615 .01565 Mdot
.39618 .01615 Mdot
.39621 .01548 Mdot
.39623 .0159 Mdot
.39626 .01533 Mdot
.39628 .01514 Mdot
.39631 .01622 Mdot
.39633 .01618 Mdot
.39636 .01566 Mdot
.39639 .0158 Mdot
.39641 .01625 Mdot
.39644 .0165 Mdot
.39646 .01572 Mdot
.39649 .0158 Mdot
.39652 .01583 Mdot
.39654 .01589 Mdot
.39657 .01547 Mdot
.39659 .01532 Mdot
.39662 .01571 Mdot
.39664 .01576 Mdot
.39667 .01511 Mdot
.3967 .01566 Mdot
.39672 .01565 Mdot
.39675 .01595 Mdot
.39677 .0149 Mdot
.3968 .01599 Mdot
.39683 .01627 Mdot
.39685 .01637 Mdot
.39688 .01528 Mdot
.3969 .0154 Mdot
.39693 .01506 Mdot
.39695 .01602 Mdot
.39698 .01703 Mdot
.39701 .0159 Mdot
.39703 .01558 Mdot
.39706 .01559 Mdot
.39708 .01604 Mdot
.39711 .01552 Mdot
.39714 .01557 Mdot
.39716 .01602 Mdot
.39719 .01601 Mdot
.39721 .01651 Mdot
.39724 .01564 Mdot
.39726 .01523 Mdot
.39729 .01604 Mdot
.39732 .01649 Mdot
.39734 .01639 Mdot
.39737 .01576 Mdot
.39739 .01508 Mdot
.39742 .01584 Mdot
.39745 .01664 Mdot
.39747 .01645 Mdot
.3975 .01553 Mdot
.39752 .01549 Mdot
.39755 .01508 Mdot
.39757 .01594 Mdot
.3976 .01623 Mdot
.39763 .01598 Mdot
.39765 .01478 Mdot
.39768 .01521 Mdot
.3977 .01586 Mdot
.39773 .01571 Mdot
.39776 .01585 Mdot
.39778 .01602 Mdot
.39781 .016 Mdot
.39783 .01616 Mdot
.39786 .01657 Mdot
.39788 .0164 Mdot
.39791 .0156 Mdot
.39794 .01563 Mdot
.39796 .01668 Mdot
.39799 .01684 Mdot
.39801 .0158 Mdot
.39804 .01635 Mdot
.39807 .01532 Mdot
.39809 .01751 Mdot
.39812 .01558 Mdot
.39814 .01585 Mdot
.39817 .01554 Mdot
.39819 .01644 Mdot
.39822 .01592 Mdot
.39825 .01544 Mdot
.39827 .01544 Mdot
.3983 .01585 Mdot
.39832 .01624 Mdot
.39835 .01514 Mdot
.39838 .01623 Mdot
.3984 .01592 Mdot
.39843 .01629 Mdot
.39845 .01482 Mdot
.39848 .01583 Mdot
.3985 .01578 Mdot
.39853 .01556 Mdot
.39856 .01672 Mdot
.39858 .01589 Mdot
.39861 .01571 Mdot
.39863 .01698 Mdot
.39866 .016 Mdot
.39869 .0149 Mdot
.39871 .01651 Mdot
.39874 .01616 Mdot
.39876 .01625 Mdot
.39879 .01533 Mdot
.39881 .01552 Mdot
.39884 .01558 Mdot
.39887 .01575 Mdot
.39889 .01548 Mdot
.39892 .01644 Mdot
.39894 .0155 Mdot
.39897 .01583 Mdot
.399 .01659 Mdot
.39902 .01587 Mdot
.39905 .01552 Mdot
.39907 .01587 Mdot
.3991 .01562 Mdot
.39912 .01524 Mdot
.39915 .01523 Mdot
.39918 .01562 Mdot
.3992 .01595 Mdot
.39923 .01611 Mdot
.39925 .01613 Mdot
.39928 .01653 Mdot
.39931 .01522 Mdot
.39933 .0158 Mdot
.39936 .01594 Mdot
.39938 .01497 Mdot
.39941 .01565 Mdot
.39943 .01513 Mdot
.39946 .01669 Mdot
.39949 .01592 Mdot
.39951 .01525 Mdot
.39954 .01599 Mdot
.39956 .01747 Mdot
.39959 .0153 Mdot
.39962 .01609 Mdot
.39964 .01513 Mdot
.39967 .01546 Mdot
.39969 .01662 Mdot
.39972 .01602 Mdot
.39974 .01525 Mdot
.39977 .01739 Mdot
.3998 .01592 Mdot
.39982 .01567 Mdot
.39985 .01659 Mdot
.39987 .01539 Mdot
.3999 .01571 Mdot
.39993 .01554 Mdot
.39995 .01504 Mdot
.39998 .01501 Mdot
.4 .01518 Mdot
.40003 .0158 Mdot
.40005 .01562 Mdot
.40008 .01668 Mdot
.40011 .01642 Mdot
.40013 .01529 Mdot
.40016 .01686 Mdot
.40018 .01598 Mdot
.40021 .0155 Mdot
.40024 .01568 Mdot
.40026 .01659 Mdot
.40029 .01543 Mdot
.40031 .01548 Mdot
.40034 .01539 Mdot
.40036 .01609 Mdot
.40039 .01527 Mdot
.40042 .01514 Mdot
.40044 .01543 Mdot
.40047 .01591 Mdot
.40049 .01534 Mdot
.40052 .01639 Mdot
.40055 .01568 Mdot
.40057 .01629 Mdot
.4006 .01575 Mdot
.40062 .01634 Mdot
.40065 .01578 Mdot
.40067 .01841 Mdot
.4007 .01651 Mdot
.40073 .01638 Mdot
.40075 .01718 Mdot
.40078 .01591 Mdot
.4008 .016 Mdot
.40083 .0162 Mdot
.40086 .01615 Mdot
.40088 .0153 Mdot
.40091 .01567 Mdot
.40093 .0157 Mdot
.40096 .01533 Mdot
.40098 .01544 Mdot
.40101 .01487 Mdot
.40104 .01661 Mdot
.40106 .01556 Mdot
.40109 .0157 Mdot
.40111 .0156 Mdot
.40114 .01492 Mdot
.40117 .016 Mdot
.40119 .0162 Mdot
.40122 .01488 Mdot
.40124 .01525 Mdot
.40127 .01556 Mdot
.40129 .0157 Mdot
.40132 .01512 Mdot
.40135 .01638 Mdot
.40137 .0163 Mdot
.4014 .01547 Mdot
.40142 .01511 Mdot
.40145 .01549 Mdot
.40148 .01545 Mdot
.4015 .01527 Mdot
.40153 .01564 Mdot
.40155 .01638 Mdot
.40158 .01551 Mdot
.4016 .01637 Mdot
.40163 .01634 Mdot
.40166 .01607 Mdot
.40168 .01537 Mdot
.40171 .01539 Mdot
.40173 .01517 Mdot
.40176 .0164 Mdot
.40179 .01595 Mdot
.40181 .01627 Mdot
.40184 .01648 Mdot
.40186 .01494 Mdot
.40189 .01652 Mdot
.40191 .01615 Mdot
.40194 .0149 Mdot
.40197 .01625 Mdot
.40199 .01551 Mdot
.40202 .01528 Mdot
.40204 .01549 Mdot
.40207 .01498 Mdot
.4021 .01598 Mdot
.40212 .01681 Mdot
.40215 .01617 Mdot
.40217 .01617 Mdot
.4022 .01568 Mdot
.40222 .01637 Mdot
.40225 .01586 Mdot
.40228 .01517 Mdot
.4023 .01477 Mdot
.40233 .01558 Mdot
.40235 .01559 Mdot
.40238 .01529 Mdot
.40241 .01647 Mdot
.40243 .01509 Mdot
.40246 .01568 Mdot
.40248 .01591 Mdot
.40251 .01542 Mdot
.40253 .01513 Mdot
.40256 .01547 Mdot
.40259 .01649 Mdot
.40261 .01529 Mdot
.40264 .01564 Mdot
.40266 .01525 Mdot
.40269 .01565 Mdot
.40272 .01606 Mdot
.40274 .01507 Mdot
.40277 .01505 Mdot
.40279 .0158 Mdot
.40282 .01516 Mdot
.40284 .01642 Mdot
.40287 .01574 Mdot
.4029 .01542 Mdot
.40292 .01587 Mdot
.40295 .01558 Mdot
.40297 .01594 Mdot
.403 .01658 Mdot
.40303 .01542 Mdot
.40305 .01604 Mdot
.40308 .01547 Mdot
.4031 .01745 Mdot
.40313 .01543 Mdot
.40315 .01633 Mdot
.40318 .01482 Mdot
.40321 .01697 Mdot
.40323 .01643 Mdot
.40326 .01658 Mdot
.40328 .01593 Mdot
.40331 .01482 Mdot
.40334 .01612 Mdot
.40336 .01483 Mdot
.40339 .01526 Mdot
.40341 .01603 Mdot
.40344 .01494 Mdot
.40346 .01537 Mdot
.40349 .01509 Mdot
.40352 .01529 Mdot
.40354 .01568 Mdot
.40357 .01553 Mdot
.40359 .01514 Mdot
.40362 .01533 Mdot
.40365 .01664 Mdot
.40367 .01634 Mdot
.4037 .01583 Mdot
.40372 .0157 Mdot
.40375 .01612 Mdot
.40377 .01572 Mdot
.4038 .01515 Mdot
.40383 .01567 Mdot
.40385 .0149 Mdot
.40388 .01568 Mdot
.4039 .01512 Mdot
.40393 .01766 Mdot
.40396 .0165 Mdot
.40398 .01687 Mdot
.40401 .01536 Mdot
.40403 .01563 Mdot
.40406 .01488 Mdot
.40409 .01539 Mdot
.40411 .01564 Mdot
.40414 .01529 Mdot
.40416 .01539 Mdot
.40419 .01512 Mdot
.40421 .01639 Mdot
.40424 .01649 Mdot
.40427 .01549 Mdot
.40429 .01581 Mdot
.40432 .01604 Mdot
.40434 .01611 Mdot
.40437 .01632 Mdot
.4044 .01613 Mdot
.40442 .0158 Mdot
.40445 .01543 Mdot
.40447 .01551 Mdot
.4045 .01605 Mdot
.40452 .01495 Mdot
.40455 .01502 Mdot
.40458 .01517 Mdot
.4046 .01564 Mdot
.40463 .01661 Mdot
.40465 .01634 Mdot
.40468 .01623 Mdot
.40471 .01602 Mdot
.40473 .01528 Mdot
.40476 .01558 Mdot
.40478 .01552 Mdot
.40481 .01666 Mdot
.40483 .01537 Mdot
.40486 .01568 Mdot
.40489 .01679 Mdot
.40491 .01557 Mdot
.40494 .0158 Mdot
.40496 .0169 Mdot
.40499 .01515 Mdot
.40502 .015 Mdot
.40504 .01624 Mdot
.40507 .0156 Mdot
.40509 .01535 Mdot
.40512 .0166 Mdot
.40514 .01613 Mdot
.40517 .01598 Mdot
.4052 .01523 Mdot
.40522 .01583 Mdot
.40525 .01689 Mdot
.40527 .01586 Mdot
.4053 .01608 Mdot
.40533 .01499 Mdot
.40535 .01582 Mdot
.40538 .01536 Mdot
.4054 .01485 Mdot
.40543 .0161 Mdot
.40545 .01581 Mdot
.40548 .01528 Mdot
.40551 .01507 Mdot
.40553 .01711 Mdot
.40556 .01561 Mdot
.40558 .01525 Mdot
.40561 .01598 Mdot
.40564 .01548 Mdot
.40566 .01554 Mdot
.40569 .0158 Mdot
.40571 .01682 Mdot
.40574 .01649 Mdot
.40576 .01601 Mdot
.40579 .01596 Mdot
.40582 .01624 Mdot
.40584 .01546 Mdot
.40587 .01654 Mdot
.40589 .0153 Mdot
.40592 .01492 Mdot
.40595 .01563 Mdot
.40597 .01492 Mdot
.406 .01562 Mdot
.40602 .01566 Mdot
.40605 .01613 Mdot
.40607 .01553 Mdot
.4061 .01511 Mdot
.40613 .01531 Mdot
.40615 .01537 Mdot
.40618 .01729 Mdot
.4062 .01576 Mdot
.40623 .01585 Mdot
.40626 .01581 Mdot
.40628 .01514 Mdot
.40631 .01685 Mdot
.40633 .01659 Mdot
.40636 .01536 Mdot
.40638 .01637 Mdot
.40641 .01592 Mdot
.40644 .01585 Mdot
.40646 .0166 Mdot
.40649 .01572 Mdot
.40651 .01559 Mdot
.40654 .01558 Mdot
.40657 .01516 Mdot
.40659 .01562 Mdot
.40662 .01532 Mdot
.40664 .01531 Mdot
.40667 .01518 Mdot
.40669 .01598 Mdot
.40672 .01492 Mdot
.40675 .01573 Mdot
.40677 .01514 Mdot
.4068 .01527 Mdot
.40682 .01532 Mdot
.40685 .01577 Mdot
.40688 .01542 Mdot
.4069 .01539 Mdot
.40693 .01674 Mdot
.40695 .01591 Mdot
.40698 .01695 Mdot
.407 .01579 Mdot
.40703 .01648 Mdot
.40706 .01586 Mdot
.40708 .01523 Mdot
.40711 .01498 Mdot
.40713 .01581 Mdot
.40716 .01522 Mdot
.40719 .01565 Mdot
.40721 .01519 Mdot
.40724 .01551 Mdot
.40726 .01527 Mdot
.40729 .01505 Mdot
.40731 .01522 Mdot
.40734 .01529 Mdot
.40737 .01569 Mdot
.40739 .01655 Mdot
.40742 .0158 Mdot
.40744 .01647 Mdot
.40747 .01523 Mdot
.4075 .01675 Mdot
.40752 .016 Mdot
.40755 .01728 Mdot
.40757 .01628 Mdot
.4076 .01562 Mdot
.40762 .01679 Mdot
.40765 .01557 Mdot
.40768 .01576 Mdot
.4077 .01526 Mdot
.40773 .01576 Mdot
.40775 .01643 Mdot
.40778 .01622 Mdot
.40781 .01623 Mdot
.40783 .01621 Mdot
.40786 .01477 Mdot
.40788 .01509 Mdot
.40791 .01595 Mdot
.40793 .01634 Mdot
.40796 .01661 Mdot
.40799 .01619 Mdot
.40801 .01529 Mdot
.40804 .01556 Mdot
.40806 .01581 Mdot
.40809 .01707 Mdot
.40812 .01628 Mdot
.40814 .01629 Mdot
.40817 .01648 Mdot
.40819 .01571 Mdot
.40822 .0156 Mdot
.40824 .01572 Mdot
.40827 .01561 Mdot
.4083 .01601 Mdot
.40832 .0155 Mdot
.40835 .01658 Mdot
.40837 .01608 Mdot
.4084 .0161 Mdot
.40843 .01594 Mdot
.40845 .01504 Mdot
.40848 .01668 Mdot
.4085 .01661 Mdot
.40853 .015 Mdot
.40855 .01587 Mdot
.40858 .0177 Mdot
.40861 .01546 Mdot
.40863 .01493 Mdot
.40866 .01567 Mdot
.40868 .01656 Mdot
.40871 .01507 Mdot
.40874 .0156 Mdot
.40876 .01573 Mdot
.40879 .01596 Mdot
.40881 .01608 Mdot
.40884 .01652 Mdot
.40886 .01543 Mdot
.40889 .01526 Mdot
.40892 .01574 Mdot
.40894 .0162 Mdot
.40897 .01567 Mdot
.40899 .01568 Mdot
.40902 .01571 Mdot
.40905 .01566 Mdot
.40907 .01558 Mdot
.4091 .01645 Mdot
.40912 .01476 Mdot
.40915 .01576 Mdot
.40917 .01663 Mdot
.4092 .01644 Mdot
.40923 .01538 Mdot
.40925 .01523 Mdot
.40928 .01514 Mdot
.4093 .01634 Mdot
.40933 .0155 Mdot
.40936 .01568 Mdot
.40938 .01548 Mdot
.40941 .01538 Mdot
.40943 .01545 Mdot
.40946 .0167 Mdot
.40948 .01567 Mdot
.40951 .01637 Mdot
.40954 .01532 Mdot
.40956 .01669 Mdot
.40959 .0161 Mdot
.40961 .01525 Mdot
.40964 .01487 Mdot
.40967 .01609 Mdot
.40969 .01611 Mdot
.40972 .01627 Mdot
.40974 .01646 Mdot
.40977 .01635 Mdot
.40979 .01627 Mdot
.40982 .01542 Mdot
.40985 .01533 Mdot
.40987 .01555 Mdot
.4099 .01541 Mdot
.40992 .01652 Mdot
.40995 .01567 Mdot
.40998 .01492 Mdot
.41 .01589 Mdot
.41003 .0167 Mdot
.41005 .01536 Mdot
.41008 .01573 Mdot
.4101 .0152 Mdot
.41013 .01638 Mdot
.41016 .01494 Mdot
.41018 .01575 Mdot
.41021 .0151 Mdot
.41023 .01573 Mdot
.41026 .01588 Mdot
.41029 .01518 Mdot
.41031 .01551 Mdot
.41034 .01563 Mdot
.41036 .01644 Mdot
.41039 .01544 Mdot
.41041 .01554 Mdot
.41044 .01491 Mdot
.41047 .01546 Mdot
.41049 .01673 Mdot
.41052 .01568 Mdot
.41054 .01578 Mdot
.41057 .01525 Mdot
.4106 .01683 Mdot
.41062 .01549 Mdot
.41065 .01481 Mdot
.41067 .01544 Mdot
.4107 .01749 Mdot
.41072 .01643 Mdot
.41075 .01587 Mdot
.41078 .01591 Mdot
.4108 .015 Mdot
.41083 .01567 Mdot
.41085 .0167 Mdot
.41088 .01533 Mdot
.41091 .01685 Mdot
.41093 .01677 Mdot
.41096 .01531 Mdot
.41098 .0157 Mdot
.41101 .01566 Mdot
.41103 .01698 Mdot
.41106 .01532 Mdot
.41109 .01631 Mdot
.41111 .01641 Mdot
.41114 .01607 Mdot
.41116 .01591 Mdot
.41119 .0157 Mdot
.41122 .01656 Mdot
.41124 .01515 Mdot
.41127 .01863 Mdot
.41129 .01647 Mdot
.41132 .01717 Mdot
.41134 .01497 Mdot
.41137 .01625 Mdot
.4114 .01522 Mdot
.41142 .01614 Mdot
.41145 .01502 Mdot
.41147 .01626 Mdot
.4115 .01557 Mdot
.41153 .01646 Mdot
.41155 .01573 Mdot
.41158 .0158 Mdot
.4116 .01682 Mdot
.41163 .01592 Mdot
.41165 .01516 Mdot
.41168 .01588 Mdot
.41171 .0155 Mdot
.41173 .0156 Mdot
.41176 .01585 Mdot
.41178 .01587 Mdot
.41181 .01671 Mdot
.41184 .01507 Mdot
.41186 .01552 Mdot
.41189 .01557 Mdot
.41191 .01484 Mdot
.41194 .01579 Mdot
.41196 .01632 Mdot
.41199 .01652 Mdot
.41202 .01614 Mdot
.41204 .01617 Mdot
.41207 .01621 Mdot
.41209 .01598 Mdot
.41212 .01566 Mdot
.41215 .01491 Mdot
.41217 .01628 Mdot
.4122 .01594 Mdot
.41222 .0161 Mdot
.41225 .01553 Mdot
.41227 .0156 Mdot
.4123 .01569 Mdot
.41233 .01499 Mdot
.41235 .01569 Mdot
.41238 .01627 Mdot
.4124 .01644 Mdot
.41243 .01485 Mdot
.41246 .0158 Mdot
.41248 .01575 Mdot
.41251 .01531 Mdot
.41253 .01558 Mdot
.41256 .01524 Mdot
.41258 .01643 Mdot
.41261 .01566 Mdot
.41264 .01554 Mdot
.41266 .0156 Mdot
.41269 .01516 Mdot
.41271 .01533 Mdot
.41274 .01569 Mdot
.41277 .01538 Mdot
.41279 .01608 Mdot
.41282 .01578 Mdot
.41284 .01693 Mdot
.41287 .01564 Mdot
.41289 .01527 Mdot
.41292 .01605 Mdot
.41295 .01593 Mdot
.41297 .01528 Mdot
.413 .01597 Mdot
.41302 .01615 Mdot
.41305 .01523 Mdot
.41308 .01529 Mdot
.4131 .01651 Mdot
.41313 .0156 Mdot
.41315 .01521 Mdot
.41318 .01564 Mdot
.41321 .01632 Mdot
.41323 .01614 Mdot
.41326 .01492 Mdot
.41328 .0159 Mdot
.41331 .01524 Mdot
.41333 .01632 Mdot
.41336 .01567 Mdot
.41339 .01543 Mdot
.41341 .01641 Mdot
.41344 .01638 Mdot
.41346 .0157 Mdot
.41349 .01574 Mdot
.41352 .01559 Mdot
.41354 .01536 Mdot
.41357 .01562 Mdot
.41359 .01668 Mdot
.41362 .01697 Mdot
.41364 .01491 Mdot
.41367 .01562 Mdot
.4137 .01625 Mdot
.41372 .01592 Mdot
.41375 .01576 Mdot
.41377 .01578 Mdot
.4138 .01563 Mdot
.41383 .01665 Mdot
.41385 .01504 Mdot
.41388 .01564 Mdot
.4139 .01617 Mdot
.41393 .0158 Mdot
.41395 .01567 Mdot
.41398 .01578 Mdot
.41401 .01527 Mdot
.41403 .01582 Mdot
.41406 .01587 Mdot
.41408 .01576 Mdot
.41411 .01546 Mdot
.41414 .01553 Mdot
.41416 .01604 Mdot
.41419 .01639 Mdot
.41421 .01629 Mdot
.41424 .01568 Mdot
.41426 .01611 Mdot
.41429 .01596 Mdot
.41432 .01509 Mdot
.41434 .01578 Mdot
.41437 .01708 Mdot
.41439 .01597 Mdot
.41442 .01525 Mdot
.41445 .01517 Mdot
.41447 .01651 Mdot
.4145 .01566 Mdot
.41452 .01564 Mdot
.41455 .01543 Mdot
.41457 .01521 Mdot
.4146 .01644 Mdot
.41463 .01568 Mdot
.41465 .01493 Mdot
.41468 .01554 Mdot
.4147 .01569 Mdot
.41473 .01641 Mdot
.41476 .01627 Mdot
.41478 .01579 Mdot
.41481 .01536 Mdot
.41483 .01496 Mdot
.41486 .0157 Mdot
.41488 .01579 Mdot
.41491 .01576 Mdot
.41494 .01515 Mdot
.41496 .01578 Mdot
.41499 .016 Mdot
.41501 .0153 Mdot
.41504 .0158 Mdot
.41507 .01633 Mdot
.41509 .01616 Mdot
.41512 .01582 Mdot
.41514 .01705 Mdot
.41517 .01525 Mdot
.41519 .01553 Mdot
.41522 .01593 Mdot
.41525 .01512 Mdot
.41527 .01586 Mdot
.4153 .01722 Mdot
.41532 .01482 Mdot
.41535 .01512 Mdot
.41538 .01532 Mdot
.4154 .01538 Mdot
.41543 .0161 Mdot
.41545 .01682 Mdot
.41548 .01684 Mdot
.4155 .01623 Mdot
.41553 .01613 Mdot
.41556 .01609 Mdot
.41558 .01606 Mdot
.41561 .01617 Mdot
.41563 .01631 Mdot
.41566 .01554 Mdot
.41569 .0153 Mdot
.41571 .0156 Mdot
.41574 .01602 Mdot
.41576 .01568 Mdot
.41579 .01564 Mdot
.41581 .01562 Mdot
.41584 .01635 Mdot
.41587 .01643 Mdot
.41589 .01678 Mdot
.41592 .01579 Mdot
.41594 .01553 Mdot
.41597 .01581 Mdot
.416 .01612 Mdot
.41602 .01552 Mdot
.41605 .01629 Mdot
.41607 .01491 Mdot
.4161 .01546 Mdot
.41612 .01669 Mdot
.41615 .01507 Mdot
.41618 .01542 Mdot
.4162 .01514 Mdot
.41623 .0156 Mdot
.41625 .01617 Mdot
.41628 .01552 Mdot
.41631 .015 Mdot
.41633 .01536 Mdot
.41636 .01572 Mdot
.41638 .01512 Mdot
.41641 .01545 Mdot
.41643 .01586 Mdot
.41646 .01523 Mdot
.41649 .01499 Mdot
.41651 .0149 Mdot
.41654 .01519 Mdot
.41656 .01541 Mdot
.41659 .01511 Mdot
.41662 .01584 Mdot
.41664 .01484 Mdot
.41667 .01551 Mdot
.41669 .01613 Mdot
.41672 .01545 Mdot
.41674 .01558 Mdot
.41677 .01555 Mdot
.4168 .01582 Mdot
.41682 .0157 Mdot
.41685 .01529 Mdot
.41687 .01622 Mdot
.4169 .01681 Mdot
.41693 .01514 Mdot
.41695 .01525 Mdot
.41698 .01577 Mdot
.417 .01599 Mdot
.41703 .01539 Mdot
.41705 .01543 Mdot
.41708 .01502 Mdot
.41711 .01475 Mdot
.41713 .01616 Mdot
.41716 .01619 Mdot
.41718 .01534 Mdot
.41721 .01591 Mdot
.41724 .01498 Mdot
.41726 .01576 Mdot
.41729 .01552 Mdot
.41731 .01564 Mdot
.41734 .01545 Mdot
.41736 .01648 Mdot
.41739 .01585 Mdot
.41742 .01635 Mdot
.41744 .01539 Mdot
.41747 .01602 Mdot
.41749 .016 Mdot
.41752 .01555 Mdot
.41755 .01717 Mdot
.41757 .01586 Mdot
.4176 .01561 Mdot
.41762 .01572 Mdot
.41765 .01571 Mdot
.41767 .01527 Mdot
.4177 .01579 Mdot
.41773 .01498 Mdot
.41775 .01596 Mdot
.41778 .01602 Mdot
.4178 .01576 Mdot
.41783 .01526 Mdot
.41786 .01515 Mdot
.41788 .01576 Mdot
.41791 .01614 Mdot
.41793 .01601 Mdot
.41796 .01654 Mdot
.41798 .01527 Mdot
.41801 .01592 Mdot
.41804 .01561 Mdot
.41806 .01556 Mdot
.41809 .01523 Mdot
.41811 .01494 Mdot
.41814 .0151 Mdot
.41817 .01688 Mdot
.41819 .01616 Mdot
.41822 .01601 Mdot
.41824 .01517 Mdot
.41827 .01586 Mdot
.41829 .01654 Mdot
.41832 .01531 Mdot
.41835 .01515 Mdot
.41837 .01485 Mdot
.4184 .01505 Mdot
.41842 .01478 Mdot
.41845 .01596 Mdot
.41848 .0159 Mdot
.4185 .0159 Mdot
.41853 .01621 Mdot
.41855 .01606 Mdot
.41858 .01639 Mdot
.4186 .01634 Mdot
.41863 .01489 Mdot
.41866 .01552 Mdot
.41868 .01632 Mdot
.41871 .01643 Mdot
.41873 .01524 Mdot
.41876 .01603 Mdot
.41879 .0168 Mdot
.41881 .0149 Mdot
.41884 .01572 Mdot
.41886 .01494 Mdot
.41889 .0161 Mdot
.41891 .01557 Mdot
.41894 .01537 Mdot
.41897 .01517 Mdot
.41899 .0154 Mdot
.41902 .01554 Mdot
.41904 .016 Mdot
.41907 .01628 Mdot
.4191 .01554 Mdot
.41912 .01515 Mdot
.41915 .01534 Mdot
.41917 .01616 Mdot
.4192 .01538 Mdot
.41922 .01529 Mdot
.41925 .01562 Mdot
.41928 .01555 Mdot
.4193 .01519 Mdot
.41933 .01615 Mdot
.41935 .01535 Mdot
.41938 .01555 Mdot
.41941 .01496 Mdot
.41943 .01527 Mdot
.41946 .01568 Mdot
.41948 .01533 Mdot
.41951 .01604 Mdot
.41953 .01521 Mdot
.41956 .01536 Mdot
.41959 .01488 Mdot
.41961 .01521 Mdot
.41964 .01591 Mdot
.41966 .01529 Mdot
.41969 .0155 Mdot
.41972 .01479 Mdot
.41974 .01499 Mdot
.41977 .01504 Mdot
.41979 .01542 Mdot
.41982 .01579 Mdot
.41984 .01483 Mdot
.41987 .01594 Mdot
.4199 .01523 Mdot
.41992 .01605 Mdot
.41995 .01541 Mdot
.41997 .01645 Mdot
.42 .01563 Mdot
.42003 .01534 Mdot
.42005 .01495 Mdot
.42008 .01578 Mdot
.4201 .01502 Mdot
.42013 .01508 Mdot
.42015 .01507 Mdot
.42018 .01499 Mdot
.42021 .0161 Mdot
.42023 .01564 Mdot
.42026 .01583 Mdot
.42028 .01558 Mdot
.42031 .01608 Mdot
.42034 .0156 Mdot
.42036 .01654 Mdot
.42039 .01487 Mdot
.42041 .01602 Mdot
.42044 .01544 Mdot
.42046 .01528 Mdot
.42049 .01575 Mdot
.42052 .01634 Mdot
.42054 .01523 Mdot
.42057 .0161 Mdot
.42059 .01503 Mdot
.42062 .01619 Mdot
.42065 .01531 Mdot
.42067 .01513 Mdot
.4207 .01515 Mdot
.42072 .01538 Mdot
.42075 .01525 Mdot
.42077 .01565 Mdot
.4208 .01564 Mdot
.42083 .0165 Mdot
.42085 .01572 Mdot
.42088 .0159 Mdot
.4209 .01589 Mdot
.42093 .01594 Mdot
.42096 .01526 Mdot
.42098 .01584 Mdot
.42101 .01553 Mdot
.42103 .01588 Mdot
.42106 .01558 Mdot
.42108 .01615 Mdot
.42111 .01646 Mdot
.42114 .01542 Mdot
.42116 .01532 Mdot
.42119 .01547 Mdot
.42121 .01563 Mdot
.42124 .01555 Mdot
.42127 .01563 Mdot
.42129 .01633 Mdot
.42132 .01596 Mdot
.42134 .01509 Mdot
.42137 .01518 Mdot
.42139 .01539 Mdot
.42142 .01505 Mdot
.42145 .01529 Mdot
.42147 .01563 Mdot
.4215 .01529 Mdot
.42152 .01524 Mdot
.42155 .01666 Mdot
.42158 .01548 Mdot
.4216 .0151 Mdot
.42163 .0157 Mdot
.42165 .01485 Mdot
.42168 .0161 Mdot
.4217 .0153 Mdot
.42173 .01621 Mdot
.42176 .01686 Mdot
.42178 .01535 Mdot
.42181 .01619 Mdot
.42183 .01522 Mdot
.42186 .01533 Mdot
.42189 .01538 Mdot
.42191 .01615 Mdot
.42194 .01601 Mdot
.42196 .01505 Mdot
.42199 .0158 Mdot
.42201 .01653 Mdot
.42204 .01545 Mdot
.42207 .01507 Mdot
.42209 .0154 Mdot
.42212 .01553 Mdot
.42214 .01589 Mdot
.42217 .01492 Mdot
.4222 .01498 Mdot
.42222 .01517 Mdot
.42225 .01478 Mdot
.42227 .01691 Mdot
.4223 .01567 Mdot
.42233 .01667 Mdot
.42235 .01574 Mdot
.42238 .0157 Mdot
.4224 .01533 Mdot
.42243 .01561 Mdot
.42245 .01505 Mdot
.42248 .015 Mdot
.42251 .01577 Mdot
.42253 .01516 Mdot
.42256 .01661 Mdot
.42258 .01684 Mdot
.42261 .01646 Mdot
.42264 .01608 Mdot
.42266 .01583 Mdot
.42269 .01579 Mdot
.42271 .01586 Mdot
.42274 .0154 Mdot
.42276 .01622 Mdot
.42279 .01513 Mdot
.42282 .01573 Mdot
.42284 .01505 Mdot
.42287 .01583 Mdot
.42289 .01553 Mdot
.42292 .0152 Mdot
.42295 .01586 Mdot
.42297 .01625 Mdot
.423 .01575 Mdot
.42302 .01579 Mdot
.42305 .01519 Mdot
.42307 .01517 Mdot
.4231 .01665 Mdot
.42313 .01604 Mdot
.42315 .01637 Mdot
.42318 .01523 Mdot
.4232 .01562 Mdot
.42323 .01584 Mdot
.42326 .01657 Mdot
.42328 .01728 Mdot
.42331 .01531 Mdot
.42333 .0166 Mdot
.42336 .0156 Mdot
.42338 .01544 Mdot
.42341 .01581 Mdot
.42344 .01527 Mdot
.42346 .01524 Mdot
.42349 .01536 Mdot
.42351 .016 Mdot
.42354 .0161 Mdot
.42357 .01548 Mdot
.42359 .01686 Mdot
.42362 .01581 Mdot
.42364 .01605 Mdot
.42367 .01544 Mdot
.42369 .01551 Mdot
.42372 .01606 Mdot
.42375 .01616 Mdot
.42377 .01621 Mdot
.4238 .01572 Mdot
.42382 .01623 Mdot
.42385 .01499 Mdot
.42388 .0158 Mdot
.4239 .01592 Mdot
.42393 .01507 Mdot
.42395 .01578 Mdot
.42398 .01514 Mdot
.424 .0161 Mdot
.42403 .01629 Mdot
.42406 .01633 Mdot
.42408 .01487 Mdot
.42411 .01626 Mdot
.42413 .01568 Mdot
.42416 .01531 Mdot
.42419 .01645 Mdot
.42421 .01559 Mdot
.42424 .01503 Mdot
.42426 .01638 Mdot
.42429 .01545 Mdot
.42431 .01746 Mdot
.42434 .01617 Mdot
.42437 .01567 Mdot
.42439 .01518 Mdot
.42442 .01589 Mdot
.42444 .01567 Mdot
.42447 .01604 Mdot
.4245 .01541 Mdot
.42452 .01583 Mdot
.42455 .01513 Mdot
.42457 .01497 Mdot
.4246 .01487 Mdot
.42462 .01622 Mdot
.42465 .0161 Mdot
.42468 .01538 Mdot
.4247 .01636 Mdot
.42473 .01531 Mdot
.42475 .01607 Mdot
.42478 .01675 Mdot
.42481 .01489 Mdot
.42483 .01574 Mdot
.42486 .01539 Mdot
.42488 .01533 Mdot
.42491 .01544 Mdot
.42493 .01515 Mdot
.42496 .01648 Mdot
.42499 .01554 Mdot
.42501 .01633 Mdot
.42504 .01579 Mdot
.42506 .01565 Mdot
.42509 .01596 Mdot
.42512 .0154 Mdot
.42514 .01561 Mdot
.42517 .0158 Mdot
.42519 .01687 Mdot
.42522 .01655 Mdot
.42524 .01501 Mdot
.42527 .01543 Mdot
.4253 .01586 Mdot
.42532 .01486 Mdot
.42535 .01535 Mdot
.42537 .01552 Mdot
.4254 .015 Mdot
.42543 .01545 Mdot
.42545 .01619 Mdot
.42548 .0164 Mdot
.4255 .01522 Mdot
.42553 .01508 Mdot
.42555 .01565 Mdot
.42558 .01552 Mdot
.42561 .01592 Mdot
.42563 .01585 Mdot
.42566 .01571 Mdot
.42568 .01531 Mdot
.42571 .01611 Mdot
.42574 .01581 Mdot
.42576 .01542 Mdot
.42579 .0154 Mdot
.42581 .01513 Mdot
.42584 .01598 Mdot
.42586 .01565 Mdot
.42589 .01537 Mdot
.42592 .01617 Mdot
.42594 .01524 Mdot
.42597 .0159 Mdot
.42599 .0154 Mdot
.42602 .01602 Mdot
.42605 .01572 Mdot
.42607 .01526 Mdot
.4261 .01538 Mdot
.42612 .01643 Mdot
.42615 .01557 Mdot
.42617 .01581 Mdot
.4262 .01537 Mdot
.42623 .01571 Mdot
.42625 .01601 Mdot
.42628 .01642 Mdot
.4263 .01625 Mdot
.42633 .01649 Mdot
.42636 .01621 Mdot
.42638 .01534 Mdot
.42641 .01535 Mdot
.42643 .01595 Mdot
.42646 .01564 Mdot
.42648 .01614 Mdot
.42651 .01525 Mdot
.42654 .0155 Mdot
.42656 .01628 Mdot
.42659 .0159 Mdot
.42661 .01564 Mdot
.42664 .01583 Mdot
.42667 .01554 Mdot
.42669 .01569 Mdot
.42672 .01576 Mdot
.42674 .01596 Mdot
.42677 .0164 Mdot
.42679 .015 Mdot
.42682 .01474 Mdot
.42685 .01649 Mdot
.42687 .01592 Mdot
.4269 .01577 Mdot
.42692 .01548 Mdot
.42695 .0156 Mdot
.42698 .01645 Mdot
.427 .0163 Mdot
.42703 .01598 Mdot
.42705 .01712 Mdot
.42708 .01558 Mdot
.4271 .01651 Mdot
.42713 .01626 Mdot
.42716 .01514 Mdot
.42718 .01567 Mdot
.42721 .01602 Mdot
.42723 .01577 Mdot
.42726 .01636 Mdot
.42729 .01663 Mdot
.42731 .01545 Mdot
.42734 .01583 Mdot
.42736 .01603 Mdot
.42739 .01694 Mdot
.42741 .01563 Mdot
.42744 .01664 Mdot
.42747 .01625 Mdot
.42749 .01633 Mdot
.42752 .01531 Mdot
.42754 .01483 Mdot
.42757 .01529 Mdot
.4276 .0155 Mdot
.42762 .01606 Mdot
.42765 .01699 Mdot
.42767 .01535 Mdot
.4277 .01581 Mdot
.42772 .01589 Mdot
.42775 .0159 Mdot
.42778 .01528 Mdot
.4278 .0148 Mdot
.42783 .01576 Mdot
.42785 .01548 Mdot
.42788 .01601 Mdot
.42791 .01646 Mdot
.42793 .01566 Mdot
.42796 .01487 Mdot
.42798 .01725 Mdot
.42801 .01515 Mdot
.42803 .01523 Mdot
.42806 .01514 Mdot
.42809 .01677 Mdot
.42811 .01587 Mdot
.42814 .0151 Mdot
.42816 .01548 Mdot
.42819 .01548 Mdot
.42822 .01705 Mdot
.42824 .01624 Mdot
.42827 .01503 Mdot
.42829 .01598 Mdot
.42832 .01638 Mdot
.42834 .01611 Mdot
.42837 .01546 Mdot
.4284 .01531 Mdot
.42842 .01746 Mdot
.42845 .01607 Mdot
.42847 .01591 Mdot
.4285 .01637 Mdot
.42853 .01622 Mdot
.42855 .01586 Mdot
.42858 .01624 Mdot
.4286 .01634 Mdot
.42863 .01536 Mdot
.42865 .01509 Mdot
.42868 .01595 Mdot
.42871 .01697 Mdot
.42873 .01744 Mdot
.42876 .01558 Mdot
.42878 .01476 Mdot
.42881 .01674 Mdot
.42884 .01546 Mdot
.42886 .01502 Mdot
.42889 .01643 Mdot
.42891 .01507 Mdot
.42894 .01598 Mdot
.42896 .01596 Mdot
.42899 .01599 Mdot
.42902 .01586 Mdot
.42904 .01771 Mdot
.42907 .01611 Mdot
.42909 .01558 Mdot
.42912 .01655 Mdot
.42915 .01519 Mdot
.42917 .01543 Mdot
.4292 .01503 Mdot
.42922 .01555 Mdot
.42925 .01523 Mdot
.42927 .01686 Mdot
.4293 .01565 Mdot
.42933 .01586 Mdot
.42935 .01523 Mdot
.42938 .01624 Mdot
.4294 .0158 Mdot
.42943 .01529 Mdot
.42946 .01652 Mdot
.42948 .01572 Mdot
.42951 .01586 Mdot
.42953 .01668 Mdot
.42956 .01533 Mdot
.42958 .01569 Mdot
.42961 .01513 Mdot
.42964 .01613 Mdot
.42966 .01568 Mdot
.42969 .01586 Mdot
.42971 .01547 Mdot
.42974 .01594 Mdot
.42977 .01526 Mdot
.42979 .0155 Mdot
.42982 .01694 Mdot
.42984 .01598 Mdot
.42987 .01599 Mdot
.42989 .01514 Mdot
.42992 .01571 Mdot
.42995 .01606 Mdot
.42997 .01633 Mdot
.43 .01577 Mdot
.43002 .01536 Mdot
.43005 .01562 Mdot
.43008 .01593 Mdot
.4301 .01744 Mdot
.43013 .01542 Mdot
.43015 .01585 Mdot
.43018 .01553 Mdot
.4302 .01598 Mdot
.43023 .01563 Mdot
.43026 .01594 Mdot
.43028 .0154 Mdot
.43031 .01543 Mdot
.43033 .01534 Mdot
.43036 .01588 Mdot
.43039 .01554 Mdot
.43041 .01516 Mdot
.43044 .01525 Mdot
.43046 .01504 Mdot
.43049 .01543 Mdot
.43051 .0153 Mdot
.43054 .01545 Mdot
.43057 .01538 Mdot
.43059 .01624 Mdot
.43062 .01584 Mdot
.43064 .01565 Mdot
.43067 .01524 Mdot
.4307 .01529 Mdot
.43072 .01705 Mdot
.43075 .01613 Mdot
.43077 .01499 Mdot
.4308 .01544 Mdot
.43082 .01591 Mdot
.43085 .01619 Mdot
.43088 .01605 Mdot
.4309 .01657 Mdot
.43093 .0155 Mdot
.43095 .01525 Mdot
.43098 .01519 Mdot
.43101 .01526 Mdot
.43103 .01583 Mdot
.43106 .01538 Mdot
.43108 .01566 Mdot
.43111 .01654 Mdot
.43113 .01588 Mdot
.43116 .01559 Mdot
.43119 .01516 Mdot
.43121 .0161 Mdot
.43124 .0157 Mdot
.43126 .01579 Mdot
.43129 .01603 Mdot
.43132 .01498 Mdot
.43134 .01596 Mdot
.43137 .01521 Mdot
.43139 .01528 Mdot
.43142 .01745 Mdot
.43145 .01542 Mdot
.43147 .01573 Mdot
.4315 .01614 Mdot
.43152 .01525 Mdot
.43155 .01599 Mdot
.43157 .01598 Mdot
.4316 .01592 Mdot
.43163 .01553 Mdot
.43165 .01528 Mdot
.43168 .01574 Mdot
.4317 .01571 Mdot
.43173 .01513 Mdot
.43176 .01584 Mdot
.43178 .01519 Mdot
.43181 .01521 Mdot
.43183 .01599 Mdot
.43186 .01535 Mdot
.43188 .01527 Mdot
.43191 .01604 Mdot
.43194 .01579 Mdot
.43196 .01475 Mdot
.43199 .01548 Mdot
.43201 .01532 Mdot
.43204 .01565 Mdot
.43207 .0159 Mdot
.43209 .01623 Mdot
.43212 .01651 Mdot
.43214 .01653 Mdot
.43217 .0166 Mdot
.43219 .01578 Mdot
.43222 .01513 Mdot
.43225 .01641 Mdot
.43227 .01512 Mdot
.4323 .01648 Mdot
.43232 .01567 Mdot
.43235 .01526 Mdot
.43238 .01513 Mdot
.4324 .01669 Mdot
.43243 .01584 Mdot
.43245 .01623 Mdot
.43248 .01555 Mdot
.4325 .01516 Mdot
.43253 .01584 Mdot
.43256 .01673 Mdot
.43258 .01579 Mdot
.43261 .01508 Mdot
.43263 .01529 Mdot
.43266 .01572 Mdot
.43269 .01632 Mdot
.43271 .0161 Mdot
.43274 .01529 Mdot
.43276 .01665 Mdot
.43279 .01522 Mdot
.43281 .01516 Mdot
.43284 .01483 Mdot
.43287 .01522 Mdot
.43289 .01573 Mdot
.43292 .01534 Mdot
.43294 .01585 Mdot
.43297 .01699 Mdot
.433 .01524 Mdot
.43302 .01677 Mdot
.43305 .01532 Mdot
.43307 .01555 Mdot
.4331 .01546 Mdot
.43312 .01627 Mdot
.43315 .01635 Mdot
.43318 .01619 Mdot
.4332 .01546 Mdot
.43323 .01517 Mdot
.43325 .01531 Mdot
.43328 .01538 Mdot
.43331 .0161 Mdot
.43333 .01587 Mdot
.43336 .01568 Mdot
.43338 .01588 Mdot
.43341 .01632 Mdot
.43343 .01555 Mdot
.43346 .01543 Mdot
.43349 .01495 Mdot
.43351 .01774 Mdot
.43354 .01623 Mdot
.43356 .01557 Mdot
.43359 .01578 Mdot
.43362 .0151 Mdot
.43364 .01595 Mdot
.43367 .0154 Mdot
.43369 .01626 Mdot
.43372 .01595 Mdot
.43374 .0152 Mdot
.43377 .01572 Mdot
.4338 .01555 Mdot
.43382 .01661 Mdot
.43385 .01624 Mdot
.43387 .01537 Mdot
.4339 .01715 Mdot
.43393 .01532 Mdot
.43395 .01565 Mdot
.43398 .01506 Mdot
.434 .01649 Mdot
.43403 .0151 Mdot
.43405 .01534 Mdot
.43408 .01597 Mdot
.43411 .01654 Mdot
.43413 .01643 Mdot
.43416 .0155 Mdot
.43418 .01511 Mdot
.43421 .01667 Mdot
.43424 .01513 Mdot
.43426 .0163 Mdot
.43429 .01576 Mdot
.43431 .01572 Mdot
.43434 .0157 Mdot
.43436 .01526 Mdot
.43439 .01596 Mdot
.43442 .01521 Mdot
.43444 .01563 Mdot
.43447 .01532 Mdot
.43449 .01608 Mdot
.43452 .01504 Mdot
.43455 .01676 Mdot
.43457 .01509 Mdot
.4346 .01709 Mdot
.43462 .01616 Mdot
.43465 .01576 Mdot
.43467 .01678 Mdot
.4347 .0161 Mdot
.43473 .01601 Mdot
.43475 .01606 Mdot
.43478 .01562 Mdot
.4348 .01614 Mdot
.43483 .01557 Mdot
.43486 .01562 Mdot
.43488 .01487 Mdot
.43491 .01545 Mdot
.43493 .01665 Mdot
.43496 .01554 Mdot
.43498 .01662 Mdot
.43501 .01632 Mdot
.43504 .01583 Mdot
.43506 .01497 Mdot
.43509 .01512 Mdot
.43511 .01521 Mdot
.43514 .01551 Mdot
.43517 .01529 Mdot
.43519 .01635 Mdot
.43522 .0153 Mdot
.43524 .0161 Mdot
.43527 .01524 Mdot
.43529 .01529 Mdot
.43532 .0161 Mdot
.43535 .01509 Mdot
.43537 .01511 Mdot
.4354 .01527 Mdot
.43542 .01505 Mdot
.43545 .01558 Mdot
.43548 .01538 Mdot
.4355 .01509 Mdot
.43553 .01522 Mdot
.43555 .0157 Mdot
.43558 .01565 Mdot
.4356 .01578 Mdot
.43563 .01524 Mdot
.43566 .01533 Mdot
.43568 .01508 Mdot
.43571 .01624 Mdot
.43573 .01573 Mdot
.43576 .01552 Mdot
.43579 .0157 Mdot
.43581 .01547 Mdot
.43584 .01504 Mdot
.43586 .01553 Mdot
.43589 .01633 Mdot
.43591 .01699 Mdot
.43594 .0166 Mdot
.43597 .01526 Mdot
.43599 .01573 Mdot
.43602 .01487 Mdot
.43604 .01571 Mdot
.43607 .01558 Mdot
.4361 .01645 Mdot
.43612 .01572 Mdot
.43615 .01715 Mdot
.43617 .015 Mdot
.4362 .01621 Mdot
.43622 .01563 Mdot
.43625 .01539 Mdot
.43628 .0162 Mdot
.4363 .01641 Mdot
.43633 .01583 Mdot
.43635 .0163 Mdot
.43638 .01507 Mdot
.43641 .015 Mdot
.43643 .01525 Mdot
.43646 .0154 Mdot
.43648 .01538 Mdot
.43651 .015 Mdot
.43653 .01592 Mdot
.43656 .01523 Mdot
.43659 .01578 Mdot
.43661 .01543 Mdot
.43664 .01568 Mdot
.43666 .01634 Mdot
.43669 .01513 Mdot
.43672 .01582 Mdot
.43674 .0164 Mdot
.43677 .0156 Mdot
.43679 .0155 Mdot
.43682 .0149 Mdot
.43684 .01494 Mdot
.43687 .01567 Mdot
.4369 .01588 Mdot
.43692 .01526 Mdot
.43695 .01583 Mdot
.43697 .01552 Mdot
.437 .01654 Mdot
.43703 .01569 Mdot
.43705 .01585 Mdot
.43708 .01501 Mdot
.4371 .01587 Mdot
.43713 .01535 Mdot
.43715 .01582 Mdot
.43718 .01569 Mdot
.43721 .01569 Mdot
.43723 .01633 Mdot
.43726 .01638 Mdot
.43728 .01506 Mdot
.43731 .01509 Mdot
.43734 .01624 Mdot
.43736 .01565 Mdot
.43739 .01544 Mdot
.43741 .01521 Mdot
.43744 .01547 Mdot
.43746 .01558 Mdot
.43749 .01546 Mdot
.43752 .01505 Mdot
.43754 .01629 Mdot
.43757 .01575 Mdot
.43759 .01505 Mdot
.43762 .01604 Mdot
.43765 .01593 Mdot
.43767 .01586 Mdot
.4377 .01487 Mdot
.43772 .01521 Mdot
.43775 .01771 Mdot
.43777 .01542 Mdot
.4378 .01639 Mdot
.43783 .017 Mdot
.43785 .01611 Mdot
.43788 .01615 Mdot
.4379 .01512 Mdot
.43793 .01582 Mdot
.43796 .01501 Mdot
.43798 .01522 Mdot
.43801 .016 Mdot
.43803 .01526 Mdot
.43806 .01495 Mdot
.43808 .01527 Mdot
.43811 .01538 Mdot
.43814 .01542 Mdot
.43816 .01522 Mdot
.43819 .01575 Mdot
.43821 .01541 Mdot
.43824 .0159 Mdot
.43827 .01683 Mdot
.43829 .0166 Mdot
.43832 .01591 Mdot
.43834 .015 Mdot
.43837 .01503 Mdot
.43839 .01549 Mdot
.43842 .01591 Mdot
.43845 .01574 Mdot
.43847 .015 Mdot
.4385 .01566 Mdot
.43852 .01521 Mdot
.43855 .01574 Mdot
.43858 .01496 Mdot
.4386 .01578 Mdot
.43863 .01542 Mdot
.43865 .01525 Mdot
.43868 .01515 Mdot
.4387 .01545 Mdot
.43873 .01627 Mdot
.43876 .01566 Mdot
.43878 .01571 Mdot
.43881 .01539 Mdot
.43883 .01607 Mdot
.43886 .01701 Mdot
.43889 .01615 Mdot
.43891 .01536 Mdot
.43894 .01547 Mdot
.43896 .0153 Mdot
.43899 .01626 Mdot
.43901 .01596 Mdot
.43904 .01556 Mdot
.43907 .01543 Mdot
.43909 .01647 Mdot
.43912 .01587 Mdot
.43914 .01591 Mdot
.43917 .0155 Mdot
.4392 .0155 Mdot
.43922 .01621 Mdot
.43925 .01627 Mdot
.43927 .01589 Mdot
.4393 .01537 Mdot
.43932 .0148 Mdot
.43935 .01522 Mdot
.43938 .01685 Mdot
.4394 .01487 Mdot
.43943 .01625 Mdot
.43945 .01519 Mdot
.43948 .01495 Mdot
.43951 .01591 Mdot
.43953 .01604 Mdot
.43956 .01516 Mdot
.43958 .01503 Mdot
.43961 .01584 Mdot
.43963 .01535 Mdot
.43966 .01509 Mdot
.43969 .01502 Mdot
.43971 .01568 Mdot
.43974 .01565 Mdot
.43976 .01603 Mdot
.43979 .01573 Mdot
.43982 .01597 Mdot
.43984 .01516 Mdot
.43987 .01606 Mdot
.43989 .01588 Mdot
.43992 .01495 Mdot
.43994 .01638 Mdot
.43997 .01596 Mdot
.44 .0152 Mdot
.44002 .01638 Mdot
.44005 .01623 Mdot
.44007 .01541 Mdot
.4401 .01615 Mdot
.44013 .01523 Mdot
.44015 .01591 Mdot
.44018 .01574 Mdot
.4402 .0152 Mdot
.44023 .01615 Mdot
.44025 .01516 Mdot
.44028 .01584 Mdot
.44031 .01606 Mdot
.44033 .01515 Mdot
.44036 .01681 Mdot
.44038 .01482 Mdot
.44041 .01547 Mdot
.44044 .01512 Mdot
.44046 .01493 Mdot
.44049 .01542 Mdot
.44051 .01609 Mdot
.44054 .01575 Mdot
.44057 .01581 Mdot
.44059 .01557 Mdot
.44062 .01502 Mdot
.44064 .01669 Mdot
.44067 .0153 Mdot
.44069 .01519 Mdot
.44072 .01613 Mdot
.44075 .01655 Mdot
.44077 .01557 Mdot
.4408 .01573 Mdot
.44082 .0152 Mdot
.44085 .01559 Mdot
.44088 .01594 Mdot
.4409 .01527 Mdot
.44093 .01523 Mdot
.44095 .01633 Mdot
.44098 .01537 Mdot
.441 .01556 Mdot
.44103 .01577 Mdot
.44106 .0161 Mdot
.44108 .01629 Mdot
.44111 .01523 Mdot
.44113 .01496 Mdot
.44116 .01537 Mdot
.44119 .01591 Mdot
.44121 .01552 Mdot
.44124 .01478 Mdot
.44126 .01522 Mdot
.44129 .01618 Mdot
.44131 .0157 Mdot
.44134 .01582 Mdot
.44137 .01561 Mdot
.44139 .01551 Mdot
.44142 .01548 Mdot
.44144 .0149 Mdot
.44147 .01679 Mdot
.4415 .01663 Mdot
.44152 .01651 Mdot
.44155 .01582 Mdot
.44157 .01555 Mdot
.4416 .01557 Mdot
.44162 .01608 Mdot
.44165 .01595 Mdot
.44168 .01595 Mdot
.4417 .01531 Mdot
.44173 .01508 Mdot
.44175 .01512 Mdot
.44178 .01496 Mdot
.44181 .01542 Mdot
.44183 .01555 Mdot
.44186 .01576 Mdot
.44188 .01581 Mdot
.44191 .01554 Mdot
.44193 .01565 Mdot
.44196 .01515 Mdot
.44199 .01543 Mdot
.44201 .01537 Mdot
.44204 .01539 Mdot
.44206 .01525 Mdot
.44209 .01531 Mdot
.44212 .01569 Mdot
.44214 .01558 Mdot
.44217 .01556 Mdot
.44219 .01518 Mdot
.44222 .01563 Mdot
.44224 .01569 Mdot
.44227 .01588 Mdot
.4423 .01529 Mdot
.44232 .01571 Mdot
.44235 .01511 Mdot
.44237 .01565 Mdot
.4424 .01507 Mdot
.44243 .01566 Mdot
.44245 .01611 Mdot
.44248 .01564 Mdot
.4425 .01649 Mdot
.44253 .01516 Mdot
.44255 .0159 Mdot
.44258 .01514 Mdot
.44261 .01543 Mdot
.44263 .01559 Mdot
.44266 .01544 Mdot
.44268 .01509 Mdot
.44271 .01572 Mdot
.44274 .01604 Mdot
.44276 .01545 Mdot
.44279 .01528 Mdot
.44281 .01567 Mdot
.44284 .01553 Mdot
.44286 .01553 Mdot
.44289 .01549 Mdot
.44292 .01536 Mdot
.44294 .01551 Mdot
.44297 .01571 Mdot
.44299 .01501 Mdot
.44302 .0153 Mdot
.44305 .01537 Mdot
.44307 .01546 Mdot
.4431 .01595 Mdot
.44312 .01526 Mdot
.44315 .01532 Mdot
.44317 .01589 Mdot
.4432 .01526 Mdot
.44323 .01612 Mdot
.44325 .01543 Mdot
.44328 .01531 Mdot
.4433 .0157 Mdot
.44333 .01518 Mdot
.44336 .0156 Mdot
.44338 .01511 Mdot
.44341 .01544 Mdot
.44343 .01493 Mdot
.44346 .01694 Mdot
.44348 .01583 Mdot
.44351 .01583 Mdot
.44354 .01495 Mdot
.44356 .01472 Mdot
.44359 .01565 Mdot
.44361 .01727 Mdot
.44364 .01564 Mdot
.44367 .01564 Mdot
.44369 .01566 Mdot
.44372 .015 Mdot
.44374 .01523 Mdot
.44377 .01544 Mdot
.44379 .01674 Mdot
.44382 .01576 Mdot
.44385 .01577 Mdot
.44387 .0162 Mdot
.4439 .016 Mdot
.44392 .01536 Mdot
.44395 .016 Mdot
.44398 .01588 Mdot
.444 .0151 Mdot
.44403 .01533 Mdot
.44405 .01526 Mdot
.44408 .01613 Mdot
.4441 .01574 Mdot
.44413 .01611 Mdot
.44416 .01528 Mdot
.44418 .01562 Mdot
.44421 .0155 Mdot
.44423 .01548 Mdot
.44426 .01577 Mdot
.44429 .01515 Mdot
.44431 .01487 Mdot
.44434 .0158 Mdot
.44436 .01506 Mdot
.44439 .01541 Mdot
.44441 .01496 Mdot
.44444 .01613 Mdot
.44447 .01524 Mdot
.44449 .01545 Mdot
.44452 .01583 Mdot
.44454 .01642 Mdot
.44457 .01526 Mdot
.4446 .01525 Mdot
.44462 .01563 Mdot
.44465 .01499 Mdot
.44467 .01547 Mdot
.4447 .01596 Mdot
.44472 .01551 Mdot
.44475 .01516 Mdot
.44478 .01513 Mdot
.4448 .01502 Mdot
.44483 .0155 Mdot
.44485 .01537 Mdot
.44488 .01538 Mdot
.44491 .01564 Mdot
.44493 .01532 Mdot
.44496 .01543 Mdot
.44498 .01555 Mdot
.44501 .01517 Mdot
.44503 .01588 Mdot
.44506 .01557 Mdot
.44509 .01503 Mdot
.44511 .01553 Mdot
.44514 .01544 Mdot
.44516 .01498 Mdot
.44519 .01548 Mdot
.44522 .01551 Mdot
.44524 .01506 Mdot
.44527 .01496 Mdot
.44529 .01638 Mdot
.44532 .01604 Mdot
.44534 .01644 Mdot
.44537 .01531 Mdot
.4454 .01558 Mdot
.44542 .01513 Mdot
.44545 .01478 Mdot
.44547 .01537 Mdot
.4455 .01574 Mdot
.44553 .01547 Mdot
.44555 .01552 Mdot
.44558 .01473 Mdot
.4456 .01589 Mdot
.44563 .01519 Mdot
.44565 .01567 Mdot
.44568 .01538 Mdot
.44571 .01545 Mdot
.44573 .01497 Mdot
.44576 .01616 Mdot
.44578 .01657 Mdot
.44581 .01566 Mdot
.44584 .01561 Mdot
.44586 .01537 Mdot
.44589 .01514 Mdot
.44591 .01564 Mdot
.44594 .01549 Mdot
.44596 .01555 Mdot
.44599 .01606 Mdot
.44602 .01552 Mdot
.44604 .01529 Mdot
.44607 .01558 Mdot
.44609 .01671 Mdot
.44612 .01537 Mdot
.44615 .01558 Mdot
.44617 .01652 Mdot
.4462 .01609 Mdot
.44622 .01561 Mdot
.44625 .01484 Mdot
.44627 .01519 Mdot
.4463 .01523 Mdot
.44633 .01536 Mdot
.44635 .01519 Mdot
.44638 .01482 Mdot
.4464 .01497 Mdot
.44643 .01559 Mdot
.44646 .0158 Mdot
.44648 .01521 Mdot
.44651 .01526 Mdot
.44653 .01537 Mdot
.44656 .01583 Mdot
.44658 .01497 Mdot
.44661 .01511 Mdot
.44664 .01561 Mdot
.44666 .01498 Mdot
.44669 .01575 Mdot
.44671 .01581 Mdot
.44674 .01502 Mdot
.44677 .0157 Mdot
.44679 .01521 Mdot
.44682 .01595 Mdot
.44684 .01515 Mdot
.44687 .01636 Mdot
.44689 .01593 Mdot
.44692 .01591 Mdot
.44695 .01537 Mdot
.44697 .01513 Mdot
.447 .0162 Mdot
.44702 .01498 Mdot
.44705 .01567 Mdot
.44708 .01586 Mdot
.4471 .01598 Mdot
.44713 .0157 Mdot
.44715 .01602 Mdot
.44718 .01564 Mdot
.4472 .01563 Mdot
.44723 .01632 Mdot
.44726 .01551 Mdot
.44728 .01598 Mdot
.44731 .01615 Mdot
.44733 .01514 Mdot
.44736 .01614 Mdot
.44739 .01514 Mdot
.44741 .01515 Mdot
.44744 .01569 Mdot
.44746 .01529 Mdot
.44749 .01652 Mdot
.44751 .01498 Mdot
.44754 .01522 Mdot
.44757 .01612 Mdot
.44759 .01522 Mdot
.44762 .01594 Mdot
.44764 .01667 Mdot
.44767 .01598 Mdot
.4477 .01502 Mdot
.44772 .01529 Mdot
.44775 .01603 Mdot
.44777 .01602 Mdot
.4478 .01547 Mdot
.44782 .01622 Mdot
.44785 .01589 Mdot
.44788 .01595 Mdot
.4479 .01629 Mdot
.44793 .01519 Mdot
.44795 .01596 Mdot
.44798 .01492 Mdot
.44801 .01566 Mdot
.44803 .0155 Mdot
.44806 .01543 Mdot
.44808 .01578 Mdot
.44811 .01535 Mdot
.44813 .01534 Mdot
.44816 .01662 Mdot
.44819 .01527 Mdot
.44821 .01586 Mdot
.44824 .01547 Mdot
.44826 .01535 Mdot
.44829 .01492 Mdot
.44832 .01502 Mdot
.44834 .01568 Mdot
.44837 .01525 Mdot
.44839 .01534 Mdot
.44842 .01686 Mdot
.44844 .01615 Mdot
.44847 .01678 Mdot
.4485 .015 Mdot
.44852 .01591 Mdot
.44855 .01631 Mdot
.44857 .01492 Mdot
.4486 .0152 Mdot
.44863 .01595 Mdot
.44865 .01534 Mdot
.44868 .01527 Mdot
.4487 .01502 Mdot
.44873 .01598 Mdot
.44875 .0153 Mdot
.44878 .01496 Mdot
.44881 .01502 Mdot
.44883 .0154 Mdot
.44886 .01584 Mdot
.44888 .01563 Mdot
.44891 .01496 Mdot
.44894 .01543 Mdot
.44896 .01483 Mdot
.44899 .01545 Mdot
.44901 .01648 Mdot
.44904 .01533 Mdot
.44906 .01578 Mdot
.44909 .01511 Mdot
.44912 .01521 Mdot
.44914 .0156 Mdot
.44917 .01517 Mdot
.44919 .0167 Mdot
.44922 .0165 Mdot
.44925 .01582 Mdot
.44927 .01505 Mdot
.4493 .01496 Mdot
.44932 .0156 Mdot
.44935 .01517 Mdot
.44937 .01558 Mdot
.4494 .01486 Mdot
.44943 .01582 Mdot
.44945 .01551 Mdot
.44948 .01499 Mdot
.4495 .01592 Mdot
.44953 .01493 Mdot
.44956 .01553 Mdot
.44958 .01548 Mdot
.44961 .01541 Mdot
.44963 .01548 Mdot
.44966 .01717 Mdot
.44968 .01536 Mdot
.44971 .01588 Mdot
.44974 .01635 Mdot
.44976 .01631 Mdot
.44979 .01649 Mdot
.44981 .01598 Mdot
.44984 .01506 Mdot
.44987 .01635 Mdot
.44989 .0157 Mdot
.44992 .01585 Mdot
.44994 .01589 Mdot
.44997 .01508 Mdot
.45 .01531 Mdot
.45002 .01617 Mdot
.45005 .01655 Mdot
.45007 .01488 Mdot
.4501 .01629 Mdot
.45012 .01576 Mdot
.45015 .01513 Mdot
.45018 .0153 Mdot
.4502 .01564 Mdot
.45023 .01551 Mdot
.45025 .01512 Mdot
.45028 .01545 Mdot
.45031 .01606 Mdot
.45033 .01583 Mdot
.45036 .0154 Mdot
.45038 .01499 Mdot
.45041 .01573 Mdot
.45043 .01576 Mdot
.45046 .01512 Mdot
.45049 .0152 Mdot
.45051 .01556 Mdot
.45054 .01576 Mdot
.45056 .01568 Mdot
.45059 .01504 Mdot
.45062 .01508 Mdot
.45064 .01574 Mdot
.45067 .01519 Mdot
.45069 .01525 Mdot
.45072 .01598 Mdot
.45074 .01493 Mdot
.45077 .01545 Mdot
.4508 .01609 Mdot
.45082 .01566 Mdot
.45085 .01552 Mdot
.45087 .01476 Mdot
.4509 .01609 Mdot
.45093 .01567 Mdot
.45095 .01543 Mdot
.45098 .01558 Mdot
.451 .01555 Mdot
.45103 .01652 Mdot
.45105 .01634 Mdot
.45108 .01647 Mdot
.45111 .01678 Mdot
.45113 .01537 Mdot
.45116 .01572 Mdot
.45118 .01527 Mdot
.45121 .01504 Mdot
.45124 .01608 Mdot
.45126 .0154 Mdot
.45129 .01542 Mdot
.45131 .01681 Mdot
.45134 .0153 Mdot
.45136 .01575 Mdot
.45139 .01522 Mdot
.45142 .01603 Mdot
.45144 .01626 Mdot
.45147 .01605 Mdot
.45149 .01618 Mdot
.45152 .01509 Mdot
.45155 .01565 Mdot
.45157 .01577 Mdot
.4516 .01502 Mdot
.45162 .01552 Mdot
.45165 .0161 Mdot
.45167 .01579 Mdot
.4517 .01543 Mdot
.45173 .01537 Mdot
.45175 .01568 Mdot
.45178 .01501 Mdot
.4518 .01565 Mdot
.45183 .01588 Mdot
.45186 .01584 Mdot
.45188 .01519 Mdot
.45191 .01502 Mdot
.45193 .01506 Mdot
.45196 .01548 Mdot
.45198 .0156 Mdot
.45201 .01528 Mdot
.45204 .01485 Mdot
.45206 .01586 Mdot
.45209 .01612 Mdot
.45211 .01577 Mdot
.45214 .01504 Mdot
.45217 .01575 Mdot
.45219 .01605 Mdot
.45222 .01531 Mdot
.45224 .015 Mdot
.45227 .01559 Mdot
.45229 .016 Mdot
.45232 .01558 Mdot
.45235 .016 Mdot
.45237 .01531 Mdot
.4524 .01614 Mdot
.45242 .01558 Mdot
.45245 .01552 Mdot
.45248 .01587 Mdot
.4525 .01686 Mdot
.45253 .01579 Mdot
.45255 .01514 Mdot
.45258 .01506 Mdot
.4526 .01543 Mdot
.45263 .01578 Mdot
.45266 .01581 Mdot
.45268 .01512 Mdot
.45271 .01646 Mdot
.45273 .01533 Mdot
.45276 .01559 Mdot
.45279 .01637 Mdot
.45281 .01561 Mdot
.45284 .01556 Mdot
.45286 .01618 Mdot
.45289 .01573 Mdot
.45291 .01591 Mdot
.45294 .01596 Mdot
.45297 .01562 Mdot
.45299 .01578 Mdot
.45302 .01528 Mdot
.45304 .01567 Mdot
.45307 .01593 Mdot
.4531 .01624 Mdot
.45312 .01587 Mdot
.45315 .01587 Mdot
.45317 .01523 Mdot
.4532 .01644 Mdot
.45322 .0156 Mdot
.45325 .01559 Mdot
.45328 .0156 Mdot
.4533 .01573 Mdot
.45333 .01536 Mdot
.45335 .01596 Mdot
.45338 .01526 Mdot
.45341 .01543 Mdot
.45343 .01542 Mdot
.45346 .01522 Mdot
.45348 .01516 Mdot
.45351 .01555 Mdot
.45353 .0162 Mdot
.45356 .01548 Mdot
.45359 .01614 Mdot
.45361 .01516 Mdot
.45364 .01538 Mdot
.45366 .01509 Mdot
.45369 .01577 Mdot
.45372 .01603 Mdot
.45374 .01674 Mdot
.45377 .0151 Mdot
.45379 .01544 Mdot
.45382 .01492 Mdot
.45384 .01534 Mdot
.45387 .0159 Mdot
.4539 .01575 Mdot
.45392 .01491 Mdot
.45395 .01626 Mdot
.45397 .01523 Mdot
.454 .01552 Mdot
.45403 .01533 Mdot
.45405 .01571 Mdot
.45408 .01506 Mdot
.4541 .01494 Mdot
.45413 .01537 Mdot
.45415 .01568 Mdot
.45418 .01596 Mdot
.45421 .01527 Mdot
.45423 .01496 Mdot
.45426 .01567 Mdot
.45428 .01557 Mdot
.45431 .01535 Mdot
.45434 .01512 Mdot
.45436 .01556 Mdot
.45439 .0152 Mdot
.45441 .01538 Mdot
.45444 .01607 Mdot
.45446 .01574 Mdot
.45449 .01564 Mdot
.45452 .01655 Mdot
.45454 .01575 Mdot
.45457 .01553 Mdot
.45459 .01655 Mdot
.45462 .01507 Mdot
.45465 .0159 Mdot
.45467 .01536 Mdot
.4547 .01617 Mdot
.45472 .01553 Mdot
.45475 .01617 Mdot
.45477 .01558 Mdot
.4548 .01574 Mdot
.45483 .01632 Mdot
.45485 .01569 Mdot
.45488 .01551 Mdot
.4549 .01494 Mdot
.45493 .01579 Mdot
.45496 .01577 Mdot
.45498 .01538 Mdot
.45501 .01537 Mdot
.45503 .016 Mdot
.45506 .01606 Mdot
.45508 .01557 Mdot
.45511 .01569 Mdot
.45514 .01576 Mdot
.45516 .01604 Mdot
.45519 .0155 Mdot
.45521 .01592 Mdot
.45524 .01631 Mdot
.45527 .01669 Mdot
.45529 .01545 Mdot
.45532 .01628 Mdot
.45534 .0159 Mdot
.45537 .01508 Mdot
.45539 .01608 Mdot
.45542 .01573 Mdot
.45545 .01496 Mdot
.45547 .01571 Mdot
.4555 .01513 Mdot
.45552 .01605 Mdot
.45555 .01619 Mdot
.45558 .01592 Mdot
.4556 .01505 Mdot
.45563 .01538 Mdot
.45565 .01596 Mdot
.45568 .01553 Mdot
.4557 .01589 Mdot
.45573 .0163 Mdot
.45576 .01518 Mdot
.45578 .01582 Mdot
.45581 .01593 Mdot
.45583 .01539 Mdot
.45586 .01585 Mdot
.45589 .01555 Mdot
.45591 .01541 Mdot
.45594 .01584 Mdot
.45596 .01574 Mdot
.45599 .01564 Mdot
.45601 .01587 Mdot
.45604 .01646 Mdot
.45607 .017 Mdot
.45609 .01526 Mdot
.45612 .01635 Mdot
.45614 .01475 Mdot
.45617 .01577 Mdot
.4562 .01562 Mdot
.45622 .01594 Mdot
.45625 .01526 Mdot
.45627 .01486 Mdot
.4563 .01552 Mdot
.45632 .01625 Mdot
.45635 .0157 Mdot
.45638 .01551 Mdot
.4564 .01524 Mdot
.45643 .01512 Mdot
.45645 .01524 Mdot
.45648 .01594 Mdot
.45651 .01537 Mdot
.45653 .01548 Mdot
.45656 .01539 Mdot
.45658 .01573 Mdot
.45661 .0158 Mdot
.45663 .01505 Mdot
.45666 .01604 Mdot
.45669 .01504 Mdot
.45671 .01575 Mdot
.45674 .0159 Mdot
.45676 .01537 Mdot
.45679 .0152 Mdot
.45682 .01525 Mdot
.45684 .0164 Mdot
.45687 .0153 Mdot
.45689 .01562 Mdot
.45692 .01639 Mdot
.45694 .01481 Mdot
.45697 .01517 Mdot
.457 .01625 Mdot
.45702 .01492 Mdot
.45705 .01539 Mdot
.45707 .01586 Mdot
.4571 .01578 Mdot
.45713 .0155 Mdot
.45715 .01504 Mdot
.45718 .01539 Mdot
.4572 .0151 Mdot
.45723 .01514 Mdot
.45725 .01628 Mdot
.45728 .01588 Mdot
.45731 .01612 Mdot
.45733 .01583 Mdot
.45736 .0157 Mdot
.45738 .0159 Mdot
.45741 .0151 Mdot
.45744 .01508 Mdot
.45746 .01509 Mdot
.45749 .01618 Mdot
.45751 .01526 Mdot
.45754 .01554 Mdot
.45756 .01545 Mdot
.45759 .01578 Mdot
.45762 .01636 Mdot
.45764 .01532 Mdot
.45767 .0152 Mdot
.45769 .01535 Mdot
.45772 .01543 Mdot
.45775 .01584 Mdot
.45777 .01599 Mdot
.4578 .01635 Mdot
.45782 .01571 Mdot
.45785 .01542 Mdot
.45787 .01582 Mdot
.4579 .01539 Mdot
.45793 .01585 Mdot
.45795 .01547 Mdot
.45798 .01505 Mdot
.458 .01564 Mdot
.45803 .01598 Mdot
.45806 .01675 Mdot
.45808 .01619 Mdot
.45811 .01591 Mdot
.45813 .01624 Mdot
.45816 .01549 Mdot
.45818 .01557 Mdot
.45821 .01566 Mdot
.45824 .01522 Mdot
.45826 .01541 Mdot
.45829 .01573 Mdot
.45831 .01617 Mdot
.45834 .01571 Mdot
.45837 .01593 Mdot
.45839 .01495 Mdot
.45842 .01572 Mdot
.45844 .01494 Mdot
.45847 .01484 Mdot
.45849 .01574 Mdot
.45852 .01524 Mdot
.45855 .01538 Mdot
.45857 .0157 Mdot
.4586 .01565 Mdot
.45862 .01591 Mdot
.45865 .01532 Mdot
.45868 .01492 Mdot
.4587 .01519 Mdot
.45873 .0155 Mdot
.45875 .0155 Mdot
.45878 .01548 Mdot
.4588 .01572 Mdot
.45883 .0151 Mdot
.45886 .01503 Mdot
.45888 .01632 Mdot
.45891 .01584 Mdot
.45893 .0161 Mdot
.45896 .01516 Mdot
.45899 .01554 Mdot
.45901 .015 Mdot
.45904 .01593 Mdot
.45906 .01631 Mdot
.45909 .01548 Mdot
.45912 .01574 Mdot
.45914 .01587 Mdot
.45917 .01576 Mdot
.45919 .01709 Mdot
.45922 .01563 Mdot
.45924 .01575 Mdot
.45927 .01531 Mdot
.4593 .0154 Mdot
.45932 .01594 Mdot
.45935 .01703 Mdot
.45937 .01596 Mdot
.4594 .01576 Mdot
.45943 .01528 Mdot
.45945 .01527 Mdot
.45948 .01547 Mdot
.4595 .01522 Mdot
.45953 .01546 Mdot
.45955 .01496 Mdot
.45958 .01537 Mdot
.45961 .01558 Mdot
.45963 .01514 Mdot
.45966 .01545 Mdot
.45968 .01575 Mdot
.45971 .01622 Mdot
.45974 .01609 Mdot
.45976 .01643 Mdot
.45979 .01491 Mdot
.45981 .01651 Mdot
.45984 .01584 Mdot
.45986 .0151 Mdot
.45989 .01516 Mdot
.45992 .01494 Mdot
.45994 .01582 Mdot
.45997 .01514 Mdot
.45999 .01636 Mdot
.46002 .0151 Mdot
.46005 .01641 Mdot
.46007 .01659 Mdot
.4601 .01562 Mdot
.46012 .01646 Mdot
.46015 .01707 Mdot
.46017 .01599 Mdot
.4602 .01589 Mdot
.46023 .01562 Mdot
.46025 .01506 Mdot
.46028 .01582 Mdot
.4603 .0152 Mdot
.46033 .0156 Mdot
.46036 .01537 Mdot
.46038 .01564 Mdot
.46041 .01578 Mdot
.46043 .01508 Mdot
.46046 .01507 Mdot
.46048 .01613 Mdot
.46051 .0161 Mdot
.46054 .01559 Mdot
.46056 .01475 Mdot
.46059 .01606 Mdot
.46061 .01508 Mdot
.46064 .01605 Mdot
.46067 .01516 Mdot
.46069 .01607 Mdot
.46072 .01583 Mdot
.46074 .01558 Mdot
.46077 .01596 Mdot
.46079 .01582 Mdot
.46082 .0158 Mdot
.46085 .01612 Mdot
.46087 .01612 Mdot
.4609 .01559 Mdot
.46092 .01633 Mdot
.46095 .01604 Mdot
.46098 .01556 Mdot
.461 .01512 Mdot
.46103 .01509 Mdot
.46105 .01529 Mdot
.46108 .01592 Mdot
.4611 .0154 Mdot
.46113 .01548 Mdot
.46116 .01521 Mdot
.46118 .01539 Mdot
.46121 .01502 Mdot
.46123 .01495 Mdot
.46126 .0166 Mdot
.46129 .01675 Mdot
.46131 .01647 Mdot
.46134 .01596 Mdot
.46136 .01628 Mdot
.46139 .01525 Mdot
.46141 .01685 Mdot
.46144 .01473 Mdot
.46147 .01529 Mdot
.46149 .01502 Mdot
.46152 .01559 Mdot
.46154 .015 Mdot
.46157 .01488 Mdot
.4616 .01562 Mdot
.46162 .01522 Mdot
.46165 .01509 Mdot
.46167 .01565 Mdot
.4617 .01658 Mdot
.46172 .01564 Mdot
.46175 .01548 Mdot
.46178 .01517 Mdot
.4618 .01484 Mdot
.46183 .01572 Mdot
.46185 .01499 Mdot
.46188 .01522 Mdot
.46191 .01562 Mdot
.46193 .01523 Mdot
.46196 .01559 Mdot
.46198 .01493 Mdot
.46201 .01568 Mdot
.46203 .01556 Mdot
.46206 .01584 Mdot
.46209 .01527 Mdot
.46211 .01703 Mdot
.46214 .01593 Mdot
.46216 .01583 Mdot
.46219 .01558 Mdot
.46222 .01559 Mdot
.46224 .01566 Mdot
.46227 .0166 Mdot
.46229 .01537 Mdot
.46232 .01629 Mdot
.46234 .01533 Mdot
.46237 .01568 Mdot
.4624 .01525 Mdot
.46242 .01545 Mdot
.46245 .01557 Mdot
.46247 .01575 Mdot
.4625 .01572 Mdot
.46253 .01509 Mdot
.46255 .01529 Mdot
.46258 .01571 Mdot
.4626 .01523 Mdot
.46263 .01503 Mdot
.46265 .01571 Mdot
.46268 .01565 Mdot
.46271 .01618 Mdot
.46273 .01631 Mdot
.46276 .01521 Mdot
.46278 .01494 Mdot
.46281 .01524 Mdot
.46284 .01577 Mdot
.46286 .01638 Mdot
.46289 .01577 Mdot
.46291 .01618 Mdot
.46294 .01514 Mdot
.46296 .01568 Mdot
.46299 .01682 Mdot
.46302 .01682 Mdot
.46304 .01561 Mdot
.46307 .01505 Mdot
.46309 .015 Mdot
.46312 .01626 Mdot
.46315 .01657 Mdot
.46317 .01567 Mdot
.4632 .01501 Mdot
.46322 .01513 Mdot
.46325 .01587 Mdot
.46327 .01566 Mdot
.4633 .01544 Mdot
.46333 .01548 Mdot
.46335 .01527 Mdot
.46338 .01561 Mdot
.4634 .01623 Mdot
.46343 .01514 Mdot
.46346 .0155 Mdot
.46348 .01634 Mdot
.46351 .01569 Mdot
.46353 .01551 Mdot
.46356 .01518 Mdot
.46358 .01492 Mdot
.46361 .01626 Mdot
.46364 .01575 Mdot
.46366 .01669 Mdot
.46369 .01496 Mdot
.46371 .01596 Mdot
.46374 .01499 Mdot
.46377 .01545 Mdot
.46379 .0159 Mdot
.46382 .01635 Mdot
.46384 .01568 Mdot
.46387 .01541 Mdot
.46389 .01548 Mdot
.46392 .01663 Mdot
.46395 .01546 Mdot
.46397 .01715 Mdot
.464 .01536 Mdot
.46402 .01529 Mdot
.46405 .01483 Mdot
.46408 .01522 Mdot
.4641 .01491 Mdot
.46413 .01622 Mdot
.46415 .01584 Mdot
.46418 .01531 Mdot
.4642 .01636 Mdot
.46423 .01509 Mdot
.46426 .01608 Mdot
.46428 .01536 Mdot
.46431 .01579 Mdot
.46433 .01548 Mdot
.46436 .01504 Mdot
.46439 .01623 Mdot
.46441 .01505 Mdot
.46444 .01534 Mdot
.46446 .01589 Mdot
.46449 .01582 Mdot
.46451 .01517 Mdot
.46454 .01558 Mdot
.46457 .01534 Mdot
.46459 .01552 Mdot
.46462 .01565 Mdot
.46464 .01614 Mdot
.46467 .01559 Mdot
.4647 .01578 Mdot
.46472 .01561 Mdot
.46475 .01732 Mdot
.46477 .01607 Mdot
.4648 .01539 Mdot
.46482 .01529 Mdot
.46485 .01653 Mdot
.46488 .01496 Mdot
.4649 .01613 Mdot
.46493 .01697 Mdot
.46495 .01572 Mdot
.46498 .016 Mdot
.46501 .01645 Mdot
.46503 .01504 Mdot
.46506 .01612 Mdot
.46508 .01554 Mdot
.46511 .01531 Mdot
.46513 .01627 Mdot
.46516 .01498 Mdot
.46519 .01575 Mdot
.46521 .01514 Mdot
.46524 .01534 Mdot
.46526 .01503 Mdot
.46529 .01541 Mdot
.46532 .01567 Mdot
.46534 .01619 Mdot
.46537 .01646 Mdot
.46539 .01541 Mdot
.46542 .01549 Mdot
.46544 .01543 Mdot
.46547 .01535 Mdot
.4655 .01499 Mdot
.46552 .01606 Mdot
.46555 .01651 Mdot
.46557 .01596 Mdot
.4656 .016 Mdot
.46563 .01584 Mdot
.46565 .01523 Mdot
.46568 .01538 Mdot
.4657 .01539 Mdot
.46573 .01537 Mdot
.46575 .01519 Mdot
.46578 .01498 Mdot
.46581 .01485 Mdot
.46583 .01552 Mdot
.46586 .01513 Mdot
.46588 .01504 Mdot
.46591 .01665 Mdot
.46594 .01641 Mdot
.46596 .01556 Mdot
.46599 .01581 Mdot
.46601 .01525 Mdot
.46604 .01586 Mdot
.46606 .01545 Mdot
.46609 .01582 Mdot
.46612 .01526 Mdot
.46614 .01511 Mdot
.46617 .01592 Mdot
.46619 .0157 Mdot
.46622 .01567 Mdot
.46625 .01531 Mdot
.46627 .01615 Mdot
.4663 .01513 Mdot
.46632 .01553 Mdot
.46635 .01657 Mdot
.46637 .01643 Mdot
.4664 .01619 Mdot
.46643 .01588 Mdot
.46645 .01513 Mdot
.46648 .01595 Mdot
.4665 .01491 Mdot
.46653 .01655 Mdot
.46656 .01584 Mdot
.46658 .0151 Mdot
.46661 .01555 Mdot
.46663 .01561 Mdot
.46666 .01579 Mdot
.46668 .01549 Mdot
.46671 .01592 Mdot
.46674 .01549 Mdot
.46676 .01544 Mdot
.46679 .01563 Mdot
.46681 .0154 Mdot
.46684 .01557 Mdot
.46687 .01663 Mdot
.46689 .01541 Mdot
.46692 .01524 Mdot
.46694 .01621 Mdot
.46697 .015 Mdot
.46699 .01644 Mdot
.46702 .01504 Mdot
.46705 .01491 Mdot
.46707 .01514 Mdot
.4671 .01582 Mdot
.46712 .01535 Mdot
.46715 .01539 Mdot
.46718 .01589 Mdot
.4672 .01508 Mdot
.46723 .01529 Mdot
.46725 .01592 Mdot
.46728 .0153 Mdot
.4673 .01529 Mdot
.46733 .01546 Mdot
.46736 .01613 Mdot
.46738 .01606 Mdot
.46741 .0157 Mdot
.46743 .01545 Mdot
.46746 .01482 Mdot
.46749 .01617 Mdot
.46751 .0151 Mdot
.46754 .01577 Mdot
.46756 .01553 Mdot
.46759 .01534 Mdot
.46761 .01523 Mdot
.46764 .01493 Mdot
.46767 .01671 Mdot
.46769 .01631 Mdot
.46772 .01624 Mdot
.46774 .01497 Mdot
.46777 .01548 Mdot
.4678 .01718 Mdot
.46782 .01558 Mdot
.46785 .01562 Mdot
.46787 .01613 Mdot
.4679 .01521 Mdot
.46792 .01579 Mdot
.46795 .01551 Mdot
.46798 .01611 Mdot
.468 .01531 Mdot
.46803 .0164 Mdot
.46805 .01512 Mdot
.46808 .01533 Mdot
.46811 .01534 Mdot
.46813 .01533 Mdot
.46816 .0159 Mdot
.46818 .01545 Mdot
.46821 .01582 Mdot
.46824 .01512 Mdot
.46826 .01561 Mdot
.46829 .01582 Mdot
.46831 .01499 Mdot
.46834 .01499 Mdot
.46836 .01584 Mdot
.46839 .01492 Mdot
.46842 .01488 Mdot
.46844 .01538 Mdot
.46847 .0152 Mdot
.46849 .01572 Mdot
.46852 .0158 Mdot
.46855 .01591 Mdot
.46857 .01543 Mdot
.4686 .01583 Mdot
.46862 .01494 Mdot
.46865 .01578 Mdot
.46867 .01516 Mdot
.4687 .01507 Mdot
.46873 .01542 Mdot
.46875 .01537 Mdot
.46878 .01634 Mdot
.4688 .01599 Mdot
.46883 .01516 Mdot
.46886 .016 Mdot
.46888 .01535 Mdot
.46891 .01492 Mdot
.46893 .01621 Mdot
.46896 .01559 Mdot
.46898 .01576 Mdot
.46901 .01617 Mdot
.46904 .01601 Mdot
.46906 .01568 Mdot
.46909 .01515 Mdot
.46911 .01541 Mdot
.46914 .01553 Mdot
.46917 .01598 Mdot
.46919 .01521 Mdot
.46922 .01604 Mdot
.46924 .0155 Mdot
.46927 .01515 Mdot
.46929 .015 Mdot
.46932 .01533 Mdot
.46935 .01542 Mdot
.46937 .0162 Mdot
.4694 .01521 Mdot
.46942 .01532 Mdot
.46945 .01525 Mdot
.46948 .01494 Mdot
.4695 .01635 Mdot
.46953 .01551 Mdot
.46955 .01565 Mdot
.46958 .01613 Mdot
.4696 .01705 Mdot
.46963 .01619 Mdot
.46966 .01597 Mdot
.46968 .01495 Mdot
.46971 .01563 Mdot
.46973 .01502 Mdot
.46976 .0163 Mdot
.46979 .01616 Mdot
.46981 .01582 Mdot
.46984 .01475 Mdot
.46986 .01592 Mdot
.46989 .01495 Mdot
.46991 .01509 Mdot
.46994 .01539 Mdot
.46997 .01559 Mdot
.46999 .01623 Mdot
.47002 .01595 Mdot
.47004 .01707 Mdot
.47007 .01529 Mdot
.4701 .0159 Mdot
.47012 .0152 Mdot
.47015 .01555 Mdot
.47017 .01506 Mdot
.4702 .01557 Mdot
.47022 .01558 Mdot
.47025 .01568 Mdot
.47028 .01567 Mdot
.4703 .01507 Mdot
.47033 .01566 Mdot
.47035 .01547 Mdot
.47038 .01612 Mdot
.47041 .01591 Mdot
.47043 .01483 Mdot
.47046 .01651 Mdot
.47048 .01536 Mdot
.47051 .01594 Mdot
.47053 .01639 Mdot
.47056 .01606 Mdot
.47059 .01565 Mdot
.47061 .01593 Mdot
.47064 .01578 Mdot
.47066 .01536 Mdot
.47069 .0158 Mdot
.47072 .01569 Mdot
.47074 .01568 Mdot
.47077 .0152 Mdot
.47079 .01511 Mdot
.47082 .01512 Mdot
.47084 .01532 Mdot
.47087 .01562 Mdot
.4709 .0152 Mdot
.47092 .01492 Mdot
.47095 .01539 Mdot
.47097 .01632 Mdot
.471 .01525 Mdot
.47103 .01608 Mdot
.47105 .01579 Mdot
.47108 .01556 Mdot
.4711 .01548 Mdot
.47113 .01504 Mdot
.47115 .01554 Mdot
.47118 .01576 Mdot
.47121 .01543 Mdot
.47123 .01549 Mdot
.47126 .01641 Mdot
.47128 .01645 Mdot
.47131 .01637 Mdot
.47134 .0151 Mdot
.47136 .01516 Mdot
.47139 .01534 Mdot
.47141 .01476 Mdot
.47144 .0152 Mdot
.47146 .01549 Mdot
.47149 .01595 Mdot
.47152 .01519 Mdot
.47154 .01572 Mdot
.47157 .01567 Mdot
.47159 .0152 Mdot
.47162 .0157 Mdot
.47165 .01518 Mdot
.47167 .01569 Mdot
.4717 .01493 Mdot
.47172 .01531 Mdot
.47175 .01511 Mdot
.47177 .01483 Mdot
.4718 .01517 Mdot
.47183 .01534 Mdot
.47185 .01486 Mdot
.47188 .01514 Mdot
.4719 .01658 Mdot
.47193 .016 Mdot
.47196 .01575 Mdot
.47198 .01616 Mdot
.47201 .01606 Mdot
.47203 .01509 Mdot
.47206 .01493 Mdot
.47208 .01575 Mdot
.47211 .0152 Mdot
.47214 .0158 Mdot
.47216 .01574 Mdot
.47219 .01569 Mdot
.47221 .01537 Mdot
.47224 .01543 Mdot
.47227 .01602 Mdot
.47229 .01591 Mdot
.47232 .0157 Mdot
.47234 .01549 Mdot
.47237 .016 Mdot
.47239 .01571 Mdot
.47242 .0152 Mdot
.47245 .01596 Mdot
.47247 .01566 Mdot
.4725 .0161 Mdot
.47252 .01533 Mdot
.47255 .01603 Mdot
.47258 .01527 Mdot
.4726 .01519 Mdot
.47263 .01729 Mdot
.47265 .01512 Mdot
.47268 .01484 Mdot
.4727 .01575 Mdot
.47273 .01555 Mdot
.47276 .01567 Mdot
.47278 .01488 Mdot
.47281 .01493 Mdot
.47283 .01538 Mdot
.47286 .01494 Mdot
.47289 .01525 Mdot
.47291 .01628 Mdot
.47294 .0155 Mdot
.47296 .01573 Mdot
.47299 .01589 Mdot
.47301 .01549 Mdot
.47304 .01569 Mdot
.47307 .01578 Mdot
.47309 .01533 Mdot
.47312 .01552 Mdot
.47314 .01556 Mdot
.47317 .01533 Mdot
.4732 .01481 Mdot
.47322 .01526 Mdot
.47325 .01506 Mdot
.47327 .01522 Mdot
.4733 .01528 Mdot
.47332 .01616 Mdot
.47335 .01505 Mdot
.47338 .01533 Mdot
.4734 .01483 Mdot
.47343 .0158 Mdot
.47345 .01528 Mdot
.47348 .01663 Mdot
.47351 .0152 Mdot
.47353 .01605 Mdot
.47356 .01552 Mdot
.47358 .01586 Mdot
.47361 .01626 Mdot
.47363 .01639 Mdot
.47366 .0166 Mdot
.47369 .01499 Mdot
.47371 .01582 Mdot
.47374 .01565 Mdot
.47376 .01631 Mdot
.47379 .01551 Mdot
.47382 .01507 Mdot
.47384 .01511 Mdot
.47387 .01654 Mdot
.47389 .01583 Mdot
.47392 .01553 Mdot
.47394 .01501 Mdot
.47397 .01551 Mdot
.474 .01551 Mdot
.47402 .01534 Mdot
.47405 .01631 Mdot
.47407 .01576 Mdot
.4741 .01556 Mdot
.47413 .01585 Mdot
.47415 .01498 Mdot
.47418 .01484 Mdot
.4742 .01605 Mdot
.47423 .01572 Mdot
.47425 .01586 Mdot
.47428 .0165 Mdot
.47431 .01557 Mdot
.47433 .01473 Mdot
.47436 .01514 Mdot
.47438 .01503 Mdot
.47441 .01596 Mdot
.47444 .0155 Mdot
.47446 .01587 Mdot
.47449 .01628 Mdot
.47451 .01567 Mdot
.47454 .01562 Mdot
.47456 .01516 Mdot
.47459 .01503 Mdot
.47462 .01613 Mdot
.47464 .01562 Mdot
.47467 .01542 Mdot
.47469 .01536 Mdot
.47472 .01537 Mdot
.47475 .01552 Mdot
.47477 .01591 Mdot
.4748 .01604 Mdot
.47482 .01514 Mdot
.47485 .01637 Mdot
.47487 .01612 Mdot
.4749 .01683 Mdot
.47493 .01601 Mdot
.47495 .01639 Mdot
.47498 .01538 Mdot
.475 .01548 Mdot
.47503 .01574 Mdot
.47506 .01569 Mdot
.47508 .01633 Mdot
.47511 .01681 Mdot
.47513 .01642 Mdot
.47516 .0153 Mdot
.47518 .01524 Mdot
.47521 .01486 Mdot
.47524 .01547 Mdot
.47526 .01528 Mdot
.47529 .01498 Mdot
.47531 .01557 Mdot
.47534 .01546 Mdot
.47537 .01593 Mdot
.47539 .01657 Mdot
.47542 .01635 Mdot
.47544 .01522 Mdot
.47547 .01518 Mdot
.47549 .01492 Mdot
.47552 .01649 Mdot
.47555 .01549 Mdot
.47557 .01524 Mdot
.4756 .01515 Mdot
.47562 .01489 Mdot
.47565 .01616 Mdot
.47568 .01535 Mdot
.4757 .01517 Mdot
.47573 .01594 Mdot
.47575 .01533 Mdot
.47578 .01613 Mdot
.4758 .01501 Mdot
.47583 .01522 Mdot
.47586 .01482 Mdot
.47588 .01534 Mdot
.47591 .01602 Mdot
.47593 .0154 Mdot
.47596 .01541 Mdot
.47599 .01589 Mdot
.47601 .01636 Mdot
.47604 .01618 Mdot
.47606 .01575 Mdot
.47609 .01595 Mdot
.47611 .01516 Mdot
.47614 .01528 Mdot
.47617 .01529 Mdot
.47619 .01507 Mdot
.47622 .01474 Mdot
.47624 .01536 Mdot
.47627 .01612 Mdot
.4763 .01531 Mdot
.47632 .01499 Mdot
.47635 .01519 Mdot
.47637 .01501 Mdot
.4764 .015 Mdot
.47642 .01506 Mdot
.47645 .01476 Mdot
.47648 .01569 Mdot
.4765 .01591 Mdot
.47653 .01644 Mdot
.47655 .01649 Mdot
.47658 .01553 Mdot
.47661 .01577 Mdot
.47663 .01541 Mdot
.47666 .01527 Mdot
.47668 .01532 Mdot
.47671 .01647 Mdot
.47673 .01593 Mdot
.47676 .01519 Mdot
.47679 .01576 Mdot
.47681 .01515 Mdot
.47684 .01563 Mdot
.47686 .01649 Mdot
.47689 .01484 Mdot
.47692 .01561 Mdot
.47694 .01508 Mdot
.47697 .01552 Mdot
.47699 .01556 Mdot
.47702 .0148 Mdot
.47704 .01557 Mdot
.47707 .01524 Mdot
.4771 .01585 Mdot
.47712 .01624 Mdot
.47715 .01534 Mdot
.47717 .01511 Mdot
.4772 .01604 Mdot
.47723 .01624 Mdot
.47725 .01541 Mdot
.47728 .0151 Mdot
.4773 .01544 Mdot
.47733 .01536 Mdot
.47736 .01528 Mdot
.47738 .01583 Mdot
.47741 .01505 Mdot
.47743 .01515 Mdot
.47746 .01528 Mdot
.47748 .0161 Mdot
.47751 .01476 Mdot
.47754 .01662 Mdot
.47756 .01524 Mdot
.47759 .01527 Mdot
.47761 .0155 Mdot
.47764 .01559 Mdot
.47767 .01513 Mdot
.47769 .01573 Mdot
.47772 .01573 Mdot
.47774 .0156 Mdot
.47777 .01598 Mdot
.47779 .01578 Mdot
.47782 .01594 Mdot
.47785 .0165 Mdot
.47787 .01634 Mdot
.4779 .01624 Mdot
.47792 .01528 Mdot
.47795 .01555 Mdot
.47798 .01525 Mdot
.478 .01632 Mdot
.47803 .01515 Mdot
.47805 .01508 Mdot
.47808 .01561 Mdot
.4781 .01647 Mdot
.47813 .01526 Mdot
.47816 .01492 Mdot
.47818 .01559 Mdot
.47821 .01618 Mdot
.47823 .01578 Mdot
.47826 .01528 Mdot
.47829 .0158 Mdot
.47831 .01574 Mdot
.47834 .01558 Mdot
.47836 .01569 Mdot
.47839 .01527 Mdot
.47841 .0161 Mdot
.47844 .01539 Mdot
.47847 .01521 Mdot
.47849 .0155 Mdot
.47852 .01533 Mdot
.47854 .01549 Mdot
.47857 .01568 Mdot
.4786 .01529 Mdot
.47862 .01531 Mdot
.47865 .01596 Mdot
.47867 .01642 Mdot
.4787 .01522 Mdot
.47872 .01512 Mdot
.47875 .01563 Mdot
.47878 .01589 Mdot
.4788 .01567 Mdot
.47883 .01678 Mdot
.47885 .01673 Mdot
.47888 .01593 Mdot
.47891 .01657 Mdot
.47893 .01524 Mdot
.47896 .01538 Mdot
.47898 .01588 Mdot
.47901 .01541 Mdot
.47903 .01573 Mdot
.47906 .01536 Mdot
.47909 .01614 Mdot
.47911 .01546 Mdot
.47914 .016 Mdot
.47916 .01523 Mdot
.47919 .01506 Mdot
.47922 .01573 Mdot
.47924 .01586 Mdot
.47927 .01722 Mdot
.47929 .01526 Mdot
.47932 .01612 Mdot
.47934 .01577 Mdot
.47937 .01604 Mdot
.4794 .0152 Mdot
.47942 .0148 Mdot
.47945 .01557 Mdot
.47947 .01515 Mdot
.4795 .01528 Mdot
.47953 .01559 Mdot
.47955 .01491 Mdot
.47958 .0158 Mdot
.4796 .01564 Mdot
.47963 .01489 Mdot
.47965 .01545 Mdot
.47968 .01553 Mdot
.47971 .01503 Mdot
.47973 .01618 Mdot
.47976 .01611 Mdot
.47978 .01544 Mdot
.47981 .01547 Mdot
.47984 .01638 Mdot
.47986 .01598 Mdot
.47989 .01561 Mdot
.47991 .0152 Mdot
.47994 .01664 Mdot
.47996 .01554 Mdot
.47999 .01528 Mdot
.48002 .01612 Mdot
.48004 .01596 Mdot
.48007 .01593 Mdot
.48009 .01609 Mdot
.48012 .01644 Mdot
.48015 .01601 Mdot
.48017 .01518 Mdot
.4802 .01522 Mdot
.48022 .01615 Mdot
.48025 .01538 Mdot
.48027 .01535 Mdot
.4803 .01686 Mdot
.48033 .01517 Mdot
.48035 .01509 Mdot
.48038 .01631 Mdot
.4804 .01542 Mdot
.48043 .01671 Mdot
.48046 .01586 Mdot
.48048 .01537 Mdot
.48051 .01572 Mdot
.48053 .01575 Mdot
.48056 .01554 Mdot
.48058 .01626 Mdot
.48061 .01523 Mdot
.48064 .01516 Mdot
.48066 .01562 Mdot
.48069 .01487 Mdot
.48071 .01543 Mdot
.48074 .01578 Mdot
.48077 .01557 Mdot
.48079 .01539 Mdot
.48082 .01523 Mdot
.48084 .01579 Mdot
.48087 .01543 Mdot
.48089 .0159 Mdot
.48092 .01538 Mdot
.48095 .01509 Mdot
.48097 .01597 Mdot
.481 .01489 Mdot
.48102 .01589 Mdot
.48105 .01629 Mdot
.48108 .01605 Mdot
.4811 .01543 Mdot
.48113 .01536 Mdot
.48115 .01532 Mdot
.48118 .01532 Mdot
.4812 .01576 Mdot
.48123 .01547 Mdot
.48126 .01597 Mdot
.48128 .01503 Mdot
.48131 .01619 Mdot
.48133 .01522 Mdot
.48136 .01499 Mdot
.48139 .0157 Mdot
.48141 .01662 Mdot
.48144 .01486 Mdot
.48146 .01592 Mdot
.48149 .01519 Mdot
.48151 .01555 Mdot
.48154 .01538 Mdot
.48157 .01614 Mdot
.48159 .01585 Mdot
.48162 .0152 Mdot
.48164 .01635 Mdot
.48167 .01699 Mdot
.4817 .01494 Mdot
.48172 .01489 Mdot
.48175 .01502 Mdot
.48177 .01605 Mdot
.4818 .0153 Mdot
.48182 .01553 Mdot
.48185 .0154 Mdot
.48188 .01531 Mdot
.4819 .01496 Mdot
.48193 .01519 Mdot
.48195 .01479 Mdot
.48198 .01522 Mdot
.48201 .01573 Mdot
.48203 .0156 Mdot
.48206 .01515 Mdot
.48208 .01548 Mdot
.48211 .01506 Mdot
.48213 .01639 Mdot
.48216 .01645 Mdot
.48219 .01508 Mdot
.48221 .0155 Mdot
.48224 .01584 Mdot
.48226 .01553 Mdot
.48229 .01554 Mdot
.48232 .01541 Mdot
.48234 .01616 Mdot
.48237 .01598 Mdot
.48239 .01527 Mdot
.48242 .01583 Mdot
.48244 .01544 Mdot
.48247 .01546 Mdot
.4825 .01722 Mdot
.48252 .01641 Mdot
.48255 .0155 Mdot
.48257 .01536 Mdot
.4826 .01564 Mdot
.48263 .01513 Mdot
.48265 .01537 Mdot
.48268 .01576 Mdot
.4827 .01494 Mdot
.48273 .01604 Mdot
.48275 .01512 Mdot
.48278 .01618 Mdot
.48281 .01562 Mdot
.48283 .01482 Mdot
.48286 .01628 Mdot
.48288 .01516 Mdot
.48291 .01563 Mdot
.48294 .01553 Mdot
.48296 .01528 Mdot
.48299 .01574 Mdot
.48301 .01638 Mdot
.48304 .01547 Mdot
.48306 .01524 Mdot
.48309 .01542 Mdot
.48312 .01637 Mdot
.48314 .01595 Mdot
.48317 .01624 Mdot
.48319 .0158 Mdot
.48322 .0151 Mdot
.48325 .01565 Mdot
.48327 .01602 Mdot
.4833 .015 Mdot
.48332 .01529 Mdot
.48335 .01573 Mdot
.48337 .01541 Mdot
.4834 .01589 Mdot
.48343 .01576 Mdot
.48345 .01531 Mdot
.48348 .01612 Mdot
.4835 .0155 Mdot
.48353 .01632 Mdot
.48356 .01539 Mdot
.48358 .01583 Mdot
.48361 .0157 Mdot
.48363 .01617 Mdot
.48366 .01533 Mdot
.48368 .01552 Mdot
.48371 .01542 Mdot
.48374 .01537 Mdot
.48376 .01475 Mdot
.48379 .01587 Mdot
.48381 .01573 Mdot
.48384 .01509 Mdot
.48387 .01578 Mdot
.48389 .01516 Mdot
.48392 .01564 Mdot
.48394 .01626 Mdot
.48397 .01553 Mdot
.48399 .01556 Mdot
.48402 .01593 Mdot
.48405 .01492 Mdot
.48407 .01692 Mdot
.4841 .01478 Mdot
.48412 .01499 Mdot
.48415 .01486 Mdot
.48418 .01487 Mdot
.4842 .01632 Mdot
.48423 .01634 Mdot
.48425 .01548 Mdot
.48428 .01526 Mdot
.4843 .01544 Mdot
.48433 .01545 Mdot
.48436 .0156 Mdot
.48438 .01564 Mdot
.48441 .01536 Mdot
.48443 .01482 Mdot
.48446 .01579 Mdot
.48449 .01582 Mdot
.48451 .0158 Mdot
.48454 .01518 Mdot
.48456 .01567 Mdot
.48459 .01634 Mdot
.48461 .01516 Mdot
.48464 .01571 Mdot
.48467 .01491 Mdot
.48469 .01573 Mdot
.48472 .01537 Mdot
.48474 .01562 Mdot
.48477 .01575 Mdot
.4848 .01547 Mdot
.48482 .01603 Mdot
.48485 .01602 Mdot
.48487 .01534 Mdot
.4849 .01582 Mdot
.48492 .01594 Mdot
.48495 .0155 Mdot
.48498 .01565 Mdot
.485 .01489 Mdot
.48503 .01574 Mdot
.48505 .01521 Mdot
.48508 .01548 Mdot
.48511 .01608 Mdot
.48513 .01533 Mdot
.48516 .01487 Mdot
.48518 .01547 Mdot
.48521 .01515 Mdot
.48523 .01543 Mdot
.48526 .0161 Mdot
.48529 .0153 Mdot
.48531 .0148 Mdot
.48534 .01493 Mdot
.48536 .01523 Mdot
.48539 .01532 Mdot
.48542 .01523 Mdot
.48544 .01496 Mdot
.48547 .01589 Mdot
.48549 .01555 Mdot
.48552 .01605 Mdot
.48554 .01513 Mdot
.48557 .01498 Mdot
.4856 .01535 Mdot
.48562 .01649 Mdot
.48565 .01541 Mdot
.48567 .01575 Mdot
.4857 .01514 Mdot
.48573 .01585 Mdot
.48575 .01693 Mdot
.48578 .01619 Mdot
.4858 .01566 Mdot
.48583 .01568 Mdot
.48585 .01534 Mdot
.48588 .01524 Mdot
.48591 .01584 Mdot
.48593 .01554 Mdot
.48596 .01596 Mdot
.48598 .01602 Mdot
.48601 .01613 Mdot
.48604 .01524 Mdot
.48606 .01537 Mdot
.48609 .01594 Mdot
.48611 .01615 Mdot
.48614 .0155 Mdot
.48616 .01593 Mdot
.48619 .01492 Mdot
.48622 .01494 Mdot
.48624 .01548 Mdot
.48627 .01528 Mdot
.48629 .016 Mdot
.48632 .01525 Mdot
.48635 .01497 Mdot
.48637 .01514 Mdot
.4864 .01591 Mdot
.48642 .01517 Mdot
.48645 .01581 Mdot
.48648 .0162 Mdot
.4865 .01647 Mdot
.48653 .01509 Mdot
.48655 .01485 Mdot
.48658 .01545 Mdot
.4866 .01524 Mdot
.48663 .01542 Mdot
.48666 .01536 Mdot
.48668 .01509 Mdot
.48671 .01561 Mdot
.48673 .01564 Mdot
.48676 .01577 Mdot
.48679 .01562 Mdot
.48681 .01577 Mdot
.48684 .01668 Mdot
.48686 .01552 Mdot
.48689 .01547 Mdot
.48691 .01523 Mdot
.48694 .01529 Mdot
.48697 .01608 Mdot
.48699 .01536 Mdot
.48702 .01567 Mdot
.48704 .015 Mdot
.48707 .01552 Mdot
.4871 .01573 Mdot
.48712 .01572 Mdot
.48715 .01592 Mdot
.48717 .01572 Mdot
.4872 .01503 Mdot
.48722 .0154 Mdot
.48725 .01522 Mdot
.48728 .01567 Mdot
.4873 .01505 Mdot
.48733 .01518 Mdot
.48735 .01557 Mdot
.48738 .01586 Mdot
.48741 .01519 Mdot
.48743 .01581 Mdot
.48746 .01589 Mdot
.48748 .01547 Mdot
.48751 .01592 Mdot
.48753 .01572 Mdot
.48756 .01698 Mdot
.48759 .01616 Mdot
.48761 .01499 Mdot
.48764 .01575 Mdot
.48766 .01601 Mdot
.48769 .01575 Mdot
.48772 .01506 Mdot
.48774 .01539 Mdot
.48777 .01479 Mdot
.48779 .01609 Mdot
.48782 .01503 Mdot
.48784 .01566 Mdot
.48787 .01607 Mdot
.4879 .01494 Mdot
.48792 .01608 Mdot
.48795 .01548 Mdot
.48797 .016 Mdot
.488 .01621 Mdot
.48803 .01582 Mdot
.48805 .01532 Mdot
.48808 .01598 Mdot
.4881 .01544 Mdot
.48813 .01538 Mdot
.48815 .01503 Mdot
.48818 .01556 Mdot
.48821 .01514 Mdot
.48823 .01498 Mdot
.48826 .01497 Mdot
.48828 .01592 Mdot
.48831 .01655 Mdot
.48834 .01583 Mdot
.48836 .01495 Mdot
.48839 .0157 Mdot
.48841 .01565 Mdot
.48844 .01578 Mdot
.48846 .01519 Mdot
.48849 .01579 Mdot
.48852 .01577 Mdot
.48854 .01604 Mdot
.48857 .01539 Mdot
.48859 .01581 Mdot
.48862 .01571 Mdot
.48865 .01592 Mdot
.48867 .01562 Mdot
.4887 .01512 Mdot
.48872 .01503 Mdot
.48875 .01653 Mdot
.48877 .01693 Mdot
.4888 .01549 Mdot
.48883 .01625 Mdot
.48885 .01554 Mdot
.48888 .01579 Mdot
.4889 .01503 Mdot
.48893 .01544 Mdot
.48896 .01593 Mdot
.48898 .01718 Mdot
.48901 .01557 Mdot
.48903 .01579 Mdot
.48906 .01583 Mdot
.48908 .01558 Mdot
.48911 .01601 Mdot
.48914 .01566 Mdot
.48916 .01586 Mdot
.48919 .01636 Mdot
.48921 .01547 Mdot
.48924 .01546 Mdot
.48927 .01475 Mdot
.48929 .01522 Mdot
.48932 .01497 Mdot
.48934 .01582 Mdot
.48937 .01554 Mdot
.48939 .0161 Mdot
.48942 .01532 Mdot
.48945 .01521 Mdot
.48947 .01608 Mdot
.4895 .01564 Mdot
.48952 .01506 Mdot
.48955 .01544 Mdot
.48958 .01575 Mdot
.4896 .01646 Mdot
.48963 .01505 Mdot
.48965 .01584 Mdot
.48968 .01582 Mdot
.4897 .01512 Mdot
.48973 .01587 Mdot
.48976 .01606 Mdot
.48978 .01543 Mdot
.48981 .01575 Mdot
.48983 .01543 Mdot
.48986 .01553 Mdot
.48989 .01576 Mdot
.48991 .01524 Mdot
.48994 .0152 Mdot
.48996 .01506 Mdot
.48999 .01494 Mdot
.49001 .01661 Mdot
.49004 .01583 Mdot
.49007 .01578 Mdot
.49009 .01546 Mdot
.49012 .01571 Mdot
.49014 .01549 Mdot
.49017 .0159 Mdot
.4902 .01513 Mdot
.49022 .01517 Mdot
.49025 .01588 Mdot
.49027 .01519 Mdot
.4903 .01521 Mdot
.49032 .01598 Mdot
.49035 .01533 Mdot
.49038 .01583 Mdot
.4904 .01549 Mdot
.49043 .01604 Mdot
.49045 .01636 Mdot
.49048 .01582 Mdot
.49051 .01537 Mdot
.49053 .01527 Mdot
.49056 .01513 Mdot
.49058 .01515 Mdot
.49061 .01608 Mdot
.49063 .01628 Mdot
.49066 .0153 Mdot
.49069 .01578 Mdot
.49071 .0164 Mdot
.49074 .01568 Mdot
.49076 .0154 Mdot
.49079 .01542 Mdot
.49082 .0156 Mdot
.49084 .01481 Mdot
.49087 .01506 Mdot
.49089 .01549 Mdot
.49092 .015 Mdot
.49094 .01612 Mdot
.49097 .01505 Mdot
.491 .01662 Mdot
.49102 .01559 Mdot
.49105 .01521 Mdot
.49107 .01542 Mdot
.4911 .01548 Mdot
.49113 .01614 Mdot
.49115 .01508 Mdot
.49118 .01482 Mdot
.4912 .01547 Mdot
.49123 .01649 Mdot
.49125 .01642 Mdot
.49128 .01611 Mdot
.49131 .01595 Mdot
.49133 .01586 Mdot
.49136 .01588 Mdot
.49138 .01507 Mdot
.49141 .01534 Mdot
.49144 .01602 Mdot
.49146 .01543 Mdot
.49149 .01642 Mdot
.49151 .01544 Mdot
.49154 .01595 Mdot
.49156 .01508 Mdot
.49159 .01538 Mdot
.49162 .01628 Mdot
.49164 .01623 Mdot
.49167 .01546 Mdot
.49169 .016 Mdot
.49172 .01546 Mdot
.49175 .01571 Mdot
.49177 .0153 Mdot
.4918 .01529 Mdot
.49182 .01595 Mdot
.49185 .01493 Mdot
.49187 .01499 Mdot
.4919 .01499 Mdot
.49193 .01517 Mdot
.49195 .01568 Mdot
.49198 .01582 Mdot
.492 .0155 Mdot
.49203 .01639 Mdot
.49206 .01524 Mdot
.49208 .01512 Mdot
.49211 .01498 Mdot
.49213 .01552 Mdot
.49216 .01531 Mdot
.49218 .01538 Mdot
.49221 .01653 Mdot
.49224 .01564 Mdot
.49226 .01534 Mdot
.49229 .01533 Mdot
.49231 .0155 Mdot
.49234 .01512 Mdot
.49237 .01601 Mdot
.49239 .01509 Mdot
.49242 .0156 Mdot
.49244 .01537 Mdot
.49247 .01515 Mdot
.49249 .01506 Mdot
.49252 .01537 Mdot
.49255 .0154 Mdot
.49257 .01573 Mdot
.4926 .01583 Mdot
.49262 .015 Mdot
.49265 .01504 Mdot
.49268 .01541 Mdot
.4927 .01582 Mdot
.49273 .01652 Mdot
.49275 .01531 Mdot
.49278 .0163 Mdot
.4928 .01592 Mdot
.49283 .01554 Mdot
.49286 .01528 Mdot
.49288 .01581 Mdot
.49291 .01533 Mdot
.49293 .01685 Mdot
.49296 .01599 Mdot
.49299 .01559 Mdot
.49301 .01521 Mdot
.49304 .01585 Mdot
.49306 .01551 Mdot
.49309 .0151 Mdot
.49311 .01489 Mdot
.49314 .01516 Mdot
.49317 .01631 Mdot
.49319 .01581 Mdot
.49322 .01527 Mdot
.49324 .0157 Mdot
.49327 .01599 Mdot
.4933 .01491 Mdot
.49332 .01553 Mdot
.49335 .01632 Mdot
.49337 .0166 Mdot
.4934 .01598 Mdot
.49342 .01549 Mdot
.49345 .01523 Mdot
.49348 .0153 Mdot
.4935 .01601 Mdot
.49353 .01588 Mdot
.49355 .01538 Mdot
.49358 .0151 Mdot
.49361 .01531 Mdot
.49363 .01582 Mdot
.49366 .01581 Mdot
.49368 .01652 Mdot
.49371 .01492 Mdot
.49373 .01541 Mdot
.49376 .01634 Mdot
.49379 .01582 Mdot
.49381 .01553 Mdot
.49384 .01498 Mdot
.49386 .01612 Mdot
.49389 .01609 Mdot
.49392 .01514 Mdot
.49394 .01506 Mdot
.49397 .0152 Mdot
.49399 .0152 Mdot
.49402 .01597 Mdot
.49404 .01525 Mdot
.49407 .01492 Mdot
.4941 .01491 Mdot
.49412 .01617 Mdot
.49415 .01569 Mdot
.49417 .01512 Mdot
.4942 .01646 Mdot
.49423 .01559 Mdot
.49425 .0159 Mdot
.49428 .01646 Mdot
.4943 .01533 Mdot
.49433 .01623 Mdot
.49435 .01593 Mdot
.49438 .01611 Mdot
.49441 .01514 Mdot
.49443 .01538 Mdot
.49446 .01606 Mdot
.49448 .01635 Mdot
.49451 .01609 Mdot
.49454 .01639 Mdot
.49456 .01534 Mdot
.49459 .01636 Mdot
.49461 .01535 Mdot
.49464 .01514 Mdot
.49466 .01485 Mdot
.49469 .0151 Mdot
.49472 .01528 Mdot
.49474 .01559 Mdot
.49477 .01598 Mdot
.49479 .01618 Mdot
.49482 .01535 Mdot
.49485 .01523 Mdot
.49487 .01555 Mdot
.4949 .01525 Mdot
.49492 .01522 Mdot
.49495 .01661 Mdot
.49497 .01519 Mdot
.495 .01606 Mdot
.49503 .01506 Mdot
.49505 .01577 Mdot
.49508 .01503 Mdot
.4951 .01551 Mdot
.49513 .01529 Mdot
.49516 .01558 Mdot
.49518 .01578 Mdot
.49521 .01544 Mdot
.49523 .0154 Mdot
.49526 .01527 Mdot
.49528 .0154 Mdot
.49531 .01587 Mdot
.49534 .01599 Mdot
.49536 .01538 Mdot
.49539 .01547 Mdot
.49541 .01513 Mdot
.49544 .01583 Mdot
.49547 .01622 Mdot
.49549 .016 Mdot
.49552 .01504 Mdot
.49554 .01536 Mdot
.49557 .01599 Mdot
.4956 .01563 Mdot
.49562 .0156 Mdot
.49565 .01642 Mdot
.49567 .01531 Mdot
.4957 .01561 Mdot
.49572 .01557 Mdot
.49575 .0157 Mdot
.49578 .01563 Mdot
.4958 .01578 Mdot
.49583 .01552 Mdot
.49585 .01634 Mdot
.49588 .0152 Mdot
.49591 .01601 Mdot
.49593 .01544 Mdot
.49596 .01517 Mdot
.49598 .01524 Mdot
.49601 .01652 Mdot
.49603 .01699 Mdot
.49606 .01568 Mdot
.49609 .01491 Mdot
.49611 .01481 Mdot
.49614 .01585 Mdot
.49616 .0154 Mdot
.49619 .01493 Mdot
.49622 .01538 Mdot
.49624 .01561 Mdot
.49627 .0154 Mdot
.49629 .01659 Mdot
.49632 .01565 Mdot
.49634 .01642 Mdot
.49637 .01558 Mdot
.4964 .01514 Mdot
.49642 .01526 Mdot
.49645 .01548 Mdot
.49647 .01591 Mdot
.4965 .01575 Mdot
.49653 .01609 Mdot
.49655 .01527 Mdot
.49658 .01562 Mdot
.4966 .01528 Mdot
.49663 .01507 Mdot
.49665 .01698 Mdot
.49668 .01768 Mdot
.49671 .01501 Mdot
.49673 .01508 Mdot
.49676 .01553 Mdot
.49678 .01628 Mdot
.49681 .01548 Mdot
.49684 .01499 Mdot
.49686 .01578 Mdot
.49689 .01555 Mdot
.49691 .01607 Mdot
.49694 .01525 Mdot
.49696 .01511 Mdot
.49699 .01565 Mdot
.49702 .01579 Mdot
.49704 .01515 Mdot
.49707 .0156 Mdot
.49709 .0158 Mdot
.49712 .01634 Mdot
.49715 .01482 Mdot
.49717 .01499 Mdot
.4972 .01494 Mdot
.49722 .01725 Mdot
.49725 .01578 Mdot
.49727 .01626 Mdot
.4973 .01567 Mdot
.49733 .01575 Mdot
.49735 .01502 Mdot
.49738 .01505 Mdot
.4974 .01522 Mdot
.49743 .01507 Mdot
.49746 .0151 Mdot
.49748 .01516 Mdot
.49751 .01601 Mdot
.49753 .01596 Mdot
.49756 .01527 Mdot
.49758 .01511 Mdot
.49761 .01528 Mdot
.49764 .0151 Mdot
.49766 .01533 Mdot
.49769 .01516 Mdot
.49771 .01568 Mdot
.49774 .01546 Mdot
.49777 .01553 Mdot
.49779 .01554 Mdot
.49782 .01635 Mdot
.49784 .01582 Mdot
.49787 .01569 Mdot
.49789 .01484 Mdot
.49792 .01526 Mdot
.49795 .01534 Mdot
.49797 .01519 Mdot
.498 .01534 Mdot
.49802 .01628 Mdot
.49805 .01587 Mdot
.49808 .01592 Mdot
.4981 .01575 Mdot
.49813 .01491 Mdot
.49815 .01625 Mdot
.49818 .01583 Mdot
.4982 .01582 Mdot
.49823 .01532 Mdot
.49826 .01637 Mdot
.49828 .0158 Mdot
.49831 .01572 Mdot
.49833 .01486 Mdot
.49836 .01503 Mdot
.49839 .01589 Mdot
.49841 .01588 Mdot
.49844 .01592 Mdot
.49846 .01533 Mdot
.49849 .01539 Mdot
.49851 .01509 Mdot
.49854 .01565 Mdot
.49857 .01517 Mdot
.49859 .01647 Mdot
.49862 .01519 Mdot
.49864 .01517 Mdot
.49867 .01511 Mdot
.4987 .01548 Mdot
.49872 .0155 Mdot
.49875 .01578 Mdot
.49877 .01525 Mdot
.4988 .01498 Mdot
.49882 .01574 Mdot
.49885 .01612 Mdot
.49888 .01497 Mdot
.4989 .01525 Mdot
.49893 .01635 Mdot
.49895 .01503 Mdot
.49898 .01589 Mdot
.49901 .01534 Mdot
.49903 .01594 Mdot
.49906 .01665 Mdot
.49908 .01512 Mdot
.49911 .01563 Mdot
.49913 .01595 Mdot
.49916 .01659 Mdot
.49919 .01492 Mdot
.49921 .01545 Mdot
.49924 .01569 Mdot
.49926 .01502 Mdot
.49929 .01552 Mdot
.49932 .01507 Mdot
.49934 .0154 Mdot
.49937 .0152 Mdot
.49939 .01523 Mdot
.49942 .01545 Mdot
.49944 .01681 Mdot
.49947 .01501 Mdot
.4995 .01548 Mdot
.49952 .01506 Mdot
.49955 .0161 Mdot
.49957 .01555 Mdot
.4996 .01515 Mdot
.49963 .01634 Mdot
.49965 .01632 Mdot
.49968 .01523 Mdot
.4997 .01619 Mdot
.49973 .01557 Mdot
.49975 .01591 Mdot
.49978 .01552 Mdot
.49981 .01576 Mdot
.49983 .01544 Mdot
.49986 .016 Mdot
.49988 .01604 Mdot
.49991 .01494 Mdot
.49994 .01553 Mdot
.49996 .01551 Mdot
.49999 .01514 Mdot
.50001 .01563 Mdot
.50004 .01514 Mdot
.50006 .01551 Mdot
.50009 .01553 Mdot
.50012 .01494 Mdot
.50014 .01604 Mdot
.50017 .016 Mdot
.50019 .01544 Mdot
.50022 .01576 Mdot
.50025 .01552 Mdot
.50027 .01591 Mdot
.5003 .01557 Mdot
.50032 .01619 Mdot
.50035 .01523 Mdot
.50037 .01632 Mdot
.5004 .01634 Mdot
.50043 .01515 Mdot
.50045 .01555 Mdot
.50048 .0161 Mdot
.5005 .01506 Mdot
.50053 .01548 Mdot
.50056 .01501 Mdot
.50058 .01681 Mdot
.50061 .01545 Mdot
.50063 .01523 Mdot
.50066 .0152 Mdot
.50068 .0154 Mdot
.50071 .01507 Mdot
.50074 .01552 Mdot
.50076 .01502 Mdot
.50079 .01569 Mdot
.50081 .01545 Mdot
.50084 .01492 Mdot
.50087 .01659 Mdot
.50089 .01595 Mdot
.50092 .01563 Mdot
.50094 .01512 Mdot
.50097 .01665 Mdot
.50099 .01594 Mdot
.50102 .01534 Mdot
.50105 .01589 Mdot
.50107 .01503 Mdot
.5011 .01635 Mdot
.50112 .01525 Mdot
.50115 .01497 Mdot
.50118 .01612 Mdot
.5012 .01574 Mdot
.50123 .01498 Mdot
.50125 .01525 Mdot
.50128 .01578 Mdot
.5013 .0155 Mdot
.50133 .01548 Mdot
.50136 .01511 Mdot
.50138 .01517 Mdot
.50141 .01519 Mdot
.50143 .01647 Mdot
.50146 .01517 Mdot
.50149 .01565 Mdot
.50151 .01509 Mdot
.50154 .01539 Mdot
.50156 .01533 Mdot
.50159 .01592 Mdot
.50161 .01588 Mdot
.50164 .01589 Mdot
.50167 .01503 Mdot
.50169 .01486 Mdot
.50172 .01572 Mdot
.50174 .0158 Mdot
.50177 .01637 Mdot
.5018 .01532 Mdot
.50182 .01582 Mdot
.50185 .01583 Mdot
.50187 .01625 Mdot
.5019 .01491 Mdot
.50192 .01575 Mdot
.50195 .01592 Mdot
.50198 .01587 Mdot
.502 .01628 Mdot
.50203 .01534 Mdot
.50205 .01519 Mdot
.50208 .01534 Mdot
.50211 .01526 Mdot
.50213 .01484 Mdot
.50216 .01569 Mdot
.50218 .01582 Mdot
.50221 .01635 Mdot
.50223 .01554 Mdot
.50226 .01553 Mdot
.50229 .01546 Mdot
.50231 .01568 Mdot
.50234 .01516 Mdot
.50236 .01533 Mdot
.50239 .0151 Mdot
.50242 .01528 Mdot
.50244 .01511 Mdot
.50247 .01527 Mdot
.50249 .01596 Mdot
.50252 .01601 Mdot
.50254 .01516 Mdot
.50257 .0151 Mdot
.5026 .01507 Mdot
.50262 .01522 Mdot
.50265 .01505 Mdot
.50267 .01502 Mdot
.5027 .01575 Mdot
.50273 .01567 Mdot
.50275 .01626 Mdot
.50278 .01578 Mdot
.5028 .01725 Mdot
.50283 .01494 Mdot
.50285 .01499 Mdot
.50288 .01482 Mdot
.50291 .01634 Mdot
.50293 .0158 Mdot
.50296 .0156 Mdot
.50298 .01515 Mdot
.50301 .01579 Mdot
.50304 .01565 Mdot
.50306 .01511 Mdot
.50309 .01525 Mdot
.50311 .01607 Mdot
.50314 .01555 Mdot
.50316 .01578 Mdot
.50319 .01499 Mdot
.50322 .01548 Mdot
.50324 .01628 Mdot
.50327 .01553 Mdot
.50329 .01508 Mdot
.50332 .01501 Mdot
.50335 .01768 Mdot
.50337 .01698 Mdot
.5034 .01507 Mdot
.50342 .01528 Mdot
.50345 .01562 Mdot
.50347 .01527 Mdot
.5035 .01609 Mdot
.50353 .01575 Mdot
.50355 .01591 Mdot
.50358 .01548 Mdot
.5036 .01526 Mdot
.50363 .01514 Mdot
.50366 .01558 Mdot
.50368 .01642 Mdot
.50371 .01565 Mdot
.50373 .01659 Mdot
.50376 .0154 Mdot
.50378 .01561 Mdot
.50381 .01538 Mdot
.50384 .01493 Mdot
.50386 .0154 Mdot
.50389 .01585 Mdot
.50391 .01481 Mdot
.50394 .01491 Mdot
.50397 .01568 Mdot
.50399 .01699 Mdot
.50402 .01652 Mdot
.50404 .01524 Mdot
.50407 .01517 Mdot
.50409 .01544 Mdot
.50412 .01601 Mdot
.50415 .0152 Mdot
.50417 .01634 Mdot
.5042 .01552 Mdot
.50422 .01578 Mdot
.50425 .01563 Mdot
.50428 .0157 Mdot
.5043 .01557 Mdot
.50433 .01561 Mdot
.50435 .01531 Mdot
.50438 .01642 Mdot
.5044 .0156 Mdot
.50443 .01563 Mdot
.50446 .01599 Mdot
.50448 .01536 Mdot
.50451 .01504 Mdot
.50453 .016 Mdot
.50456 .01622 Mdot
.50459 .01583 Mdot
.50461 .01513 Mdot
.50464 .01547 Mdot
.50466 .01538 Mdot
.50469 .01599 Mdot
.50472 .01587 Mdot
.50474 .0154 Mdot
.50477 .01527 Mdot
.50479 .0154 Mdot
.50482 .01544 Mdot
.50484 .01578 Mdot
.50487 .01558 Mdot
.5049 .01529 Mdot
.50492 .01551 Mdot
.50495 .01503 Mdot
.50497 .01577 Mdot
.505 .01506 Mdot
.50503 .01606 Mdot
.50505 .01519 Mdot
.50508 .01661 Mdot
.5051 .01522 Mdot
.50513 .01525 Mdot
.50515 .01555 Mdot
.50518 .01523 Mdot
.50521 .01535 Mdot
.50523 .01618 Mdot
.50526 .01598 Mdot
.50528 .01559 Mdot
.50531 .01528 Mdot
.50534 .0151 Mdot
.50536 .01485 Mdot
.50539 .01514 Mdot
.50541 .01535 Mdot
.50544 .01636 Mdot
.50546 .01534 Mdot
.50549 .01639 Mdot
.50552 .01609 Mdot
.50554 .01635 Mdot
.50557 .01606 Mdot
.50559 .01538 Mdot
.50562 .01514 Mdot
.50565 .01611 Mdot
.50567 .01593 Mdot
.5057 .01623 Mdot
.50572 .01533 Mdot
.50575 .01646 Mdot
.50577 .0159 Mdot
.5058 .01559 Mdot
.50583 .01646 Mdot
.50585 .01512 Mdot
.50588 .01569 Mdot
.5059 .01617 Mdot
.50593 .01491 Mdot
.50596 .01492 Mdot
.50598 .01525 Mdot
.50601 .01597 Mdot
.50603 .0152 Mdot
.50606 .0152 Mdot
.50608 .01506 Mdot
.50611 .01514 Mdot
.50614 .01609 Mdot
.50616 .01612 Mdot
.50619 .01498 Mdot
.50621 .01553 Mdot
.50624 .01582 Mdot
.50627 .01634 Mdot
.50629 .01541 Mdot
.50632 .01492 Mdot
.50634 .01652 Mdot
.50637 .01581 Mdot
.50639 .01582 Mdot
.50642 .01531 Mdot
.50645 .0151 Mdot
.50647 .01538 Mdot
.5065 .01588 Mdot
.50652 .01601 Mdot
.50655 .0153 Mdot
.50658 .01523 Mdot
.5066 .01549 Mdot
.50663 .01598 Mdot
.50665 .0166 Mdot
.50668 .01632 Mdot
.5067 .01553 Mdot
.50673 .01491 Mdot
.50676 .01599 Mdot
.50678 .0157 Mdot
.50681 .01527 Mdot
.50683 .01581 Mdot
.50686 .01631 Mdot
.50689 .01516 Mdot
.50691 .01489 Mdot
.50694 .0151 Mdot
.50696 .01551 Mdot
.50699 .01585 Mdot
.50701 .01521 Mdot
.50704 .01559 Mdot
.50707 .01599 Mdot
.50709 .01685 Mdot
.50712 .01533 Mdot
.50714 .01581 Mdot
.50717 .01528 Mdot
.5072 .01554 Mdot
.50722 .01592 Mdot
.50725 .0163 Mdot
.50727 .01531 Mdot
.5073 .01652 Mdot
.50732 .01582 Mdot
.50735 .01541 Mdot
.50738 .01504 Mdot
.5074 .015 Mdot
.50743 .01583 Mdot
.50745 .01573 Mdot
.50748 .0154 Mdot
.50751 .01537 Mdot
.50753 .01506 Mdot
.50756 .01515 Mdot
.50758 .01537 Mdot
.50761 .0156 Mdot
.50763 .01509 Mdot
.50766 .01601 Mdot
.50769 .01512 Mdot
.50771 .0155 Mdot
.50774 .01533 Mdot
.50776 .01534 Mdot
.50779 .01564 Mdot
.50782 .01653 Mdot
.50784 .01538 Mdot
.50787 .01531 Mdot
.50789 .01552 Mdot
.50792 .01498 Mdot
.50794 .01512 Mdot
.50797 .01524 Mdot
.508 .01639 Mdot
.50802 .0155 Mdot
.50805 .01582 Mdot
.50807 .01568 Mdot
.5081 .01517 Mdot
.50813 .01499 Mdot
.50815 .01499 Mdot
.50818 .01493 Mdot
.5082 .01595 Mdot
.50823 .01529 Mdot
.50825 .0153 Mdot
.50828 .01571 Mdot
.50831 .01546 Mdot
.50833 .016 Mdot
.50836 .01546 Mdot
.50838 .01623 Mdot
.50841 .01628 Mdot
.50844 .01538 Mdot
.50846 .01508 Mdot
.50849 .01595 Mdot
.50851 .01544 Mdot
.50854 .01642 Mdot
.50856 .01543 Mdot
.50859 .01602 Mdot
.50862 .01534 Mdot
.50864 .01507 Mdot
.50867 .01588 Mdot
.50869 .01586 Mdot
.50872 .01595 Mdot
.50875 .01611 Mdot
.50877 .01642 Mdot
.5088 .01649 Mdot
.50882 .01547 Mdot
.50885 .01482 Mdot
.50887 .01508 Mdot
.5089 .01614 Mdot
.50893 .01548 Mdot
.50895 .01542 Mdot
.50898 .01521 Mdot
.509 .01559 Mdot
.50903 .01662 Mdot
.50906 .01505 Mdot
.50908 .01612 Mdot
.50911 .015 Mdot
.50913 .01549 Mdot
.50916 .01506 Mdot
.50918 .01481 Mdot
.50921 .0156 Mdot
.50924 .01542 Mdot
.50926 .0154 Mdot
.50929 .01568 Mdot
.50931 .0164 Mdot
.50934 .01578 Mdot
.50937 .0153 Mdot
.50939 .01628 Mdot
.50942 .01608 Mdot
.50944 .01515 Mdot
.50947 .01513 Mdot
.50949 .01527 Mdot
.50952 .01537 Mdot
.50955 .01582 Mdot
.50957 .01636 Mdot
.5096 .01604 Mdot
.50962 .01549 Mdot
.50965 .01583 Mdot
.50968 .01533 Mdot
.5097 .01598 Mdot
.50973 .01521 Mdot
.50975 .01519 Mdot
.50978 .01588 Mdot
.5098 .01517 Mdot
.50983 .01513 Mdot
.50986 .0159 Mdot
.50988 .01549 Mdot
.50991 .01571 Mdot
.50993 .01546 Mdot
.50996 .01578 Mdot
.50999 .01583 Mdot
.51001 .01661 Mdot
.51004 .01494 Mdot
.51006 .01506 Mdot
.51009 .0152 Mdot
.51011 .01524 Mdot
.51014 .01576 Mdot
.51017 .01553 Mdot
.51019 .01543 Mdot
.51022 .01575 Mdot
.51024 .01543 Mdot
.51027 .01606 Mdot
.5103 .01587 Mdot
.51032 .01512 Mdot
.51035 .01582 Mdot
.51037 .01584 Mdot
.5104 .01505 Mdot
.51042 .01646 Mdot
.51045 .01575 Mdot
.51048 .01544 Mdot
.5105 .01506 Mdot
.51053 .01564 Mdot
.51055 .01608 Mdot
.51058 .01521 Mdot
.51061 .01532 Mdot
.51063 .0161 Mdot
.51066 .01554 Mdot
.51068 .01582 Mdot
.51071 .01497 Mdot
.51073 .01522 Mdot
.51076 .01475 Mdot
.51079 .01546 Mdot
.51081 .01547 Mdot
.51084 .01636 Mdot
.51086 .01586 Mdot
.51089 .01566 Mdot
.51092 .01601 Mdot
.51094 .01558 Mdot
.51097 .01583 Mdot
.51099 .01579 Mdot
.51102 .01557 Mdot
.51104 .01718 Mdot
.51107 .01593 Mdot
.5111 .01544 Mdot
.51112 .01503 Mdot
.51115 .01579 Mdot
.51117 .01554 Mdot
.5112 .01625 Mdot
.51123 .01549 Mdot
.51125 .01693 Mdot
.51128 .01653 Mdot
.5113 .01503 Mdot
.51133 .01512 Mdot
.51135 .01562 Mdot
.51138 .01592 Mdot
.51141 .01571 Mdot
.51143 .01581 Mdot
.51146 .01539 Mdot
.51148 .01604 Mdot
.51151 .01577 Mdot
.51154 .01579 Mdot
.51156 .01519 Mdot
.51159 .01578 Mdot
.51161 .01565 Mdot
.51164 .0157 Mdot
.51166 .01495 Mdot
.51169 .01583 Mdot
.51172 .01655 Mdot
.51174 .01592 Mdot
.51177 .01497 Mdot
.51179 .01498 Mdot
.51182 .01514 Mdot
.51185 .01556 Mdot
.51187 .01503 Mdot
.5119 .01538 Mdot
.51192 .01544 Mdot
.51195 .01598 Mdot
.51197 .01532 Mdot
.512 .01582 Mdot
.51203 .01621 Mdot
.51205 .016 Mdot
.51208 .01548 Mdot
.5121 .01608 Mdot
.51213 .01494 Mdot
.51216 .01607 Mdot
.51218 .01566 Mdot
.51221 .01503 Mdot
.51223 .01609 Mdot
.51226 .01479 Mdot
.51228 .01539 Mdot
.51231 .01506 Mdot
.51234 .01575 Mdot
.51236 .01601 Mdot
.51239 .01575 Mdot
.51241 .01499 Mdot
.51244 .01616 Mdot
.51247 .01698 Mdot
.51249 .01572 Mdot
.51252 .01592 Mdot
.51254 .01547 Mdot
.51257 .01589 Mdot
.51259 .01581 Mdot
.51262 .01519 Mdot
.51265 .01586 Mdot
.51267 .01557 Mdot
.5127 .01518 Mdot
.51272 .01505 Mdot
.51275 .01567 Mdot
.51278 .01522 Mdot
.5128 .0154 Mdot
.51283 .01503 Mdot
.51285 .01572 Mdot
.51288 .01592 Mdot
.5129 .01572 Mdot
.51293 .01573 Mdot
.51296 .01552 Mdot
.51298 .015 Mdot
.51301 .01567 Mdot
.51303 .01536 Mdot
.51306 .01608 Mdot
.51309 .01529 Mdot
.51311 .01523 Mdot
.51314 .01547 Mdot
.51316 .01552 Mdot
.51319 .01668 Mdot
.51321 .01577 Mdot
.51324 .01562 Mdot
.51327 .01577 Mdot
.51329 .01564 Mdot
.51332 .01561 Mdot
.51334 .01509 Mdot
.51337 .01536 Mdot
.5134 .01542 Mdot
.51342 .01524 Mdot
.51345 .01545 Mdot
.51347 .01485 Mdot
.5135 .01509 Mdot
.51352 .01647 Mdot
.51355 .0162 Mdot
.51358 .01581 Mdot
.5136 .01517 Mdot
.51363 .01591 Mdot
.51365 .01514 Mdot
.51368 .01497 Mdot
.51371 .01525 Mdot
.51373 .016 Mdot
.51376 .01528 Mdot
.51378 .01548 Mdot
.51381 .01494 Mdot
.51384 .01492 Mdot
.51386 .01593 Mdot
.51389 .0155 Mdot
.51391 .01615 Mdot
.51394 .01594 Mdot
.51396 .01537 Mdot
.51399 .01524 Mdot
.51402 .01613 Mdot
.51404 .01602 Mdot
.51407 .01596 Mdot
.51409 .01554 Mdot
.51412 .01584 Mdot
.51415 .01524 Mdot
.51417 .01534 Mdot
.5142 .01568 Mdot
.51422 .01566 Mdot
.51425 .01619 Mdot
.51427 .01693 Mdot
.5143 .01585 Mdot
.51433 .01514 Mdot
.51435 .01575 Mdot
.51438 .01541 Mdot
.5144 .01649 Mdot
.51443 .01535 Mdot
.51446 .01498 Mdot
.51448 .01513 Mdot
.51451 .01605 Mdot
.51453 .01555 Mdot
.51456 .01589 Mdot
.51458 .01496 Mdot
.51461 .01523 Mdot
.51464 .01532 Mdot
.51466 .01523 Mdot
.51469 .01493 Mdot
.51471 .0148 Mdot
.51474 .0153 Mdot
.51477 .0161 Mdot
.51479 .01543 Mdot
.51482 .01515 Mdot
.51484 .01547 Mdot
.51487 .01487 Mdot
.51489 .01533 Mdot
.51492 .01608 Mdot
.51495 .01548 Mdot
.51497 .01521 Mdot
.515 .01574 Mdot
.51502 .01489 Mdot
.51505 .01565 Mdot
.51508 .0155 Mdot
.5151 .01594 Mdot
.51513 .01582 Mdot
.51515 .01534 Mdot
.51518 .01602 Mdot
.5152 .01603 Mdot
.51523 .01547 Mdot
.51526 .01575 Mdot
.51528 .01562 Mdot
.51531 .01537 Mdot
.51533 .01573 Mdot
.51536 .01491 Mdot
.51539 .01571 Mdot
.51541 .01516 Mdot
.51544 .01634 Mdot
.51546 .01567 Mdot
.51549 .01518 Mdot
.51551 .0158 Mdot
.51554 .01582 Mdot
.51557 .01579 Mdot
.51559 .01482 Mdot
.51562 .01536 Mdot
.51564 .01564 Mdot
.51567 .0156 Mdot
.5157 .01545 Mdot
.51572 .01544 Mdot
.51575 .01526 Mdot
.51577 .01548 Mdot
.5158 .01634 Mdot
.51582 .01632 Mdot
.51585 .01487 Mdot
.51588 .01486 Mdot
.5159 .01499 Mdot
.51593 .01478 Mdot
.51595 .01692 Mdot
.51598 .01492 Mdot
.51601 .01593 Mdot
.51603 .01556 Mdot
.51606 .01553 Mdot
.51608 .01626 Mdot
.51611 .01564 Mdot
.51613 .01516 Mdot
.51616 .01578 Mdot
.51619 .01509 Mdot
.51621 .01573 Mdot
.51624 .01587 Mdot
.51626 .01475 Mdot
.51629 .01537 Mdot
.51632 .01542 Mdot
.51634 .01552 Mdot
.51637 .01533 Mdot
.51639 .01617 Mdot
.51642 .0157 Mdot
.51644 .01583 Mdot
.51647 .01539 Mdot
.5165 .01632 Mdot
.51652 .0155 Mdot
.51655 .01612 Mdot
.51657 .01531 Mdot
.5166 .01576 Mdot
.51663 .01589 Mdot
.51665 .01541 Mdot
.51668 .01573 Mdot
.5167 .01529 Mdot
.51673 .015 Mdot
.51675 .01602 Mdot
.51678 .01565 Mdot
.51681 .0151 Mdot
.51683 .0158 Mdot
.51686 .01624 Mdot
.51688 .01595 Mdot
.51691 .01637 Mdot
.51694 .01542 Mdot
.51696 .01524 Mdot
.51699 .01547 Mdot
.51701 .01638 Mdot
.51704 .01574 Mdot
.51706 .01528 Mdot
.51709 .01553 Mdot
.51712 .01563 Mdot
.51714 .01516 Mdot
.51717 .01628 Mdot
.51719 .01482 Mdot
.51722 .01562 Mdot
.51725 .01618 Mdot
.51727 .01512 Mdot
.5173 .01604 Mdot
.51732 .01494 Mdot
.51735 .01576 Mdot
.51737 .01537 Mdot
.5174 .01513 Mdot
.51743 .01564 Mdot
.51745 .01536 Mdot
.51748 .0155 Mdot
.5175 .01641 Mdot
.51753 .01722 Mdot
.51756 .01546 Mdot
.51758 .01544 Mdot
.51761 .01583 Mdot
.51763 .01527 Mdot
.51766 .01598 Mdot
.51768 .01616 Mdot
.51771 .01541 Mdot
.51774 .01554 Mdot
.51776 .01553 Mdot
.51779 .01584 Mdot
.51781 .0155 Mdot
.51784 .01508 Mdot
.51787 .01645 Mdot
.51789 .01639 Mdot
.51792 .01506 Mdot
.51794 .01548 Mdot
.51797 .01515 Mdot
.51799 .0156 Mdot
.51802 .01573 Mdot
.51805 .01522 Mdot
.51807 .01479 Mdot
.5181 .01519 Mdot
.51812 .01496 Mdot
.51815 .01531 Mdot
.51818 .0154 Mdot
.5182 .01553 Mdot
.51823 .0153 Mdot
.51825 .01605 Mdot
.51828 .01502 Mdot
.5183 .01489 Mdot
.51833 .01494 Mdot
.51836 .01699 Mdot
.51838 .01635 Mdot
.51841 .0152 Mdot
.51843 .01585 Mdot
.51846 .01614 Mdot
.51849 .01538 Mdot
.51851 .01555 Mdot
.51854 .01519 Mdot
.51856 .01592 Mdot
.51859 .01486 Mdot
.51861 .01662 Mdot
.51864 .0157 Mdot
.51867 .01499 Mdot
.51869 .01522 Mdot
.51872 .01619 Mdot
.51874 .01503 Mdot
.51877 .01597 Mdot
.5188 .01547 Mdot
.51882 .01576 Mdot
.51885 .01532 Mdot
.51887 .01532 Mdot
.5189 .01536 Mdot
.51892 .01543 Mdot
.51895 .01605 Mdot
.51898 .01629 Mdot
.519 .01589 Mdot
.51903 .01489 Mdot
.51905 .01597 Mdot
.51908 .01509 Mdot
.51911 .01538 Mdot
.51913 .0159 Mdot
.51916 .01543 Mdot
.51918 .01579 Mdot
.51921 .01523 Mdot
.51923 .01539 Mdot
.51926 .01557 Mdot
.51929 .01578 Mdot
.51931 .01543 Mdot
.51934 .01487 Mdot
.51936 .01562 Mdot
.51939 .01516 Mdot
.51942 .01523 Mdot
.51944 .01626 Mdot
.51947 .01554 Mdot
.51949 .01575 Mdot
.51952 .01572 Mdot
.51954 .01537 Mdot
.51957 .01586 Mdot
.5196 .01671 Mdot
.51962 .01542 Mdot
.51965 .01631 Mdot
.51967 .01509 Mdot
.5197 .01517 Mdot
.51973 .01686 Mdot
.51975 .01535 Mdot
.51978 .01538 Mdot
.5198 .01615 Mdot
.51983 .01522 Mdot
.51985 .01518 Mdot
.51988 .01601 Mdot
.51991 .01644 Mdot
.51993 .01609 Mdot
.51996 .01593 Mdot
.51998 .01596 Mdot
.52001 .01612 Mdot
.52004 .01528 Mdot
.52006 .01554 Mdot
.52009 .01664 Mdot
.52011 .0152 Mdot
.52014 .01561 Mdot
.52016 .01598 Mdot
.52019 .01638 Mdot
.52022 .01547 Mdot
.52024 .01544 Mdot
.52027 .01611 Mdot
.52029 .01618 Mdot
.52032 .01503 Mdot
.52035 .01553 Mdot
.52037 .01545 Mdot
.5204 .01489 Mdot
.52042 .01564 Mdot
.52045 .0158 Mdot
.52047 .01491 Mdot
.5205 .01559 Mdot
.52053 .01528 Mdot
.52055 .01515 Mdot
.52058 .01557 Mdot
.5206 .0148 Mdot
.52063 .0152 Mdot
.52066 .01604 Mdot
.52068 .01577 Mdot
.52071 .01612 Mdot
.52073 .01526 Mdot
.52076 .01722 Mdot
.52078 .01586 Mdot
.52081 .01573 Mdot
.52084 .01506 Mdot
.52086 .01523 Mdot
.52089 .016 Mdot
.52091 .01546 Mdot
.52094 .01614 Mdot
.52097 .01536 Mdot
.52099 .01573 Mdot
.52102 .01541 Mdot
.52104 .01588 Mdot
.52107 .01538 Mdot
.52109 .01524 Mdot
.52112 .01657 Mdot
.52115 .01593 Mdot
.52117 .01673 Mdot
.5212 .01678 Mdot
.52122 .01567 Mdot
.52125 .01589 Mdot
.52128 .01563 Mdot
.5213 .01512 Mdot
.52133 .01522 Mdot
.52135 .01642 Mdot
.52138 .01596 Mdot
.5214 .01531 Mdot
.52143 .01529 Mdot
.52146 .01568 Mdot
.52148 .01549 Mdot
.52151 .01533 Mdot
.52153 .0155 Mdot
.52156 .01521 Mdot
.52159 .01539 Mdot
.52161 .0161 Mdot
.52164 .01527 Mdot
.52166 .01569 Mdot
.52169 .01558 Mdot
.52171 .01574 Mdot
.52174 .0158 Mdot
.52177 .01528 Mdot
.52179 .01578 Mdot
.52182 .01618 Mdot
.52184 .01559 Mdot
.52187 .01492 Mdot
.5219 .01526 Mdot
.52192 .01647 Mdot
.52195 .01561 Mdot
.52197 .01508 Mdot
.522 .01515 Mdot
.52202 .01632 Mdot
.52205 .01525 Mdot
.52208 .01555 Mdot
.5221 .01528 Mdot
.52213 .01624 Mdot
.52215 .01634 Mdot
.52218 .0165 Mdot
.52221 .01594 Mdot
.52223 .01578 Mdot
.52226 .01598 Mdot
.52228 .0156 Mdot
.52231 .01573 Mdot
.52233 .01573 Mdot
.52236 .01513 Mdot
.52239 .01559 Mdot
.52241 .0155 Mdot
.52244 .01527 Mdot
.52246 .01524 Mdot
.52249 .01662 Mdot
.52252 .01476 Mdot
.52254 .0161 Mdot
.52257 .01528 Mdot
.52259 .01515 Mdot
.52262 .01505 Mdot
.52264 .01583 Mdot
.52267 .01528 Mdot
.5227 .01536 Mdot
.52272 .01544 Mdot
.52275 .0151 Mdot
.52277 .01541 Mdot
.5228 .01624 Mdot
.52283 .01604 Mdot
.52285 .01511 Mdot
.52288 .01534 Mdot
.5229 .01624 Mdot
.52293 .01585 Mdot
.52296 .01524 Mdot
.52298 .01557 Mdot
.52301 .0148 Mdot
.52303 .01556 Mdot
.52306 .01552 Mdot
.52308 .01508 Mdot
.52311 .01561 Mdot
.52314 .01484 Mdot
.52316 .01649 Mdot
.52319 .01563 Mdot
.52321 .01515 Mdot
.52324 .01576 Mdot
.52327 .01519 Mdot
.52329 .01593 Mdot
.52332 .01647 Mdot
.52334 .01532 Mdot
.52337 .01527 Mdot
.52339 .01541 Mdot
.52342 .01577 Mdot
.52345 .01553 Mdot
.52347 .01649 Mdot
.5235 .01644 Mdot
.52352 .01591 Mdot
.52355 .01569 Mdot
.52358 .01476 Mdot
.5236 .01506 Mdot
.52363 .015 Mdot
.52365 .01501 Mdot
.52368 .01519 Mdot
.5237 .01499 Mdot
.52373 .01531 Mdot
.52376 .01612 Mdot
.52378 .01536 Mdot
.52381 .01474 Mdot
.52383 .01507 Mdot
.52386 .01529 Mdot
.52389 .01528 Mdot
.52391 .01516 Mdot
.52394 .01595 Mdot
.52396 .01575 Mdot
.52399 .01618 Mdot
.52401 .01636 Mdot
.52404 .01589 Mdot
.52407 .01541 Mdot
.52409 .0154 Mdot
.52412 .01602 Mdot
.52414 .01534 Mdot
.52417 .01482 Mdot
.5242 .01522 Mdot
.52422 .01501 Mdot
.52425 .01613 Mdot
.52427 .01533 Mdot
.5243 .01594 Mdot
.52432 .01517 Mdot
.52435 .01535 Mdot
.52438 .01616 Mdot
.5244 .01489 Mdot
.52443 .01515 Mdot
.52445 .01524 Mdot
.52448 .01549 Mdot
.52451 .01649 Mdot
.52453 .01492 Mdot
.52456 .01518 Mdot
.52458 .01522 Mdot
.52461 .01635 Mdot
.52463 .01657 Mdot
.52466 .01593 Mdot
.52469 .01546 Mdot
.52471 .01557 Mdot
.52474 .01498 Mdot
.52476 .01528 Mdot
.52479 .01547 Mdot
.52482 .01486 Mdot
.52484 .01524 Mdot
.52487 .0153 Mdot
.52489 .01642 Mdot
.52492 .01681 Mdot
.52494 .01633 Mdot
.52497 .01569 Mdot
.525 .01574 Mdot
.52502 .01548 Mdot
.52505 .01538 Mdot
.52507 .01639 Mdot
.5251 .01601 Mdot
.52513 .01683 Mdot
.52515 .01612 Mdot
.52518 .01637 Mdot
.5252 .01514 Mdot
.52523 .01604 Mdot
.52525 .01591 Mdot
.52528 .01552 Mdot
.52531 .01537 Mdot
.52533 .01536 Mdot
.52536 .01542 Mdot
.52538 .01562 Mdot
.52541 .01613 Mdot
.52544 .01503 Mdot
.52546 .01516 Mdot
.52549 .01562 Mdot
.52551 .01567 Mdot
.52554 .01628 Mdot
.52556 .01587 Mdot
.52559 .0155 Mdot
.52562 .01596 Mdot
.52564 .01503 Mdot
.52567 .01514 Mdot
.52569 .01473 Mdot
.52572 .01557 Mdot
.52575 .0165 Mdot
.52577 .01586 Mdot
.5258 .01572 Mdot
.52582 .01605 Mdot
.52585 .01484 Mdot
.52587 .01498 Mdot
.5259 .01585 Mdot
.52593 .01556 Mdot
.52595 .01576 Mdot
.52598 .01631 Mdot
.526 .01534 Mdot
.52603 .01551 Mdot
.52606 .01551 Mdot
.52608 .01501 Mdot
.52611 .01553 Mdot
.52613 .01583 Mdot
.52616 .01654 Mdot
.52618 .01511 Mdot
.52621 .01507 Mdot
.52624 .01551 Mdot
.52626 .01631 Mdot
.52629 .01565 Mdot
.52631 .01582 Mdot
.52634 .01499 Mdot
.52637 .0166 Mdot
.52639 .01639 Mdot
.52642 .01626 Mdot
.52644 .01586 Mdot
.52647 .01552 Mdot
.52649 .01605 Mdot
.52652 .0152 Mdot
.52655 .01663 Mdot
.52657 .01528 Mdot
.5266 .0158 Mdot
.52662 .01483 Mdot
.52665 .01533 Mdot
.52668 .01505 Mdot
.5267 .01616 Mdot
.52673 .01528 Mdot
.52675 .01522 Mdot
.52678 .01506 Mdot
.5268 .01526 Mdot
.52683 .01481 Mdot
.52686 .01533 Mdot
.52688 .01556 Mdot
.52691 .01552 Mdot
.52693 .01533 Mdot
.52696 .01578 Mdot
.52699 .01569 Mdot
.52701 .01549 Mdot
.52704 .01589 Mdot
.52706 .01573 Mdot
.52709 .0155 Mdot
.52711 .01628 Mdot
.52714 .01525 Mdot
.52717 .01494 Mdot
.52719 .01538 Mdot
.52722 .01493 Mdot
.52724 .01488 Mdot
.52727 .01567 Mdot
.5273 .01555 Mdot
.52732 .01575 Mdot
.52735 .01484 Mdot
.52737 .01512 Mdot
.5274 .01729 Mdot
.52742 .01519 Mdot
.52745 .01527 Mdot
.52748 .01603 Mdot
.5275 .01533 Mdot
.52753 .0161 Mdot
.52755 .01566 Mdot
.52758 .01596 Mdot
.52761 .0152 Mdot
.52763 .01571 Mdot
.52766 .016 Mdot
.52768 .01549 Mdot
.52771 .0157 Mdot
.52773 .01591 Mdot
.52776 .01602 Mdot
.52779 .01543 Mdot
.52781 .01537 Mdot
.52784 .01569 Mdot
.52786 .01574 Mdot
.52789 .0158 Mdot
.52792 .0152 Mdot
.52794 .01575 Mdot
.52797 .01493 Mdot
.52799 .01509 Mdot
.52802 .01606 Mdot
.52804 .01616 Mdot
.52807 .01575 Mdot
.5281 .016 Mdot
.52812 .01658 Mdot
.52815 .01514 Mdot
.52817 .01486 Mdot
.5282 .01534 Mdot
.52823 .01517 Mdot
.52825 .01483 Mdot
.52828 .01511 Mdot
.5283 .01531 Mdot
.52833 .01493 Mdot
.52835 .01569 Mdot
.52838 .01518 Mdot
.52841 .0157 Mdot
.52843 .0152 Mdot
.52846 .01567 Mdot
.52848 .01572 Mdot
.52851 .01519 Mdot
.52854 .01595 Mdot
.52856 .01549 Mdot
.52859 .0152 Mdot
.52861 .01476 Mdot
.52864 .01534 Mdot
.52866 .01516 Mdot
.52869 .0151 Mdot
.52872 .01637 Mdot
.52874 .01645 Mdot
.52877 .01641 Mdot
.52879 .01549 Mdot
.52882 .01543 Mdot
.52885 .01576 Mdot
.52887 .01554 Mdot
.5289 .01504 Mdot
.52892 .01548 Mdot
.52895 .01556 Mdot
.52897 .01579 Mdot
.529 .01608 Mdot
.52903 .01525 Mdot
.52905 .01632 Mdot
.52908 .01539 Mdot
.5291 .01492 Mdot
.52913 .0152 Mdot
.52916 .01562 Mdot
.52918 .01532 Mdot
.52921 .01512 Mdot
.52923 .01511 Mdot
.52926 .0152 Mdot
.52928 .01568 Mdot
.52931 .01569 Mdot
.52934 .0158 Mdot
.52936 .01536 Mdot
.52939 .01578 Mdot
.52941 .01593 Mdot
.52944 .01565 Mdot
.52947 .01606 Mdot
.52949 .01639 Mdot
.52952 .01594 Mdot
.52954 .01536 Mdot
.52957 .01651 Mdot
.52959 .01483 Mdot
.52962 .01591 Mdot
.52965 .01612 Mdot
.52967 .01547 Mdot
.5297 .01566 Mdot
.52972 .01507 Mdot
.52975 .01567 Mdot
.52978 .01568 Mdot
.5298 .01558 Mdot
.52983 .01557 Mdot
.52985 .01506 Mdot
.52988 .01555 Mdot
.5299 .0152 Mdot
.52993 .0159 Mdot
.52996 .01529 Mdot
.52998 .01707 Mdot
.53001 .01595 Mdot
.53003 .01623 Mdot
.53006 .01559 Mdot
.53009 .01539 Mdot
.53011 .01509 Mdot
.53014 .01495 Mdot
.53016 .01592 Mdot
.53019 .01475 Mdot
.53021 .01582 Mdot
.53024 .01616 Mdot
.53027 .0163 Mdot
.53029 .01502 Mdot
.53032 .01563 Mdot
.53034 .01495 Mdot
.53037 .01597 Mdot
.5304 .01619 Mdot
.53042 .01705 Mdot
.53045 .01613 Mdot
.53047 .01565 Mdot
.5305 .01551 Mdot
.53052 .01635 Mdot
.53055 .01494 Mdot
.53058 .01525 Mdot
.5306 .01532 Mdot
.53063 .01521 Mdot
.53065 .0162 Mdot
.53068 .01542 Mdot
.53071 .01533 Mdot
.53073 .015 Mdot
.53076 .01515 Mdot
.53078 .0155 Mdot
.53081 .01604 Mdot
.53083 .01521 Mdot
.53086 .01598 Mdot
.53089 .01553 Mdot
.53091 .01541 Mdot
.53094 .01515 Mdot
.53096 .01568 Mdot
.53099 .01601 Mdot
.53102 .01617 Mdot
.53104 .01576 Mdot
.53107 .01559 Mdot
.53109 .01621 Mdot
.53112 .01492 Mdot
.53114 .01535 Mdot
.53117 .016 Mdot
.5312 .01516 Mdot
.53122 .01599 Mdot
.53125 .01634 Mdot
.53127 .01537 Mdot
.5313 .01542 Mdot
.53133 .01507 Mdot
.53135 .01516 Mdot
.53138 .01578 Mdot
.5314 .01494 Mdot
.53143 .01583 Mdot
.53145 .01543 Mdot
.53148 .01591 Mdot
.53151 .0158 Mdot
.53153 .01572 Mdot
.53156 .0152 Mdot
.53158 .01538 Mdot
.53161 .01488 Mdot
.53164 .01492 Mdot
.53166 .01584 Mdot
.53169 .01499 Mdot
.53171 .01499 Mdot
.53174 .01582 Mdot
.53176 .01561 Mdot
.53179 .01512 Mdot
.53182 .01582 Mdot
.53184 .01545 Mdot
.53187 .0159 Mdot
.53189 .01533 Mdot
.53192 .01534 Mdot
.53195 .01533 Mdot
.53197 .01512 Mdot
.532 .0164 Mdot
.53202 .01531 Mdot
.53205 .01611 Mdot
.53208 .01551 Mdot
.5321 .01579 Mdot
.53213 .01521 Mdot
.53215 .01613 Mdot
.53218 .01562 Mdot
.5322 .01558 Mdot
.53223 .01718 Mdot
.53226 .01548 Mdot
.53228 .01497 Mdot
.53231 .01624 Mdot
.53233 .01631 Mdot
.53236 .01671 Mdot
.53239 .01493 Mdot
.53241 .01523 Mdot
.53244 .01534 Mdot
.53246 .01553 Mdot
.53249 .01577 Mdot
.53251 .0151 Mdot
.53254 .01617 Mdot
.53257 .01482 Mdot
.53259 .01545 Mdot
.53262 .0157 Mdot
.53264 .01606 Mdot
.53267 .01613 Mdot
.5327 .01546 Mdot
.53272 .01529 Mdot
.53275 .0153 Mdot
.53277 .01592 Mdot
.5328 .01529 Mdot
.53282 .01508 Mdot
.53285 .01589 Mdot
.53288 .01539 Mdot
.5329 .01535 Mdot
.53293 .01582 Mdot
.53295 .01514 Mdot
.53298 .01491 Mdot
.53301 .01504 Mdot
.53303 .01644 Mdot
.53306 .015 Mdot
.53308 .01621 Mdot
.53311 .01524 Mdot
.53313 .01541 Mdot
.53316 .01663 Mdot
.53319 .01557 Mdot
.53321 .0154 Mdot
.53324 .01563 Mdot
.53326 .01544 Mdot
.53329 .01549 Mdot
.53332 .01592 Mdot
.53334 .01549 Mdot
.53337 .01579 Mdot
.53339 .01561 Mdot
.53342 .01555 Mdot
.53344 .0151 Mdot
.53347 .01584 Mdot
.5335 .01655 Mdot
.53352 .01491 Mdot
.53355 .01595 Mdot
.53357 .01513 Mdot
.5336 .01588 Mdot
.53363 .01619 Mdot
.53365 .01643 Mdot
.53368 .01657 Mdot
.5337 .01553 Mdot
.53373 .01513 Mdot
.53375 .01615 Mdot
.53378 .01531 Mdot
.53381 .01567 Mdot
.53383 .0157 Mdot
.53386 .01592 Mdot
.53388 .01511 Mdot
.53391 .01526 Mdot
.53394 .01582 Mdot
.53396 .01545 Mdot
.53399 .01586 Mdot
.53401 .01525 Mdot
.53404 .01581 Mdot
.53406 .01556 Mdot
.53409 .01641 Mdot
.53412 .01665 Mdot
.53414 .01504 Mdot
.53417 .01513 Mdot
.53419 .01552 Mdot
.53422 .01485 Mdot
.53425 .01498 Mdot
.53427 .01519 Mdot
.5343 .01537 Mdot
.53432 .01539 Mdot
.53435 .01538 Mdot
.53437 .01523 Mdot
.5344 .01584 Mdot
.53443 .016 Mdot
.53445 .01596 Mdot
.53448 .01651 Mdot
.5345 .01606 Mdot
.53453 .01499 Mdot
.53456 .01535 Mdot
.53458 .01543 Mdot
.53461 .01549 Mdot
.53463 .01541 Mdot
.53466 .01646 Mdot
.53468 .01619 Mdot
.53471 .01567 Mdot
.53474 .01541 Mdot
.53476 .01503 Mdot
.53479 .01534 Mdot
.53481 .01514 Mdot
.53484 .01575 Mdot
.53487 .01498 Mdot
.53489 .01627 Mdot
.53492 .01531 Mdot
.53494 .01554 Mdot
.53497 .01612 Mdot
.53499 .01504 Mdot
.53502 .01645 Mdot
.53505 .016 Mdot
.53507 .01572 Mdot
.5351 .01697 Mdot
.53512 .01613 Mdot
.53515 .01496 Mdot
.53518 .01653 Mdot
.5352 .01529 Mdot
.53523 .01539 Mdot
.53525 .01607 Mdot
.53528 .01732 Mdot
.5353 .01561 Mdot
.53533 .01578 Mdot
.53536 .01559 Mdot
.53538 .01614 Mdot
.53541 .01565 Mdot
.53543 .01552 Mdot
.53546 .01534 Mdot
.53549 .01558 Mdot
.53551 .01517 Mdot
.53554 .01582 Mdot
.53556 .01589 Mdot
.53559 .01534 Mdot
.53561 .01505 Mdot
.53564 .01623 Mdot
.53567 .01504 Mdot
.53569 .01548 Mdot
.53572 .01579 Mdot
.53574 .01536 Mdot
.53577 .01608 Mdot
.5358 .01509 Mdot
.53582 .01636 Mdot
.53585 .01531 Mdot
.53587 .01584 Mdot
.5359 .01622 Mdot
.53592 .01491 Mdot
.53595 .01522 Mdot
.53598 .01483 Mdot
.536 .01529 Mdot
.53603 .01536 Mdot
.53605 .01715 Mdot
.53608 .01546 Mdot
.53611 .01663 Mdot
.53613 .01548 Mdot
.53616 .01541 Mdot
.53618 .01568 Mdot
.53621 .01635 Mdot
.53623 .0159 Mdot
.53626 .01545 Mdot
.53629 .01499 Mdot
.53631 .01596 Mdot
.53634 .01496 Mdot
.53636 .01669 Mdot
.53639 .01575 Mdot
.53642 .01626 Mdot
.53644 .01492 Mdot
.53647 .01518 Mdot
.53649 .01551 Mdot
.53652 .01569 Mdot
.53654 .01634 Mdot
.53657 .0155 Mdot
.5366 .01514 Mdot
.53662 .01623 Mdot
.53665 .01561 Mdot
.53667 .01527 Mdot
.5367 .01548 Mdot
.53673 .01544 Mdot
.53675 .01566 Mdot
.53678 .01587 Mdot
.5368 .01513 Mdot
.53683 .01501 Mdot
.53685 .01567 Mdot
.53688 .01657 Mdot
.53691 .01626 Mdot
.53693 .015 Mdot
.53696 .01505 Mdot
.53698 .01561 Mdot
.53701 .01682 Mdot
.53704 .01682 Mdot
.53706 .01568 Mdot
.53709 .01514 Mdot
.53711 .01618 Mdot
.53714 .01577 Mdot
.53716 .01638 Mdot
.53719 .01577 Mdot
.53722 .01524 Mdot
.53724 .01494 Mdot
.53727 .01521 Mdot
.53729 .01631 Mdot
.53732 .01618 Mdot
.53735 .01565 Mdot
.53737 .01571 Mdot
.5374 .01503 Mdot
.53742 .01523 Mdot
.53745 .01571 Mdot
.53747 .01529 Mdot
.5375 .01509 Mdot
.53753 .01572 Mdot
.53755 .01575 Mdot
.53758 .01557 Mdot
.5376 .01545 Mdot
.53763 .01525 Mdot
.53766 .01568 Mdot
.53768 .01533 Mdot
.53771 .01629 Mdot
.53773 .01537 Mdot
.53776 .0166 Mdot
.53778 .01566 Mdot
.53781 .01559 Mdot
.53784 .01558 Mdot
.53786 .01583 Mdot
.53789 .01593 Mdot
.53791 .01703 Mdot
.53794 .01527 Mdot
.53797 .01584 Mdot
.53799 .01556 Mdot
.53802 .01568 Mdot
.53804 .01493 Mdot
.53807 .01559 Mdot
.53809 .01523 Mdot
.53812 .01562 Mdot
.53815 .01522 Mdot
.53817 .01499 Mdot
.5382 .01572 Mdot
.53822 .01484 Mdot
.53825 .01517 Mdot
.53828 .01548 Mdot
.5383 .01564 Mdot
.53833 .01658 Mdot
.53835 .01565 Mdot
.53838 .01509 Mdot
.5384 .01522 Mdot
.53843 .01562 Mdot
.53846 .01488 Mdot
.53848 .015 Mdot
.53851 .01559 Mdot
.53853 .01502 Mdot
.53856 .01529 Mdot
.53859 .01473 Mdot
.53861 .01685 Mdot
.53864 .01525 Mdot
.53866 .01628 Mdot
.53869 .01596 Mdot
.53871 .01647 Mdot
.53874 .01675 Mdot
.53877 .0166 Mdot
.53879 .01495 Mdot
.53882 .01502 Mdot
.53884 .01539 Mdot
.53887 .01521 Mdot
.5389 .01548 Mdot
.53892 .0154 Mdot
.53895 .01592 Mdot
.53897 .01529 Mdot
.539 .01509 Mdot
.53902 .01512 Mdot
.53905 .01556 Mdot
.53908 .01604 Mdot
.5391 .01633 Mdot
.53913 .01559 Mdot
.53915 .01612 Mdot
.53918 .01612 Mdot
.53921 .0158 Mdot
.53923 .01582 Mdot
.53926 .01596 Mdot
.53928 .01558 Mdot
.53931 .01583 Mdot
.53933 .01607 Mdot
.53936 .01516 Mdot
.53939 .01605 Mdot
.53941 .01508 Mdot
.53944 .01606 Mdot
.53946 .01475 Mdot
.53949 .01559 Mdot
.53952 .0161 Mdot
.53954 .01613 Mdot
.53957 .01507 Mdot
.53959 .01508 Mdot
.53962 .01578 Mdot
.53964 .01564 Mdot
.53967 .01537 Mdot
.5397 .0156 Mdot
.53972 .0152 Mdot
.53975 .01582 Mdot
.53977 .01506 Mdot
.5398 .01562 Mdot
.53983 .01589 Mdot
.53985 .01599 Mdot
.53988 .01707 Mdot
.5399 .01646 Mdot
.53993 .01562 Mdot
.53995 .01659 Mdot
.53998 .01641 Mdot
.54001 .0151 Mdot
.54003 .01636 Mdot
.54006 .01514 Mdot
.54008 .01582 Mdot
.54011 .01494 Mdot
.54014 .01516 Mdot
.54016 .0151 Mdot
.54019 .01584 Mdot
.54021 .01651 Mdot
.54024 .01491 Mdot
.54026 .01643 Mdot
.54029 .01609 Mdot
.54032 .01622 Mdot
.54034 .01575 Mdot
.54037 .01545 Mdot
.54039 .01514 Mdot
.54042 .01558 Mdot
.54045 .01537 Mdot
.54047 .01496 Mdot
.5405 .01546 Mdot
.54052 .01522 Mdot
.54055 .01547 Mdot
.54057 .01527 Mdot
.5406 .01528 Mdot
.54063 .01576 Mdot
.54065 .01596 Mdot
.54068 .01703 Mdot
.5407 .01594 Mdot
.54073 .0154 Mdot
.54076 .01531 Mdot
.54078 .01575 Mdot
.54081 .01563 Mdot
.54083 .01709 Mdot
.54086 .01576 Mdot
.54088 .01587 Mdot
.54091 .01574 Mdot
.54094 .01548 Mdot
.54096 .01631 Mdot
.54099 .01593 Mdot
.54101 .015 Mdot
.54104 .01554 Mdot
.54107 .01516 Mdot
.54109 .0161 Mdot
.54112 .01584 Mdot
.54114 .01632 Mdot
.54117 .01503 Mdot
.5412 .0151 Mdot
.54122 .01572 Mdot
.54125 .01548 Mdot
.54127 .0155 Mdot
.5413 .0155 Mdot
.54132 .01519 Mdot
.54135 .01492 Mdot
.54138 .01532 Mdot
.5414 .01591 Mdot
.54143 .01565 Mdot
.54145 .0157 Mdot
.54148 .01538 Mdot
.54151 .01524 Mdot
.54153 .01574 Mdot
.54156 .01484 Mdot
.54158 .01494 Mdot
.54161 .01572 Mdot
.54163 .01495 Mdot
.54166 .01593 Mdot
.54169 .01571 Mdot
.54171 .01617 Mdot
.54174 .01573 Mdot
.54176 .01541 Mdot
.54179 .01522 Mdot
.54182 .01566 Mdot
.54184 .01557 Mdot
.54187 .01549 Mdot
.54189 .01624 Mdot
.54192 .01591 Mdot
.54194 .01619 Mdot
.54197 .01675 Mdot
.542 .01598 Mdot
.54202 .01564 Mdot
.54205 .01505 Mdot
.54207 .01547 Mdot
.5421 .01585 Mdot
.54213 .01539 Mdot
.54215 .01582 Mdot
.54218 .01542 Mdot
.5422 .01571 Mdot
.54223 .01635 Mdot
.54225 .01599 Mdot
.54228 .01584 Mdot
.54231 .01543 Mdot
.54233 .01535 Mdot
.54236 .0152 Mdot
.54238 .01532 Mdot
.54241 .01636 Mdot
.54244 .01578 Mdot
.54246 .01545 Mdot
.54249 .01554 Mdot
.54251 .01526 Mdot
.54254 .01618 Mdot
.54256 .01509 Mdot
.54259 .01508 Mdot
.54262 .0151 Mdot
.54264 .0159 Mdot
.54267 .0157 Mdot
.54269 .01583 Mdot
.54272 .01612 Mdot
.54275 .01588 Mdot
.54277 .01628 Mdot
.5428 .01514 Mdot
.54282 .0151 Mdot
.54285 .01539 Mdot
.54287 .01504 Mdot
.5429 .0155 Mdot
.54293 .01578 Mdot
.54295 .01586 Mdot
.54298 .01539 Mdot
.543 .01492 Mdot
.54303 .01625 Mdot
.54306 .01517 Mdot
.54308 .01481 Mdot
.54311 .01639 Mdot
.54313 .01562 Mdot
.54316 .0153 Mdot
.54318 .0164 Mdot
.54321 .01525 Mdot
.54324 .0152 Mdot
.54326 .01537 Mdot
.54329 .0159 Mdot
.54331 .01575 Mdot
.54334 .01504 Mdot
.54337 .01604 Mdot
.54339 .01505 Mdot
.54342 .0158 Mdot
.54344 .01573 Mdot
.54347 .01539 Mdot
.54349 .01548 Mdot
.54352 .01537 Mdot
.54355 .01594 Mdot
.54357 .01524 Mdot
.5436 .01512 Mdot
.54362 .01524 Mdot
.54365 .01551 Mdot
.54368 .0157 Mdot
.5437 .01625 Mdot
.54373 .01552 Mdot
.54375 .01486 Mdot
.54378 .01526 Mdot
.5438 .01594 Mdot
.54383 .01562 Mdot
.54386 .01577 Mdot
.54388 .01475 Mdot
.54391 .01635 Mdot
.54393 .01526 Mdot
.54396 .017 Mdot
.54399 .01646 Mdot
.54401 .01587 Mdot
.54404 .01564 Mdot
.54406 .01574 Mdot
.54409 .01584 Mdot
.54411 .01541 Mdot
.54414 .01555 Mdot
.54417 .01585 Mdot
.54419 .01539 Mdot
.54422 .01593 Mdot
.54424 .01582 Mdot
.54427 .01518 Mdot
.5443 .0163 Mdot
.54432 .01589 Mdot
.54435 .01553 Mdot
.54437 .01596 Mdot
.5444 .01538 Mdot
.54442 .01505 Mdot
.54445 .01592 Mdot
.54448 .01619 Mdot
.5445 .01605 Mdot
.54453 .01513 Mdot
.54455 .01571 Mdot
.54458 .01496 Mdot
.54461 .01573 Mdot
.54463 .01608 Mdot
.54466 .01508 Mdot
.54468 .0159 Mdot
.54471 .01628 Mdot
.54473 .01545 Mdot
.54476 .01669 Mdot
.54479 .01631 Mdot
.54481 .01592 Mdot
.54484 .0155 Mdot
.54486 .01604 Mdot
.54489 .01576 Mdot
.54492 .01569 Mdot
.54494 .01557 Mdot
.54497 .01606 Mdot
.54499 .016 Mdot
.54502 .01537 Mdot
.54504 .01538 Mdot
.54507 .01577 Mdot
.5451 .01579 Mdot
.54512 .01494 Mdot
.54515 .01551 Mdot
.54517 .01569 Mdot
.5452 .01632 Mdot
.54523 .01574 Mdot
.54525 .01558 Mdot
.54528 .01617 Mdot
.5453 .01553 Mdot
.54533 .01617 Mdot
.54535 .01536 Mdot
.54538 .0159 Mdot
.54541 .01507 Mdot
.54543 .01655 Mdot
.54546 .01553 Mdot
.54548 .01575 Mdot
.54551 .01655 Mdot
.54554 .01564 Mdot
.54556 .01574 Mdot
.54559 .01607 Mdot
.54561 .01538 Mdot
.54564 .0152 Mdot
.54566 .01556 Mdot
.54569 .01512 Mdot
.54572 .01535 Mdot
.54574 .01557 Mdot
.54577 .01567 Mdot
.54579 .01496 Mdot
.54582 .01527 Mdot
.54585 .01596 Mdot
.54587 .01568 Mdot
.5459 .01537 Mdot
.54592 .01494 Mdot
.54595 .01506 Mdot
.54597 .01571 Mdot
.546 .01533 Mdot
.54603 .01552 Mdot
.54605 .01523 Mdot
.54608 .01626 Mdot
.5461 .01491 Mdot
.54613 .01575 Mdot
.54616 .0159 Mdot
.54618 .01534 Mdot
.54621 .01492 Mdot
.54623 .01544 Mdot
.54626 .0151 Mdot
.54628 .01674 Mdot
.54631 .01603 Mdot
.54634 .01577 Mdot
.54636 .01509 Mdot
.54639 .01538 Mdot
.54641 .01516 Mdot
.54644 .01614 Mdot
.54647 .01548 Mdot
.54649 .0162 Mdot
.54652 .01555 Mdot
.54654 .01516 Mdot
.54657 .01522 Mdot
.54659 .01542 Mdot
.54662 .01543 Mdot
.54665 .01526 Mdot
.54667 .01596 Mdot
.5467 .01536 Mdot
.54672 .01573 Mdot
.54675 .0156 Mdot
.54678 .01559 Mdot
.5468 .0156 Mdot
.54683 .01644 Mdot
.54685 .01523 Mdot
.54688 .01587 Mdot
.5469 .01587 Mdot
.54693 .01624 Mdot
.54696 .01593 Mdot
.54698 .01567 Mdot
.54701 .01528 Mdot
.54703 .01578 Mdot
.54706 .01562 Mdot
.54709 .01596 Mdot
.54711 .01591 Mdot
.54714 .01573 Mdot
.54716 .01618 Mdot
.54719 .01556 Mdot
.54721 .01561 Mdot
.54724 .01637 Mdot
.54727 .01559 Mdot
.54729 .01533 Mdot
.54732 .01646 Mdot
.54734 .01512 Mdot
.54737 .01581 Mdot
.5474 .01578 Mdot
.54742 .01543 Mdot
.54745 .01506 Mdot
.54747 .01514 Mdot
.5475 .01579 Mdot
.54752 .01686 Mdot
.54755 .01587 Mdot
.54758 .01552 Mdot
.5476 .01558 Mdot
.54763 .01614 Mdot
.54765 .01531 Mdot
.54768 .016 Mdot
.54771 .01558 Mdot
.54773 .016 Mdot
.54776 .01559 Mdot
.54778 .015 Mdot
.54781 .01531 Mdot
.54783 .01605 Mdot
.54786 .01575 Mdot
.54789 .01504 Mdot
.54791 .01577 Mdot
.54794 .01612 Mdot
.54796 .01586 Mdot
.54799 .01485 Mdot
.54802 .01528 Mdot
.54804 .0156 Mdot
.54807 .01548 Mdot
.54809 .01506 Mdot
.54812 .01502 Mdot
.54814 .01519 Mdot
.54817 .01584 Mdot
.5482 .01588 Mdot
.54822 .01565 Mdot
.54825 .01501 Mdot
.54827 .01568 Mdot
.5483 .01537 Mdot
.54833 .01543 Mdot
.54835 .01579 Mdot
.54838 .0161 Mdot
.5484 .01552 Mdot
.54843 .01502 Mdot
.54845 .01577 Mdot
.54848 .01565 Mdot
.54851 .01509 Mdot
.54853 .01618 Mdot
.54856 .01605 Mdot
.54858 .01626 Mdot
.54861 .01603 Mdot
.54864 .01522 Mdot
.54866 .01575 Mdot
.54869 .0153 Mdot
.54871 .01681 Mdot
.54874 .01542 Mdot
.54876 .0154 Mdot
.54879 .01608 Mdot
.54882 .01504 Mdot
.54884 .01527 Mdot
.54887 .01572 Mdot
.54889 .01537 Mdot
.54892 .01678 Mdot
.54895 .01647 Mdot
.54897 .01634 Mdot
.549 .01652 Mdot
.54902 .01555 Mdot
.54905 .01558 Mdot
.54907 .01543 Mdot
.5491 .01567 Mdot
.54913 .01609 Mdot
.54915 .01476 Mdot
.54918 .01552 Mdot
.5492 .01566 Mdot
.54923 .01609 Mdot
.54926 .01545 Mdot
.54928 .01493 Mdot
.54931 .01598 Mdot
.54933 .01525 Mdot
.54936 .01519 Mdot
.54938 .01574 Mdot
.54941 .01508 Mdot
.54944 .01504 Mdot
.54946 .01568 Mdot
.54949 .01576 Mdot
.54951 .01556 Mdot
.54954 .0152 Mdot
.54957 .01512 Mdot
.54959 .01576 Mdot
.54962 .01573 Mdot
.54964 .01499 Mdot
.54967 .0154 Mdot
.54969 .01583 Mdot
.54972 .01606 Mdot
.54975 .01545 Mdot
.54977 .01512 Mdot
.5498 .01551 Mdot
.54982 .01564 Mdot
.54985 .0153 Mdot
.54988 .01513 Mdot
.5499 .01576 Mdot
.54993 .01629 Mdot
.54995 .01488 Mdot
.54998 .01655 Mdot
.55 .01617 Mdot
.55003 .01531 Mdot
.55006 .01508 Mdot
.55008 .01589 Mdot
.55011 .01585 Mdot
.55013 .0157 Mdot
.55016 .01635 Mdot
.55019 .01506 Mdot
.55021 .01598 Mdot
.55024 .01649 Mdot
.55026 .01631 Mdot
.55029 .01635 Mdot
.55032 .01588 Mdot
.55034 .01536 Mdot
.55037 .01717 Mdot
.55039 .01548 Mdot
.55042 .01541 Mdot
.55044 .01548 Mdot
.55047 .01553 Mdot
.5505 .01493 Mdot
.55052 .01592 Mdot
.55055 .01499 Mdot
.55057 .01551 Mdot
.5506 .01582 Mdot
.55063 .01486 Mdot
.55065 .01558 Mdot
.55068 .01517 Mdot
.5507 .0156 Mdot
.55073 .01496 Mdot
.55075 .01505 Mdot
.55078 .01582 Mdot
.55081 .0165 Mdot
.55083 .0167 Mdot
.55086 .01517 Mdot
.55088 .0156 Mdot
.55091 .01521 Mdot
.55094 .01511 Mdot
.55096 .01578 Mdot
.55099 .01533 Mdot
.55101 .01648 Mdot
.55104 .01545 Mdot
.55106 .01483 Mdot
.55109 .01543 Mdot
.55112 .01496 Mdot
.55114 .01563 Mdot
.55117 .01584 Mdot
.55119 .0154 Mdot
.55122 .01502 Mdot
.55125 .01496 Mdot
.55127 .0153 Mdot
.5513 .01598 Mdot
.55132 .01502 Mdot
.55135 .01527 Mdot
.55137 .01534 Mdot
.5514 .01595 Mdot
.55143 .0152 Mdot
.55145 .01492 Mdot
.55148 .01631 Mdot
.5515 .01591 Mdot
.55153 .015 Mdot
.55156 .01678 Mdot
.55158 .01615 Mdot
.55161 .01686 Mdot
.55163 .01534 Mdot
.55166 .01525 Mdot
.55168 .01568 Mdot
.55171 .01502 Mdot
.55174 .01492 Mdot
.55176 .01535 Mdot
.55179 .01547 Mdot
.55181 .01586 Mdot
.55184 .01527 Mdot
.55187 .01662 Mdot
.55189 .01534 Mdot
.55192 .01535 Mdot
.55194 .01578 Mdot
.55197 .01543 Mdot
.55199 .0155 Mdot
.55202 .01566 Mdot
.55205 .01492 Mdot
.55207 .01596 Mdot
.5521 .01519 Mdot
.55212 .01629 Mdot
.55215 .01595 Mdot
.55218 .01589 Mdot
.5522 .01622 Mdot
.55223 .01547 Mdot
.55225 .01602 Mdot
.55228 .01603 Mdot
.5523 .01529 Mdot
.55233 .01502 Mdot
.55236 .01598 Mdot
.55238 .01667 Mdot
.55241 .01594 Mdot
.55243 .01522 Mdot
.55246 .01612 Mdot
.55249 .01522 Mdot
.55251 .01498 Mdot
.55254 .01652 Mdot
.55256 .01529 Mdot
.55259 .01569 Mdot
.55261 .01515 Mdot
.55264 .01514 Mdot
.55267 .01614 Mdot
.55269 .01514 Mdot
.55272 .01615 Mdot
.55274 .01598 Mdot
.55277 .01551 Mdot
.5528 .01632 Mdot
.55282 .01563 Mdot
.55285 .01564 Mdot
.55287 .01602 Mdot
.5529 .0157 Mdot
.55292 .01598 Mdot
.55295 .01586 Mdot
.55298 .01567 Mdot
.553 .01498 Mdot
.55303 .0162 Mdot
.55305 .01513 Mdot
.55308 .01537 Mdot
.55311 .01591 Mdot
.55313 .01593 Mdot
.55316 .01636 Mdot
.55318 .01515 Mdot
.55321 .01595 Mdot
.55323 .01521 Mdot
.55326 .0157 Mdot
.55329 .01502 Mdot
.55331 .01581 Mdot
.55334 .01575 Mdot
.55336 .01498 Mdot
.55339 .01561 Mdot
.55342 .01511 Mdot
.55344 .01497 Mdot
.55347 .01583 Mdot
.55349 .01537 Mdot
.55352 .01526 Mdot
.55354 .01521 Mdot
.55357 .0158 Mdot
.5536 .01559 Mdot
.55362 .01497 Mdot
.55365 .01482 Mdot
.55367 .01519 Mdot
.5537 .01536 Mdot
.55373 .01523 Mdot
.55375 .01519 Mdot
.55378 .01484 Mdot
.5538 .01561 Mdot
.55383 .01609 Mdot
.55385 .01652 Mdot
.55388 .01558 Mdot
.55391 .01537 Mdot
.55393 .01671 Mdot
.55396 .01558 Mdot
.55398 .01529 Mdot
.55401 .01552 Mdot
.55404 .01606 Mdot
.55406 .01555 Mdot
.55409 .01549 Mdot
.55411 .01564 Mdot
.55414 .01514 Mdot
.55416 .01537 Mdot
.55419 .01561 Mdot
.55422 .01566 Mdot
.55424 .01657 Mdot
.55427 .01616 Mdot
.55429 .01497 Mdot
.55432 .01545 Mdot
.55435 .01538 Mdot
.55437 .01567 Mdot
.5544 .01519 Mdot
.55442 .01589 Mdot
.55445 .01473 Mdot
.55447 .01552 Mdot
.5545 .01547 Mdot
.55453 .01574 Mdot
.55455 .01537 Mdot
.55458 .01478 Mdot
.5546 .01513 Mdot
.55463 .01558 Mdot
.55466 .01531 Mdot
.55468 .01644 Mdot
.55471 .01604 Mdot
.55473 .01638 Mdot
.55476 .01496 Mdot
.55478 .01506 Mdot
.55481 .01551 Mdot
.55484 .01548 Mdot
.55486 .01498 Mdot
.55489 .01544 Mdot
.55491 .01553 Mdot
.55494 .01503 Mdot
.55497 .01557 Mdot
.55499 .01588 Mdot
.55502 .01517 Mdot
.55504 .01555 Mdot
.55507 .01543 Mdot
.55509 .01532 Mdot
.55512 .01564 Mdot
.55515 .01538 Mdot
.55517 .01537 Mdot
.5552 .0155 Mdot
.55522 .01502 Mdot
.55525 .01513 Mdot
.55528 .01516 Mdot
.5553 .01551 Mdot
.55533 .01596 Mdot
.55535 .01547 Mdot
.55538 .01499 Mdot
.5554 .01563 Mdot
.55543 .01525 Mdot
.55546 .01526 Mdot
.55548 .01642 Mdot
.55551 .01583 Mdot
.55553 .01545 Mdot
.55556 .01524 Mdot
.55559 .01613 Mdot
.55561 .01496 Mdot
.55564 .01541 Mdot
.55566 .01506 Mdot
.55569 .0158 Mdot
.55571 .01487 Mdot
.55574 .01515 Mdot
.55577 .01577 Mdot
.55579 .01548 Mdot
.55582 .0155 Mdot
.55584 .01562 Mdot
.55587 .01528 Mdot
.5559 .01611 Mdot
.55592 .01574 Mdot
.55595 .01613 Mdot
.55597 .01526 Mdot
.556 .01533 Mdot
.55602 .0151 Mdot
.55605 .01588 Mdot
.55608 .016 Mdot
.5561 .01536 Mdot
.55613 .016 Mdot
.55615 .0162 Mdot
.55618 .01577 Mdot
.55621 .01576 Mdot
.55623 .01674 Mdot
.55626 .01544 Mdot
.55628 .01523 Mdot
.55631 .015 Mdot
.55633 .01566 Mdot
.55636 .01564 Mdot
.55639 .01564 Mdot
.55641 .01727 Mdot
.55644 .01565 Mdot
.55646 .01472 Mdot
.55649 .01495 Mdot
.55652 .01583 Mdot
.55654 .01583 Mdot
.55657 .01694 Mdot
.55659 .01493 Mdot
.55662 .01544 Mdot
.55664 .01511 Mdot
.55667 .0156 Mdot
.5567 .01518 Mdot
.55672 .0157 Mdot
.55675 .01531 Mdot
.55677 .01543 Mdot
.5568 .01612 Mdot
.55683 .01526 Mdot
.55685 .01589 Mdot
.55688 .01532 Mdot
.5569 .01526 Mdot
.55693 .01595 Mdot
.55695 .01546 Mdot
.55698 .01537 Mdot
.55701 .0153 Mdot
.55703 .01501 Mdot
.55706 .01571 Mdot
.55708 .01551 Mdot
.55711 .01536 Mdot
.55714 .01549 Mdot
.55716 .01553 Mdot
.55719 .01553 Mdot
.55721 .01567 Mdot
.55724 .01528 Mdot
.55726 .01545 Mdot
.55729 .01604 Mdot
.55732 .01572 Mdot
.55734 .01509 Mdot
.55737 .01544 Mdot
.55739 .01559 Mdot
.55742 .01543 Mdot
.55745 .01514 Mdot
.55747 .0159 Mdot
.5575 .01516 Mdot
.55752 .01649 Mdot
.55755 .01564 Mdot
.55757 .01611 Mdot
.5576 .01566 Mdot
.55763 .01507 Mdot
.55765 .01565 Mdot
.55768 .01511 Mdot
.5577 .01571 Mdot
.55773 .01529 Mdot
.55776 .01588 Mdot
.55778 .01569 Mdot
.55781 .01563 Mdot
.55783 .01518 Mdot
.55786 .01556 Mdot
.55788 .01558 Mdot
.55791 .01569 Mdot
.55794 .01531 Mdot
.55796 .01525 Mdot
.55799 .01539 Mdot
.55801 .01537 Mdot
.55804 .01543 Mdot
.55807 .01515 Mdot
.55809 .01565 Mdot
.55812 .01554 Mdot
.55814 .01581 Mdot
.55817 .01576 Mdot
.55819 .01555 Mdot
.55822 .01542 Mdot
.55825 .01496 Mdot
.55827 .01512 Mdot
.5583 .01508 Mdot
.55832 .01531 Mdot
.55835 .01595 Mdot
.55838 .01595 Mdot
.5584 .01608 Mdot
.55843 .01557 Mdot
.55845 .01555 Mdot
.55848 .01582 Mdot
.5585 .01651 Mdot
.55853 .01663 Mdot
.55856 .01679 Mdot
.55858 .0149 Mdot
.55861 .01548 Mdot
.55863 .01551 Mdot
.55866 .01561 Mdot
.55869 .01582 Mdot
.55871 .0157 Mdot
.55874 .01618 Mdot
.55876 .01522 Mdot
.55879 .01478 Mdot
.55881 .01552 Mdot
.55884 .01591 Mdot
.55887 .01537 Mdot
.55889 .01496 Mdot
.55892 .01523 Mdot
.55894 .01629 Mdot
.55897 .0161 Mdot
.559 .01577 Mdot
.55902 .01556 Mdot
.55905 .01537 Mdot
.55907 .01633 Mdot
.5591 .01523 Mdot
.55912 .01527 Mdot
.55915 .01594 Mdot
.55918 .01559 Mdot
.5592 .0152 Mdot
.55923 .01573 Mdot
.55925 .01557 Mdot
.55928 .01655 Mdot
.55931 .01613 Mdot
.55933 .01519 Mdot
.55936 .0153 Mdot
.55938 .01669 Mdot
.55941 .01502 Mdot
.55943 .01557 Mdot
.55946 .01581 Mdot
.55949 .01575 Mdot
.55951 .01609 Mdot
.55954 .01542 Mdot
.55956 .01493 Mdot
.55959 .01512 Mdot
.55962 .01547 Mdot
.55964 .01482 Mdot
.55967 .01681 Mdot
.55969 .01515 Mdot
.55972 .01606 Mdot
.55975 .01584 Mdot
.55977 .01516 Mdot
.5598 .01615 Mdot
.55982 .0152 Mdot
.55985 .01574 Mdot
.55987 .01591 Mdot
.5599 .01523 Mdot
.55993 .01615 Mdot
.55995 .01541 Mdot
.55998 .01623 Mdot
.56 .01638 Mdot
.56003 .0152 Mdot
.56006 .01596 Mdot
.56008 .01638 Mdot
.56011 .01495 Mdot
.56013 .01588 Mdot
.56016 .01606 Mdot
.56018 .01516 Mdot
.56021 .01597 Mdot
.56024 .01573 Mdot
.56026 .01603 Mdot
.56029 .01565 Mdot
.56031 .01568 Mdot
.56034 .01502 Mdot
.56037 .01509 Mdot
.56039 .01535 Mdot
.56042 .01584 Mdot
.56044 .01503 Mdot
.56047 .01516 Mdot
.56049 .01604 Mdot
.56052 .01591 Mdot
.56055 .01495 Mdot
.56057 .01519 Mdot
.5606 .01625 Mdot
.56062 .01487 Mdot
.56065 .01685 Mdot
.56068 .01522 Mdot
.5607 .0148 Mdot
.56073 .01537 Mdot
.56075 .01589 Mdot
.56078 .01627 Mdot
.5608 .01621 Mdot
.56083 .0155 Mdot
.56086 .0155 Mdot
.56088 .01591 Mdot
.56091 .01587 Mdot
.56093 .01647 Mdot
.56096 .01543 Mdot
.56099 .01556 Mdot
.56101 .01596 Mdot
.56104 .01626 Mdot
.56106 .0153 Mdot
.56109 .01547 Mdot
.56111 .01536 Mdot
.56114 .01615 Mdot
.56117 .01701 Mdot
.56119 .01607 Mdot
.56122 .01539 Mdot
.56124 .01571 Mdot
.56127 .01566 Mdot
.5613 .01627 Mdot
.56132 .01545 Mdot
.56135 .01515 Mdot
.56137 .01525 Mdot
.5614 .01542 Mdot
.56142 .01578 Mdot
.56145 .01496 Mdot
.56148 .01574 Mdot
.5615 .01521 Mdot
.56153 .01566 Mdot
.56155 .015 Mdot
.56158 .01574 Mdot
.56161 .01591 Mdot
.56163 .01549 Mdot
.56166 .01503 Mdot
.56168 .015 Mdot
.56171 .01591 Mdot
.56173 .0166 Mdot
.56176 .01683 Mdot
.56179 .0159 Mdot
.56181 .01541 Mdot
.56184 .01575 Mdot
.56186 .01522 Mdot
.56189 .01542 Mdot
.56192 .01538 Mdot
.56194 .01527 Mdot
.56197 .01495 Mdot
.56199 .01526 Mdot
.56202 .016 Mdot
.56204 .01522 Mdot
.56207 .01501 Mdot
.5621 .01582 Mdot
.56212 .01512 Mdot
.56215 .01615 Mdot
.56217 .01611 Mdot
.5622 .017 Mdot
.56223 .01639 Mdot
.56225 .01542 Mdot
.56228 .01771 Mdot
.5623 .01521 Mdot
.56233 .01487 Mdot
.56235 .01586 Mdot
.56238 .01593 Mdot
.56241 .01604 Mdot
.56243 .01505 Mdot
.56246 .01575 Mdot
.56248 .01629 Mdot
.56251 .01505 Mdot
.56254 .01546 Mdot
.56256 .01558 Mdot
.56259 .01547 Mdot
.56261 .01521 Mdot
.56264 .01544 Mdot
.56266 .01565 Mdot
.56269 .01624 Mdot
.56272 .01509 Mdot
.56274 .01506 Mdot
.56277 .01638 Mdot
.56279 .01633 Mdot
.56282 .01569 Mdot
.56285 .01569 Mdot
.56287 .01582 Mdot
.5629 .01535 Mdot
.56292 .01587 Mdot
.56295 .01501 Mdot
.56297 .01585 Mdot
.563 .01569 Mdot
.56303 .01654 Mdot
.56305 .01552 Mdot
.56308 .01583 Mdot
.5631 .01526 Mdot
.56313 .01588 Mdot
.56316 .01567 Mdot
.56318 .01494 Mdot
.56321 .0149 Mdot
.56323 .0155 Mdot
.56326 .0156 Mdot
.56328 .0164 Mdot
.56331 .01582 Mdot
.56334 .01513 Mdot
.56336 .01634 Mdot
.56339 .01568 Mdot
.56341 .01543 Mdot
.56344 .01578 Mdot
.56347 .01523 Mdot
.56349 .01592 Mdot
.56352 .015 Mdot
.56354 .01538 Mdot
.56357 .0154 Mdot
.56359 .01525 Mdot
.56362 .015 Mdot
.56365 .01507 Mdot
.56367 .0163 Mdot
.5637 .01583 Mdot
.56372 .01641 Mdot
.56375 .0162 Mdot
.56378 .01539 Mdot
.5638 .01563 Mdot
.56383 .01621 Mdot
.56385 .015 Mdot
.56388 .01715 Mdot
.5639 .01572 Mdot
.56393 .01645 Mdot
.56396 .01558 Mdot
.56398 .01571 Mdot
.56401 .01487 Mdot
.56403 .01573 Mdot
.56406 .01526 Mdot
.56409 .0166 Mdot
.56411 .01699 Mdot
.56414 .01633 Mdot
.56416 .01553 Mdot
.56419 .01504 Mdot
.56421 .01547 Mdot
.56424 .0157 Mdot
.56427 .01552 Mdot
.56429 .01573 Mdot
.56432 .01624 Mdot
.56434 .01508 Mdot
.56437 .01533 Mdot
.5644 .01524 Mdot
.56442 .01578 Mdot
.56445 .01565 Mdot
.56447 .0157 Mdot
.5645 .01522 Mdot
.56452 .01509 Mdot
.56455 .01538 Mdot
.56458 .01558 Mdot
.5646 .01505 Mdot
.56463 .01527 Mdot
.56465 .01511 Mdot
.56468 .01509 Mdot
.56471 .0161 Mdot
.56473 .01529 Mdot
.56476 .01524 Mdot
.56478 .0161 Mdot
.56481 .0153 Mdot
.56483 .01635 Mdot
.56486 .01529 Mdot
.56489 .01551 Mdot
.56491 .01521 Mdot
.56494 .01512 Mdot
.56496 .01497 Mdot
.56499 .01583 Mdot
.56502 .01632 Mdot
.56504 .01662 Mdot
.56507 .01554 Mdot
.56509 .01665 Mdot
.56512 .01545 Mdot
.56514 .01487 Mdot
.56517 .01562 Mdot
.5652 .01557 Mdot
.56522 .01614 Mdot
.56525 .01562 Mdot
.56527 .01606 Mdot
.5653 .01601 Mdot
.56533 .0161 Mdot
.56535 .01678 Mdot
.56538 .01576 Mdot
.5654 .01616 Mdot
.56543 .01709 Mdot
.56545 .01509 Mdot
.56548 .01676 Mdot
.56551 .01504 Mdot
.56553 .01608 Mdot
.56556 .01532 Mdot
.56558 .01563 Mdot
.56561 .01521 Mdot
.56564 .01596 Mdot
.56566 .01526 Mdot
.56569 .0157 Mdot
.56571 .01572 Mdot
.56574 .01576 Mdot
.56576 .0163 Mdot
.56579 .01513 Mdot
.56582 .01667 Mdot
.56584 .01511 Mdot
.56587 .0155 Mdot
.56589 .01643 Mdot
.56592 .01654 Mdot
.56595 .01597 Mdot
.56597 .01534 Mdot
.566 .0151 Mdot
.56602 .01649 Mdot
.56605 .01506 Mdot
.56607 .01565 Mdot
.5661 .01532 Mdot
.56613 .01715 Mdot
.56615 .01537 Mdot
.56618 .01624 Mdot
.5662 .01661 Mdot
.56623 .01555 Mdot
.56626 .01572 Mdot
.56628 .0152 Mdot
.56631 .01595 Mdot
.56633 .01626 Mdot
.56636 .0154 Mdot
.56638 .01595 Mdot
.56641 .0151 Mdot
.56644 .01578 Mdot
.56646 .01557 Mdot
.56649 .01623 Mdot
.56651 .01774 Mdot
.56654 .01495 Mdot
.56657 .01543 Mdot
.56659 .01555 Mdot
.56662 .01632 Mdot
.56664 .01588 Mdot
.56667 .01568 Mdot
.56669 .01587 Mdot
.56672 .0161 Mdot
.56675 .01538 Mdot
.56677 .01531 Mdot
.5668 .01517 Mdot
.56682 .01546 Mdot
.56685 .01619 Mdot
.56688 .01635 Mdot
.5669 .01627 Mdot
.56693 .01546 Mdot
.56695 .01555 Mdot
.56698 .01532 Mdot
.567 .01677 Mdot
.56703 .01524 Mdot
.56706 .01699 Mdot
.56708 .01585 Mdot
.56711 .01534 Mdot
.56713 .01573 Mdot
.56716 .01522 Mdot
.56719 .01483 Mdot
.56721 .01516 Mdot
.56724 .01522 Mdot
.56726 .01665 Mdot
.56729 .01529 Mdot
.56731 .0161 Mdot
.56734 .01632 Mdot
.56737 .01572 Mdot
.56739 .01529 Mdot
.56742 .01508 Mdot
.56744 .01579 Mdot
.56747 .01673 Mdot
.5675 .01584 Mdot
.56752 .01516 Mdot
.56755 .01555 Mdot
.56757 .01623 Mdot
.5676 .01584 Mdot
.56762 .01669 Mdot
.56765 .01513 Mdot
.56768 .01526 Mdot
.5677 .01567 Mdot
.56773 .01648 Mdot
.56775 .01512 Mdot
.56778 .01641 Mdot
.56781 .01513 Mdot
.56783 .01578 Mdot
.56786 .0166 Mdot
.56788 .01653 Mdot
.56791 .01651 Mdot
.56793 .01623 Mdot
.56796 .0159 Mdot
.56799 .01565 Mdot
.56801 .01532 Mdot
.56804 .01548 Mdot
.56806 .01475 Mdot
.56809 .01579 Mdot
.56812 .01604 Mdot
.56814 .01527 Mdot
.56817 .01535 Mdot
.56819 .01599 Mdot
.56822 .01521 Mdot
.56824 .01519 Mdot
.56827 .01584 Mdot
.5683 .01513 Mdot
.56832 .01571 Mdot
.56835 .01574 Mdot
.56837 .01528 Mdot
.5684 .01553 Mdot
.56843 .01592 Mdot
.56845 .01598 Mdot
.56848 .01599 Mdot
.5685 .01525 Mdot
.56853 .01614 Mdot
.56855 .01573 Mdot
.56858 .01542 Mdot
.56861 .01745 Mdot
.56863 .01528 Mdot
.56866 .01521 Mdot
.56868 .01596 Mdot
.56871 .01498 Mdot
.56874 .01603 Mdot
.56876 .01579 Mdot
.56879 .0157 Mdot
.56881 .0161 Mdot
.56884 .01516 Mdot
.56887 .01559 Mdot
.56889 .01588 Mdot
.56892 .01654 Mdot
.56894 .01566 Mdot
.56897 .01538 Mdot
.56899 .01583 Mdot
.56902 .01526 Mdot
.56905 .01519 Mdot
.56907 .01525 Mdot
.5691 .0155 Mdot
.56912 .01657 Mdot
.56915 .01605 Mdot
.56918 .01619 Mdot
.5692 .01591 Mdot
.56923 .01544 Mdot
.56925 .01499 Mdot
.56928 .01613 Mdot
.5693 .01705 Mdot
.56933 .01529 Mdot
.56936 .01524 Mdot
.56938 .01565 Mdot
.56941 .01584 Mdot
.56943 .01624 Mdot
.56946 .01538 Mdot
.56949 .01545 Mdot
.56951 .0153 Mdot
.56954 .01543 Mdot
.56956 .01504 Mdot
.56959 .01525 Mdot
.56961 .01516 Mdot
.56964 .01554 Mdot
.56967 .01588 Mdot
.56969 .01534 Mdot
.56972 .01543 Mdot
.56974 .0154 Mdot
.56977 .01594 Mdot
.5698 .01563 Mdot
.56982 .01598 Mdot
.56985 .01553 Mdot
.56987 .01585 Mdot
.5699 .01542 Mdot
.56992 .01744 Mdot
.56995 .01593 Mdot
.56998 .01562 Mdot
.57 .01536 Mdot
.57003 .01577 Mdot
.57005 .01633 Mdot
.57008 .01606 Mdot
.57011 .01571 Mdot
.57013 .01514 Mdot
.57016 .01599 Mdot
.57018 .01598 Mdot
.57021 .01694 Mdot
.57023 .0155 Mdot
.57026 .01526 Mdot
.57029 .01594 Mdot
.57031 .01547 Mdot
.57034 .01586 Mdot
.57036 .01568 Mdot
.57039 .01613 Mdot
.57042 .01513 Mdot
.57044 .01569 Mdot
.57047 .01533 Mdot
.57049 .01668 Mdot
.57052 .01586 Mdot
.57054 .01572 Mdot
.57057 .01652 Mdot
.5706 .01529 Mdot
.57062 .0158 Mdot
.57065 .01624 Mdot
.57067 .01523 Mdot
.5707 .01586 Mdot
.57073 .01565 Mdot
.57075 .01686 Mdot
.57078 .01523 Mdot
.5708 .01555 Mdot
.57083 .01503 Mdot
.57085 .01543 Mdot
.57088 .01519 Mdot
.57091 .01655 Mdot
.57093 .01558 Mdot
.57096 .01611 Mdot
.57098 .01771 Mdot
.57101 .01586 Mdot
.57104 .01599 Mdot
.57106 .01596 Mdot
.57109 .01598 Mdot
.57111 .01507 Mdot
.57114 .01643 Mdot
.57116 .01502 Mdot
.57119 .01546 Mdot
.57122 .01674 Mdot
.57124 .01476 Mdot
.57127 .01558 Mdot
.57129 .01744 Mdot
.57132 .01697 Mdot
.57135 .01595 Mdot
.57137 .01509 Mdot
.5714 .01536 Mdot
.57142 .01634 Mdot
.57145 .01624 Mdot
.57147 .01586 Mdot
.5715 .01622 Mdot
.57153 .01637 Mdot
.57155 .01591 Mdot
.57158 .01607 Mdot
.5716 .01746 Mdot
.57163 .01531 Mdot
.57166 .01546 Mdot
.57168 .01611 Mdot
.57171 .01638 Mdot
.57173 .01598 Mdot
.57176 .01503 Mdot
.57178 .01624 Mdot
.57181 .01705 Mdot
.57184 .01548 Mdot
.57186 .01548 Mdot
.57189 .0151 Mdot
.57191 .01587 Mdot
.57194 .01677 Mdot
.57197 .01514 Mdot
.57199 .01523 Mdot
.57202 .01515 Mdot
.57204 .01725 Mdot
.57207 .01487 Mdot
.57209 .01566 Mdot
.57212 .01646 Mdot
.57215 .01601 Mdot
.57217 .01548 Mdot
.5722 .01576 Mdot
.57222 .0148 Mdot
.57225 .01528 Mdot
.57228 .0159 Mdot
.5723 .01589 Mdot
.57233 .01581 Mdot
.57235 .01535 Mdot
.57238 .01699 Mdot
.5724 .01606 Mdot
.57243 .0155 Mdot
.57246 .01529 Mdot
.57248 .01483 Mdot
.57251 .01531 Mdot
.57253 .01633 Mdot
.57256 .01625 Mdot
.57259 .01664 Mdot
.57261 .01563 Mdot
.57264 .01694 Mdot
.57266 .01603 Mdot
.57269 .01583 Mdot
.57271 .01545 Mdot
.57274 .01663 Mdot
.57277 .01636 Mdot
.57279 .01577 Mdot
.57282 .01602 Mdot
.57284 .01567 Mdot
.57287 .01514 Mdot
.5729 .01626 Mdot
.57292 .01651 Mdot
.57295 .01558 Mdot
.57297 .01712 Mdot
.573 .01598 Mdot
.57302 .0163 Mdot
.57305 .01645 Mdot
.57308 .0156 Mdot
.5731 .01548 Mdot
.57313 .01577 Mdot
.57315 .01592 Mdot
.57318 .01649 Mdot
.57321 .01474 Mdot
.57323 .015 Mdot
.57326 .0164 Mdot
.57328 .01596 Mdot
.57331 .01576 Mdot
.57333 .01569 Mdot
.57336 .01554 Mdot
.57339 .01583 Mdot
.57341 .01564 Mdot
.57344 .0159 Mdot
.57346 .01628 Mdot
.57349 .0155 Mdot
.57352 .01525 Mdot
.57354 .01614 Mdot
.57357 .01564 Mdot
.57359 .01595 Mdot
.57362 .01535 Mdot
.57364 .01534 Mdot
.57367 .01621 Mdot
.5737 .01649 Mdot
.57372 .01625 Mdot
.57375 .01642 Mdot
.57377 .01601 Mdot
.5738 .01571 Mdot
.57383 .01537 Mdot
.57385 .01581 Mdot
.57388 .01557 Mdot
.5739 .01643 Mdot
.57393 .01538 Mdot
.57395 .01526 Mdot
.57398 .01572 Mdot
.57401 .01602 Mdot
.57403 .0154 Mdot
.57406 .0159 Mdot
.57408 .01524 Mdot
.57411 .01617 Mdot
.57414 .01537 Mdot
.57416 .01565 Mdot
.57419 .01598 Mdot
.57421 .01513 Mdot
.57424 .0154 Mdot
.57426 .01542 Mdot
.57429 .01581 Mdot
.57432 .01611 Mdot
.57434 .01531 Mdot
.57437 .01571 Mdot
.57439 .01585 Mdot
.57442 .01592 Mdot
.57445 .01552 Mdot
.57447 .01565 Mdot
.5745 .01508 Mdot
.57452 .01522 Mdot
.57455 .0164 Mdot
.57457 .01619 Mdot
.5746 .01545 Mdot
.57463 .015 Mdot
.57465 .01552 Mdot
.57468 .01535 Mdot
.5747 .01486 Mdot
.57473 .01586 Mdot
.57476 .01543 Mdot
.57478 .01501 Mdot
.57481 .01655 Mdot
.57483 .01687 Mdot
.57486 .0158 Mdot
.57488 .01561 Mdot
.57491 .0154 Mdot
.57494 .01596 Mdot
.57496 .01565 Mdot
.57499 .01579 Mdot
.57501 .01633 Mdot
.57504 .01554 Mdot
.57507 .01648 Mdot
.57509 .01515 Mdot
.57512 .01544 Mdot
.57514 .01533 Mdot
.57517 .01539 Mdot
.57519 .01574 Mdot
.57522 .01489 Mdot
.57525 .01675 Mdot
.57527 .01607 Mdot
.5753 .01531 Mdot
.57532 .01636 Mdot
.57535 .01538 Mdot
.57538 .0161 Mdot
.5754 .01622 Mdot
.57543 .01487 Mdot
.57545 .01497 Mdot
.57548 .01513 Mdot
.5755 .01583 Mdot
.57553 .01541 Mdot
.57556 .01604 Mdot
.57558 .01567 Mdot
.57561 .01589 Mdot
.57563 .01518 Mdot
.57566 .01567 Mdot
.57569 .01617 Mdot
.57571 .01746 Mdot
.57574 .01545 Mdot
.57576 .01638 Mdot
.57579 .01503 Mdot
.57581 .01559 Mdot
.57584 .01645 Mdot
.57587 .01531 Mdot
.57589 .01568 Mdot
.57592 .01626 Mdot
.57594 .01487 Mdot
.57597 .01633 Mdot
.576 .01629 Mdot
.57602 .0161 Mdot
.57605 .01514 Mdot
.57607 .01578 Mdot
.5761 .01507 Mdot
.57612 .01592 Mdot
.57615 .0158 Mdot
.57618 .01499 Mdot
.5762 .01623 Mdot
.57623 .01572 Mdot
.57625 .01621 Mdot
.57628 .01616 Mdot
.57631 .01606 Mdot
.57633 .01551 Mdot
.57636 .01544 Mdot
.57638 .01605 Mdot
.57641 .01581 Mdot
.57643 .01686 Mdot
.57646 .01548 Mdot
.57649 .0161 Mdot
.57651 .016 Mdot
.57654 .01536 Mdot
.57656 .01524 Mdot
.57659 .01527 Mdot
.57662 .01581 Mdot
.57664 .01544 Mdot
.57667 .0156 Mdot
.57669 .0166 Mdot
.57672 .01531 Mdot
.57674 .01728 Mdot
.57677 .01657 Mdot
.5768 .01584 Mdot
.57682 .01562 Mdot
.57685 .01523 Mdot
.57687 .01637 Mdot
.5769 .01604 Mdot
.57693 .01665 Mdot
.57695 .01517 Mdot
.57698 .01519 Mdot
.577 .01579 Mdot
.57703 .01575 Mdot
.57705 .01625 Mdot
.57708 .01586 Mdot
.57711 .0152 Mdot
.57713 .01553 Mdot
.57716 .01583 Mdot
.57718 .01505 Mdot
.57721 .01573 Mdot
.57724 .01513 Mdot
.57726 .01622 Mdot
.57729 .0154 Mdot
.57731 .01586 Mdot
.57734 .01579 Mdot
.57736 .01583 Mdot
.57739 .01608 Mdot
.57742 .01646 Mdot
.57744 .01684 Mdot
.57747 .01661 Mdot
.57749 .01516 Mdot
.57752 .01577 Mdot
.57755 .015 Mdot
.57757 .01505 Mdot
.5776 .01561 Mdot
.57762 .01533 Mdot
.57765 .0157 Mdot
.57767 .01574 Mdot
.5777 .01667 Mdot
.57773 .01567 Mdot
.57775 .01691 Mdot
.57778 .01478 Mdot
.5778 .01517 Mdot
.57783 .01498 Mdot
.57786 .01492 Mdot
.57788 .01589 Mdot
.57791 .01553 Mdot
.57793 .0154 Mdot
.57796 .01507 Mdot
.57799 .01545 Mdot
.57801 .01653 Mdot
.57804 .0158 Mdot
.57806 .01505 Mdot
.57809 .01601 Mdot
.57811 .01615 Mdot
.57814 .01538 Mdot
.57817 .01533 Mdot
.57819 .01522 Mdot
.57822 .01619 Mdot
.57824 .01535 Mdot
.57827 .01686 Mdot
.5783 .01621 Mdot
.57832 .0153 Mdot
.57835 .0161 Mdot
.57837 .01485 Mdot
.5784 .0157 Mdot
.57842 .0151 Mdot
.57845 .01548 Mdot
.57848 .01666 Mdot
.5785 .01524 Mdot
.57853 .01529 Mdot
.57855 .01563 Mdot
.57858 .01529 Mdot
.57861 .01505 Mdot
.57863 .01539 Mdot
.57866 .01518 Mdot
.57868 .01509 Mdot
.57871 .01596 Mdot
.57873 .01633 Mdot
.57876 .01563 Mdot
.57879 .01555 Mdot
.57881 .01563 Mdot
.57884 .01547 Mdot
.57886 .01532 Mdot
.57889 .01542 Mdot
.57892 .01646 Mdot
.57894 .01615 Mdot
.57897 .01558 Mdot
.57899 .01588 Mdot
.57902 .01553 Mdot
.57904 .01584 Mdot
.57907 .01526 Mdot
.5791 .01594 Mdot
.57912 .01589 Mdot
.57915 .0159 Mdot
.57917 .01572 Mdot
.5792 .0165 Mdot
.57923 .01564 Mdot
.57925 .01565 Mdot
.57928 .01525 Mdot
.5793 .01538 Mdot
.57933 .01515 Mdot
.57935 .01513 Mdot
.57938 .01531 Mdot
.57941 .01619 Mdot
.57943 .01503 Mdot
.57946 .0161 Mdot
.57948 .01523 Mdot
.57951 .01634 Mdot
.57954 .01575 Mdot
.57956 .01528 Mdot
.57959 .01544 Mdot
.57961 .01602 Mdot
.57964 .01487 Mdot
.57966 .01654 Mdot
.57969 .0156 Mdot
.57972 .01608 Mdot
.57974 .01558 Mdot
.57977 .01583 Mdot
.57979 .01564 Mdot
.57982 .0161 Mdot
.57985 .01499 Mdot
.57987 .01507 Mdot
.5799 .01508 Mdot
.57992 .01502 Mdot
.57995 .01578 Mdot
.57997 .01495 Mdot
.58 .01534 Mdot
.58003 .01563 Mdot
.58005 .01645 Mdot
.58008 .01541 Mdot
.5801 .01605 Mdot
.58013 .01523 Mdot
.58016 .01594 Mdot
.58018 .01483 Mdot
.58021 .01579 Mdot
.58023 .01542 Mdot
.58026 .01504 Mdot
.58028 .01499 Mdot
.58031 .01479 Mdot
.58034 .0155 Mdot
.58036 .01529 Mdot
.58039 .01591 Mdot
.58041 .01521 Mdot
.58044 .01488 Mdot
.58047 .01536 Mdot
.58049 .01521 Mdot
.58052 .01604 Mdot
.58054 .01533 Mdot
.58057 .01568 Mdot
.58059 .01527 Mdot
.58062 .01496 Mdot
.58065 .01555 Mdot
.58067 .01535 Mdot
.5807 .01615 Mdot
.58072 .01519 Mdot
.58075 .01555 Mdot
.58078 .01562 Mdot
.5808 .01529 Mdot
.58083 .01538 Mdot
.58085 .01616 Mdot
.58088 .01534 Mdot
.5809 .01515 Mdot
.58093 .01554 Mdot
.58096 .01628 Mdot
.58098 .016 Mdot
.58101 .01554 Mdot
.58103 .0154 Mdot
.58106 .01517 Mdot
.58109 .01537 Mdot
.58111 .01557 Mdot
.58114 .0161 Mdot
.58116 .01494 Mdot
.58119 .01572 Mdot
.58121 .0149 Mdot
.58124 .0168 Mdot
.58127 .01603 Mdot
.58129 .01524 Mdot
.58132 .01643 Mdot
.58134 .01632 Mdot
.58137 .01552 Mdot
.5814 .01489 Mdot
.58142 .01634 Mdot
.58145 .01639 Mdot
.58147 .01606 Mdot
.5815 .01621 Mdot
.58152 .0159 Mdot
.58155 .0159 Mdot
.58158 .01596 Mdot
.5816 .01478 Mdot
.58163 .01505 Mdot
.58165 .01485 Mdot
.58168 .01515 Mdot
.58171 .01531 Mdot
.58173 .01654 Mdot
.58176 .01586 Mdot
.58178 .01517 Mdot
.58181 .01601 Mdot
.58183 .01616 Mdot
.58186 .01688 Mdot
.58189 .0151 Mdot
.58191 .01494 Mdot
.58194 .01523 Mdot
.58196 .01556 Mdot
.58199 .01561 Mdot
.58202 .01592 Mdot
.58204 .01527 Mdot
.58207 .01654 Mdot
.58209 .01601 Mdot
.58212 .01614 Mdot
.58214 .01576 Mdot
.58217 .01515 Mdot
.5822 .01526 Mdot
.58222 .01576 Mdot
.58225 .01602 Mdot
.58227 .01596 Mdot
.5823 .01498 Mdot
.58233 .01579 Mdot
.58235 .01527 Mdot
.58238 .01571 Mdot
.5824 .01572 Mdot
.58243 .01561 Mdot
.58245 .01586 Mdot
.58248 .01717 Mdot
.58251 .01555 Mdot
.58253 .016 Mdot
.58256 .01602 Mdot
.58258 .01539 Mdot
.58261 .01635 Mdot
.58264 .01585 Mdot
.58266 .01648 Mdot
.58269 .01545 Mdot
.58271 .01564 Mdot
.58274 .01552 Mdot
.58276 .01576 Mdot
.58279 .01498 Mdot
.58282 .01591 Mdot
.58284 .01534 Mdot
.58287 .01619 Mdot
.58289 .01616 Mdot
.58292 .01475 Mdot
.58295 .01502 Mdot
.58297 .01543 Mdot
.583 .01539 Mdot
.58302 .01599 Mdot
.58305 .01577 Mdot
.58307 .01525 Mdot
.5831 .01514 Mdot
.58313 .01681 Mdot
.58315 .01622 Mdot
.58318 .01529 Mdot
.5832 .0157 Mdot
.58323 .01582 Mdot
.58326 .01555 Mdot
.58328 .01558 Mdot
.58331 .01545 Mdot
.58333 .01613 Mdot
.58336 .01551 Mdot
.58338 .01484 Mdot
.58341 .01584 Mdot
.58344 .01511 Mdot
.58346 .01541 Mdot
.58349 .01519 Mdot
.58351 .0149 Mdot
.58354 .01499 Mdot
.58357 .01523 Mdot
.58359 .01586 Mdot
.58362 .01545 Mdot
.58364 .01512 Mdot
.58367 .01572 Mdot
.58369 .01536 Mdot
.58372 .015 Mdot
.58375 .01552 Mdot
.58377 .01617 Mdot
.5838 .0156 Mdot
.58382 .01514 Mdot
.58385 .01542 Mdot
.58388 .01507 Mdot
.5839 .01669 Mdot
.58393 .01546 Mdot
.58395 .01491 Mdot
.58398 .01629 Mdot
.584 .01552 Mdot
.58403 .01612 Mdot
.58406 .01581 Mdot
.58408 .01553 Mdot
.58411 .01579 Mdot
.58413 .01678 Mdot
.58416 .01643 Mdot
.58419 .01635 Mdot
.58421 .01562 Mdot
.58424 .01564 Mdot
.58426 .01568 Mdot
.58429 .01602 Mdot
.58431 .0156 Mdot
.58434 .0153 Mdot
.58437 .01554 Mdot
.58439 .01631 Mdot
.58442 .01617 Mdot
.58444 .01606 Mdot
.58447 .01609 Mdot
.5845 .01613 Mdot
.58452 .01623 Mdot
.58455 .01684 Mdot
.58457 .01682 Mdot
.5846 .0161 Mdot
.58462 .01538 Mdot
.58465 .01532 Mdot
.58468 .01512 Mdot
.5847 .01482 Mdot
.58473 .01722 Mdot
.58475 .01586 Mdot
.58478 .01512 Mdot
.58481 .01593 Mdot
.58483 .01553 Mdot
.58486 .01525 Mdot
.58488 .01705 Mdot
.58491 .01582 Mdot
.58493 .01616 Mdot
.58496 .01633 Mdot
.58499 .0158 Mdot
.58501 .0153 Mdot
.58504 .016 Mdot
.58506 .01578 Mdot
.58509 .01515 Mdot
.58512 .01576 Mdot
.58514 .01579 Mdot
.58517 .0157 Mdot
.58519 .01496 Mdot
.58522 .01536 Mdot
.58524 .01579 Mdot
.58527 .01627 Mdot
.5853 .01641 Mdot
.58532 .01569 Mdot
.58535 .01554 Mdot
.58537 .01493 Mdot
.5854 .01568 Mdot
.58543 .01644 Mdot
.58545 .01521 Mdot
.58548 .01543 Mdot
.5855 .01564 Mdot
.58553 .01566 Mdot
.58555 .01651 Mdot
.58558 .01517 Mdot
.58561 .01525 Mdot
.58563 .01597 Mdot
.58566 .01708 Mdot
.58568 .01578 Mdot
.58571 .01509 Mdot
.58574 .01596 Mdot
.58576 .01611 Mdot
.58579 .01568 Mdot
.58581 .01629 Mdot
.58584 .01639 Mdot
.58586 .01604 Mdot
.58589 .01553 Mdot
.58592 .01546 Mdot
.58594 .01576 Mdot
.58597 .01587 Mdot
.58599 .01582 Mdot
.58602 .01527 Mdot
.58605 .01578 Mdot
.58607 .01567 Mdot
.5861 .0158 Mdot
.58612 .01617 Mdot
.58615 .01564 Mdot
.58617 .01504 Mdot
.5862 .01665 Mdot
.58623 .01563 Mdot
.58625 .01578 Mdot
.58628 .01576 Mdot
.5863 .01592 Mdot
.58633 .01625 Mdot
.58636 .01562 Mdot
.58638 .01491 Mdot
.58641 .01697 Mdot
.58643 .01668 Mdot
.58646 .01562 Mdot
.58648 .01536 Mdot
.58651 .01559 Mdot
.58654 .01574 Mdot
.58656 .0157 Mdot
.58659 .01638 Mdot
.58661 .01641 Mdot
.58664 .01543 Mdot
.58667 .01567 Mdot
.58669 .01632 Mdot
.58672 .01524 Mdot
.58674 .0159 Mdot
.58677 .01492 Mdot
.58679 .01614 Mdot
.58682 .01632 Mdot
.58685 .01564 Mdot
.58687 .01521 Mdot
.5869 .0156 Mdot
.58692 .01651 Mdot
.58695 .01529 Mdot
.58698 .01523 Mdot
.587 .01615 Mdot
.58703 .01597 Mdot
.58705 .01528 Mdot
.58708 .01593 Mdot
.58711 .01605 Mdot
.58713 .01527 Mdot
.58716 .01564 Mdot
.58718 .01693 Mdot
.58721 .01578 Mdot
.58723 .01608 Mdot
.58726 .01538 Mdot
.58729 .01569 Mdot
.58731 .01533 Mdot
.58734 .01516 Mdot
.58736 .0156 Mdot
.58739 .01554 Mdot
.58742 .01566 Mdot
.58744 .01643 Mdot
.58747 .01524 Mdot
.58749 .01558 Mdot
.58752 .01531 Mdot
.58754 .01575 Mdot
.58757 .0158 Mdot
.5876 .01485 Mdot
.58762 .01644 Mdot
.58765 .01627 Mdot
.58767 .01569 Mdot
.5877 .01499 Mdot
.58773 .01569 Mdot
.58775 .0156 Mdot
.58778 .01553 Mdot
.5878 .0161 Mdot
.58783 .01594 Mdot
.58785 .01628 Mdot
.58788 .01491 Mdot
.58791 .01566 Mdot
.58793 .01598 Mdot
.58796 .01621 Mdot
.58798 .01617 Mdot
.58801 .01614 Mdot
.58804 .01652 Mdot
.58806 .01632 Mdot
.58809 .01579 Mdot
.58811 .01484 Mdot
.58814 .01557 Mdot
.58816 .01552 Mdot
.58819 .01507 Mdot
.58822 .01671 Mdot
.58824 .01587 Mdot
.58827 .01585 Mdot
.58829 .0156 Mdot
.58832 .0155 Mdot
.58835 .01588 Mdot
.58837 .01516 Mdot
.5884 .01592 Mdot
.58842 .01682 Mdot
.58845 .0158 Mdot
.58847 .01573 Mdot
.5885 .01646 Mdot
.58853 .01557 Mdot
.58855 .01626 Mdot
.58858 .01502 Mdot
.5886 .01614 Mdot
.58863 .01522 Mdot
.58866 .01625 Mdot
.58868 .01497 Mdot
.58871 .01717 Mdot
.58873 .01647 Mdot
.58876 .01863 Mdot
.58878 .01515 Mdot
.58881 .01656 Mdot
.58884 .0157 Mdot
.58886 .01591 Mdot
.58889 .01607 Mdot
.58891 .01641 Mdot
.58894 .01631 Mdot
.58897 .01532 Mdot
.58899 .01698 Mdot
.58902 .01566 Mdot
.58904 .0157 Mdot
.58907 .01531 Mdot
.58909 .01677 Mdot
.58912 .01685 Mdot
.58915 .01533 Mdot
.58917 .0167 Mdot
.5892 .01567 Mdot
.58922 .015 Mdot
.58925 .01591 Mdot
.58928 .01587 Mdot
.5893 .01643 Mdot
.58933 .01749 Mdot
.58935 .01544 Mdot
.58938 .01481 Mdot
.5894 .01549 Mdot
.58943 .01683 Mdot
.58946 .01525 Mdot
.58948 .01578 Mdot
.58951 .01568 Mdot
.58953 .01673 Mdot
.58956 .01546 Mdot
.58959 .01491 Mdot
.58961 .01554 Mdot
.58964 .01544 Mdot
.58966 .01644 Mdot
.58969 .01563 Mdot
.58971 .01551 Mdot
.58974 .01518 Mdot
.58977 .01588 Mdot
.58979 .01573 Mdot
.58982 .0151 Mdot
.58984 .01575 Mdot
.58987 .01494 Mdot
.5899 .01638 Mdot
.58992 .0152 Mdot
.58995 .01573 Mdot
.58997 .01536 Mdot
.59 .0167 Mdot
.59002 .01589 Mdot
.59005 .01492 Mdot
.59008 .01567 Mdot
.5901 .01652 Mdot
.59013 .01541 Mdot
.59015 .01555 Mdot
.59018 .01533 Mdot
.59021 .01542 Mdot
.59023 .01627 Mdot
.59026 .01635 Mdot
.59028 .01646 Mdot
.59031 .01627 Mdot
.59033 .01611 Mdot
.59036 .01609 Mdot
.59039 .01487 Mdot
.59041 .01525 Mdot
.59044 .0161 Mdot
.59046 .01669 Mdot
.59049 .01532 Mdot
.59052 .01637 Mdot
.59054 .01567 Mdot
.59057 .0167 Mdot
.59059 .01545 Mdot
.59062 .01538 Mdot
.59064 .01548 Mdot
.59067 .01568 Mdot
.5907 .0155 Mdot
.59072 .01634 Mdot
.59075 .01514 Mdot
.59077 .01523 Mdot
.5908 .01538 Mdot
.59083 .01644 Mdot
.59085 .01663 Mdot
.59088 .01576 Mdot
.5909 .01476 Mdot
.59093 .01645 Mdot
.59095 .01558 Mdot
.59098 .01566 Mdot
.59101 .01571 Mdot
.59103 .01568 Mdot
.59106 .01567 Mdot
.59108 .0162 Mdot
.59111 .01574 Mdot
.59114 .01526 Mdot
.59116 .01543 Mdot
.59119 .01652 Mdot
.59121 .01608 Mdot
.59124 .01596 Mdot
.59126 .01573 Mdot
.59129 .0156 Mdot
.59132 .01507 Mdot
.59134 .01656 Mdot
.59137 .01567 Mdot
.59139 .01493 Mdot
.59142 .01546 Mdot
.59145 .0177 Mdot
.59147 .01587 Mdot
.5915 .015 Mdot
.59152 .01661 Mdot
.59155 .01668 Mdot
.59157 .01504 Mdot
.5916 .01594 Mdot
.59163 .0161 Mdot
.59165 .01608 Mdot
.59168 .01658 Mdot
.5917 .0155 Mdot
.59173 .01601 Mdot
.59176 .01561 Mdot
.59178 .01572 Mdot
.59181 .0156 Mdot
.59183 .01571 Mdot
.59186 .01648 Mdot
.59188 .01629 Mdot
.59191 .01628 Mdot
.59194 .01707 Mdot
.59196 .01581 Mdot
.59199 .01556 Mdot
.59201 .01529 Mdot
.59204 .01619 Mdot
.59207 .01661 Mdot
.59209 .01634 Mdot
.59212 .01595 Mdot
.59214 .01509 Mdot
.59217 .01477 Mdot
.59219 .01621 Mdot
.59222 .01623 Mdot
.59225 .01622 Mdot
.59227 .01643 Mdot
.5923 .01576 Mdot
.59232 .01526 Mdot
.59235 .01576 Mdot
.59238 .01557 Mdot
.5924 .01679 Mdot
.59243 .01562 Mdot
.59245 .01628 Mdot
.59248 .01728 Mdot
.5925 .016 Mdot
.59253 .01675 Mdot
.59256 .01523 Mdot
.59258 .01647 Mdot
.59261 .0158 Mdot
.59263 .01655 Mdot
.59266 .01569 Mdot
.59269 .01529 Mdot
.59271 .01522 Mdot
.59274 .01505 Mdot
.59276 .01527 Mdot
.59279 .01551 Mdot
.59281 .01519 Mdot
.59284 .01565 Mdot
.59287 .01522 Mdot
.59289 .01581 Mdot
.59292 .01498 Mdot
.59294 .01523 Mdot
.59297 .01586 Mdot
.593 .01648 Mdot
.59302 .01579 Mdot
.59305 .01695 Mdot
.59307 .01591 Mdot
.5931 .01674 Mdot
.59312 .01539 Mdot
.59315 .01542 Mdot
.59318 .01577 Mdot
.5932 .01532 Mdot
.59323 .01527 Mdot
.59325 .01514 Mdot
.59328 .01573 Mdot
.59331 .01492 Mdot
.59333 .01598 Mdot
.59336 .01518 Mdot
.59338 .01531 Mdot
.59341 .01532 Mdot
.59343 .01562 Mdot
.59346 .01516 Mdot
.59349 .01558 Mdot
.59351 .01559 Mdot
.59354 .01572 Mdot
.59356 .0166 Mdot
.59359 .01585 Mdot
.59362 .01592 Mdot
.59364 .01637 Mdot
.59367 .01536 Mdot
.59369 .01659 Mdot
.59372 .01685 Mdot
.59374 .01514 Mdot
.59377 .01581 Mdot
.5938 .01585 Mdot
.59382 .01576 Mdot
.59385 .01729 Mdot
.59387 .01537 Mdot
.5939 .01531 Mdot
.59393 .01511 Mdot
.59395 .01553 Mdot
.59398 .01613 Mdot
.594 .01566 Mdot
.59403 .01562 Mdot
.59405 .01492 Mdot
.59408 .01563 Mdot
.59411 .01492 Mdot
.59413 .0153 Mdot
.59416 .01654 Mdot
.59418 .01546 Mdot
.59421 .01624 Mdot
.59424 .01596 Mdot
.59426 .01601 Mdot
.59429 .01649 Mdot
.59431 .01682 Mdot
.59434 .0158 Mdot
.59436 .01554 Mdot
.59439 .01548 Mdot
.59442 .01598 Mdot
.59444 .01525 Mdot
.59447 .01561 Mdot
.59449 .01711 Mdot
.59452 .01507 Mdot
.59455 .01528 Mdot
.59457 .01581 Mdot
.5946 .0161 Mdot
.59462 .01485 Mdot
.59465 .01536 Mdot
.59467 .01582 Mdot
.5947 .01499 Mdot
.59473 .01608 Mdot
.59475 .01586 Mdot
.59478 .01689 Mdot
.5948 .01583 Mdot
.59483 .01523 Mdot
.59486 .01598 Mdot
.59488 .01613 Mdot
.59491 .0166 Mdot
.59493 .01535 Mdot
.59496 .0156 Mdot
.59498 .01624 Mdot
.59501 .015 Mdot
.59504 .01515 Mdot
.59506 .0169 Mdot
.59509 .0158 Mdot
.59511 .01557 Mdot
.59514 .01679 Mdot
.59517 .01568 Mdot
.59519 .01537 Mdot
.59522 .01666 Mdot
.59524 .01552 Mdot
.59527 .01558 Mdot
.59529 .01528 Mdot
.59532 .01602 Mdot
.59535 .01623 Mdot
.59537 .01634 Mdot
.5954 .01661 Mdot
.59542 .01564 Mdot
.59545 .01517 Mdot
.59548 .01502 Mdot
.5955 .01495 Mdot
.59553 .01605 Mdot
.59555 .01551 Mdot
.59558 .01543 Mdot
.5956 .0158 Mdot
.59563 .01613 Mdot
.59566 .01632 Mdot
.59568 .01611 Mdot
.59571 .01604 Mdot
.59573 .01581 Mdot
.59576 .01549 Mdot
.59579 .01649 Mdot
.59581 .01639 Mdot
.59584 .01512 Mdot
.59586 .01539 Mdot
.59589 .01529 Mdot
.59591 .01564 Mdot
.59594 .01539 Mdot
.59597 .01488 Mdot
.59599 .01563 Mdot
.59602 .01536 Mdot
.59604 .01687 Mdot
.59607 .0165 Mdot
.5961 .01766 Mdot
.59612 .01512 Mdot
.59615 .01568 Mdot
.59617 .0149 Mdot
.5962 .01567 Mdot
.59623 .01515 Mdot
.59625 .01572 Mdot
.59628 .01612 Mdot
.5963 .0157 Mdot
.59633 .01583 Mdot
.59635 .01634 Mdot
.59638 .01664 Mdot
.59641 .01533 Mdot
.59643 .01514 Mdot
.59646 .01553 Mdot
.59648 .01568 Mdot
.59651 .01529 Mdot
.59654 .01509 Mdot
.59656 .01537 Mdot
.59659 .01494 Mdot
.59661 .01603 Mdot
.59664 .01526 Mdot
.59666 .01483 Mdot
.59669 .01612 Mdot
.59672 .01482 Mdot
.59674 .01593 Mdot
.59677 .01658 Mdot
.59679 .01643 Mdot
.59682 .01697 Mdot
.59685 .01482 Mdot
.59687 .01633 Mdot
.5969 .01543 Mdot
.59692 .01745 Mdot
.59695 .01547 Mdot
.59697 .01604 Mdot
.597 .01542 Mdot
.59703 .01658 Mdot
.59705 .01594 Mdot
.59708 .01558 Mdot
.5971 .01587 Mdot
.59713 .01542 Mdot
.59716 .01574 Mdot
.59718 .01642 Mdot
.59721 .01516 Mdot
.59723 .0158 Mdot
.59726 .01505 Mdot
.59728 .01507 Mdot
.59731 .01606 Mdot
.59734 .01565 Mdot
.59736 .01525 Mdot
.59739 .01564 Mdot
.59741 .01529 Mdot
.59744 .01649 Mdot
.59747 .01547 Mdot
.59749 .01513 Mdot
.59752 .01542 Mdot
.59754 .01591 Mdot
.59757 .01568 Mdot
.59759 .01509 Mdot
.59762 .01647 Mdot
.59765 .01529 Mdot
.59767 .01559 Mdot
.5977 .01558 Mdot
.59772 .01477 Mdot
.59775 .01517 Mdot
.59778 .01586 Mdot
.5978 .01637 Mdot
.59783 .01568 Mdot
.59785 .01617 Mdot
.59788 .01617 Mdot
.5979 .01681 Mdot
.59793 .01598 Mdot
.59796 .01498 Mdot
.59798 .01549 Mdot
.59801 .01528 Mdot
.59803 .01551 Mdot
.59806 .01625 Mdot
.59809 .0149 Mdot
.59811 .01615 Mdot
.59814 .01652 Mdot
.59816 .01494 Mdot
.59819 .01648 Mdot
.59821 .01627 Mdot
.59824 .01595 Mdot
.59827 .0164 Mdot
.59829 .01517 Mdot
.59832 .01539 Mdot
.59834 .01537 Mdot
.59837 .01607 Mdot
.5984 .01634 Mdot
.59842 .01637 Mdot
.59845 .01551 Mdot
.59847 .01638 Mdot
.5985 .01564 Mdot
.59852 .01527 Mdot
.59855 .01545 Mdot
.59858 .01549 Mdot
.5986 .01511 Mdot
.59863 .01547 Mdot
.59865 .0163 Mdot
.59868 .01638 Mdot
.59871 .01512 Mdot
.59873 .0157 Mdot
.59876 .01556 Mdot
.59878 .01525 Mdot
.59881 .01488 Mdot
.59883 .0162 Mdot
.59886 .016 Mdot
.59889 .01492 Mdot
.59891 .0156 Mdot
.59894 .0157 Mdot
.59896 .01556 Mdot
.59899 .01661 Mdot
.59902 .01487 Mdot
.59904 .01544 Mdot
.59907 .01533 Mdot
.59909 .0157 Mdot
.59912 .01567 Mdot
.59914 .0153 Mdot
.59917 .01615 Mdot
.5992 .0162 Mdot
.59922 .016 Mdot
.59925 .01591 Mdot
.59927 .01718 Mdot
.5993 .01638 Mdot
.59933 .01651 Mdot
.59935 .01841 Mdot
.59938 .01578 Mdot
.5994 .01634 Mdot
.59943 .01575 Mdot
.59945 .01629 Mdot
.59948 .01568 Mdot
.59951 .01639 Mdot
.59953 .01534 Mdot
.59956 .01591 Mdot
.59958 .01543 Mdot
.59961 .01514 Mdot
.59964 .01527 Mdot
.59966 .01609 Mdot
.59969 .01539 Mdot
.59971 .01548 Mdot
.59974 .01543 Mdot
.59976 .01659 Mdot
.59979 .01568 Mdot
.59982 .0155 Mdot
.59984 .01598 Mdot
.59987 .01686 Mdot
.59989 .01529 Mdot
.59992 .01642 Mdot
.59995 .01668 Mdot
.59997 .01562 Mdot
.6 .0158 Mdot
.60002 .01518 Mdot
.60005 .01501 Mdot
.60007 .01504 Mdot
.6001 .01554 Mdot
.60013 .01571 Mdot
.60015 .01539 Mdot
.60018 .01659 Mdot
.6002 .01567 Mdot
.60023 .01592 Mdot
.60026 .01739 Mdot
.60028 .01525 Mdot
.60031 .01602 Mdot
.60033 .01662 Mdot
.60036 .01546 Mdot
.60038 .01513 Mdot
.60041 .01609 Mdot
.60044 .0153 Mdot
.60046 .01747 Mdot
.60049 .01599 Mdot
.60051 .01525 Mdot
.60054 .01592 Mdot
.60057 .01669 Mdot
.60059 .01513 Mdot
.60062 .01565 Mdot
.60064 .01497 Mdot
.60067 .01594 Mdot
.60069 .0158 Mdot
.60072 .01522 Mdot
.60075 .01653 Mdot
.60077 .01613 Mdot
.6008 .01611 Mdot
.60082 .01595 Mdot
.60085 .01562 Mdot
.60088 .01523 Mdot
.6009 .01524 Mdot
.60093 .01562 Mdot
.60095 .01587 Mdot
.60098 .01552 Mdot
.601 .01587 Mdot
.60103 .01659 Mdot
.60106 .01583 Mdot
.60108 .0155 Mdot
.60111 .01644 Mdot
.60113 .01548 Mdot
.60116 .01575 Mdot
.60119 .01558 Mdot
.60121 .01552 Mdot
.60124 .01533 Mdot
.60126 .01625 Mdot
.60129 .01616 Mdot
.60131 .01651 Mdot
.60134 .0149 Mdot
.60137 .016 Mdot
.60139 .01698 Mdot
.60142 .01571 Mdot
.60144 .01589 Mdot
.60147 .01672 Mdot
.6015 .01556 Mdot
.60152 .01578 Mdot
.60155 .01583 Mdot
.60157 .01482 Mdot
.6016 .01629 Mdot
.60162 .01592 Mdot
.60165 .01623 Mdot
.60168 .01514 Mdot
.6017 .01624 Mdot
.60173 .01585 Mdot
.60175 .01544 Mdot
.60178 .01544 Mdot
.60181 .01592 Mdot
.60183 .01644 Mdot
.60186 .01554 Mdot
.60188 .01585 Mdot
.60191 .01558 Mdot
.60193 .01751 Mdot
.60196 .01532 Mdot
.60199 .01635 Mdot
.60201 .0158 Mdot
.60204 .01684 Mdot
.60206 .01668 Mdot
.60209 .01563 Mdot
.60212 .0156 Mdot
.60214 .0164 Mdot
.60217 .01657 Mdot
.60219 .01616 Mdot
.60222 .016 Mdot
.60224 .01602 Mdot
.60227 .01585 Mdot
.6023 .01571 Mdot
.60232 .01586 Mdot
.60235 .01521 Mdot
.60237 .01478 Mdot
.6024 .01598 Mdot
.60243 .01623 Mdot
.60245 .01594 Mdot
.60248 .01508 Mdot
.6025 .01549 Mdot
.60253 .01553 Mdot
.60255 .01645 Mdot
.60258 .01664 Mdot
.60261 .01584 Mdot
.60263 .01508 Mdot
.60266 .01576 Mdot
.60268 .01639 Mdot
.60271 .01649 Mdot
.60274 .01604 Mdot
.60276 .01523 Mdot
.60279 .01564 Mdot
.60281 .01651 Mdot
.60284 .01601 Mdot
.60286 .01602 Mdot
.60289 .01557 Mdot
.60292 .01552 Mdot
.60294 .01604 Mdot
.60297 .01559 Mdot
.60299 .01558 Mdot
.60302 .0159 Mdot
.60305 .01703 Mdot
.60307 .01602 Mdot
.6031 .01506 Mdot
.60312 .0154 Mdot
.60315 .01528 Mdot
.60317 .01637 Mdot
.6032 .01627 Mdot
.60323 .01599 Mdot
.60325 .0149 Mdot
.60328 .01595 Mdot
.6033 .01565 Mdot
.60333 .01566 Mdot
.60336 .01511 Mdot
.60338 .01576 Mdot
.60341 .01571 Mdot
.60343 .01532 Mdot
.60346 .01547 Mdot
.60348 .01589 Mdot
.60351 .01583 Mdot
.60354 .0158 Mdot
.60356 .01572 Mdot
.60359 .0165 Mdot
.60361 .01625 Mdot
.60364 .0158 Mdot
.60367 .01566 Mdot
.60369 .01618 Mdot
.60372 .01622 Mdot
.60374 .01514 Mdot
.60377 .01533 Mdot
.60379 .0159 Mdot
.60382 .01548 Mdot
.60385 .01615 Mdot
.60387 .01565 Mdot
.6039 .01586 Mdot
.60392 .01488 Mdot
.60395 .01587 Mdot
.60398 .01526 Mdot
.604 .0153 Mdot
.60403 .01527 Mdot
.60405 .01576 Mdot
.60408 .01512 Mdot
.6041 .01536 Mdot
.60413 .01629 Mdot
.60416 .01509 Mdot
.60418 .0159 Mdot
.60421 .01621 Mdot
.60423 .01612 Mdot
.60426 .01555 Mdot
.60429 .01656 Mdot
.60431 .01579 Mdot
.60434 .01515 Mdot
.60436 .0155 Mdot
.60439 .01715 Mdot
.60441 .01553 Mdot
.60444 .0164 Mdot
.60447 .01617 Mdot
.60449 .01498 Mdot
.60452 .01551 Mdot
.60454 .01554 Mdot
.60457 .01528 Mdot
.6046 .01509 Mdot
.60462 .01488 Mdot
.60465 .01606 Mdot
.60467 .01576 Mdot
.6047 .01527 Mdot
.60472 .01598 Mdot
.60475 .01533 Mdot
.60478 .01569 Mdot
.6048 .01661 Mdot
.60483 .01579 Mdot
.60485 .0161 Mdot
.60488 .01614 Mdot
.60491 .01546 Mdot
.60493 .01594 Mdot
.60496 .01575 Mdot
.60498 .01498 Mdot
.60501 .01498 Mdot
.60503 .01641 Mdot
.60506 .01612 Mdot
.60509 .01545 Mdot
.60511 .01543 Mdot
.60514 .01546 Mdot
.60516 .01605 Mdot
.60519 .01524 Mdot
.60522 .01555 Mdot
.60524 .01648 Mdot
.60527 .01518 Mdot
.60529 .0159 Mdot
.60532 .01586 Mdot
.60535 .01612 Mdot
.60537 .01566 Mdot
.6054 .01721 Mdot
.60542 .01591 Mdot
.60545 .01626 Mdot
.60547 .01652 Mdot
.6055 .01587 Mdot
.60553 .01515 Mdot
.60555 .0151 Mdot
.60558 .01577 Mdot
.6056 .01534 Mdot
.60563 .01666 Mdot
.60566 .01603 Mdot
.60568 .01485 Mdot
.60571 .01712 Mdot
.60573 .01516 Mdot
.60576 .01626 Mdot
.60578 .01633 Mdot
.60581 .01542 Mdot
.60584 .01675 Mdot
.60586 .0163 Mdot
.60589 .01494 Mdot
.60591 .01545 Mdot
.60594 .01536 Mdot
.60597 .01528 Mdot
.60599 .01632 Mdot
.60602 .01617 Mdot
.60604 .01604 Mdot
.60607 .01541 Mdot
.60609 .01541 Mdot
.60612 .01587 Mdot
.60615 .01557 Mdot
.60617 .01641 Mdot
.6062 .01503 Mdot
.60622 .01638 Mdot
.60625 .01507 Mdot
.60628 .01534 Mdot
.6063 .01612 Mdot
.60633 .01579 Mdot
.60635 .01535 Mdot
.60638 .01735 Mdot
.6064 .01607 Mdot
.60643 .01554 Mdot
.60646 .01648 Mdot
.60648 .01573 Mdot
.60651 .01611 Mdot
.60653 .01565 Mdot
.60656 .01525 Mdot
.60659 .01594 Mdot
.60661 .01576 Mdot
.60664 .01548 Mdot
.60666 .0151 Mdot
.60669 .01557 Mdot
.60671 .01589 Mdot
.60674 .01491 Mdot
.60677 .01611 Mdot
.60679 .01581 Mdot
.60682 .01529 Mdot
.60684 .01529 Mdot
.60687 .01568 Mdot
.6069 .01754 Mdot
.60692 .01706 Mdot
.60695 .0159 Mdot
.60697 .01607 Mdot
.607 .01625 Mdot
.60702 .01505 Mdot
.60705 .01548 Mdot
.60708 .01504 Mdot
.6071 .01518 Mdot
.60713 .01579 Mdot
.60715 .01552 Mdot
.60718 .01576 Mdot
.60721 .01642 Mdot
.60723 .01556 Mdot
.60726 .01498 Mdot
.60728 .0154 Mdot
.60731 .01605 Mdot
.60733 .01604 Mdot
.60736 .01651 Mdot
.60739 .01708 Mdot
.60741 .01498 Mdot
.60744 .01543 Mdot
.60746 .01556 Mdot
.60749 .01562 Mdot
.60752 .0161 Mdot
.60754 .01509 Mdot
.60757 .01531 Mdot
.60759 .01556 Mdot
.60762 .01495 Mdot
.60764 .01572 Mdot
.60767 .01535 Mdot
.6077 .01629 Mdot
.60772 .01536 Mdot
.60775 .01492 Mdot
.60777 .01491 Mdot
.6078 .01558 Mdot
.60783 .01501 Mdot
.60785 .01551 Mdot
.60788 .01574 Mdot
.6079 .01627 Mdot
.60793 .01694 Mdot
.60795 .01497 Mdot
.60798 .01599 Mdot
.60801 .01609 Mdot
.60803 .01596 Mdot
.60806 .01638 Mdot
.60808 .01569 Mdot
.60811 .01481 Mdot
.60814 .01544 Mdot
.60816 .01572 Mdot
.60819 .01562 Mdot
.60821 .01524 Mdot
.60824 .01602 Mdot
.60826 .01574 Mdot
.60829 .01719 Mdot
.60832 .0175 Mdot
.60834 .01566 Mdot
.60837 .01723 Mdot
.60839 .01616 Mdot
.60842 .01511 Mdot
.60845 .01539 Mdot
.60847 .01533 Mdot
.6085 .01583 Mdot
.60852 .01569 Mdot
.60855 .01589 Mdot
.60857 .01568 Mdot
.6086 .01541 Mdot
.60863 .01573 Mdot
.60865 .01572 Mdot
.60868 .01573 Mdot
.6087 .01589 Mdot
.60873 .01537 Mdot
.60876 .01496 Mdot
.60878 .01586 Mdot
.60881 .01612 Mdot
.60883 .01631 Mdot
.60886 .0149 Mdot
.60888 .01557 Mdot
.60891 .01569 Mdot
.60894 .01645 Mdot
.60896 .01536 Mdot
.60899 .01635 Mdot
.60901 .01489 Mdot
.60904 .01588 Mdot
.60907 .01541 Mdot
.60909 .0152 Mdot
.60912 .01533 Mdot
.60914 .0167 Mdot
.60917 .01626 Mdot
.60919 .01515 Mdot
.60922 .01597 Mdot
.60925 .01594 Mdot
.60927 .01556 Mdot
.6093 .01561 Mdot
.60932 .01551 Mdot
.60935 .01584 Mdot
.60938 .01511 Mdot
.6094 .01606 Mdot
.60943 .0169 Mdot
.60945 .01567 Mdot
.60948 .01549 Mdot
.6095 .01597 Mdot
.60953 .01549 Mdot
.60956 .01534 Mdot
.60958 .01565 Mdot
.60961 .01508 Mdot
.60963 .01575 Mdot
.60966 .01528 Mdot
.60969 .01655 Mdot
.60971 .01549 Mdot
.60974 .0156 Mdot
.60976 .01513 Mdot
.60979 .01533 Mdot
.60981 .01556 Mdot
.60984 .01511 Mdot
.60987 .01659 Mdot
.60989 .01595 Mdot
.60992 .01562 Mdot
.60994 .01663 Mdot
.60997 .01486 Mdot
.61 .01546 Mdot
.61002 .01521 Mdot
.61005 .01524 Mdot
.61007 .01525 Mdot
.6101 .01573 Mdot
.61012 .01767 Mdot
.61015 .01584 Mdot
.61018 .01699 Mdot
.6102 .01657 Mdot
.61023 .01605 Mdot
.61025 .0168 Mdot
.61028 .01559 Mdot
.61031 .01595 Mdot
.61033 .01528 Mdot
.61036 .0158 Mdot
.61038 .01536 Mdot
.61041 .01652 Mdot
.61043 .01591 Mdot
.61046 .01564 Mdot
.61049 .01579 Mdot
.61051 .01612 Mdot
.61054 .01538 Mdot
.61056 .01576 Mdot
.61059 .01495 Mdot
.61062 .01567 Mdot
.61064 .01574 Mdot
.61067 .0158 Mdot
.61069 .01535 Mdot
.61072 .01578 Mdot
.61074 .01589 Mdot
.61077 .01503 Mdot
.6108 .01587 Mdot
.61082 .01565 Mdot
.61085 .01499 Mdot
.61087 .01482 Mdot
.6109 .01589 Mdot
.61093 .01621 Mdot
.61095 .01591 Mdot
.61098 .01519 Mdot
.611 .01519 Mdot
.61103 .01513 Mdot
.61105 .01503 Mdot
.61108 .01518 Mdot
.61111 .01602 Mdot
.61113 .01644 Mdot
.61116 .01566 Mdot
.61118 .01493 Mdot
.61121 .01557 Mdot
.61124 .01568 Mdot
.61126 .01652 Mdot
.61129 .01512 Mdot
.61131 .01564 Mdot
.61134 .01635 Mdot
.61136 .01593 Mdot
.61139 .01543 Mdot
.61142 .01526 Mdot
.61144 .01556 Mdot
.61147 .01624 Mdot
.61149 .01568 Mdot
.61152 .0159 Mdot
.61155 .01588 Mdot
.61157 .01524 Mdot
.6116 .01646 Mdot
.61162 .01524 Mdot
.61165 .01536 Mdot
.61167 .01593 Mdot
.6117 .01527 Mdot
.61173 .01533 Mdot
.61175 .01582 Mdot
.61178 .01636 Mdot
.6118 .01555 Mdot
.61183 .01536 Mdot
.61186 .01568 Mdot
.61188 .01489 Mdot
.61191 .01682 Mdot
.61193 .01576 Mdot
.61196 .01593 Mdot
.61198 .01524 Mdot
.61201 .01601 Mdot
.61204 .01531 Mdot
.61206 .01647 Mdot
.61209 .01595 Mdot
.61211 .01723 Mdot
.61214 .01609 Mdot
.61217 .01689 Mdot
.61219 .01498 Mdot
.61222 .01563 Mdot
.61224 .01551 Mdot
.61227 .01614 Mdot
.61229 .01617 Mdot
.61232 .01568 Mdot
.61235 .01494 Mdot
.61237 .01778 Mdot
.6124 .01684 Mdot
.61242 .01541 Mdot
.61245 .01492 Mdot
.61248 .01567 Mdot
.6125 .01674 Mdot
.61253 .0164 Mdot
.61255 .01534 Mdot
.61258 .01521 Mdot
.6126 .01625 Mdot
.61263 .01623 Mdot
.61266 .01654 Mdot
.61268 .01482 Mdot
.61271 .01548 Mdot
.61273 .0167 Mdot
.61276 .0151 Mdot
.61279 .01559 Mdot
.61281 .01564 Mdot
.61284 .01529 Mdot
.61286 .01555 Mdot
.61289 .01601 Mdot
.61291 .01505 Mdot
.61294 .01512 Mdot
.61297 .0155 Mdot
.61299 .01558 Mdot
.61302 .01601 Mdot
.61304 .01524 Mdot
.61307 .01597 Mdot
.6131 .01552 Mdot
.61312 .0161 Mdot
.61315 .01505 Mdot
.61317 .01581 Mdot
.6132 .01559 Mdot
.61322 .01503 Mdot
.61325 .01558 Mdot
.61328 .01516 Mdot
.6133 .01561 Mdot
.61333 .01585 Mdot
.61335 .01541 Mdot
.61338 .01698 Mdot
.61341 .01549 Mdot
.61343 .01603 Mdot
.61346 .01537 Mdot
.61348 .0149 Mdot
.61351 .01639 Mdot
.61353 .01541 Mdot
.61356 .01543 Mdot
.61359 .01657 Mdot
.61361 .01491 Mdot
.61364 .01513 Mdot
.61366 .01509 Mdot
.61369 .01564 Mdot
.61372 .01533 Mdot
.61374 .01614 Mdot
.61377 .01663 Mdot
.61379 .01472 Mdot
.61382 .01581 Mdot
.61384 .01586 Mdot
.61387 .01484 Mdot
.6139 .01552 Mdot
.61392 .01671 Mdot
.61395 .0153 Mdot
.61397 .01676 Mdot
.614 .01546 Mdot
.61403 .01606 Mdot
.61405 .01552 Mdot
.61408 .01693 Mdot
.6141 .01537 Mdot
.61413 .01502 Mdot
.61415 .01611 Mdot
.61418 .01529 Mdot
.61421 .01591 Mdot
.61423 .01524 Mdot
.61426 .01664 Mdot
.61428 .01504 Mdot
.61431 .01541 Mdot
.61434 .01553 Mdot
.61436 .01504 Mdot
.61439 .01539 Mdot
.61441 .016 Mdot
.61444 .01568 Mdot
.61447 .01514 Mdot
.61449 .01653 Mdot
.61452 .01496 Mdot
.61454 .01591 Mdot
.61457 .01479 Mdot
.61459 .01519 Mdot
.61462 .01683 Mdot
.61465 .01579 Mdot
.61467 .0167 Mdot
.6147 .01577 Mdot
.61472 .01584 Mdot
.61475 .01498 Mdot
.61478 .01531 Mdot
.6148 .01579 Mdot
.61483 .0162 Mdot
.61485 .01617 Mdot
.61488 .01647 Mdot
.6149 .01559 Mdot
.61493 .01529 Mdot
.61496 .01575 Mdot
.61498 .01536 Mdot
.61501 .0152 Mdot
.61503 .01558 Mdot
.61506 .01508 Mdot
.61509 .01709 Mdot
.61511 .01511 Mdot
.61514 .01525 Mdot
.61516 .01598 Mdot
.61519 .01527 Mdot
.61521 .01561 Mdot
.61524 .01531 Mdot
.61527 .01596 Mdot
.61529 .01486 Mdot
.61532 .01562 Mdot
.61534 .01582 Mdot
.61537 .016 Mdot
.6154 .0157 Mdot
.61542 .01524 Mdot
.61545 .01604 Mdot
.61547 .01579 Mdot
.6155 .01485 Mdot
.61552 .0149 Mdot
.61555 .01648 Mdot
.61558 .01651 Mdot
.6156 .01559 Mdot
.61563 .01547 Mdot
.61565 .01512 Mdot
.61568 .01527 Mdot
.61571 .01595 Mdot
.61573 .01564 Mdot
.61576 .01532 Mdot
.61578 .01558 Mdot
.61581 .01556 Mdot
.61583 .01575 Mdot
.61586 .0156 Mdot
.61589 .01606 Mdot
.61591 .01586 Mdot
.61594 .01707 Mdot
.61596 .01557 Mdot
.61599 .01635 Mdot
.61602 .0154 Mdot
.61604 .01581 Mdot
.61607 .01557 Mdot
.61609 .01556 Mdot
.61612 .01553 Mdot
.61614 .01566 Mdot
.61617 .01618 Mdot
.6162 .01618 Mdot
.61622 .0154 Mdot
.61625 .01616 Mdot
.61627 .01634 Mdot
.6163 .01636 Mdot
.61633 .01516 Mdot
.61635 .01654 Mdot
.61638 .01586 Mdot
.6164 .01553 Mdot
.61643 .01537 Mdot
.61645 .01572 Mdot
.61648 .01517 Mdot
.61651 .01555 Mdot
.61653 .01546 Mdot
.61656 .01525 Mdot
.61658 .01546 Mdot
.61661 .01514 Mdot
.61664 .01622 Mdot
.61666 .01594 Mdot
.61669 .01621 Mdot
.61671 .01576 Mdot
.61674 .01575 Mdot
.61676 .01552 Mdot
.61679 .01513 Mdot
.61682 .01601 Mdot
.61684 .01569 Mdot
.61687 .01598 Mdot
.61689 .01528 Mdot
.61692 .01528 Mdot
.61695 .0151 Mdot
.61697 .01552 Mdot
.617 .01538 Mdot
.61702 .01518 Mdot
.61705 .01554 Mdot
.61707 .01558 Mdot
.6171 .01581 Mdot
.61713 .01605 Mdot
.61715 .01616 Mdot
.61718 .01574 Mdot
.6172 .01523 Mdot
.61723 .01576 Mdot
.61726 .01658 Mdot
.61728 .01555 Mdot
.61731 .01528 Mdot
.61733 .016 Mdot
.61736 .01527 Mdot
.61738 .01551 Mdot
.61741 .01594 Mdot
.61744 .01549 Mdot
.61746 .01523 Mdot
.61749 .01698 Mdot
.61751 .01515 Mdot
.61754 .01679 Mdot
.61757 .016 Mdot
.61759 .01564 Mdot
.61762 .01577 Mdot
.61764 .01528 Mdot
.61767 .01608 Mdot
.61769 .0151 Mdot
.61772 .01566 Mdot
.61775 .01534 Mdot
.61777 .0155 Mdot
.6178 .01514 Mdot
.61782 .01714 Mdot
.61785 .01686 Mdot
.61788 .01483 Mdot
.6179 .01543 Mdot
.61793 .01594 Mdot
.61795 .01543 Mdot
.61798 .01517 Mdot
.618 .01533 Mdot
.61803 .01614 Mdot
.61806 .01498 Mdot
.61808 .01549 Mdot
.61811 .01548 Mdot
.61813 .01529 Mdot
.61816 .01521 Mdot
.61819 .01588 Mdot
.61821 .01589 Mdot
.61824 .01576 Mdot
.61826 .01537 Mdot
.61829 .01587 Mdot
.61831 .01565 Mdot
.61834 .01564 Mdot
.61837 .016 Mdot
.61839 .01572 Mdot
.61842 .01589 Mdot
.61844 .01606 Mdot
.61847 .01663 Mdot
.6185 .01588 Mdot
.61852 .01596 Mdot
.61855 .01517 Mdot
.61857 .01555 Mdot
.6186 .01516 Mdot
.61862 .01605 Mdot
.61865 .01538 Mdot
.61868 .01594 Mdot
.6187 .01554 Mdot
.61873 .01586 Mdot
.61875 .0155 Mdot
.61878 .01504 Mdot
.61881 .01666 Mdot
.61883 .01522 Mdot
.61886 .01536 Mdot
.61888 .01524 Mdot
.61891 .01527 Mdot
.61893 .01498 Mdot
.61896 .01494 Mdot
.61899 .01706 Mdot
.61901 .01579 Mdot
.61904 .01557 Mdot
.61906 .01609 Mdot
.61909 .01524 Mdot
.61912 .01563 Mdot
.61914 .01527 Mdot
.61917 .01548 Mdot
.61919 .01599 Mdot
.61922 .01555 Mdot
.61924 .01506 Mdot
.61927 .0157 Mdot
.6193 .01524 Mdot
.61932 .01599 Mdot
.61935 .01516 Mdot
.61937 .01592 Mdot
.6194 .01555 Mdot
.61943 .01586 Mdot
.61945 .01555 Mdot
.61948 .01582 Mdot
.6195 .01544 Mdot
.61953 .0154 Mdot
.61955 .01612 Mdot
.61958 .01517 Mdot
.61961 .01564 Mdot
.61963 .01529 Mdot
.61966 .01551 Mdot
.61968 .0152 Mdot
.61971 .0152 Mdot
.61974 .01577 Mdot
.61976 .01492 Mdot
.61979 .01528 Mdot
.61981 .01563 Mdot
.61984 .01509 Mdot
.61986 .0154 Mdot
.61989 .0158 Mdot
.61992 .01567 Mdot
.61994 .01553 Mdot
.61997 .01536 Mdot
.61999 .01553 Mdot
.62002 .01574 Mdot
.62005 .01545 Mdot
.62007 .01574 Mdot
.6201 .01629 Mdot
.62012 .0152 Mdot
.62015 .01572 Mdot
.62017 .01579 Mdot
.6202 .01588 Mdot
.62023 .01563 Mdot
.62025 .01501 Mdot
.62028 .01523 Mdot
.6203 .01575 Mdot
.62033 .01507 Mdot
.62036 .01611 Mdot
.62038 .01658 Mdot
.62041 .01689 Mdot
.62043 .01509 Mdot
.62046 .01631 Mdot
.62048 .01633 Mdot
.62051 .01655 Mdot
.62054 .01605 Mdot
.62056 .01563 Mdot
.62059 .01492 Mdot
.62061 .0162 Mdot
.62064 .01581 Mdot
.62067 .01514 Mdot
.62069 .01512 Mdot
.62072 .01561 Mdot
.62074 .01515 Mdot
.62077 .01554 Mdot
.62079 .01647 Mdot
.62082 .01574 Mdot
.62085 .01597 Mdot
.62087 .01558 Mdot
.6209 .01491 Mdot
.62092 .01671 Mdot
.62095 .01516 Mdot
.62098 .01563 Mdot
.621 .01536 Mdot
.62103 .01536 Mdot
.62105 .01525 Mdot
.62108 .01562 Mdot
.6211 .01611 Mdot
.62113 .01504 Mdot
.62116 .01572 Mdot
.62118 .01542 Mdot
.62121 .01542 Mdot
.62123 .0155 Mdot
.62126 .01613 Mdot
.62129 .01515 Mdot
.62131 .01613 Mdot
.62134 .01609 Mdot
.62136 .01536 Mdot
.62139 .01509 Mdot
.62141 .01529 Mdot
.62144 .01587 Mdot
.62147 .01525 Mdot
.62149 .01629 Mdot
.62152 .01575 Mdot
.62154 .01506 Mdot
.62157 .01536 Mdot
.6216 .01524 Mdot
.62162 .01514 Mdot
.62165 .01541 Mdot
.62167 .01712 Mdot
.6217 .01654 Mdot
.62172 .01647 Mdot
.62175 .01482 Mdot
.62178 .01608 Mdot
.6218 .01563 Mdot
.62183 .01651 Mdot
.62185 .01667 Mdot
.62188 .01565 Mdot
.62191 .01513 Mdot
.62193 .0162 Mdot
.62196 .01507 Mdot
.62198 .01607 Mdot
.62201 .01655 Mdot
.62203 .01589 Mdot
.62206 .01597 Mdot
.62209 .0153 Mdot
.62211 .01515 Mdot
.62214 .01531 Mdot
.62216 .01543 Mdot
.62219 .01563 Mdot
.62222 .01528 Mdot
.62224 .01489 Mdot
.62227 .01591 Mdot
.62229 .01494 Mdot
.62232 .01567 Mdot
.62234 .01567 Mdot
.62237 .01524 Mdot
.6224 .01565 Mdot
.62242 .01622 Mdot
.62245 .01557 Mdot
.62247 .01531 Mdot
.6225 .01686 Mdot
.62253 .01576 Mdot
.62255 .01508 Mdot
.62258 .01543 Mdot
.6226 .01538 Mdot
.62263 .01573 Mdot
.62265 .01516 Mdot
.62268 .01549 Mdot
.62271 .0155 Mdot
.62273 .0156 Mdot
.62276 .0166 Mdot
.62278 .01524 Mdot
.62281 .01564 Mdot
.62284 .01741 Mdot
.62286 .01541 Mdot
.62289 .0165 Mdot
.62291 .01547 Mdot
.62294 .01596 Mdot
.62296 .01534 Mdot
.62299 .01671 Mdot
.62302 .0151 Mdot
.62304 .01556 Mdot
.62307 .01535 Mdot
.62309 .0152 Mdot
.62312 .01511 Mdot
.62315 .01562 Mdot
.62317 .01627 Mdot
.6232 .01647 Mdot
.62322 .01484 Mdot
.62325 .01533 Mdot
.62327 .01544 Mdot
.6233 .01745 Mdot
.62333 .01623 Mdot
.62335 .01558 Mdot
.62338 .01571 Mdot
.6234 .01521 Mdot
.62343 .01503 Mdot
.62346 .01548 Mdot
.62348 .01547 Mdot
.62351 .01626 Mdot
.62353 .01546 Mdot
.62356 .01666 Mdot
.62359 .01639 Mdot
.62361 .01608 Mdot
.62364 .01622 Mdot
.62366 .01518 Mdot
.62369 .01502 Mdot
.62371 .01537 Mdot
.62374 .01516 Mdot
.62377 .01581 Mdot
.62379 .01649 Mdot
.62382 .01559 Mdot
.62384 .01483 Mdot
.62387 .01535 Mdot
.6239 .01629 Mdot
.62392 .01576 Mdot
.62395 .0156 Mdot
.62397 .01535 Mdot
.624 .01517 Mdot
.62402 .01509 Mdot
.62405 .01612 Mdot
.62408 .01654 Mdot
.6241 .01482 Mdot
.62413 .01488 Mdot
.62415 .01675 Mdot
.62418 .01617 Mdot
.62421 .01517 Mdot
.62423 .01536 Mdot
.62426 .01614 Mdot
.62428 .01559 Mdot
.62431 .0159 Mdot
.62433 .01513 Mdot
.62436 .01511 Mdot
.62439 .01514 Mdot
.62441 .01556 Mdot
.62444 .01612 Mdot
.62446 .01559 Mdot
.62449 .01594 Mdot
.62452 .01548 Mdot
.62454 .0154 Mdot
.62457 .01563 Mdot
.62459 .01569 Mdot
.62462 .01591 Mdot
.62464 .01534 Mdot
.62467 .01597 Mdot
.6247 .01514 Mdot
.62472 .01544 Mdot
.62475 .01585 Mdot
.62477 .01542 Mdot
.6248 .01507 Mdot
.62483 .01506 Mdot
.62485 .01559 Mdot
.62488 .01606 Mdot
.6249 .01611 Mdot
.62493 .01596 Mdot
.62495 .01614 Mdot
.62498 .01538 Mdot
.62501 .01492 Mdot
.62503 .01547 Mdot
.62506 .01549 Mdot
.62508 .01577 Mdot
.62511 .01566 Mdot
.62514 .01565 Mdot
.62516 .0156 Mdot
.62519 .01524 Mdot
.62521 .01574 Mdot
.62524 .01524 Mdot
.62526 .01548 Mdot
.62529 .01625 Mdot
.62532 .01603 Mdot
.62534 .01558 Mdot
.62537 .01562 Mdot
.62539 .01525 Mdot
.62542 .01505 Mdot
.62545 .01638 Mdot
.62547 .01553 Mdot
.6255 .01583 Mdot
.62552 .01655 Mdot
.62555 .01558 Mdot
.62557 .01609 Mdot
.6256 .01532 Mdot
.62563 .0154 Mdot
.62565 .01654 Mdot
.62568 .015 Mdot
.6257 .01623 Mdot
.62573 .01525 Mdot
.62576 .01503 Mdot
.62578 .01621 Mdot
.62581 .01533 Mdot
.62583 .0155 Mdot
.62586 .01563 Mdot
.62588 .01688 Mdot
.62591 .01627 Mdot
.62594 .01586 Mdot
.62596 .01578 Mdot
.62599 .01599 Mdot
.62601 .01515 Mdot
.62604 .01618 Mdot
.62607 .01594 Mdot
.62609 .01525 Mdot
.62612 .01577 Mdot
.62614 .01549 Mdot
.62617 .0161 Mdot
.62619 .0161 Mdot
.62622 .01605 Mdot
.62625 .01528 Mdot
.62627 .01602 Mdot
.6263 .0161 Mdot
.62632 .01635 Mdot
.62635 .01615 Mdot
.62638 .01551 Mdot
.6264 .01655 Mdot
.62643 .01509 Mdot
.62645 .01536 Mdot
.62648 .01537 Mdot
.6265 .01503 Mdot
.62653 .01479 Mdot
.62656 .01616 Mdot
.62658 .01535 Mdot
.62661 .01621 Mdot
.62663 .01557 Mdot
.62666 .01552 Mdot
.62669 .01582 Mdot
.62671 .01598 Mdot
.62674 .01661 Mdot
.62676 .01542 Mdot
.62679 .0157 Mdot
.62681 .01595 Mdot
.62684 .01578 Mdot
.62687 .0157 Mdot
.62689 .01717 Mdot
.62692 .01654 Mdot
.62694 .01537 Mdot
.62697 .01527 Mdot
.627 .01551 Mdot
.62702 .01676 Mdot
.62705 .01579 Mdot
.62707 .01541 Mdot
.6271 .01645 Mdot
.62712 .01531 Mdot
.62715 .0166 Mdot
.62718 .01534 Mdot
.6272 .01522 Mdot
.62723 .01583 Mdot
.62725 .01557 Mdot
.62728 .01591 Mdot
.62731 .01543 Mdot
.62733 .01493 Mdot
.62736 .0167 Mdot
.62738 .01602 Mdot
.62741 .01709 Mdot
.62743 .01601 Mdot
.62746 .01623 Mdot
.62749 .0151 Mdot
.62751 .01586 Mdot
.62754 .01564 Mdot
.62756 .01595 Mdot
.62759 .01515 Mdot
.62762 .01581 Mdot
.62764 .01564 Mdot
.62767 .01528 Mdot
.62769 .01551 Mdot
.62772 .01613 Mdot
.62774 .0163 Mdot
.62777 .01537 Mdot
.6278 .01542 Mdot
.62782 .01584 Mdot
.62785 .01644 Mdot
.62787 .01546 Mdot
.6279 .01502 Mdot
.62793 .01518 Mdot
.62795 .01496 Mdot
.62798 .01534 Mdot
.628 .01541 Mdot
.62803 .01636 Mdot
.62805 .01673 Mdot
.62808 .01524 Mdot
.62811 .01521 Mdot
.62813 .0161 Mdot
.62816 .01489 Mdot
.62818 .01573 Mdot
.62821 .01558 Mdot
.62824 .01654 Mdot
.62826 .01614 Mdot
.62829 .01607 Mdot
.62831 .01555 Mdot
.62834 .01615 Mdot
.62836 .01639 Mdot
.62839 .01528 Mdot
.62842 .01543 Mdot
.62844 .01516 Mdot
.62847 .0157 Mdot
.62849 .01645 Mdot
.62852 .0162 Mdot
.62855 .01513 Mdot
.62857 .01642 Mdot
.6286 .01651 Mdot
.62862 .01563 Mdot
.62865 .01616 Mdot
.62867 .01522 Mdot
.6287 .01563 Mdot
.62873 .01564 Mdot
.62875 .01481 Mdot
.62878 .01496 Mdot
.6288 .01527 Mdot
.62883 .01577 Mdot
.62886 .01585 Mdot
.62888 .01572 Mdot
.62891 .0158 Mdot
.62893 .0159 Mdot
.62896 .01535 Mdot
.62898 .01614 Mdot
.62901 .01551 Mdot
.62904 .01526 Mdot
.62906 .0154 Mdot
.62909 .016 Mdot
.62911 .0159 Mdot
.62914 .01672 Mdot
.62917 .01588 Mdot
.62919 .01554 Mdot
.62922 .01526 Mdot
.62924 .01518 Mdot
.62927 .01601 Mdot
.62929 .01525 Mdot
.62932 .01525 Mdot
.62935 .01494 Mdot
.62937 .01492 Mdot
.6294 .01622 Mdot
.62942 .01538 Mdot
.62945 .01513 Mdot
.62948 .01613 Mdot
.6295 .01588 Mdot
.62953 .01641 Mdot
.62955 .0158 Mdot
.62958 .01549 Mdot
.6296 .01571 Mdot
.62963 .01511 Mdot
.62966 .01545 Mdot
.62968 .01574 Mdot
.62971 .01601 Mdot
.62973 .01528 Mdot
.62976 .01553 Mdot
.62979 .01609 Mdot
.62981 .01574 Mdot
.62984 .01535 Mdot
.62986 .01567 Mdot
.62989 .01558 Mdot
.62991 .0167 Mdot
.62994 .01595 Mdot
.62997 .01627 Mdot
.62999 .01595 Mdot
.63002 .01681 Mdot
.63004 .01521 Mdot
.63007 .01493 Mdot
.6301 .01543 Mdot
.63012 .01662 Mdot
.63015 .01611 Mdot
.63017 .01627 Mdot
.6302 .01567 Mdot
.63022 .01534 Mdot
.63025 .01567 Mdot
.63028 .01511 Mdot
.6303 .01557 Mdot
.63033 .01622 Mdot
.63035 .01572 Mdot
.63038 .01551 Mdot
.63041 .01565 Mdot
.63043 .01565 Mdot
.63046 .01577 Mdot
.63048 .0153 Mdot
.63051 .01617 Mdot
.63053 .01569 Mdot
.63056 .01531 Mdot
.63059 .01569 Mdot
.63061 .01483 Mdot
.63064 .0152 Mdot
.63066 .01522 Mdot
.63069 .0152 Mdot
.63072 .01616 Mdot
.63074 .01607 Mdot
.63077 .01658 Mdot
.63079 .01524 Mdot
.63082 .01526 Mdot
.63084 .01487 Mdot
.63087 .01548 Mdot
.6309 .01557 Mdot
.63092 .016 Mdot
.63095 .01553 Mdot
.63097 .01603 Mdot
.631 .01574 Mdot
.63103 .01511 Mdot
.63105 .01656 Mdot
.63108 .01603 Mdot
.6311 .0154 Mdot
.63113 .0149 Mdot
.63115 .01646 Mdot
.63118 .01533 Mdot
.63121 .01522 Mdot
.63123 .01533 Mdot
.63126 .01559 Mdot
.63128 .01743 Mdot
.63131 .01546 Mdot
.63134 .01618 Mdot
.63136 .01577 Mdot
.63139 .01584 Mdot
.63141 .01515 Mdot
.63144 .01577 Mdot
.63146 .01548 Mdot
.63149 .01484 Mdot
.63152 .01479 Mdot
.63154 .01599 Mdot
.63157 .01535 Mdot
.63159 .01613 Mdot
.63162 .01529 Mdot
.63165 .01556 Mdot
.63167 .01565 Mdot
.6317 .01545 Mdot
.63172 .01582 Mdot
.63175 .01595 Mdot
.63177 .01652 Mdot
.6318 .01621 Mdot
.63183 .01592 Mdot
.63185 .01606 Mdot
.63188 .01558 Mdot
.6319 .01507 Mdot
.63193 .01599 Mdot
.63196 .01525 Mdot
.63198 .0164 Mdot
.63201 .01582 Mdot
.63203 .01485 Mdot
.63206 .01567 Mdot
.63208 .01482 Mdot
.63211 .01582 Mdot
.63214 .01656 Mdot
.63216 .01535 Mdot
.63219 .01548 Mdot
.63221 .01588 Mdot
.63224 .01563 Mdot
.63227 .01584 Mdot
.63229 .01538 Mdot
.63232 .01582 Mdot
.63234 .01595 Mdot
.63237 .01552 Mdot
.63239 .01687 Mdot
.63242 .01578 Mdot
.63245 .01603 Mdot
.63247 .01585 Mdot
.6325 .01583 Mdot
.63252 .01598 Mdot
.63255 .01621 Mdot
.63258 .01591 Mdot
.6326 .01638 Mdot
.63263 .01575 Mdot
.63265 .01567 Mdot
.63268 .01513 Mdot
.63271 .01583 Mdot
.63273 .015 Mdot
.63276 .01595 Mdot
.63278 .01533 Mdot
.63281 .01489 Mdot
.63283 .01591 Mdot
.63286 .01517 Mdot
.63289 .01588 Mdot
.63291 .01522 Mdot
.63294 .01515 Mdot
.63296 .01607 Mdot
.63299 .01551 Mdot
.63302 .01534 Mdot
.63304 .01624 Mdot
.63307 .01543 Mdot
.63309 .01614 Mdot
.63312 .01496 Mdot
.63314 .01528 Mdot
.63317 .01604 Mdot
.6332 .01538 Mdot
.63322 .01561 Mdot
.63325 .01484 Mdot
.63327 .01568 Mdot
.6333 .01576 Mdot
.63333 .01665 Mdot
.63335 .01497 Mdot
.63338 .01491 Mdot
.6334 .01588 Mdot
.63343 .01498 Mdot
.63345 .01555 Mdot
.63348 .01542 Mdot
.63351 .01497 Mdot
.63353 .01544 Mdot
.63356 .01537 Mdot
.63358 .01559 Mdot
.63361 .01522 Mdot
.63364 .01592 Mdot
.63366 .01582 Mdot
.63369 .01586 Mdot
.63371 .01588 Mdot
.63374 .01532 Mdot
.63376 .01557 Mdot
.63379 .01665 Mdot
.63382 .01592 Mdot
.63384 .0152 Mdot
.63387 .01526 Mdot
.63389 .01501 Mdot
.63392 .0162 Mdot
.63395 .01633 Mdot
.63397 .01513 Mdot
.634 .01567 Mdot
.63402 .01535 Mdot
.63405 .01584 Mdot
.63407 .01579 Mdot
.6341 .01532 Mdot
.63413 .01535 Mdot
.63415 .01543 Mdot
.63418 .01574 Mdot
.6342 .01608 Mdot
.63423 .0157 Mdot
.63426 .01543 Mdot
.63428 .01592 Mdot
.63431 .01541 Mdot
.63433 .01625 Mdot
.63436 .01543 Mdot
.63438 .01627 Mdot
.63441 .01546 Mdot
.63444 .01529 Mdot
.63446 .01597 Mdot
.63449 .01519 Mdot
.63451 .01508 Mdot
.63454 .01576 Mdot
.63457 .01602 Mdot
.63459 .01571 Mdot
.63462 .01672 Mdot
.63464 .01648 Mdot
.63467 .01545 Mdot
.63469 .0161 Mdot
.63472 .01557 Mdot
.63475 .01546 Mdot
.63477 .01611 Mdot
.6348 .01571 Mdot
.63482 .01557 Mdot
.63485 .01513 Mdot
.63488 .01511 Mdot
.6349 .01583 Mdot
.63493 .01562 Mdot
.63495 .01558 Mdot
.63498 .01548 Mdot
.635 .01559 Mdot
.63503 .01549 Mdot
.63506 .01634 Mdot
.63508 .01618 Mdot
.63511 .01614 Mdot
.63513 .01612 Mdot
.63516 .01583 Mdot
.63519 .01625 Mdot
.63521 .01552 Mdot
.63524 .01532 Mdot
.63526 .01529 Mdot
.63529 .01522 Mdot
.63531 .01582 Mdot
.63534 .0161 Mdot
.63537 .01583 Mdot
.63539 .01491 Mdot
.63542 .0156 Mdot
.63544 .0158 Mdot
.63547 .01524 Mdot
.6355 .0154 Mdot
.63552 .01533 Mdot
.63555 .01592 Mdot
.63557 .01499 Mdot
.6356 .01549 Mdot
.63562 .01636 Mdot
.63565 .01509 Mdot
.63568 .01687 Mdot
.6357 .01538 Mdot
.63573 .01515 Mdot
.63575 .01572 Mdot
.63578 .01613 Mdot
.63581 .01542 Mdot
.63583 .01578 Mdot
.63586 .01524 Mdot
.63588 .01546 Mdot
.63591 .01545 Mdot
.63593 .01637 Mdot
.63596 .01592 Mdot
.63599 .01571 Mdot
.63601 .01504 Mdot
.63604 .01598 Mdot
.63606 .016 Mdot
.63609 .01619 Mdot
.63612 .01505 Mdot
.63614 .01627 Mdot
.63617 .01568 Mdot
.63619 .01541 Mdot
.63622 .01571 Mdot
.63624 .01484 Mdot
.63627 .01553 Mdot
.6363 .01529 Mdot
.63632 .01516 Mdot
.63635 .01536 Mdot
.63637 .01503 Mdot
.6364 .01571 Mdot
.63643 .01592 Mdot
.63645 .01574 Mdot
.63648 .01557 Mdot
.6365 .01617 Mdot
.63653 .01673 Mdot
.63655 .018 Mdot
.63658 .0158 Mdot
.63661 .01584 Mdot
.63663 .01637 Mdot
.63666 .01511 Mdot
.63668 .01608 Mdot
.63671 .01518 Mdot
.63674 .01607 Mdot
.63676 .01558 Mdot
.63679 .01512 Mdot
.63681 .01596 Mdot
.63684 .0153 Mdot
.63686 .01523 Mdot
.63689 .0168 Mdot
.63692 .0156 Mdot
.63694 .01514 Mdot
.63697 .01583 Mdot
.63699 .01548 Mdot
.63702 .01584 Mdot
.63705 .01616 Mdot
.63707 .01551 Mdot
.6371 .01511 Mdot
.63712 .01621 Mdot
.63715 .0151 Mdot
.63717 .01522 Mdot
.6372 .01505 Mdot
.63723 .01527 Mdot
.63725 .01526 Mdot
.63728 .01551 Mdot
.6373 .01566 Mdot
.63733 .01555 Mdot
.63736 .01492 Mdot
.63738 .01626 Mdot
.63741 .0157 Mdot
.63743 .01518 Mdot
.63746 .01526 Mdot
.63748 .01513 Mdot
.63751 .01569 Mdot
.63754 .01562 Mdot
.63756 .01532 Mdot
.63759 .0166 Mdot
.63761 .01659 Mdot
.63764 .0162 Mdot
.63767 .01531 Mdot
.63769 .01532 Mdot
.63772 .01581 Mdot
.63774 .01502 Mdot
.63777 .01522 Mdot
.63779 .01523 Mdot
.63782 .01567 Mdot
.63785 .01627 Mdot
.63787 .01542 Mdot
.6379 .01623 Mdot
.63792 .01503 Mdot
.63795 .01606 Mdot
.63798 .01596 Mdot
.638 .01486 Mdot
.63803 .01566 Mdot
.63805 .01568 Mdot
.63808 .01491 Mdot
.6381 .01542 Mdot
.63813 .01588 Mdot
.63816 .0153 Mdot
.63818 .01567 Mdot
.63821 .01578 Mdot
.63823 .01689 Mdot
.63826 .01575 Mdot
.63829 .01558 Mdot
.63831 .01576 Mdot
.63834 .01536 Mdot
.63836 .01624 Mdot
.63839 .01636 Mdot
.63841 .01535 Mdot
.63844 .01592 Mdot
.63847 .01636 Mdot
.63849 .01583 Mdot
.63852 .01527 Mdot
.63854 .01556 Mdot
.63857 .01488 Mdot
.6386 .01551 Mdot
.63862 .01532 Mdot
.63865 .01588 Mdot
.63867 .01604 Mdot
.6387 .01583 Mdot
.63872 .01664 Mdot
.63875 .01549 Mdot
.63878 .01523 Mdot
.6388 .01599 Mdot
.63883 .01591 Mdot
.63885 .01522 Mdot
.63888 .01625 Mdot
.63891 .01626 Mdot
.63893 .01525 Mdot
.63896 .01645 Mdot
.63898 .01508 Mdot
.63901 .01528 Mdot
.63903 .01481 Mdot
.63906 .01565 Mdot
.63909 .01559 Mdot
.63911 .01533 Mdot
.63914 .01521 Mdot
.63916 .01575 Mdot
.63919 .01592 Mdot
.63922 .01528 Mdot
.63924 .01558 Mdot
.63927 .01559 Mdot
.63929 .01611 Mdot
.63932 .01488 Mdot
.63934 .01658 Mdot
.63937 .01527 Mdot
.6394 .01672 Mdot
.63942 .01514 Mdot
.63945 .01509 Mdot
.63947 .01576 Mdot
.6395 .01508 Mdot
.63953 .0154 Mdot
.63955 .01545 Mdot
.63958 .01708 Mdot
.6396 .01524 Mdot
.63963 .01559 Mdot
.63965 .01597 Mdot
.63968 .01654 Mdot
.63971 .01575 Mdot
.63973 .01551 Mdot
.63976 .01689 Mdot
.63978 .01599 Mdot
.63981 .01656 Mdot
.63984 .01626 Mdot
.63986 .01504 Mdot
.63989 .01567 Mdot
.63991 .01571 Mdot
.63994 .01531 Mdot
.63996 .01517 Mdot
.63999 .01555 Mdot
.64002 .01566 Mdot
.64004 .0153 Mdot
.64007 .01532 Mdot
.64009 .01495 Mdot
.64012 .01545 Mdot
.64015 .01637 Mdot
.64017 .01579 Mdot
.6402 .01625 Mdot
.64022 .0157 Mdot
.64025 .01657 Mdot
.64027 .0149 Mdot
.6403 .01535 Mdot
.64033 .01553 Mdot
.64035 .01652 Mdot
.64038 .01581 Mdot
.6404 .01491 Mdot
.64043 .01696 Mdot
.64046 .01631 Mdot
.64048 .01545 Mdot
.64051 .01532 Mdot
.64053 .01652 Mdot
.64056 .01577 Mdot
.64058 .01597 Mdot
.64061 .01516 Mdot
.64064 .01533 Mdot
.64066 .01643 Mdot
.64069 .01557 Mdot
.64071 .01511 Mdot
.64074 .01714 Mdot
.64077 .01585 Mdot
.64079 .01574 Mdot
.64082 .01628 Mdot
.64084 .01588 Mdot
.64087 .01487 Mdot
.64089 .0157 Mdot
.64092 .0151 Mdot
.64095 .0153 Mdot
.64097 .01554 Mdot
.641 .01534 Mdot
.64102 .01561 Mdot
.64105 .01629 Mdot
.64108 .01521 Mdot
.6411 .01571 Mdot
.64113 .01592 Mdot
.64115 .01532 Mdot
.64118 .01573 Mdot
.6412 .01532 Mdot
.64123 .01602 Mdot
.64126 .01565 Mdot
.64128 .01637 Mdot
.64131 .01694 Mdot
.64133 .01525 Mdot
.64136 .0153 Mdot
.64139 .01545 Mdot
.64141 .0151 Mdot
.64144 .01587 Mdot
.64146 .01556 Mdot
.64149 .01572 Mdot
.64151 .01518 Mdot
.64154 .01561 Mdot
.64157 .01537 Mdot
.64159 .01546 Mdot
.64162 .0149 Mdot
.64164 .01585 Mdot
.64167 .01608 Mdot
.6417 .01521 Mdot
.64172 .01549 Mdot
.64175 .01549 Mdot
.64177 .01711 Mdot
.6418 .0162 Mdot
.64183 .01634 Mdot
.64185 .01506 Mdot
.64188 .01565 Mdot
.6419 .01544 Mdot
.64193 .01566 Mdot
.64195 .01578 Mdot
.64198 .01517 Mdot
.64201 .01623 Mdot
.64203 .01585 Mdot
.64206 .01585 Mdot
.64208 .01549 Mdot
.64211 .01656 Mdot
.64214 .0161 Mdot
.64216 .01604 Mdot
.64219 .01632 Mdot
.64221 .01591 Mdot
.64224 .01565 Mdot
.64226 .01523 Mdot
.64229 .01519 Mdot
.64232 .01546 Mdot
.64234 .01495 Mdot
.64237 .0154 Mdot
.64239 .0164 Mdot
.64242 .0153 Mdot
.64245 .01531 Mdot
.64247 .0161 Mdot
.6425 .01556 Mdot
.64252 .01524 Mdot
.64255 .01527 Mdot
.64257 .01478 Mdot
.6426 .01526 Mdot
.64263 .01523 Mdot
.64265 .01557 Mdot
.64268 .01501 Mdot
.6427 .01559 Mdot
.64273 .01529 Mdot
.64276 .01507 Mdot
.64278 .01522 Mdot
.64281 .01601 Mdot
.64283 .01574 Mdot
.64286 .01602 Mdot
.64288 .01489 Mdot
.64291 .01516 Mdot
.64294 .0159 Mdot
.64296 .01582 Mdot
.64299 .01653 Mdot
.64301 .01546 Mdot
.64304 .0157 Mdot
.64307 .0152 Mdot
.64309 .01567 Mdot
.64312 .01606 Mdot
.64314 .01608 Mdot
.64317 .01615 Mdot
.64319 .01632 Mdot
.64322 .01572 Mdot
.64325 .01546 Mdot
.64327 .01495 Mdot
.6433 .01633 Mdot
.64332 .01562 Mdot
.64335 .01541 Mdot
.64338 .01541 Mdot
.6434 .01608 Mdot
.64343 .01601 Mdot
.64345 .01651 Mdot
.64348 .01687 Mdot
.6435 .01566 Mdot
.64353 .01614 Mdot
.64356 .01502 Mdot
.64358 .01656 Mdot
.64361 .01565 Mdot
.64363 .01523 Mdot
.64366 .01503 Mdot
.64369 .01523 Mdot
.64371 .01509 Mdot
.64374 .01578 Mdot
.64376 .01506 Mdot
.64379 .01565 Mdot
.64381 .01568 Mdot
.64384 .01512 Mdot
.64387 .01536 Mdot
.64389 .01495 Mdot
.64392 .01668 Mdot
.64394 .01523 Mdot
.64397 .01539 Mdot
.644 .01706 Mdot
.64402 .01553 Mdot
.64405 .01505 Mdot
.64407 .01624 Mdot
.6441 .01565 Mdot
.64412 .01563 Mdot
.64415 .0164 Mdot
.64418 .0149 Mdot
.6442 .01541 Mdot
.64423 .01601 Mdot
.64425 .01543 Mdot
.64428 .0153 Mdot
.64431 .01577 Mdot
.64433 .01573 Mdot
.64436 .01524 Mdot
.64438 .01584 Mdot
.64441 .01616 Mdot
.64443 .01613 Mdot
.64446 .01527 Mdot
.64449 .01537 Mdot
.64451 .0163 Mdot
.64454 .01535 Mdot
.64456 .01489 Mdot
.64459 .01557 Mdot
.64462 .0157 Mdot
.64464 .01501 Mdot
.64467 .0152 Mdot
.64469 .01548 Mdot
.64472 .01606 Mdot
.64474 .01598 Mdot
.64477 .01537 Mdot
.6448 .01503 Mdot
.64482 .01553 Mdot
.64485 .01541 Mdot
.64487 .01513 Mdot
.6449 .0157 Mdot
.64493 .01544 Mdot
.64495 .01753 Mdot
.64498 .01527 Mdot
.645 .0149 Mdot
.64503 .01604 Mdot
.64505 .01512 Mdot
.64508 .01538 Mdot
.64511 .01588 Mdot
.64513 .01565 Mdot
.64516 .01498 Mdot
.64518 .01512 Mdot
.64521 .0157 Mdot
.64524 .01506 Mdot
.64526 .01496 Mdot
.64529 .01501 Mdot
.64531 .01642 Mdot
.64534 .0158 Mdot
.64536 .01547 Mdot
.64539 .01623 Mdot
.64542 .01533 Mdot
.64544 .01566 Mdot
.64547 .01499 Mdot
.64549 .01481 Mdot
.64552 .01639 Mdot
.64555 .01558 Mdot
.64557 .01517 Mdot
.6456 .0168 Mdot
.64562 .01499 Mdot
.64565 .01514 Mdot
.64567 .01587 Mdot
.6457 .01623 Mdot
.64573 .0156 Mdot
.64575 .01636 Mdot
.64578 .0148 Mdot
.6458 .01497 Mdot
.64583 .01578 Mdot
.64586 .01599 Mdot
.64588 .01706 Mdot
.64591 .01588 Mdot
.64593 .01542 Mdot
.64596 .01594 Mdot
.64598 .01544 Mdot
.64601 .01503 Mdot
.64604 .01508 Mdot
.64606 .01523 Mdot
.64609 .01623 Mdot
.64611 .01588 Mdot
.64614 .01585 Mdot
.64617 .01568 Mdot
.64619 .01588 Mdot
.64622 .01522 Mdot
.64624 .01571 Mdot
.64627 .01598 Mdot
.64629 .01491 Mdot
.64632 .01591 Mdot
.64635 .0155 Mdot
.64637 .01522 Mdot
.6464 .01543 Mdot
.64642 .01526 Mdot
.64645 .01582 Mdot
.64648 .01526 Mdot
.6465 .01584 Mdot
.64653 .01605 Mdot
.64655 .01497 Mdot
.64658 .01617 Mdot
.6466 .01609 Mdot
.64663 .01538 Mdot
.64666 .01556 Mdot
.64668 .0164 Mdot
.64671 .01559 Mdot
.64673 .01546 Mdot
.64676 .01527 Mdot
.64679 .01629 Mdot
.64681 .01655 Mdot
.64684 .01603 Mdot
.64686 .0161 Mdot
.64689 .01548 Mdot
.64691 .01552 Mdot
.64694 .01509 Mdot
.64697 .01536 Mdot
.64699 .0156 Mdot
.64702 .01535 Mdot
.64704 .01657 Mdot
.64707 .016 Mdot
.6471 .01503 Mdot
.64712 .01543 Mdot
.64715 .01638 Mdot
.64717 .01633 Mdot
.6472 .01535 Mdot
.64722 .01537 Mdot
.64725 .01504 Mdot
.64728 .01582 Mdot
.6473 .01616 Mdot
.64733 .01497 Mdot
.64735 .01531 Mdot
.64738 .01583 Mdot
.64741 .01594 Mdot
.64743 .01531 Mdot
.64746 .01545 Mdot
.64748 .0155 Mdot
.64751 .01539 Mdot
.64753 .01511 Mdot
.64756 .01547 Mdot
.64759 .01567 Mdot
.64761 .01547 Mdot
.64764 .01709 Mdot
.64766 .01521 Mdot
.64769 .01601 Mdot
.64772 .01485 Mdot
.64774 .01617 Mdot
.64777 .01578 Mdot
.64779 .0148 Mdot
.64782 .01501 Mdot
.64784 .01536 Mdot
.64787 .01578 Mdot
.6479 .01615 Mdot
.64792 .0159 Mdot
.64795 .01524 Mdot
.64797 .01546 Mdot
.648 .01554 Mdot
.64803 .0151 Mdot
.64805 .01503 Mdot
.64808 .01652 Mdot
.6481 .01494 Mdot
.64813 .01656 Mdot
.64815 .01488 Mdot
.64818 .01541 Mdot
.64821 .01566 Mdot
.64823 .015 Mdot
.64826 .01592 Mdot
.64828 .01588 Mdot
.64831 .01581 Mdot
.64834 .01583 Mdot
.64836 .01555 Mdot
.64839 .0158 Mdot
.64841 .01596 Mdot
.64844 .01536 Mdot
.64846 .01591 Mdot
.64849 .0159 Mdot
.64852 .01631 Mdot
.64854 .01598 Mdot
.64857 .01536 Mdot
.64859 .01627 Mdot
.64862 .01485 Mdot
.64865 .01492 Mdot
.64867 .01578 Mdot
.6487 .01571 Mdot
.64872 .01521 Mdot
.64875 .01493 Mdot
.64877 .01611 Mdot
.6488 .01581 Mdot
.64883 .01503 Mdot
.64885 .01582 Mdot
.64888 .01565 Mdot
.6489 .01518 Mdot
.64893 .01688 Mdot
.64896 .01648 Mdot
.64898 .01591 Mdot
.64901 .01478 Mdot
.64903 .01677 Mdot
.64906 .01495 Mdot
.64908 .01542 Mdot
.64911 .01678 Mdot
.64914 .01668 Mdot
.64916 .01538 Mdot
.64919 .01588 Mdot
.64921 .01551 Mdot
.64924 .01576 Mdot
.64927 .01576 Mdot
.64929 .01548 Mdot
.64932 .01607 Mdot
.64934 .01681 Mdot
.64937 .01521 Mdot
.64939 .01567 Mdot
.64942 .01504 Mdot
.64945 .01528 Mdot
.64947 .01542 Mdot
.6495 .01519 Mdot
.64952 .01531 Mdot
.64955 .01542 Mdot
.64958 .01576 Mdot
.6496 .01518 Mdot
.64963 .01571 Mdot
.64965 .01578 Mdot
.64968 .01627 Mdot
.6497 .01522 Mdot
.64973 .01537 Mdot
.64976 .01537 Mdot
.64978 .01551 Mdot
.64981 .01617 Mdot
.64983 .01527 Mdot
.64986 .01564 Mdot
.64989 .01668 Mdot
.64991 .01598 Mdot
.64994 .01524 Mdot
.64996 .0167 Mdot
.64999 .01664 Mdot
.65001 .01514 Mdot
.65004 .0158 Mdot
.65007 .01612 Mdot
.65009 .01698 Mdot
.65012 .01529 Mdot
.65014 .01527 Mdot
.65017 .01533 Mdot
.6502 .01619 Mdot
.65022 .01624 Mdot
.65025 .01623 Mdot
.65027 .01561 Mdot
.6503 .01493 Mdot
.65032 .01586 Mdot
.65035 .01641 Mdot
.65038 .01584 Mdot
.6504 .01556 Mdot
.65043 .01541 Mdot
.65045 .01569 Mdot
.65048 .0154 Mdot
.65051 .01478 Mdot
.65053 .01638 Mdot
.65056 .0157 Mdot
.65058 .01564 Mdot
.65061 .01586 Mdot
.65063 .01537 Mdot
.65066 .01519 Mdot
.65069 .01615 Mdot
.65071 .01601 Mdot
.65074 .01556 Mdot
.65076 .0152 Mdot
.65079 .01549 Mdot
.65082 .0151 Mdot
.65084 .01615 Mdot
.65087 .01631 Mdot
.65089 .01664 Mdot
.65092 .01597 Mdot
.65095 .01506 Mdot
.65097 .01549 Mdot
.651 .01543 Mdot
.65102 .01563 Mdot
.65105 .01627 Mdot
.65107 .0154 Mdot
.6511 .01558 Mdot
.65113 .01548 Mdot
.65115 .01576 Mdot
.65118 .01557 Mdot
.6512 .01511 Mdot
.65123 .01571 Mdot
.65126 .01682 Mdot
.65128 .01531 Mdot
.65131 .01605 Mdot
.65133 .01586 Mdot
.65136 .01601 Mdot
.65138 .01524 Mdot
.65141 .01507 Mdot
.65144 .01646 Mdot
.65146 .01621 Mdot
.65149 .01541 Mdot
.65151 .01519 Mdot
.65154 .01538 Mdot
.65157 .0153 Mdot
.65159 .01494 Mdot
.65162 .01528 Mdot
.65164 .01524 Mdot
.65167 .01529 Mdot
.65169 .01509 Mdot
.65172 .01578 Mdot
.65175 .01576 Mdot
.65177 .01571 Mdot
.6518 .01556 Mdot
.65182 .01507 Mdot
.65185 .01662 Mdot
.65188 .01574 Mdot
.6519 .01604 Mdot
.65193 .01609 Mdot
.65195 .01519 Mdot
.65198 .01547 Mdot
.652 .01595 Mdot
.65203 .01552 Mdot
.65206 .01516 Mdot
.65208 .0156 Mdot
.65211 .0155 Mdot
.65213 .01548 Mdot
.65216 .01522 Mdot
.65219 .01617 Mdot
.65221 .0155 Mdot
.65224 .01654 Mdot
.65226 .01671 Mdot
.65229 .01579 Mdot
.65231 .01568 Mdot
.65234 .01604 Mdot
.65237 .0149 Mdot
.65239 .01516 Mdot
.65242 .015 Mdot
.65244 .01634 Mdot
.65247 .01592 Mdot
.6525 .01559 Mdot
.65252 .01535 Mdot
.65255 .0155 Mdot
.65257 .01627 Mdot
.6526 .01586 Mdot
.65262 .01539 Mdot
.65265 .0156 Mdot
.65268 .01527 Mdot
.6527 .01563 Mdot
.65273 .01661 Mdot
.65275 .01492 Mdot
.65278 .01479 Mdot
.65281 .01524 Mdot
.65283 .01567 Mdot
.65286 .01531 Mdot
.65288 .01731 Mdot
.65291 .01625 Mdot
.65293 .01566 Mdot
.65296 .01589 Mdot
.65299 .01568 Mdot
.65301 .01513 Mdot
.65304 .01552 Mdot
.65306 .01547 Mdot
.65309 .01606 Mdot
.65312 .01498 Mdot
.65314 .01513 Mdot
.65317 .01629 Mdot
.65319 .01617 Mdot
.65322 .01578 Mdot
.65324 .01592 Mdot
.65327 .01562 Mdot
.6533 .01553 Mdot
.65332 .01617 Mdot
.65335 .01521 Mdot
.65337 .01543 Mdot
.6534 .01523 Mdot
.65343 .01493 Mdot
.65345 .01567 Mdot
.65348 .01508 Mdot
.6535 .0156 Mdot
.65353 .01575 Mdot
.65355 .01537 Mdot
.65358 .01652 Mdot
.65361 .0167 Mdot
.65363 .01572 Mdot
.65366 .01552 Mdot
.65368 .01569 Mdot
.65371 .01494 Mdot
.65374 .01576 Mdot
.65376 .01641 Mdot
.65379 .01554 Mdot
.65381 .01619 Mdot
.65384 .01496 Mdot
.65386 .01581 Mdot
.65389 .01572 Mdot
.65392 .01609 Mdot
.65394 .01506 Mdot
.65397 .0154 Mdot
.65399 .01516 Mdot
.65402 .01598 Mdot
.65405 .01529 Mdot
.65407 .01539 Mdot
.6541 .01629 Mdot
.65412 .01623 Mdot
.65415 .01588 Mdot
.65417 .01531 Mdot
.6542 .01523 Mdot
.65423 .01481 Mdot
.65425 .01594 Mdot
.65428 .01546 Mdot
.6543 .0163 Mdot
.65433 .01486 Mdot
.65436 .01698 Mdot
.65438 .01497 Mdot
.65441 .01627 Mdot
.65443 .01662 Mdot
.65446 .01536 Mdot
.65448 .01571 Mdot
.65451 .01511 Mdot
.65454 .01503 Mdot
.65456 .01654 Mdot
.65459 .01497 Mdot
.65461 .01513 Mdot
.65464 .01603 Mdot
.65467 .01564 Mdot
.65469 .01504 Mdot
.65472 .01559 Mdot
.65474 .01672 Mdot
.65477 .01539 Mdot
.65479 .0157 Mdot
.65482 .01542 Mdot
.65485 .01613 Mdot
.65487 .01532 Mdot
.6549 .01535 Mdot
.65492 .01548 Mdot
.65495 .01543 Mdot
.65498 .01582 Mdot
.655 .01557 Mdot
.65503 .01499 Mdot
.65505 .01497 Mdot
.65508 .01489 Mdot
.6551 .01504 Mdot
.65513 .01535 Mdot
.65516 .01568 Mdot
.65518 .01555 Mdot
.65521 .0156 Mdot
.65523 .01604 Mdot
.65526 .01595 Mdot
.65529 .01494 Mdot
.65531 .01586 Mdot
.65534 .01571 Mdot
.65536 .01557 Mdot
.65539 .01547 Mdot
.65541 .01546 Mdot
.65544 .01665 Mdot
.65547 .01512 Mdot
.65549 .01484 Mdot
.65552 .0153 Mdot
.65554 .01661 Mdot
.65557 .01615 Mdot
.6556 .01549 Mdot
.65562 .01575 Mdot
.65565 .01524 Mdot
.65567 .01632 Mdot
.6557 .01507 Mdot
.65572 .01649 Mdot
.65575 .01515 Mdot
.65578 .01519 Mdot
.6558 .01488 Mdot
.65583 .01635 Mdot
.65585 .01561 Mdot
.65588 .01535 Mdot
.65591 .01532 Mdot
.65593 .01502 Mdot
.65596 .01512 Mdot
.65598 .01629 Mdot
.65601 .01756 Mdot
.65603 .01637 Mdot
.65606 .0161 Mdot
.65609 .01512 Mdot
.65611 .01564 Mdot
.65614 .01597 Mdot
.65616 .01644 Mdot
.65619 .01563 Mdot
.65622 .01572 Mdot
.65624 .01557 Mdot
.65627 .01571 Mdot
.65629 .01578 Mdot
.65632 .01665 Mdot
.65634 .01487 Mdot
.65637 .01505 Mdot
.6564 .01638 Mdot
.65642 .01597 Mdot
.65645 .0165 Mdot
.65647 .01622 Mdot
.6565 .01547 Mdot
.65653 .01601 Mdot
.65655 .01607 Mdot
.65658 .01533 Mdot
.6566 .01511 Mdot
.65663 .01557 Mdot
.65665 .0166 Mdot
.65668 .01571 Mdot
.65671 .01575 Mdot
.65673 .01539 Mdot
.65676 .0154 Mdot
.65678 .01599 Mdot
.65681 .01568 Mdot
.65684 .01612 Mdot
.65686 .0164 Mdot
.65689 .0163 Mdot
.65691 .01559 Mdot
.65694 .01582 Mdot
.65696 .01702 Mdot
.65699 .01717 Mdot
.65702 .0166 Mdot
.65704 .01541 Mdot
.65707 .01739 Mdot
.65709 .0149 Mdot
.65712 .01571 Mdot
.65715 .01529 Mdot
.65717 .01623 Mdot
.6572 .01591 Mdot
.65722 .01588 Mdot
.65725 .01654 Mdot
.65727 .01586 Mdot
.6573 .0156 Mdot
.65733 .01634 Mdot
.65735 .01657 Mdot
.65738 .01586 Mdot
.6574 .01675 Mdot
.65743 .01496 Mdot
.65746 .01515 Mdot
.65748 .0157 Mdot
.65751 .01572 Mdot
.65753 .0157 Mdot
.65756 .01576 Mdot
.65758 .01555 Mdot
.65761 .01529 Mdot
.65764 .01528 Mdot
.65766 .01564 Mdot
.65769 .01537 Mdot
.65771 .01574 Mdot
.65774 .01672 Mdot
.65777 .01502 Mdot
.65779 .016 Mdot
.65782 .01509 Mdot
.65784 .01596 Mdot
.65787 .01598 Mdot
.65789 .01671 Mdot
.65792 .01539 Mdot
.65795 .01548 Mdot
.65797 .01524 Mdot
.658 .01536 Mdot
.65802 .01637 Mdot
.65805 .01501 Mdot
.65808 .01505 Mdot
.6581 .01559 Mdot
.65813 .01606 Mdot
.65815 .01564 Mdot
.65818 .01535 Mdot
.6582 .01533 Mdot
.65823 .01558 Mdot
.65826 .01722 Mdot
.65828 .01521 Mdot
.65831 .01555 Mdot
.65833 .01619 Mdot
.65836 .01528 Mdot
.65839 .01538 Mdot
.65841 .01502 Mdot
.65844 .01575 Mdot
.65846 .0151 Mdot
.65849 .01604 Mdot
.65851 .01603 Mdot
.65854 .01579 Mdot
.65857 .0152 Mdot
.65859 .01599 Mdot
.65862 .01537 Mdot
.65864 .01619 Mdot
.65867 .01648 Mdot
.6587 .0153 Mdot
.65872 .01566 Mdot
.65875 .015 Mdot
.65877 .01554 Mdot
.6588 .01696 Mdot
.65882 .0156 Mdot
.65885 .01568 Mdot
.65888 .01525 Mdot
.6589 .01586 Mdot
.65893 .0155 Mdot
.65895 .01605 Mdot
.65898 .01504 Mdot
.65901 .01521 Mdot
.65903 .01614 Mdot
.65906 .01613 Mdot
.65908 .01546 Mdot
.65911 .01575 Mdot
.65913 .01637 Mdot
.65916 .01528 Mdot
.65919 .0161 Mdot
.65921 .01608 Mdot
.65924 .01597 Mdot
.65926 .01686 Mdot
.65929 .01515 Mdot
.65932 .01535 Mdot
.65934 .01664 Mdot
.65937 .01528 Mdot
.65939 .01569 Mdot
.65942 .01525 Mdot
.65944 .01626 Mdot
.65947 .01572 Mdot
.6595 .01637 Mdot
.65952 .01496 Mdot
.65955 .01562 Mdot
.65957 .01599 Mdot
.6596 .01617 Mdot
.65963 .01505 Mdot
.65965 .01542 Mdot
.65968 .01636 Mdot
.6597 .01552 Mdot
.65973 .01494 Mdot
.65975 .01547 Mdot
.65978 .01612 Mdot
.65981 .01496 Mdot
.65983 .01559 Mdot
.65986 .01531 Mdot
.65988 .01618 Mdot
.65991 .01518 Mdot
.65994 .01507 Mdot
.65996 .01682 Mdot
.65999 .01672 Mdot
.66001 .01515 Mdot
.66004 .01565 Mdot
.66007 .01492 Mdot
.66009 .01565 Mdot
.66012 .01483 Mdot
.66014 .01483 Mdot
.66017 .01492 Mdot
.66019 .01606 Mdot
.66022 .01604 Mdot
.66025 .01627 Mdot
.66027 .01542 Mdot
.6603 .0158 Mdot
.66032 .01602 Mdot
.66035 .01601 Mdot
.66038 .01584 Mdot
.6604 .01661 Mdot
.66043 .01587 Mdot
.66045 .01615 Mdot
.66048 .01647 Mdot
.6605 .01537 Mdot
.66053 .01519 Mdot
.66056 .01477 Mdot
.66058 .01594 Mdot
.66061 .01572 Mdot
.66063 .01545 Mdot
.66066 .01584 Mdot
.66069 .01591 Mdot
.66071 .01552 Mdot
.66074 .01538 Mdot
.66076 .01741 Mdot
.66079 .01575 Mdot
.66081 .01572 Mdot
.66084 .01533 Mdot
.66087 .01615 Mdot
.66089 .01516 Mdot
.66092 .01613 Mdot
.66094 .01513 Mdot
.66097 .01607 Mdot
.661 .01579 Mdot
.66102 .01553 Mdot
.66105 .01546 Mdot
.66107 .01614 Mdot
.6611 .01576 Mdot
.66112 .01537 Mdot
.66115 .01553 Mdot
.66118 .01575 Mdot
.6612 .01596 Mdot
.66123 .01602 Mdot
.66125 .01475 Mdot
.66128 .01559 Mdot
.66131 .01545 Mdot
.66133 .01559 Mdot
.66136 .01582 Mdot
.66138 .01625 Mdot
.66141 .01534 Mdot
.66143 .01656 Mdot
.66146 .01472 Mdot
.66149 .01651 Mdot
.66151 .01551 Mdot
.66154 .01537 Mdot
.66156 .01675 Mdot
.66159 .01563 Mdot
.66162 .01527 Mdot
.66164 .01568 Mdot
.66167 .01556 Mdot
.66169 .01647 Mdot
.66172 .01618 Mdot
.66174 .01543 Mdot
.66177 .01557 Mdot
.6618 .01531 Mdot
.66182 .01527 Mdot
.66185 .01592 Mdot
.66187 .01583 Mdot
.6619 .01567 Mdot
.66193 .01588 Mdot
.66195 .01574 Mdot
.66198 .01502 Mdot
.662 .01561 Mdot
.66203 .01542 Mdot
.66205 .01519 Mdot
.66208 .01639 Mdot
.66211 .01681 Mdot
.66213 .01538 Mdot
.66216 .01512 Mdot
.66218 .01508 Mdot
.66221 .01496 Mdot
.66224 .01526 Mdot
.66226 .01572 Mdot
.66229 .01504 Mdot
.66231 .01519 Mdot
.66234 .01497 Mdot
.66236 .01591 Mdot
.66239 .01497 Mdot
.66242 .0167 Mdot
.66244 .01529 Mdot
.66247 .01587 Mdot
.66249 .01626 Mdot
.66252 .01681 Mdot
.66255 .01556 Mdot
.66257 .01478 Mdot
.6626 .0153 Mdot
.66262 .01561 Mdot
.66265 .01517 Mdot
.66267 .01535 Mdot
.6627 .0156 Mdot
.66273 .01552 Mdot
.66275 .01554 Mdot
.66278 .01566 Mdot
.6628 .01569 Mdot
.66283 .01547 Mdot
.66286 .01598 Mdot
.66288 .01554 Mdot
.66291 .01556 Mdot
.66293 .01537 Mdot
.66296 .01662 Mdot
.66298 .01565 Mdot
.66301 .01539 Mdot
.66304 .0154 Mdot
.66306 .01669 Mdot
.66309 .0153 Mdot
.66311 .01505 Mdot
.66314 .01562 Mdot
.66317 .0152 Mdot
.66319 .01611 Mdot
.66322 .01585 Mdot
.66324 .0153 Mdot
.66327 .01572 Mdot
.66329 .01554 Mdot
.66332 .01692 Mdot
.66335 .01548 Mdot
.66337 .01584 Mdot
.6634 .01557 Mdot
.66342 .01592 Mdot
.66345 .01564 Mdot
.66348 .0158 Mdot
.6635 .01625 Mdot
.66353 .0151 Mdot
.66355 .01667 Mdot
.66358 .01515 Mdot
.6636 .01571 Mdot
.66363 .01625 Mdot
.66366 .0151 Mdot
.66368 .01487 Mdot
.66371 .01629 Mdot
.66373 .01506 Mdot
.66376 .0155 Mdot
.66379 .01653 Mdot
.66381 .01586 Mdot
.66384 .01568 Mdot
.66386 .01519 Mdot
.66389 .01582 Mdot
.66391 .01545 Mdot
.66394 .01535 Mdot
.66397 .01598 Mdot
.66399 .01526 Mdot
.66402 .01636 Mdot
.66404 .01609 Mdot
.66407 .01521 Mdot
.6641 .01536 Mdot
.66412 .01592 Mdot
.66415 .01556 Mdot
.66417 .01585 Mdot
.6642 .01522 Mdot
.66422 .01542 Mdot
.66425 .01603 Mdot
.66428 .01576 Mdot
.6643 .01627 Mdot
.66433 .01546 Mdot
.66435 .01518 Mdot
.66438 .01566 Mdot
.66441 .01592 Mdot
.66443 .01614 Mdot
.66446 .01527 Mdot
.66448 .01598 Mdot
.66451 .01546 Mdot
.66453 .01512 Mdot
.66456 .01491 Mdot
.66459 .01652 Mdot
.66461 .01587 Mdot
.66464 .01585 Mdot
.66466 .01577 Mdot
.66469 .01517 Mdot
.66472 .01535 Mdot
.66474 .01566 Mdot
.66477 .0162 Mdot
.66479 .01499 Mdot
.66482 .01608 Mdot
.66484 .01608 Mdot
.66487 .01548 Mdot
.6649 .01624 Mdot
.66492 .01528 Mdot
.66495 .01627 Mdot
.66497 .01578 Mdot
.665 .01555 Mdot
.66503 .01505 Mdot
.66505 .01579 Mdot
.66508 .01574 Mdot
.6651 .01564 Mdot
.66513 .01574 Mdot
.66515 .0149 Mdot
.66518 .01556 Mdot
.66521 .01614 Mdot
.66523 .01594 Mdot
.66526 .01554 Mdot
.66528 .0157 Mdot
.66531 .01505 Mdot
.66534 .01496 Mdot
.66536 .01692 Mdot
.66539 .01545 Mdot
.66541 .01568 Mdot
.66544 .01529 Mdot
.66546 .01594 Mdot
.66549 .01503 Mdot
.66552 .01523 Mdot
.66554 .01524 Mdot
.66557 .01502 Mdot
.66559 .01568 Mdot
.66562 .01538 Mdot
.66565 .01482 Mdot
.66567 .01545 Mdot
.6657 .01618 Mdot
.66572 .01556 Mdot
.66575 .01658 Mdot
.66577 .01598 Mdot
.6658 .01523 Mdot
.66583 .01555 Mdot
.66585 .01548 Mdot
.66588 .01577 Mdot
.6659 .01575 Mdot
.66593 .01501 Mdot
.66596 .01661 Mdot
.66598 .01523 Mdot
.66601 .01528 Mdot
.66603 .01614 Mdot
.66606 .01587 Mdot
.66608 .01679 Mdot
.66611 .01655 Mdot
.66614 .01494 Mdot
.66616 .01694 Mdot
.66619 .01583 Mdot
.66621 .01638 Mdot
.66624 .01527 Mdot
.66627 .01566 Mdot
.66629 .01481 Mdot
.66632 .01485 Mdot
.66634 .01534 Mdot
.66637 .01698 Mdot
.66639 .01543 Mdot
.66642 .01529 Mdot
.66645 .01519 Mdot
.66647 .01619 Mdot
.6665 .01584 Mdot
.66652 .01695 Mdot
.66655 .01517 Mdot
.66658 .01616 Mdot
.6666 .01642 Mdot
.66663 .01576 Mdot
.66665 .01507 Mdot
.66668 .01595 Mdot
.6667 .01671 Mdot
.66673 .01545 Mdot
.66676 .01534 Mdot
.66678 .0163 Mdot
.66681 .01506 Mdot
.66683 .01511 Mdot
.66686 .01577 Mdot
.66689 .01684 Mdot
.66691 .01634 Mdot
.66694 .01541 Mdot
.66696 .01595 Mdot
.66699 .01527 Mdot
.66701 .01602 Mdot
.66704 .01554 Mdot
.66707 .0156 Mdot
.66709 .01529 Mdot
.66712 .0154 Mdot
.66714 .01554 Mdot
.66717 .0156 Mdot
.6672 .01604 Mdot
.66722 .01545 Mdot
.66725 .01523 Mdot
.66727 .01566 Mdot
.6673 .01635 Mdot
.66732 .016 Mdot
.66735 .01621 Mdot
.66738 .01568 Mdot
.6674 .01514 Mdot
.66743 .01562 Mdot
.66745 .0157 Mdot
.66748 .01603 Mdot
.66751 .01556 Mdot
.66753 .01546 Mdot
.66756 .0163 Mdot
.66758 .01541 Mdot
.66761 .01566 Mdot
.66763 .01545 Mdot
.66766 .01611 Mdot
.66769 .016 Mdot
.66771 .01567 Mdot
.66774 .01516 Mdot
.66776 .01506 Mdot
.66779 .01591 Mdot
.66782 .01527 Mdot
.66784 .01508 Mdot
.66787 .01554 Mdot
.66789 .01563 Mdot
.66792 .0151 Mdot
.66794 .0154 Mdot
.66797 .01518 Mdot
.668 .01561 Mdot
.66802 .01536 Mdot
.66805 .01536 Mdot
.66807 .0153 Mdot
.6681 .01533 Mdot
.66813 .01576 Mdot
.66815 .01631 Mdot
.66818 .01569 Mdot
.6682 .01545 Mdot
.66823 .01665 Mdot
.66825 .01593 Mdot
.66828 .01529 Mdot
.66831 .01493 Mdot
.66833 .01593 Mdot
.66836 .01592 Mdot
.66838 .01534 Mdot
.66841 .01652 Mdot
.66844 .01611 Mdot
.66846 .01548 Mdot
.66849 .01581 Mdot
.66851 .01494 Mdot
.66854 .01566 Mdot
.66856 .01525 Mdot
.66859 .01591 Mdot
.66862 .01557 Mdot
.66864 .0149 Mdot
.66867 .0155 Mdot
.66869 .01652 Mdot
.66872 .01565 Mdot
.66875 .01592 Mdot
.66877 .01566 Mdot
.6688 .01486 Mdot
.66882 .01647 Mdot
.66885 .01554 Mdot
.66887 .01588 Mdot
.6689 .01534 Mdot
.66893 .01581 Mdot
.66895 .01561 Mdot
.66898 .0152 Mdot
.669 .01668 Mdot
.66903 .01547 Mdot
.66906 .0155 Mdot
.66908 .01504 Mdot
.66911 .0162 Mdot
.66913 .01638 Mdot
.66916 .01519 Mdot
.66919 .01623 Mdot
.66921 .01539 Mdot
.66924 .01623 Mdot
.66926 .01688 Mdot
.66929 .01498 Mdot
.66931 .01552 Mdot
.66934 .01591 Mdot
.66937 .01544 Mdot
.66939 .01488 Mdot
.66942 .01506 Mdot
.66944 .01518 Mdot
.66947 .01614 Mdot
.6695 .01529 Mdot
.66952 .01554 Mdot
.66955 .01569 Mdot
.66957 .01601 Mdot
.6696 .01599 Mdot
.66962 .01532 Mdot
.66965 .01563 Mdot
.66968 .01496 Mdot
.6697 .01528 Mdot
.66973 .01603 Mdot
.66975 .01553 Mdot
.66978 .01528 Mdot
.66981 .01547 Mdot
.66983 .01535 Mdot
.66986 .01531 Mdot
.66988 .01529 Mdot
.66991 .01636 Mdot
.66993 .01487 Mdot
.66996 .01539 Mdot
.66999 .01576 Mdot
.67001 .01613 Mdot
.67004 .01521 Mdot
.67006 .01575 Mdot
.67009 .01594 Mdot
.67012 .01584 Mdot
.67014 .0168 Mdot
.67017 .01545 Mdot
.67019 .0158 Mdot
.67022 .01553 Mdot
.67024 .01602 Mdot
.67027 .01587 Mdot
.6703 .01695 Mdot
.67032 .0158 Mdot
.67035 .0154 Mdot
.67037 .01623 Mdot
.6704 .01558 Mdot
.67043 .01605 Mdot
.67045 .0157 Mdot
.67048 .01651 Mdot
.6705 .01565 Mdot
.67053 .01495 Mdot
.67055 .01478 Mdot
.67058 .0155 Mdot
.67061 .01513 Mdot
.67063 .01584 Mdot
.67066 .01525 Mdot
.67068 .01571 Mdot
.67071 .01565 Mdot
.67074 .01549 Mdot
.67076 .01537 Mdot
.67079 .01555 Mdot
.67081 .01543 Mdot
.67084 .01566 Mdot
.67086 .01592 Mdot
.67089 .01563 Mdot
.67092 .01506 Mdot
.67094 .01581 Mdot
.67097 .01568 Mdot
.67099 .01651 Mdot
.67102 .01596 Mdot
.67105 .01515 Mdot
.67107 .01507 Mdot
.6711 .01528 Mdot
.67112 .01595 Mdot
.67115 .01581 Mdot
.67117 .01572 Mdot
.6712 .01559 Mdot
.67123 .0161 Mdot
.67125 .01539 Mdot
.67128 .01564 Mdot
.6713 .01506 Mdot
.67133 .01555 Mdot
.67136 .01525 Mdot
.67138 .01545 Mdot
.67141 .01531 Mdot
.67143 .01624 Mdot
.67146 .01529 Mdot
.67148 .01552 Mdot
.67151 .01547 Mdot
.67154 .01594 Mdot
.67156 .01551 Mdot
.67159 .01593 Mdot
.67161 .01485 Mdot
.67164 .01534 Mdot
.67167 .01581 Mdot
.67169 .01521 Mdot
.67172 .01538 Mdot
.67174 .01501 Mdot
.67177 .01514 Mdot
.67179 .01534 Mdot
.67182 .01505 Mdot
.67185 .01514 Mdot
.67187 .01493 Mdot
.6719 .01582 Mdot
.67192 .01577 Mdot
.67195 .01543 Mdot
.67198 .0154 Mdot
.672 .01562 Mdot
.67203 .01682 Mdot
.67205 .01586 Mdot
.67208 .0153 Mdot
.6721 .01557 Mdot
.67213 .0154 Mdot
.67216 .0153 Mdot
.67218 .01503 Mdot
.67221 .01604 Mdot
.67223 .01647 Mdot
.67226 .01562 Mdot
.67229 .01583 Mdot
.67231 .01528 Mdot
.67234 .01607 Mdot
.67236 .01624 Mdot
.67239 .01506 Mdot
.67241 .01493 Mdot
.67244 .01631 Mdot
.67247 .01589 Mdot
.67249 .01585 Mdot
.67252 .0156 Mdot
.67254 .01581 Mdot
.67257 .0157 Mdot
.6726 .01586 Mdot
.67262 .01575 Mdot
.67265 .01607 Mdot
.67267 .01476 Mdot
.6727 .01492 Mdot
.67272 .01517 Mdot
.67275 .0152 Mdot
.67278 .01548 Mdot
.6728 .01509 Mdot
.67283 .01555 Mdot
.67285 .01535 Mdot
.67288 .01585 Mdot
.67291 .01532 Mdot
.67293 .01504 Mdot
.67296 .0152 Mdot
.67298 .01511 Mdot
.67301 .01672 Mdot
.67303 .01522 Mdot
.67306 .01662 Mdot
.67309 .0153 Mdot
.67311 .01477 Mdot
.67314 .01549 Mdot
.67316 .01515 Mdot
.67319 .01649 Mdot
.67322 .01483 Mdot
.67324 .01575 Mdot
.67327 .01589 Mdot
.67329 .01635 Mdot
.67332 .01508 Mdot
.67334 .01622 Mdot
.67337 .01538 Mdot
.6734 .01562 Mdot
.67342 .01594 Mdot
.67345 .0152 Mdot
.67347 .01512 Mdot
.6735 .01635 Mdot
.67353 .01658 Mdot
.67355 .01536 Mdot
.67358 .01579 Mdot
.6736 .0158 Mdot
.67363 .01637 Mdot
.67365 .01508 Mdot
.67368 .0148 Mdot
.67371 .01561 Mdot
.67373 .01568 Mdot
.67376 .01489 Mdot
.67378 .01645 Mdot
.67381 .0149 Mdot
.67384 .01597 Mdot
.67386 .01685 Mdot
.67389 .01653 Mdot
.67391 .01564 Mdot
.67394 .01547 Mdot
.67396 .01547 Mdot
.67399 .0151 Mdot
.67402 .01613 Mdot
.67404 .01562 Mdot
.67407 .01506 Mdot
.67409 .0154 Mdot
.67412 .01634 Mdot
.67415 .01534 Mdot
.67417 .0164 Mdot
.6742 .01603 Mdot
.67422 .01534 Mdot
.67425 .01494 Mdot
.67427 .01557 Mdot
.6743 .01559 Mdot
.67433 .01517 Mdot
.67435 .01555 Mdot
.67438 .01598 Mdot
.6744 .01612 Mdot
.67443 .01668 Mdot
.67446 .01497 Mdot
.67448 .01503 Mdot
.67451 .01637 Mdot
.67453 .01536 Mdot
.67456 .01517 Mdot
.67458 .01635 Mdot
.67461 .01579 Mdot
.67464 .01641 Mdot
.67466 .01559 Mdot
.67469 .01617 Mdot
.67471 .01571 Mdot
.67474 .01623 Mdot
.67477 .01551 Mdot
.67479 .01572 Mdot
.67482 .01559 Mdot
.67484 .01559 Mdot
.67487 .01483 Mdot
.67489 .0153 Mdot
.67492 .01529 Mdot
.67495 .01595 Mdot
.67497 .01517 Mdot
.675 .01488 Mdot
.67502 .01514 Mdot
.67505 .01537 Mdot
.67508 .01542 Mdot
.6751 .01589 Mdot
.67513 .01528 Mdot
.67515 .0162 Mdot
.67518 .01687 Mdot
.6752 .01599 Mdot
.67523 .01553 Mdot
.67526 .01608 Mdot
.67528 .01582 Mdot
.67531 .01617 Mdot
.67533 .0153 Mdot
.67536 .01571 Mdot
.67539 .01517 Mdot
.67541 .01516 Mdot
.67544 .01506 Mdot
.67546 .01527 Mdot
.67549 .01497 Mdot
.67551 .01497 Mdot
.67554 .01625 Mdot
.67557 .01503 Mdot
.67559 .01498 Mdot
.67562 .01539 Mdot
.67564 .01531 Mdot
.67567 .01503 Mdot
.6757 .01516 Mdot
.67572 .01519 Mdot
.67575 .01553 Mdot
.67577 .01594 Mdot
.6758 .01601 Mdot
.67582 .01521 Mdot
.67585 .01567 Mdot
.67588 .01525 Mdot
.6759 .01543 Mdot
.67593 .01601 Mdot
.67595 .01627 Mdot
.67598 .01531 Mdot
.67601 .01561 Mdot
.67603 .01604 Mdot
.67606 .01671 Mdot
.67608 .01646 Mdot
.67611 .015 Mdot
.67613 .0163 Mdot
.67616 .01556 Mdot
.67619 .01574 Mdot
.67621 .01565 Mdot
.67624 .01498 Mdot
.67626 .01519 Mdot
.67629 .01601 Mdot
.67632 .01542 Mdot
.67634 .01548 Mdot
.67637 .01568 Mdot
.67639 .01643 Mdot
.67642 .01598 Mdot
.67644 .01556 Mdot
.67647 .01598 Mdot
.6765 .01554 Mdot
.67652 .01516 Mdot
.67655 .01546 Mdot
.67657 .01678 Mdot
.6766 .01611 Mdot
.67663 .01658 Mdot
.67665 .0154 Mdot
.67668 .0162 Mdot
.6767 .01636 Mdot
.67673 .01544 Mdot
.67675 .01572 Mdot
.67678 .0162 Mdot
.67681 .01581 Mdot
.67683 .01553 Mdot
.67686 .01642 Mdot
.67688 .01565 Mdot
.67691 .01497 Mdot
.67694 .01583 Mdot
.67696 .01476 Mdot
.67699 .01542 Mdot
.67701 .0156 Mdot
.67704 .01563 Mdot
.67706 .01636 Mdot
.67709 .01633 Mdot
.67712 .01612 Mdot
.67714 .01564 Mdot
.67717 .01568 Mdot
.67719 .01569 Mdot
.67722 .01553 Mdot
.67725 .0153 Mdot
.67727 .01614 Mdot
.6773 .01509 Mdot
.67732 .01604 Mdot
.67735 .01563 Mdot
.67737 .01565 Mdot
.6774 .01537 Mdot
.67743 .01706 Mdot
.67745 .01569 Mdot
.67748 .01511 Mdot
.6775 .0152 Mdot
.67753 .01482 Mdot
.67756 .016 Mdot
.67758 .01578 Mdot
.67761 .01634 Mdot
.67763 .01578 Mdot
.67766 .01529 Mdot
.67768 .01545 Mdot
.67771 .01498 Mdot
.67774 .01549 Mdot
.67776 .0158 Mdot
.67779 .01581 Mdot
.67781 .01567 Mdot
.67784 .01565 Mdot
.67787 .01514 Mdot
.67789 .01659 Mdot
.67792 .0159 Mdot
.67794 .01583 Mdot
.67797 .01538 Mdot
.67799 .01517 Mdot
.67802 .01556 Mdot
.67805 .01582 Mdot
.67807 .01559 Mdot
.6781 .01567 Mdot
.67812 .01557 Mdot
.67815 .01543 Mdot
.67818 .01664 Mdot
.6782 .01634 Mdot
.67823 .01597 Mdot
.67825 .01566 Mdot
.67828 .01498 Mdot
.6783 .01615 Mdot
.67833 .01603 Mdot
.67836 .01698 Mdot
.67838 .01505 Mdot
.67841 .01529 Mdot
.67843 .01576 Mdot
.67846 .01541 Mdot
.67849 .01617 Mdot
.67851 .01576 Mdot
.67854 .01617 Mdot
.67856 .01587 Mdot
.67859 .01663 Mdot
.67862 .01516 Mdot
.67864 .01534 Mdot
.67867 .01537 Mdot
.67869 .01486 Mdot
.67872 .01515 Mdot
.67874 .01555 Mdot
.67877 .01569 Mdot
.6788 .01494 Mdot
.67882 .015 Mdot
.67885 .01551 Mdot
.67887 .01593 Mdot
.6789 .01653 Mdot
.67893 .01501 Mdot
.67895 .01488 Mdot
.67898 .01515 Mdot
.679 .01587 Mdot
.67903 .01618 Mdot
.67905 .01626 Mdot
.67908 .0158 Mdot
.67911 .01547 Mdot
.67913 .01606 Mdot
.67916 .01508 Mdot
.67918 .01511 Mdot
.67921 .01557 Mdot
.67924 .01626 Mdot
.67926 .01597 Mdot
.67929 .01673 Mdot
.67931 .01729 Mdot
.67934 .01669 Mdot
.67936 .01619 Mdot
.67939 .01541 Mdot
.67942 .0156 Mdot
.67944 .01612 Mdot
.67947 .01484 Mdot
.67949 .016 Mdot
.67952 .01509 Mdot
.67955 .01572 Mdot
.67957 .01585 Mdot
.6796 .01627 Mdot
.67962 .01542 Mdot
.67965 .01592 Mdot
.67967 .01547 Mdot
.6797 .01499 Mdot
.67973 .01565 Mdot
.67975 .01515 Mdot
.67978 .01502 Mdot
.6798 .01521 Mdot
.67983 .01578 Mdot
.67986 .01585 Mdot
.67988 .01545 Mdot
.67991 .01617 Mdot
.67993 .01611 Mdot
.67996 .01523 Mdot
.67998 .01542 Mdot
.68001 .0152 Mdot
.68004 .01555 Mdot
.68006 .01534 Mdot
.68009 .01497 Mdot
.68011 .01501 Mdot
.68014 .01629 Mdot
.68017 .01592 Mdot
.68019 .01487 Mdot
.68022 .01519 Mdot
.68024 .01641 Mdot
.68027 .0156 Mdot
.68029 .01613 Mdot
.68032 .01597 Mdot
.68035 .01574 Mdot
.68037 .0154 Mdot
.6804 .01493 Mdot
.68042 .01541 Mdot
.68045 .01484 Mdot
.68048 .01665 Mdot
.6805 .01632 Mdot
.68053 .01532 Mdot
.68055 .01544 Mdot
.68058 .01624 Mdot
.6806 .01544 Mdot
.68063 .01539 Mdot
.68066 .01627 Mdot
.68068 .01533 Mdot
.68071 .01568 Mdot
.68073 .01515 Mdot
.68076 .01547 Mdot
.68079 .01565 Mdot
.68081 .01664 Mdot
.68084 .01524 Mdot
.68086 .01558 Mdot
.68089 .01525 Mdot
.68091 .01632 Mdot
.68094 .01641 Mdot
.68097 .01552 Mdot
.68099 .01553 Mdot
.68102 .01608 Mdot
.68104 .01529 Mdot
.68107 .01615 Mdot
.6811 .01534 Mdot
.68112 .01595 Mdot
.68115 .01623 Mdot
.68117 .01613 Mdot
.6812 .01547 Mdot
.68122 .01568 Mdot
.68125 .01496 Mdot
.68128 .01519 Mdot
.6813 .01511 Mdot
.68133 .01514 Mdot
.68135 .01516 Mdot
.68138 .01507 Mdot
.68141 .01528 Mdot
.68143 .01572 Mdot
.68146 .01616 Mdot
.68148 .01496 Mdot
.68151 .01542 Mdot
.68153 .01602 Mdot
.68156 .01655 Mdot
.68159 .01565 Mdot
.68161 .01562 Mdot
.68164 .01623 Mdot
.68166 .01559 Mdot
.68169 .01578 Mdot
.68172 .01534 Mdot
.68174 .01559 Mdot
.68177 .01518 Mdot
.68179 .01531 Mdot
.68182 .01644 Mdot
.68184 .01685 Mdot
.68187 .01579 Mdot
.6819 .01548 Mdot
.68192 .01497 Mdot
.68195 .01514 Mdot
.68197 .01592 Mdot
.682 .01609 Mdot
.68203 .01532 Mdot
.68205 .0156 Mdot
.68208 .01566 Mdot
.6821 .01496 Mdot
.68213 .01558 Mdot
.68215 .01639 Mdot
.68218 .01512 Mdot
.68221 .01502 Mdot
.68223 .01566 Mdot
.68226 .0154 Mdot
.68228 .01753 Mdot
.68231 .01566 Mdot
.68234 .01592 Mdot
.68236 .01515 Mdot
.68239 .0155 Mdot
.68241 .01576 Mdot
.68244 .01473 Mdot
.68246 .01482 Mdot
.68249 .01528 Mdot
.68252 .01574 Mdot
.68254 .01598 Mdot
.68257 .0149 Mdot
.68259 .01676 Mdot
.68262 .01556 Mdot
.68265 .01576 Mdot
.68267 .01548 Mdot
.6827 .01554 Mdot
.68272 .01542 Mdot
.68275 .01501 Mdot
.68277 .01577 Mdot
.6828 .01485 Mdot
.68283 .01513 Mdot
.68285 .01569 Mdot
.68288 .01489 Mdot
.6829 .0154 Mdot
.68293 .01596 Mdot
.68296 .01472 Mdot
.68298 .016 Mdot
.68301 .01473 Mdot
.68303 .0153 Mdot
.68306 .01645 Mdot
.68308 .01589 Mdot
.68311 .01546 Mdot
.68314 .01551 Mdot
.68316 .0151 Mdot
.68319 .01531 Mdot
.68321 .01577 Mdot
.68324 .01633 Mdot
.68327 .01549 Mdot
.68329 .01512 Mdot
.68332 .01584 Mdot
.68334 .01491 Mdot
.68337 .01629 Mdot
.68339 .01589 Mdot
.68342 .01553 Mdot
.68345 .0148 Mdot
.68347 .01532 Mdot
.6835 .01583 Mdot
.68352 .01502 Mdot
.68355 .015 Mdot
.68358 .01553 Mdot
.6836 .01524 Mdot
.68363 .0158 Mdot
.68365 .01582 Mdot
.68368 .01562 Mdot
.6837 .01529 Mdot
.68373 .01608 Mdot
.68376 .01582 Mdot
.68378 .01513 Mdot
.68381 .01651 Mdot
.68383 .01566 Mdot
.68386 .01555 Mdot
.68389 .01578 Mdot
.68391 .01629 Mdot
.68394 .01541 Mdot
.68396 .01548 Mdot
.68399 .01603 Mdot
.68401 .01494 Mdot
.68404 .01476 Mdot
.68407 .01554 Mdot
.68409 .01552 Mdot
.68412 .01622 Mdot
.68414 .01701 Mdot
.68417 .01604 Mdot
.6842 .0157 Mdot
.68422 .01573 Mdot
.68425 .01603 Mdot
.68427 .01498 Mdot
.6843 .01539 Mdot
.68432 .0149 Mdot
.68435 .01598 Mdot
.68438 .01545 Mdot
.6844 .01587 Mdot
.68443 .01569 Mdot
.68445 .01486 Mdot
.68448 .01507 Mdot
.68451 .01589 Mdot
.68453 .01523 Mdot
.68456 .01658 Mdot
.68458 .01599 Mdot
.68461 .01524 Mdot
.68463 .01533 Mdot
.68466 .01568 Mdot
.68469 .01495 Mdot
.68471 .01538 Mdot
.68474 .01546 Mdot
.68476 .01618 Mdot
.68479 .01512 Mdot
.68482 .01511 Mdot
.68484 .01503 Mdot
.68487 .01554 Mdot
.68489 .01544 Mdot
.68492 .0157 Mdot
.68494 .01479 Mdot
.68497 .01644 Mdot
.685 .01478 Mdot
.68502 .01492 Mdot
.68505 .01528 Mdot
.68507 .0154 Mdot
.6851 .01548 Mdot
.68513 .01618 Mdot
.68515 .01525 Mdot
.68518 .01575 Mdot
.6852 .01539 Mdot
.68523 .0151 Mdot
.68525 .01631 Mdot
.68528 .01555 Mdot
.68531 .01527 Mdot
.68533 .01547 Mdot
.68536 .01542 Mdot
.68538 .016 Mdot
.68541 .01575 Mdot
.68544 .01623 Mdot
.68546 .01623 Mdot
.68549 .01492 Mdot
.68551 .01499 Mdot
.68554 .01564 Mdot
.68556 .01522 Mdot
.68559 .01677 Mdot
.68562 .01625 Mdot
.68564 .01594 Mdot
.68567 .01493 Mdot
.68569 .01605 Mdot
.68572 .01537 Mdot
.68575 .01555 Mdot
.68577 .01496 Mdot
.6858 .01609 Mdot
.68582 .0159 Mdot
.68585 .01694 Mdot
.68587 .01518 Mdot
.6859 .01565 Mdot
.68593 .01512 Mdot
.68595 .01579 Mdot
.68598 .0162 Mdot
.686 .01517 Mdot
.68603 .01501 Mdot
.68606 .01495 Mdot
.68608 .01535 Mdot
.68611 .01577 Mdot
.68613 .01499 Mdot
.68616 .01513 Mdot
.68618 .01552 Mdot
.68621 .01591 Mdot
.68624 .01564 Mdot
.68626 .0148 Mdot
.68629 .01651 Mdot
.68631 .01587 Mdot
.68634 .01491 Mdot
.68637 .01535 Mdot
.68639 .01658 Mdot
.68642 .01618 Mdot
.68644 .01609 Mdot
.68647 .01578 Mdot
.68649 .01566 Mdot
.68652 .0154 Mdot
.68655 .01623 Mdot
.68657 .01719 Mdot
.6866 .01613 Mdot
.68662 .01534 Mdot
.68665 .01621 Mdot
.68668 .01535 Mdot
.6867 .01593 Mdot
.68673 .01609 Mdot
.68675 .01604 Mdot
.68678 .01561 Mdot
.6868 .01638 Mdot
.68683 .01548 Mdot
.68686 .01592 Mdot
.68688 .01668 Mdot
.68691 .0156 Mdot
.68693 .01563 Mdot
.68696 .01539 Mdot
.68699 .01584 Mdot
.68701 .01562 Mdot
.68704 .01493 Mdot
.68706 .01596 Mdot
.68709 .01528 Mdot
.68711 .01613 Mdot
.68714 .01606 Mdot
.68717 .0162 Mdot
.68719 .01553 Mdot
.68722 .01549 Mdot
.68724 .01499 Mdot
.68727 .01525 Mdot
.6873 .01593 Mdot
.68732 .01587 Mdot
.68735 .01494 Mdot
.68737 .01653 Mdot
.6874 .01573 Mdot
.68742 .01568 Mdot
.68745 .01507 Mdot
.68748 .01647 Mdot
.6875 .01584 Mdot
.68753 .01557 Mdot
.68755 .01482 Mdot
.68758 .01499 Mdot
.68761 .01523 Mdot
.68763 .0152 Mdot
.68766 .01624 Mdot
.68768 .01499 Mdot
.68771 .01577 Mdot
.68774 .01574 Mdot
.68776 .01551 Mdot
.68779 .015 Mdot
.68781 .01548 Mdot
.68784 .01564 Mdot
.68786 .01598 Mdot
.68789 .01558 Mdot
.68792 .01675 Mdot
.68794 .01563 Mdot
.68797 .01559 Mdot
.68799 .01509 Mdot
.68802 .01637 Mdot
.68805 .01548 Mdot
.68807 .01516 Mdot
.6881 .01532 Mdot
.68812 .01573 Mdot
.68815 .01541 Mdot
.68817 .01499 Mdot
.6882 .01517 Mdot
.68823 .0156 Mdot
.68825 .01612 Mdot
.68828 .01527 Mdot
.6883 .0157 Mdot
.68833 .01517 Mdot
.68836 .01512 Mdot
.68838 .01539 Mdot
.68841 .01543 Mdot
.68843 .01576 Mdot
.68846 .01592 Mdot
.68848 .0157 Mdot
.68851 .01531 Mdot
.68854 .01603 Mdot
.68856 .01626 Mdot
.68859 .01521 Mdot
.68861 .01551 Mdot
.68864 .01565 Mdot
.68867 .01515 Mdot
.68869 .01504 Mdot
.68872 .01582 Mdot
.68874 .01482 Mdot
.68877 .01562 Mdot
.68879 .01496 Mdot
.68882 .01523 Mdot
.68885 .01608 Mdot
.68887 .01566 Mdot
.6889 .01541 Mdot
.68892 .01509 Mdot
.68895 .01591 Mdot
.68898 .01515 Mdot
.689 .01599 Mdot
.68903 .0151 Mdot
.68905 .01508 Mdot
.68908 .01552 Mdot
.6891 .01624 Mdot
.68913 .01594 Mdot
.68916 .01644 Mdot
.68918 .01597 Mdot
.68921 .01509 Mdot
.68923 .01533 Mdot
.68926 .0153 Mdot
.68929 .01567 Mdot
.68931 .01633 Mdot
.68934 .01549 Mdot
.68936 .01595 Mdot
.68939 .01586 Mdot
.68941 .01555 Mdot
.68944 .01567 Mdot
.68947 .01626 Mdot
.68949 .0151 Mdot
.68952 .0154 Mdot
.68954 .01527 Mdot
.68957 .01631 Mdot
.6896 .01637 Mdot
.68962 .01532 Mdot
.68965 .01626 Mdot
.68967 .01564 Mdot
.6897 .01533 Mdot
.68972 .01526 Mdot
.68975 .0152 Mdot
.68978 .01511 Mdot
.6898 .01572 Mdot
.68983 .01617 Mdot
.68985 .01547 Mdot
.68988 .0163 Mdot
.68991 .01619 Mdot
.68993 .01519 Mdot
.68996 .01544 Mdot
.68998 .0161 Mdot
.69001 .01583 Mdot
.69003 .01509 Mdot
.69006 .01591 Mdot
.69009 .01526 Mdot
.69011 .01593 Mdot
.69014 .01616 Mdot
.69016 .01513 Mdot
.69019 .0155 Mdot
.69022 .01583 Mdot
.69024 .0155 Mdot
.69027 .01547 Mdot
.69029 .01636 Mdot
.69032 .01611 Mdot
.69034 .01556 Mdot
.69037 .01511 Mdot
.6904 .01638 Mdot
.69042 .01561 Mdot
.69045 .01639 Mdot
.69047 .01574 Mdot
.6905 .01554 Mdot
.69053 .01621 Mdot
.69055 .0162 Mdot
.69058 .01569 Mdot
.6906 .01516 Mdot
.69063 .01604 Mdot
.69065 .01527 Mdot
.69068 .01486 Mdot
.69071 .01512 Mdot
.69073 .01526 Mdot
.69076 .01484 Mdot
.69078 .01537 Mdot
.69081 .01621 Mdot
.69084 .01614 Mdot
.69086 .01523 Mdot
.69089 .01499 Mdot
.69091 .0157 Mdot
.69094 .01487 Mdot
.69096 .01588 Mdot
.69099 .01618 Mdot
.69102 .01706 Mdot
.69104 .01597 Mdot
.69107 .01599 Mdot
.69109 .0158 Mdot
.69112 .01506 Mdot
.69115 .0151 Mdot
.69117 .01547 Mdot
.6912 .0149 Mdot
.69122 .01548 Mdot
.69125 .01555 Mdot
.69127 .01516 Mdot
.6913 .0151 Mdot
.69133 .01584 Mdot
.69135 .01506 Mdot
.69138 .01567 Mdot
.6914 .0152 Mdot
.69143 .01621 Mdot
.69146 .01587 Mdot
.69148 .01593 Mdot
.69151 .01483 Mdot
.69153 .01567 Mdot
.69156 .01555 Mdot
.69158 .01581 Mdot
.69161 .01538 Mdot
.69164 .01549 Mdot
.69166 .01511 Mdot
.69169 .01552 Mdot
.69171 .0154 Mdot
.69174 .01563 Mdot
.69177 .01562 Mdot
.69179 .01549 Mdot
.69182 .0148 Mdot
.69184 .01523 Mdot
.69187 .01498 Mdot
.69189 .01603 Mdot
.69192 .01539 Mdot
.69195 .01517 Mdot
.69197 .01514 Mdot
.692 .01537 Mdot
.69202 .01515 Mdot
.69205 .0149 Mdot
.69208 .01577 Mdot
.6921 .01549 Mdot
.69213 .01612 Mdot
.69215 .01547 Mdot
.69218 .01538 Mdot
.6922 .0155 Mdot
.69223 .01517 Mdot
.69226 .01515 Mdot
.69228 .01559 Mdot
.69231 .01592 Mdot
.69233 .01637 Mdot
.69236 .01515 Mdot
.69239 .0153 Mdot
.69241 .01589 Mdot
.69244 .01612 Mdot
.69246 .01579 Mdot
.69249 .01574 Mdot
.69251 .0151 Mdot
.69254 .01517 Mdot
.69257 .0159 Mdot
.69259 .01572 Mdot
.69262 .01522 Mdot
.69264 .01597 Mdot
.69267 .01626 Mdot
.6927 .01474 Mdot
.69272 .01586 Mdot
.69275 .01524 Mdot
.69277 .015 Mdot
.6928 .01579 Mdot
.69282 .01542 Mdot
.69285 .01516 Mdot
.69288 .01631 Mdot
.6929 .01594 Mdot
.69293 .01578 Mdot
.69295 .01616 Mdot
.69298 .01558 Mdot
.69301 .01499 Mdot
.69303 .01609 Mdot
.69306 .01548 Mdot
.69308 .01545 Mdot
.69311 .01553 Mdot
.69313 .01552 Mdot
.69316 .01593 Mdot
.69319 .01506 Mdot
.69321 .01509 Mdot
.69324 .01568 Mdot
.69326 .01486 Mdot
.69329 .01577 Mdot
.69332 .01641 Mdot
.69334 .0151 Mdot
.69337 .0155 Mdot
.69339 .01537 Mdot
.69342 .01528 Mdot
.69344 .01536 Mdot
.69347 .01501 Mdot
.6935 .01493 Mdot
.69352 .01576 Mdot
.69355 .01514 Mdot
.69357 .01502 Mdot
.6936 .0152 Mdot
.69363 .01619 Mdot
.69365 .01607 Mdot
.69368 .01526 Mdot
.6937 .01591 Mdot
.69373 .01568 Mdot
.69375 .0158 Mdot
.69378 .01579 Mdot
.69381 .01613 Mdot
.69383 .01672 Mdot
.69386 .01594 Mdot
.69388 .01683 Mdot
.69391 .01582 Mdot
.69394 .01555 Mdot
.69396 .01545 Mdot
.69399 .01559 Mdot
.69401 .01702 Mdot
.69404 .01542 Mdot
.69406 .01555 Mdot
.69409 .016 Mdot
.69412 .01609 Mdot
.69414 .01479 Mdot
.69417 .01515 Mdot
.69419 .0165 Mdot
.69422 .01644 Mdot
.69425 .01502 Mdot
.69427 .01481 Mdot
.6943 .01618 Mdot
.69432 .01543 Mdot
.69435 .01513 Mdot
.69437 .01551 Mdot
.6944 .01526 Mdot
.69443 .01568 Mdot
.69445 .01585 Mdot
.69448 .01539 Mdot
.6945 .01507 Mdot
.69453 .0161 Mdot
.69456 .01538 Mdot
.69458 .01511 Mdot
.69461 .01639 Mdot
.69463 .01576 Mdot
.69466 .01572 Mdot
.69468 .01506 Mdot
.69471 .01588 Mdot
.69474 .01549 Mdot
.69476 .01531 Mdot
.69479 .01581 Mdot
.69481 .01556 Mdot
.69484 .01568 Mdot
.69487 .01531 Mdot
.69489 .01634 Mdot
.69492 .01623 Mdot
.69494 .01535 Mdot
.69497 .01554 Mdot
.69499 .01501 Mdot
.69502 .01531 Mdot
.69505 .01545 Mdot
.69507 .01575 Mdot
.6951 .01634 Mdot
.69512 .01542 Mdot
.69515 .01592 Mdot
.69518 .01512 Mdot
.6952 .01521 Mdot
.69523 .01604 Mdot
.69525 .01577 Mdot
.69528 .01535 Mdot
.6953 .01621 Mdot
.69533 .015 Mdot
.69536 .01607 Mdot
.69538 .01559 Mdot
.69541 .01644 Mdot
.69543 .01577 Mdot
.69546 .01559 Mdot
.69549 .01564 Mdot
.69551 .01526 Mdot
.69554 .01593 Mdot
.69556 .01522 Mdot
.69559 .01545 Mdot
.69561 .01618 Mdot
.69564 .01533 Mdot
.69567 .01568 Mdot
.69569 .01604 Mdot
.69572 .01606 Mdot
.69574 .01625 Mdot
.69577 .01583 Mdot
.6958 .01585 Mdot
.69582 .01605 Mdot
.69585 .016 Mdot
.69587 .01566 Mdot
.6959 .01636 Mdot
.69592 .01709 Mdot
.69595 .01579 Mdot
.69598 .01599 Mdot
.696 .01555 Mdot
.69603 .01579 Mdot
.69605 .01515 Mdot
.69608 .01586 Mdot
.69611 .01634 Mdot
.69613 .01624 Mdot
.69616 .01636 Mdot
.69618 .01588 Mdot
.69621 .01625 Mdot
.69623 .01502 Mdot
.69626 .01514 Mdot
.69629 .0154 Mdot
.69631 .01532 Mdot
.69634 .01613 Mdot
.69636 .01595 Mdot
.69639 .01515 Mdot
.69642 .0152 Mdot
.69644 .0158 Mdot
.69647 .01505 Mdot
.69649 .01509 Mdot
.69652 .01565 Mdot
.69654 .01573 Mdot
.69657 .01556 Mdot
.6966 .01545 Mdot
.69662 .01477 Mdot
.69665 .01596 Mdot
.69667 .01559 Mdot
.6967 .01621 Mdot
.69673 .01612 Mdot
.69675 .01598 Mdot
.69678 .01614 Mdot
.6968 .0149 Mdot
.69683 .01582 Mdot
.69686 .01609 Mdot
.69688 .01617 Mdot
.69691 .01676 Mdot
.69693 .01523 Mdot
.69696 .01563 Mdot
.69698 .01542 Mdot
.69701 .01654 Mdot
.69704 .01538 Mdot
.69706 .01533 Mdot
.69709 .01576 Mdot
.69711 .01704 Mdot
.69714 .01662 Mdot
.69717 .01548 Mdot
.69719 .01661 Mdot
.69722 .01552 Mdot
.69724 .01501 Mdot
.69727 .01576 Mdot
.69729 .01565 Mdot
.69732 .01547 Mdot
.69735 .01621 Mdot
.69737 .01536 Mdot
.6974 .01542 Mdot
.69742 .01577 Mdot
.69745 .01586 Mdot
.69748 .01605 Mdot
.6975 .0165 Mdot
.69753 .01547 Mdot
.69755 .01563 Mdot
.69758 .01664 Mdot
.6976 .01732 Mdot
.69763 .01525 Mdot
.69766 .017 Mdot
.69768 .0154 Mdot
.69771 .01494 Mdot
.69773 .0159 Mdot
.69776 .01524 Mdot
.69779 .01507 Mdot
.69781 .01525 Mdot
.69784 .01578 Mdot
.69786 .01591 Mdot
.69789 .01607 Mdot
.69791 .015 Mdot
.69794 .01636 Mdot
.69797 .0158 Mdot
.69799 .01639 Mdot
.69802 .01512 Mdot
.69804 .01585 Mdot
.69807 .01478 Mdot
.6981 .0165 Mdot
.69812 .01569 Mdot
.69815 .01582 Mdot
.69817 .01592 Mdot
.6982 .01501 Mdot
.69822 .01549 Mdot
.69825 .01582 Mdot
.69828 .01557 Mdot
.6983 .01498 Mdot
.69833 .01645 Mdot
.69835 .01531 Mdot
.69838 .01532 Mdot
.69841 .01555 Mdot
.69843 .01664 Mdot
.69846 .0155 Mdot
.69848 .01532 Mdot
.69851 .01594 Mdot
.69853 .01723 Mdot
.69856 .01527 Mdot
.69859 .01577 Mdot
.69861 .01564 Mdot
.69864 .01638 Mdot
.69866 .01673 Mdot
.69869 .0151 Mdot
.69872 .01535 Mdot
.69874 .01543 Mdot
.69877 .01509 Mdot
.69879 .01563 Mdot
.69882 .01673 Mdot
.69884 .01579 Mdot
.69887 .01524 Mdot
.6989 .01608 Mdot
.69892 .01648 Mdot
.69895 .01598 Mdot
.69897 .01527 Mdot
.699 .0151 Mdot
.69903 .01568 Mdot
.69905 .01516 Mdot
.69908 .01541 Mdot
.6991 .01475 Mdot
.69913 .01619 Mdot
.69915 .01552 Mdot
.69918 .01535 Mdot
.69921 .01617 Mdot
.69923 .01599 Mdot
.69926 .0149 Mdot
.69928 .01615 Mdot
.69931 .01556 Mdot
.69934 .01634 Mdot
.69936 .0166 Mdot
.69939 .01548 Mdot
.69941 .01614 Mdot
.69944 .01627 Mdot
.69946 .01499 Mdot
.69949 .01497 Mdot
.69952 .01596 Mdot
.69954 .01562 Mdot
.69957 .0162 Mdot
.69959 .0157 Mdot
.69962 .01634 Mdot
.69965 .0162 Mdot
.69967 .01554 Mdot
.6997 .01509 Mdot
.69972 .01536 Mdot
.69975 .0166 Mdot
.69977 .01558 Mdot
.6998 .01588 Mdot
.69983 .01582 Mdot
.69985 .0167 Mdot
.69988 .015 Mdot
.6999 .01522 Mdot
.69993 .01568 Mdot
.69996 .01564 Mdot
.69998 .01592 Mdot
.70001 .01531 Mdot
.70003 .01579 Mdot
.70006 .01641 Mdot
.70008 .01587 Mdot
.70011 .01586 Mdot
.70014 .01633 Mdot
.70016 .01515 Mdot
.70019 .01493 Mdot
.70021 .0162 Mdot
.70024 .01593 Mdot
.70027 .01548 Mdot
.70029 .01543 Mdot
.70032 .01558 Mdot
.70034 .01566 Mdot
.70037 .01583 Mdot
.70039 .01586 Mdot
.70042 .0155 Mdot
.70045 .0151 Mdot
.70047 .01525 Mdot
.7005 .01545 Mdot
.70052 .01558 Mdot
.70055 .0159 Mdot
.70058 .01536 Mdot
.7006 .01575 Mdot
.70063 .01582 Mdot
.70065 .01526 Mdot
.70068 .01651 Mdot
.7007 .01566 Mdot
.70073 .01532 Mdot
.70076 .01505 Mdot
.70078 .01662 Mdot
.70081 .0163 Mdot
.70083 .01548 Mdot
.70086 .01579 Mdot
.70089 .01569 Mdot
.70091 .01497 Mdot
.70094 .01583 Mdot
.70096 .01515 Mdot
.70099 .01517 Mdot
.70101 .01573 Mdot
.70104 .01521 Mdot
.70107 .01616 Mdot
.70109 .01686 Mdot
.70112 .01489 Mdot
.70114 .01553 Mdot
.70117 .0152 Mdot
.7012 .01579 Mdot
.70122 .01589 Mdot
.70125 .01595 Mdot
.70127 .01556 Mdot
.7013 .01524 Mdot
.70132 .0155 Mdot
.70135 .01542 Mdot
.70138 .01533 Mdot
.7014 .01603 Mdot
.70143 .01633 Mdot
.70145 .01548 Mdot
.70148 .01603 Mdot
.70151 .01585 Mdot
.70153 .01508 Mdot
.70156 .01611 Mdot
.70158 .01622 Mdot
.70161 .01565 Mdot
.70163 .015 Mdot
.70166 .01509 Mdot
.70169 .01517 Mdot
.70171 .01556 Mdot
.70174 .01506 Mdot
.70176 .01598 Mdot
.70179 .01616 Mdot
.70182 .01574 Mdot
.70184 .01561 Mdot
.70187 .01557 Mdot
.70189 .01578 Mdot
.70192 .01587 Mdot
.70194 .0154 Mdot
.70197 .01668 Mdot
.702 .0157 Mdot
.70202 .01641 Mdot
.70205 .0156 Mdot
.70207 .01508 Mdot
.7021 .01664 Mdot
.70213 .0163 Mdot
.70215 .01666 Mdot
.70218 .01698 Mdot
.7022 .0171 Mdot
.70223 .01606 Mdot
.70225 .01604 Mdot
.70228 .01548 Mdot
.70231 .01552 Mdot
.70233 .01499 Mdot
.70236 .01567 Mdot
.70238 .01633 Mdot
.70241 .01501 Mdot
.70244 .0158 Mdot
.70246 .01535 Mdot
.70249 .01537 Mdot
.70251 .01575 Mdot
.70254 .01605 Mdot
.70256 .01541 Mdot
.70259 .01497 Mdot
.70262 .01488 Mdot
.70264 .01717 Mdot
.70267 .01617 Mdot
.70269 .01598 Mdot
.70272 .01523 Mdot
.70275 .01566 Mdot
.70277 .01521 Mdot
.7028 .01571 Mdot
.70282 .01515 Mdot
.70285 .01607 Mdot
.70287 .01561 Mdot
.7029 .01516 Mdot
.70293 .01576 Mdot
.70295 .01629 Mdot
.70298 .01592 Mdot
.703 .01541 Mdot
.70303 .01639 Mdot
.70306 .01625 Mdot
.70308 .01608 Mdot
.70311 .01555 Mdot
.70313 .01501 Mdot
.70316 .01717 Mdot
.70318 .01523 Mdot
.70321 .0152 Mdot
.70324 .0159 Mdot
.70326 .01516 Mdot
.70329 .01503 Mdot
.70331 .01633 Mdot
.70334 .01579 Mdot
.70337 .01492 Mdot
.70339 .0156 Mdot
.70342 .01833 Mdot
.70344 .01551 Mdot
.70347 .01555 Mdot
.70349 .0159 Mdot
.70352 .01541 Mdot
.70355 .01497 Mdot
.70357 .01553 Mdot
.7036 .01651 Mdot
.70362 .01527 Mdot
.70365 .01633 Mdot
.70368 .01504 Mdot
.7037 .01534 Mdot
.70373 .01716 Mdot
.70375 .01673 Mdot
.70378 .01692 Mdot
.7038 .01512 Mdot
.70383 .01627 Mdot
.70386 .01595 Mdot
.70388 .01557 Mdot
.70391 .01534 Mdot
.70393 .01505 Mdot
.70396 .01625 Mdot
.70399 .0171 Mdot
.70401 .01554 Mdot
.70404 .01604 Mdot
.70406 .01623 Mdot
.70409 .0165 Mdot
.70411 .01602 Mdot
.70414 .01503 Mdot
.70417 .0153 Mdot
.70419 .01615 Mdot
.70422 .01572 Mdot
.70424 .01665 Mdot
.70427 .0148 Mdot
.7043 .01651 Mdot
.70432 .0162 Mdot
.70435 .01502 Mdot
.70437 .01633 Mdot
.7044 .01612 Mdot
.70442 .01541 Mdot
.70445 .01577 Mdot
.70448 .01552 Mdot
.7045 .01557 Mdot
.70453 .01666 Mdot
.70455 .01599 Mdot
.70458 .01629 Mdot
.70461 .01531 Mdot
.70463 .01539 Mdot
.70466 .01501 Mdot
.70468 .01533 Mdot
.70471 .01591 Mdot
.70473 .01717 Mdot
.70476 .01606 Mdot
.70479 .01627 Mdot
.70481 .01592 Mdot
.70484 .01684 Mdot
.70486 .01488 Mdot
.70489 .01559 Mdot
.70492 .01609 Mdot
.70494 .01573 Mdot
.70497 .01535 Mdot
.70499 .01501 Mdot
.70502 .01631 Mdot
.70504 .01592 Mdot
.70507 .0156 Mdot
.7051 .01561 Mdot
.70512 .0161 Mdot
.70515 .01549 Mdot
.70517 .01569 Mdot
.7052 .01605 Mdot
.70523 .01584 Mdot
.70525 .01501 Mdot
.70528 .01709 Mdot
.7053 .01561 Mdot
.70533 .01512 Mdot
.70535 .01499 Mdot
.70538 .01572 Mdot
.70541 .01502 Mdot
.70543 .01569 Mdot
.70546 .01606 Mdot
.70548 .01536 Mdot
.70551 .01547 Mdot
.70554 .01607 Mdot
.70556 .01581 Mdot
.70559 .0159 Mdot
.70561 .01593 Mdot
.70564 .01524 Mdot
.70566 .01564 Mdot
.70569 .01592 Mdot
.70572 .01534 Mdot
.70574 .01601 Mdot
.70577 .01609 Mdot
.70579 .0156 Mdot
.70582 .01503 Mdot
.70585 .01663 Mdot
.70587 .01542 Mdot
.7059 .01596 Mdot
.70592 .01623 Mdot
.70595 .01642 Mdot
.70598 .01558 Mdot
.706 .01531 Mdot
.70603 .01551 Mdot
.70605 .01577 Mdot
.70608 .01656 Mdot
.7061 .01612 Mdot
.70613 .01547 Mdot
.70616 .01565 Mdot
.70618 .01581 Mdot
.70621 .01536 Mdot
.70623 .01547 Mdot
.70626 .01603 Mdot
.70629 .01537 Mdot
.70631 .01566 Mdot
.70634 .01613 Mdot
.70636 .01609 Mdot
.70639 .01594 Mdot
.70641 .01531 Mdot
.70644 .01521 Mdot
.70647 .01686 Mdot
.70649 .01522 Mdot
.70652 .01632 Mdot
.70654 .01493 Mdot
.70657 .0165 Mdot
.7066 .01493 Mdot
.70662 .01601 Mdot
.70665 .0154 Mdot
.70667 .0156 Mdot
.7067 .01516 Mdot
.70672 .01518 Mdot
.70675 .01528 Mdot
.70678 .01631 Mdot
.7068 .01495 Mdot
.70683 .01673 Mdot
.70685 .01524 Mdot
.70688 .01543 Mdot
.70691 .0155 Mdot
.70693 .01565 Mdot
.70696 .01541 Mdot
.70698 .01536 Mdot
.70701 .01491 Mdot
.70703 .01597 Mdot
.70706 .01538 Mdot
.70709 .0155 Mdot
.70711 .01556 Mdot
.70714 .0161 Mdot
.70716 .0157 Mdot
.70719 .01548 Mdot
.70722 .0162 Mdot
.70724 .01536 Mdot
.70727 .01611 Mdot
.70729 .01527 Mdot
.70732 .0151 Mdot
.70734 .01547 Mdot
.70737 .01569 Mdot
.7074 .01527 Mdot
.70742 .01589 Mdot
.70745 .01649 Mdot
.70747 .01515 Mdot
.7075 .01652 Mdot
.70753 .01502 Mdot
.70755 .01562 Mdot
.70758 .01645 Mdot
.7076 .01523 Mdot
.70763 .01504 Mdot
.70765 .01524 Mdot
.70768 .01529 Mdot
.70771 .01611 Mdot
.70773 .01554 Mdot
.70776 .01561 Mdot
.70778 .01548 Mdot
.70781 .01573 Mdot
.70784 .01535 Mdot
.70786 .01531 Mdot
.70789 .01558 Mdot
.70791 .01654 Mdot
.70794 .01634 Mdot
.70796 .01553 Mdot
.70799 .01544 Mdot
.70802 .01564 Mdot
.70804 .01571 Mdot
.70807 .01565 Mdot
.70809 .01612 Mdot
.70812 .01617 Mdot
.70815 .01661 Mdot
.70817 .01625 Mdot
.7082 .01632 Mdot
.70822 .01611 Mdot
.70825 .0155 Mdot
.70827 .01569 Mdot
.7083 .01583 Mdot
.70833 .01583 Mdot
.70835 .01539 Mdot
.70838 .01571 Mdot
.7084 .01732 Mdot
.70843 .01496 Mdot
.70846 .01628 Mdot
.70848 .01502 Mdot
.70851 .01535 Mdot
.70853 .0154 Mdot
.70856 .01523 Mdot
.70858 .01509 Mdot
.70861 .01599 Mdot
.70864 .01607 Mdot
.70866 .01557 Mdot
.70869 .01492 Mdot
.70871 .01566 Mdot
.70874 .0165 Mdot
.70877 .0153 Mdot
.70879 .01582 Mdot
.70882 .0165 Mdot
.70884 .01541 Mdot
.70887 .01512 Mdot
.70889 .01538 Mdot
.70892 .0153 Mdot
.70895 .0159 Mdot
.70897 .01524 Mdot
.709 .01565 Mdot
.70902 .01526 Mdot
.70905 .01593 Mdot
.70908 .01712 Mdot
.7091 .0173 Mdot
.70913 .0162 Mdot
.70915 .01567 Mdot
.70918 .01541 Mdot
.7092 .01588 Mdot
.70923 .01613 Mdot
.70926 .01641 Mdot
.70928 .01558 Mdot
.70931 .01548 Mdot
.70933 .01616 Mdot
.70936 .01624 Mdot
.70939 .01548 Mdot
.70941 .01591 Mdot
.70944 .01488 Mdot
.70946 .01546 Mdot
.70949 .0161 Mdot
.70951 .01526 Mdot
.70954 .01526 Mdot
.70957 .01592 Mdot
.70959 .01536 Mdot
.70962 .01644 Mdot
.70964 .01618 Mdot
.70967 .01548 Mdot
.7097 .01503 Mdot
.70972 .01591 Mdot
.70975 .01546 Mdot
.70977 .01635 Mdot
.7098 .01492 Mdot
.70982 .0157 Mdot
.70985 .01714 Mdot
.70988 .01522 Mdot
.7099 .01536 Mdot
.70993 .01491 Mdot
.70995 .01599 Mdot
.70998 .01625 Mdot
.71001 .01569 Mdot
.71003 .01583 Mdot
.71006 .015 Mdot
.71008 .01604 Mdot
.71011 .01532 Mdot
.71013 .01634 Mdot
.71016 .01548 Mdot
.71019 .01519 Mdot
.71021 .01639 Mdot
.71024 .01492 Mdot
.71026 .01652 Mdot
.71029 .01479 Mdot
.71032 .01601 Mdot
.71034 .0155 Mdot
.71037 .01508 Mdot
.71039 .01567 Mdot
.71042 .01523 Mdot
.71044 .0152 Mdot
.71047 .01615 Mdot
.7105 .01662 Mdot
.71052 .01513 Mdot
.71055 .01589 Mdot
.71057 .01526 Mdot
.7106 .01583 Mdot
.71063 .01618 Mdot
.71065 .01526 Mdot
.71068 .01638 Mdot
.7107 .01528 Mdot
.71073 .0152 Mdot
.71075 .01608 Mdot
.71078 .01548 Mdot
.71081 .01611 Mdot
.71083 .01516 Mdot
.71086 .01489 Mdot
.71088 .01587 Mdot
.71091 .01494 Mdot
.71094 .01573 Mdot
.71096 .01631 Mdot
.71099 .01616 Mdot
.71101 .01556 Mdot
.71104 .01483 Mdot
.71106 .01602 Mdot
.71109 .01491 Mdot
.71112 .01488 Mdot
.71114 .01553 Mdot
.71117 .01586 Mdot
.71119 .0158 Mdot
.71122 .01632 Mdot
.71125 .01524 Mdot
.71127 .01652 Mdot
.7113 .01599 Mdot
.71132 .01617 Mdot
.71135 .01603 Mdot
.71137 .01543 Mdot
.7114 .01525 Mdot
.71143 .0149 Mdot
.71145 .01569 Mdot
.71148 .01497 Mdot
.7115 .01588 Mdot
.71153 .01546 Mdot
.71156 .01535 Mdot
.71158 .01573 Mdot
.71161 .01597 Mdot
.71163 .01517 Mdot
.71166 .01554 Mdot
.71168 .01623 Mdot
.71171 .01542 Mdot
.71174 .01611 Mdot
.71176 .01535 Mdot
.71179 .01638 Mdot
.71181 .01554 Mdot
.71184 .01588 Mdot
.71187 .01624 Mdot
.71189 .0157 Mdot
.71192 .01529 Mdot
.71194 .01549 Mdot
.71197 .01576 Mdot
.71199 .01532 Mdot
.71202 .01589 Mdot
.71205 .01579 Mdot
.71207 .0155 Mdot
.7121 .01633 Mdot
.71212 .01551 Mdot
.71215 .01532 Mdot
.71218 .01541 Mdot
.7122 .01707 Mdot
.71223 .01551 Mdot
.71225 .01586 Mdot
.71228 .01537 Mdot
.7123 .01565 Mdot
.71233 .01557 Mdot
.71236 .01536 Mdot
.71238 .01547 Mdot
.71241 .01493 Mdot
.71243 .01488 Mdot
.71246 .01571 Mdot
.71249 .01568 Mdot
.71251 .01542 Mdot
.71254 .01554 Mdot
.71256 .0149 Mdot
.71259 .01547 Mdot
.71261 .01639 Mdot
.71264 .01634 Mdot
.71267 .01579 Mdot
.71269 .01538 Mdot
.71272 .01492 Mdot
.71274 .01524 Mdot
.71277 .01577 Mdot
.7128 .0162 Mdot
.71282 .01541 Mdot
.71285 .01604 Mdot
.71287 .01542 Mdot
.7129 .01511 Mdot
.71292 .01612 Mdot
.71295 .01573 Mdot
.71298 .01563 Mdot
.713 .01626 Mdot
.71303 .01524 Mdot
.71305 .01578 Mdot
.71308 .01631 Mdot
.71311 .01521 Mdot
.71313 .01518 Mdot
.71316 .01567 Mdot
.71318 .01617 Mdot
.71321 .01552 Mdot
.71323 .01482 Mdot
.71326 .0153 Mdot
.71329 .01533 Mdot
.71331 .01694 Mdot
.71334 .0161 Mdot
.71336 .0157 Mdot
.71339 .01677 Mdot
.71342 .01591 Mdot
.71344 .01536 Mdot
.71347 .0159 Mdot
.71349 .01527 Mdot
.71352 .01574 Mdot
.71354 .01548 Mdot
.71357 .01552 Mdot
.7136 .01483 Mdot
.71362 .01542 Mdot
.71365 .01585 Mdot
.71367 .01672 Mdot
.7137 .01551 Mdot
.71373 .01575 Mdot
.71375 .01498 Mdot
.71378 .01549 Mdot
.7138 .01546 Mdot
.71383 .01575 Mdot
.71385 .0159 Mdot
.71388 .01511 Mdot
.71391 .0156 Mdot
.71393 .01627 Mdot
.71396 .01595 Mdot
.71398 .01719 Mdot
.71401 .01551 Mdot
.71404 .01698 Mdot
.71406 .01503 Mdot
.71409 .01668 Mdot
.71411 .01601 Mdot
.71414 .01577 Mdot
.71416 .01576 Mdot
.71419 .01516 Mdot
.71422 .01545 Mdot
.71424 .01554 Mdot
.71427 .01591 Mdot
.71429 .01585 Mdot
.71432 .0156 Mdot
.71435 .0159 Mdot
.71437 .01614 Mdot
.7144 .01668 Mdot
.71442 .01561 Mdot
.71445 .01636 Mdot
.71447 .01589 Mdot
.7145 .01573 Mdot
.71453 .01619 Mdot
.71455 .0149 Mdot
.71458 .01666 Mdot
.7146 .01506 Mdot
.71463 .01705 Mdot
.71466 .01788 Mdot
.71468 .01589 Mdot
.71471 .01542 Mdot
.71473 .01546 Mdot
.71476 .01687 Mdot
.71478 .01529 Mdot
.71481 .01563 Mdot
.71484 .01496 Mdot
.71486 .01508 Mdot
.71489 .0156 Mdot
.71491 .01589 Mdot
.71494 .01622 Mdot
.71497 .01588 Mdot
.71499 .01604 Mdot
.71502 .01548 Mdot
.71504 .01574 Mdot
.71507 .01575 Mdot
.7151 .01509 Mdot
.71512 .01486 Mdot
.71515 .01607 Mdot
.71517 .01595 Mdot
.7152 .01538 Mdot
.71522 .0159 Mdot
.71525 .01571 Mdot
.71528 .0159 Mdot
.7153 .0162 Mdot
.71533 .01581 Mdot
.71535 .01586 Mdot
.71538 .01602 Mdot
.71541 .01629 Mdot
.71543 .01529 Mdot
.71546 .0159 Mdot
.71548 .01537 Mdot
.71551 .0159 Mdot
.71553 .01602 Mdot
.71556 .01584 Mdot
.71559 .01511 Mdot
.71561 .01502 Mdot
.71564 .01689 Mdot
.71566 .01555 Mdot
.71569 .01627 Mdot
.71572 .01496 Mdot
.71574 .01589 Mdot
.71577 .01502 Mdot
.71579 .01555 Mdot
.71582 .01595 Mdot
.71584 .01528 Mdot
.71587 .0157 Mdot
.7159 .01579 Mdot
.71592 .01583 Mdot
.71595 .01642 Mdot
.71597 .01541 Mdot
.716 .01538 Mdot
.71603 .01481 Mdot
.71605 .01514 Mdot
.71608 .01501 Mdot
.7161 .01562 Mdot
.71613 .01532 Mdot
.71615 .017 Mdot
.71618 .01605 Mdot
.71621 .01511 Mdot
.71623 .01608 Mdot
.71626 .0156 Mdot
.71628 .01643 Mdot
.71631 .01579 Mdot
.71634 .01577 Mdot
.71636 .01706 Mdot
.71639 .01587 Mdot
.71641 .0154 Mdot
.71644 .01495 Mdot
.71646 .01543 Mdot
.71649 .01525 Mdot
.71652 .01532 Mdot
.71654 .01685 Mdot
.71657 .01602 Mdot
.71659 .01551 Mdot
.71662 .01538 Mdot
.71665 .0157 Mdot
.71667 .01533 Mdot
.7167 .01555 Mdot
.71672 .01541 Mdot
.71675 .01776 Mdot
.71677 .01617 Mdot
.7168 .01587 Mdot
.71683 .01549 Mdot
.71685 .01549 Mdot
.71688 .01625 Mdot
.7169 .01611 Mdot
.71693 .01508 Mdot
.71696 .01566 Mdot
.71698 .01573 Mdot
.71701 .01488 Mdot
.71703 .01559 Mdot
.71706 .0151 Mdot
.71708 .01523 Mdot
.71711 .01583 Mdot
.71714 .01525 Mdot
.71716 .01558 Mdot
.71719 .01563 Mdot
.71721 .01479 Mdot
.71724 .01553 Mdot
.71727 .01558 Mdot
.71729 .01508 Mdot
.71732 .01517 Mdot
.71734 .01592 Mdot
.71737 .01541 Mdot
.71739 .015 Mdot
.71742 .01572 Mdot
.71745 .01573 Mdot
.71747 .01623 Mdot
.7175 .01562 Mdot
.71752 .0152 Mdot
.71755 .01596 Mdot
.71758 .01655 Mdot
.7176 .01519 Mdot
.71763 .01642 Mdot
.71765 .01616 Mdot
.71768 .01579 Mdot
.7177 .01539 Mdot
.71773 .01617 Mdot
.71776 .01524 Mdot
.71778 .01606 Mdot
.71781 .01521 Mdot
.71783 .01488 Mdot
.71786 .01619 Mdot
.71789 .01641 Mdot
.71791 .01578 Mdot
.71794 .01554 Mdot
.71796 .01607 Mdot
.71799 .01561 Mdot
.71801 .01608 Mdot
.71804 .01588 Mdot
.71807 .01518 Mdot
.71809 .0153 Mdot
.71812 .0152 Mdot
.71814 .01667 Mdot
.71817 .01507 Mdot
.7182 .01483 Mdot
.71822 .01516 Mdot
.71825 .01604 Mdot
.71827 .01647 Mdot
.7183 .01545 Mdot
.71832 .01578 Mdot
.71835 .0162 Mdot
.71838 .01569 Mdot
.7184 .0163 Mdot
.71843 .01655 Mdot
.71845 .01631 Mdot
.71848 .01557 Mdot
.71851 .01517 Mdot
.71853 .01542 Mdot
.71856 .01655 Mdot
.71858 .01599 Mdot
.71861 .01521 Mdot
.71863 .0157 Mdot
.71866 .01526 Mdot
.71869 .01555 Mdot
.71871 .01531 Mdot
.71874 .01574 Mdot
.71876 .01558 Mdot
.71879 .01575 Mdot
.71882 .01626 Mdot
.71884 .01523 Mdot
.71887 .01657 Mdot
.71889 .01532 Mdot
.71892 .01573 Mdot
.71894 .01635 Mdot
.71897 .01567 Mdot
.719 .01646 Mdot
.71902 .01655 Mdot
.71905 .01537 Mdot
.71907 .01653 Mdot
.7191 .0176 Mdot
.71913 .01636 Mdot
.71915 .01635 Mdot
.71918 .01614 Mdot
.7192 .01569 Mdot
.71923 .01617 Mdot
.71925 .01506 Mdot
.71928 .0162 Mdot
.71931 .01613 Mdot
.71933 .01628 Mdot
.71936 .01543 Mdot
.71938 .01509 Mdot
.71941 .01495 Mdot
.71944 .01527 Mdot
.71946 .01569 Mdot
.71949 .01545 Mdot
.71951 .01559 Mdot
.71954 .01529 Mdot
.71956 .01559 Mdot
.71959 .01565 Mdot
.71962 .01535 Mdot
.71964 .01648 Mdot
.71967 .01559 Mdot
.71969 .01542 Mdot
.71972 .01567 Mdot
.71975 .01644 Mdot
.71977 .01537 Mdot
.7198 .01668 Mdot
.71982 .01601 Mdot
.71985 .0155 Mdot
.71987 .01496 Mdot
.7199 .01546 Mdot
.71993 .01566 Mdot
.71995 .01655 Mdot
.71998 .01702 Mdot
.72 .01541 Mdot
.72003 .01651 Mdot
.72006 .01625 Mdot
.72008 .01616 Mdot
.72011 .01509 Mdot
.72013 .01564 Mdot
.72016 .01614 Mdot
.72018 .01629 Mdot
.72021 .01553 Mdot
.72024 .01629 Mdot
.72026 .01504 Mdot
.72029 .01543 Mdot
.72031 .01652 Mdot
.72034 .01533 Mdot
.72037 .01567 Mdot
.72039 .0152 Mdot
.72042 .01634 Mdot
.72044 .01495 Mdot
.72047 .01612 Mdot
.72049 .01545 Mdot
.72052 .01554 Mdot
.72055 .01534 Mdot
.72057 .01614 Mdot
.7206 .01547 Mdot
.72062 .01604 Mdot
.72065 .01525 Mdot
.72068 .0155 Mdot
.7207 .01521 Mdot
.72073 .01605 Mdot
.72075 .0152 Mdot
.72078 .01558 Mdot
.7208 .01536 Mdot
.72083 .01584 Mdot
.72086 .01476 Mdot
.72088 .0151 Mdot
.72091 .01523 Mdot
.72093 .01516 Mdot
.72096 .0155 Mdot
.72099 .01587 Mdot
.72101 .01514 Mdot
.72104 .01681 Mdot
.72106 .01516 Mdot
.72109 .0149 Mdot
.72111 .01504 Mdot
.72114 .0152 Mdot
.72117 .01511 Mdot
.72119 .01648 Mdot
.72122 .01591 Mdot
.72124 .01566 Mdot
.72127 .01554 Mdot
.7213 .0152 Mdot
.72132 .0157 Mdot
.72135 .01652 Mdot
.72137 .0158 Mdot
.7214 .01548 Mdot
.72142 .01515 Mdot
.72145 .01546 Mdot
.72148 .0151 Mdot
.7215 .01578 Mdot
.72153 .01657 Mdot
.72155 .01569 Mdot
.72158 .01523 Mdot
.72161 .01579 Mdot
.72163 .01625 Mdot
.72166 .01499 Mdot
.72168 .01594 Mdot
.72171 .01576 Mdot
.72173 .01524 Mdot
.72176 .01593 Mdot
.72179 .01607 Mdot
.72181 .0164 Mdot
.72184 .01545 Mdot
.72186 .01581 Mdot
.72189 .0152 Mdot
.72192 .01551 Mdot
.72194 .01553 Mdot
.72197 .01587 Mdot
.72199 .01558 Mdot
.72202 .0156 Mdot
.72204 .01514 Mdot
.72207 .01511 Mdot
.7221 .01596 Mdot
.72212 .01584 Mdot
.72215 .01631 Mdot
.72217 .01521 Mdot
.7222 .01601 Mdot
.72223 .01522 Mdot
.72225 .01535 Mdot
.72228 .01614 Mdot
.7223 .01575 Mdot
.72233 .01515 Mdot
.72235 .0154 Mdot
.72238 .01478 Mdot
.72241 .0148 Mdot
.72243 .01583 Mdot
.72246 .01545 Mdot
.72248 .01645 Mdot
.72251 .01487 Mdot
.72254 .01624 Mdot
.72256 .0154 Mdot
.72259 .01486 Mdot
.72261 .01591 Mdot
.72264 .01591 Mdot
.72266 .01593 Mdot
.72269 .01616 Mdot
.72272 .01531 Mdot
.72274 .01555 Mdot
.72277 .01496 Mdot
.72279 .01545 Mdot
.72282 .01618 Mdot
.72285 .01512 Mdot
.72287 .01639 Mdot
.7229 .01691 Mdot
.72292 .01528 Mdot
.72295 .01644 Mdot
.72297 .01567 Mdot
.723 .01597 Mdot
.72303 .01508 Mdot
.72305 .0154 Mdot
.72308 .01587 Mdot
.7231 .01687 Mdot
.72313 .01601 Mdot
.72316 .01512 Mdot
.72318 .01591 Mdot
.72321 .01595 Mdot
.72323 .01505 Mdot
.72326 .01644 Mdot
.72328 .01633 Mdot
.72331 .01491 Mdot
.72334 .01588 Mdot
.72336 .01646 Mdot
.72339 .01672 Mdot
.72341 .01525 Mdot
.72344 .01575 Mdot
.72347 .01517 Mdot
.72349 .01589 Mdot
.72352 .01738 Mdot
.72354 .01552 Mdot
.72357 .0154 Mdot
.72359 .01522 Mdot
.72362 .0153 Mdot
.72365 .01674 Mdot
.72367 .0166 Mdot
.7237 .01539 Mdot
.72372 .01548 Mdot
.72375 .01517 Mdot
.72378 .01602 Mdot
.7238 .01596 Mdot
.72383 .01649 Mdot
.72385 .01581 Mdot
.72388 .01626 Mdot
.7239 .0161 Mdot
.72393 .01548 Mdot
.72396 .01584 Mdot
.72398 .0152 Mdot
.72401 .01675 Mdot
.72403 .01556 Mdot
.72406 .01525 Mdot
.72409 .015 Mdot
.72411 .01562 Mdot
.72414 .01554 Mdot
.72416 .0153 Mdot
.72419 .0161 Mdot
.72422 .01579 Mdot
.72424 .01515 Mdot
.72427 .0153 Mdot
.72429 .0153 Mdot
.72432 .01532 Mdot
.72434 .01582 Mdot
.72437 .01511 Mdot
.7244 .01693 Mdot
.72442 .01504 Mdot
.72445 .01506 Mdot
.72447 .01498 Mdot
.7245 .01626 Mdot
.72453 .01559 Mdot
.72455 .01631 Mdot
.72458 .01582 Mdot
.7246 .01564 Mdot
.72463 .01582 Mdot
.72465 .01518 Mdot
.72468 .01608 Mdot
.72471 .01523 Mdot
.72473 .0163 Mdot
.72476 .01502 Mdot
.72478 .01543 Mdot
.72481 .01502 Mdot
.72484 .01601 Mdot
.72486 .01574 Mdot
.72489 .01505 Mdot
.72491 .01543 Mdot
.72494 .017 Mdot
.72496 .0176 Mdot
.72499 .01544 Mdot
.72502 .01545 Mdot
.72504 .01537 Mdot
.72507 .0155 Mdot
.72509 .0163 Mdot
.72512 .01655 Mdot
.72515 .01568 Mdot
.72517 .01615 Mdot
.7252 .01602 Mdot
.72522 .01502 Mdot
.72525 .01633 Mdot
.72527 .01531 Mdot
.7253 .0166 Mdot
.72533 .0167 Mdot
.72535 .01564 Mdot
.72538 .01689 Mdot
.7254 .01546 Mdot
.72543 .0166 Mdot
.72546 .015 Mdot
.72548 .01559 Mdot
.72551 .01641 Mdot
.72553 .01527 Mdot
.72556 .01608 Mdot
.72558 .01546 Mdot
.72561 .01641 Mdot
.72564 .01536 Mdot
.72566 .0156 Mdot
.72569 .01562 Mdot
.72571 .01521 Mdot
.72574 .0159 Mdot
.72577 .01621 Mdot
.72579 .01633 Mdot
.72582 .01506 Mdot
.72584 .01553 Mdot
.72587 .01508 Mdot
.72589 .01538 Mdot
.72592 .01558 Mdot
.72595 .01568 Mdot
.72597 .01508 Mdot
.726 .01487 Mdot
.72602 .01571 Mdot
.72605 .01504 Mdot
.72608 .01551 Mdot
.7261 .0151 Mdot
.72613 .01577 Mdot
.72615 .01546 Mdot
.72618 .01488 Mdot
.7262 .01546 Mdot
.72623 .01606 Mdot
.72626 .01508 Mdot
.72628 .01598 Mdot
.72631 .01594 Mdot
.72633 .01576 Mdot
.72636 .01616 Mdot
.72639 .01633 Mdot
.72641 .01597 Mdot
.72644 .01523 Mdot
.72646 .01541 Mdot
.72649 .01495 Mdot
.72651 .01566 Mdot
.72654 .0154 Mdot
.72657 .01507 Mdot
.72659 .01513 Mdot
.72662 .0151 Mdot
.72664 .01539 Mdot
.72667 .01511 Mdot
.7267 .01655 Mdot
.72672 .01528 Mdot
.72675 .01577 Mdot
.72677 .01637 Mdot
.7268 .01561 Mdot
.72682 .01516 Mdot
.72685 .01535 Mdot
.72688 .01538 Mdot
.7269 .01653 Mdot
.72693 .01526 Mdot
.72695 .01493 Mdot
.72698 .01548 Mdot
.72701 .01525 Mdot
.72703 .01656 Mdot
.72706 .0158 Mdot
.72708 .01609 Mdot
.72711 .01578 Mdot
.72713 .01551 Mdot
.72716 .01555 Mdot
.72719 .01576 Mdot
.72721 .01577 Mdot
.72724 .01539 Mdot
.72726 .01627 Mdot
.72729 .0156 Mdot
.72732 .01508 Mdot
.72734 .01531 Mdot
.72737 .01606 Mdot
.72739 .01546 Mdot
.72742 .01497 Mdot
.72744 .01554 Mdot
.72747 .01546 Mdot
.7275 .01537 Mdot
.72752 .015 Mdot
.72755 .01532 Mdot
.72757 .01526 Mdot
.7276 .01581 Mdot
.72763 .01595 Mdot
.72765 .01577 Mdot
.72768 .01621 Mdot
.7277 .01566 Mdot
.72773 .01594 Mdot
.72775 .0163 Mdot
.72778 .01559 Mdot
.72781 .01534 Mdot
.72783 .0151 Mdot
.72786 .01496 Mdot
.72788 .01544 Mdot
.72791 .01561 Mdot
.72794 .01581 Mdot
.72796 .01552 Mdot
.72799 .01627 Mdot
.72801 .01589 Mdot
.72804 .01607 Mdot
.72806 .01702 Mdot
.72809 .0157 Mdot
.72812 .01522 Mdot
.72814 .01599 Mdot
.72817 .0158 Mdot
.72819 .01629 Mdot
.72822 .01508 Mdot
.72825 .01546 Mdot
.72827 .01513 Mdot
.7283 .01507 Mdot
.72832 .01512 Mdot
.72835 .01512 Mdot
.72837 .01629 Mdot
.7284 .01618 Mdot
.72843 .01579 Mdot
.72845 .01596 Mdot
.72848 .01515 Mdot
.7285 .01563 Mdot
.72853 .01588 Mdot
.72856 .01714 Mdot
.72858 .01491 Mdot
.72861 .01602 Mdot
.72863 .01576 Mdot
.72866 .0155 Mdot
.72868 .01622 Mdot
.72871 .01504 Mdot
.72874 .01532 Mdot
.72876 .01519 Mdot
.72879 .01525 Mdot
.72881 .01559 Mdot
.72884 .01601 Mdot
.72887 .01558 Mdot
.72889 .0164 Mdot
.72892 .01718 Mdot
.72894 .01516 Mdot
.72897 .01532 Mdot
.72899 .01493 Mdot
.72902 .01525 Mdot
.72905 .01586 Mdot
.72907 .01516 Mdot
.7291 .01515 Mdot
.72912 .01536 Mdot
.72915 .01553 Mdot
.72918 .01663 Mdot
.7292 .01598 Mdot
.72923 .01546 Mdot
.72925 .01582 Mdot
.72928 .01487 Mdot
.7293 .01713 Mdot
.72933 .01621 Mdot
.72936 .0165 Mdot
.72938 .01667 Mdot
.72941 .01552 Mdot
.72943 .01586 Mdot
.72946 .01647 Mdot
.72949 .01551 Mdot
.72951 .01674 Mdot
.72954 .01563 Mdot
.72956 .01601 Mdot
.72959 .01545 Mdot
.72961 .01505 Mdot
.72964 .01607 Mdot
.72967 .01735 Mdot
.72969 .01564 Mdot
.72972 .0164 Mdot
.72974 .01484 Mdot
.72977 .01576 Mdot
.7298 .01503 Mdot
.72982 .01529 Mdot
.72985 .01612 Mdot
.72987 .01675 Mdot
.7299 .01544 Mdot
.72992 .01549 Mdot
.72995 .01591 Mdot
.72998 .01609 Mdot
.73 .01624 Mdot
.73003 .01673 Mdot
.73005 .01632 Mdot
.73008 .01563 Mdot
.73011 .01532 Mdot
.73013 .01496 Mdot
.73016 .01552 Mdot
.73018 .01532 Mdot
.73021 .01549 Mdot
.73023 .01516 Mdot
.73026 .01523 Mdot
.73029 .01763 Mdot
.73031 .01566 Mdot
.73034 .01548 Mdot
.73036 .0161 Mdot
.73039 .01539 Mdot
.73042 .01474 Mdot
.73044 .01616 Mdot
.73047 .01587 Mdot
.73049 .01531 Mdot
.73052 .01527 Mdot
.73054 .01563 Mdot
.73057 .01602 Mdot
.7306 .01595 Mdot
.73062 .01672 Mdot
.73065 .01558 Mdot
.73067 .01557 Mdot
.7307 .01501 Mdot
.73073 .01513 Mdot
.73075 .01594 Mdot
.73078 .015 Mdot
.7308 .01542 Mdot
.73083 .01533 Mdot
.73085 .01539 Mdot
.73088 .01598 Mdot
.73091 .01608 Mdot
.73093 .01597 Mdot
.73096 .01571 Mdot
.73098 .01635 Mdot
.73101 .01559 Mdot
.73104 .0158 Mdot
.73106 .01573 Mdot
.73109 .01543 Mdot
.73111 .01627 Mdot
.73114 .01558 Mdot
.73116 .01599 Mdot
.73119 .01617 Mdot
.73122 .01629 Mdot
.73124 .01636 Mdot
.73127 .0161 Mdot
.73129 .01605 Mdot
.73132 .01644 Mdot
.73135 .01574 Mdot
.73137 .01595 Mdot
.7314 .01623 Mdot
.73142 .0148 Mdot
.73145 .01529 Mdot
.73147 .01734 Mdot
.7315 .01524 Mdot
.73153 .0164 Mdot
.73155 .01499 Mdot
.73158 .0155 Mdot
.7316 .01642 Mdot
.73163 .01523 Mdot
.73166 .01569 Mdot
.73168 .01534 Mdot
.73171 .01585 Mdot
.73173 .01628 Mdot
.73176 .01615 Mdot
.73178 .01559 Mdot
.73181 .01555 Mdot
.73184 .01664 Mdot
.73186 .01596 Mdot
.73189 .01631 Mdot
.73191 .0153 Mdot
.73194 .01561 Mdot
.73197 .01618 Mdot
.73199 .01585 Mdot
.73202 .01492 Mdot
.73204 .01525 Mdot
.73207 .01516 Mdot
.73209 .01576 Mdot
.73212 .01519 Mdot
.73215 .01611 Mdot
.73217 .01522 Mdot
.7322 .01518 Mdot
.73222 .0158 Mdot
.73225 .0155 Mdot
.73228 .01566 Mdot
.7323 .0156 Mdot
.73233 .01672 Mdot
.73235 .01584 Mdot
.73238 .01625 Mdot
.7324 .01529 Mdot
.73243 .01508 Mdot
.73246 .01599 Mdot
.73248 .01507 Mdot
.73251 .015 Mdot
.73253 .0156 Mdot
.73256 .01511 Mdot
.73259 .01617 Mdot
.73261 .01559 Mdot
.73264 .01526 Mdot
.73266 .01671 Mdot
.73269 .01535 Mdot
.73271 .0159 Mdot
.73274 .01776 Mdot
.73277 .01567 Mdot
.73279 .01537 Mdot
.73282 .01519 Mdot
.73284 .01531 Mdot
.73287 .01554 Mdot
.7329 .01629 Mdot
.73292 .01563 Mdot
.73295 .01492 Mdot
.73297 .01541 Mdot
.733 .01604 Mdot
.73302 .01553 Mdot
.73305 .01717 Mdot
.73308 .01537 Mdot
.7331 .01521 Mdot
.73313 .01527 Mdot
.73315 .01564 Mdot
.73318 .01604 Mdot
.73321 .01531 Mdot
.73323 .01491 Mdot
.73326 .0156 Mdot
.73328 .0152 Mdot
.73331 .01546 Mdot
.73334 .01697 Mdot
.73336 .01556 Mdot
.73339 .01651 Mdot
.73341 .01575 Mdot
.73344 .01666 Mdot
.73346 .0157 Mdot
.73349 .01601 Mdot
.73352 .01564 Mdot
.73354 .01561 Mdot
.73357 .0154 Mdot
.73359 .01624 Mdot
.73362 .01509 Mdot
.73365 .01633 Mdot
.73367 .01586 Mdot
.7337 .01669 Mdot
.73372 .01534 Mdot
.73375 .01633 Mdot
.73377 .01567 Mdot
.7338 .01527 Mdot
.73383 .01561 Mdot
.73385 .01587 Mdot
.73388 .01552 Mdot
.7339 .01627 Mdot
.73393 .01538 Mdot
.73396 .01587 Mdot
.73398 .01516 Mdot
.73401 .0152 Mdot
.73403 .01544 Mdot
.73406 .01523 Mdot
.73408 .01495 Mdot
.73411 .016 Mdot
.73414 .0148 Mdot
.73416 .01618 Mdot
.73419 .01588 Mdot
.73421 .01596 Mdot
.73424 .01504 Mdot
.73427 .0157 Mdot
.73429 .01582 Mdot
.73432 .01628 Mdot
.73434 .01671 Mdot
.73437 .01532 Mdot
.73439 .01502 Mdot
.73442 .01536 Mdot
.73445 .01528 Mdot
.73447 .01517 Mdot
.7345 .01572 Mdot
.73452 .01547 Mdot
.73455 .01617 Mdot
.73458 .01613 Mdot
.7346 .01576 Mdot
.73463 .01493 Mdot
.73465 .0149 Mdot
.73468 .01604 Mdot
.7347 .01569 Mdot
.73473 .01532 Mdot
.73476 .01528 Mdot
.73478 .01601 Mdot
.73481 .01551 Mdot
.73483 .01516 Mdot
.73486 .01538 Mdot
.73489 .01574 Mdot
.73491 .01586 Mdot
.73494 .01516 Mdot
.73496 .01578 Mdot
.73499 .01644 Mdot
.73501 .01617 Mdot
.73504 .01538 Mdot
.73507 .01577 Mdot
.73509 .01501 Mdot
.73512 .01538 Mdot
.73514 .01605 Mdot
.73517 .01508 Mdot
.7352 .01575 Mdot
.73522 .01593 Mdot
.73525 .0149 Mdot
.73527 .01723 Mdot
.7353 .0151 Mdot
.73532 .01544 Mdot
.73535 .0149 Mdot
.73538 .01593 Mdot
.7354 .01641 Mdot
.73543 .01646 Mdot
.73545 .01548 Mdot
.73548 .01489 Mdot
.73551 .01548 Mdot
.73553 .01578 Mdot
.73556 .01586 Mdot
.73558 .01522 Mdot
.73561 .01637 Mdot
.73563 .01571 Mdot
.73566 .01487 Mdot
.73569 .01517 Mdot
.73571 .0164 Mdot
.73574 .01643 Mdot
.73576 .01503 Mdot
.73579 .01534 Mdot
.73582 .01507 Mdot
.73584 .01492 Mdot
.73587 .01608 Mdot
.73589 .01555 Mdot
.73592 .01559 Mdot
.73594 .01568 Mdot
.73597 .01573 Mdot
.736 .01707 Mdot
.73602 .01713 Mdot
.73605 .01531 Mdot
.73607 .01594 Mdot
.7361 .0151 Mdot
.73613 .01518 Mdot
.73615 .0156 Mdot
.73618 .01521 Mdot
.7362 .01626 Mdot
.73623 .01517 Mdot
.73625 .01536 Mdot
.73628 .01499 Mdot
.73631 .01631 Mdot
.73633 .01501 Mdot
.73636 .01619 Mdot
.73638 .01619 Mdot
.73641 .01592 Mdot
.73644 .01541 Mdot
.73646 .01575 Mdot
.73649 .01527 Mdot
.73651 .01583 Mdot
.73654 .01517 Mdot
.73656 .01562 Mdot
.73659 .01546 Mdot
.73662 .01504 Mdot
.73664 .0161 Mdot
.73667 .01582 Mdot
.73669 .01549 Mdot
.73672 .0148 Mdot
.73675 .01543 Mdot
.73677 .0155 Mdot
.7368 .01634 Mdot
.73682 .01539 Mdot
.73685 .01603 Mdot
.73687 .01587 Mdot
.7369 .01512 Mdot
.73693 .01571 Mdot
.73695 .01546 Mdot
.73698 .01509 Mdot
.737 .01588 Mdot
.73703 .01508 Mdot
.73706 .01602 Mdot
.73708 .01576 Mdot
.73711 .01572 Mdot
.73713 .01556 Mdot
.73716 .01548 Mdot
.73718 .01571 Mdot
.73721 .01753 Mdot
.73724 .01501 Mdot
.73726 .01601 Mdot
.73729 .01609 Mdot
.73731 .01497 Mdot
.73734 .01514 Mdot
.73737 .01621 Mdot
.73739 .0158 Mdot
.73742 .01556 Mdot
.73744 .01533 Mdot
.73747 .01597 Mdot
.73749 .01549 Mdot
.73752 .01799 Mdot
.73755 .01528 Mdot
.73757 .01629 Mdot
.7376 .01505 Mdot
.73762 .01601 Mdot
.73765 .01536 Mdot
.73768 .01707 Mdot
.7377 .01579 Mdot
.73773 .01555 Mdot
.73775 .01502 Mdot
.73778 .01559 Mdot
.7378 .01544 Mdot
.73783 .01658 Mdot
.73786 .01556 Mdot
.73788 .01549 Mdot
.73791 .01615 Mdot
.73793 .01478 Mdot
.73796 .01529 Mdot
.73799 .01514 Mdot
.73801 .01578 Mdot
.73804 .0154 Mdot
.73806 .01523 Mdot
.73809 .01633 Mdot
.73811 .01488 Mdot
.73814 .01499 Mdot
.73817 .01482 Mdot
.73819 .01604 Mdot
.73822 .01493 Mdot
.73824 .01581 Mdot
.73827 .01604 Mdot
.7383 .01629 Mdot
.73832 .01636 Mdot
.73835 .01581 Mdot
.73837 .01538 Mdot
.7384 .01504 Mdot
.73842 .01556 Mdot
.73845 .01508 Mdot
.73848 .01512 Mdot
.7385 .01581 Mdot
.73853 .01768 Mdot
.73855 .01527 Mdot
.73858 .01493 Mdot
.73861 .01511 Mdot
.73863 .01599 Mdot
.73866 .01562 Mdot
.73868 .0162 Mdot
.73871 .01596 Mdot
.73873 .01649 Mdot
.73876 .01579 Mdot
.73879 .01606 Mdot
.73881 .01581 Mdot
.73884 .01602 Mdot
.73886 .01512 Mdot
.73889 .01527 Mdot
.73892 .01513 Mdot
.73894 .01563 Mdot
.73897 .01535 Mdot
.73899 .01593 Mdot
.73902 .01551 Mdot
.73904 .01523 Mdot
.73907 .0161 Mdot
.7391 .01522 Mdot
.73912 .01597 Mdot
.73915 .016 Mdot
.73917 .01514 Mdot
.7392 .01575 Mdot
.73923 .01693 Mdot
.73925 .01484 Mdot
.73928 .01573 Mdot
.7393 .01611 Mdot
.73933 .01568 Mdot
.73935 .01684 Mdot
.73938 .01585 Mdot
.73941 .01605 Mdot
.73943 .01527 Mdot
.73946 .01647 Mdot
.73948 .01623 Mdot
.73951 .01641 Mdot
.73954 .01595 Mdot
.73956 .01628 Mdot
.73959 .01605 Mdot
.73961 .01552 Mdot
.73964 .01649 Mdot
.73966 .01567 Mdot
.73969 .01526 Mdot
.73972 .01572 Mdot
.73974 .01556 Mdot
.73977 .01579 Mdot
.73979 .01633 Mdot
.73982 .01595 Mdot
.73985 .01578 Mdot
.73987 .01622 Mdot
.7399 .01611 Mdot
.73992 .01507 Mdot
.73995 .0168 Mdot
.73997 .0155 Mdot
.74 .01547 Mdot
.74003 .01548 Mdot
.74005 .01633 Mdot
.74008 .01513 Mdot
.7401 .01556 Mdot
.74013 .01679 Mdot
.74016 .01514 Mdot
.74018 .01649 Mdot
.74021 .01543 Mdot
.74023 .01623 Mdot
.74026 .01633 Mdot
.74028 .01577 Mdot
.74031 .0152 Mdot
.74034 .01653 Mdot
.74036 .01608 Mdot
.74039 .01566 Mdot
.74041 .01641 Mdot
.74044 .01541 Mdot
.74047 .01521 Mdot
.74049 .01558 Mdot
.74052 .01505 Mdot
.74054 .01519 Mdot
.74057 .01587 Mdot
.74059 .01519 Mdot
.74062 .01571 Mdot
.74065 .0162 Mdot
.74067 .01483 Mdot
.7407 .0155 Mdot
.74072 .01534 Mdot
.74075 .01582 Mdot
.74078 .01557 Mdot
.7408 .01703 Mdot
.74083 .01522 Mdot
.74085 .0152 Mdot
.74088 .01591 Mdot
.7409 .0151 Mdot
.74093 .0161 Mdot
.74096 .01477 Mdot
.74098 .01495 Mdot
.74101 .01531 Mdot
.74103 .01504 Mdot
.74106 .01539 Mdot
.74109 .01532 Mdot
.74111 .01593 Mdot
.74114 .01605 Mdot
.74116 .01569 Mdot
.74119 .01589 Mdot
.74121 .01576 Mdot
.74124 .01701 Mdot
.74127 .01543 Mdot
.74129 .01633 Mdot
.74132 .01545 Mdot
.74134 .01621 Mdot
.74137 .01569 Mdot
.7414 .01607 Mdot
.74142 .0153 Mdot
.74145 .01542 Mdot
.74147 .01534 Mdot
.7415 .01569 Mdot
.74152 .0154 Mdot
.74155 .0153 Mdot
.74158 .01609 Mdot
.7416 .01539 Mdot
.74163 .01554 Mdot
.74165 .01576 Mdot
.74168 .01584 Mdot
.74171 .01595 Mdot
.74173 .01567 Mdot
.74176 .01538 Mdot
.74178 .01653 Mdot
.74181 .01555 Mdot
.74183 .01537 Mdot
.74186 .01584 Mdot
.74189 .01534 Mdot
.74191 .01524 Mdot
.74194 .01525 Mdot
.74196 .01606 Mdot
.74199 .01636 Mdot
.74202 .01674 Mdot
.74204 .01648 Mdot
.74207 .01532 Mdot
.74209 .01507 Mdot
.74212 .01624 Mdot
.74214 .01526 Mdot
.74217 .01659 Mdot
.7422 .01551 Mdot
.74222 .01537 Mdot
.74225 .01573 Mdot
.74227 .01511 Mdot
.7423 .01727 Mdot
.74233 .01544 Mdot
.74235 .01583 Mdot
.74238 .01575 Mdot
.7424 .0171 Mdot
.74243 .01509 Mdot
.74246 .01597 Mdot
.74248 .01557 Mdot
.74251 .01527 Mdot
.74253 .01582 Mdot
.74256 .0154 Mdot
.74258 .01674 Mdot
.74261 .01594 Mdot
.74264 .01563 Mdot
.74266 .01522 Mdot
.74269 .01595 Mdot
.74271 .01558 Mdot
.74274 .01587 Mdot
.74277 .01585 Mdot
.74279 .01654 Mdot
.74282 .01525 Mdot
.74284 .0154 Mdot
.74287 .01579 Mdot
.74289 .0155 Mdot
.74292 .01622 Mdot
.74295 .01549 Mdot
.74297 .01584 Mdot
.743 .01724 Mdot
.74302 .0164 Mdot
.74305 .01585 Mdot
.74308 .01567 Mdot
.7431 .01643 Mdot
.74313 .01492 Mdot
.74315 .01517 Mdot
.74318 .01533 Mdot
.7432 .01582 Mdot
.74323 .0163 Mdot
.74326 .01532 Mdot
.74328 .01524 Mdot
.74331 .01648 Mdot
.74333 .01618 Mdot
.74336 .0161 Mdot
.74339 .0153 Mdot
.74341 .01506 Mdot
.74344 .01535 Mdot
.74346 .01533 Mdot
.74349 .0159 Mdot
.74351 .01593 Mdot
.74354 .01556 Mdot
.74357 .01574 Mdot
.74359 .0149 Mdot
.74362 .01509 Mdot
.74364 .01573 Mdot
.74367 .016 Mdot
.7437 .01595 Mdot
.74372 .01556 Mdot
.74375 .01574 Mdot
.74377 .01564 Mdot
.7438 .01602 Mdot
.74382 .01582 Mdot
.74385 .01614 Mdot
.74388 .0156 Mdot
.7439 .01499 Mdot
.74393 .01581 Mdot
.74395 .01635 Mdot
.74398 .01678 Mdot
.74401 .01654 Mdot
.74403 .01503 Mdot
.74406 .01536 Mdot
.74408 .01523 Mdot
.74411 .01558 Mdot
.74413 .01582 Mdot
.74416 .01561 Mdot
.74419 .01619 Mdot
.74421 .01505 Mdot
.74424 .01685 Mdot
.74426 .01538 Mdot
.74429 .01595 Mdot
.74432 .01608 Mdot
.74434 .0153 Mdot
.74437 .01552 Mdot
.74439 .01544 Mdot
.74442 .01597 Mdot
.74444 .0152 Mdot
.74447 .01558 Mdot
.7445 .01588 Mdot
.74452 .0161 Mdot
.74455 .01588 Mdot
.74457 .01517 Mdot
.7446 .01573 Mdot
.74463 .01509 Mdot
.74465 .01581 Mdot
.74468 .01563 Mdot
.7447 .01507 Mdot
.74473 .01595 Mdot
.74475 .01565 Mdot
.74478 .01507 Mdot
.74481 .01532 Mdot
.74483 .01595 Mdot
.74486 .01592 Mdot
.74488 .01653 Mdot
.74491 .01547 Mdot
.74494 .01544 Mdot
.74496 .015 Mdot
.74499 .01617 Mdot
.74501 .01578 Mdot
.74504 .01587 Mdot
.74506 .01517 Mdot
.74509 .01628 Mdot
.74512 .01556 Mdot
.74514 .01582 Mdot
.74517 .01563 Mdot
.74519 .01536 Mdot
.74522 .01525 Mdot
.74525 .01613 Mdot
.74527 .01505 Mdot
.7453 .01546 Mdot
.74532 .01586 Mdot
.74535 .01543 Mdot
.74537 .01525 Mdot
.7454 .01563 Mdot
.74543 .01537 Mdot
.74545 .01569 Mdot
.74548 .01603 Mdot
.7455 .01657 Mdot
.74553 .01562 Mdot
.74556 .0161 Mdot
.74558 .0164 Mdot
.74561 .01557 Mdot
.74563 .01543 Mdot
.74566 .0159 Mdot
.74568 .01654 Mdot
.74571 .01601 Mdot
.74574 .01555 Mdot
.74576 .01481 Mdot
.74579 .01569 Mdot
.74581 .01665 Mdot
.74584 .01555 Mdot
.74587 .01476 Mdot
.74589 .01561 Mdot
.74592 .01542 Mdot
.74594 .01636 Mdot
.74597 .01591 Mdot
.74599 .01537 Mdot
.74602 .0154 Mdot
.74605 .01597 Mdot
.74607 .01545 Mdot
.7461 .01494 Mdot
.74612 .01612 Mdot
.74615 .01535 Mdot
.74618 .01555 Mdot
.7462 .01574 Mdot
.74623 .01655 Mdot
.74625 .01557 Mdot
.74628 .01636 Mdot
.7463 .01597 Mdot
.74633 .01612 Mdot
.74636 .01564 Mdot
.74638 .0156 Mdot
.74641 .01582 Mdot
.74643 .01529 Mdot
.74646 .01547 Mdot
.74649 .01553 Mdot
.74651 .01656 Mdot
.74654 .01545 Mdot
.74656 .01625 Mdot
.74659 .01545 Mdot
.74661 .01593 Mdot
.74664 .01539 Mdot
.74667 .01567 Mdot
.74669 .01654 Mdot
.74672 .01565 Mdot
.74674 .01589 Mdot
.74677 .01608 Mdot
.7468 .01555 Mdot
.74682 .01527 Mdot
.74685 .01536 Mdot
.74687 .01627 Mdot
.7469 .0157 Mdot
.74692 .01545 Mdot
.74695 .01542 Mdot
.74698 .0152 Mdot
.747 .01515 Mdot
.74703 .01564 Mdot
.74705 .01605 Mdot
.74708 .01581 Mdot
.74711 .01657 Mdot
.74713 .01624 Mdot
.74716 .01597 Mdot
.74718 .01553 Mdot
.74721 .01544 Mdot
.74723 .01601 Mdot
.74726 .01687 Mdot
.74729 .01537 Mdot
.74731 .01563 Mdot
.74734 .01599 Mdot
.74736 .01568 Mdot
.74739 .01596 Mdot
.74742 .01564 Mdot
.74744 .01557 Mdot
.74747 .01602 Mdot
.74749 .01637 Mdot
.74752 .01484 Mdot
.74754 .01565 Mdot
.74757 .01652 Mdot
.7476 .01683 Mdot
.74762 .01542 Mdot
.74765 .01538 Mdot
.74767 .01619 Mdot
.7477 .0155 Mdot
.74773 .01696 Mdot
.74775 .01501 Mdot
.74778 .01569 Mdot
.7478 .01519 Mdot
.74783 .01617 Mdot
.74785 .0151 Mdot
.74788 .0153 Mdot
.74791 .01533 Mdot
.74793 .01503 Mdot
.74796 .01675 Mdot
.74798 .01674 Mdot
.74801 .01596 Mdot
.74804 .01666 Mdot
.74806 .01639 Mdot
.74809 .01536 Mdot
.74811 .01505 Mdot
.74814 .01515 Mdot
.74816 .01555 Mdot
.74819 .01528 Mdot
.74822 .01542 Mdot
.74824 .01555 Mdot
.74827 .01499 Mdot
.74829 .01552 Mdot
.74832 .01666 Mdot
.74835 .01516 Mdot
.74837 .01557 Mdot
.7484 .01645 Mdot
.74842 .01658 Mdot
.74845 .01588 Mdot
.74847 .01532 Mdot
.7485 .0154 Mdot
.74853 .01542 Mdot
.74855 .01576 Mdot
.74858 .01488 Mdot
.7486 .0153 Mdot
.74863 .01523 Mdot
.74866 .01561 Mdot
.74868 .01581 Mdot
.74871 .01656 Mdot
.74873 .01552 Mdot
.74876 .01688 Mdot
.74878 .01582 Mdot
.74881 .01477 Mdot
.74884 .01521 Mdot
.74886 .01617 Mdot
.74889 .0151 Mdot
.74891 .01583 Mdot
.74894 .01513 Mdot
.74897 .01556 Mdot
.74899 .01561 Mdot
.74902 .01623 Mdot
.74904 .01518 Mdot
.74907 .0154 Mdot
.74909 .01641 Mdot
.74912 .0164 Mdot
.74915 .01503 Mdot
.74917 .01573 Mdot
.7492 .01529 Mdot
.74922 .01474 Mdot
.74925 .01576 Mdot
.74928 .01554 Mdot
.7493 .01494 Mdot
.74933 .01564 Mdot
.74935 .01553 Mdot
.74938 .01485 Mdot
.7494 .01505 Mdot
.74943 .01497 Mdot
.74946 .01547 Mdot
.74948 .01583 Mdot
.74951 .01498 Mdot
.74953 .01639 Mdot
.74956 .01611 Mdot
.74959 .01662 Mdot
.74961 .01542 Mdot
.74964 .01571 Mdot
.74966 .01655 Mdot
.74969 .016 Mdot
.74971 .01541 Mdot
.74974 .0159 Mdot
.74977 .01617 Mdot
.74979 .01606 Mdot
.74982 .0153 Mdot
.74984 .01506 Mdot
.74987 .01564 Mdot
.7499 .01693 Mdot
.74992 .01505 Mdot
.74995 .01526 Mdot
.74997 .01509 Mdot
.75 .01578 Mdot
.75002 .01616 Mdot
.75005 .01583 Mdot
.75008 .01608 Mdot
.7501 .0151 Mdot
.75013 .01548 Mdot
.75015 .01563 Mdot
.75018 .01501 Mdot
.75021 .01581 Mdot
.75023 .01585 Mdot
.75026 .0161 Mdot
.75028 .01579 Mdot
.75031 .01733 Mdot
.75033 .01575 Mdot
.75036 .01583 Mdot
.75039 .01528 Mdot
.75041 .01554 Mdot
.75044 .01624 Mdot
.75046 .01718 Mdot
.75049 .01485 Mdot
.75052 .01617 Mdot
.75054 .01495 Mdot
.75057 .01589 Mdot
.75059 .01643 Mdot
.75062 .01532 Mdot
.75064 .01554 Mdot
.75067 .01494 Mdot
.7507 .01593 Mdot
.75072 .01609 Mdot
.75075 .01568 Mdot
.75077 .01644 Mdot
.7508 .01658 Mdot
.75083 .01565 Mdot
.75085 .0161 Mdot
.75088 .01492 Mdot
.7509 .01628 Mdot
.75093 .01612 Mdot
.75095 .01493 Mdot
.75098 .01545 Mdot
.75101 .01569 Mdot
.75103 .01695 Mdot
.75106 .01585 Mdot
.75108 .01514 Mdot
.75111 .01577 Mdot
.75114 .01567 Mdot
.75116 .01554 Mdot
.75119 .01628 Mdot
.75121 .01727 Mdot
.75124 .01582 Mdot
.75126 .01657 Mdot
.75129 .01632 Mdot
.75132 .01614 Mdot
.75134 .01568 Mdot
.75137 .01532 Mdot
.75139 .01646 Mdot
.75142 .01565 Mdot
.75145 .01498 Mdot
.75147 .01543 Mdot
.7515 .01543 Mdot
.75152 .01516 Mdot
.75155 .01572 Mdot
.75158 .01508 Mdot
.7516 .01548 Mdot
.75163 .01616 Mdot
.75165 .01513 Mdot
.75168 .01615 Mdot
.7517 .01548 Mdot
.75173 .01565 Mdot
.75176 .01585 Mdot
.75178 .01573 Mdot
.75181 .01524 Mdot
.75183 .01624 Mdot
.75186 .01536 Mdot
.75189 .01661 Mdot
.75191 .0149 Mdot
.75194 .01502 Mdot
.75196 .01572 Mdot
.75199 .01507 Mdot
.75201 .01588 Mdot
.75204 .01569 Mdot
.75207 .01565 Mdot
.75209 .0151 Mdot
.75212 .01627 Mdot
.75214 .01562 Mdot
.75217 .01587 Mdot
.7522 .01509 Mdot
.75222 .01565 Mdot
.75225 .01584 Mdot
.75227 .01501 Mdot
.7523 .01499 Mdot
.75232 .01519 Mdot
.75235 .01512 Mdot
.75238 .01615 Mdot
.7524 .0159 Mdot
.75243 .01605 Mdot
.75245 .01569 Mdot
.75248 .01584 Mdot
.75251 .01543 Mdot
.75253 .01528 Mdot
.75256 .01614 Mdot
.75258 .01518 Mdot
.75261 .01559 Mdot
.75263 .01681 Mdot
.75266 .01537 Mdot
.75269 .01498 Mdot
.75271 .01651 Mdot
.75274 .01645 Mdot
.75276 .01567 Mdot
.75279 .01581 Mdot
.75282 .01561 Mdot
.75284 .01566 Mdot
.75287 .01525 Mdot
.75289 .01547 Mdot
.75292 .01559 Mdot
.75294 .01635 Mdot
.75297 .01582 Mdot
.753 .01604 Mdot
.75302 .01678 Mdot
.75305 .01708 Mdot
.75307 .0168 Mdot
.7531 .01549 Mdot
.75313 .01508 Mdot
.75315 .01563 Mdot
.75318 .01658 Mdot
.7532 .01546 Mdot
.75323 .0152 Mdot
.75325 .01547 Mdot
.75328 .01592 Mdot
.75331 .01588 Mdot
.75333 .01514 Mdot
.75336 .01484 Mdot
.75338 .01499 Mdot
.75341 .01559 Mdot
.75344 .01627 Mdot
.75346 .01626 Mdot
.75349 .01569 Mdot
.75351 .0154 Mdot
.75354 .01604 Mdot
.75356 .01654 Mdot
.75359 .01568 Mdot
.75362 .01485 Mdot
.75364 .01582 Mdot
.75367 .01577 Mdot
.75369 .01607 Mdot
.75372 .01576 Mdot
.75375 .0162 Mdot
.75377 .015 Mdot
.7538 .01602 Mdot
.75382 .01578 Mdot
.75385 .01607 Mdot
.75387 .01539 Mdot
.7539 .01509 Mdot
.75393 .01513 Mdot
.75395 .01526 Mdot
.75398 .01597 Mdot
.754 .01482 Mdot
.75403 .01544 Mdot
.75406 .01651 Mdot
.75408 .01571 Mdot
.75411 .01597 Mdot
.75413 .01526 Mdot
.75416 .01603 Mdot
.75418 .01569 Mdot
.75421 .01513 Mdot
.75424 .01494 Mdot
.75426 .01499 Mdot
.75429 .01588 Mdot
.75431 .01597 Mdot
.75434 .01569 Mdot
.75437 .0153 Mdot
.75439 .01629 Mdot
.75442 .01605 Mdot
.75444 .01669 Mdot
.75447 .01525 Mdot
.75449 .01622 Mdot
.75452 .01587 Mdot
.75455 .01552 Mdot
.75457 .01556 Mdot
.7546 .01589 Mdot
.75462 .01599 Mdot
.75465 .01574 Mdot
.75468 .01522 Mdot
.7547 .01519 Mdot
.75473 .0166 Mdot
.75475 .01703 Mdot
.75478 .01582 Mdot
.7548 .01504 Mdot
.75483 .01569 Mdot
.75486 .01556 Mdot
.75488 .01588 Mdot
.75491 .01684 Mdot
.75493 .01552 Mdot
.75496 .01568 Mdot
.75499 .01659 Mdot
.75501 .01592 Mdot
.75504 .01509 Mdot
.75506 .01581 Mdot
.75509 .01618 Mdot
.75511 .01591 Mdot
.75514 .01577 Mdot
.75517 .01633 Mdot
.75519 .01521 Mdot
.75522 .0158 Mdot
.75524 .01766 Mdot
.75527 .01575 Mdot
.7553 .01589 Mdot
.75532 .01516 Mdot
.75535 .0183 Mdot
.75537 .01524 Mdot
.7554 .01503 Mdot
.75542 .01635 Mdot
.75545 .01664 Mdot
.75548 .01598 Mdot
.7555 .01717 Mdot
.75553 .01535 Mdot
.75555 .01529 Mdot
.75558 .01515 Mdot
.75561 .01637 Mdot
.75563 .0154 Mdot
.75566 .01601 Mdot
.75568 .01602 Mdot
.75571 .01543 Mdot
.75573 .01634 Mdot
.75576 .0151 Mdot
.75579 .01506 Mdot
.75581 .01517 Mdot
.75584 .01623 Mdot
.75586 .01601 Mdot
.75589 .01699 Mdot
.75592 .0154 Mdot
.75594 .01505 Mdot
.75597 .01576 Mdot
.75599 .01645 Mdot
.75602 .01554 Mdot
.75604 .01519 Mdot
.75607 .01548 Mdot
.7561 .01532 Mdot
.75612 .01501 Mdot
.75615 .0162 Mdot
.75617 .01519 Mdot
.7562 .01643 Mdot
.75623 .01632 Mdot
.75625 .01503 Mdot
.75628 .01547 Mdot
.7563 .01483 Mdot
.75633 .01483 Mdot
.75635 .01541 Mdot
.75638 .01591 Mdot
.75641 .01583 Mdot
.75643 .01501 Mdot
.75646 .01565 Mdot
.75648 .01581 Mdot
.75651 .01495 Mdot
.75654 .01562 Mdot
.75656 .01564 Mdot
.75659 .01568 Mdot
.75661 .01511 Mdot
.75664 .01667 Mdot
.75666 .01592 Mdot
.75669 .01659 Mdot
.75672 .01528 Mdot
.75674 .01581 Mdot
.75677 .01536 Mdot
.75679 .01632 Mdot
.75682 .01546 Mdot
.75685 .01555 Mdot
.75687 .01521 Mdot
.7569 .01654 Mdot
.75692 .0159 Mdot
.75695 .01557 Mdot
.75697 .01689 Mdot
.757 .01729 Mdot
.75703 .01495 Mdot
.75705 .01531 Mdot
.75708 .01482 Mdot
.7571 .01602 Mdot
.75713 .01549 Mdot
.75716 .01554 Mdot
.75718 .0155 Mdot
.75721 .01522 Mdot
.75723 .0167 Mdot
.75726 .01507 Mdot
.75728 .01566 Mdot
.75731 .01501 Mdot
.75734 .01583 Mdot
.75736 .01658 Mdot
.75739 .01605 Mdot
.75741 .0154 Mdot
.75744 .01604 Mdot
.75747 .0154 Mdot
.75749 .0161 Mdot
.75752 .01632 Mdot
.75754 .01513 Mdot
.75757 .01551 Mdot
.75759 .01613 Mdot
.75762 .01501 Mdot
.75765 .01559 Mdot
.75767 .01586 Mdot
.7577 .01625 Mdot
.75772 .01548 Mdot
.75775 .01551 Mdot
.75778 .01529 Mdot
.7578 .0164 Mdot
.75783 .0153 Mdot
.75785 .01535 Mdot
.75788 .01638 Mdot
.7579 .01487 Mdot
.75793 .01557 Mdot
.75796 .01477 Mdot
.75798 .01548 Mdot
.75801 .01513 Mdot
.75803 .01498 Mdot
.75806 .01607 Mdot
.75809 .01649 Mdot
.75811 .01607 Mdot
.75814 .01515 Mdot
.75816 .01533 Mdot
.75819 .01522 Mdot
.75821 .01527 Mdot
.75824 .01638 Mdot
.75827 .01661 Mdot
.75829 .0152 Mdot
.75832 .01495 Mdot
.75834 .01579 Mdot
.75837 .01495 Mdot
.7584 .01595 Mdot
.75842 .01567 Mdot
.75845 .01505 Mdot
.75847 .016 Mdot
.7585 .01619 Mdot
.75852 .01489 Mdot
.75855 .0162 Mdot
.75858 .01537 Mdot
.7586 .01524 Mdot
.75863 .01516 Mdot
.75865 .01636 Mdot
.75868 .01578 Mdot
.75871 .01475 Mdot
.75873 .01654 Mdot
.75876 .01627 Mdot
.75878 .01513 Mdot
.75881 .01513 Mdot
.75883 .01486 Mdot
.75886 .01558 Mdot
.75889 .01606 Mdot
.75891 .01584 Mdot
.75894 .01614 Mdot
.75896 .01548 Mdot
.75899 .01566 Mdot
.75902 .0158 Mdot
.75904 .01555 Mdot
.75907 .01682 Mdot
.75909 .01618 Mdot
.75912 .0161 Mdot
.75914 .01747 Mdot
.75917 .01514 Mdot
.7592 .01509 Mdot
.75922 .01504 Mdot
.75925 .01549 Mdot
.75927 .01529 Mdot
.7593 .01607 Mdot
.75933 .01569 Mdot
.75935 .01529 Mdot
.75938 .01584 Mdot
.7594 .01603 Mdot
.75943 .01554 Mdot
.75945 .016 Mdot
.75948 .01506 Mdot
.75951 .01541 Mdot
.75953 .01527 Mdot
.75956 .0154 Mdot
.75958 .01631 Mdot
.75961 .01513 Mdot
.75964 .01721 Mdot
.75966 .01741 Mdot
.75969 .01548 Mdot
.75971 .01536 Mdot
.75974 .01649 Mdot
.75976 .01579 Mdot
.75979 .0166 Mdot
.75982 .01552 Mdot
.75984 .01516 Mdot
.75987 .01619 Mdot
.75989 .01516 Mdot
.75992 .01474 Mdot
.75995 .01578 Mdot
.75997 .01589 Mdot
.76 .01525 Mdot
.76002 .01596 Mdot
.76005 .01671 Mdot
.76007 .01521 Mdot
.7601 .01567 Mdot
.76013 .0159 Mdot
.76015 .01589 Mdot
.76018 .01517 Mdot
.7602 .01494 Mdot
.76023 .01596 Mdot
.76026 .01484 Mdot
.76028 .0158 Mdot
.76031 .01541 Mdot
.76033 .01509 Mdot
.76036 .01624 Mdot
.76038 .01562 Mdot
.76041 .01554 Mdot
.76044 .01484 Mdot
.76046 .01539 Mdot
.76049 .01683 Mdot
.76051 .01568 Mdot
.76054 .01583 Mdot
.76057 .01514 Mdot
.76059 .01606 Mdot
.76062 .01562 Mdot
.76064 .01639 Mdot
.76067 .01558 Mdot
.7607 .01662 Mdot
.76072 .01525 Mdot
.76075 .01597 Mdot
.76077 .01522 Mdot
.7608 .0151 Mdot
.76082 .01547 Mdot
.76085 .01589 Mdot
.76088 .01538 Mdot
.7609 .01648 Mdot
.76093 .01584 Mdot
.76095 .01646 Mdot
.76098 .01571 Mdot
.76101 .01478 Mdot
.76103 .01508 Mdot
.76106 .01509 Mdot
.76108 .01575 Mdot
.76111 .01527 Mdot
.76113 .01515 Mdot
.76116 .01629 Mdot
.76119 .01624 Mdot
.76121 .0158 Mdot
.76124 .01683 Mdot
.76126 .01554 Mdot
.76129 .01575 Mdot
.76132 .01575 Mdot
.76134 .01564 Mdot
.76137 .01528 Mdot
.76139 .01539 Mdot
.76142 .0158 Mdot
.76144 .01634 Mdot
.76147 .01564 Mdot
.7615 .01592 Mdot
.76152 .01628 Mdot
.76155 .01528 Mdot
.76157 .01683 Mdot
.7616 .01624 Mdot
.76163 .01569 Mdot
.76165 .01618 Mdot
.76168 .01537 Mdot
.7617 .01554 Mdot
.76173 .01662 Mdot
.76175 .0155 Mdot
.76178 .01548 Mdot
.76181 .01652 Mdot
.76183 .01555 Mdot
.76186 .01622 Mdot
.76188 .0151 Mdot
.76191 .0161 Mdot
.76194 .01492 Mdot
.76196 .0158 Mdot
.76199 .01498 Mdot
.76201 .01579 Mdot
.76204 .01558 Mdot
.76206 .01591 Mdot
.76209 .01527 Mdot
.76212 .01632 Mdot
.76214 .01519 Mdot
.76217 .01579 Mdot
.76219 .01557 Mdot
.76222 .01547 Mdot
.76225 .01529 Mdot
.76227 .01579 Mdot
.7623 .01574 Mdot
.76232 .01545 Mdot
.76235 .0155 Mdot
.76237 .01504 Mdot
.7624 .01565 Mdot
.76243 .01662 Mdot
.76245 .01586 Mdot
.76248 .0156 Mdot
.7625 .01558 Mdot
.76253 .01523 Mdot
.76256 .01552 Mdot
.76258 .01643 Mdot
.76261 .01704 Mdot
.76263 .01547 Mdot
.76266 .01526 Mdot
.76268 .01625 Mdot
.76271 .01576 Mdot
.76274 .01562 Mdot
.76276 .01504 Mdot
.76279 .0154 Mdot
.76281 .01509 Mdot
.76284 .01609 Mdot
.76287 .01572 Mdot
.76289 .01528 Mdot
.76292 .01642 Mdot
.76294 .01547 Mdot
.76297 .01573 Mdot
.76299 .017 Mdot
.76302 .01689 Mdot
.76305 .01633 Mdot
.76307 .01603 Mdot
.7631 .015 Mdot
.76312 .01532 Mdot
.76315 .01766 Mdot
.76318 .01583 Mdot
.7632 .01601 Mdot
.76323 .01596 Mdot
.76325 .01522 Mdot
.76328 .0154 Mdot
.7633 .01595 Mdot
.76333 .01599 Mdot
.76336 .01505 Mdot
.76338 .01517 Mdot
.76341 .0151 Mdot
.76343 .01585 Mdot
.76346 .01522 Mdot
.76349 .01614 Mdot
.76351 .01562 Mdot
.76354 .01524 Mdot
.76356 .01573 Mdot
.76359 .01539 Mdot
.76361 .01662 Mdot
.76364 .01511 Mdot
.76367 .01554 Mdot
.76369 .0154 Mdot
.76372 .01559 Mdot
.76374 .01509 Mdot
.76377 .01528 Mdot
.7638 .01545 Mdot
.76382 .01506 Mdot
.76385 .01578 Mdot
.76387 .0155 Mdot
.7639 .01597 Mdot
.76392 .01493 Mdot
.76395 .01529 Mdot
.76398 .01557 Mdot
.764 .01517 Mdot
.76403 .01617 Mdot
.76405 .01631 Mdot
.76408 .01558 Mdot
.76411 .01572 Mdot
.76413 .01592 Mdot
.76416 .01569 Mdot
.76418 .01761 Mdot
.76421 .01521 Mdot
.76423 .0163 Mdot
.76426 .01641 Mdot
.76429 .01575 Mdot
.76431 .015 Mdot
.76434 .01473 Mdot
.76436 .0153 Mdot
.76439 .01511 Mdot
.76442 .01606 Mdot
.76444 .01667 Mdot
.76447 .0163 Mdot
.76449 .01533 Mdot
.76452 .01569 Mdot
.76454 .01574 Mdot
.76457 .01614 Mdot
.7646 .01576 Mdot
.76462 .01672 Mdot
.76465 .01571 Mdot
.76467 .0158 Mdot
.7647 .01582 Mdot
.76473 .01582 Mdot
.76475 .01579 Mdot
.76478 .01494 Mdot
.7648 .01517 Mdot
.76483 .01619 Mdot
.76485 .01504 Mdot
.76488 .0157 Mdot
.76491 .01609 Mdot
.76493 .01629 Mdot
.76496 .01527 Mdot
.76498 .01628 Mdot
.76501 .01514 Mdot
.76504 .01575 Mdot
.76506 .01515 Mdot
.76509 .01704 Mdot
.76511 .01506 Mdot
.76514 .01556 Mdot
.76516 .01632 Mdot
.76519 .01591 Mdot
.76522 .01619 Mdot
.76524 .01545 Mdot
.76527 .01587 Mdot
.76529 .0155 Mdot
.76532 .01499 Mdot
.76535 .01502 Mdot
.76537 .01636 Mdot
.7654 .01588 Mdot
.76542 .0157 Mdot
.76545 .01566 Mdot
.76547 .01552 Mdot
.7655 .01627 Mdot
.76553 .01611 Mdot
.76555 .0155 Mdot
.76558 .01568 Mdot
.7656 .0151 Mdot
.76563 .0153 Mdot
.76566 .015 Mdot
.76568 .0163 Mdot
.76571 .01584 Mdot
.76573 .01526 Mdot
.76576 .01521 Mdot
.76578 .01619 Mdot
.76581 .01564 Mdot
.76584 .01643 Mdot
.76586 .01525 Mdot
.76589 .01501 Mdot
.76591 .01564 Mdot
.76594 .01512 Mdot
.76597 .01567 Mdot
.76599 .01551 Mdot
.76602 .01552 Mdot
.76604 .01668 Mdot
.76607 .01678 Mdot
.76609 .01563 Mdot
.76612 .01675 Mdot
.76615 .01562 Mdot
.76617 .01633 Mdot
.7662 .01585 Mdot
.76622 .01591 Mdot
.76625 .01571 Mdot
.76628 .01611 Mdot
.7663 .01733 Mdot
.76633 .01518 Mdot
.76635 .01616 Mdot
.76638 .01637 Mdot
.7664 .01516 Mdot
.76643 .01531 Mdot
.76646 .01513 Mdot
.76648 .01576 Mdot
.76651 .01603 Mdot
.76653 .01541 Mdot
.76656 .0155 Mdot
.76659 .01505 Mdot
.76661 .01544 Mdot
.76664 .01512 Mdot
.76666 .01571 Mdot
.76669 .01662 Mdot
.76671 .01575 Mdot
.76674 .01511 Mdot
.76677 .01598 Mdot
.76679 .01486 Mdot
.76682 .01492 Mdot
.76684 .01578 Mdot
.76687 .01537 Mdot
.7669 .01637 Mdot
.76692 .01515 Mdot
.76695 .01502 Mdot
.76697 .01563 Mdot
.767 .01532 Mdot
.76702 .0164 Mdot
.76705 .01531 Mdot
.76708 .01623 Mdot
.7671 .01497 Mdot
.76713 .0175 Mdot
.76715 .0168 Mdot
.76718 .01584 Mdot
.76721 .01567 Mdot
.76723 .01531 Mdot
.76726 .01583 Mdot
.76728 .01665 Mdot
.76731 .01554 Mdot
.76733 .01561 Mdot
.76736 .0165 Mdot
.76739 .0165 Mdot
.76741 .0153 Mdot
.76744 .01521 Mdot
.76746 .01698 Mdot
.76749 .01575 Mdot
.76752 .01549 Mdot
.76754 .015 Mdot
.76757 .01598 Mdot
.76759 .01568 Mdot
.76762 .01548 Mdot
.76764 .01547 Mdot
.76767 .015 Mdot
.7677 .01513 Mdot
.76772 .01633 Mdot
.76775 .0152 Mdot
.76777 .01539 Mdot
.7678 .01607 Mdot
.76783 .01639 Mdot
.76785 .01506 Mdot
.76788 .0154 Mdot
.7679 .01605 Mdot
.76793 .01606 Mdot
.76795 .01516 Mdot
.76798 .01628 Mdot
.76801 .01733 Mdot
.76803 .01601 Mdot
.76806 .01516 Mdot
.76808 .01632 Mdot
.76811 .01547 Mdot
.76814 .01495 Mdot
.76816 .01536 Mdot
.76819 .01617 Mdot
.76821 .0154 Mdot
.76824 .01628 Mdot
.76826 .0153 Mdot
.76829 .01486 Mdot
.76832 .01608 Mdot
.76834 .01601 Mdot
.76837 .01577 Mdot
.76839 .01552 Mdot
.76842 .01491 Mdot
.76845 .01556 Mdot
.76847 .01731 Mdot
.7685 .01575 Mdot
.76852 .01612 Mdot
.76855 .01606 Mdot
.76857 .01564 Mdot
.7686 .01572 Mdot
.76863 .01556 Mdot
.76865 .01529 Mdot
.76868 .01566 Mdot
.7687 .01602 Mdot
.76873 .01678 Mdot
.76876 .01616 Mdot
.76878 .01536 Mdot
.76881 .01694 Mdot
.76883 .01543 Mdot
.76886 .01686 Mdot
.76888 .01612 Mdot
.76891 .01583 Mdot
.76894 .01592 Mdot
.76896 .01629 Mdot
.76899 .01567 Mdot
.76901 .01697 Mdot
.76904 .01653 Mdot
.76907 .01595 Mdot
.76909 .01501 Mdot
.76912 .01473 Mdot
.76914 .01521 Mdot
.76917 .01546 Mdot
.76919 .01559 Mdot
.76922 .0155 Mdot
.76925 .01536 Mdot
.76927 .01515 Mdot
.7693 .01706 Mdot
.76932 .01577 Mdot
.76935 .01573 Mdot
.76938 .01521 Mdot
.7694 .01587 Mdot
.76943 .01536 Mdot
.76945 .01664 Mdot
.76948 .01543 Mdot
.7695 .01528 Mdot
.76953 .0156 Mdot
.76956 .01525 Mdot
.76958 .01634 Mdot
.76961 .0157 Mdot
.76963 .0154 Mdot
.76966 .01588 Mdot
.76969 .01586 Mdot
.76971 .01561 Mdot
.76974 .01542 Mdot
.76976 .01601 Mdot
.76979 .01486 Mdot
.76982 .01648 Mdot
.76984 .01696 Mdot
.76987 .01632 Mdot
.76989 .01582 Mdot
.76992 .01517 Mdot
.76994 .0156 Mdot
.76997 .01651 Mdot
.77 .01554 Mdot
.77002 .01533 Mdot
.77005 .01533 Mdot
.77007 .01564 Mdot
.7701 .01561 Mdot
.77013 .01578 Mdot
.77015 .0167 Mdot
.77018 .01496 Mdot
.7702 .01562 Mdot
.77023 .01609 Mdot
.77025 .0167 Mdot
.77028 .01535 Mdot
.77031 .01566 Mdot
.77033 .01593 Mdot
.77036 .01594 Mdot
.77038 .01747 Mdot
.77041 .01713 Mdot
.77044 .01533 Mdot
.77046 .01528 Mdot
.77049 .01664 Mdot
.77051 .01576 Mdot
.77054 .01649 Mdot
.77056 .01582 Mdot
.77059 .01561 Mdot
.77062 .0157 Mdot
.77064 .01525 Mdot
.77067 .01543 Mdot
.77069 .01606 Mdot
.77072 .01647 Mdot
.77075 .01686 Mdot
.77077 .01611 Mdot
.7708 .01565 Mdot
.77082 .01515 Mdot
.77085 .015 Mdot
.77087 .0151 Mdot
.7709 .01569 Mdot
.77093 .01542 Mdot
.77095 .01514 Mdot
.77098 .01678 Mdot
.771 .01513 Mdot
.77103 .01579 Mdot
.77106 .01587 Mdot
.77108 .01584 Mdot
.77111 .01572 Mdot
.77113 .01582 Mdot
.77116 .01662 Mdot
.77118 .01527 Mdot
.77121 .01571 Mdot
.77124 .0159 Mdot
.77126 .01653 Mdot
.77129 .01538 Mdot
.77131 .01661 Mdot
.77134 .01538 Mdot
.77137 .01654 Mdot
.77139 .01582 Mdot
.77142 .01542 Mdot
.77144 .01684 Mdot
.77147 .01522 Mdot
.77149 .01501 Mdot
.77152 .01568 Mdot
.77155 .016 Mdot
.77157 .01636 Mdot
.7716 .01495 Mdot
.77162 .01601 Mdot
.77165 .01566 Mdot
.77168 .01533 Mdot
.7717 .01654 Mdot
.77173 .01549 Mdot
.77175 .01665 Mdot
.77178 .01566 Mdot
.7718 .01607 Mdot
.77183 .01485 Mdot
.77186 .01517 Mdot
.77188 .01479 Mdot
.77191 .01541 Mdot
.77193 .01611 Mdot
.77196 .01689 Mdot
.77199 .01502 Mdot
.77201 .01531 Mdot
.77204 .01523 Mdot
.77206 .01621 Mdot
.77209 .01521 Mdot
.77211 .01609 Mdot
.77214 .01548 Mdot
.77217 .01576 Mdot
.77219 .01595 Mdot
.77222 .01657 Mdot
.77224 .01577 Mdot
.77227 .01516 Mdot
.7723 .01598 Mdot
.77232 .01553 Mdot
.77235 .01569 Mdot
.77237 .01649 Mdot
.7724 .01577 Mdot
.77242 .01533 Mdot
.77245 .01517 Mdot
.77248 .01604 Mdot
.7725 .01586 Mdot
.77253 .01549 Mdot
.77255 .01544 Mdot
.77258 .01553 Mdot
.77261 .01552 Mdot
.77263 .01536 Mdot
.77266 .01565 Mdot
.77268 .01576 Mdot
.77271 .0152 Mdot
.77273 .01779 Mdot
.77276 .01681 Mdot
.77279 .0161 Mdot
.77281 .01585 Mdot
.77284 .01552 Mdot
.77286 .01503 Mdot
.77289 .01522 Mdot
.77292 .01599 Mdot
.77294 .01495 Mdot
.77297 .01575 Mdot
.77299 .01552 Mdot
.77302 .01544 Mdot
.77304 .0155 Mdot
.77307 .01628 Mdot
.7731 .0158 Mdot
.77312 .01546 Mdot
.77315 .01543 Mdot
.77317 .01671 Mdot
.7732 .01584 Mdot
.77323 .01634 Mdot
.77325 .0154 Mdot
.77328 .0151 Mdot
.7733 .01657 Mdot
.77333 .01645 Mdot
.77335 .01714 Mdot
.77338 .01677 Mdot
.77341 .01587 Mdot
.77343 .01591 Mdot
.77346 .01573 Mdot
.77348 .01644 Mdot
.77351 .01603 Mdot
.77354 .01591 Mdot
.77356 .01486 Mdot
.77359 .015 Mdot
.77361 .01651 Mdot
.77364 .01629 Mdot
.77366 .0162 Mdot
.77369 .01505 Mdot
.77372 .01481 Mdot
.77374 .01504 Mdot
.77377 .01557 Mdot
.77379 .0168 Mdot
.77382 .01571 Mdot
.77385 .01526 Mdot
.77387 .01623 Mdot
.7739 .01536 Mdot
.77392 .01579 Mdot
.77395 .01608 Mdot
.77397 .0154 Mdot
.774 .01583 Mdot
.77403 .01628 Mdot
.77405 .01569 Mdot
.77408 .01558 Mdot
.7741 .01564 Mdot
.77413 .01569 Mdot
.77416 .0152 Mdot
.77418 .01585 Mdot
.77421 .01723 Mdot
.77423 .01569 Mdot
.77426 .01526 Mdot
.77428 .0164 Mdot
.77431 .0162 Mdot
.77434 .01581 Mdot
.77436 .01591 Mdot
.77439 .01601 Mdot
.77441 .01683 Mdot
.77444 .01542 Mdot
.77447 .01652 Mdot
.77449 .01645 Mdot
.77452 .0157 Mdot
.77454 .0167 Mdot
.77457 .01587 Mdot
.77459 .01545 Mdot
.77462 .01551 Mdot
.77465 .01517 Mdot
.77467 .01588 Mdot
.7747 .01519 Mdot
.77472 .01545 Mdot
.77475 .01578 Mdot
.77478 .01543 Mdot
.7748 .01634 Mdot
.77483 .01535 Mdot
.77485 .01563 Mdot
.77488 .01506 Mdot
.7749 .01544 Mdot
.77493 .01551 Mdot
.77496 .01634 Mdot
.77498 .0157 Mdot
.77501 .01614 Mdot
.77503 .01527 Mdot
.77506 .01562 Mdot
.77509 .0161 Mdot
.77511 .01583 Mdot
.77514 .01609 Mdot
.77516 .0155 Mdot
.77519 .01834 Mdot
.77521 .01614 Mdot
.77524 .0151 Mdot
.77527 .01599 Mdot
.77529 .01515 Mdot
.77532 .01559 Mdot
.77534 .01509 Mdot
.77537 .01562 Mdot
.7754 .01637 Mdot
.77542 .01503 Mdot
.77545 .01589 Mdot
.77547 .01581 Mdot
.7755 .01592 Mdot
.77552 .01574 Mdot
.77555 .0165 Mdot
.77558 .01616 Mdot
.7756 .01599 Mdot
.77563 .01559 Mdot
.77565 .01587 Mdot
.77568 .01519 Mdot
.77571 .01495 Mdot
.77573 .01524 Mdot
.77576 .0165 Mdot
.77578 .01573 Mdot
.77581 .01553 Mdot
.77583 .01635 Mdot
.77586 .0164 Mdot
.77589 .01521 Mdot
.77591 .01599 Mdot
.77594 .01601 Mdot
.77596 .01516 Mdot
.77599 .01566 Mdot
.77602 .01733 Mdot
.77604 .01582 Mdot
.77607 .0155 Mdot
.77609 .01552 Mdot
.77612 .01552 Mdot
.77614 .01586 Mdot
.77617 .01552 Mdot
.7762 .0152 Mdot
.77622 .01552 Mdot
.77625 .01536 Mdot
.77627 .0157 Mdot
.7763 .01511 Mdot
.77633 .01585 Mdot
.77635 .01538 Mdot
.77638 .01635 Mdot
.7764 .01512 Mdot
.77643 .01534 Mdot
.77645 .01608 Mdot
.77648 .01566 Mdot
.77651 .01573 Mdot
.77653 .01608 Mdot
.77656 .01588 Mdot
.77658 .01629 Mdot
.77661 .01627 Mdot
.77664 .01556 Mdot
.77666 .01569 Mdot
.77669 .01569 Mdot
.77671 .01581 Mdot
.77674 .0157 Mdot
.77676 .01547 Mdot
.77679 .01537 Mdot
.77682 .01617 Mdot
.77684 .01554 Mdot
.77687 .01554 Mdot
.77689 .01539 Mdot
.77692 .01509 Mdot
.77695 .0148 Mdot
.77697 .01638 Mdot
.777 .01611 Mdot
.77702 .01588 Mdot
.77705 .01578 Mdot
.77707 .01607 Mdot
.7771 .01549 Mdot
.77713 .01537 Mdot
.77715 .01652 Mdot
.77718 .01681 Mdot
.7772 .01675 Mdot
.77723 .01546 Mdot
.77726 .01685 Mdot
.77728 .015 Mdot
.77731 .01546 Mdot
.77733 .01602 Mdot
.77736 .01651 Mdot
.77738 .01505 Mdot
.77741 .01547 Mdot
.77744 .01614 Mdot
.77746 .01607 Mdot
.77749 .01584 Mdot
.77751 .0157 Mdot
.77754 .01525 Mdot
.77757 .01641 Mdot
.77759 .01543 Mdot
.77762 .01491 Mdot
.77764 .01503 Mdot
.77767 .01662 Mdot
.77769 .0162 Mdot
.77772 .01676 Mdot
.77775 .01605 Mdot
.77777 .01585 Mdot
.7778 .01596 Mdot
.77782 .01555 Mdot
.77785 .0163 Mdot
.77788 .01498 Mdot
.7779 .01662 Mdot
.77793 .01493 Mdot
.77795 .01653 Mdot
.77798 .01605 Mdot
.778 .01662 Mdot
.77803 .01588 Mdot
.77806 .01539 Mdot
.77808 .01523 Mdot
.77811 .0153 Mdot
.77813 .01586 Mdot
.77816 .01499 Mdot
.77819 .01585 Mdot
.77821 .01557 Mdot
.77824 .01645 Mdot
.77826 .01672 Mdot
.77829 .0179 Mdot
.77831 .01604 Mdot
.77834 .01535 Mdot
.77837 .01561 Mdot
.77839 .01536 Mdot
.77842 .01555 Mdot
.77844 .01616 Mdot
.77847 .01499 Mdot
.7785 .01643 Mdot
.77852 .01553 Mdot
.77855 .01567 Mdot
.77857 .01612 Mdot
.7786 .01632 Mdot
.77862 .01582 Mdot
.77865 .01503 Mdot
.77868 .016 Mdot
.7787 .01574 Mdot
.77873 .01533 Mdot
.77875 .01611 Mdot
.77878 .01533 Mdot
.77881 .01566 Mdot
.77883 .01561 Mdot
.77886 .01531 Mdot
.77888 .01615 Mdot
.77891 .01606 Mdot
.77894 .0154 Mdot
.77896 .01608 Mdot
.77899 .01617 Mdot
.77901 .01639 Mdot
.77904 .01534 Mdot
.77906 .016 Mdot
.77909 .01487 Mdot
.77912 .01512 Mdot
.77914 .01601 Mdot
.77917 .01504 Mdot
.77919 .01482 Mdot
.77922 .01517 Mdot
.77925 .01631 Mdot
.77927 .01587 Mdot
.7793 .016 Mdot
.77932 .0155 Mdot
.77935 .01506 Mdot
.77937 .01514 Mdot
.7794 .01601 Mdot
.77943 .01542 Mdot
.77945 .01648 Mdot
.77948 .01531 Mdot
.7795 .01563 Mdot
.77953 .01565 Mdot
.77956 .01539 Mdot
.77958 .01627 Mdot
.77961 .01538 Mdot
.77963 .01613 Mdot
.77966 .01551 Mdot
.77968 .0153 Mdot
.77971 .01688 Mdot
.77974 .01551 Mdot
.77976 .01499 Mdot
.77979 .01608 Mdot
.77981 .01541 Mdot
.77984 .0154 Mdot
.77987 .01549 Mdot
.77989 .01511 Mdot
.77992 .0156 Mdot
.77994 .01521 Mdot
.77997 .01567 Mdot
.77999 .01572 Mdot
.78002 .01502 Mdot
.78005 .01492 Mdot
.78007 .01527 Mdot
.7801 .01538 Mdot
.78012 .01561 Mdot
.78015 .01539 Mdot
.78018 .01685 Mdot
.7802 .01497 Mdot
.78023 .01539 Mdot
.78025 .01562 Mdot
.78028 .01531 Mdot
.7803 .01591 Mdot
.78033 .01575 Mdot
.78036 .01641 Mdot
.78038 .01501 Mdot
.78041 .01744 Mdot
.78043 .01599 Mdot
.78046 .01524 Mdot
.78049 .01632 Mdot
.78051 .0159 Mdot
.78054 .01592 Mdot
.78056 .01584 Mdot
.78059 .01591 Mdot
.78061 .01605 Mdot
.78064 .01572 Mdot
.78067 .01551 Mdot
.78069 .01583 Mdot
.78072 .01512 Mdot
.78074 .01479 Mdot
.78077 .01643 Mdot
.7808 .01576 Mdot
.78082 .01484 Mdot
.78085 .01513 Mdot
.78087 .01534 Mdot
.7809 .0164 Mdot
.78092 .01543 Mdot
.78095 .01614 Mdot
.78098 .0157 Mdot
.781 .01555 Mdot
.78103 .01651 Mdot
.78105 .01622 Mdot
.78108 .01703 Mdot
.78111 .01524 Mdot
.78113 .01654 Mdot
.78116 .01483 Mdot
.78118 .01554 Mdot
.78121 .01475 Mdot
.78123 .01506 Mdot
.78126 .01634 Mdot
.78129 .01608 Mdot
.78131 .01508 Mdot
.78134 .0152 Mdot
.78136 .01536 Mdot
.78139 .01502 Mdot
.78142 .01588 Mdot
.78144 .01544 Mdot
.78147 .01585 Mdot
.78149 .01552 Mdot
.78152 .01678 Mdot
.78154 .01493 Mdot
.78157 .01531 Mdot
.7816 .01544 Mdot
.78162 .01512 Mdot
.78165 .01601 Mdot
.78167 .01522 Mdot
.7817 .01579 Mdot
.78173 .01692 Mdot
.78175 .01516 Mdot
.78178 .0164 Mdot
.7818 .0158 Mdot
.78183 .01534 Mdot
.78185 .01583 Mdot
.78188 .01665 Mdot
.78191 .01538 Mdot
.78193 .01529 Mdot
.78196 .01546 Mdot
.78198 .016 Mdot
.78201 .01509 Mdot
.78204 .01493 Mdot
.78206 .01549 Mdot
.78209 .01614 Mdot
.78211 .0153 Mdot
.78214 .01624 Mdot
.78216 .01683 Mdot
.78219 .015 Mdot
.78222 .01578 Mdot
.78224 .01525 Mdot
.78227 .01574 Mdot
.78229 .01533 Mdot
.78232 .01591 Mdot
.78235 .01664 Mdot
.78237 .01534 Mdot
.7824 .01579 Mdot
.78242 .01655 Mdot
.78245 .01559 Mdot
.78247 .01548 Mdot
.7825 .01581 Mdot
.78253 .01602 Mdot
.78255 .01632 Mdot
.78258 .01573 Mdot
.7826 .01632 Mdot
.78263 .01699 Mdot
.78266 .01538 Mdot
.78268 .01629 Mdot
.78271 .01583 Mdot
.78273 .01555 Mdot
.78276 .01627 Mdot
.78278 .01565 Mdot
.78281 .01587 Mdot
.78284 .01494 Mdot
.78286 .01516 Mdot
.78289 .01536 Mdot
.78291 .0149 Mdot
.78294 .01656 Mdot
.78297 .01598 Mdot
.78299 .01554 Mdot
.78302 .01485 Mdot
.78304 .01588 Mdot
.78307 .01606 Mdot
.78309 .01583 Mdot
.78312 .01637 Mdot
.78315 .01519 Mdot
.78317 .0156 Mdot
.7832 .0155 Mdot
.78322 .01571 Mdot
.78325 .01598 Mdot
.78328 .01568 Mdot
.7833 .01542 Mdot
.78333 .01531 Mdot
.78335 .01497 Mdot
.78338 .01591 Mdot
.7834 .01519 Mdot
.78343 .01516 Mdot
.78346 .01517 Mdot
.78348 .01656 Mdot
.78351 .01626 Mdot
.78353 .01555 Mdot
.78356 .01573 Mdot
.78359 .01521 Mdot
.78361 .01601 Mdot
.78364 .01528 Mdot
.78366 .01552 Mdot
.78369 .01527 Mdot
.78371 .01584 Mdot
.78374 .01588 Mdot
.78377 .01556 Mdot
.78379 .01565 Mdot
.78382 .01549 Mdot
.78384 .01701 Mdot
.78387 .01558 Mdot
.7839 .01513 Mdot
.78392 .01632 Mdot
.78395 .0168 Mdot
.78397 .01492 Mdot
.784 .01673 Mdot
.78402 .01478 Mdot
.78405 .01543 Mdot
.78408 .01508 Mdot
.7841 .01584 Mdot
.78413 .01545 Mdot
.78415 .01586 Mdot
.78418 .01586 Mdot
.78421 .01665 Mdot
.78423 .01522 Mdot
.78426 .01519 Mdot
.78428 .01564 Mdot
.78431 .01579 Mdot
.78433 .01602 Mdot
.78436 .01645 Mdot
.78439 .0152 Mdot
.78441 .01615 Mdot
.78444 .01622 Mdot
.78446 .01655 Mdot
.78449 .01626 Mdot
.78452 .01574 Mdot
.78454 .01518 Mdot
.78457 .0156 Mdot
.78459 .01573 Mdot
.78462 .01612 Mdot
.78464 .01674 Mdot
.78467 .01607 Mdot
.7847 .01537 Mdot
.78472 .0161 Mdot
.78475 .01615 Mdot
.78477 .01556 Mdot
.7848 .01595 Mdot
.78483 .01613 Mdot
.78485 .015 Mdot
.78488 .01545 Mdot
.7849 .01591 Mdot
.78493 .01588 Mdot
.78495 .01609 Mdot
.78498 .01545 Mdot
.78501 .01629 Mdot
.78503 .01635 Mdot
.78506 .01568 Mdot
.78508 .01507 Mdot
.78511 .0155 Mdot
.78514 .01643 Mdot
.78516 .01556 Mdot
.78519 .01523 Mdot
.78521 .0148 Mdot
.78524 .01589 Mdot
.78526 .0164 Mdot
.78529 .0159 Mdot
.78532 .01592 Mdot
.78534 .01663 Mdot
.78537 .01519 Mdot
.78539 .01502 Mdot
.78542 .01513 Mdot
.78545 .01606 Mdot
.78547 .01547 Mdot
.7855 .01531 Mdot
.78552 .0165 Mdot
.78555 .01606 Mdot
.78557 .0162 Mdot
.7856 .01585 Mdot
.78563 .0162 Mdot
.78565 .01504 Mdot
.78568 .01559 Mdot
.7857 .01535 Mdot
.78573 .01596 Mdot
.78576 .01499 Mdot
.78578 .01525 Mdot
.78581 .01558 Mdot
.78583 .01548 Mdot
.78586 .01541 Mdot
.78588 .01484 Mdot
.78591 .01504 Mdot
.78594 .01708 Mdot
.78596 .01629 Mdot
.78599 .01581 Mdot
.78601 .0152 Mdot
.78604 .01551 Mdot
.78607 .01547 Mdot
.78609 .0159 Mdot
.78612 .01509 Mdot
.78614 .01551 Mdot
.78617 .01523 Mdot
.78619 .01575 Mdot
.78622 .01488 Mdot
.78625 .01548 Mdot
.78627 .01506 Mdot
.7863 .01594 Mdot
.78632 .01483 Mdot
.78635 .01616 Mdot
.78638 .01672 Mdot
.7864 .01644 Mdot
.78643 .01511 Mdot
.78645 .01539 Mdot
.78648 .01563 Mdot
.7865 .01642 Mdot
.78653 .01624 Mdot
.78656 .01591 Mdot
.78658 .01513 Mdot
.78661 .01521 Mdot
.78663 .01539 Mdot
.78666 .01624 Mdot
.78669 .01542 Mdot
.78671 .01639 Mdot
.78674 .01541 Mdot
.78676 .0155 Mdot
.78679 .01737 Mdot
.78681 .01586 Mdot
.78684 .01486 Mdot
.78687 .01628 Mdot
.78689 .01633 Mdot
.78692 .01618 Mdot
.78694 .0156 Mdot
.78697 .01589 Mdot
.787 .01533 Mdot
.78702 .01653 Mdot
.78705 .01616 Mdot
.78707 .01491 Mdot
.7871 .01532 Mdot
.78712 .01541 Mdot
.78715 .01559 Mdot
.78718 .01522 Mdot
.7872 .01509 Mdot
.78723 .0155 Mdot
.78725 .01483 Mdot
.78728 .01641 Mdot
.78731 .01518 Mdot
.78733 .01591 Mdot
.78736 .0167 Mdot
.78738 .01554 Mdot
.78741 .01556 Mdot
.78743 .01608 Mdot
.78746 .01563 Mdot
.78749 .01659 Mdot
.78751 .01587 Mdot
.78754 .01554 Mdot
.78756 .01586 Mdot
.78759 .01506 Mdot
.78762 .01513 Mdot
.78764 .01667 Mdot
.78767 .01516 Mdot
.78769 .01493 Mdot
.78772 .01542 Mdot
.78774 .01543 Mdot
.78777 .01619 Mdot
.7878 .01559 Mdot
.78782 .01563 Mdot
.78785 .01535 Mdot
.78787 .01613 Mdot
.7879 .01622 Mdot
.78793 .0153 Mdot
.78795 .01526 Mdot
.78798 .01551 Mdot
.788 .01535 Mdot
.78803 .01615 Mdot
.78805 .01489 Mdot
.78808 .01535 Mdot
.78811 .01517 Mdot
.78813 .01527 Mdot
.78816 .01687 Mdot
.78818 .01483 Mdot
.78821 .01637 Mdot
.78824 .01584 Mdot
.78826 .01501 Mdot
.78829 .01543 Mdot
.78831 .01607 Mdot
.78834 .01668 Mdot
.78837 .01657 Mdot
.78839 .0158 Mdot
.78842 .01639 Mdot
.78844 .01523 Mdot
.78847 .01714 Mdot
.78849 .01573 Mdot
.78852 .01495 Mdot
.78855 .01557 Mdot
.78857 .01617 Mdot
.7886 .0159 Mdot
.78862 .01652 Mdot
.78865 .01551 Mdot
.78868 .01667 Mdot
.7887 .01612 Mdot
.78873 .01517 Mdot
.78875 .01497 Mdot
.78878 .0161 Mdot
.7888 .01504 Mdot
.78883 .01559 Mdot
.78886 .01701 Mdot
.78888 .01537 Mdot
.78891 .01777 Mdot
.78893 .01518 Mdot
.78896 .01566 Mdot
.78899 .01653 Mdot
.78901 .0153 Mdot
.78904 .01487 Mdot
.78906 .01605 Mdot
.78909 .01558 Mdot
.78911 .01531 Mdot
.78914 .01585 Mdot
.78917 .01675 Mdot
.78919 .01498 Mdot
.78922 .0165 Mdot
.78924 .01538 Mdot
.78927 .01589 Mdot
.7893 .01507 Mdot
.78932 .01664 Mdot
.78935 .01505 Mdot
.78937 .01663 Mdot
.7894 .0172 Mdot
.78942 .01591 Mdot
.78945 .01504 Mdot
.78948 .01555 Mdot
.7895 .01619 Mdot
.78953 .01602 Mdot
.78955 .01621 Mdot
.78958 .01611 Mdot
.78961 .0159 Mdot
.78963 .01563 Mdot
.78966 .01633 Mdot
.78968 .01616 Mdot
.78971 .01536 Mdot
.78973 .01501 Mdot
.78976 .01806 Mdot
.78979 .01632 Mdot
.78981 .01561 Mdot
.78984 .01546 Mdot
.78986 .01565 Mdot
.78989 .01615 Mdot
.78992 .01544 Mdot
.78994 .01532 Mdot
.78997 .01566 Mdot
.78999 .0166 Mdot
.79002 .01587 Mdot
.79004 .01581 Mdot
.79007 .01648 Mdot
.7901 .01636 Mdot
.79012 .01535 Mdot
.79015 .01519 Mdot
.79017 .01604 Mdot
.7902 .01514 Mdot
.79023 .01476 Mdot
.79025 .01624 Mdot
.79028 .01531 Mdot
.7903 .01544 Mdot
.79033 .01587 Mdot
.79035 .01612 Mdot
.79038 .01611 Mdot
.79041 .01479 Mdot
.79043 .01563 Mdot
.79046 .01603 Mdot
.79048 .016 Mdot
.79051 .01507 Mdot
.79054 .01712 Mdot
.79056 .01596 Mdot
.79059 .01553 Mdot
.79061 .01623 Mdot
.79064 .01499 Mdot
.79066 .01582 Mdot
.79069 .01591 Mdot
.79072 .01589 Mdot
.79074 .01526 Mdot
.79077 .01525 Mdot
.79079 .0158 Mdot
.79082 .01544 Mdot
.79085 .01552 Mdot
.79087 .01624 Mdot
.7909 .01581 Mdot
.79092 .0163 Mdot
.79095 .016 Mdot
.79097 .01489 Mdot
.791 .01639 Mdot
.79103 .01539 Mdot
.79105 .01514 Mdot
.79108 .01653 Mdot
.7911 .01492 Mdot
.79113 .01579 Mdot
.79116 .01645 Mdot
.79118 .01515 Mdot
.79121 .01524 Mdot
.79123 .01624 Mdot
.79126 .01546 Mdot
.79128 .01575 Mdot
.79131 .01681 Mdot
.79134 .01501 Mdot
.79136 .01585 Mdot
.79139 .0162 Mdot
.79141 .0153 Mdot
.79144 .01494 Mdot
.79147 .01605 Mdot
.79149 .01589 Mdot
.79152 .01617 Mdot
.79154 .01607 Mdot
.79157 .01558 Mdot
.79159 .01527 Mdot
.79162 .0153 Mdot
.79165 .01559 Mdot
.79167 .01585 Mdot
.7917 .01511 Mdot
.79172 .01496 Mdot
.79175 .0154 Mdot
.79178 .01558 Mdot
.7918 .01597 Mdot
.79183 .01581 Mdot
.79185 .01586 Mdot
.79188 .01576 Mdot
.7919 .01607 Mdot
.79193 .01505 Mdot
.79196 .0159 Mdot
.79198 .01517 Mdot
.79201 .0157 Mdot
.79203 .01612 Mdot
.79206 .01577 Mdot
.79209 .01629 Mdot
.79211 .01496 Mdot
.79214 .01545 Mdot
.79216 .01574 Mdot
.79219 .01587 Mdot
.79221 .01571 Mdot
.79224 .01649 Mdot
.79227 .01684 Mdot
.79229 .01475 Mdot
.79232 .01499 Mdot
.79234 .01601 Mdot
.79237 .01523 Mdot
.7924 .01659 Mdot
.79242 .01604 Mdot
.79245 .01611 Mdot
.79247 .01555 Mdot
.7925 .01578 Mdot
.79252 .01522 Mdot
.79255 .01555 Mdot
.79258 .0156 Mdot
.7926 .01547 Mdot
.79263 .01629 Mdot
.79265 .01574 Mdot
.79268 .01639 Mdot
.79271 .01526 Mdot
.79273 .01573 Mdot
.79276 .01539 Mdot
.79278 .01596 Mdot
.79281 .01621 Mdot
.79283 .01564 Mdot
.79286 .01605 Mdot
.79289 .01578 Mdot
.79291 .01649 Mdot
.79294 .01645 Mdot
.79296 .01569 Mdot
.79299 .01567 Mdot
.79302 .01492 Mdot
.79304 .01538 Mdot
.79307 .01515 Mdot
.79309 .01533 Mdot
.79312 .01648 Mdot
.79314 .01677 Mdot
.79317 .0159 Mdot
.7932 .01577 Mdot
.79322 .01529 Mdot
.79325 .01604 Mdot
.79327 .01557 Mdot
.7933 .01602 Mdot
.79333 .01574 Mdot
.79335 .01555 Mdot
.79338 .01578 Mdot
.7934 .01527 Mdot
.79343 .01537 Mdot
.79345 .01537 Mdot
.79348 .01675 Mdot
.79351 .01644 Mdot
.79353 .01648 Mdot
.79356 .01546 Mdot
.79358 .01548 Mdot
.79361 .0151 Mdot
.79364 .01688 Mdot
.79366 .01541 Mdot
.79369 .01521 Mdot
.79371 .01583 Mdot
.79374 .01523 Mdot
.79376 .0166 Mdot
.79379 .0151 Mdot
.79382 .01591 Mdot
.79384 .0149 Mdot
.79387 .01595 Mdot
.79389 .01703 Mdot
.79392 .01595 Mdot
.79395 .01522 Mdot
.79397 .0156 Mdot
.794 .01527 Mdot
.79402 .01536 Mdot
.79405 .01693 Mdot
.79407 .01521 Mdot
.7941 .01593 Mdot
.79413 .0153 Mdot
.79415 .01576 Mdot
.79418 .01573 Mdot
.7942 .0156 Mdot
.79423 .01562 Mdot
.79426 .01582 Mdot
.79428 .01546 Mdot
.79431 .01501 Mdot
.79433 .01557 Mdot
.79436 .01535 Mdot
.79438 .016 Mdot
.79441 .0163 Mdot
.79444 .01498 Mdot
.79446 .01508 Mdot
.79449 .01656 Mdot
.79451 .01586 Mdot
.79454 .016 Mdot
.79457 .01659 Mdot
.79459 .0157 Mdot
.79462 .01676 Mdot
.79464 .01514 Mdot
.79467 .01525 Mdot
.79469 .01519 Mdot
.79472 .01582 Mdot
.79475 .01568 Mdot
.79477 .01474 Mdot
.7948 .0153 Mdot
.79482 .016 Mdot
.79485 .01539 Mdot
.79488 .01536 Mdot
.7949 .01526 Mdot
.79493 .01611 Mdot
.79495 .01572 Mdot
.79498 .01554 Mdot
.795 .01541 Mdot
.79503 .01525 Mdot
.79506 .01516 Mdot
.79508 .01518 Mdot
.79511 .016 Mdot
.79513 .01616 Mdot
.79516 .01592 Mdot
.79519 .01533 Mdot
.79521 .01605 Mdot
.79524 .01523 Mdot
.79526 .01557 Mdot
.79529 .01541 Mdot
.79531 .01602 Mdot
.79534 .0151 Mdot
.79537 .01558 Mdot
.79539 .01548 Mdot
.79542 .01568 Mdot
.79544 .01709 Mdot
.79547 .01515 Mdot
.7955 .01581 Mdot
.79552 .0162 Mdot
.79555 .01505 Mdot
.79557 .0159 Mdot
.7956 .01506 Mdot
.79562 .01647 Mdot
.79565 .01591 Mdot
.79568 .01744 Mdot
.7957 .01632 Mdot
.79573 .01656 Mdot
.79575 .01486 Mdot
.79578 .01646 Mdot
.79581 .01652 Mdot
.79583 .01563 Mdot
.79586 .01548 Mdot
.79588 .01658 Mdot
.79591 .01553 Mdot
.79593 .01609 Mdot
.79596 .01577 Mdot
.79599 .01629 Mdot
.79601 .01586 Mdot
.79604 .01564 Mdot
.79606 .01621 Mdot
.79609 .01538 Mdot
.79612 .01606 Mdot
.79614 .01655 Mdot
.79617 .01525 Mdot
.79619 .01566 Mdot
.79622 .01556 Mdot
.79624 .01702 Mdot
.79627 .01544 Mdot
.7963 .01551 Mdot
.79632 .01639 Mdot
.79635 .0154 Mdot
.79637 .01534 Mdot
.7964 .01562 Mdot
.79643 .01518 Mdot
.79645 .01476 Mdot
.79648 .01615 Mdot
.7965 .01602 Mdot
.79653 .01522 Mdot
.79655 .01532 Mdot
.79658 .01582 Mdot
.79661 .01615 Mdot
.79663 .01514 Mdot
.79666 .01626 Mdot
.79668 .01604 Mdot
.79671 .01656 Mdot
.79674 .01485 Mdot
.79676 .01599 Mdot
.79679 .01585 Mdot
.79681 .01492 Mdot
.79684 .01506 Mdot
.79686 .01596 Mdot
.79689 .01493 Mdot
.79692 .01635 Mdot
.79694 .01509 Mdot
.79697 .0158 Mdot
.79699 .01597 Mdot
.79702 .01504 Mdot
.79705 .0156 Mdot
.79707 .01539 Mdot
.7971 .01532 Mdot
.79712 .01583 Mdot
.79715 .01643 Mdot
.79717 .01547 Mdot
.7972 .01537 Mdot
.79723 .01755 Mdot
.79725 .01501 Mdot
.79728 .01608 Mdot
.7973 .01492 Mdot
.79733 .0161 Mdot
.79736 .01607 Mdot
.79738 .01801 Mdot
.79741 .01513 Mdot
.79743 .01526 Mdot
.79746 .0152 Mdot
.79749 .01511 Mdot
.79751 .01484 Mdot
.79754 .01604 Mdot
.79756 .0163 Mdot
.79759 .01568 Mdot
.79761 .0149 Mdot
.79764 .0163 Mdot
.79767 .01553 Mdot
.79769 .01582 Mdot
.79772 .01589 Mdot
.79774 .01642 Mdot
.79777 .01595 Mdot
.7978 .01656 Mdot
.79782 .01506 Mdot
.79785 .01596 Mdot
.79787 .01559 Mdot
.7979 .01583 Mdot
.79792 .01725 Mdot
.79795 .01602 Mdot
.79798 .01672 Mdot
.798 .01603 Mdot
.79803 .01571 Mdot
.79805 .01533 Mdot
.79808 .01549 Mdot
.79811 .01635 Mdot
.79813 .0152 Mdot
.79816 .0165 Mdot
.79818 .01622 Mdot
.79821 .01566 Mdot
.79823 .01573 Mdot
.79826 .01596 Mdot
.79829 .01531 Mdot
.79831 .01745 Mdot
.79834 .01588 Mdot
.79836 .01605 Mdot
.79839 .01622 Mdot
.79842 .01615 Mdot
.79844 .01605 Mdot
.79847 .01623 Mdot
.79849 .01624 Mdot
.79852 .01584 Mdot
.79854 .01594 Mdot
.79857 .01592 Mdot
.7986 .01533 Mdot
.79862 .01626 Mdot
.79865 .01632 Mdot
.79867 .0155 Mdot
.7987 .01571 Mdot
.79873 .0163 Mdot
.79875 .01696 Mdot
.79878 .01499 Mdot
.7988 .01541 Mdot
.79883 .01525 Mdot
.79885 .01587 Mdot
.79888 .01548 Mdot
.79891 .0164 Mdot
.79893 .01533 Mdot
.79896 .01577 Mdot
.79898 .01589 Mdot
.79901 .01572 Mdot
.79904 .0156 Mdot
.79906 .01555 Mdot
.79909 .01611 Mdot
.79911 .01598 Mdot
.79914 .01517 Mdot
.79916 .01537 Mdot
.79919 .01555 Mdot
.79922 .01675 Mdot
.79924 .01594 Mdot
.79927 .01486 Mdot
.79929 .01581 Mdot
.79932 .01487 Mdot
.79935 .01526 Mdot
.79937 .01529 Mdot
.7994 .01522 Mdot
.79942 .01523 Mdot
.79945 .01615 Mdot
.79947 .01565 Mdot
.7995 .01654 Mdot
.79953 .01478 Mdot
.79955 .01597 Mdot
.79958 .01568 Mdot
.7996 .01579 Mdot
.79963 .01554 Mdot
.79966 .01541 Mdot
.79968 .0148 Mdot
.79971 .01532 Mdot
.79973 .01506 Mdot
.79976 .01508 Mdot
.79978 .01562 Mdot
.79981 .01644 Mdot
.79984 .01601 Mdot
.79986 .01748 Mdot
.79989 .01527 Mdot
.79991 .01564 Mdot
.79994 .01581 Mdot
.79997 .01502 Mdot
.79999 .01608 Mdot
.80002 .01574 Mdot
.80004 .0158 Mdot
.80007 .01511 Mdot
.80009 .01615 Mdot
.80012 .01619 Mdot
.80015 .01631 Mdot
.80017 .01541 Mdot
.8002 .01644 Mdot
.80022 .01595 Mdot
.80025 .01603 Mdot
.80028 .01561 Mdot
.8003 .01561 Mdot
.80033 .01599 Mdot
.80035 .01542 Mdot
.80038 .01648 Mdot
.8004 .01696 Mdot
.80043 .01707 Mdot
.80046 .01527 Mdot
.80048 .01548 Mdot
.80051 .01664 Mdot
.80053 .01553 Mdot
.80056 .01634 Mdot
.80059 .01566 Mdot
.80061 .01607 Mdot
.80064 .01496 Mdot
.80066 .01544 Mdot
.80069 .01565 Mdot
.80071 .01526 Mdot
.80074 .01644 Mdot
.80077 .01689 Mdot
.80079 .015 Mdot
.80082 .01632 Mdot
.80084 .01528 Mdot
.80087 .01573 Mdot
.8009 .01504 Mdot
.80092 .01532 Mdot
.80095 .01569 Mdot
.80097 .01488 Mdot
.801 .017 Mdot
.80102 .01569 Mdot
.80105 .01507 Mdot
.80108 .01563 Mdot
.8011 .01496 Mdot
.80113 .01613 Mdot
.80115 .01643 Mdot
.80118 .01663 Mdot
.80121 .01614 Mdot
.80123 .01652 Mdot
.80126 .015 Mdot
.80128 .01563 Mdot
.80131 .01642 Mdot
.80133 .01654 Mdot
.80136 .01555 Mdot
.80139 .01485 Mdot
.80141 .01553 Mdot
.80144 .01811 Mdot
.80146 .01632 Mdot
.80149 .01523 Mdot
.80152 .01594 Mdot
.80154 .0182 Mdot
.80157 .01513 Mdot
.80159 .01543 Mdot
.80162 .01577 Mdot
.80164 .01647 Mdot
.80167 .01643 Mdot
.8017 .01628 Mdot
.80172 .01485 Mdot
.80175 .01698 Mdot
.80177 .0164 Mdot
.8018 .01792 Mdot
.80183 .01524 Mdot
.80185 .01637 Mdot
.80188 .01614 Mdot
.8019 .01576 Mdot
.80193 .01675 Mdot
.80195 .01605 Mdot
.80198 .01512 Mdot
.80201 .0155 Mdot
.80203 .01539 Mdot
.80206 .01618 Mdot
.80208 .01619 Mdot
.80211 .01539 Mdot
.80214 .01608 Mdot
.80216 .01596 Mdot
.80219 .01598 Mdot
.80221 .01545 Mdot
.80224 .01572 Mdot
.80226 .0156 Mdot
.80229 .01605 Mdot
.80232 .01592 Mdot
.80234 .01698 Mdot
.80237 .01579 Mdot
.80239 .01579 Mdot
.80242 .01688 Mdot
.80245 .01632 Mdot
.80247 .01769 Mdot
.8025 .01627 Mdot
.80252 .01621 Mdot
.80255 .01529 Mdot
.80257 .01513 Mdot
.8026 .01656 Mdot
.80263 .01673 Mdot
.80265 .01521 Mdot
.80268 .01523 Mdot
.8027 .01725 Mdot
.80273 .01629 Mdot
.80276 .0166 Mdot
.80278 .0168 Mdot
.80281 .01559 Mdot
.80283 .01608 Mdot
.80286 .01579 Mdot
.80288 .01557 Mdot
.80291 .01611 Mdot
.80294 .01723 Mdot
.80296 .01616 Mdot
.80299 .01717 Mdot
.80301 .01544 Mdot
.80304 .0156 Mdot
.80307 .01598 Mdot
.80309 .01746 Mdot
.80312 .01838 Mdot
.80314 .01624 Mdot
.80317 .01722 Mdot
.80319 .0157 Mdot
.80322 .01644 Mdot
.80325 .01637 Mdot
.80327 .01657 Mdot
.8033 .01568 Mdot
.80332 .01722 Mdot
.80335 .01491 Mdot
.80338 .01533 Mdot
.8034 .01598 Mdot
.80343 .01644 Mdot
.80345 .01649 Mdot
.80348 .01524 Mdot
.8035 .01629 Mdot
.80353 .01622 Mdot
.80356 .0164 Mdot
.80358 .0157 Mdot
.80361 .01547 Mdot
.80363 .01622 Mdot
.80366 .01611 Mdot
.80369 .01538 Mdot
.80371 .01653 Mdot
.80374 .01538 Mdot
.80376 .01727 Mdot
.80379 .01795 Mdot
.80381 .01707 Mdot
.80384 .01631 Mdot
.80387 .01569 Mdot
.80389 .01679 Mdot
.80392 .01513 Mdot
.80394 .01725 Mdot
.80397 .01704 Mdot
.804 .01604 Mdot
.80402 .01605 Mdot
.80405 .01519 Mdot
.80407 .01602 Mdot
.8041 .01675 Mdot
.80412 .01517 Mdot
.80415 .01544 Mdot
.80418 .0158 Mdot
.8042 .01617 Mdot
.80423 .01588 Mdot
.80425 .01807 Mdot
.80428 .016 Mdot
.80431 .01499 Mdot
.80433 .01599 Mdot
.80436 .01849 Mdot
.80438 .01567 Mdot
.80441 .01547 Mdot
.80443 .01717 Mdot
.80446 .01754 Mdot
.80449 .01694 Mdot
.80451 .01631 Mdot
.80454 .01663 Mdot
.80456 .01576 Mdot
.80459 .01499 Mdot
.80462 .01599 Mdot
.80464 .01696 Mdot
.80467 .0159 Mdot
.80469 .0171 Mdot
.80472 .01657 Mdot
.80474 .01573 Mdot
.80477 .01626 Mdot
.8048 .01509 Mdot
.80482 .01632 Mdot
.80485 .01565 Mdot
.80487 .01561 Mdot
.8049 .01625 Mdot
.80493 .01629 Mdot
.80495 .01498 Mdot
.80498 .01654 Mdot
.805 .01661 Mdot
.80503 .01615 Mdot
.80505 .0154 Mdot
.80508 .01534 Mdot
.80511 .01596 Mdot
.80513 .01719 Mdot
.80516 .01654 Mdot
.80518 .01671 Mdot
.80521 .01611 Mdot
.80524 .01711 Mdot
.80526 .01657 Mdot
.80529 .01835 Mdot
.80531 .01793 Mdot
.80534 .0162 Mdot
.80536 .01771 Mdot
.80539 .01676 Mdot
.80542 .01594 Mdot
.80544 .0179 Mdot
.80547 .01676 Mdot
.80549 .01705 Mdot
.80552 .01793 Mdot
.80555 .01824 Mdot
.80557 .01841 Mdot
.8056 .01719 Mdot
.80562 .01648 Mdot
.80565 .01699 Mdot
.80567 .01673 Mdot
.8057 .01712 Mdot
.80573 .01677 Mdot
.80575 .01753 Mdot
.80578 .01544 Mdot
.8058 .01495 Mdot
.80583 .01694 Mdot
.80586 .01652 Mdot
.80588 .0163 Mdot
.80591 .01777 Mdot
.80593 .01556 Mdot
.80596 .01636 Mdot
.80598 .01621 Mdot
.80601 .01804 Mdot
.80604 .01757 Mdot
.80606 .01641 Mdot
.80609 .01709 Mdot
.80611 .01511 Mdot
.80614 .01554 Mdot
.80617 .01708 Mdot
.80619 .01747 Mdot
.80622 .01773 Mdot
.80624 .01537 Mdot
.80627 .01565 Mdot
.80629 .01487 Mdot
.80632 .01691 Mdot
.80635 .01598 Mdot
.80637 .01664 Mdot
.8064 .0168 Mdot
.80642 .01771 Mdot
.80645 .01669 Mdot
.80648 .01738 Mdot
.8065 .01643 Mdot
.80653 .01643 Mdot
.80655 .0174 Mdot
.80658 .01631 Mdot
.80661 .01584 Mdot
.80663 .01654 Mdot
.80666 .01662 Mdot
.80668 .01548 Mdot
.80671 .01679 Mdot
.80673 .01598 Mdot
.80676 .01725 Mdot
.80679 .01606 Mdot
.80681 .0166 Mdot
.80684 .01586 Mdot
.80686 .01756 Mdot
.80689 .01576 Mdot
.80692 .01675 Mdot
.80694 .01758 Mdot
.80697 .01531 Mdot
.80699 .0168 Mdot
.80702 .01531 Mdot
.80704 .01498 Mdot
.80707 .01548 Mdot
.8071 .01548 Mdot
.80712 .01623 Mdot
.80715 .01835 Mdot
.80717 .01596 Mdot
.8072 .01525 Mdot
.80723 .0151 Mdot
.80725 .01613 Mdot
.80728 .01523 Mdot
.8073 .0152 Mdot
.80733 .01618 Mdot
.80735 .01567 Mdot
.80738 .01513 Mdot
.80741 .01512 Mdot
.80743 .01626 Mdot
.80746 .01732 Mdot
.80748 .01674 Mdot
.80751 .01705 Mdot
.80754 .01636 Mdot
.80756 .01683 Mdot
.80759 .01514 Mdot
.80761 .01517 Mdot
.80764 .01531 Mdot
.80766 .0149 Mdot
.80769 .01644 Mdot
.80772 .01786 Mdot
.80774 .01737 Mdot
.80777 .01582 Mdot
.80779 .01541 Mdot
.80782 .01844 Mdot
.80785 .01887 Mdot
.80787 .01554 Mdot
.8079 .01512 Mdot
.80792 .01768 Mdot
.80795 .01659 Mdot
.80797 .01821 Mdot
.808 .01603 Mdot
.80803 .01621 Mdot
.80805 .01586 Mdot
.80808 .01601 Mdot
.8081 .01678 Mdot
.80813 .01589 Mdot
.80816 .0164 Mdot
.80818 .01558 Mdot
.80821 .01584 Mdot
.80823 .01611 Mdot
.80826 .01595 Mdot
.80828 .01598 Mdot
.80831 .01562 Mdot
.80834 .01658 Mdot
.80836 .01532 Mdot
.80839 .01694 Mdot
.80841 .01614 Mdot
.80844 .01568 Mdot
.80847 .01755 Mdot
.80849 .01768 Mdot
.80852 .01727 Mdot
.80854 .01715 Mdot
.80857 .01752 Mdot
.80859 .01629 Mdot
.80862 .01636 Mdot
.80865 .01634 Mdot
.80867 .01676 Mdot
.8087 .01554 Mdot
.80872 .01662 Mdot
.80875 .01685 Mdot
.80878 .01638 Mdot
.8088 .01519 Mdot
.80883 .01824 Mdot
.80885 .01601 Mdot
.80888 .01547 Mdot
.8089 .01676 Mdot
.80893 .0167 Mdot
.80896 .01693 Mdot
.80898 .0164 Mdot
.80901 .01536 Mdot
.80903 .01523 Mdot
.80906 .01708 Mdot
.80909 .01726 Mdot
.80911 .01713 Mdot
.80914 .01651 Mdot
.80916 .01778 Mdot
.80919 .01825 Mdot
.80921 .0167 Mdot
.80924 .01827 Mdot
.80927 .01861 Mdot
.80929 .01782 Mdot
.80932 .01695 Mdot
.80934 .01728 Mdot
.80937 .01599 Mdot
.8094 .01654 Mdot
.80942 .01738 Mdot
.80945 .0151 Mdot
.80947 .01733 Mdot
.8095 .01583 Mdot
.80952 .01529 Mdot
.80955 .01592 Mdot
.80958 .01616 Mdot
.8096 .01513 Mdot
.80963 .01641 Mdot
.80965 .01608 Mdot
.80968 .0159 Mdot
.80971 .01599 Mdot
.80973 .01712 Mdot
.80976 .01535 Mdot
.80978 .01547 Mdot
.80981 .01577 Mdot
.80983 .01755 Mdot
.80986 .0168 Mdot
.80989 .0157 Mdot
.80991 .01667 Mdot
.80994 .01675 Mdot
.80996 .01515 Mdot
.80999 .01684 Mdot
.81002 .0162 Mdot
.81004 .01515 Mdot
.81007 .01728 Mdot
.81009 .01656 Mdot
.81012 .01595 Mdot
.81014 .01523 Mdot
.81017 .01692 Mdot
.8102 .01523 Mdot
.81022 .01577 Mdot
.81025 .01675 Mdot
.81027 .01685 Mdot
.8103 .01674 Mdot
.81033 .01631 Mdot
.81035 .01705 Mdot
.81038 .0167 Mdot
.8104 .01571 Mdot
.81043 .01803 Mdot
.81045 .01573 Mdot
.81048 .01531 Mdot
.81051 .01655 Mdot
.81053 .01673 Mdot
.81056 .01592 Mdot
.81058 .01566 Mdot
.81061 .01526 Mdot
.81064 .01653 Mdot
.81066 .01556 Mdot
.81069 .01516 Mdot
.81071 .01523 Mdot
.81074 .01599 Mdot
.81076 .0178 Mdot
.81079 .01676 Mdot
.81082 .01814 Mdot
.81084 .01645 Mdot
.81087 .01905 Mdot
.81089 .01779 Mdot
.81092 .01706 Mdot
.81095 .01615 Mdot
.81097 .01562 Mdot
.811 .0152 Mdot
.81102 .01682 Mdot
.81105 .01612 Mdot
.81107 .01577 Mdot
.8111 .01555 Mdot
.81113 .01721 Mdot
.81115 .01591 Mdot
.81118 .01746 Mdot
.8112 .0162 Mdot
.81123 .01573 Mdot
.81126 .01556 Mdot
.81128 .01539 Mdot
.81131 .01696 Mdot
.81133 .01586 Mdot
.81136 .01549 Mdot
.81138 .01727 Mdot
.81141 .01571 Mdot
.81144 .01598 Mdot
.81146 .01767 Mdot
.81149 .01837 Mdot
.81151 .01614 Mdot
.81154 .01625 Mdot
.81157 .01622 Mdot
.81159 .01792 Mdot
.81162 .01727 Mdot
.81164 .0174 Mdot
.81167 .01824 Mdot
.81169 .01683 Mdot
.81172 .01576 Mdot
.81175 .01661 Mdot
.81177 .01785 Mdot
.8118 .01762 Mdot
.81182 .01787 Mdot
.81185 .01567 Mdot
.81188 .01513 Mdot
.8119 .01543 Mdot
.81193 .01791 Mdot
.81195 .01871 Mdot
.81198 .01606 Mdot
.812 .01605 Mdot
.81203 .01519 Mdot
.81206 .01555 Mdot
.81208 .01481 Mdot
.81211 .01501 Mdot
.81213 .01602 Mdot
.81216 .01653 Mdot
.81219 .01588 Mdot
.81221 .0161 Mdot
.81224 .01749 Mdot
.81226 .01594 Mdot
.81229 .01578 Mdot
.81231 .01636 Mdot
.81234 .01517 Mdot
.81237 .01507 Mdot
.81239 .01695 Mdot
.81242 .01695 Mdot
.81244 .01819 Mdot
.81247 .01588 Mdot
.8125 .01678 Mdot
.81252 .01637 Mdot
.81255 .01614 Mdot
.81257 .01549 Mdot
.8126 .01565 Mdot
.81262 .01718 Mdot
.81265 .01575 Mdot
.81268 .01598 Mdot
.8127 .01563 Mdot
.81273 .01705 Mdot
.81275 .01643 Mdot
.81278 .0165 Mdot
.81281 .01543 Mdot
.81283 .0159 Mdot
.81286 .01672 Mdot
.81288 .01587 Mdot
.81291 .01705 Mdot
.81293 .01516 Mdot
.81296 .0154 Mdot
.81299 .01579 Mdot
.81301 .01634 Mdot
.81304 .01638 Mdot
.81306 .01601 Mdot
.81309 .01641 Mdot
.81312 .01604 Mdot
.81314 .01653 Mdot
.81317 .01636 Mdot
.81319 .01781 Mdot
.81322 .016 Mdot
.81324 .01529 Mdot
.81327 .01643 Mdot
.8133 .01621 Mdot
.81332 .01666 Mdot
.81335 .0165 Mdot
.81337 .01522 Mdot
.8134 .01657 Mdot
.81343 .02135 Mdot
.81345 .01921 Mdot
.81348 .01731 Mdot
.8135 .01598 Mdot
.81353 .0154 Mdot
.81355 .01636 Mdot
.81358 .01594 Mdot
.81361 .01742 Mdot
.81363 .01778 Mdot
.81366 .01593 Mdot
.81368 .01645 Mdot
.81371 .01586 Mdot
.81374 .01617 Mdot
.81376 .01517 Mdot
.81379 .01663 Mdot
.81381 .01729 Mdot
.81384 .0183 Mdot
.81386 .0162 Mdot
.81389 .01668 Mdot
.81392 .01501 Mdot
.81394 .01702 Mdot
.81397 .01611 Mdot
.81399 .01897 Mdot
.81402 .01597 Mdot
.81405 .01816 Mdot
.81407 .01866 Mdot
.8141 .01701 Mdot
.81412 .01507 Mdot
.81415 .01596 Mdot
.81417 .01611 Mdot
.8142 .01641 Mdot
.81423 .01549 Mdot
.81425 .01679 Mdot
.81428 .01884 Mdot
.8143 .01885 Mdot
.81433 .01672 Mdot
.81436 .01697 Mdot
.81438 .01831 Mdot
.81441 .01786 Mdot
.81443 .01706 Mdot
.81446 .01773 Mdot
.81448 .01659 Mdot
.81451 .01876 Mdot
.81454 .01604 Mdot
.81456 .01762 Mdot
.81459 .01717 Mdot
.81461 .01717 Mdot
.81464 .01769 Mdot
.81467 .01826 Mdot
.81469 .0156 Mdot
.81472 .01758 Mdot
.81474 .01705 Mdot
.81477 .01556 Mdot
.81479 .01553 Mdot
.81482 .01641 Mdot
.81485 .01757 Mdot
.81487 .0174 Mdot
.8149 .01645 Mdot
.81492 .01568 Mdot
.81495 .01753 Mdot
.81498 .01825 Mdot
.815 .01729 Mdot
.81503 .0175 Mdot
.81505 .01971 Mdot
.81508 .01859 Mdot
.8151 .01564 Mdot
.81513 .01558 Mdot
.81516 .01749 Mdot
.81518 .01572 Mdot
.81521 .0169 Mdot
.81523 .01635 Mdot
.81526 .01727 Mdot
.81529 .01747 Mdot
.81531 .01667 Mdot
.81534 .01573 Mdot
.81536 .01683 Mdot
.81539 .01505 Mdot
.81541 .01549 Mdot
.81544 .01561 Mdot
.81547 .01488 Mdot
.81549 .01603 Mdot
.81552 .01628 Mdot
.81554 .01599 Mdot
.81557 .01644 Mdot
.8156 .0165 Mdot
.81562 .01729 Mdot
.81565 .01658 Mdot
.81567 .01672 Mdot
.8157 .0156 Mdot
.81573 .01551 Mdot
.81575 .01707 Mdot
.81578 .01554 Mdot
.8158 .01577 Mdot
.81583 .01561 Mdot
.81585 .01527 Mdot
.81588 .0162 Mdot
.81591 .01628 Mdot
.81593 .0155 Mdot
.81596 .01494 Mdot
.81598 .01546 Mdot
.81601 .01545 Mdot
.81604 .01535 Mdot
.81606 .01546 Mdot
.81609 .01572 Mdot
.81611 .01632 Mdot
.81614 .0165 Mdot
.81616 .01643 Mdot
.81619 .01561 Mdot
.81622 .01558 Mdot
.81624 .01532 Mdot
.81627 .01567 Mdot
.81629 .01546 Mdot
.81632 .01646 Mdot
.81635 .01613 Mdot
.81637 .01517 Mdot
.8164 .01726 Mdot
.81642 .01613 Mdot
.81645 .01654 Mdot
.81647 .0151 Mdot
.8165 .01578 Mdot
.81653 .01622 Mdot
.81655 .0152 Mdot
.81658 .01581 Mdot
.8166 .01552 Mdot
.81663 .01535 Mdot
.81666 .0159 Mdot
.81668 .01581 Mdot
.81671 .01653 Mdot
.81673 .01548 Mdot
.81676 .01532 Mdot
.81678 .01536 Mdot
.81681 .01651 Mdot
.81684 .01506 Mdot
.81686 .0154 Mdot
.81689 .01581 Mdot
.81691 .01538 Mdot
.81694 .0153 Mdot
.81697 .01616 Mdot
.81699 .01656 Mdot
.81702 .01567 Mdot
.81704 .01578 Mdot
.81707 .01549 Mdot
.81709 .01567 Mdot
.81712 .01694 Mdot
.81715 .01796 Mdot
.81717 .01854 Mdot
.8172 .01671 Mdot
.81722 .01733 Mdot
.81725 .01761 Mdot
.81728 .01551 Mdot
.8173 .01514 Mdot
.81733 .01583 Mdot
.81735 .01599 Mdot
.81738 .0167 Mdot
.8174 .01482 Mdot
.81743 .01571 Mdot
.81746 .01545 Mdot
.81748 .01686 Mdot
.81751 .01734 Mdot
.81753 .01555 Mdot
.81756 .01737 Mdot
.81759 .01524 Mdot
.81761 .01532 Mdot
.81764 .01525 Mdot
.81766 .01583 Mdot
.81769 .01648 Mdot
.81771 .01649 Mdot
.81774 .01672 Mdot
.81777 .01718 Mdot
.81779 .0171 Mdot
.81782 .01643 Mdot
.81784 .01738 Mdot
.81787 .01717 Mdot
.8179 .01777 Mdot
.81792 .01555 Mdot
.81795 .0152 Mdot
.81797 .01642 Mdot
.818 .01637 Mdot
.81802 .01702 Mdot
.81805 .01587 Mdot
.81808 .01573 Mdot
.8181 .01574 Mdot
.81813 .01589 Mdot
.81815 .01687 Mdot
.81818 .01541 Mdot
.81821 .01549 Mdot
.81823 .01863 Mdot
.81826 .01681 Mdot
.81828 .01791 Mdot
.81831 .01619 Mdot
.81833 .01582 Mdot
.81836 .0159 Mdot
.81839 .01563 Mdot
.81841 .01509 Mdot
.81844 .01652 Mdot
.81846 .01663 Mdot
.81849 .01535 Mdot
.81852 .01647 Mdot
.81854 .017 Mdot
.81857 .01689 Mdot
.81859 .01524 Mdot
.81862 .01621 Mdot
.81864 .01693 Mdot
.81867 .01649 Mdot
.8187 .01809 Mdot
.81872 .01721 Mdot
.81875 .01519 Mdot
.81877 .01613 Mdot
.8188 .01592 Mdot
.81883 .01585 Mdot
.81885 .01721 Mdot
.81888 .01553 Mdot
.8189 .01694 Mdot
.81893 .01661 Mdot
.81895 .01515 Mdot
.81898 .01713 Mdot
.81901 .0166 Mdot
.81903 .01644 Mdot
.81906 .015 Mdot
.81908 .01838 Mdot
.81911 .01822 Mdot
.81914 .01862 Mdot
.81916 .01633 Mdot
.81919 .01578 Mdot
.81921 .01628 Mdot
.81924 .01724 Mdot
.81926 .01602 Mdot
.81929 .01566 Mdot
.81932 .01676 Mdot
.81934 .01723 Mdot
.81937 .01546 Mdot
.81939 .01776 Mdot
.81942 .0179 Mdot
.81945 .01559 Mdot
.81947 .01639 Mdot
.8195 .01799 Mdot
.81952 .01635 Mdot
.81955 .01612 Mdot
.81957 .01572 Mdot
.8196 .01585 Mdot
.81963 .01564 Mdot
.81965 .01627 Mdot
.81968 .01615 Mdot
.8197 .01617 Mdot
.81973 .01674 Mdot
.81976 .016 Mdot
.81978 .0152 Mdot
.81981 .01703 Mdot
.81983 .01508 Mdot
.81986 .01554 Mdot
.81988 .01588 Mdot
.81991 .01727 Mdot
.81994 .01773 Mdot
.81996 .01652 Mdot
.81999 .0154 Mdot
.82001 .01561 Mdot
.82004 .01511 Mdot
.82007 .01639 Mdot
.82009 .01735 Mdot
.82012 .01535 Mdot
.82014 .01731 Mdot
.82017 .01624 Mdot
.82019 .01781 Mdot
.82022 .01635 Mdot
.82025 .01517 Mdot
.82027 .01737 Mdot
.8203 .01826 Mdot
.82032 .0167 Mdot
.82035 .01579 Mdot
.82038 .01695 Mdot
.8204 .01687 Mdot
.82043 .01681 Mdot
.82045 .017 Mdot
.82048 .01577 Mdot
.8205 .01659 Mdot
.82053 .01585 Mdot
.82056 .01731 Mdot
.82058 .01753 Mdot
.82061 .01735 Mdot
.82063 .01627 Mdot
.82066 .01855 Mdot
.82069 .0154 Mdot
.82071 .01523 Mdot
.82074 .01799 Mdot
.82076 .01545 Mdot
.82079 .01629 Mdot
.82081 .01762 Mdot
.82084 .01682 Mdot
.82087 .01621 Mdot
.82089 .01611 Mdot
.82092 .01658 Mdot
.82094 .01562 Mdot
.82097 .01615 Mdot
.821 .01702 Mdot
.82102 .01565 Mdot
.82105 .01587 Mdot
.82107 .0165 Mdot
.8211 .01592 Mdot
.82112 .01514 Mdot
.82115 .01603 Mdot
.82118 .01556 Mdot
.8212 .01698 Mdot
.82123 .0175 Mdot
.82125 .01655 Mdot
.82128 .01771 Mdot
.82131 .01687 Mdot
.82133 .01666 Mdot
.82136 .01656 Mdot
.82138 .01562 Mdot
.82141 .01758 Mdot
.82143 .01802 Mdot
.82146 .01669 Mdot
.82149 .01575 Mdot
.82151 .01749 Mdot
.82154 .01661 Mdot
.82156 .01672 Mdot
.82159 .01645 Mdot
.82162 .016 Mdot
.82164 .01491 Mdot
.82167 .01952 Mdot
.82169 .01743 Mdot
.82172 .01693 Mdot
.82174 .0196 Mdot
.82177 .0181 Mdot
.8218 .01922 Mdot
.82182 .01555 Mdot
.82185 .01613 Mdot
.82187 .01757 Mdot
.8219 .01556 Mdot
.82193 .01513 Mdot
.82195 .01702 Mdot
.82198 .01657 Mdot
.822 .01609 Mdot
.82203 .01571 Mdot
.82205 .01633 Mdot
.82208 .01603 Mdot
.82211 .01515 Mdot
.82213 .01512 Mdot
.82216 .01556 Mdot
.82218 .01671 Mdot
.82221 .01587 Mdot
.82224 .01601 Mdot
.82226 .0157 Mdot
.82229 .01579 Mdot
.82231 .01736 Mdot
.82234 .01745 Mdot
.82236 .01784 Mdot
.82239 .0161 Mdot
.82242 .01509 Mdot
.82244 .01732 Mdot
.82247 .0162 Mdot
.82249 .01587 Mdot
.82252 .01523 Mdot
.82255 .01562 Mdot
.82257 .01682 Mdot
.8226 .01585 Mdot
.82262 .01531 Mdot
.82265 .0163 Mdot
.82267 .01643 Mdot
.8227 .01538 Mdot
.82273 .01668 Mdot
.82275 .01534 Mdot
.82278 .01734 Mdot
.8228 .01617 Mdot
.82283 .01695 Mdot
.82286 .01515 Mdot
.82288 .01634 Mdot
.82291 .01711 Mdot
.82293 .01578 Mdot
.82296 .01775 Mdot
.82298 .01647 Mdot
.82301 .0169 Mdot
.82304 .01561 Mdot
.82306 .01609 Mdot
.82309 .01619 Mdot
.82311 .01507 Mdot
.82314 .01563 Mdot
.82317 .01541 Mdot
.82319 .01729 Mdot
.82322 .01626 Mdot
.82324 .01541 Mdot
.82327 .01776 Mdot
.82329 .01611 Mdot
.82332 .01575 Mdot
.82335 .01606 Mdot
.82337 .0165 Mdot
.8234 .01661 Mdot
.82342 .01656 Mdot
.82345 .01602 Mdot
.82348 .01742 Mdot
.8235 .0161 Mdot
.82353 .01841 Mdot
.82355 .01556 Mdot
.82358 .0173 Mdot
.8236 .01777 Mdot
.82363 .01822 Mdot
.82366 .01622 Mdot
.82368 .01799 Mdot
.82371 .01742 Mdot
.82373 .01905 Mdot
.82376 .01887 Mdot
.82379 .01571 Mdot
.82381 .01505 Mdot
.82384 .0158 Mdot
.82386 .01596 Mdot
.82389 .01597 Mdot
.82391 .01705 Mdot
.82394 .01518 Mdot
.82397 .01569 Mdot
.82399 .01674 Mdot
.82402 .01781 Mdot
.82404 .01582 Mdot
.82407 .01583 Mdot
.8241 .01642 Mdot
.82412 .0166 Mdot
.82415 .01796 Mdot
.82417 .01742 Mdot
.8242 .01807 Mdot
.82422 .01727 Mdot
.82425 .0168 Mdot
.82428 .01779 Mdot
.8243 .0192 Mdot
.82433 .02051 Mdot
.82435 .01669 Mdot
.82438 .01777 Mdot
.82441 .01556 Mdot
.82443 .01785 Mdot
.82446 .01736 Mdot
.82448 .01644 Mdot
.82451 .01599 Mdot
.82453 .01519 Mdot
.82456 .01733 Mdot
.82459 .01701 Mdot
.82461 .01922 Mdot
.82464 .0165 Mdot
.82466 .01552 Mdot
.82469 .01767 Mdot
.82472 .01713 Mdot
.82474 .021 Mdot
.82477 .01931 Mdot
.82479 .01719 Mdot
.82482 .0175 Mdot
.82485 .01973 Mdot
.82487 .01905 Mdot
.8249 .01627 Mdot
.82492 .01691 Mdot
.82495 .01738 Mdot
.82497 .01954 Mdot
.825 .01894 Mdot
.82503 .01648 Mdot
.82505 .01661 Mdot
.82508 .0166 Mdot
.8251 .01683 Mdot
.82513 .01664 Mdot
.82516 .01841 Mdot
.82518 .01857 Mdot
.82521 .01655 Mdot
.82523 .01706 Mdot
.82526 .01924 Mdot
.82528 .01585 Mdot
.82531 .01561 Mdot
.82534 .01512 Mdot
.82536 .01806 Mdot
.82539 .01899 Mdot
.82541 .01764 Mdot
.82544 .01519 Mdot
.82547 .01618 Mdot
.82549 .01592 Mdot
.82552 .0165 Mdot
.82554 .01757 Mdot
.82557 .01812 Mdot
.82559 .0179 Mdot
.82562 .01724 Mdot
.82565 .01523 Mdot
.82567 .01743 Mdot
.8257 .01567 Mdot
.82572 .01624 Mdot
.82575 .01956 Mdot
.82578 .01619 Mdot
.8258 .01821 Mdot
.82583 .01857 Mdot
.82585 .0169 Mdot
.82588 .01611 Mdot
.8259 .01716 Mdot
.82593 .01551 Mdot
.82596 .0175 Mdot
.82598 .01514 Mdot
.82601 .01792 Mdot
.82603 .01793 Mdot
.82606 .01748 Mdot
.82609 .01822 Mdot
.82611 .01724 Mdot
.82614 .01754 Mdot
.82616 .01663 Mdot
.82619 .01919 Mdot
.82621 .01899 Mdot
.82624 .01875 Mdot
.82627 .01794 Mdot
.82629 .01565 Mdot
.82632 .0169 Mdot
.82634 .01657 Mdot
.82637 .02096 Mdot
.8264 .02349 Mdot
.82642 .01703 Mdot
.82645 .01613 Mdot
.82647 .01774 Mdot
.8265 .01876 Mdot
.82652 .01665 Mdot
.82655 .02018 Mdot
.82658 .01971 Mdot
.8266 .01919 Mdot
.82663 .01839 Mdot
.82665 .01561 Mdot
.82668 .01787 Mdot
.82671 .01664 Mdot
.82673 .01656 Mdot
.82676 .01583 Mdot
.82678 .01737 Mdot
.82681 .01758 Mdot
.82683 .01718 Mdot
.82686 .0204 Mdot
.82689 .0193 Mdot
.82691 .01998 Mdot
.82694 .01838 Mdot
.82696 .01793 Mdot
.82699 .01802 Mdot
.82702 .01634 Mdot
.82704 .01645 Mdot
.82707 .01888 Mdot
.82709 .01683 Mdot
.82712 .01661 Mdot
.82714 .01647 Mdot
.82717 .01682 Mdot
.8272 .01719 Mdot
.82722 .01535 Mdot
.82725 .01515 Mdot
.82727 .01731 Mdot
.8273 .01599 Mdot
.82733 .01902 Mdot
.82735 .01658 Mdot
.82738 .0181 Mdot
.8274 .01803 Mdot
.82743 .01627 Mdot
.82745 .01786 Mdot
.82748 .01826 Mdot
.82751 .01781 Mdot
.82753 .01623 Mdot
.82756 .01718 Mdot
.82758 .01909 Mdot
.82761 .01744 Mdot
.82764 .01493 Mdot
.82766 .01639 Mdot
.82769 .01824 Mdot
.82771 .01548 Mdot
.82774 .01626 Mdot
.82776 .01735 Mdot
.82779 .01696 Mdot
.82782 .01523 Mdot
.82784 .01558 Mdot
.82787 .01601 Mdot
.82789 .01702 Mdot
.82792 .01606 Mdot
.82795 .01724 Mdot
.82797 .01501 Mdot
.828 .0161 Mdot
.82802 .01561 Mdot
.82805 .01828 Mdot
.82807 .01801 Mdot
.8281 .01645 Mdot
.82813 .01647 Mdot
.82815 .01805 Mdot
.82818 .01682 Mdot
.8282 .0202 Mdot
.82823 .0165 Mdot
.82826 .01641 Mdot
.82828 .01627 Mdot
.82831 .01662 Mdot
.82833 .01544 Mdot
.82836 .0172 Mdot
.82838 .01639 Mdot
.82841 .01542 Mdot
.82844 .01501 Mdot
.82846 .01703 Mdot
.82849 .01657 Mdot
.82851 .01687 Mdot
.82854 .01555 Mdot
.82857 .01569 Mdot
.82859 .01631 Mdot
.82862 .01669 Mdot
.82864 .01682 Mdot
.82867 .01601 Mdot
.82869 .01638 Mdot
.82872 .01653 Mdot
.82875 .01573 Mdot
.82877 .01499 Mdot
.8288 .0167 Mdot
.82882 .01885 Mdot
.82885 .01834 Mdot
.82888 .01692 Mdot
.8289 .01541 Mdot
.82893 .01535 Mdot
.82895 .01648 Mdot
.82898 .01739 Mdot
.829 .01682 Mdot
.82903 .01633 Mdot
.82906 .01596 Mdot
.82908 .01592 Mdot
.82911 .01605 Mdot
.82913 .01671 Mdot
.82916 .0152 Mdot
.82919 .01641 Mdot
.82921 .01656 Mdot
.82924 .01699 Mdot
.82926 .01672 Mdot
.82929 .0163 Mdot
.82931 .01634 Mdot
.82934 .01679 Mdot
.82937 .01585 Mdot
.82939 .01703 Mdot
.82942 .01593 Mdot
.82944 .01734 Mdot
.82947 .01586 Mdot
.8295 .01736 Mdot
.82952 .01632 Mdot
.82955 .01565 Mdot
.82957 .01811 Mdot
.8296 .01798 Mdot
.82962 .01527 Mdot
.82965 .01691 Mdot
.82968 .01532 Mdot
.8297 .01606 Mdot
.82973 .01685 Mdot
.82975 .01686 Mdot
.82978 .01569 Mdot
.82981 .01685 Mdot
.82983 .01812 Mdot
.82986 .01609 Mdot
.82988 .01765 Mdot
.82991 .01658 Mdot
.82993 .01645 Mdot
.82996 .01598 Mdot
.82999 .01572 Mdot
.83001 .01674 Mdot
.83004 .01626 Mdot
.83006 .01596 Mdot
.83009 .01693 Mdot
.83012 .01657 Mdot
.83014 .01581 Mdot
.83017 .01801 Mdot
.83019 .01522 Mdot
.83022 .01722 Mdot
.83024 .01589 Mdot
.83027 .01564 Mdot
.8303 .01733 Mdot
.83032 .01905 Mdot
.83035 .01797 Mdot
.83037 .01645 Mdot
.8304 .01801 Mdot
.83043 .01545 Mdot
.83045 .01658 Mdot
.83048 .01601 Mdot
.8305 .01717 Mdot
.83053 .01615 Mdot
.83055 .01716 Mdot
.83058 .01703 Mdot
.83061 .01883 Mdot
.83063 .01554 Mdot
.83066 .01893 Mdot
.83068 .01743 Mdot
.83071 .01885 Mdot
.83074 .01484 Mdot
.83076 .01613 Mdot
.83079 .01887 Mdot
.83081 .01915 Mdot
.83084 .01709 Mdot
.83086 .01831 Mdot
.83089 .01879 Mdot
.83092 .01766 Mdot
.83094 .01693 Mdot
.83097 .01885 Mdot
.83099 .0167 Mdot
.83102 .01667 Mdot
.83105 .01571 Mdot
.83107 .01632 Mdot
.8311 .01769 Mdot
.83112 .01738 Mdot
.83115 .01769 Mdot
.83117 .01638 Mdot
.8312 .01704 Mdot
.83123 .01879 Mdot
.83125 .01876 Mdot
.83128 .01584 Mdot
.8313 .01766 Mdot
.83133 .01688 Mdot
.83136 .01748 Mdot
.83138 .01911 Mdot
.83141 .01786 Mdot
.83143 .0168 Mdot
.83146 .01733 Mdot
.83148 .01863 Mdot
.83151 .01679 Mdot
.83154 .01509 Mdot
.83156 .01631 Mdot
.83159 .01811 Mdot
.83161 .01598 Mdot
.83164 .01751 Mdot
.83167 .02093 Mdot
.83169 .01912 Mdot
.83172 .01804 Mdot
.83174 .01915 Mdot
.83177 .02102 Mdot
.83179 .02089 Mdot
.83182 .01958 Mdot
.83185 .01683 Mdot
.83187 .01672 Mdot
.8319 .01757 Mdot
.83192 .01631 Mdot
.83195 .01775 Mdot
.83198 .01706 Mdot
.832 .01501 Mdot
.83203 .01945 Mdot
.83205 .02308 Mdot
.83208 .02029 Mdot
.8321 .01865 Mdot
.83213 .01772 Mdot
.83216 .01847 Mdot
.83218 .017 Mdot
.83221 .01672 Mdot
.83223 .01807 Mdot
.83226 .01771 Mdot
.83229 .0171 Mdot
.83231 .02113 Mdot
.83234 .01778 Mdot
.83236 .01796 Mdot
.83239 .01605 Mdot
.83241 .01768 Mdot
.83244 .0166 Mdot
.83247 .01765 Mdot
.83249 .01592 Mdot
.83252 .01728 Mdot
.83254 .0161 Mdot
.83257 .01524 Mdot
.8326 .01634 Mdot
.83262 .01717 Mdot
.83265 .01765 Mdot
.83267 .01592 Mdot
.8327 .01761 Mdot
.83272 .01664 Mdot
.83275 .01668 Mdot
.83278 .01738 Mdot
.8328 .01529 Mdot
.83283 .01653 Mdot
.83285 .01688 Mdot
.83288 .01847 Mdot
.83291 .01716 Mdot
.83293 .01587 Mdot
.83296 .01795 Mdot
.83298 .01593 Mdot
.83301 .01511 Mdot
.83303 .01768 Mdot
.83306 .01862 Mdot
.83309 .01901 Mdot
.83311 .01847 Mdot
.83314 .01981 Mdot
.83316 .02064 Mdot
.83319 .01685 Mdot
.83322 .01539 Mdot
.83324 .01744 Mdot
.83327 .01563 Mdot
.83329 .01606 Mdot
.83332 .01578 Mdot
.83334 .01895 Mdot
.83337 .01798 Mdot
.8334 .01584 Mdot
.83342 .01825 Mdot
.83345 .01746 Mdot
.83347 .01777 Mdot
.8335 .01773 Mdot
.83353 .01903 Mdot
.83355 .0205 Mdot
.83358 .01924 Mdot
.8336 .01668 Mdot
.83363 .01872 Mdot
.83365 .02035 Mdot
.83368 .01679 Mdot
.83371 .01681 Mdot
.83373 .02001 Mdot
.83376 .01975 Mdot
.83378 .01501 Mdot
.83381 .02109 Mdot
.83384 .02233 Mdot
.83386 .02131 Mdot
.83389 .01968 Mdot
.83391 .02165 Mdot
.83394 .02175 Mdot
.83397 .01909 Mdot
.83399 .01769 Mdot
.83402 .01918 Mdot
.83404 .01754 Mdot
.83407 .01878 Mdot
.83409 .01867 Mdot
.83412 .01617 Mdot
.83415 .01802 Mdot
.83417 .01962 Mdot
.8342 .01735 Mdot
.83422 .01622 Mdot
.83425 .01653 Mdot
.83428 .01706 Mdot
.8343 .0168 Mdot
.83433 .01705 Mdot
.83435 .01714 Mdot
.83438 .01619 Mdot
.8344 .01599 Mdot
.83443 .01675 Mdot
.83446 .01988 Mdot
.83448 .01917 Mdot
.83451 .01991 Mdot
.83453 .01973 Mdot
.83456 .01814 Mdot
.83459 .01837 Mdot
.83461 .01678 Mdot
.83464 .0171 Mdot
.83466 .01742 Mdot
.83469 .01727 Mdot
.83471 .01972 Mdot
.83474 .01763 Mdot
.83477 .02057 Mdot
.83479 .01798 Mdot
.83482 .01842 Mdot
.83484 .01675 Mdot
.83487 .01697 Mdot
.8349 .01646 Mdot
.83492 .0166 Mdot
.83495 .01666 Mdot
.83497 .01539 Mdot
.835 .01823 Mdot
.83502 .01773 Mdot
.83505 .01728 Mdot
.83508 .01692 Mdot
.8351 .01888 Mdot
.83513 .01972 Mdot
.83515 .0167 Mdot
.83518 .01689 Mdot
.83521 .01696 Mdot
.83523 .01718 Mdot
.83526 .01576 Mdot
.83528 .01619 Mdot
.83531 .0159 Mdot
.83533 .01543 Mdot
.83536 .01623 Mdot
.83539 .01745 Mdot
.83541 .01705 Mdot
.83544 .01498 Mdot
.83546 .01653 Mdot
.83549 .0158 Mdot
.83552 .01556 Mdot
.83554 .01491 Mdot
.83557 .01628 Mdot
.83559 .01763 Mdot
.83562 .01588 Mdot
.83564 .01663 Mdot
.83567 .01726 Mdot
.8357 .01734 Mdot
.83572 .0161 Mdot
.83575 .01711 Mdot
.83577 .0157 Mdot
.8358 .01493 Mdot
.83583 .01607 Mdot
.83585 .01673 Mdot
.83588 .01568 Mdot
.8359 .01767 Mdot
.83593 .01535 Mdot
.83595 .01744 Mdot
.83598 .01574 Mdot
.83601 .01782 Mdot
.83603 .01513 Mdot
.83606 .01584 Mdot
.83608 .01625 Mdot
.83611 .01644 Mdot
.83614 .01613 Mdot
.83616 .01685 Mdot
.83619 .01635 Mdot
.83621 .01875 Mdot
.83624 .01563 Mdot
.83626 .01651 Mdot
.83629 .01951 Mdot
.83632 .01599 Mdot
.83634 .01675 Mdot
.83637 .01748 Mdot
.83639 .01537 Mdot
.83642 .01688 Mdot
.83645 .01549 Mdot
.83647 .01531 Mdot
.8365 .01682 Mdot
.83652 .01727 Mdot
.83655 .01655 Mdot
.83657 .0151 Mdot
.8366 .01648 Mdot
.83663 .01532 Mdot
.83665 .01529 Mdot
.83668 .0152 Mdot
.8367 .01596 Mdot
.83673 .01645 Mdot
.83676 .01495 Mdot
.83678 .01591 Mdot
.83681 .01646 Mdot
.83683 .01894 Mdot
.83686 .01696 Mdot
.83688 .01663 Mdot
.83691 .01735 Mdot
.83694 .0179 Mdot
.83696 .01958 Mdot
.83699 .0168 Mdot
.83701 .01834 Mdot
.83704 .01634 Mdot
.83707 .01854 Mdot
.83709 .01999 Mdot
.83712 .02097 Mdot
.83714 .01749 Mdot
.83717 .01569 Mdot
.83719 .01743 Mdot
.83722 .02181 Mdot
.83725 .02276 Mdot
.83727 .01969 Mdot
.8373 .01881 Mdot
.83732 .01873 Mdot
.83735 .01882 Mdot
.83738 .01642 Mdot
.8374 .0216 Mdot
.83743 .01943 Mdot
.83745 .01585 Mdot
.83748 .01916 Mdot
.8375 .01628 Mdot
.83753 .0183 Mdot
.83756 .01495 Mdot
.83758 .01885 Mdot
.83761 .01736 Mdot
.83763 .01764 Mdot
.83766 .01803 Mdot
.83769 .01962 Mdot
.83771 .01728 Mdot
.83774 .01604 Mdot
.83776 .01709 Mdot
.83779 .01646 Mdot
.83781 .01764 Mdot
.83784 .01723 Mdot
.83787 .01506 Mdot
.83789 .01556 Mdot
.83792 .01755 Mdot
.83794 .0156 Mdot
.83797 .01565 Mdot
.838 .0164 Mdot
.83802 .01689 Mdot
.83805 .0199 Mdot
.83807 .01693 Mdot
.8381 .01663 Mdot
.83812 .01601 Mdot
.83815 .01618 Mdot
.83818 .01574 Mdot
.8382 .01546 Mdot
.83823 .01832 Mdot
.83825 .01559 Mdot
.83828 .01599 Mdot
.83831 .01703 Mdot
.83833 .02107 Mdot
.83836 .02271 Mdot
.83838 .02091 Mdot
.83841 .02223 Mdot
.83843 .0193 Mdot
.83846 .01877 Mdot
.83849 .01849 Mdot
.83851 .01786 Mdot
.83854 .01753 Mdot
.83856 .01962 Mdot
.83859 .02158 Mdot
.83862 .02151 Mdot
.83864 .02257 Mdot
.83867 .02169 Mdot
.83869 .0176 Mdot
.83872 .01604 Mdot
.83874 .01829 Mdot
.83877 .02199 Mdot
.8388 .01949 Mdot
.83882 .02036 Mdot
.83885 .02031 Mdot
.83887 .0182 Mdot
.8389 .01797 Mdot
.83893 .02058 Mdot
.83895 .01758 Mdot
.83898 .01976 Mdot
.839 .01926 Mdot
.83903 .01747 Mdot
.83905 .01768 Mdot
.83908 .01876 Mdot
.83911 .01692 Mdot
.83913 .01773 Mdot
.83916 .01612 Mdot
.83918 .02101 Mdot
.83921 .01669 Mdot
.83924 .0148 Mdot
.83926 .01934 Mdot
.83929 .01709 Mdot
.83931 .02009 Mdot
.83934 .01662 Mdot
.83936 .01752 Mdot
.83939 .01548 Mdot
.83942 .01887 Mdot
.83944 .01954 Mdot
.83947 .01943 Mdot
.83949 .0153 Mdot
.83952 .01795 Mdot
.83955 .017 Mdot
.83957 .01694 Mdot
.8396 .01658 Mdot
.83962 .01865 Mdot
.83965 .01784 Mdot
.83967 .01592 Mdot
.8397 .01571 Mdot
.83973 .01847 Mdot
.83975 .01833 Mdot
.83978 .01754 Mdot
.8398 .01799 Mdot
.83983 .01985 Mdot
.83986 .02121 Mdot
.83988 .01687 Mdot
.83991 .02006 Mdot
.83993 .02142 Mdot
.83996 .01834 Mdot
.83998 .01764 Mdot
.84001 .02071 Mdot
.84004 .01692 Mdot
.84006 .01616 Mdot
.84009 .02281 Mdot
.84011 .02163 Mdot
.84014 .01877 Mdot
.84017 .01886 Mdot
.84019 .02329 Mdot
.84022 .02298 Mdot
.84024 .02014 Mdot
.84027 .02177 Mdot
.84029 .02342 Mdot
.84032 .01754 Mdot
.84035 .02034 Mdot
.84037 .0202 Mdot
.8404 .01701 Mdot
.84042 .01758 Mdot
.84045 .01721 Mdot
.84048 .01794 Mdot
.8405 .02143 Mdot
.84053 .01891 Mdot
.84055 .01773 Mdot
.84058 .01843 Mdot
.8406 .01694 Mdot
.84063 .01703 Mdot
.84066 .01636 Mdot
.84068 .0183 Mdot
.84071 .01576 Mdot
.84073 .01617 Mdot
.84076 .01686 Mdot
.84079 .01851 Mdot
.84081 .01666 Mdot
.84084 .01811 Mdot
.84086 .01688 Mdot
.84089 .01661 Mdot
.84091 .01604 Mdot
.84094 .01694 Mdot
.84097 .0177 Mdot
.84099 .01786 Mdot
.84102 .0177 Mdot
.84104 .01977 Mdot
.84107 .02102 Mdot
.8411 .01909 Mdot
.84112 .01961 Mdot
.84115 .01921 Mdot
.84117 .01851 Mdot
.8412 .01729 Mdot
.84122 .01868 Mdot
.84125 .01769 Mdot
.84128 .01558 Mdot
.8413 .01659 Mdot
.84133 .01695 Mdot
.84135 .01749 Mdot
.84138 .01545 Mdot
.84141 .01642 Mdot
.84143 .01704 Mdot
.84146 .01643 Mdot
.84148 .01781 Mdot
.84151 .01672 Mdot
.84153 .01759 Mdot
.84156 .01724 Mdot
.84159 .01491 Mdot
.84161 .01694 Mdot
.84164 .01643 Mdot
.84166 .01593 Mdot
.84169 .0164 Mdot
.84172 .0174 Mdot
.84174 .01599 Mdot
.84177 .01674 Mdot
.84179 .01596 Mdot
.84182 .0172 Mdot
.84184 .01556 Mdot
.84187 .01709 Mdot
.8419 .01634 Mdot
.84192 .01725 Mdot
.84195 .0188 Mdot
.84197 .01661 Mdot
.842 .01869 Mdot
.84203 .01572 Mdot
.84205 .0169 Mdot
.84208 .01596 Mdot
.8421 .01834 Mdot
.84213 .01714 Mdot
.84215 .01645 Mdot
.84218 .01777 Mdot
.84221 .01631 Mdot
.84223 .01553 Mdot
.84226 .01724 Mdot
.84228 .01658 Mdot
.84231 .01655 Mdot
.84234 .01505 Mdot
.84236 .0163 Mdot
.84239 .01685 Mdot
.84241 .01797 Mdot
.84244 .01629 Mdot
.84246 .01561 Mdot
.84249 .01643 Mdot
.84252 .01789 Mdot
.84254 .01614 Mdot
.84257 .01646 Mdot
.84259 .0166 Mdot
.84262 .016 Mdot
.84265 .01558 Mdot
.84267 .01681 Mdot
.8427 .01648 Mdot
.84272 .0179 Mdot
.84275 .0167 Mdot
.84277 .01589 Mdot
.8428 .01711 Mdot
.84283 .01735 Mdot
.84285 .01978 Mdot
.84288 .01982 Mdot
.8429 .01582 Mdot
.84293 .01913 Mdot
.84296 .01683 Mdot
.84298 .0172 Mdot
.84301 .01609 Mdot
.84303 .017 Mdot
.84306 .01901 Mdot
.84309 .01815 Mdot
.84311 .02104 Mdot
.84314 .02031 Mdot
.84316 .01731 Mdot
.84319 .01872 Mdot
.84321 .01749 Mdot
.84324 .01832 Mdot
.84327 .01905 Mdot
.84329 .01623 Mdot
.84332 .01888 Mdot
.84334 .01818 Mdot
.84337 .01809 Mdot
.8434 .01694 Mdot
.84342 .01815 Mdot
.84345 .01984 Mdot
.84347 .02109 Mdot
.8435 .02236 Mdot
.84352 .02112 Mdot
.84355 .01694 Mdot
.84358 .0186 Mdot
.8436 .01856 Mdot
.84363 .02354 Mdot
.84365 .02113 Mdot
.84368 .01756 Mdot
.84371 .01568 Mdot
.84373 .01779 Mdot
.84376 .01773 Mdot
.84378 .01863 Mdot
.84381 .01939 Mdot
.84383 .01927 Mdot
.84386 .01961 Mdot
.84389 .01775 Mdot
.84391 .01945 Mdot
.84394 .01805 Mdot
.84396 .01768 Mdot
.84399 .01903 Mdot
.84402 .01885 Mdot
.84404 .01949 Mdot
.84407 .0169 Mdot
.84409 .01679 Mdot
.84412 .01746 Mdot
.84414 .01554 Mdot
.84417 .01716 Mdot
.8442 .01528 Mdot
.84422 .01678 Mdot
.84425 .01569 Mdot
.84427 .02006 Mdot
.8443 .01966 Mdot
.84433 .01756 Mdot
.84435 .01971 Mdot
.84438 .0196 Mdot
.8444 .02141 Mdot
.84443 .01853 Mdot
.84445 .01902 Mdot
.84448 .02036 Mdot
.84451 .01725 Mdot
.84453 .01516 Mdot
.84456 .01685 Mdot
.84458 .02154 Mdot
.84461 .02251 Mdot
.84464 .02544 Mdot
.84466 .02321 Mdot
.84469 .02369 Mdot
.84471 .02277 Mdot
.84474 .01954 Mdot
.84476 .02186 Mdot
.84479 .01914 Mdot
.84482 .01738 Mdot
.84484 .02143 Mdot
.84487 .01986 Mdot
.84489 .01987 Mdot
.84492 .02195 Mdot
.84495 .02265 Mdot
.84497 .01965 Mdot
.845 .01733 Mdot
.84502 .0185 Mdot
.84505 .02149 Mdot
.84507 .02145 Mdot
.8451 .02373 Mdot
.84513 .02343 Mdot
.84515 .02007 Mdot
.84518 .02085 Mdot
.8452 .01962 Mdot
.84523 .01935 Mdot
.84526 .02492 Mdot
.84528 .02643 Mdot
.84531 .02184 Mdot
.84533 .01685 Mdot
.84536 .01854 Mdot
.84538 .02196 Mdot
.84541 .0212 Mdot
.84544 .02235 Mdot
.84546 .02165 Mdot
.84549 .02145 Mdot
.84551 .01741 Mdot
.84554 .01946 Mdot
.84557 .02074 Mdot
.84559 .02535 Mdot
.84562 .02112 Mdot
.84564 .02001 Mdot
.84567 .01866 Mdot
.84569 .02221 Mdot
.84572 .01948 Mdot
.84575 .02029 Mdot
.84577 .01778 Mdot
.8458 .01747 Mdot
.84582 .02003 Mdot
.84585 .01895 Mdot
.84588 .01711 Mdot
.8459 .01957 Mdot
.84593 .02089 Mdot
.84595 .01535 Mdot
.84598 .01735 Mdot
.846 .01925 Mdot
.84603 .02016 Mdot
.84606 .01896 Mdot
.84608 .01874 Mdot
.84611 .01992 Mdot
.84613 .02111 Mdot
.84616 .01751 Mdot
.84619 .02064 Mdot
.84621 .02415 Mdot
.84624 .02116 Mdot
.84626 .0205 Mdot
.84629 .01913 Mdot
.84631 .01634 Mdot
.84634 .02015 Mdot
.84637 .0223 Mdot
.84639 .01996 Mdot
.84642 .01673 Mdot
.84644 .02239 Mdot
.84647 .02382 Mdot
.8465 .02177 Mdot
.84652 .01737 Mdot
.84655 .02165 Mdot
.84657 .02013 Mdot
.8466 .01656 Mdot
.84662 .01549 Mdot
.84665 .02142 Mdot
.84668 .016 Mdot
.8467 .01552 Mdot
.84673 .01904 Mdot
.84675 .01894 Mdot
.84678 .02061 Mdot
.84681 .02125 Mdot
.84683 .0225 Mdot
.84686 .02158 Mdot
.84688 .0234 Mdot
.84691 .02136 Mdot
.84693 .02341 Mdot
.84696 .0199 Mdot
.84699 .01894 Mdot
.84701 .01958 Mdot
.84704 .01713 Mdot
.84706 .01767 Mdot
.84709 .01513 Mdot
.84712 .0181 Mdot
.84714 .01559 Mdot
.84717 .01885 Mdot
.84719 .01782 Mdot
.84722 .01872 Mdot
.84724 .01657 Mdot
.84727 .01515 Mdot
.8473 .0177 Mdot
.84732 .01618 Mdot
.84735 .01816 Mdot
.84737 .0184 Mdot
.8474 .01529 Mdot
.84743 .01583 Mdot
.84745 .01674 Mdot
.84748 .01679 Mdot
.8475 .01859 Mdot
.84753 .0199 Mdot
.84755 .0191 Mdot
.84758 .02021 Mdot
.84761 .02049 Mdot
.84763 .02129 Mdot
.84766 .0194 Mdot
.84768 .01698 Mdot
.84771 .01645 Mdot
.84774 .01843 Mdot
.84776 .01698 Mdot
.84779 .01566 Mdot
.84781 .01674 Mdot
.84784 .01727 Mdot
.84786 .01605 Mdot
.84789 .01617 Mdot
.84792 .01681 Mdot
.84794 .01742 Mdot
.84797 .01653 Mdot
.84799 .01566 Mdot
.84802 .01543 Mdot
.84805 .0156 Mdot
.84807 .01749 Mdot
.8481 .01759 Mdot
.84812 .01585 Mdot
.84815 .01565 Mdot
.84817 .01648 Mdot
.8482 .01595 Mdot
.84823 .01693 Mdot
.84825 .01553 Mdot
.84828 .01635 Mdot
.8483 .01648 Mdot
.84833 .01614 Mdot
.84836 .0158 Mdot
.84838 .01601 Mdot
.84841 .01663 Mdot
.84843 .01589 Mdot
.84846 .01557 Mdot
.84848 .01608 Mdot
.84851 .016 Mdot
.84854 .01693 Mdot
.84856 .01693 Mdot
.84859 .01667 Mdot
.84861 .01619 Mdot
.84864 .01691 Mdot
.84867 .01753 Mdot
.84869 .01681 Mdot
.84872 .01845 Mdot
.84874 .017 Mdot
.84877 .01636 Mdot
.84879 .01703 Mdot
.84882 .01669 Mdot
.84885 .01544 Mdot
.84887 .01681 Mdot
.8489 .01622 Mdot
.84892 .01631 Mdot
.84895 .01791 Mdot
.84898 .01665 Mdot
.849 .01559 Mdot
.84903 .01602 Mdot
.84905 .01676 Mdot
.84908 .0178 Mdot
.8491 .01692 Mdot
.84913 .01603 Mdot
.84916 .01981 Mdot
.84918 .01856 Mdot
.84921 .01568 Mdot
.84923 .02029 Mdot
.84926 .01883 Mdot
.84929 .01504 Mdot
.84931 .0193 Mdot
.84934 .01999 Mdot
.84936 .02122 Mdot
.84939 .021 Mdot
.84941 .02038 Mdot
.84944 .0217 Mdot
.84947 .02016 Mdot
.84949 .02259 Mdot
.84952 .02173 Mdot
.84954 .0177 Mdot
.84957 .02163 Mdot
.8496 .02195 Mdot
.84962 .02305 Mdot
.84965 .01936 Mdot
.84967 .01921 Mdot
.8497 .01995 Mdot
.84972 .01848 Mdot
.84975 .01882 Mdot
.84978 .02034 Mdot
.8498 .01987 Mdot
.84983 .0196 Mdot
.84985 .01956 Mdot
.84988 .02217 Mdot
.84991 .02196 Mdot
.84993 .02163 Mdot
.84996 .01887 Mdot
.84998 .01794 Mdot
.85001 .01845 Mdot
.85003 .01979 Mdot
.85006 .0195 Mdot
.85009 .01536 Mdot
.85011 .01808 Mdot
.85014 .01823 Mdot
.85016 .01612 Mdot
.85019 .01541 Mdot
.85022 .01964 Mdot
.85024 .01755 Mdot
.85027 .01817 Mdot
.85029 .01985 Mdot
.85032 .01749 Mdot
.85034 .01976 Mdot
.85037 .01542 Mdot
.8504 .01898 Mdot
.85042 .01714 Mdot
.85045 .01621 Mdot
.85047 .0159 Mdot
.8505 .01794 Mdot
.85053 .01689 Mdot
.85055 .01529 Mdot
.85058 .01698 Mdot
.8506 .01665 Mdot
.85063 .01816 Mdot
.85065 .01959 Mdot
.85068 .01949 Mdot
.85071 .0209 Mdot
.85073 .01836 Mdot
.85076 .01708 Mdot
.85078 .01823 Mdot
.85081 .01612 Mdot
.85084 .01541 Mdot
.85086 .01921 Mdot
.85089 .01922 Mdot
.85091 .01825 Mdot
.85094 .02034 Mdot
.85096 .01995 Mdot
.85099 .02164 Mdot
.85102 .02018 Mdot
.85104 .01699 Mdot
.85107 .01799 Mdot
.85109 .01621 Mdot
.85112 .01578 Mdot
.85115 .01841 Mdot
.85117 .01844 Mdot
.8512 .01975 Mdot
.85122 .02123 Mdot
.85125 .02116 Mdot
.85127 .01817 Mdot
.8513 .01862 Mdot
.85133 .02092 Mdot
.85135 .02286 Mdot
.85138 .02235 Mdot
.8514 .02016 Mdot
.85143 .02169 Mdot
.85146 .02032 Mdot
.85148 .01822 Mdot
.85151 .0227 Mdot
.85153 .02123 Mdot
.85156 .02107 Mdot
.85158 .01807 Mdot
.85161 .01822 Mdot
.85164 .02123 Mdot
.85166 .01736 Mdot
.85169 .0166 Mdot
.85171 .01913 Mdot
.85174 .01925 Mdot
.85177 .01797 Mdot
.85179 .01871 Mdot
.85182 .01698 Mdot
.85184 .02316 Mdot
.85187 .01828 Mdot
.85189 .01717 Mdot
.85192 .01731 Mdot
.85195 .01599 Mdot
.85197 .01924 Mdot
.852 .01607 Mdot
.85202 .0177 Mdot
.85205 .01538 Mdot
.85208 .01571 Mdot
.8521 .01734 Mdot
.85213 .01696 Mdot
.85215 .01578 Mdot
.85218 .0193 Mdot
.85221 .0177 Mdot
.85223 .01824 Mdot
.85226 .01941 Mdot
.85228 .01829 Mdot
.85231 .02196 Mdot
.85233 .0171 Mdot
.85236 .0181 Mdot
.85239 .02044 Mdot
.85241 .02073 Mdot
.85244 .01526 Mdot
.85246 .02026 Mdot
.85249 .02027 Mdot
.85252 .01999 Mdot
.85254 .01582 Mdot
.85257 .01565 Mdot
.85259 .0186 Mdot
.85262 .01961 Mdot
.85264 .01814 Mdot
.85267 .01536 Mdot
.8527 .0173 Mdot
.85272 .01834 Mdot
.85275 .01813 Mdot
.85277 .01845 Mdot
.8528 .01863 Mdot
.85283 .01643 Mdot
.85285 .0178 Mdot
.85288 .01868 Mdot
.8529 .01748 Mdot
.85293 .01996 Mdot
.85295 .01649 Mdot
.85298 .01677 Mdot
.85301 .01776 Mdot
.85303 .01684 Mdot
.85306 .01874 Mdot
.85308 .01847 Mdot
.85311 .01842 Mdot
.85314 .02108 Mdot
.85316 .01942 Mdot
.85319 .02132 Mdot
.85321 .01912 Mdot
.85324 .02235 Mdot
.85326 .02028 Mdot
.85329 .01908 Mdot
.85332 .01853 Mdot
.85334 .01896 Mdot
.85337 .02087 Mdot
.85339 .01767 Mdot
.85342 .01776 Mdot
.85345 .01925 Mdot
.85347 .01933 Mdot
.8535 .02038 Mdot
.85352 .01995 Mdot
.85355 .01678 Mdot
.85357 .01758 Mdot
.8536 .01569 Mdot
.85363 .01671 Mdot
.85365 .01644 Mdot
.85368 .01678 Mdot
.8537 .01618 Mdot
.85373 .01686 Mdot
.85376 .01633 Mdot
.85378 .01549 Mdot
.85381 .01591 Mdot
.85383 .01807 Mdot
.85386 .01496 Mdot
.85388 .01595 Mdot
.85391 .0168 Mdot
.85394 .01554 Mdot
.85396 .01578 Mdot
.85399 .01496 Mdot
.85401 .01606 Mdot
.85404 .01644 Mdot
.85407 .01725 Mdot
.85409 .01668 Mdot
.85412 .01679 Mdot
.85414 .01657 Mdot
.85417 .01674 Mdot
.85419 .0166 Mdot
.85422 .01576 Mdot
.85425 .01644 Mdot
.85427 .01582 Mdot
.8543 .01727 Mdot
.85432 .01547 Mdot
.85435 .01826 Mdot
.85438 .01659 Mdot
.8544 .0173 Mdot
.85443 .0183 Mdot
.85445 .01679 Mdot
.85448 .01588 Mdot
.8545 .01669 Mdot
.85453 .0182 Mdot
.85456 .0168 Mdot
.85458 .0173 Mdot
.85461 .01932 Mdot
.85463 .01593 Mdot
.85466 .01541 Mdot
.85469 .01754 Mdot
.85471 .01741 Mdot
.85474 .01756 Mdot
.85476 .01585 Mdot
.85479 .01661 Mdot
.85481 .01742 Mdot
.85484 .01854 Mdot
.85487 .0177 Mdot
.85489 .01691 Mdot
.85492 .01541 Mdot
.85494 .019 Mdot
.85497 .01915 Mdot
.855 .01696 Mdot
.85502 .01966 Mdot
.85505 .0185 Mdot
.85507 .01631 Mdot
.8551 .01788 Mdot
.85512 .01663 Mdot
.85515 .01607 Mdot
.85518 .01586 Mdot
.8552 .0164 Mdot
.85523 .0179 Mdot
.85525 .01777 Mdot
.85528 .016 Mdot
.85531 .0179 Mdot
.85533 .01556 Mdot
.85536 .01544 Mdot
.85538 .01616 Mdot
.85541 .01916 Mdot
.85543 .02025 Mdot
.85546 .01834 Mdot
.85549 .01648 Mdot
.85551 .01757 Mdot
.85554 .01735 Mdot
.85556 .01895 Mdot
.85559 .01899 Mdot
.85562 .01825 Mdot
.85564 .01983 Mdot
.85567 .02164 Mdot
.85569 .02146 Mdot
.85572 .02505 Mdot
.85574 .02021 Mdot
.85577 .02148 Mdot
.8558 .0225 Mdot
.85582 .02482 Mdot
.85585 .02375 Mdot
.85587 .02496 Mdot
.8559 .02516 Mdot
.85593 .02315 Mdot
.85595 .0235 Mdot
.85598 .02519 Mdot
.856 .02288 Mdot
.85603 .02351 Mdot
.85605 .0216 Mdot
.85608 .0211 Mdot
.85611 .02392 Mdot
.85613 .02756 Mdot
.85616 .02553 Mdot
.85618 .02165 Mdot
.85621 .0225 Mdot
.85624 .02313 Mdot
.85626 .02383 Mdot
.85629 .02027 Mdot
.85631 .02561 Mdot
.85634 .02686 Mdot
.85636 .01979 Mdot
.85639 .02128 Mdot
.85642 .02161 Mdot
.85644 .02351 Mdot
.85647 .02197 Mdot
.85649 .0223 Mdot
.85652 .02063 Mdot
.85655 .02305 Mdot
.85657 .02005 Mdot
.8566 .02084 Mdot
.85662 .02337 Mdot
.85665 .02653 Mdot
.85667 .02468 Mdot
.8567 .02562 Mdot
.85673 .02481 Mdot
.85675 .02612 Mdot
.85678 .0212 Mdot
.8568 .02 Mdot
.85683 .01591 Mdot
.85686 .02128 Mdot
.85688 .01828 Mdot
.85691 .01908 Mdot
.85693 .0231 Mdot
.85696 .02024 Mdot
.85698 .02299 Mdot
.85701 .01879 Mdot
.85704 .02695 Mdot
.85706 .02187 Mdot
.85709 .01981 Mdot
.85711 .0222 Mdot
.85714 .0206 Mdot
.85717 .0185 Mdot
.85719 .0164 Mdot
.85722 .01986 Mdot
.85724 .02434 Mdot
.85727 .02502 Mdot
.85729 .02245 Mdot
.85732 .02287 Mdot
.85735 .01922 Mdot
.85737 .01605 Mdot
.8574 .0187 Mdot
.85742 .01926 Mdot
.85745 .01913 Mdot
.85748 .02059 Mdot
.8575 .02175 Mdot
.85753 .02074 Mdot
.85755 .02328 Mdot
.85758 .01967 Mdot
.8576 .0186 Mdot
.85763 .02121 Mdot
.85766 .01959 Mdot
.85768 .02167 Mdot
.85771 .02207 Mdot
.85773 .02188 Mdot
.85776 .022 Mdot
.85779 .02292 Mdot
.85781 .02325 Mdot
.85784 .02495 Mdot
.85786 .02222 Mdot
.85789 .02371 Mdot
.85791 .01973 Mdot
.85794 .01873 Mdot
.85797 .01849 Mdot
.85799 .02332 Mdot
.85802 .02081 Mdot
.85804 .0197 Mdot
.85807 .01856 Mdot
.8581 .01781 Mdot
.85812 .01757 Mdot
.85815 .01694 Mdot
.85817 .01806 Mdot
.8582 .01981 Mdot
.85822 .01706 Mdot
.85825 .01601 Mdot
.85828 .01793 Mdot
.8583 .01695 Mdot
.85833 .01776 Mdot
.85835 .01649 Mdot
.85838 .01853 Mdot
.85841 .02086 Mdot
.85843 .02106 Mdot
.85846 .02166 Mdot
.85848 .01912 Mdot
.85851 .0206 Mdot
.85853 .02228 Mdot
.85856 .02094 Mdot
.85859 .0206 Mdot
.85861 .01751 Mdot
.85864 .02202 Mdot
.85866 .02665 Mdot
.85869 .02485 Mdot
.85872 .01718 Mdot
.85874 .02645 Mdot
.85877 .02509 Mdot
.85879 .02194 Mdot
.85882 .01889 Mdot
.85884 .02074 Mdot
.85887 .02399 Mdot
.8589 .02216 Mdot
.85892 .0155 Mdot
.85895 .02023 Mdot
.85897 .01924 Mdot
.859 .01703 Mdot
.85903 .01943 Mdot
.85905 .0186 Mdot
.85908 .02056 Mdot
.8591 .01861 Mdot
.85913 .02187 Mdot
.85915 .02139 Mdot
.85918 .02291 Mdot
.85921 .02163 Mdot
.85923 .01947 Mdot
.85926 .02022 Mdot
.85928 .01743 Mdot
.85931 .01545 Mdot
.85934 .01645 Mdot
.85936 .01634 Mdot
.85939 .01672 Mdot
.85941 .01728 Mdot
.85944 .01626 Mdot
.85946 .01798 Mdot
.85949 .01777 Mdot
.85952 .01846 Mdot
.85954 .01703 Mdot
.85957 .02111 Mdot
.85959 .01686 Mdot
.85962 .02043 Mdot
.85965 .02207 Mdot
.85967 .01947 Mdot
.8597 .01694 Mdot
.85972 .02023 Mdot
.85975 .02018 Mdot
.85977 .0209 Mdot
.8598 .02089 Mdot
.85983 .0193 Mdot
.85985 .01733 Mdot
.85988 .01885 Mdot
.8599 .01709 Mdot
.85993 .02032 Mdot
.85996 .01826 Mdot
.85998 .01872 Mdot
.86001 .01826 Mdot
.86003 .01651 Mdot
.86006 .0181 Mdot
.86008 .02008 Mdot
.86011 .01982 Mdot
.86014 .01925 Mdot
.86016 .01884 Mdot
.86019 .01712 Mdot
.86021 .01647 Mdot
.86024 .01731 Mdot
.86027 .0188 Mdot
.86029 .01946 Mdot
.86032 .01895 Mdot
.86034 .01988 Mdot
.86037 .01693 Mdot
.86039 .02086 Mdot
.86042 .02213 Mdot
.86045 .01846 Mdot
.86047 .02071 Mdot
.8605 .01879 Mdot
.86052 .01675 Mdot
.86055 .02069 Mdot
.86058 .02074 Mdot
.8606 .01847 Mdot
.86063 .01703 Mdot
.86065 .01694 Mdot
.86068 .01736 Mdot
.8607 .01595 Mdot
.86073 .01657 Mdot
.86076 .01655 Mdot
.86078 .01544 Mdot
.86081 .01534 Mdot
.86083 .01735 Mdot
.86086 .02064 Mdot
.86089 .01937 Mdot
.86091 .01909 Mdot
.86094 .01708 Mdot
.86096 .01869 Mdot
.86099 .0201 Mdot
.86101 .02519 Mdot
.86104 .02014 Mdot
.86107 .02062 Mdot
.86109 .01965 Mdot
.86112 .02065 Mdot
.86114 .01775 Mdot
.86117 .0164 Mdot
.8612 .01579 Mdot
.86122 .01696 Mdot
.86125 .01856 Mdot
.86127 .01659 Mdot
.8613 .0176 Mdot
.86133 .01754 Mdot
.86135 .01789 Mdot
.86138 .01632 Mdot
.8614 .01543 Mdot
.86143 .01697 Mdot
.86145 .01644 Mdot
.86148 .01636 Mdot
.86151 .01964 Mdot
.86153 .02023 Mdot
.86156 .01896 Mdot
.86158 .01753 Mdot
.86161 .01671 Mdot
.86164 .0208 Mdot
.86166 .01697 Mdot
.86169 .01913 Mdot
.86171 .01623 Mdot
.86174 .01937 Mdot
.86176 .01951 Mdot
.86179 .01573 Mdot
.86182 .01768 Mdot
.86184 .01623 Mdot
.86187 .01645 Mdot
.86189 .0184 Mdot
.86192 .01766 Mdot
.86195 .02083 Mdot
.86197 .0219 Mdot
.862 .02248 Mdot
.86202 .01805 Mdot
.86205 .01872 Mdot
.86207 .0206 Mdot
.8621 .02206 Mdot
.86213 .02544 Mdot
.86215 .02378 Mdot
.86218 .02333 Mdot
.8622 .02208 Mdot
.86223 .02862 Mdot
.86226 .02561 Mdot
.86228 .02374 Mdot
.86231 .02224 Mdot
.86233 .01936 Mdot
.86236 .01958 Mdot
.86238 .02157 Mdot
.86241 .02902 Mdot
.86244 .02834 Mdot
.86246 .02115 Mdot
.86249 .01891 Mdot
.86251 .02857 Mdot
.86254 .03408 Mdot
.86257 .0305 Mdot
.86259 .02827 Mdot
.86262 .01906 Mdot
.86264 .02549 Mdot
.86267 .02799 Mdot
.86269 .02436 Mdot
.86272 .02986 Mdot
.86275 .02598 Mdot
.86277 .02149 Mdot
.8628 .02176 Mdot
.86282 .0188 Mdot
.86285 .02007 Mdot
.86288 .02498 Mdot
.8629 .02353 Mdot
.86293 .02361 Mdot
.86295 .04046 Mdot
.86298 .04447 Mdot
.863 .03691 Mdot
.86303 .02479 Mdot
.86306 .01841 Mdot
.86308 .02742 Mdot
.86311 .03082 Mdot
.86313 .03288 Mdot
.86316 .03181 Mdot
.86319 .02412 Mdot
.86321 .02664 Mdot
.86324 .03541 Mdot
.86326 .03708 Mdot
.86329 .02955 Mdot
.86331 .02938 Mdot
.86334 .03162 Mdot
.86337 .03556 Mdot
.86339 .03276 Mdot
.86342 .02446 Mdot
.86344 .02038 Mdot
.86347 .01907 Mdot
.8635 .03073 Mdot
.86352 .03331 Mdot
.86355 .02892 Mdot
.86357 .02578 Mdot
.8636 .03151 Mdot
.86362 .03089 Mdot
.86365 .02575 Mdot
.86368 .0229 Mdot
.8637 .02149 Mdot
.86373 .02321 Mdot
.86375 .03025 Mdot
.86378 .03968 Mdot
.86381 .03584 Mdot
.86383 .02604 Mdot
.86386 .02131 Mdot
.86388 .01579 Mdot
.86391 .0222 Mdot
.86393 .0314 Mdot
.86396 .0311 Mdot
.86399 .03411 Mdot
.86401 .03127 Mdot
.86404 .02756 Mdot
.86406 .02443 Mdot
.86409 .02689 Mdot
.86412 .03542 Mdot
.86414 .03918 Mdot
.86417 .03078 Mdot
.86419 .01927 Mdot
.86422 .02871 Mdot
.86424 .02665 Mdot
.86427 .02861 Mdot
.8643 .0345 Mdot
.86432 .03313 Mdot
.86435 .01838 Mdot
.86437 .02431 Mdot
.8644 .02331 Mdot
.86443 .02209 Mdot
.86445 .02603 Mdot
.86448 .03199 Mdot
.8645 .02647 Mdot
.86453 .01775 Mdot
.86455 .0231 Mdot
.86458 .02868 Mdot
.86461 .03202 Mdot
.86463 .02733 Mdot
.86466 .03484 Mdot
.86468 .03485 Mdot
.86471 .0349 Mdot
.86474 .02738 Mdot
.86476 .029 Mdot
.86479 .04122 Mdot
.86481 .04262 Mdot
.86484 .02265 Mdot
.86486 .03653 Mdot
.86489 .0435 Mdot
.86492 .03911 Mdot
.86494 .02702 Mdot
.86497 .02342 Mdot
.86499 .03011 Mdot
.86502 .03246 Mdot
.86505 .03023 Mdot
.86507 .02513 Mdot
.8651 .02559 Mdot
.86512 .03557 Mdot
.86515 .03757 Mdot
.86517 .02436 Mdot
.8652 .02398 Mdot
.86523 .0221 Mdot
.86525 .01847 Mdot
.86528 .01897 Mdot
.8653 .02411 Mdot
.86533 .02746 Mdot
.86536 .02415 Mdot
.86538 .02312 Mdot
.86541 .02541 Mdot
.86543 .02498 Mdot
.86546 .02761 Mdot
.86548 .02666 Mdot
.86551 .02187 Mdot
.86554 .0266 Mdot
.86556 .0279 Mdot
.86559 .02871 Mdot
.86561 .03031 Mdot
.86564 .02607 Mdot
.86567 .02266 Mdot
.86569 .01974 Mdot
.86572 .01923 Mdot
.86574 .02415 Mdot
.86577 .01918 Mdot
.86579 .02077 Mdot
.86582 .02541 Mdot
.86585 .02511 Mdot
.86587 .02272 Mdot
.8659 .02617 Mdot
.86592 .02859 Mdot
.86595 .02566 Mdot
.86598 .02529 Mdot
.866 .02049 Mdot
.86603 .02427 Mdot
.86605 .02551 Mdot
.86608 .02198 Mdot
.8661 .02618 Mdot
.86613 .02943 Mdot
.86616 .02731 Mdot
.86618 .02846 Mdot
.86621 .02823 Mdot
.86623 .0355 Mdot
.86626 .03484 Mdot
.86629 .0304 Mdot
.86631 .03808 Mdot
.86634 .03475 Mdot
.86636 .02789 Mdot
.86639 .02122 Mdot
.86641 .02096 Mdot
.86644 .01974 Mdot
.86647 .01698 Mdot
.86649 .01759 Mdot
.86652 .02206 Mdot
.86654 .0213 Mdot
.86657 .02452 Mdot
.8666 .0228 Mdot
.86662 .02464 Mdot
.86665 .02125 Mdot
.86667 .02347 Mdot
.8667 .02521 Mdot
.86672 .02328 Mdot
.86675 .02357 Mdot
.86678 .02187 Mdot
.8668 .02336 Mdot
.86683 .01771 Mdot
.86685 .01588 Mdot
.86688 .01665 Mdot
.86691 .01902 Mdot
.86693 .02273 Mdot
.86696 .0212 Mdot
.86698 .01653 Mdot
.86701 .02359 Mdot
.86703 .02458 Mdot
.86706 .02244 Mdot
.86709 .02005 Mdot
.86711 .01956 Mdot
.86714 .01938 Mdot
.86716 .02195 Mdot
.86719 .02011 Mdot
.86722 .0241 Mdot
.86724 .01542 Mdot
.86727 .02524 Mdot
.86729 .02022 Mdot
.86732 .02203 Mdot
.86734 .02113 Mdot
.86737 .01828 Mdot
.8674 .0189 Mdot
.86742 .02246 Mdot
.86745 .01925 Mdot
.86747 .02182 Mdot
.8675 .0189 Mdot
.86753 .0188 Mdot
.86755 .01895 Mdot
.86758 .02111 Mdot
.8676 .01816 Mdot
.86763 .02046 Mdot
.86765 .02495 Mdot
.86768 .01809 Mdot
.86771 .01952 Mdot
.86773 .0192 Mdot
.86776 .01793 Mdot
.86778 .01949 Mdot
.86781 .01832 Mdot
.86784 .02362 Mdot
.86786 .02206 Mdot
.86789 .01688 Mdot
.86791 .01948 Mdot
.86794 .0274 Mdot
.86796 .02464 Mdot
.86799 .02001 Mdot
.86802 .01793 Mdot
.86804 .02082 Mdot
.86807 .02389 Mdot
.86809 .01665 Mdot
.86812 .02089 Mdot
.86815 .02004 Mdot
.86817 .01727 Mdot
.8682 .02016 Mdot
.86822 .0228 Mdot
.86825 .02276 Mdot
.86827 .02002 Mdot
.8683 .02195 Mdot
.86833 .02319 Mdot
.86835 .02824 Mdot
.86838 .03352 Mdot
.8684 .03733 Mdot
.86843 .0344 Mdot
.86846 .03064 Mdot
.86848 .03427 Mdot
.86851 .03569 Mdot
.86853 .03853 Mdot
.86856 .03606 Mdot
.86858 .03853 Mdot
.86861 .03855 Mdot
.86864 .04396 Mdot
.86866 .04563 Mdot
.86869 .04374 Mdot
.86871 .03578 Mdot
.86874 .02984 Mdot
.86877 .0365 Mdot
.86879 .04498 Mdot
.86882 .04339 Mdot
.86884 .03711 Mdot
.86887 .02832 Mdot
.86889 .035 Mdot
.86892 .0412 Mdot
.86895 .04657 Mdot
.86897 .04484 Mdot
.869 .03307 Mdot
.86902 .02069 Mdot
.86905 .02959 Mdot
.86908 .03394 Mdot
.8691 .02991 Mdot
.86913 .0302 Mdot
.86915 .03638 Mdot
.86918 .03358 Mdot
.8692 .03763 Mdot
.86923 .0307 Mdot
.86926 .03781 Mdot
.86928 .04102 Mdot
.86931 .03404 Mdot
.86933 .03315 Mdot
.86936 .03887 Mdot
.86939 .05035 Mdot
.86941 .04534 Mdot
.86944 .03344 Mdot
.86946 .01968 Mdot
.86949 .02384 Mdot
.86951 .02181 Mdot
.86954 .02456 Mdot
.86957 .03927 Mdot
.86959 .04506 Mdot
.86962 .0472 Mdot
.86964 .04758 Mdot
.86967 .05066 Mdot
.8697 .04798 Mdot
.86972 .02639 Mdot
.86975 .02124 Mdot
.86977 .02695 Mdot
.8698 .02723 Mdot
.86982 .03031 Mdot
.86985 .0375 Mdot
.86988 .03507 Mdot
.8699 .03685 Mdot
.86993 .03573 Mdot
.86995 .03422 Mdot
.86998 .01607 Mdot
.87001 .02582 Mdot
.87003 .03157 Mdot
.87006 .03458 Mdot
.87008 .03142 Mdot
.87011 .03647 Mdot
.87013 .028 Mdot
.87016 .02572 Mdot
.87019 .03316 Mdot
.87021 .03372 Mdot
.87024 .03214 Mdot
.87026 .04152 Mdot
.87029 .04026 Mdot
.87032 .03242 Mdot
.87034 .02935 Mdot
.87037 .03514 Mdot
.87039 .04231 Mdot
.87042 .03816 Mdot
.87045 .02502 Mdot
.87047 .01804 Mdot
.8705 .02488 Mdot
.87052 .02544 Mdot
.87055 .02523 Mdot
.87057 .02451 Mdot
.8706 .0186 Mdot
.87063 .01675 Mdot
.87065 .01521 Mdot
.87068 .01944 Mdot
.8707 .02837 Mdot
.87073 .02856 Mdot
.87076 .02558 Mdot
.87078 .02091 Mdot
.87081 .02165 Mdot
.87083 .02548 Mdot
.87086 .03182 Mdot
.87088 .02396 Mdot
.87091 .02554 Mdot
.87094 .02867 Mdot
.87096 .02756 Mdot
.87099 .02502 Mdot
.87101 .02092 Mdot
.87104 .02656 Mdot
.87107 .0292 Mdot
.87109 .02682 Mdot
.87112 .0175 Mdot
.87114 .02767 Mdot
.87117 .03038 Mdot
.87119 .02962 Mdot
.87122 .01955 Mdot
.87125 .02377 Mdot
.87127 .02647 Mdot
.8713 .0257 Mdot
.87132 .01979 Mdot
.87135 .01851 Mdot
.87138 .02068 Mdot
.8714 .02629 Mdot
.87143 .02023 Mdot
.87145 .01689 Mdot
.87148 .02147 Mdot
.8715 .02239 Mdot
.87153 .01987 Mdot
.87156 .01583 Mdot
.87158 .01934 Mdot
.87161 .0177 Mdot
.87163 .01695 Mdot
.87166 .02194 Mdot
.87169 .02032 Mdot
.87171 .01544 Mdot
.87174 .01769 Mdot
.87176 .01709 Mdot
.87179 .01825 Mdot
.87181 .01685 Mdot
.87184 .01782 Mdot
.87187 .01741 Mdot
.87189 .01518 Mdot
.87192 .01848 Mdot
.87194 .01863 Mdot
.87197 .01852 Mdot
.872 .01668 Mdot
.87202 .01603 Mdot
.87205 .01677 Mdot
.87207 .01895 Mdot
.8721 .01702 Mdot
.87212 .01587 Mdot
.87215 .01726 Mdot
.87218 .01787 Mdot
.8722 .01673 Mdot
.87223 .01668 Mdot
.87225 .01479 Mdot
.87228 .01528 Mdot
.87231 .0173 Mdot
.87233 .01593 Mdot
.87236 .01573 Mdot
.87238 .01763 Mdot
.87241 .01894 Mdot
.87243 .01727 Mdot
.87246 .01891 Mdot
.87249 .01602 Mdot
.87251 .0152 Mdot
.87254 .01758 Mdot
.87256 .01595 Mdot
.87259 .01888 Mdot
.87262 .01765 Mdot
.87264 .01631 Mdot
.87267 .01553 Mdot
.87269 .01589 Mdot
.87272 .0163 Mdot
.87274 .01653 Mdot
.87277 .01673 Mdot
.8728 .01546 Mdot
.87282 .01589 Mdot
.87285 .01618 Mdot
.87287 .01715 Mdot
.8729 .01787 Mdot
.87293 .01772 Mdot
.87295 .01901 Mdot
.87298 .01711 Mdot
.873 .01701 Mdot
.87303 .01986 Mdot
.87305 .02053 Mdot
.87308 .01834 Mdot
.87311 .01822 Mdot
.87313 .01994 Mdot
.87316 .01716 Mdot
.87318 .01762 Mdot
.87321 .01653 Mdot
.87324 .01591 Mdot
.87326 .01735 Mdot
.87329 .01816 Mdot
.87331 .01861 Mdot
.87334 .01815 Mdot
.87336 .01553 Mdot
.87339 .01578 Mdot
.87342 .01532 Mdot
.87344 .018 Mdot
.87347 .01582 Mdot
.87349 .01738 Mdot
.87352 .01689 Mdot
.87355 .01588 Mdot
.87357 .01561 Mdot
.8736 .01614 Mdot
.87362 .01594 Mdot
.87365 .0164 Mdot
.87367 .01714 Mdot
.8737 .01646 Mdot
.87373 .01634 Mdot
.87375 .02134 Mdot
.87378 .01802 Mdot
.8738 .01588 Mdot
.87383 .01719 Mdot
.87386 .01543 Mdot
.87388 .0161 Mdot
.87391 .01981 Mdot
.87393 .01793 Mdot
.87396 .01546 Mdot
.87398 .01553 Mdot
.87401 .01695 Mdot
.87404 .01807 Mdot
.87406 .01687 Mdot
.87409 .01587 Mdot
.87411 .01841 Mdot
.87414 .01683 Mdot
.87417 .01729 Mdot
.87419 .01701 Mdot
.87422 .01706 Mdot
.87424 .01856 Mdot
.87427 .01594 Mdot
.87429 .01653 Mdot
.87432 .0192 Mdot
.87435 .01692 Mdot
.87437 .01722 Mdot
.8744 .01772 Mdot
.87442 .01779 Mdot
.87445 .01612 Mdot
.87448 .01575 Mdot
.8745 .01926 Mdot
.87453 .02054 Mdot
.87455 .01891 Mdot
.87458 .01563 Mdot
.8746 .01952 Mdot
.87463 .02004 Mdot
.87466 .02163 Mdot
.87468 .02237 Mdot
.87471 .02151 Mdot
.87473 .02234 Mdot
.87476 .02394 Mdot
.87479 .0252 Mdot
.87481 .02614 Mdot
.87484 .02351 Mdot
.87486 .02629 Mdot
.87489 .02739 Mdot
.87491 .02978 Mdot
.87494 .0288 Mdot
.87497 .02762 Mdot
.87499 .02699 Mdot
.87502 .02763 Mdot
.87504 .03031 Mdot
.87507 .03503 Mdot
.8751 .02873 Mdot
.87512 .02732 Mdot
.87515 .02161 Mdot
.87517 .03132 Mdot
.8752 .03607 Mdot
.87522 .03798 Mdot
.87525 .03242 Mdot
.87528 .0174 Mdot
.8753 .02171 Mdot
.87533 .03238 Mdot
.87535 .03577 Mdot
.87538 .03346 Mdot
.87541 .02635 Mdot
.87543 .02257 Mdot
.87546 .02516 Mdot
.87548 .02215 Mdot
.87551 .0197 Mdot
.87553 .02438 Mdot
.87556 .02501 Mdot
.87559 .02442 Mdot
.87561 .03108 Mdot
.87564 .03482 Mdot
.87566 .03566 Mdot
.87569 .03053 Mdot
.87572 .01793 Mdot
.87574 .01834 Mdot
.87577 .0228 Mdot
.87579 .02436 Mdot
.87582 .01922 Mdot
.87584 .02149 Mdot
.87587 .02824 Mdot
.8759 .02804 Mdot
.87592 .0287 Mdot
.87595 .02781 Mdot
.87597 .02457 Mdot
.876 .02079 Mdot
.87603 .01843 Mdot
.87605 .01876 Mdot
.87608 .01763 Mdot
.8761 .01877 Mdot
.87613 .02269 Mdot
.87615 .02538 Mdot
.87618 .02743 Mdot
.87621 .03067 Mdot
.87623 .02419 Mdot
.87626 .01693 Mdot
.87628 .01788 Mdot
.87631 .02465 Mdot
.87634 .02184 Mdot
.87636 .02391 Mdot
.87639 .02779 Mdot
.87641 .02448 Mdot
.87644 .02211 Mdot
.87646 .02055 Mdot
.87649 .02338 Mdot
.87652 .02279 Mdot
.87654 .02759 Mdot
.87657 .02379 Mdot
.87659 .01811 Mdot
.87662 .01984 Mdot
.87665 .01878 Mdot
.87667 .02433 Mdot
.8767 .02229 Mdot
.87672 .02104 Mdot
.87675 .01771 Mdot
.87677 .01718 Mdot
.8768 .01675 Mdot
.87683 .02047 Mdot
.87685 .0223 Mdot
.87688 .02169 Mdot
.8769 .02147 Mdot
.87693 .01556 Mdot
.87696 .02024 Mdot
.87698 .02355 Mdot
.87701 .02198 Mdot
.87703 .02202 Mdot
.87706 .01836 Mdot
.87708 .02168 Mdot
.87711 .02526 Mdot
.87714 .02387 Mdot
.87716 .02367 Mdot
.87719 .02431 Mdot
.87721 .02412 Mdot
.87724 .02212 Mdot
.87727 .0188 Mdot
.87729 .02043 Mdot
.87732 .02482 Mdot
.87734 .02417 Mdot
.87737 .01565 Mdot
.87739 .02288 Mdot
.87742 .0225 Mdot
.87745 .02242 Mdot
.87747 .01721 Mdot
.8775 .01756 Mdot
.87752 .02119 Mdot
.87755 .02226 Mdot
.87758 .01905 Mdot
.8776 .01681 Mdot
.87763 .01585 Mdot
.87765 .01882 Mdot
.87768 .01619 Mdot
.8777 .01851 Mdot
.87773 .02054 Mdot
.87776 .01894 Mdot
.87778 .01531 Mdot
.87781 .01829 Mdot
.87783 .01604 Mdot
.87786 .01829 Mdot
.87789 .01838 Mdot
.87791 .01667 Mdot
.87794 .01589 Mdot
.87796 .01598 Mdot
.87799 .01716 Mdot
.87801 .01562 Mdot
.87804 .01694 Mdot
.87807 .01586 Mdot
.87809 .01548 Mdot
.87812 .01686 Mdot
.87814 .01618 Mdot
.87817 .01598 Mdot
.8782 .01621 Mdot
.87822 .01672 Mdot
.87825 .01694 Mdot
.87827 .01607 Mdot
.8783 .01573 Mdot
.87832 .01875 Mdot
.87835 .01767 Mdot
.87838 .01667 Mdot
.8784 .01841 Mdot
.87843 .01525 Mdot
.87845 .01651 Mdot
.87848 .01567 Mdot
.87851 .0157 Mdot
.87853 .01554 Mdot
.87856 .01539 Mdot
.87858 .01535 Mdot
.87861 .0163 Mdot
.87863 .01601 Mdot
.87866 .01697 Mdot
.87869 .01628 Mdot
.87871 .01613 Mdot
.87874 .01778 Mdot
.87876 .01742 Mdot
.87879 .0172 Mdot
.87882 .01602 Mdot
.87884 .0176 Mdot
.87887 .01653 Mdot
.87889 .01597 Mdot
.87892 .0161 Mdot
.87894 .01528 Mdot
.87897 .01639 Mdot
.879 .01645 Mdot
.87902 .01655 Mdot
.87905 .01762 Mdot
.87907 .01507 Mdot
.8791 .01608 Mdot
.87913 .01538 Mdot
.87915 .01592 Mdot
.87918 .0178 Mdot
.8792 .01574 Mdot
.87923 .01626 Mdot
.87925 .0173 Mdot
.87928 .01709 Mdot
.87931 .01585 Mdot
.87933 .01623 Mdot
.87936 .01634 Mdot
.87938 .01563 Mdot
.87941 .01672 Mdot
.87944 .01528 Mdot
.87946 .01677 Mdot
.87949 .01578 Mdot
.87951 .01708 Mdot
.87954 .01832 Mdot
.87957 .01672 Mdot
.87959 .01547 Mdot
.87962 .01617 Mdot
.87964 .01574 Mdot
.87967 .01508 Mdot
.87969 .01615 Mdot
.87972 .01677 Mdot
.87975 .01544 Mdot
.87977 .01548 Mdot
.8798 .01697 Mdot
.87982 .01686 Mdot
.87985 .01618 Mdot
.87988 .01586 Mdot
.8799 .0169 Mdot
.87993 .01759 Mdot
.87995 .01555 Mdot
.87998 .01636 Mdot
.88 .01574 Mdot
.88003 .01558 Mdot
.88006 .01641 Mdot
.88008 .01642 Mdot
.88011 .01628 Mdot
.88013 .01587 Mdot
.88016 .01633 Mdot
.88019 .01842 Mdot
.88021 .01744 Mdot
.88024 .01876 Mdot
.88026 .018 Mdot
.88029 .01931 Mdot
.88031 .01709 Mdot
.88034 .01946 Mdot
.88037 .01672 Mdot
.88039 .01703 Mdot
.88042 .01651 Mdot
.88044 .01596 Mdot
.88047 .01573 Mdot
.8805 .01585 Mdot
.88052 .01564 Mdot
.88055 .01599 Mdot
.88057 .01762 Mdot
.8806 .01598 Mdot
.88062 .01694 Mdot
.88065 .01593 Mdot
.88068 .01498 Mdot
.8807 .01608 Mdot
.88073 .01519 Mdot
.88075 .01672 Mdot
.88078 .01547 Mdot
.88081 .01518 Mdot
.88083 .01566 Mdot
.88086 .01683 Mdot
.88088 .01992 Mdot
.88091 .01764 Mdot
.88093 .01625 Mdot
.88096 .01507 Mdot
.88099 .0185 Mdot
.88101 .01551 Mdot
.88104 .01989 Mdot
.88106 .01765 Mdot
.88109 .01604 Mdot
.88112 .0163 Mdot
.88114 .01965 Mdot
.88117 .0198 Mdot
.88119 .01856 Mdot
.88122 .01902 Mdot
.88124 .0182 Mdot
.88127 .0168 Mdot
.8813 .0205 Mdot
.88132 .02036 Mdot
.88135 .02152 Mdot
.88137 .01872 Mdot
.8814 .01934 Mdot
.88143 .02035 Mdot
.88145 .02219 Mdot
.88148 .02552 Mdot
.8815 .02097 Mdot
.88153 .01804 Mdot
.88155 .01837 Mdot
.88158 .0224 Mdot
.88161 .02583 Mdot
.88163 .02352 Mdot
.88166 .02236 Mdot
.88168 .01529 Mdot
.88171 .02041 Mdot
.88174 .01795 Mdot
.88176 .01747 Mdot
.88179 .02097 Mdot
.88181 .01908 Mdot
.88184 .01943 Mdot
.88186 .01898 Mdot
.88189 .01831 Mdot
.88192 .02318 Mdot
.88194 .02144 Mdot
.88197 .01613 Mdot
.88199 .01935 Mdot
.88202 .02054 Mdot
.88205 .02105 Mdot
.88207 .01843 Mdot
.8821 .01563 Mdot
.88212 .01978 Mdot
.88215 .01926 Mdot
.88217 .01983 Mdot
.8822 .02126 Mdot
.88223 .02358 Mdot
.88225 .01969 Mdot
.88228 .02134 Mdot
.8823 .02364 Mdot
.88233 .02383 Mdot
.88236 .01825 Mdot
.88238 .01714 Mdot
.88241 .01971 Mdot
.88243 .02149 Mdot
.88246 .02252 Mdot
.88248 .02382 Mdot
.88251 .01876 Mdot
.88254 .01868 Mdot
.88256 .02082 Mdot
.88259 .02383 Mdot
.88261 .01992 Mdot
.88264 .02258 Mdot
.88267 .02531 Mdot
.88269 .02172 Mdot
.88272 .02074 Mdot
.88274 .01918 Mdot
.88277 .02061 Mdot
.88279 .02442 Mdot
.88282 .02449 Mdot
.88285 .0153 Mdot
.88287 .01732 Mdot
.8829 .01791 Mdot
.88292 .0219 Mdot
.88295 .02337 Mdot
.88298 .01659 Mdot
.883 .01666 Mdot
.88303 .01709 Mdot
.88305 .01672 Mdot
.88308 .02499 Mdot
.8831 .01802 Mdot
.88313 .02028 Mdot
.88316 .0182 Mdot
.88318 .01685 Mdot
.88321 .02087 Mdot
.88323 .02374 Mdot
.88326 .02248 Mdot
.88329 .01794 Mdot
.88331 .0182 Mdot
.88334 .01897 Mdot
.88336 .02251 Mdot
.88339 .02122 Mdot
.88341 .01723 Mdot
.88344 .02331 Mdot
.88347 .02135 Mdot
.88349 .02039 Mdot
.88352 .01772 Mdot
.88354 .01627 Mdot
.88357 .01954 Mdot
.8836 .01708 Mdot
.88362 .01563 Mdot
.88365 .0187 Mdot
.88367 .01786 Mdot
.8837 .01865 Mdot
.88372 .01709 Mdot
.88375 .01755 Mdot
.88378 .01552 Mdot
.8838 .01947 Mdot
.88383 .01658 Mdot
.88385 .01488 Mdot
.88388 .01671 Mdot
.88391 .01517 Mdot
.88393 .01517 Mdot
.88396 .0152 Mdot
.88398 .0157 Mdot
.88401 .01588 Mdot
.88403 .01611 Mdot
.88406 .01685 Mdot
.88409 .01512 Mdot
.88411 .01634 Mdot
.88414 .01781 Mdot
.88416 .01645 Mdot
.88419 .01685 Mdot
.88422 .01648 Mdot
.88424 .01639 Mdot
.88427 .01793 Mdot
.88429 .01524 Mdot
.88432 .01663 Mdot
.88434 .01613 Mdot
.88437 .01698 Mdot
.8844 .01623 Mdot
.88442 .016 Mdot
.88445 .015 Mdot
.88447 .01653 Mdot
.8845 .01643 Mdot
.88453 .0166 Mdot
.88455 .01634 Mdot
.88458 .01643 Mdot
.8846 .01658 Mdot
.88463 .01541 Mdot
.88465 .01672 Mdot
.88468 .01539 Mdot
.88471 .01475 Mdot
.88473 .01652 Mdot
.88476 .01559 Mdot
.88478 .01629 Mdot
.88481 .01774 Mdot
.88484 .01558 Mdot
.88486 .01723 Mdot
.88489 .01685 Mdot
.88491 .01666 Mdot
.88494 .01595 Mdot
.88496 .01594 Mdot
.88499 .01566 Mdot
.88502 .01612 Mdot
.88504 .01546 Mdot
.88507 .01605 Mdot
.88509 .0165 Mdot
.88512 .01671 Mdot
.88515 .01554 Mdot
.88517 .01492 Mdot
.8852 .01609 Mdot
.88522 .01694 Mdot
.88525 .01608 Mdot
.88527 .01697 Mdot
.8853 .01533 Mdot
.88533 .01685 Mdot
.88535 .02124 Mdot
.88538 .01744 Mdot
.8854 .01909 Mdot
.88543 .01792 Mdot
.88546 .0213 Mdot
.88548 .01833 Mdot
.88551 .0189 Mdot
.88553 .01495 Mdot
.88556 .01745 Mdot
.88558 .01795 Mdot
.88561 .01601 Mdot
.88564 .01665 Mdot
.88566 .01751 Mdot
.88569 .01684 Mdot
.88571 .01508 Mdot
.88574 .01723 Mdot
.88577 .01586 Mdot
.88579 .0179 Mdot
.88582 .01657 Mdot
.88584 .01665 Mdot
.88587 .01814 Mdot
.88589 .01603 Mdot
.88592 .01567 Mdot
.88595 .01548 Mdot
.88597 .01827 Mdot
.886 .01731 Mdot
.88602 .01641 Mdot
.88605 .01651 Mdot
.88608 .01637 Mdot
.8861 .01494 Mdot
.88613 .01715 Mdot
.88615 .01739 Mdot
.88618 .01634 Mdot
.8862 .01702 Mdot
.88623 .01608 Mdot
.88626 .01565 Mdot
.88628 .01724 Mdot
.88631 .01582 Mdot
.88633 .01689 Mdot
.88636 .01694 Mdot
.88639 .01623 Mdot
.88641 .01628 Mdot
.88644 .01582 Mdot
.88646 .01609 Mdot
.88649 .016 Mdot
.88651 .01729 Mdot
.88654 .01525 Mdot
.88657 .01756 Mdot
.88659 .01594 Mdot
.88662 .01845 Mdot
.88664 .01602 Mdot
.88667 .01536 Mdot
.8867 .01704 Mdot
.88672 .01571 Mdot
.88675 .01631 Mdot
.88677 .01622 Mdot
.8868 .01544 Mdot
.88682 .01637 Mdot
.88685 .01845 Mdot
.88688 .01542 Mdot
.8869 .01565 Mdot
.88693 .0162 Mdot
.88695 .01597 Mdot
.88698 .01719 Mdot
.88701 .01544 Mdot
.88703 .01681 Mdot
.88706 .01523 Mdot
.88708 .01547 Mdot
.88711 .01583 Mdot
.88713 .01583 Mdot
.88716 .01569 Mdot
.88719 .01643 Mdot
.88721 .01795 Mdot
.88724 .01486 Mdot
.88726 .01684 Mdot
.88729 .01559 Mdot
.88732 .01743 Mdot
.88734 .0166 Mdot
.88737 .01753 Mdot
.88739 .01602 Mdot
.88742 .01708 Mdot
.88744 .01918 Mdot
.88747 .019 Mdot
.8875 .02067 Mdot
.88752 .02001 Mdot
.88755 .01616 Mdot
.88757 .01987 Mdot
.8876 .02002 Mdot
.88763 .02138 Mdot
.88765 .01766 Mdot
.88768 .02306 Mdot
.8877 .02142 Mdot
.88773 .02205 Mdot
.88775 .02213 Mdot
.88778 .02148 Mdot
.88781 .01719 Mdot
.88783 .01831 Mdot
.88786 .0227 Mdot
.88788 .02756 Mdot
.88791 .0258 Mdot
.88794 .01901 Mdot
.88796 .01836 Mdot
.88799 .02357 Mdot
.88801 .02367 Mdot
.88804 .02101 Mdot
.88806 .0197 Mdot
.88809 .01705 Mdot
.88812 .02307 Mdot
.88814 .01647 Mdot
.88817 .0188 Mdot
.88819 .01875 Mdot
.88822 .01731 Mdot
.88825 .0204 Mdot
.88827 .01956 Mdot
.8883 .02464 Mdot
.88832 .02443 Mdot
.88835 .02257 Mdot
.88837 .01652 Mdot
.8884 .01803 Mdot
.88843 .01889 Mdot
.88845 .01925 Mdot
.88848 .02112 Mdot
.8885 .02205 Mdot
.88853 .02545 Mdot
.88856 .02132 Mdot
.88858 .02413 Mdot
.88861 .02221 Mdot
.88863 .01994 Mdot
.88866 .01644 Mdot
.88869 .0174 Mdot
.88871 .01985 Mdot
.88874 .01919 Mdot
.88876 .02151 Mdot
.88879 .02213 Mdot
.88881 .01962 Mdot
.88884 .02517 Mdot
.88887 .01765 Mdot
.88889 .01842 Mdot
.88892 .02264 Mdot
.88894 .02346 Mdot
.88897 .02294 Mdot
.889 .01906 Mdot
.88902 .01711 Mdot
.88905 .01901 Mdot
.88907 .02017 Mdot
.8891 .01826 Mdot
.88912 .01793 Mdot
.88915 .01686 Mdot
.88918 .01713 Mdot
.8892 .01828 Mdot
.88923 .01925 Mdot
.88925 .02251 Mdot
.88928 .01852 Mdot
.88931 .02233 Mdot
.88933 .02142 Mdot
.88936 .0186 Mdot
.88938 .02381 Mdot
.88941 .0224 Mdot
.88943 .01864 Mdot
.88946 .01931 Mdot
.88949 .01762 Mdot
.88951 .02397 Mdot
.88954 .02281 Mdot
.88956 .01852 Mdot
.88959 .01881 Mdot
.88962 .02246 Mdot
.88964 .01976 Mdot
.88967 .01744 Mdot
.88969 .01984 Mdot
.88972 .02066 Mdot
.88974 .01813 Mdot
.88977 .01774 Mdot
.8898 .01507 Mdot
.88982 .02158 Mdot
.88985 .01712 Mdot
.88987 .01657 Mdot
.8899 .01539 Mdot
.88993 .01786 Mdot
.88995 .01697 Mdot
.88998 .01534 Mdot
.89 .01649 Mdot
.89003 .01504 Mdot
.89005 .01574 Mdot
.89008 .01561 Mdot
.89011 .01842 Mdot
.89013 .01788 Mdot
.89016 .01629 Mdot
.89018 .01633 Mdot
.89021 .01629 Mdot
.89024 .01749 Mdot
.89026 .01597 Mdot
.89029 .01699 Mdot
.89031 .01631 Mdot
.89034 .01522 Mdot
.89036 .01603 Mdot
.89039 .01533 Mdot
.89042 .01509 Mdot
.89044 .01486 Mdot
.89047 .01661 Mdot
.89049 .01777 Mdot
.89052 .01703 Mdot
.89055 .01614 Mdot
.89057 .01526 Mdot
.8906 .01943 Mdot
.89062 .01821 Mdot
.89065 .01617 Mdot
.89067 .01623 Mdot
.8907 .01687 Mdot
.89073 .01761 Mdot
.89075 .01593 Mdot
.89078 .01726 Mdot
.8908 .01774 Mdot
.89083 .01488 Mdot
.89086 .01742 Mdot
.89088 .01716 Mdot
.89091 .01526 Mdot
.89093 .01568 Mdot
.89096 .01643 Mdot
.89098 .01564 Mdot
.89101 .01604 Mdot
.89104 .01658 Mdot
.89106 .01516 Mdot
.89109 .01683 Mdot
.89111 .01619 Mdot
.89114 .01509 Mdot
.89117 .01507 Mdot
.89119 .01596 Mdot
.89122 .01643 Mdot
.89124 .0168 Mdot
.89127 .01622 Mdot
.89129 .01606 Mdot
.89132 .01677 Mdot
.89135 .0157 Mdot
.89137 .01653 Mdot
.8914 .0174 Mdot
.89142 .01682 Mdot
.89145 .01584 Mdot
.89148 .01526 Mdot
.8915 .01684 Mdot
.89153 .01663 Mdot
.89155 .01535 Mdot
.89158 .01508 Mdot
.8916 .01619 Mdot
.89163 .0156 Mdot
.89166 .01539 Mdot
.89168 .01568 Mdot
.89171 .01795 Mdot
.89173 .01584 Mdot
.89176 .01697 Mdot
.89179 .01777 Mdot
.89181 .0161 Mdot
.89184 .01741 Mdot
.89186 .01607 Mdot
.89189 .01658 Mdot
.89191 .01669 Mdot
.89194 .01612 Mdot
.89197 .01774 Mdot
.89199 .01658 Mdot
.89202 .01707 Mdot
.89204 .01877 Mdot
.89207 .01867 Mdot
.8921 .0177 Mdot
.89212 .01658 Mdot
.89215 .01686 Mdot
.89217 .0176 Mdot
.8922 .01644 Mdot
.89222 .01666 Mdot
.89225 .01592 Mdot
.89228 .01642 Mdot
.8923 .01563 Mdot
.89233 .01603 Mdot
.89235 .01768 Mdot
.89238 .01586 Mdot
.89241 .01666 Mdot
.89243 .01552 Mdot
.89246 .01666 Mdot
.89248 .01576 Mdot
.89251 .01558 Mdot
.89253 .01515 Mdot
.89256 .0151 Mdot
.89259 .01592 Mdot
.89261 .01772 Mdot
.89264 .01492 Mdot
.89266 .0162 Mdot
.89269 .0163 Mdot
.89272 .01514 Mdot
.89274 .01524 Mdot
.89277 .01524 Mdot
.89279 .01665 Mdot
.89282 .01782 Mdot
.89284 .01624 Mdot
.89287 .01765 Mdot
.8929 .01538 Mdot
.89292 .01698 Mdot
.89295 .01655 Mdot
.89297 .01532 Mdot
.893 .01936 Mdot
.89303 .0189 Mdot
.89305 .01537 Mdot
.89308 .01674 Mdot
.8931 .01649 Mdot
.89313 .01804 Mdot
.89315 .01771 Mdot
.89318 .01493 Mdot
.89321 .01598 Mdot
.89323 .0166 Mdot
.89326 .01889 Mdot
.89328 .01864 Mdot
.89331 .01872 Mdot
.89334 .01665 Mdot
.89336 .01601 Mdot
.89339 .01527 Mdot
.89341 .0158 Mdot
.89344 .01617 Mdot
.89346 .01657 Mdot
.89349 .01584 Mdot
.89352 .01659 Mdot
.89354 .01679 Mdot
.89357 .01761 Mdot
.89359 .01604 Mdot
.89362 .0164 Mdot
.89365 .01571 Mdot
.89367 .016 Mdot
.8937 .01548 Mdot
.89372 .01617 Mdot
.89375 .01667 Mdot
.89377 .016 Mdot
.8938 .01997 Mdot
.89383 .01801 Mdot
.89385 .01898 Mdot
.89388 .01814 Mdot
.8939 .01899 Mdot
.89393 .01657 Mdot
.89396 .01916 Mdot
.89398 .02087 Mdot
.89401 .02237 Mdot
.89403 .01663 Mdot
.89406 .01608 Mdot
.89408 .0172 Mdot
.89411 .02077 Mdot
.89414 .02228 Mdot
.89416 .0215 Mdot
.89419 .01663 Mdot
.89421 .01647 Mdot
.89424 .02113 Mdot
.89427 .02125 Mdot
.89429 .02032 Mdot
.89432 .01746 Mdot
.89434 .01626 Mdot
.89437 .01726 Mdot
.89439 .01788 Mdot
.89442 .01577 Mdot
.89445 .01725 Mdot
.89447 .01618 Mdot
.8945 .01975 Mdot
.89452 .01666 Mdot
.89455 .02159 Mdot
.89458 .02341 Mdot
.8946 .01929 Mdot
.89463 .01593 Mdot
.89465 .01756 Mdot
.89468 .01827 Mdot
.8947 .01708 Mdot
.89473 .015 Mdot
.89476 .01795 Mdot
.89478 .01963 Mdot
.89481 .01932 Mdot
.89483 .02091 Mdot
.89486 .01964 Mdot
.89489 .01774 Mdot
.89491 .01644 Mdot
.89494 .01655 Mdot
.89496 .01691 Mdot
.89499 .01609 Mdot
.89501 .02034 Mdot
.89504 .0199 Mdot
.89507 .01798 Mdot
.89509 .02088 Mdot
.89512 .02147 Mdot
.89514 .01566 Mdot
.89517 .01943 Mdot
.8952 .02177 Mdot
.89522 .01818 Mdot
.89525 .01681 Mdot
.89527 .01482 Mdot
.8953 .01712 Mdot
.89532 .01716 Mdot
.89535 .01739 Mdot
.89538 .01737 Mdot
.8954 .01486 Mdot
.89543 .01835 Mdot
.89545 .01566 Mdot
.89548 .01652 Mdot
.89551 .01957 Mdot
.89553 .01864 Mdot
.89556 .02099 Mdot
.89558 .01875 Mdot
.89561 .01861 Mdot
.89563 .0213 Mdot
.89566 .02022 Mdot
.89569 .01876 Mdot
.89571 .01626 Mdot
.89574 .02154 Mdot
.89576 .02254 Mdot
.89579 .01955 Mdot
.89582 .01627 Mdot
.89584 .01864 Mdot
.89587 .02227 Mdot
.89589 .01859 Mdot
.89592 .01585 Mdot
.89594 .0184 Mdot
.89597 .01947 Mdot
.896 .01844 Mdot
.89602 .01531 Mdot
.89605 .01595 Mdot
.89607 .01657 Mdot
.8961 .01763 Mdot
.89613 .01555 Mdot
.89615 .0157 Mdot
.89618 .01671 Mdot
.8962 .01773 Mdot
.89623 .01681 Mdot
.89625 .01662 Mdot
.89628 .01665 Mdot
.89631 .01642 Mdot
.89633 .0152 Mdot
.89636 .01752 Mdot
.89638 .01686 Mdot
.89641 .01687 Mdot
.89644 .01496 Mdot
.89646 .01677 Mdot
.89649 .01631 Mdot
.89651 .01539 Mdot
.89654 .01584 Mdot
.89656 .01676 Mdot
.89659 .0163 Mdot
.89662 .01615 Mdot
.89664 .01728 Mdot
.89667 .01606 Mdot
.89669 .01652 Mdot
.89672 .01593 Mdot
.89675 .01507 Mdot
.89677 .01529 Mdot
.8968 .01578 Mdot
.89682 .01622 Mdot
.89685 .01634 Mdot
.89687 .01538 Mdot
.8969 .01687 Mdot
.89693 .0178 Mdot
.89695 .01675 Mdot
.89698 .01601 Mdot
.897 .01675 Mdot
.89703 .01561 Mdot
.89706 .01701 Mdot
.89708 .0185 Mdot
.89711 .0156 Mdot
.89713 .01536 Mdot
.89716 .01674 Mdot
.89718 .01496 Mdot
.89721 .0154 Mdot
.89724 .01715 Mdot
.89726 .01556 Mdot
.89729 .01699 Mdot
.89731 .01547 Mdot
.89734 .01631 Mdot
.89737 .0174 Mdot
.89739 .01579 Mdot
.89742 .01543 Mdot
.89744 .0157 Mdot
.89747 .01517 Mdot
.89749 .01521 Mdot
.89752 .01673 Mdot
.89755 .0162 Mdot
.89757 .01519 Mdot
.8976 .01549 Mdot
.89762 .01522 Mdot
.89765 .01579 Mdot
.89768 .01597 Mdot
.8977 .01554 Mdot
.89773 .01566 Mdot
.89775 .01488 Mdot
.89778 .01641 Mdot
.8978 .01653 Mdot
.89783 .01662 Mdot
.89786 .01564 Mdot
.89788 .01542 Mdot
.89791 .01513 Mdot
.89793 .01592 Mdot
.89796 .01593 Mdot
.89799 .01561 Mdot
.89801 .01511 Mdot
.89804 .01488 Mdot
.89806 .01583 Mdot
.89809 .0154 Mdot
.89812 .01609 Mdot
.89814 .01636 Mdot
.89817 .01549 Mdot
.89819 .01633 Mdot
.89822 .01507 Mdot
.89824 .01669 Mdot
.89827 .01774 Mdot
.8983 .0157 Mdot
.89832 .01537 Mdot
.89835 .01544 Mdot
.89837 .01633 Mdot
.8984 .01841 Mdot
.89843 .01647 Mdot
.89845 .01837 Mdot
.89848 .02396 Mdot
.8985 .01477 Mdot
.89853 .01538 Mdot
.89855 .01603 Mdot
.89858 .0169 Mdot
.89861 .01657 Mdot
.89863 .01646 Mdot
.89866 .0162 Mdot
.89868 .01605 Mdot
.89871 .01644 Mdot
.89874 .01628 Mdot
.89876 .01574 Mdot
.89879 .01772 Mdot
.89881 .01605 Mdot
.89884 .01849 Mdot
.89886 .01667 Mdot
.89889 .01691 Mdot
.89892 .01578 Mdot
.89894 .0176 Mdot
.89897 .01584 Mdot
.89899 .01711 Mdot
.89902 .01529 Mdot
.89905 .01604 Mdot
.89907 .01592 Mdot
.8991 .01672 Mdot
.89912 .0152 Mdot
.89915 .0165 Mdot
.89917 .01698 Mdot
.8992 .0163 Mdot
.89923 .01592 Mdot
.89925 .01582 Mdot
.89928 .0161 Mdot
.8993 .01737 Mdot
.89933 .01532 Mdot
.89936 .01474 Mdot
.89938 .01741 Mdot
.89941 .01636 Mdot
.89943 .01636 Mdot
.89946 .0157 Mdot
.89948 .01622 Mdot
.89951 .01708 Mdot
.89954 .01586 Mdot
.89956 .01717 Mdot
.89959 .01722 Mdot
.89961 .0157 Mdot
.89964 .01577 Mdot
.89967 .01565 Mdot
.89969 .01601 Mdot
.89972 .01746 Mdot
.89974 .01765 Mdot
.89977 .01717 Mdot
.89979 .01622 Mdot
.89982 .01737 Mdot
.89985 .01622 Mdot
.89987 .01547 Mdot
.8999 .01585 Mdot
.89992 .01601 Mdot
.89995 .01718 Mdot
.89998 .01686 Mdot
.9 .01668 Mdot
.90003 .01558 Mdot
.90005 .01652 Mdot
.90008 .01549 Mdot
.9001 .01816 Mdot
.90013 .01733 Mdot
.90016 .01567 Mdot
.90018 .01621 Mdot
.90021 .01693 Mdot
.90023 .01486 Mdot
.90026 .01764 Mdot
.90029 .01784 Mdot
.90031 .01888 Mdot
.90034 .01566 Mdot
.90036 .01922 Mdot
.90039 .01905 Mdot
.90041 .01891 Mdot
.90044 .01943 Mdot
.90047 .01759 Mdot
.90049 .01748 Mdot
.90052 .01893 Mdot
.90054 .02036 Mdot
.90057 .02086 Mdot
.9006 .01567 Mdot
.90062 .01607 Mdot
.90065 .01808 Mdot
.90067 .01879 Mdot
.9007 .01657 Mdot
.90072 .01717 Mdot
.90075 .01548 Mdot
.90078 .01629 Mdot
.9008 .01651 Mdot
.90083 .01721 Mdot
.90085 .0168 Mdot
.90088 .01588 Mdot
.90091 .01736 Mdot
.90093 .01775 Mdot
.90096 .01685 Mdot
.90098 .01902 Mdot
.90101 .01517 Mdot
.90103 .01596 Mdot
.90106 .01736 Mdot
.90109 .01801 Mdot
.90111 .01751 Mdot
.90114 .01786 Mdot
.90116 .02028 Mdot
.90119 .0169 Mdot
.90122 .01993 Mdot
.90124 .01897 Mdot
.90127 .01636 Mdot
.90129 .01691 Mdot
.90132 .01902 Mdot
.90134 .02039 Mdot
.90137 .02019 Mdot
.9014 .01879 Mdot
.90142 .01538 Mdot
.90145 .01747 Mdot
.90147 .01843 Mdot
.9015 .01621 Mdot
.90153 .0173 Mdot
.90155 .01917 Mdot
.90158 .01562 Mdot
.9016 .01547 Mdot
.90163 .01527 Mdot
.90165 .01728 Mdot
.90168 .01857 Mdot
.90171 .01643 Mdot
.90173 .01782 Mdot
.90176 .01738 Mdot
.90178 .01705 Mdot
.90181 .01733 Mdot
.90184 .01737 Mdot
.90186 .01524 Mdot
.90189 .01817 Mdot
.90191 .0186 Mdot
.90194 .01592 Mdot
.90196 .01729 Mdot
.90199 .0159 Mdot
.90202 .01619 Mdot
.90204 .01597 Mdot
.90207 .01731 Mdot
.90209 .01513 Mdot
.90212 .01641 Mdot
.90215 .01677 Mdot
.90217 .01815 Mdot
.9022 .01547 Mdot
.90222 .0177 Mdot
.90225 .01615 Mdot
.90227 .01652 Mdot
.9023 .01579 Mdot
.90233 .01567 Mdot
.90235 .01799 Mdot
.90238 .01568 Mdot
.9024 .01643 Mdot
.90243 .01643 Mdot
.90246 .01962 Mdot
.90248 .0152 Mdot
.90251 .0165 Mdot
.90253 .01628 Mdot
.90256 .0151 Mdot
.90258 .01709 Mdot
.90261 .01602 Mdot
.90264 .01678 Mdot
.90266 .01683 Mdot
.90269 .01544 Mdot
.90271 .0153 Mdot
.90274 .01574 Mdot
.90277 .01713 Mdot
.90279 .01652 Mdot
.90282 .01687 Mdot
.90284 .01589 Mdot
.90287 .01624 Mdot
.90289 .01543 Mdot
.90292 .01502 Mdot
.90295 .01622 Mdot
.90297 .01574 Mdot
.903 .0152 Mdot
.90302 .01626 Mdot
.90305 .01607 Mdot
.90308 .01712 Mdot
.9031 .01675 Mdot
.90313 .01512 Mdot
.90315 .01662 Mdot
.90318 .01607 Mdot
.9032 .01833 Mdot
.90323 .01736 Mdot
.90326 .0163 Mdot
.90328 .01547 Mdot
.90331 .01568 Mdot
.90333 .01524 Mdot
.90336 .01701 Mdot
.90339 .01506 Mdot
.90341 .0162 Mdot
.90344 .01619 Mdot
.90346 .01634 Mdot
.90349 .01649 Mdot
.90351 .016 Mdot
.90354 .01695 Mdot
.90357 .0158 Mdot
.90359 .0165 Mdot
.90362 .01889 Mdot
.90364 .01873 Mdot
.90367 .02224 Mdot
.9037 .01985 Mdot
.90372 .01594 Mdot
.90375 .01609 Mdot
.90377 .01784 Mdot
.9038 .01612 Mdot
.90382 .01529 Mdot
.90385 .01592 Mdot
.90388 .0164 Mdot
.9039 .01648 Mdot
.90393 .01532 Mdot
.90395 .01681 Mdot
.90398 .01549 Mdot
.90401 .01569 Mdot
.90403 .01619 Mdot
.90406 .01609 Mdot
.90408 .0165 Mdot
.90411 .01575 Mdot
.90413 .01627 Mdot
.90416 .01658 Mdot
.90419 .01578 Mdot
.90421 .01572 Mdot
.90424 .01583 Mdot
.90426 .01653 Mdot
.90429 .01735 Mdot
.90432 .01625 Mdot
.90434 .01571 Mdot
.90437 .01535 Mdot
.90439 .01648 Mdot
.90442 .01655 Mdot
.90444 .0157 Mdot
.90447 .01595 Mdot
.9045 .01617 Mdot
.90452 .01524 Mdot
.90455 .01636 Mdot
.90457 .01552 Mdot
.9046 .01592 Mdot
.90463 .01658 Mdot
.90465 .01519 Mdot
.90468 .01579 Mdot
.9047 .0157 Mdot
.90473 .01584 Mdot
.90475 .01593 Mdot
.90478 .01667 Mdot
.90481 .01658 Mdot
.90483 .01672 Mdot
.90486 .01816 Mdot
.90488 .01927 Mdot
.90491 .0177 Mdot
.90494 .01672 Mdot
.90496 .01731 Mdot
.90499 .01698 Mdot
.90501 .01716 Mdot
.90504 .01795 Mdot
.90506 .01748 Mdot
.90509 .01573 Mdot
.90512 .01705 Mdot
.90514 .01656 Mdot
.90517 .01631 Mdot
.90519 .01593 Mdot
.90522 .017 Mdot
.90525 .01643 Mdot
.90527 .01643 Mdot
.9053 .01806 Mdot
.90532 .01726 Mdot
.90535 .01836 Mdot
.90537 .01617 Mdot
.9054 .01878 Mdot
.90543 .01806 Mdot
.90545 .02486 Mdot
.90548 .01522 Mdot
.9055 .01688 Mdot
.90553 .01624 Mdot
.90556 .0167 Mdot
.90558 .01593 Mdot
.90561 .01497 Mdot
.90563 .01532 Mdot
.90566 .01617 Mdot
.90568 .01526 Mdot
.90571 .01856 Mdot
.90574 .01679 Mdot
.90576 .01499 Mdot
.90579 .01642 Mdot
.90581 .01684 Mdot
.90584 .01535 Mdot
.90587 .01582 Mdot
.90589 .01716 Mdot
.90592 .01664 Mdot
.90594 .01711 Mdot
.90597 .01792 Mdot
.90599 .01697 Mdot
.90602 .01699 Mdot
.90605 .01592 Mdot
.90607 .01601 Mdot
.9061 .01705 Mdot
.90612 .01701 Mdot
.90615 .01678 Mdot
.90618 .01773 Mdot
.9062 .01616 Mdot
.90623 .01586 Mdot
.90625 .01783 Mdot
.90628 .01521 Mdot
.9063 .01671 Mdot
.90633 .01746 Mdot
.90636 .0186 Mdot
.90638 .01849 Mdot
.90641 .01703 Mdot
.90643 .0153 Mdot
.90646 .01874 Mdot
.90649 .01754 Mdot
.90651 .01923 Mdot
.90654 .01646 Mdot
.90656 .02012 Mdot
.90659 .01667 Mdot
.90661 .01781 Mdot
.90664 .01944 Mdot
.90667 .02221 Mdot
.90669 .02068 Mdot
.90672 .01702 Mdot
.90674 .01731 Mdot
.90677 .02305 Mdot
.9068 .02555 Mdot
.90682 .02469 Mdot
.90685 .01932 Mdot
.90687 .01841 Mdot
.9069 .02034 Mdot
.90692 .0218 Mdot
.90695 .02318 Mdot
.90698 .02425 Mdot
.907 .01531 Mdot
.90703 .01973 Mdot
.90705 .01518 Mdot
.90708 .01566 Mdot
.90711 .01767 Mdot
.90713 .02031 Mdot
.90716 .01606 Mdot
.90718 .01818 Mdot
.90721 .02144 Mdot
.90724 .02282 Mdot
.90726 .02149 Mdot
.90729 .01764 Mdot
.90731 .01822 Mdot
.90734 .01602 Mdot
.90736 .01621 Mdot
.90739 .01783 Mdot
.90742 .02105 Mdot
.90744 .02299 Mdot
.90747 .01846 Mdot
.90749 .02251 Mdot
.90752 .02007 Mdot
.90755 .01704 Mdot
.90757 .01782 Mdot
.9076 .01986 Mdot
.90762 .01733 Mdot
.90765 .0204 Mdot
.90767 .01776 Mdot
.9077 .01618 Mdot
.90773 .02019 Mdot
.90775 .01701 Mdot
.90778 .01603 Mdot
.9078 .01882 Mdot
.90783 .01793 Mdot
.90786 .01775 Mdot
.90788 .01757 Mdot
.90791 .0178 Mdot
.90793 .02173 Mdot
.90796 .0216 Mdot
.90798 .0185 Mdot
.90801 .0179 Mdot
.90804 .02074 Mdot
.90806 .02161 Mdot
.90809 .0175 Mdot
.90811 .01593 Mdot
.90814 .01867 Mdot
.90817 .02047 Mdot
.90819 .0189 Mdot
.90822 .01716 Mdot
.90824 .0175 Mdot
.90827 .01788 Mdot
.90829 .01803 Mdot
.90832 .01613 Mdot
.90835 .01681 Mdot
.90837 .01735 Mdot
.9084 .01563 Mdot
.90842 .0176 Mdot
.90845 .01624 Mdot
.90848 .01576 Mdot
.9085 .01759 Mdot
.90853 .01556 Mdot
.90855 .01622 Mdot
.90858 .01711 Mdot
.9086 .01706 Mdot
.90863 .01679 Mdot
.90866 .01503 Mdot
.90868 .01648 Mdot
.90871 .01637 Mdot
.90873 .01609 Mdot
.90876 .01569 Mdot
.90879 .01726 Mdot
.90881 .01846 Mdot
.90884 .02243 Mdot
.90886 .01754 Mdot
.90889 .01827 Mdot
.90891 .01709 Mdot
.90894 .01631 Mdot
.90897 .01609 Mdot
.90899 .0179 Mdot
.90902 .01563 Mdot
.90904 .01504 Mdot
.90907 .01515 Mdot
.9091 .01778 Mdot
.90912 .01799 Mdot
.90915 .01549 Mdot
.90917 .01601 Mdot
.9092 .017 Mdot
.90922 .01547 Mdot
.90925 .015 Mdot
.90928 .01737 Mdot
.9093 .01613 Mdot
.90933 .01796 Mdot
.90935 .01692 Mdot
.90938 .01601 Mdot
.90941 .01703 Mdot
.90943 .01796 Mdot
.90946 .01745 Mdot
.90948 .01517 Mdot
.90951 .01517 Mdot
.90953 .01538 Mdot
.90956 .01668 Mdot
.90959 .0162 Mdot
.90961 .01605 Mdot
.90964 .01576 Mdot
.90966 .01592 Mdot
.90969 .01599 Mdot
.90972 .01537 Mdot
.90974 .01713 Mdot
.90977 .01547 Mdot
.90979 .01617 Mdot
.90982 .01667 Mdot
.90984 .01495 Mdot
.90987 .01845 Mdot
.9099 .01566 Mdot
.90992 .01586 Mdot
.90995 .01781 Mdot
.90997 .01529 Mdot
.91 .01514 Mdot
.91003 .01755 Mdot
.91005 .01749 Mdot
.91008 .0169 Mdot
.9101 .01719 Mdot
.91013 .01582 Mdot
.91015 .01617 Mdot
.91018 .01657 Mdot
.91021 .01499 Mdot
.91023 .01624 Mdot
.91026 .01631 Mdot
.91028 .01642 Mdot
.91031 .01543 Mdot
.91034 .01569 Mdot
.91036 .01682 Mdot
.91039 .01695 Mdot
.91041 .01744 Mdot
.91044 .01543 Mdot
.91046 .01642 Mdot
.91049 .01647 Mdot
.91052 .01544 Mdot
.91054 .01782 Mdot
.91057 .01582 Mdot
.91059 .01577 Mdot
.91062 .0163 Mdot
.91065 .01633 Mdot
.91067 .01654 Mdot
.9107 .01566 Mdot
.91072 .01568 Mdot
.91075 .01494 Mdot
.91077 .01594 Mdot
.9108 .01542 Mdot
.91083 .01697 Mdot
.91085 .01547 Mdot
.91088 .01622 Mdot
.9109 .01606 Mdot
.91093 .01545 Mdot
.91096 .01501 Mdot
.91098 .01624 Mdot
.91101 .01614 Mdot
.91103 .01558 Mdot
.91106 .01567 Mdot
.91108 .01674 Mdot
.91111 .01607 Mdot
.91114 .0153 Mdot
.91116 .01537 Mdot
.91119 .01715 Mdot
.91121 .01808 Mdot
.91124 .01633 Mdot
.91127 .01563 Mdot
.91129 .01517 Mdot
.91132 .01652 Mdot
.91134 .01697 Mdot
.91137 .01573 Mdot
.91139 .01808 Mdot
.91142 .01966 Mdot
.91145 .02047 Mdot
.91147 .01947 Mdot
.9115 .01766 Mdot
.91152 .01686 Mdot
.91155 .01955 Mdot
.91158 .01825 Mdot
.9116 .01658 Mdot
.91163 .01646 Mdot
.91165 .01717 Mdot
.91168 .0157 Mdot
.9117 .01669 Mdot
.91173 .01658 Mdot
.91176 .01732 Mdot
.91178 .01591 Mdot
.91181 .01781 Mdot
.91183 .01526 Mdot
.91186 .01727 Mdot
.91189 .01705 Mdot
.91191 .01689 Mdot
.91194 .01713 Mdot
.91196 .01632 Mdot
.91199 .01784 Mdot
.91201 .01679 Mdot
.91204 .01503 Mdot
.91207 .0163 Mdot
.91209 .01734 Mdot
.91212 .01693 Mdot
.91214 .01994 Mdot
.91217 .0185 Mdot
.9122 .01735 Mdot
.91222 .01973 Mdot
.91225 .01654 Mdot
.91227 .01795 Mdot
.9123 .0162 Mdot
.91232 .0185 Mdot
.91235 .01617 Mdot
.91238 .01598 Mdot
.9124 .01752 Mdot
.91243 .01541 Mdot
.91245 .01807 Mdot
.91248 .01754 Mdot
.91251 .01659 Mdot
.91253 .01737 Mdot
.91256 .01671 Mdot
.91258 .01773 Mdot
.91261 .01901 Mdot
.91263 .0188 Mdot
.91266 .01843 Mdot
.91269 .01664 Mdot
.91271 .01811 Mdot
.91274 .01709 Mdot
.91276 .01847 Mdot
.91279 .02033 Mdot
.91282 .01712 Mdot
.91284 .01618 Mdot
.91287 .01836 Mdot
.91289 .02145 Mdot
.91292 .02261 Mdot
.91294 .01992 Mdot
.91297 .01672 Mdot
.913 .01595 Mdot
.91302 .02086 Mdot
.91305 .02455 Mdot
.91307 .02611 Mdot
.9131 .02496 Mdot
.91313 .01612 Mdot
.91315 .02323 Mdot
.91318 .02564 Mdot
.9132 .03103 Mdot
.91323 .03089 Mdot
.91325 .02132 Mdot
.91328 .01875 Mdot
.91331 .02078 Mdot
.91333 .02302 Mdot
.91336 .01667 Mdot
.91338 .0169 Mdot
.91341 .0151 Mdot
.91344 .01903 Mdot
.91346 .02428 Mdot
.91349 .02851 Mdot
.91351 .02551 Mdot
.91354 .01895 Mdot
.91356 .01739 Mdot
.91359 .02161 Mdot
.91362 .02078 Mdot
.91364 .01741 Mdot
.91367 .01562 Mdot
.91369 .02152 Mdot
.91372 .02185 Mdot
.91375 .02502 Mdot
.91377 .02486 Mdot
.9138 .01877 Mdot
.91382 .01533 Mdot
.91385 .01877 Mdot
.91387 .01544 Mdot
.9139 .0216 Mdot
.91393 .01655 Mdot
.91395 .01829 Mdot
.91398 .0155 Mdot
.914 .02118 Mdot
.91403 .02489 Mdot
.91406 .02186 Mdot
.91408 .02422 Mdot
.91411 .02243 Mdot
.91413 .01731 Mdot
.91416 .0164 Mdot
.91418 .02078 Mdot
.91421 .02 Mdot
.91424 .02586 Mdot
.91426 .02012 Mdot
.91429 .01974 Mdot
.91431 .02353 Mdot
.91434 .02045 Mdot
.91437 .01735 Mdot
.91439 .02179 Mdot
.91442 .02267 Mdot
.91444 .022 Mdot
.91447 .0179 Mdot
.91449 .01965 Mdot
.91452 .01932 Mdot
.91455 .01848 Mdot
.91457 .01574 Mdot
.9146 .01593 Mdot
.91462 .01902 Mdot
.91465 .01729 Mdot
.91468 .0155 Mdot
.9147 .01706 Mdot
.91473 .01622 Mdot
.91475 .01799 Mdot
.91478 .01644 Mdot
.9148 .01532 Mdot
.91483 .01849 Mdot
.91486 .0153 Mdot
.91488 .01572 Mdot
.91491 .01649 Mdot
.91493 .01532 Mdot
.91496 .01517 Mdot
.91499 .01765 Mdot
.91501 .01732 Mdot
.91504 .01475 Mdot
.91506 .01648 Mdot
.91509 .01644 Mdot
.91511 .01594 Mdot
.91514 .01715 Mdot
.91517 .01834 Mdot
.91519 .01495 Mdot
.91522 .01594 Mdot
.91524 .01993 Mdot
.91527 .01658 Mdot
.9153 .015 Mdot
.91532 .01621 Mdot
.91535 .01624 Mdot
.91537 .01718 Mdot
.9154 .01547 Mdot
.91542 .01729 Mdot
.91545 .01709 Mdot
.91548 .01553 Mdot
.9155 .01584 Mdot
.91553 .0158 Mdot
.91555 .01642 Mdot
.91558 .01579 Mdot
.91561 .01547 Mdot
.91563 .01566 Mdot
.91566 .01556 Mdot
.91568 .01602 Mdot
.91571 .01607 Mdot
.91573 .01531 Mdot
.91576 .01668 Mdot
.91579 .01527 Mdot
.91581 .01833 Mdot
.91584 .01606 Mdot
.91586 .01687 Mdot
.91589 .01629 Mdot
.91592 .01591 Mdot
.91594 .01773 Mdot
.91597 .01735 Mdot
.91599 .01559 Mdot
.91602 .01484 Mdot
.91604 .01736 Mdot
.91607 .01793 Mdot
.9161 .01845 Mdot
.91612 .01778 Mdot
.91615 .01531 Mdot
.91617 .01552 Mdot
.9162 .01589 Mdot
.91623 .01554 Mdot
.91625 .0153 Mdot
.91628 .0168 Mdot
.9163 .01684 Mdot
.91633 .01688 Mdot
.91636 .01605 Mdot
.91638 .01827 Mdot
.91641 .01965 Mdot
.91643 .01841 Mdot
.91646 .01553 Mdot
.91648 .0151 Mdot
.91651 .01821 Mdot
.91654 .01736 Mdot
.91656 .01677 Mdot
.91659 .01572 Mdot
.91661 .01649 Mdot
.91664 .01778 Mdot
.91667 .01587 Mdot
.91669 .01678 Mdot
.91672 .01736 Mdot
.91674 .01805 Mdot
.91677 .01755 Mdot
.91679 .01717 Mdot
.91682 .01619 Mdot
.91685 .01519 Mdot
.91687 .01752 Mdot
.9169 .01702 Mdot
.91692 .01599 Mdot
.91695 .01649 Mdot
.91698 .01557 Mdot
.917 .01697 Mdot
.91703 .01662 Mdot
.91705 .01619 Mdot
.91708 .01676 Mdot
.9171 .01612 Mdot
.91713 .01632 Mdot
.91716 .0171 Mdot
.91718 .01758 Mdot
.91721 .01771 Mdot
.91723 .01615 Mdot
.91726 .01642 Mdot
.91729 .01537 Mdot
.91731 .01837 Mdot
.91734 .01844 Mdot
.91736 .01663 Mdot
.91739 .01548 Mdot
.91741 .0155 Mdot
.91744 .01673 Mdot
.91747 .01622 Mdot
.91749 .01594 Mdot
.91752 .01631 Mdot
.91754 .01597 Mdot
.91757 .01673 Mdot
.9176 .01685 Mdot
.91762 .01597 Mdot
.91765 .01863 Mdot
.91767 .01623 Mdot
.9177 .01653 Mdot
.91772 .01663 Mdot
.91775 .01845 Mdot
.91778 .0174 Mdot
.9178 .01776 Mdot
.91783 .01796 Mdot
.91785 .02011 Mdot
.91788 .02032 Mdot
.91791 .01723 Mdot
.91793 .02045 Mdot
.91796 .01723 Mdot
.91798 .01899 Mdot
.91801 .01934 Mdot
.91803 .0198 Mdot
.91806 .02099 Mdot
.91809 .02048 Mdot
.91811 .02012 Mdot
.91814 .02182 Mdot
.91816 .02057 Mdot
.91819 .02018 Mdot
.91822 .01734 Mdot
.91824 .0192 Mdot
.91827 .01928 Mdot
.91829 .01795 Mdot
.91832 .01907 Mdot
.91834 .01776 Mdot
.91837 .01814 Mdot
.9184 .01839 Mdot
.91842 .01903 Mdot
.91845 .01696 Mdot
.91847 .01699 Mdot
.9185 .01667 Mdot
.91853 .01731 Mdot
.91855 .0161 Mdot
.91858 .01919 Mdot
.9186 .01614 Mdot
.91863 .01786 Mdot
.91865 .01692 Mdot
.91868 .01572 Mdot
.91871 .01513 Mdot
.91873 .01841 Mdot
.91876 .01606 Mdot
.91878 .01839 Mdot
.91881 .01809 Mdot
.91884 .0183 Mdot
.91886 .01837 Mdot
.91889 .01724 Mdot
.91891 .01584 Mdot
.91894 .01691 Mdot
.91896 .01627 Mdot
.91899 .01815 Mdot
.91902 .0195 Mdot
.91904 .01867 Mdot
.91907 .01652 Mdot
.91909 .01874 Mdot
.91912 .019 Mdot
.91915 .02281 Mdot
.91917 .02192 Mdot
.9192 .02524 Mdot
.91922 .01905 Mdot
.91925 .01996 Mdot
.91927 .02507 Mdot
.9193 .03035 Mdot
.91933 .03185 Mdot
.91935 .02633 Mdot
.91938 .01747 Mdot
.9194 .02421 Mdot
.91943 .03122 Mdot
.91946 .03787 Mdot
.91948 .03607 Mdot
.91951 .02558 Mdot
.91953 .01681 Mdot
.91956 .02596 Mdot
.91958 .0266 Mdot
.91961 .02619 Mdot
.91964 .01837 Mdot
.91966 .02172 Mdot
.91969 .02172 Mdot
.91971 .0225 Mdot
.91974 .02588 Mdot
.91977 .02756 Mdot
.91979 .02398 Mdot
.91982 .01767 Mdot
.91984 .0226 Mdot
.91987 .02826 Mdot
.91989 .02529 Mdot
.91992 .01728 Mdot
.91995 .02374 Mdot
.91997 .02628 Mdot
.92 .02488 Mdot
.92002 .02633 Mdot
.92005 .02296 Mdot
.92008 .01792 Mdot
.9201 .01853 Mdot
.92013 .01882 Mdot
.92015 .01748 Mdot
.92018 .01752 Mdot
.9202 .02286 Mdot
.92023 .02115 Mdot
.92026 .0204 Mdot
.92028 .0167 Mdot
.92031 .01789 Mdot
.92033 .02078 Mdot
.92036 .02007 Mdot
.92039 .01995 Mdot
.92041 .01682 Mdot
.92044 .01874 Mdot
.92046 .01673 Mdot
.92049 .01722 Mdot
.92051 .01556 Mdot
.92054 .01824 Mdot
.92057 .01985 Mdot
.92059 .01889 Mdot
.92062 .01775 Mdot
.92064 .01745 Mdot
.92067 .01968 Mdot
.9207 .01937 Mdot
.92072 .01525 Mdot
.92075 .01776 Mdot
.92077 .01826 Mdot
.9208 .01815 Mdot
.92082 .0161 Mdot
.92085 .0149 Mdot
.92088 .01829 Mdot
.9209 .01617 Mdot
.92093 .01584 Mdot
.92095 .01716 Mdot
.92098 .01601 Mdot
.92101 .01593 Mdot
.92103 .01805 Mdot
.92106 .0166 Mdot
.92108 .01849 Mdot
.92111 .01637 Mdot
.92113 .01606 Mdot
.92116 .018 Mdot
.92119 .01653 Mdot
.92121 .01627 Mdot
.92124 .01553 Mdot
.92126 .01601 Mdot
.92129 .01557 Mdot
.92132 .01848 Mdot
.92134 .01599 Mdot
.92137 .01694 Mdot
.92139 .01699 Mdot
.92142 .01652 Mdot
.92144 .0164 Mdot
.92147 .01747 Mdot
.9215 .01592 Mdot
.92152 .0157 Mdot
.92155 .01666 Mdot
.92157 .01571 Mdot
.9216 .01594 Mdot
.92163 .01575 Mdot
.92165 .01557 Mdot
.92168 .01596 Mdot
.9217 .01619 Mdot
.92173 .01736 Mdot
.92175 .01532 Mdot
.92178 .01634 Mdot
.92181 .01571 Mdot
.92183 .01612 Mdot
.92186 .01618 Mdot
.92188 .01648 Mdot
.92191 .01772 Mdot
.92194 .01513 Mdot
.92196 .01492 Mdot
.92199 .0164 Mdot
.92201 .01688 Mdot
.92204 .01656 Mdot
.92206 .01718 Mdot
.92209 .01697 Mdot
.92212 .01599 Mdot
.92214 .01498 Mdot
.92217 .01616 Mdot
.92219 .01695 Mdot
.92222 .01604 Mdot
.92225 .01529 Mdot
.92227 .01601 Mdot
.9223 .01627 Mdot
.92232 .01549 Mdot
.92235 .0155 Mdot
.92237 .01705 Mdot
.9224 .01555 Mdot
.92243 .0171 Mdot
.92245 .01621 Mdot
.92248 .01565 Mdot
.9225 .01695 Mdot
.92253 .01644 Mdot
.92256 .01507 Mdot
.92258 .01835 Mdot
.92261 .01644 Mdot
.92263 .01681 Mdot
.92266 .01507 Mdot
.92268 .0163 Mdot
.92271 .01566 Mdot
.92274 .01616 Mdot
.92276 .0165 Mdot
.92279 .01855 Mdot
.92281 .01643 Mdot
.92284 .01534 Mdot
.92287 .01941 Mdot
.92289 .01626 Mdot
.92292 .01701 Mdot
.92294 .01854 Mdot
.92297 .01654 Mdot
.92299 .01678 Mdot
.92302 .01845 Mdot
.92305 .01827 Mdot
.92307 .01809 Mdot
.9231 .021 Mdot
.92312 .01604 Mdot
.92315 .01745 Mdot
.92318 .01738 Mdot
.9232 .01554 Mdot
.92323 .01628 Mdot
.92325 .01714 Mdot
.92328 .0171 Mdot
.9233 .01565 Mdot
.92333 .0151 Mdot
.92336 .01626 Mdot
.92338 .0157 Mdot
.92341 .01492 Mdot
.92343 .01534 Mdot
.92346 .01551 Mdot
.92349 .01642 Mdot
.92351 .01623 Mdot
.92354 .01587 Mdot
.92356 .01502 Mdot
.92359 .01667 Mdot
.92361 .01649 Mdot
.92364 .01726 Mdot
.92367 .01498 Mdot
.92369 .01683 Mdot
.92372 .01748 Mdot
.92374 .01704 Mdot
.92377 .01718 Mdot
.9238 .01868 Mdot
.92382 .01644 Mdot
.92385 .01543 Mdot
.92387 .01749 Mdot
.9239 .01641 Mdot
.92392 .01552 Mdot
.92395 .01657 Mdot
.92398 .01592 Mdot
.924 .01603 Mdot
.92403 .01587 Mdot
.92405 .01753 Mdot
.92408 .01662 Mdot
.92411 .01615 Mdot
.92413 .015 Mdot
.92416 .01567 Mdot
.92418 .01869 Mdot
.92421 .01617 Mdot
.92423 .01744 Mdot
.92426 .01919 Mdot
.92429 .01956 Mdot
.92431 .01857 Mdot
.92434 .01868 Mdot
.92436 .02013 Mdot
.92439 .01801 Mdot
.92442 .02309 Mdot
.92444 .02252 Mdot
.92447 .02527 Mdot
.92449 .02081 Mdot
.92452 .02253 Mdot
.92454 .02387 Mdot
.92457 .02387 Mdot
.9246 .02224 Mdot
.92462 .02257 Mdot
.92465 .02156 Mdot
.92467 .02201 Mdot
.9247 .02375 Mdot
.92473 .02333 Mdot
.92475 .02485 Mdot
.92478 .02535 Mdot
.9248 .01913 Mdot
.92483 .02173 Mdot
.92485 .02137 Mdot
.92488 .02086 Mdot
.92491 .01923 Mdot
.92493 .01528 Mdot
.92496 .01719 Mdot
.92498 .02272 Mdot
.92501 .01693 Mdot
.92504 .01999 Mdot
.92506 .02313 Mdot
.92509 .02138 Mdot
.92511 .02598 Mdot
.92514 .0292 Mdot
.92516 .02355 Mdot
.92519 .02548 Mdot
.92522 .02683 Mdot
.92524 .02793 Mdot
.92527 .02937 Mdot
.92529 .02296 Mdot
.92532 .02017 Mdot
.92535 .02557 Mdot
.92537 .02367 Mdot
.9254 .02907 Mdot
.92542 .03952 Mdot
.92545 .03742 Mdot
.92548 .02244 Mdot
.9255 .02236 Mdot
.92553 .03606 Mdot
.92555 .06047 Mdot
.92558 .06825 Mdot
.9256 .05283 Mdot
.92563 .02396 Mdot
.92566 .02973 Mdot
.92568 .06575 Mdot
.92571 .09176 Mdot
.92573 .09318 Mdot
.92576 .06356 Mdot
.92579 .01807 Mdot
.92581 .05598 Mdot
.92584 .09009 Mdot
.92586 .10293 Mdot
.92589 .07724 Mdot
.92591 .02766 Mdot
.92594 .04065 Mdot
.92597 .03684 Mdot
.92599 .01977 Mdot
.92602 .04558 Mdot
.92604 .05119 Mdot
.92607 .04223 Mdot
.9261 .06272 Mdot
.92612 .12223 Mdot
.92615 .13575 Mdot
.92617 .08226 Mdot
.9262 .03036 Mdot
.92622 .06404 Mdot
.92625 .06534 Mdot
.92628 .07692 Mdot
.9263 .09192 Mdot
.92633 .07753 Mdot
.92635 .06736 Mdot
.92638 .08904 Mdot
.92641 .07343 Mdot
.92643 .02957 Mdot
.92646 .0901 Mdot
.92648 .09794 Mdot
.92651 .0835 Mdot
.92653 .06009 Mdot
.92656 .04183 Mdot
.92659 .11207 Mdot
.92661 .13917 Mdot
.92664 .08133 Mdot
.92666 .0402 Mdot
.92669 .06737 Mdot
.92672 .08503 Mdot
.92674 .08143 Mdot
.92677 .05864 Mdot
.92679 .07203 Mdot
.92682 .0821 Mdot
.92684 .05715 Mdot
.92687 .04322 Mdot
.9269 .0262 Mdot
.92692 .08198 Mdot
.92695 .0758 Mdot
.92697 .03135 Mdot
.927 .0487 Mdot
.92703 .03674 Mdot
.92705 .03632 Mdot
.92708 .06535 Mdot
.9271 .02416 Mdot
.92713 .06783 Mdot
.92715 .05237 Mdot
.92718 .03754 Mdot
.92721 .03846 Mdot
.92723 .03125 Mdot
.92726 .02691 Mdot
.92728 .04021 Mdot
.92731 .016 Mdot
.92734 .04395 Mdot
.92736 .02955 Mdot
.92739 .02874 Mdot
.92741 .02596 Mdot
.92744 .02526 Mdot
.92746 .01944 Mdot
.92749 .02922 Mdot
.92752 .02367 Mdot
.92754 .02416 Mdot
.92757 .01695 Mdot
.92759 .03177 Mdot
.92762 .02074 Mdot
.92765 .03296 Mdot
.92767 .02105 Mdot
.9277 .02452 Mdot
.92772 .01875 Mdot
.92775 .03759 Mdot
.92777 .01954 Mdot
.9278 .03721 Mdot
.92783 .02171 Mdot
.92785 .04526 Mdot
.92788 .02067 Mdot
.9279 .04416 Mdot
.92793 .0277 Mdot
.92796 .0358 Mdot
.92798 .02955 Mdot
.92801 .03862 Mdot
.92803 .02233 Mdot
.92806 .02946 Mdot
.92808 .02171 Mdot
.92811 .02805 Mdot
.92814 .0217 Mdot
.92816 .03457 Mdot
.92819 .01778 Mdot
.92821 .02488 Mdot
.92824 .02462 Mdot
.92827 .0276 Mdot
.92829 .01928 Mdot
.92832 .02808 Mdot
.92834 .02187 Mdot
.92837 .02108 Mdot
.92839 .01924 Mdot
.92842 .02337 Mdot
.92845 .01616 Mdot
.92847 .02616 Mdot
.9285 .01683 Mdot
.92852 .03365 Mdot
.92855 .02097 Mdot
.92858 .02156 Mdot
.9286 .02007 Mdot
.92863 .01945 Mdot
.92865 .02072 Mdot
.92868 .03003 Mdot
.9287 .02147 Mdot
.92873 .01631 Mdot
.92876 .01762 Mdot
.92878 .01684 Mdot
.92881 .02344 Mdot
.92883 .02378 Mdot
.92886 .025 Mdot
.92889 .02237 Mdot
.92891 .0226 Mdot
.92894 .02999 Mdot
.92896 .03363 Mdot
.92899 .02944 Mdot
.92901 .02649 Mdot
.92904 .03801 Mdot
.92907 .04662 Mdot
.92909 .04151 Mdot
.92912 .04234 Mdot
.92914 .04391 Mdot
.92917 .03381 Mdot
.9292 .03742 Mdot
.92922 .04034 Mdot
.92925 .04022 Mdot
.92927 .04351 Mdot
.9293 .04949 Mdot
.92932 .04854 Mdot
.92935 .0431 Mdot
.92938 .05114 Mdot
.9294 .05205 Mdot
.92943 .04291 Mdot
.92945 .05151 Mdot
.92948 .046 Mdot
.92951 .05507 Mdot
.92953 .05751 Mdot
.92956 .05195 Mdot
.92958 .05402 Mdot
.92961 .06386 Mdot
.92963 .06428 Mdot
.92966 .06174 Mdot
.92969 .05967 Mdot
.92971 .04921 Mdot
.92974 .05721 Mdot
.92976 .05574 Mdot
.92979 .06114 Mdot
.92982 .06132 Mdot
.92984 .05248 Mdot
.92987 .04914 Mdot
.92989 .04932 Mdot
.92992 .06424 Mdot
.92994 .06109 Mdot
.92997 .0545 Mdot
.93 .04594 Mdot
.93002 .05121 Mdot
.93005 .0581 Mdot
.93007 .05626 Mdot
.9301 .03997 Mdot
.93013 .03781 Mdot
.93015 .03269 Mdot
.93018 .03093 Mdot
.9302 .02719 Mdot
.93023 .0223 Mdot
.93025 .02703 Mdot
.93028 .01768 Mdot
.93031 .03722 Mdot
.93033 .04528 Mdot
.93036 .02792 Mdot
.93038 .03217 Mdot
.93041 .04812 Mdot
.93044 .0422 Mdot
.93046 .03461 Mdot
.93049 .03084 Mdot
.93051 .02872 Mdot
.93054 .04046 Mdot
.93056 .03611 Mdot
.93059 .0372 Mdot
.93062 .04503 Mdot
.93064 .03949 Mdot
.93067 .05561 Mdot
.93069 .06585 Mdot
.93072 .05963 Mdot
.93075 .07456 Mdot
.93077 .09547 Mdot
.9308 .09131 Mdot
.93082 .10805 Mdot
.93085 .11352 Mdot
.93087 .12027 Mdot
.9309 .12436 Mdot
.93093 .13536 Mdot
.93095 .16221 Mdot
.93098 .15505 Mdot
.931 .15208 Mdot
.93103 .14171 Mdot
.93106 .12647 Mdot
.93108 .13119 Mdot
.93111 .1087 Mdot
.93113 .11265 Mdot
.93116 .11895 Mdot
.93118 .08096 Mdot
.93121 .08963 Mdot
.93124 .10309 Mdot
.93126 .0839 Mdot
.93129 .09169 Mdot
.93131 .08627 Mdot
.93134 .06723 Mdot
.93137 .08163 Mdot
.93139 .06963 Mdot
.93142 .03249 Mdot
.93144 .0518 Mdot
.93147 .05379 Mdot
.93149 .05332 Mdot
.93152 .07264 Mdot
.93155 .0809 Mdot
.93157 .0524 Mdot
.9316 .04507 Mdot
.93162 .08585 Mdot
.93165 .11973 Mdot
.93168 .12583 Mdot
.9317 .08123 Mdot
.93173 .02042 Mdot
.93175 .07578 Mdot
.93178 .123 Mdot
.9318 .14337 Mdot
.93183 .1349 Mdot
.93186 .10687 Mdot
.93188 .07168 Mdot
.93191 .06914 Mdot
.93193 .11693 Mdot
.93196 .20434 Mdot
.93199 .22437 Mdot
.93201 .13559 Mdot
.93204 .04259 Mdot
.93206 .09786 Mdot
.93209 .23334 Mdot
.93211 .30992 Mdot
.93214 .26467 Mdot
.93217 .11457 Mdot
.93219 .05764 Mdot
.93222 .08815 Mdot
.93224 .08607 Mdot
.93227 .09071 Mdot
.9323 .02836 Mdot
.93232 .0714 Mdot
.93235 .108 Mdot
.93237 .16479 Mdot
.9324 .21221 Mdot
.93242 .18481 Mdot
.93245 .09997 Mdot
.93248 .06488 Mdot
.9325 .08155 Mdot
.93253 .05692 Mdot
.93255 .05311 Mdot
.93258 .11015 Mdot
.93261 .13318 Mdot
.93263 .1481 Mdot
.93266 .14194 Mdot
.93268 .05471 Mdot
.93271 .10115 Mdot
.93273 .17983 Mdot
.93276 .17201 Mdot
.93279 .10716 Mdot
.93281 .03836 Mdot
.93284 .15841 Mdot
.93286 .20666 Mdot
.93289 .12844 Mdot
.93292 .03788 Mdot
.93294 .10475 Mdot
.93297 .1244 Mdot
.93299 .12225 Mdot
.93302 .06722 Mdot
.93304 .06612 Mdot
.93307 .12008 Mdot
.9331 .09257 Mdot
.93312 .05516 Mdot
.93315 .04918 Mdot
.93317 .05879 Mdot
.9332 .08244 Mdot
.93323 .05579 Mdot
.93325 .04915 Mdot
.93328 .07038 Mdot
.9333 .04522 Mdot
.93333 .05801 Mdot
.93335 .04455 Mdot
.93338 .04089 Mdot
.93341 .04471 Mdot
.93343 .02586 Mdot
.93346 .03811 Mdot
.93348 .04497 Mdot
.93351 .03228 Mdot
.93354 .04313 Mdot
.93356 .03124 Mdot
.93359 .03801 Mdot
.93361 .03209 Mdot
.93364 .02214 Mdot
.93366 .02346 Mdot
.93369 .02406 Mdot
.93372 .02538 Mdot
.93374 .03368 Mdot
.93377 .02133 Mdot
.93379 .02373 Mdot
.93382 .01802 Mdot
.93385 .02425 Mdot
.93387 .01611 Mdot
.9339 .02308 Mdot
.93392 .01809 Mdot
.93395 .0215 Mdot
.93397 .01586 Mdot
.934 .01872 Mdot
.93403 .01913 Mdot
.93405 .02368 Mdot
.93408 .01505 Mdot
.9341 .01791 Mdot
.93413 .01953 Mdot
.93416 .01647 Mdot
.93418 .01722 Mdot
.93421 .01802 Mdot
.93423 .01686 Mdot
.93426 .01951 Mdot
.93428 .01638 Mdot
.93431 .01816 Mdot
.93434 .01622 Mdot
.93436 .01929 Mdot
.93439 .01912 Mdot
.93441 .01897 Mdot
.93444 .01905 Mdot
.93447 .02265 Mdot
.93449 .02115 Mdot
.93452 .02211 Mdot
.93454 .02248 Mdot
.93457 .02042 Mdot
.9346 .02024 Mdot
.93462 .01848 Mdot
.93465 .02218 Mdot
.93467 .02249 Mdot
.9347 .02842 Mdot
.93472 .0243 Mdot
.93475 .02173 Mdot
.93478 .01816 Mdot
.9348 .02419 Mdot
.93483 .02442 Mdot
.93485 .01866 Mdot
.93488 .01618 Mdot
.93491 .02414 Mdot
.93493 .02657 Mdot
.93496 .01652 Mdot
.93498 .02138 Mdot
.93501 .0197 Mdot
.93503 .01819 Mdot
.93506 .01644 Mdot
.93509 .01951 Mdot
.93511 .02192 Mdot
.93514 .02111 Mdot
.93516 .01839 Mdot
.93519 .02096 Mdot
.93522 .01815 Mdot
.93524 .01746 Mdot
.93527 .01697 Mdot
.93529 .01682 Mdot
.93532 .01674 Mdot
.93534 .01895 Mdot
.93537 .01907 Mdot
.9354 .01864 Mdot
.93542 .02082 Mdot
.93545 .01951 Mdot
.93547 .01646 Mdot
.9355 .01768 Mdot
.93553 .01865 Mdot
.93555 .01956 Mdot
.93558 .01695 Mdot
.9356 .01756 Mdot
.93563 .02358 Mdot
.93565 .02061 Mdot
.93568 .01904 Mdot
.93571 .02332 Mdot
.93573 .0312 Mdot
.93576 .0279 Mdot
.93578 .02114 Mdot
.93581 .02637 Mdot
.93584 .03286 Mdot
.93586 .0329 Mdot
.93589 .0237 Mdot
.93591 .02952 Mdot
.93594 .02677 Mdot
.93596 .03163 Mdot
.93599 .03167 Mdot
.93602 .02625 Mdot
.93604 .02307 Mdot
.93607 .02476 Mdot
.93609 .03281 Mdot
.93612 .03219 Mdot
.93615 .02738 Mdot
.93617 .03141 Mdot
.9362 .02875 Mdot
.93622 .0302 Mdot
.93625 .03028 Mdot
.93627 .02728 Mdot
.9363 .03342 Mdot
.93633 .03183 Mdot
.93635 .03322 Mdot
.93638 .03753 Mdot
.9364 .03225 Mdot
.93643 .0336 Mdot
.93646 .03641 Mdot
.93648 .02892 Mdot
.93651 .02321 Mdot
.93653 .02411 Mdot
.93656 .02026 Mdot
.93658 .02858 Mdot
.93661 .03212 Mdot
.93664 .02015 Mdot
.93666 .02026 Mdot
.93669 .0215 Mdot
.93671 .02383 Mdot
.93674 .02696 Mdot
.93677 .01839 Mdot
.93679 .01951 Mdot
.93682 .01894 Mdot
.93684 .02163 Mdot
.93687 .01789 Mdot
.93689 .02053 Mdot
.93692 .01993 Mdot
.93695 .02595 Mdot
.93697 .02313 Mdot
.937 .02607 Mdot
.93702 .02784 Mdot
.93705 .03188 Mdot
.93708 .02917 Mdot
.9371 .04402 Mdot
.93713 .04883 Mdot
.93715 .05201 Mdot
.93718 .06114 Mdot
.9372 .06091 Mdot
.93723 .06925 Mdot
.93726 .06694 Mdot
.93728 .07169 Mdot
.93731 .07851 Mdot
.93733 .07501 Mdot
.93736 .08458 Mdot
.93739 .07946 Mdot
.93741 .07958 Mdot
.93744 .0879 Mdot
.93746 .07172 Mdot
.93749 .07577 Mdot
.93751 .07684 Mdot
.93754 .07093 Mdot
.93757 .06982 Mdot
.93759 .05958 Mdot
.93762 .05711 Mdot
.93764 .06444 Mdot
.93767 .05774 Mdot
.9377 .0583 Mdot
.93772 .06784 Mdot
.93775 .0584 Mdot
.93777 .06206 Mdot
.9378 .0551 Mdot
.93782 .03127 Mdot
.93785 .04415 Mdot
.93788 .04941 Mdot
.9379 .05464 Mdot
.93793 .0506 Mdot
.93795 .04507 Mdot
.93798 .03084 Mdot
.93801 .02051 Mdot
.93803 .04926 Mdot
.93806 .07292 Mdot
.93808 .08256 Mdot
.93811 .06482 Mdot
.93813 .03301 Mdot
.93816 .03426 Mdot
.93819 .07089 Mdot
.93821 .12143 Mdot
.93824 .13483 Mdot
.93826 .10491 Mdot
.93829 .06649 Mdot
.93832 .0481 Mdot
.93834 .1221 Mdot
.93837 .21283 Mdot
.93839 .23281 Mdot
.93842 .15994 Mdot
.93844 .0579 Mdot
.93847 .05332 Mdot
.9385 .12878 Mdot
.93852 .17016 Mdot
.93855 .12423 Mdot
.93857 .04313 Mdot
.9386 .07922 Mdot
.93863 .11081 Mdot
.93865 .13399 Mdot
.93868 .15523 Mdot
.9387 .13625 Mdot
.93873 .0896 Mdot
.93875 .08974 Mdot
.93878 .10549 Mdot
.93881 .06447 Mdot
.93883 .04841 Mdot
.93886 .11005 Mdot
.93888 .11339 Mdot
.93891 .09706 Mdot
.93894 .06663 Mdot
.93896 .02612 Mdot
.93899 .09545 Mdot
.93901 .11518 Mdot
.93904 .07046 Mdot
.93906 .02416 Mdot
.93909 .0422 Mdot
.93912 .06913 Mdot
.93914 .07523 Mdot
.93917 .05154 Mdot
.93919 .03902 Mdot
.93922 .0532 Mdot
.93925 .0347 Mdot
.93927 .02499 Mdot
.9393 .02771 Mdot
.93932 .04169 Mdot
.93935 .0283 Mdot
.93937 .01922 Mdot
.9394 .02478 Mdot
.93943 .02214 Mdot
.93945 .02787 Mdot
.93948 .02589 Mdot
.9395 .02391 Mdot
.93953 .0298 Mdot
.93956 .0215 Mdot
.93958 .0187 Mdot
.93961 .03247 Mdot
.93963 .01988 Mdot
.93966 .0259 Mdot
.93968 .0229 Mdot
.93971 .01964 Mdot
.93974 .01694 Mdot
.93976 .02373 Mdot
.93979 .02247 Mdot
.93981 .01961 Mdot
.93984 .01669 Mdot
.93987 .02081 Mdot
.93989 .02187 Mdot
.93992 .01832 Mdot
.93994 .02619 Mdot
.93997 .02986 Mdot
.93999 .0219 Mdot
.94002 .02759 Mdot
.94005 .0239 Mdot
.94007 .01969 Mdot
.9401 .02057 Mdot
.94012 .02684 Mdot
.94015 .02248 Mdot
.94018 .02688 Mdot
.9402 .02416 Mdot
.94023 .01801 Mdot
.94025 .02174 Mdot
.94028 .02349 Mdot
.9403 .02054 Mdot
.94033 .02683 Mdot
.94036 .01928 Mdot
.94038 .02577 Mdot
.94041 .02462 Mdot
.94043 .01854 Mdot
.94046 .01668 Mdot
.94049 .02358 Mdot
.94051 .01669 Mdot
.94054 .02652 Mdot
.94056 .02297 Mdot
.94059 .02105 Mdot
.94061 .01687 Mdot
.94064 .02247 Mdot
.94067 .01877 Mdot
.94069 .01971 Mdot
.94072 .01587 Mdot
.94074 .01774 Mdot
.94077 .01612 Mdot
.9408 .01902 Mdot
.94082 .01643 Mdot
.94085 .01719 Mdot
.94087 .01768 Mdot
.9409 .01748 Mdot
.94092 .0196 Mdot
.94095 .01708 Mdot
.94098 .0213 Mdot
.941 .01793 Mdot
.94103 .01842 Mdot
.94105 .01703 Mdot
.94108 .01733 Mdot
.94111 .01577 Mdot
.94113 .01819 Mdot
.94116 .01755 Mdot
.94118 .02155 Mdot
.94121 .02127 Mdot
.94123 .01882 Mdot
.94126 .02054 Mdot
.94129 .01762 Mdot
.94131 .01671 Mdot
.94134 .01817 Mdot
.94136 .02047 Mdot
.94139 .01999 Mdot
.94142 .01744 Mdot
.94144 .01694 Mdot
.94147 .01925 Mdot
.94149 .01803 Mdot
.94152 .017 Mdot
.94154 .01871 Mdot
.94157 .01671 Mdot
.9416 .01536 Mdot
.94162 .01733 Mdot
.94165 .01829 Mdot
.94167 .01754 Mdot
.9417 .01726 Mdot
.94173 .01619 Mdot
.94175 .01701 Mdot
.94178 .01668 Mdot
.9418 .01867 Mdot
.94183 .0202 Mdot
.94185 .01777 Mdot
.94188 .02075 Mdot
.94191 .02362 Mdot
.94193 .02247 Mdot
.94196 .01586 Mdot
.94198 .02277 Mdot
.94201 .02097 Mdot
.94204 .01781 Mdot
.94206 .01906 Mdot
.94209 .0207 Mdot
.94211 .02007 Mdot
.94214 .01792 Mdot
.94216 .01953 Mdot
.94219 .02085 Mdot
.94222 .01699 Mdot
.94224 .01842 Mdot
.94227 .01828 Mdot
.94229 .01861 Mdot
.94232 .01759 Mdot
.94235 .01982 Mdot
.94237 .0226 Mdot
.9424 .01836 Mdot
.94242 .0214 Mdot
.94245 .02118 Mdot
.94247 .02415 Mdot
.9425 .02094 Mdot
.94253 .01871 Mdot
.94255 .02564 Mdot
.94258 .02292 Mdot
.9426 .02099 Mdot
.94263 .0217 Mdot
.94266 .02021 Mdot
.94268 .01699 Mdot
.94271 .02 Mdot
.94273 .01621 Mdot
.94276 .02112 Mdot
.94278 .02348 Mdot
.94281 .01718 Mdot
.94284 .02102 Mdot
.94286 .01706 Mdot
.94289 .01979 Mdot
.94291 .01905 Mdot
.94294 .02012 Mdot
.94297 .01913 Mdot
.94299 .0219 Mdot
.94302 .02147 Mdot
.94304 .01839 Mdot
.94307 .01983 Mdot
.94309 .0209 Mdot
.94312 .02023 Mdot
.94315 .021 Mdot
.94317 .01574 Mdot
.9432 .02155 Mdot
.94322 .01969 Mdot
.94325 .0161 Mdot
.94328 .01985 Mdot
.9433 .01825 Mdot
.94333 .01621 Mdot
.94335 .01639 Mdot
.94338 .01947 Mdot
.9434 .0169 Mdot
.94343 .01544 Mdot
.94346 .01567 Mdot
.94348 .01765 Mdot
.94351 .02032 Mdot
.94353 .02463 Mdot
.94356 .02586 Mdot
.94359 .02556 Mdot
.94361 .02928 Mdot
.94364 .03621 Mdot
.94366 .03889 Mdot
.94369 .04462 Mdot
.94372 .04783 Mdot
.94374 .04773 Mdot
.94377 .05802 Mdot
.94379 .05815 Mdot
.94382 .06097 Mdot
.94384 .06449 Mdot
.94387 .05815 Mdot
.9439 .06556 Mdot
.94392 .06879 Mdot
.94395 .06499 Mdot
.94397 .07165 Mdot
.944 .06786 Mdot
.94403 .06837 Mdot
.94405 .06882 Mdot
.94408 .0585 Mdot
.9441 .05748 Mdot
.94413 .064 Mdot
.94415 .05972 Mdot
.94418 .05887 Mdot
.94421 .04158 Mdot
.94423 .02797 Mdot
.94426 .0349 Mdot
.94428 .04346 Mdot
.94431 .05255 Mdot
.94434 .05142 Mdot
.94436 .04252 Mdot
.94439 .02709 Mdot
.94441 .02505 Mdot
.94444 .04603 Mdot
.94446 .0738 Mdot
.94449 .09976 Mdot
.94452 .08734 Mdot
.94454 .04592 Mdot
.94457 .02564 Mdot
.94459 .08495 Mdot
.94462 .17132 Mdot
.94465 .19552 Mdot
.94467 .14013 Mdot
.9447 .06038 Mdot
.94472 .06118 Mdot
.94475 .13021 Mdot
.94477 .15027 Mdot
.9448 .11814 Mdot
.94483 .05679 Mdot
.94485 .0342 Mdot
.94488 .04799 Mdot
.9449 .04101 Mdot
.94493 .06194 Mdot
.94496 .0751 Mdot
.94498 .07856 Mdot
.94501 .11102 Mdot
.94503 .1433 Mdot
.94506 .11819 Mdot
.94508 .03179 Mdot
.94511 .07739 Mdot
.94514 .10353 Mdot
.94516 .10519 Mdot
.94519 .07385 Mdot
.94521 .02659 Mdot
.94524 .06881 Mdot
.94527 .09023 Mdot
.94529 .0711 Mdot
.94532 .03118 Mdot
.94534 .04599 Mdot
.94537 .08635 Mdot
.94539 .09464 Mdot
.94542 .04945 Mdot
.94545 .05757 Mdot
.94547 .0667 Mdot
.9455 .05138 Mdot
.94552 .04533 Mdot
.94555 .02892 Mdot
.94558 .0566 Mdot
.9456 .06067 Mdot
.94563 .02482 Mdot
.94565 .05014 Mdot
.94568 .02896 Mdot
.9457 .03995 Mdot
.94573 .04042 Mdot
.94576 .01999 Mdot
.94578 .05363 Mdot
.94581 .04064 Mdot
.94583 .03008 Mdot
.94586 .04557 Mdot
.94589 .02693 Mdot
.94591 .03076 Mdot
.94594 .02596 Mdot
.94596 .02034 Mdot
.94599 .03394 Mdot
.94601 .02667 Mdot
.94604 .021 Mdot
.94607 .02972 Mdot
.94609 .02503 Mdot
.94612 .03136 Mdot
.94614 .0238 Mdot
.94617 .02693 Mdot
.9462 .02334 Mdot
.94622 .03008 Mdot
.94625 .02048 Mdot
.94627 .02203 Mdot
.9463 .01566 Mdot
.94632 .0183 Mdot
.94635 .02769 Mdot
.94638 .02232 Mdot
.9464 .02095 Mdot
.94643 .01965 Mdot
.94645 .0188 Mdot
.94648 .01769 Mdot
.94651 .0242 Mdot
.94653 .01868 Mdot
.94656 .02617 Mdot
.94658 .02243 Mdot
.94661 .01836 Mdot
.94663 .01627 Mdot
.94666 .01857 Mdot
.94669 .01921 Mdot
.94671 .01978 Mdot
.94674 .01786 Mdot
.94676 .01862 Mdot
.94679 .01521 Mdot
.94682 .0176 Mdot
.94684 .01728 Mdot
.94687 .01698 Mdot
.94689 .01941 Mdot
.94692 .01659 Mdot
.94694 .0193 Mdot
.94697 .02405 Mdot
.947 .01985 Mdot
.94702 .01478 Mdot
.94705 .01893 Mdot
.94707 .01496 Mdot
.9471 .01577 Mdot
.94713 .02114 Mdot
.94715 .01945 Mdot
.94718 .02213 Mdot
.9472 .01608 Mdot
.94723 .02182 Mdot
.94725 .0192 Mdot
.94728 .01984 Mdot
.94731 .02172 Mdot
.94733 .0214 Mdot
.94736 .01958 Mdot
.94738 .01706 Mdot
.94741 .02358 Mdot
.94744 .02343 Mdot
.94746 .01952 Mdot
.94749 .02329 Mdot
.94751 .02679 Mdot
.94754 .02265 Mdot
.94756 .02297 Mdot
.94759 .02674 Mdot
.94762 .02386 Mdot
.94764 .01587 Mdot
.94767 .0196 Mdot
.94769 .02428 Mdot
.94772 .02192 Mdot
.94775 .02352 Mdot
.94777 .02363 Mdot
.9478 .02307 Mdot
.94782 .02273 Mdot
.94785 .02188 Mdot
.94787 .02543 Mdot
.9479 .01927 Mdot
.94793 .01998 Mdot
.94795 .01897 Mdot
.94798 .02151 Mdot
.948 .01708 Mdot
.94803 .02126 Mdot
.94806 .0201 Mdot
.94808 .02057 Mdot
.94811 .02323 Mdot
.94813 .02338 Mdot
.94816 .02063 Mdot
.94818 .02287 Mdot
.94821 .02867 Mdot
.94824 .02761 Mdot
.94826 .02514 Mdot
.94829 .03002 Mdot
.94831 .02267 Mdot
.94834 .02067 Mdot
.94837 .0238 Mdot
.94839 .02697 Mdot
.94842 .02698 Mdot
.94844 .02158 Mdot
.94847 .02691 Mdot
.94849 .03307 Mdot
.94852 .02977 Mdot
.94855 .02562 Mdot
.94857 .0275 Mdot
.9486 .0232 Mdot
.94862 .02556 Mdot
.94865 .03035 Mdot
.94868 .02841 Mdot
.9487 .02441 Mdot
.94873 .0282 Mdot
.94875 .03636 Mdot
.94878 .02685 Mdot
.9488 .02755 Mdot
.94883 .02801 Mdot
.94886 .02297 Mdot
.94888 .02877 Mdot
.94891 .03505 Mdot
.94893 .03138 Mdot
.94896 .02901 Mdot
.94899 .04039 Mdot
.94901 .0368 Mdot
.94904 .03173 Mdot
.94906 .03899 Mdot
.94909 .03784 Mdot
.94911 .03874 Mdot
.94914 .04391 Mdot
.94917 .04082 Mdot
.94919 .03595 Mdot
.94922 .03459 Mdot
.94924 .04245 Mdot
.94927 .04323 Mdot
.9493 .04035 Mdot
.94932 .04186 Mdot
.94935 .03889 Mdot
.94937 .0386 Mdot
.9494 .03805 Mdot
.94942 .03907 Mdot
.94945 .041 Mdot
.94948 .03664 Mdot
.9495 .03161 Mdot
.94953 .02633 Mdot
.94955 .03951 Mdot
.94958 .03148 Mdot
.94961 .02782 Mdot
.94963 .03411 Mdot
.94966 .03084 Mdot
.94968 .03776 Mdot
.94971 .03671 Mdot
.94973 .02685 Mdot
.94976 .04067 Mdot
.94979 .03518 Mdot
.94981 .03125 Mdot
.94984 .02958 Mdot
.94986 .02421 Mdot
.94989 .0241 Mdot
.94992 .02076 Mdot
.94994 .01988 Mdot
.94997 .02879 Mdot
.94999 .0362 Mdot
.95002 .03343 Mdot
.95004 .0455 Mdot
.95007 .04754 Mdot
.9501 .05625 Mdot
.95012 .07113 Mdot
.95015 .06766 Mdot
.95017 .07869 Mdot
.9502 .09235 Mdot
.95023 .0986 Mdot
.95025 .11874 Mdot
.95028 .12631 Mdot
.9503 .13792 Mdot
.95033 .16511 Mdot
.95035 .16569 Mdot
.95038 .19001 Mdot
.95041 .20424 Mdot
.95043 .20725 Mdot
.95046 .21375 Mdot
.95048 .18479 Mdot
.95051 .15538 Mdot
.95054 .17144 Mdot
.95056 .17976 Mdot
.95059 .16856 Mdot
.95061 .13212 Mdot
.95064 .09118 Mdot
.95066 .09236 Mdot
.95069 .14576 Mdot
.95072 .17626 Mdot
.95074 .17031 Mdot
.95077 .12131 Mdot
.95079 .05226 Mdot
.95082 .05511 Mdot
.95085 .08863 Mdot
.95087 .29748 Mdot
.9509 .44396 Mdot
.95092 .36608 Mdot
.95095 .15561 Mdot
.95097 .03078 Mdot
.951 .26742 Mdot
.95103 .5559 Mdot
.95105 .60332 Mdot
.95108 .39093 Mdot
.9511 .10501 Mdot
.95113 .17661 Mdot
.95116 .28353 Mdot
.95118 .20904 Mdot
.95121 .0731 Mdot
.95123 .2257 Mdot
.95126 .31076 Mdot
.95128 .44203 Mdot
.95131 .5222 Mdot
.95134 .31933 Mdot
.95136 .10742 Mdot
.95139 .33288 Mdot
.95141 .3123 Mdot
.95144 .23734 Mdot
.95147 .13281 Mdot
.95149 .13269 Mdot
.95152 .25035 Mdot
.95154 .19049 Mdot
.95157 .04553 Mdot
.95159 .06186 Mdot
.95162 .09525 Mdot
.95165 .1424 Mdot
.95167 .09377 Mdot
.9517 .09935 Mdot
.95172 .11966 Mdot
.95175 .03019 Mdot
.95178 .07487 Mdot
.9518 .04207 Mdot
.95183 .05443 Mdot
.95185 .0725 Mdot
.95188 .02522 Mdot
.9519 .04935 Mdot
.95193 .05172 Mdot
.95196 .03037 Mdot
.95198 .05227 Mdot
.95201 .0169 Mdot
.95203 .04678 Mdot
.95206 .04142 Mdot
.95209 .03107 Mdot
.95211 .03876 Mdot
.95214 .02833 Mdot
.95216 .02863 Mdot
.95219 .03364 Mdot
.95221 .02345 Mdot
.95224 .03315 Mdot
.95227 .02591 Mdot
.95229 .02411 Mdot
.95232 .01696 Mdot
.95234 .02745 Mdot
.95237 .02249 Mdot
.9524 .02952 Mdot
.95242 .02313 Mdot
.95245 .02002 Mdot
.95247 .02714 Mdot
.9525 .02734 Mdot
.95252 .02128 Mdot
.95255 .02507 Mdot
.95258 .01862 Mdot
.9526 .02411 Mdot
.95263 .0233 Mdot
.95265 .02535 Mdot
.95268 .02148 Mdot
.95271 .02068 Mdot
.95273 .01755 Mdot
.95276 .02445 Mdot
.95278 .02226 Mdot
.95281 .02363 Mdot
.95284 .01987 Mdot
.95286 .01541 Mdot
.95289 .01706 Mdot
.95291 .02412 Mdot
.95294 .01823 Mdot
.95296 .02308 Mdot
.95299 .01929 Mdot
.95302 .023 Mdot
.95304 .01728 Mdot
.95307 .0199 Mdot
.95309 .01991 Mdot
.95312 .01829 Mdot
.95315 .02464 Mdot
.95317 .01921 Mdot
.9532 .02328 Mdot
.95322 .02281 Mdot
.95325 .02137 Mdot
.95327 .01948 Mdot
.9533 .02274 Mdot
.95333 .02393 Mdot
.95335 .02323 Mdot
.95338 .01777 Mdot
.9534 .01729 Mdot
.95343 .01555 Mdot
.95346 .01821 Mdot
.95348 .01864 Mdot
.95351 .02128 Mdot
.95353 .02219 Mdot
.95356 .01896 Mdot
.95358 .01476 Mdot
.95361 .02114 Mdot
.95364 .02744 Mdot
.95366 .0233 Mdot
.95369 .02439 Mdot
.95371 .02208 Mdot
.95374 .02462 Mdot
.95377 .01928 Mdot
.95379 .0223 Mdot
.95382 .02352 Mdot
.95384 .02306 Mdot
.95387 .01691 Mdot
.95389 .02015 Mdot
.95392 .02192 Mdot
.95395 .01823 Mdot
.95397 .01883 Mdot
.954 .02371 Mdot
.95402 .02293 Mdot
.95405 .02513 Mdot
.95408 .0204 Mdot
.9541 .0205 Mdot
.95413 .02629 Mdot
.95415 .02263 Mdot
.95418 .01894 Mdot
.9542 .01622 Mdot
.95423 .02102 Mdot
.95426 .02274 Mdot
.95428 .02159 Mdot
.95431 .02203 Mdot
.95433 .0185 Mdot
.95436 .01941 Mdot
.95439 .0187 Mdot
.95441 .02186 Mdot
.95444 .02092 Mdot
.95446 .01975 Mdot
.95449 .01783 Mdot
.95451 .02067 Mdot
.95454 .02114 Mdot
.95457 .02215 Mdot
.95459 .02468 Mdot
.95462 .02192 Mdot
.95464 .01886 Mdot
.95467 .02454 Mdot
.9547 .02265 Mdot
.95472 .02577 Mdot
.95475 .02009 Mdot
.95477 .01975 Mdot
.9548 .01752 Mdot
.95482 .01743 Mdot
.95485 .01697 Mdot
.95488 .01832 Mdot
.9549 .0205 Mdot
.95493 .01871 Mdot
.95495 .02127 Mdot
.95498 .02226 Mdot
.95501 .01855 Mdot
.95503 .01973 Mdot
.95506 .01888 Mdot
.95508 .01977 Mdot
.95511 .02583 Mdot
.95513 .02371 Mdot
.95516 .02157 Mdot
.95519 .02002 Mdot
.95521 .02004 Mdot
.95524 .01838 Mdot
.95526 .02143 Mdot
.95529 .01841 Mdot
.95532 .01889 Mdot
.95534 .02096 Mdot
.95537 .0176 Mdot
.95539 .0219 Mdot
.95542 .02671 Mdot
.95544 .02822 Mdot
.95547 .02267 Mdot
.9555 .03033 Mdot
.95552 .02325 Mdot
.95555 .01855 Mdot
.95557 .02409 Mdot
.9556 .02353 Mdot
.95563 .02013 Mdot
.95565 .02242 Mdot
.95568 .02079 Mdot
.9557 .01691 Mdot
.95573 .02338 Mdot
.95575 .02201 Mdot
.95578 .02318 Mdot
.95581 .02204 Mdot
.95583 .02101 Mdot
.95586 .02205 Mdot
.95588 .02158 Mdot
.95591 .02317 Mdot
.95594 .02482 Mdot
.95596 .02272 Mdot
.95599 .02298 Mdot
.95601 .02106 Mdot
.95604 .02644 Mdot
.95606 .02622 Mdot
.95609 .02545 Mdot
.95612 .02325 Mdot
.95614 .02474 Mdot
.95617 .02382 Mdot
.95619 .02224 Mdot
.95622 .02658 Mdot
.95625 .02424 Mdot
.95627 .02352 Mdot
.9563 .02113 Mdot
.95632 .01923 Mdot
.95635 .02406 Mdot
.95637 .01832 Mdot
.9564 .02483 Mdot
.95643 .01979 Mdot
.95645 .02764 Mdot
.95648 .03355 Mdot
.9565 .04692 Mdot
.95653 .05524 Mdot
.95656 .05282 Mdot
.95658 .06677 Mdot
.95661 .07348 Mdot
.95663 .07375 Mdot
.95666 .09168 Mdot
.95668 .08967 Mdot
.95671 .10222 Mdot
.95674 .1149 Mdot
.95676 .10648 Mdot
.95679 .11548 Mdot
.95681 .12083 Mdot
.95684 .1213 Mdot
.95687 .11525 Mdot
.95689 .10254 Mdot
.95692 .0954 Mdot
.95694 .10426 Mdot
.95697 .10763 Mdot
.95699 .10149 Mdot
.95702 .07686 Mdot
.95705 .05889 Mdot
.95707 .06043 Mdot
.9571 .06055 Mdot
.95712 .09844 Mdot
.95715 .12269 Mdot
.95718 .09685 Mdot
.9572 .0593 Mdot
.95723 .02896 Mdot
.95725 .09665 Mdot
.95728 .23252 Mdot
.9573 .29397 Mdot
.95733 .22385 Mdot
.95736 .08553 Mdot
.95738 .08889 Mdot
.95741 .21509 Mdot
.95743 .25091 Mdot
.95746 .15095 Mdot
.95749 .05915 Mdot
.95751 .13629 Mdot
.95754 .17972 Mdot
.95756 .2208 Mdot
.95759 .17815 Mdot
.95761 .0484 Mdot
.95764 .11335 Mdot
.95767 .13037 Mdot
.95769 .09505 Mdot
.95772 .06622 Mdot
.95774 .03925 Mdot
.95777 .10494 Mdot
.9578 .08321 Mdot
.95782 .02573 Mdot
.95785 .04387 Mdot
.95787 .03628 Mdot
.9579 .0549 Mdot
.95792 .04814 Mdot
.95795 .03339 Mdot
.95798 .05814 Mdot
.958 .02531 Mdot
.95803 .03727 Mdot
.95805 .03244 Mdot
.95808 .01774 Mdot
.95811 .03363 Mdot
.95813 .02425 Mdot
.95816 .0295 Mdot
.95818 .03053 Mdot
.95821 .01763 Mdot
.95823 .02776 Mdot
.95826 .0181 Mdot
.95829 .02286 Mdot
.95831 .02264 Mdot
.95834 .02203 Mdot
.95836 .02236 Mdot
.95839 .0211 Mdot
.95842 .01994 Mdot
.95844 .01939 Mdot
.95847 .01788 Mdot
.95849 .01936 Mdot
.95852 .0175 Mdot
.95854 .01799 Mdot
.95857 .01829 Mdot
.9586 .01615 Mdot
.95862 .01835 Mdot
.95865 .01783 Mdot
.95867 .01629 Mdot
.9587 .01619 Mdot
.95873 .01837 Mdot
.95875 .01507 Mdot
.95878 .01599 Mdot
.9588 .01696 Mdot
.95883 .01859 Mdot
.95885 .01705 Mdot
.95888 .01864 Mdot
.95891 .01746 Mdot
.95893 .01773 Mdot
.95896 .01649 Mdot
.95898 .01803 Mdot
.95901 .0156 Mdot
.95904 .01976 Mdot
.95906 .01675 Mdot
.95909 .01832 Mdot
.95911 .01898 Mdot
.95914 .01782 Mdot
.95916 .01695 Mdot
.95919 .01728 Mdot
.95922 .01727 Mdot
.95924 .01661 Mdot
.95927 .01659 Mdot
.95929 .01653 Mdot
.95932 .01691 Mdot
.95935 .01642 Mdot
.95937 .01895 Mdot
.9594 .01541 Mdot
.95942 .01807 Mdot
.95945 .01864 Mdot
.95947 .01727 Mdot
.9595 .01642 Mdot
.95953 .01594 Mdot
.95955 .01629 Mdot
.95958 .01567 Mdot
.9596 .0153 Mdot
.95963 .01794 Mdot
.95966 .01695 Mdot
.95968 .01709 Mdot
.95971 .0166 Mdot
.95973 .01716 Mdot
.95976 .01794 Mdot
.95978 .0186 Mdot
.95981 .01569 Mdot
.95984 .01809 Mdot
.95986 .01776 Mdot
.95989 .01646 Mdot
.95991 .01558 Mdot
.95994 .01667 Mdot
.95997 .01647 Mdot
.95999 .01559 Mdot
.96002 .01779 Mdot
.96004 .01814 Mdot
.96007 .01761 Mdot
.96009 .01505 Mdot
.96012 .01743 Mdot
.96015 .01671 Mdot
.96017 .01802 Mdot
.9602 .01517 Mdot
.96022 .01862 Mdot
.96025 .01853 Mdot
.96028 .01595 Mdot
.9603 .01719 Mdot
.96033 .01519 Mdot
.96035 .01786 Mdot
.96038 .01777 Mdot
.9604 .01793 Mdot
.96043 .01664 Mdot
.96046 .01533 Mdot
.96048 .01676 Mdot
.96051 .01582 Mdot
.96053 .01538 Mdot
.96056 .01588 Mdot
.96059 .01546 Mdot
.96061 .01839 Mdot
.96064 .02082 Mdot
.96066 .02751 Mdot
.96069 .02117 Mdot
.96071 .0198 Mdot
.96074 .01638 Mdot
.96077 .01663 Mdot
.96079 .01876 Mdot
.96082 .01525 Mdot
.96084 .0168 Mdot
.96087 .01741 Mdot
.9609 .01805 Mdot
.96092 .01885 Mdot
.96095 .01555 Mdot
.96097 .01545 Mdot
.961 .01612 Mdot
.96102 .01816 Mdot
.96105 .01866 Mdot
.96108 .01826 Mdot
.9611 .01559 Mdot
.96113 .0157 Mdot
.96115 .01514 Mdot
.96118 .01613 Mdot
.96121 .01965 Mdot
.96123 .01829 Mdot
.96126 .01859 Mdot
.96128 .01713 Mdot
.96131 .01673 Mdot
.96133 .01704 Mdot
.96136 .01653 Mdot
.96139 .0171 Mdot
.96141 .01691 Mdot
.96144 .01549 Mdot
.96146 .01716 Mdot
.96149 .01734 Mdot
.96152 .01649 Mdot
.96154 .01545 Mdot
.96157 .01741 Mdot
.96159 .01731 Mdot
.96162 .01675 Mdot
.96164 .0153 Mdot
.96167 .01672 Mdot
.9617 .0165 Mdot
.96172 .0162 Mdot
.96175 .01685 Mdot
.96177 .01763 Mdot
.9618 .01587 Mdot
.96183 .01531 Mdot
.96185 .01697 Mdot
.96188 .01909 Mdot
.9619 .01645 Mdot
.96193 .0163 Mdot
.96196 .0152 Mdot
.96198 .01973 Mdot
.96201 .01666 Mdot
.96203 .01668 Mdot
.96206 .0155 Mdot
.96208 .01614 Mdot
.96211 .01699 Mdot
.96214 .01889 Mdot
.96216 .01622 Mdot
.96219 .01725 Mdot
.96221 .01742 Mdot
.96224 .01743 Mdot
.96227 .01612 Mdot
.96229 .0168 Mdot
.96232 .01987 Mdot
.96234 .01892 Mdot
.96237 .01839 Mdot
.96239 .01831 Mdot
.96242 .01841 Mdot
.96245 .01897 Mdot
.96247 .02119 Mdot
.9625 .01565 Mdot
.96252 .01758 Mdot
.96255 .01762 Mdot
.96258 .01905 Mdot
.9626 .01771 Mdot
.96263 .02043 Mdot
.96265 .01906 Mdot
.96268 .02166 Mdot
.9627 .02251 Mdot
.96273 .01595 Mdot
.96276 .01947 Mdot
.96278 .01742 Mdot
.96281 .02043 Mdot
.96283 .01895 Mdot
.96286 .01632 Mdot
.96289 .01804 Mdot
.96291 .01759 Mdot
.96294 .02221 Mdot
.96296 .02383 Mdot
.96299 .02574 Mdot
.96301 .02575 Mdot
.96304 .02783 Mdot
.96307 .03213 Mdot
.96309 .03484 Mdot
.96312 .03767 Mdot
.96314 .04019 Mdot
.96317 .04181 Mdot
.9632 .04709 Mdot
.96322 .05053 Mdot
.96325 .04807 Mdot
.96327 .04501 Mdot
.9633 .04766 Mdot
.96332 .04127 Mdot
.96335 .0395 Mdot
.96338 .04813 Mdot
.9634 .04609 Mdot
.96343 .04122 Mdot
.96345 .02806 Mdot
.96348 .03318 Mdot
.96351 .02745 Mdot
.96353 .06579 Mdot
.96356 .07817 Mdot
.96358 .06444 Mdot
.96361 .04298 Mdot
.96363 .02971 Mdot
.96366 .08464 Mdot
.96369 .12878 Mdot
.96371 .11323 Mdot
.96374 .04558 Mdot
.96376 .04503 Mdot
.96379 .06537 Mdot
.96382 .08203 Mdot
.96384 .07765 Mdot
.96387 .04072 Mdot
.96389 .03533 Mdot
.96392 .04598 Mdot
.96394 .02885 Mdot
.96397 .02421 Mdot
.964 .02298 Mdot
.96402 .03059 Mdot
.96405 .03149 Mdot
.96407 .02087 Mdot
.9641 .0213 Mdot
.96413 .0185 Mdot
.96415 .02179 Mdot
.96418 .02276 Mdot
.9642 .02269 Mdot
.96423 .02162 Mdot
.96425 .0196 Mdot
.96428 .0175 Mdot
.96431 .02102 Mdot
.96433 .01602 Mdot
.96436 .01976 Mdot
.96438 .01645 Mdot
.96441 .01826 Mdot
.96444 .01796 Mdot
.96446 .01709 Mdot
.96449 .01582 Mdot
.96451 .01701 Mdot
.96454 .01909 Mdot
.96456 .01634 Mdot
.96459 .01938 Mdot
.96462 .02135 Mdot
.96464 .01553 Mdot
.96467 .01713 Mdot
.96469 .01731 Mdot
.96472 .01893 Mdot
.96475 .01666 Mdot
.96477 .01626 Mdot
.9648 .01639 Mdot
.96482 .0167 Mdot
.96485 .01626 Mdot
.96487 .01786 Mdot
.9649 .01609 Mdot
.96493 .01573 Mdot
.96495 .01588 Mdot
.96498 .01711 Mdot
.965 .01577 Mdot
.96503 .01629 Mdot
.96506 .01604 Mdot
.96508 .01513 Mdot
.96511 .01881 Mdot
.96513 .01866 Mdot
.96516 .01662 Mdot
.96518 .01959 Mdot
.96521 .01663 Mdot
.96524 .01712 Mdot
.96526 .01549 Mdot
.96529 .01913 Mdot
.96531 .0191 Mdot
.96534 .01678 Mdot
.96537 .01663 Mdot
.96539 .01601 Mdot
.96542 .01784 Mdot
.96544 .01678 Mdot
.96547 .01733 Mdot
.96549 .01654 Mdot
.96552 .01618 Mdot
.96555 .0154 Mdot
.96557 .01679 Mdot
.9656 .0188 Mdot
.96562 .01581 Mdot
.96565 .01728 Mdot
.96568 .01583 Mdot
.9657 .01914 Mdot
.96573 .01992 Mdot
.96575 .0161 Mdot
.96578 .01681 Mdot
.9658 .01812 Mdot
.96583 .01846 Mdot
.96586 .02657 Mdot
.96588 .02283 Mdot
.96591 .01661 Mdot
.96593 .01553 Mdot
.96596 .01765 Mdot
.96599 .01649 Mdot
.96601 .01528 Mdot
.96604 .01677 Mdot
.96606 .01503 Mdot
.96609 .01743 Mdot
.96611 .01781 Mdot
.96614 .01685 Mdot
.96617 .01552 Mdot
.96619 .01776 Mdot
.96622 .01807 Mdot
.96624 .01697 Mdot
.96627 .01692 Mdot
.9663 .01564 Mdot
.96632 .01747 Mdot
.96635 .01578 Mdot
.96637 .01812 Mdot
.9664 .01864 Mdot
.96642 .01791 Mdot
.96645 .01854 Mdot
.96648 .01731 Mdot
.9665 .01741 Mdot
.96653 .01698 Mdot
.96655 .0192 Mdot
.96658 .01719 Mdot
.96661 .01703 Mdot
.96663 .0197 Mdot
.96666 .01957 Mdot
.96668 .01693 Mdot
.96671 .01962 Mdot
.96673 .01706 Mdot
.96676 .01972 Mdot
.96679 .01714 Mdot
.96681 .01861 Mdot
.96684 .01958 Mdot
.96686 .01676 Mdot
.96689 .01818 Mdot
.96692 .01837 Mdot
.96694 .0177 Mdot
.96697 .01759 Mdot
.96699 .0174 Mdot
.96702 .01584 Mdot
.96704 .01743 Mdot
.96707 .01933 Mdot
.9671 .02049 Mdot
.96712 .01625 Mdot
.96715 .01701 Mdot
.96717 .01814 Mdot
.9672 .01769 Mdot
.96723 .01662 Mdot
.96725 .01878 Mdot
.96728 .01835 Mdot
.9673 .01515 Mdot
.96733 .01768 Mdot
.96735 .02102 Mdot
.96738 .01789 Mdot
.96741 .0181 Mdot
.96743 .01781 Mdot
.96746 .01849 Mdot
.96748 .01575 Mdot
.96751 .01699 Mdot
.96754 .01543 Mdot
.96756 .01602 Mdot
.96759 .0163 Mdot
.96761 .01598 Mdot
.96764 .0173 Mdot
.96766 .01877 Mdot
.96769 .01795 Mdot
.96772 .01704 Mdot
.96774 .01612 Mdot
.96777 .01795 Mdot
.96779 .01597 Mdot
.96782 .01708 Mdot
.96785 .01762 Mdot
.96787 .01663 Mdot
.9679 .01721 Mdot
.96792 .02077 Mdot
.96795 .02011 Mdot
.96797 .01678 Mdot
.968 .01676 Mdot
.96803 .01672 Mdot
.96805 .01966 Mdot
.96808 .01931 Mdot
.9681 .01892 Mdot
.96813 .02158 Mdot
.96816 .02119 Mdot
.96818 .02144 Mdot
.96821 .02175 Mdot
.96823 .02237 Mdot
.96826 .01685 Mdot
.96828 .0197 Mdot
.96831 .02449 Mdot
.96834 .02291 Mdot
.96836 .01894 Mdot
.96839 .01779 Mdot
.96841 .02133 Mdot
.96844 .0265 Mdot
.96847 .02425 Mdot
.96849 .02367 Mdot
.96852 .02171 Mdot
.96854 .02077 Mdot
.96857 .0217 Mdot
.96859 .02212 Mdot
.96862 .01966 Mdot
.96865 .02267 Mdot
.96867 .02418 Mdot
.9687 .02271 Mdot
.96872 .02278 Mdot
.96875 .02596 Mdot
.96878 .0226 Mdot
.9688 .02646 Mdot
.96883 .02829 Mdot
.96885 .02484 Mdot
.96888 .02701 Mdot
.9689 .02737 Mdot
.96893 .02138 Mdot
.96896 .02108 Mdot
.96898 .02797 Mdot
.96901 .02821 Mdot
.96903 .02059 Mdot
.96906 .02703 Mdot
.96909 .02851 Mdot
.96911 .02468 Mdot
.96914 .02722 Mdot
.96916 .02946 Mdot
.96919 .02533 Mdot
.96921 .02686 Mdot
.96924 .0282 Mdot
.96927 .03064 Mdot
.96929 .0336 Mdot
.96932 .01943 Mdot
.96934 .02365 Mdot
.96937 .03203 Mdot
.9694 .02535 Mdot
.96942 .0316 Mdot
.96945 .03024 Mdot
.96947 .03376 Mdot
.9695 .03598 Mdot
.96952 .03921 Mdot
.96955 .04829 Mdot
.96958 .05668 Mdot
.9696 .06731 Mdot
.96963 .07076 Mdot
.96965 .09003 Mdot
.96968 .0998 Mdot
.96971 .09067 Mdot
.96973 .10649 Mdot
.96976 .0906 Mdot
.96978 .11992 Mdot
.96981 .18766 Mdot
.96983 .11484 Mdot
.96986 .09655 Mdot
.96989 .1048 Mdot
.96991 .18456 Mdot
.96994 .42945 Mdot
.96996 .40482 Mdot
.96999 .18502 Mdot
.97002 .05043 Mdot
.97004 .09771 Mdot
.97007 .08385 Mdot
.97009 .12729 Mdot
.97012 .08207 Mdot
.97014 .05156 Mdot
.97017 .06387 Mdot
.9702 .02543 Mdot
.97022 .03866 Mdot
.97025 .01942 Mdot
.97027 .03801 Mdot
.9703 .03839 Mdot
.97033 .02717 Mdot
.97035 .03343 Mdot
.97038 .02053 Mdot
.9704 .02627 Mdot
.97043 .02688 Mdot
.97045 .02819 Mdot
.97048 .02444 Mdot
.97051 .0157 Mdot
.97053 .01943 Mdot
.97056 .0182 Mdot
.97058 .0194 Mdot
.97061 .01705 Mdot
.97064 .01655 Mdot
.97066 .0191 Mdot
.97069 .01995 Mdot
.97071 .01855 Mdot
.97074 .01599 Mdot
.97076 .01565 Mdot
.97079 .01654 Mdot
.97082 .0169 Mdot
.97084 .01712 Mdot
.97087 .02059 Mdot
.97089 .01807 Mdot
.97092 .01846 Mdot
.97095 .01959 Mdot
.97097 .01564 Mdot
.971 .02141 Mdot
.97102 .03301 Mdot
.97105 .01728 Mdot
.97108 .01995 Mdot
.9711 .022 Mdot
.97113 .01907 Mdot
.97115 .01592 Mdot
.97118 .01886 Mdot
.9712 .01659 Mdot
.97123 .01733 Mdot
.97126 .01601 Mdot
.97128 .01733 Mdot
.97131 .01812 Mdot
.97133 .01884 Mdot
.97136 .01616 Mdot
.97139 .01828 Mdot
.97141 .01816 Mdot
.97144 .01617 Mdot
.97146 .01784 Mdot
.97149 .01739 Mdot
.97151 .0158 Mdot
.97154 .01624 Mdot
.97157 .01761 Mdot
.97159 .01767 Mdot
.97162 .01945 Mdot
.97164 .01795 Mdot
.97167 .01736 Mdot
.9717 .01666 Mdot
.97172 .01747 Mdot
.97175 .01961 Mdot
.97177 .02246 Mdot
.9718 .01862 Mdot
.97182 .01751 Mdot
.97185 .01758 Mdot
.97188 .0169 Mdot
.9719 .01722 Mdot
.97193 .01805 Mdot
.97195 .01822 Mdot
.97198 .01721 Mdot
.97201 .01778 Mdot
.97203 .01731 Mdot
.97206 .0179 Mdot
.97208 .01775 Mdot
.97211 .01808 Mdot
.97213 .01706 Mdot
.97216 .0175 Mdot
.97219 .01636 Mdot
.97221 .01569 Mdot
.97224 .01566 Mdot
.97226 .01543 Mdot
.97229 .01641 Mdot
.97232 .01683 Mdot
.97234 .01664 Mdot
.97237 .01846 Mdot
.97239 .01794 Mdot
.97242 .01504 Mdot
.97244 .01825 Mdot
.97247 .01878 Mdot
.9725 .01677 Mdot
.97252 .01742 Mdot
.97255 .01622 Mdot
.97257 .01901 Mdot
.9726 .01912 Mdot
.97263 .01855 Mdot
.97265 .01666 Mdot
.97268 .01527 Mdot
.9727 .01667 Mdot
.97273 .01647 Mdot
.97275 .01554 Mdot
.97278 .01847 Mdot
.97281 .01692 Mdot
.97283 .01649 Mdot
.97286 .01634 Mdot
.97288 .0165 Mdot
.97291 .01766 Mdot
.97294 .01652 Mdot
.97296 .01689 Mdot
.97299 .01659 Mdot
.97301 .01615 Mdot
.97304 .0164 Mdot
.97306 .01821 Mdot
.97309 .01951 Mdot
.97312 .0158 Mdot
.97314 .01792 Mdot
.97317 .01829 Mdot
.97319 .01631 Mdot
.97322 .01644 Mdot
.97325 .01763 Mdot
.97327 .01653 Mdot
.9733 .01779 Mdot
.97332 .01873 Mdot
.97335 .01564 Mdot
.97337 .01608 Mdot
.9734 .01557 Mdot
.97343 .01648 Mdot
.97345 .01756 Mdot
.97348 .01875 Mdot
.9735 .01763 Mdot
.97353 .01591 Mdot
.97356 .01737 Mdot
.97358 .01601 Mdot
.97361 .02067 Mdot
.97363 .02212 Mdot
.97366 .01648 Mdot
.97368 .02041 Mdot
.97371 .02087 Mdot
.97374 .02812 Mdot
.97376 .02626 Mdot
.97379 .03166 Mdot
.97381 .0198 Mdot
.97384 .02445 Mdot
.97387 .02206 Mdot
.97389 .0185 Mdot
.97392 .02124 Mdot
.97394 .02367 Mdot
.97397 .01987 Mdot
.97399 .01876 Mdot
.97402 .02033 Mdot
.97405 .01867 Mdot
.97407 .0178 Mdot
.9741 .01965 Mdot
.97412 .02027 Mdot
.97415 .02046 Mdot
.97418 .01762 Mdot
.9742 .01637 Mdot
.97423 .02111 Mdot
.97425 .02169 Mdot
.97428 .02092 Mdot
.9743 .01883 Mdot
.97433 .01642 Mdot
.97436 .01709 Mdot
.97438 .02038 Mdot
.97441 .01936 Mdot
.97443 .01796 Mdot
.97446 .01678 Mdot
.97449 .01688 Mdot
.97451 .02127 Mdot
.97454 .01528 Mdot
.97456 .01879 Mdot
.97459 .01667 Mdot
.97461 .01572 Mdot
.97464 .01645 Mdot
.97467 .01741 Mdot
.97469 .01888 Mdot
.97472 .01738 Mdot
.97474 .01626 Mdot
.97477 .0178 Mdot
.9748 .01585 Mdot
.97482 .01681 Mdot
.97485 .02028 Mdot
.97487 .02097 Mdot
.9749 .01796 Mdot
.97492 .01843 Mdot
.97495 .01758 Mdot
.97498 .01693 Mdot
.975 .01874 Mdot
.97503 .01643 Mdot
.97505 .01688 Mdot
.97508 .01882 Mdot
.97511 .01992 Mdot
.97513 .01733 Mdot
.97516 .01705 Mdot
.97518 .01813 Mdot
.97521 .0204 Mdot
.97523 .01846 Mdot
.97526 .01694 Mdot
.97529 .01621 Mdot
.97531 .01543 Mdot
.97534 .01588 Mdot
.97536 .0202 Mdot
.97539 .01963 Mdot
.97542 .01844 Mdot
.97544 .02446 Mdot
.97547 .02762 Mdot
.97549 .02134 Mdot
.97552 .02088 Mdot
.97554 .01758 Mdot
.97557 .01938 Mdot
.9756 .0208 Mdot
.97562 .01795 Mdot
.97565 .01813 Mdot
.97567 .01718 Mdot
.9757 .01527 Mdot
.97573 .01624 Mdot
.97575 .0183 Mdot
.97578 .01931 Mdot
.9758 .01861 Mdot
.97583 .01633 Mdot
.97585 .01693 Mdot
.97588 .01705 Mdot
.97591 .01913 Mdot
.97593 .02118 Mdot
.97596 .01542 Mdot
.97598 .0199 Mdot
.97601 .02044 Mdot
.97604 .01801 Mdot
.97606 .02235 Mdot
.97609 .01594 Mdot
.97611 .02275 Mdot
.97614 .0239 Mdot
.97616 .02819 Mdot
.97619 .05576 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo001DOol40006Ool20007Ool2
0007Ool2000@Ool50005Ool20007Ool20007Ool20007Ool2000;Ool50004Ool40006Ool20007Ool2
0007Ool2000;Ool60005Ool20007Ool20007Ool20007Ool2000:Ool60004Ool40006Ool20007Ool2
0007Ool2000;Ool40006Ool20007Ool20007Ool20007Ool2000<Ool40005Ool40006Ool20007Ool2
0007Ool2000;Ool005=oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0005Ool01000Oomo
o`001Goo00@007ooOol0015oo`03001oogoo00Aoo`04001oogoo0005Ool01000Oomoo`001Goo00@0
07ooOol000Eoo`04001oogoo000<Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
1000Oomoo`001Goo00@007ooOol000Eoo`04001oogoo000;Ool01@00Oomoogoo000017oo00@007oo
Ool000Eoo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol000Yoo`05001oogooOol00003
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol000Eoo`04001oogoo
0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol000Eoo`04001o
ogoo0005Ool01000Oomoo`002Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009o
o`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol000Yoo`00F7oo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol03Woo00<007ooOol00goo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<0
07ooOol02Goo00<007ooOol027oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol02Goo00<007ooOol017oo00<007ooOol00Woo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol027oo00<007ooOol02Goo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02goo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo00aoo`03001oogoo00Ioo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D0
07ooOomoo`0000Aoo`03001oogoo00Moo`00F7oo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02Goo00<007oo
Ool027oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007oo
Ool02Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol02Goo00<007ooOol027oo00D007ooOomoo`0000Aoo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02goo00D007ooOomoo`0000Aoo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00aoo`03
001oogoo00Ioo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03
001oogoo00Moo`00Dgoo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
1@00Oomoogoo000017oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02Goo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00<007ooOol02goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02Woo00<007ooOol00Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol0
27oo0`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomo
ogoo000017oo00<007ooOol02Goo0`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol01goo001COol50004Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00ioo`03001oogoo00=oo`03
001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03
001oogoo00Uoo`03001oogoo00=oo`D000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00
Oomoogoo000017oo00<007ooOol037oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool01@00
Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00]oo`04001oogooOol50004Ool00`00
Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00]oo`05001oogoo
Ool00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00
Oomoo`0<Ool01000Oomoogoo1@0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`07Ool005=oo`03001oogoo00Ioo`03001oogoo009oo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol03Woo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02Goo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool00`00Oomoo`0<Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001oogooOol0
0004Ool01@00Oomoogoo000017oo00<007ooOol02goo00D007ooOomoo`0000Qoo`03001oogoo009o
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol02goo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00ao
o`05001oogooOol00008Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Ao
o`03001oogoo00Moo`00Dgoo00<007ooOol01goo00@007ooOol000Eoo`04001oogoo0005Ool01000
Oomoo`003goo0`001Woo00@007ooOol000Eoo`04001oogoo0005Ool01000Oomoo`001Goo00@007oo
Ool000Yoo`<000Eoo`03001oogoo00Moo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol0
00Yoo`03001oogoo009oo`03001oogoo009oo`04001oogoo0005Ool01000Oomoo`001Goo00@007oo
Ool000Eoo`04001oogoo0009Ool00`00Oomoo`02Ool01@00Oomoogoo00002Goo00@007ooOol000Eo
o`04001oogoo0005Ool01000Oomoo`002Goo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0
00Eoo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol000Yoo`03001oogoo009oo`05001o
ogooOol00009Ool01000Oomoo`001Goo00@007ooOol000Eoo`04001oogoo000:Ool005=oo`D000Io
o`8000Moo`8000Moo`80015oo`8000Moo`8000Moo`8000Moo`8000Moo`8000aoo`8000Eoo`D000Io
o`8000Moo`8000Moo`8000aoo`@000Ioo`8000Moo`8000Moo`8000Moo`8000]oo`@000Aoo`D000Io
o`8000Moo`8000Moo`8000]oo`@000Ioo`8000Moo`8000Moo`8000Moo`8000aoo`@000Aoo`D000Io
o`8000Moo`8000Moo`8000]oo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0
02Qoool008T00000<7ooo`00N@0027oo000`Oooo001i0008Ool0031oog0000=oo`@000Aooa800003
Ool0000000/00003Ool0000000T000Eoo`<00004Ool000000006Ool60006Ool70004Ool;0002Ool<
00000goo0000000@0002Ool00`00Ool000030003Oom`0009Ool0031oocl00004Ool00000003bOol3
00000goo0000000l0009Ool0031ooch00?aoocd000Uoo`00<7oo7P0017oo400000=oo`0000000P00
ogoo2goo0`0000=oo`0000003P0017oo7P002Goo000`OolL0007Ool300000goo00000009003oOolD
Ool;0002Ool30007OolK0009Ool0035ooa/000]oo`T00?mooaUoo`P000aooaX000Yoo`00<Goo6000
3goo2000ogoo6Goo20003Woo5`002goo000aOol00`00Ool0000E000?Ool8003oOolIOol8000>OolG
000;Ool0035oo`03001oo`0001D000moo`P00?mooaUoo`P000iooaL000]oo`00<Goo00@007ooOomo
oa8001=oo`H00?mooaUoo`H001=ooa4000ioo`00<Goo00<007oo00004`004goo1P00ogoo6Goo1P00
4goo50002goo000aOol00`00Ool0000C000COol3003oOolNOol4000BOolE000;Ool0035oo`03001o
o`0001<001=oo`<00?mooaioo`@0019ooaD000]oo`00<7oo1P0000=oo`0000003P004goo0`00ogoo
7goo0`004Woo40000Woo1@002Goo000`Ool600000goo0000000>003oOom:Ool@0002Ool50009Ool0
031oo`H00003Ool0000000h00?moodYooa00009oo`D000Uoo`00<Goo00<007oo00004`00ogooBWoo
5@002goo000aOol00`00Ool0000C003oOom:OolE000;Ool0035oo`03001oo`0001<00?moodYooaD0
00]oo`00<Goo00<007oo00000P000Woo3`00ogooBWoo40000Woo0`002goo000aOol00`00Ool00002
0002Ool?003oOom;Ool?0002Ool3000;Ool0035oo`<00003Ool0000001000?mood]ooa4000ioo`00
<Goo00@007ooOomooa800?mood]ooa4000ioo`00<Goo00<007oo00004`00ogooBgoo50002goo000a
Ool00`00Ool0000700000goo00000009003oOom;Ool:0002Ool8000;Ool0035oo`03001oo`0001<0
0?mood]ooa@000]oo`00<Goo00<007oo00004`00ogooBWoo5@002goo000aOol00`00Ool000020002
Ool?003oOom:Ool@0002Ool3000;Ool0035oo`03001oo`000080009oo`l00?moodYooa00009oo`<0
00]oo`00<Goo1@000Woo3`00ogooBWoo40000Woo0`002goo000aOol00`00Ool000020002Ool?003o
Oom;Ool?0002Ool3000;Ool0035oo`03001oo`000080009oo`l00?moodYooa00009oo`<000]oo`00
<Goo00<007oo00000P000Woo3`00ogooBWoo40000Woo0`002goo000aOol00`00Ool000020002Ool?
003oOom:Ool@0002Ool3000;Ool000=oo`8000Moo`<000Ioo`8000Moo`8000Ioo`D000Ioo`03001o
o`000080009oo`d00?moodioo`h0009oo`<000]oo`000Woo00@007ooOol000Ioo`<000Eoo`04001o
ogoo0005Ool01000Oomoo`001goo00<007ooOol01Woo00@007ooOomooa800?mood]ooa4000ioo`00
00=oo`00Ool00goo00<007ooOol00goo0`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03
001oogoo00Aoo`03001oogoo00Ioo`X0009oo`X00?mood]oo`X0009oo`P000]oo`0000=oo`00Ool0
0goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001o
ogoo00Ioo`03001oo`0001<00?mood]ooa@000]oo`0000=oo`00Ool00goo00<007ooOol02Woo00<0
07ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oo`000080
009oo`l00?mood]oo`l0009oo`<000]oo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol0
0Woo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oo`000080009oo`l0
0?mood]oo`l0009oo`<000]oo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo00Ioo`03001oo`000080009oo`D0009oo`P0
0?mood]oo`L0009oo`H0009oo`<000]oo`000Woo00@007ooOol000ioo`04001oogoo0005Ool01000
Oomoo`001Goo0`0027oo00<007oo00002@000Woo1P00ogooCWoo1P000Woo2`002goo0003Ool2000@
Ool20007Ool20007Ool20008Ool00`00Ool0000A003oOom?OolB000;Ool0035oo`04001oogooOol@
003oOom?Ool?000>Ool0035oo`<000Aoo`l00?mood]oo`l0011oo`00<Goo00<007ooOol017oo3`00
ogooBgoo3`0047oo000aOol00`00Oomoo`04Ool?003oOom;Ool?000@Ool0035oo`03001oogoo00Io
o`H00003Ool0000000@00?mood]oo`D0009oo`H0019oo`00<Goo00<007ooOol01Woo1P0000=oo`00
00000P00ogooCgoo0`000Woo1P004Woo000aOol00`00Oomoo`06Ool600000goo00000002003oOom?
Ool30002Ool5000COol0035oo`03001oogoo00Aoo`P00003Ool0000000800?moodioo`@0009oo`P0
011oo`00<Goo00<007ooOol017oo3@00ogooCWoo3P0047oo000aOol30004Ool50002Ool6003oOom>
Ool60002Ool6000@Ool0035oo`03001oogoo00Ioo`<0009oo`H00?moodioo`H0009oo`<001=oo`00
<Goo00<007ooOol01Woo0`000Woo1P00ogooCWoo1P000Woo0`004goo000aOol00`00Oomoo`06Ool3
0002Ool6003oOom>Ool60002Ool3000COol0035oo`03001oogoo00Ioo`<000Aoo`@00?moodioo`@0
00Aoo`<001=oo`00<Goo00<007ooOol01Woo0`000Woo1@00ogooD7oo1@000Woo0`004goo000aOol0
0`00Oomoo`06Ool:003oOom@Ool:000COol0035oo`03001oogoo00Ioo`X00?mooe1oo`X001=oo`00
<Goo0`0017oo200000Aoo`0000000?mooe1oo`<0009oo`P0011oo`00<Goo00<007ooOol017oo1@00
17oo0`00ogooD7oo0`0017oo1P0047oo000aOol00`00Oomoo`04Ool50004Ool3003oOom@Ool30004
Ool6000@Ool0035oo`03001oo`000080009oo`D000Aoo`<00?mooe1oo`<000Aoo`H0009oo`<000]o
o`00<Goo00<007oo00000P0017oo0`0017oo0`00ogooD7oo0`0017oo0`001Goo0`002goo000aOol0
0`00Ool000020004Ool30004Ool3003oOom@Ool30004Ool40004Ool3000;Ool0035oo`03001oo`00
008000Aoo`<00?mooeioo`@000Aoo`<000]oo`00<Goo00<007ooOol01Woo1P00ogooFGoo1P004Woo
000aOol30009Ool3003oOomIOol3000EOol0035oo`03001oogoo00Uoo`<00?mooeUoo`<001Eoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`06Ool30004Ool4003oOom?Ool30004Ool3000C
Ool0035oo`03001oogoo00Ioo`<000Aoo`@00?moodmoo`<000Aoo`<001=oo`000goo0P001goo0`00
1Woo0P001goo0P001Goo1P001Woo00<007ooOol01Woo0`0017oo1000ogooCgoo0`0017oo0`004goo
0002Ool01000Oomoo`001Woo0`001Goo00@007ooOol000Eoo`04001oogoo0005Ool01@00Oomoogoo
00001Woo00<007ooOol01Woo0`000Woo1@00ogooD7oo1@000Woo0`004goo00000goo001oo`03Ool0
0`00Oomoo`03Ool30004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00goo00<0
07ooOol01goo10000goo1@000Woo1@00ogooD7oo1@000Woo1P0047oo00000goo001oo`03Ool00`00
Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol017oo00<007ooOol01Woo
00<007ooOol017oo1@000Woo1@00ogooD7oo1@000Woo1P0047oo00000goo001oo`03Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Goo00<007ooOol01Goo00<0
07ooOol017oo0`00ogooHgoo0`0047oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02
Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo0`001goo
0`00ogooCgoo0`001goo0`0047oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol017oo00<007ooOol017oo1@001Goo0`00
ogooCgoo0`0017oo1P0047oo0002Ool01000Oomoo`003Woo00@007ooOol000Eoo`04001oogoo0004
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool50005Ool3003oOom?Ool30004Ool6
000@Ool000=oo`80011oo`8000Moo`8000Ioo`@000Moo`03001oogoo00Ioo`<00?mooeioo`<001=o
o`00<Goo00<007ooOol017oo0`0017oo1P00ogooCgoo1@001Goo0`0047oo000aOol30004Ool50002
Ool6003oOom?Ool50002Ool6000@Ool0035oo`03001oogoo00Aoo`D0009oo`H00?moodmoo`D0009o
o`H0011oo`00<Goo00<007ooOol01Woo0`00ogooGWoo0`004goo000aOol00`00Oomoo`3oOommOol0
035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`04Ool5003o
OomOOol5000@Ool0035oo`03001oogoo00Aoo`D00?mooemoo`D0011oo`00<Goo0`0017oo1@00ogoo
Ggoo1@0047oo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007oo
Ool03Woo0`00ogooCgoo0`006Woo000aOol00`00Oomoo`06Ool30005Ool3003oOom?Ool30004Ool3
000COol0035oo`03001oogoo00Ioo`<000Eoo`<00?moodmoo`<000Aoo`<001=oo`00<Goo00<007oo
Ool01Woo0`00ogooGWoo0`004goo000aOol00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo
00<007ooOol0ogooOGoo000aOol00`00Oomoo`06Ool3003oOomNOol3000COol0035oo`03001oogoo
00Ioo`<00?mooeioo`<001=oo`00<Goo00<007ooOol01Woo0`00ogooGWoo0`004goo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol017oo0`00ogooHgoo0`00
47oo000aOol30004Ool5003oOomNOol6000@Ool0035oo`03001oogoo00Aoo`D00?mooeioo`H0011o
o`00<Goo00<007ooOol01Woo0`00ogooGWoo0`004goo000aOol00`00Oomoo`3oOommOol0035oo`03
001oogoo0?moogeoo`000goo0P001goo0`001Woo0P001goo0P001Woo10001goo00<007ooOol01Woo
0`001Goo0`00ogooCgoo0`0017oo0`004goo0002Ool01000Oomoo`001Woo0`001Goo00@007ooOol0
00Eoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`06Ool30005Ool3
003oOom?Ool30004Ool3000COol00003Ool007oo00=oo`03001oogoo00=oo`<000Aoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool40005Ool30005Ool3003o
Oom?Ool30004Ool3000COol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`06Ool3003oOomNOol3000C
Ool00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`03Ool30007Ool00`00Oomoo`06Ool3003oOomNOol3000COol00003Ool007oo00=oo`03001o
ogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool0
0`00Oomoo`06Ool3003oOomNOol3000COol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol0
009oo`04001oogoo000>Ool01000Oomoo`001Goo00@007ooOol000Aoo`03001oogoo009oo`03001o
ogoo00Aoo`03001oogoo0?moogeoo`000goo0P0047oo0P001goo0P001Woo10001goo00<007ooOol0
ogooOGoo000aOol00`00Oomoo`06Ool3003oOomNOol3000COol0035oo`<000Ioo`<00?mooeioo`<0
01=oo`00<Goo00<007ooOol01Woo0`00ogooGWoo0`004goo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035o
o`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001o
ogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
ogoo00Ioo`<00?mooeioo`<001=oo`00<Goo00<007ooOol01Woo0`00ogooGWoo0`004goo000aOol0
0`00Oomoo`06Ool3003oOomNOol3000COol0035oo`03001oogoo0?moogeoo`00<Goo0`00ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo
000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo00Ioo`<00?mooeioo`<001=oo`00<Goo00<0
07ooOol01Woo0`00ogooGWoo0`004goo000aOol00`00Oomoo`06Ool3003oOomNOol3000COol0035o
o`<00?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001o
o`0000800?moofeoo`<000]oo`00<Goo00<007oo00000P00ogooKGoo0`002goo0003Ool20007Ool3
0006Ool20007Ool20008Ool30006Ool00`00Ool00002003oOom]Ool3000;Ool0009oo`04001oogoo
0006Ool30005Ool01000Oomoo`001Goo00@007ooOol000Qoo`03001oogoo00Eoo`03001oogoo0?mo
ogeoo`0000=oo`00Ool00goo00<007ooOol00goo0`0017oo00<007ooOol00Woo00D007ooOomoo`00
00Aoo`04001oogooOol60006Ool4003oOomlOol00003Ool007oo00=oo`03001oogoo00Yoo`03001o
ogoo009oo`05001oogooOol00004Ool01@00Oomoogoo00000goo00<007ooOol01Goo00<007ooOol0
ogooOGoo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol00Woo00@007ooOol000Moo`03001oogoo0?moogeoo`0000=oo`00Ool00goo00<007oo
Ool02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03001oo`0000Moo`03
001oogoo0?moogeoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomo
o`0000Aoo`03001oogoo00=oo`03001oo`0000Moo`03001oogoo0?moogeoo`000Woo00@007ooOol0
00ioo`04001oogoo0005Ool01000Oomoo`001goo0P001goo00<007oo00000P00ogooKGoo0`002goo
0003Ool2000@Ool20007Ool20009Ool00`00Oomoo`05Ool00`00Ool00002003oOom]Ool3000;Ool0
035oo`03001oo`0000800?moofeoo`<000]oo`00<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOomm
Ool0035oo`03001oogoo00Ioo`<00?mooeioo`<001=oo`00<Goo00<007ooOol01Woo0`00ogooGWoo
0`004goo000aOol00`00Oomoo`06Ool3003oOomNOol3000COol0035oo`03001oogoo00Ioo`<00?mo
oeioo`<001=oo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`<00?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?mo
ogeoo`00<Goo00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00
<Goo0`00ogooOGoo000aOol00`00Oomoo`3oOommOol0031oo`<00?moogioo`00<7oo0`00ogooOWoo
000`Ool3003oOomnOol000=oo`8000Moo`<000Ioo`8000Moo`8000Ioo`@000Moo`03001oogoo0?mo
ogeoo`000Woo00@007ooOol000Ioo`<000Eoo`04001oogoo0005Ool01000Oomoo`0017oo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol0ogooOGoo00000goo001oo`03Ool00`00Oomoo`03Ool3
0004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol017oo1000
ogooO7oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol01Woo00<007ooOol017oo00<007ooOol0ogooOGoo00000goo001oo`03Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Ao
o`03001oogoo0?moogeoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007oo
Oomoo`0000Aoo`04001oogooOol50007Ool00`00Oomoo`06Ool3003oOomNOol3000COol00003Ool0
07oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
2goo00<007ooOol01Woo0`00ogooGWoo0`004goo0002Ool01000Oomoo`003Woo00@007ooOol000Eo
o`04001oogoo0004Ool00`00Oomoo`09Ool00`00Oomoo`06Ool3003oOomNOol3000COol000=oo`80
011oo`8000Moo`8000Eoo`D000Moo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000a
Ool3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007ooOol0ogooOGoo000aOol00`00
Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo0`001Woo0`00ogooGWoo0`004goo000a
Ool00`00Oomoo`06Ool3003oOomNOol3000COol0035oo`03001oogoo00Ioo`<00?mooeioo`<001=o
o`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeo
o`00<Goo00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`<00?moogeoo`00<Goo
00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo
00<007ooOol0ogooOGoo000aOol00`00Oomoo`3oOommOol0035oo`03001oogoo0?moogeoo`00<Goo
00<007ooOol0ogooOGoo000aOol3003oOommOol0035oo`03001oogoo0?moogeoo`00<Goo00<007oo
Ool01Woo0`00ogooGWoo0`004goo000aOol00`00Oomoo`06Ool3003oOomNOol3000COol0035oo`03
001oogoo00Ioo`<00?mooeioo`<001=oo`000goo0P001goo0`001Woo0P001goo0P001Woo10001goo
00<007ooOol0ogooOGoo0002Ool01000Oomoo`001Woo0`001Goo00@007ooOol000Eoo`04001oogoo
0004Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol00003Ool007oo00=oo`03
001oogoo00=oo`<000Aoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol017oo1000ogooO7oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00Aoo`03001oogoo0?moogeoo`00
00=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`04001oogoo
Ool20003Ool00`00Oomoo`04Ool00`00Oomoo`3oOommOol00003Ool007oo00=oo`03001oogoo00Yo
o`03001oogoo009oo`05001oogooOol00004Ool01P00Oomoogoo001oo`<00?moohMoo`0000=oo`00
Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03
001oogoo0?moohQoo`000Woo00@007ooOol000ioo`04001oogoo0005Ool01000Oomoo`001Goo0P00
ogooRGoo0003Ool2000@Ool20007Ool20008Ool3003oOon6Ool00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-4945, 0, 148, 0}}]
}, Open  ]],

Cell[TextData[{
  "It is easier to comprehend this data if we plot it in terms of actual \
frequencies rather than just the order of the elements of ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["f",
            FontWeight->"Bold"], "~"], TraditionalForm]]],
  ", so we will replot the data. The separation \[CapitalDelta]\[Omega] \
between adjacent Fourier modes is ",
  Cell[BoxData[
      FormBox[
        RowBox[{"2", " ", 
          RowBox[{"\[Pi]", " ", "/", 
            RowBox[{"(", 
              RowBox[{"N", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], ")"}]}]}], 
        TraditionalForm]]],
  ", in radians per second. In hertz, the separation is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["f",
                FontSlant->"Italic"]}]], "=", 
          RowBox[{"1", "/", 
            RowBox[{"(", 
              RowBox[{"N", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]]}], ")"}]}]}], 
        TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalDelta]f\  = \ 1/\((nn\ \[CapitalDelta]t)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.78"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\[CapitalDelta]f\)\" is \
similar to existing symbol \"\!\(\[CapitalDelta]t\)\"."\)], "Message"],

Cell[BoxData[
    \(0.59814453125`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We therefore create a data list, ",
  Cell[BoxData[
      \(TraditionalForm\`{n\ \[CapitalDelta]f, f\&~\_n}\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(n = 0\), ",", "1", ",", "2", ",", "...", ",", 
          RowBox[{
            StyleBox["nn",
              FontSlant->"Italic"], "-", "1"}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(fdata\  = \ 
        Table[{n\ \[CapitalDelta]f, f\&~[\([n + 1]\)]}, {n, 0, 
            nn - 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.79"],

Cell[TextData[{
  "and in Cell ",
  ButtonBox["2.80",
    ButtonData:>"Cell 2.80",
    ButtonStyle->"Hyperlink"],
  " we plot this list over a range of low frequencies, up to 3000 hertz."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Abs[fdata], PlotRange \[Rule] {{0, 3000}, All}, 
        AxesLabel \[Rule] {"\<freq. (hz)\>", \
\*"\"\<|\!\(f\&~\)|\>\""}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.80"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.66967e-17 0.000333333 0.0147013 99.8399 [
[.16667 .0022 -9 -9 ]
[.16667 .0022 9 0 ]
[.33333 .0022 -12 -9 ]
[.33333 .0022 12 0 ]
[.5 .0022 -12 -9 ]
[.5 .0022 12 0 ]
[.66667 .0022 -12 -9 ]
[.66667 .0022 12 0 ]
[.83333 .0022 -12 -9 ]
[.83333 .0022 12 0 ]
[1 .0022 -12 -9 ]
[1 .0022 12 0 ]
[1.025 .0147 0 -6 ]
[1.025 .0147 64 6 ]
[-0.0125 .11454 -30 -4.5 ]
[-0.0125 .11454 0 4.5 ]
[-0.0125 .21438 -30 -4.5 ]
[-0.0125 .21438 0 4.5 ]
[-0.0125 .31422 -30 -4.5 ]
[-0.0125 .31422 0 4.5 ]
[-0.0125 .41406 -30 -4.5 ]
[-0.0125 .41406 0 4.5 ]
[-0.0125 .5139 -30 -4.5 ]
[-0.0125 .5139 0 4.5 ]
[-0.0125 .61374 -30 -4.5 ]
[-0.0125 .61374 0 4.5 ]
[0 .64303 -11 0 ]
[0 .64303 11 12.875 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .0147 m
.16667 .02095 L
s
[(500)] .16667 .0022 0 1 Mshowa
.33333 .0147 m
.33333 .02095 L
s
[(1000)] .33333 .0022 0 1 Mshowa
.5 .0147 m
.5 .02095 L
s
[(1500)] .5 .0022 0 1 Mshowa
.66667 .0147 m
.66667 .02095 L
s
[(2000)] .66667 .0022 0 1 Mshowa
.83333 .0147 m
.83333 .02095 L
s
[(2500)] .83333 .0022 0 1 Mshowa
1 .0147 m
1 .02095 L
s
[(3000)] 1 .0022 0 1 Mshowa
.125 Mabswid
.03333 .0147 m
.03333 .01845 L
s
.06667 .0147 m
.06667 .01845 L
s
.1 .0147 m
.1 .01845 L
s
.13333 .0147 m
.13333 .01845 L
s
.2 .0147 m
.2 .01845 L
s
.23333 .0147 m
.23333 .01845 L
s
.26667 .0147 m
.26667 .01845 L
s
.3 .0147 m
.3 .01845 L
s
.36667 .0147 m
.36667 .01845 L
s
.4 .0147 m
.4 .01845 L
s
.43333 .0147 m
.43333 .01845 L
s
.46667 .0147 m
.46667 .01845 L
s
.53333 .0147 m
.53333 .01845 L
s
.56667 .0147 m
.56667 .01845 L
s
.6 .0147 m
.6 .01845 L
s
.63333 .0147 m
.63333 .01845 L
s
.7 .0147 m
.7 .01845 L
s
.73333 .0147 m
.73333 .01845 L
s
.76667 .0147 m
.76667 .01845 L
s
.8 .0147 m
.8 .01845 L
s
.86667 .0147 m
.86667 .01845 L
s
.9 .0147 m
.9 .01845 L
s
.93333 .0147 m
.93333 .01845 L
s
.96667 .0147 m
.96667 .01845 L
s
.25 Mabswid
0 .0147 m
1 .0147 L
s
gsave
1.025 .0147 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(freq) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(H) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(hz) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .11454 m
.00625 .11454 L
s
[(0.001)] -0.0125 .11454 1 0 Mshowa
0 .21438 m
.00625 .21438 L
s
[(0.002)] -0.0125 .21438 1 0 Mshowa
0 .31422 m
.00625 .31422 L
s
[(0.003)] -0.0125 .31422 1 0 Mshowa
0 .41406 m
.00625 .41406 L
s
[(0.004)] -0.0125 .41406 1 0 Mshowa
0 .5139 m
.00625 .5139 L
s
[(0.005)] -0.0125 .5139 1 0 Mshowa
0 .61374 m
.00625 .61374 L
s
[(0.006)] -0.0125 .61374 1 0 Mshowa
.125 Mabswid
0 .03467 m
.00375 .03467 L
s
0 .05464 m
.00375 .05464 L
s
0 .07461 m
.00375 .07461 L
s
0 .09457 m
.00375 .09457 L
s
0 .13451 m
.00375 .13451 L
s
0 .15448 m
.00375 .15448 L
s
0 .17445 m
.00375 .17445 L
s
0 .19441 m
.00375 .19441 L
s
0 .23435 m
.00375 .23435 L
s
0 .25432 m
.00375 .25432 L
s
0 .27429 m
.00375 .27429 L
s
0 .29425 m
.00375 .29425 L
s
0 .33419 m
.00375 .33419 L
s
0 .35416 m
.00375 .35416 L
s
0 .37412 m
.00375 .37412 L
s
0 .39409 m
.00375 .39409 L
s
0 .43403 m
.00375 .43403 L
s
0 .454 m
.00375 .454 L
s
0 .47396 m
.00375 .47396 L
s
0 .49393 m
.00375 .49393 L
s
0 .53387 m
.00375 .53387 L
s
0 .55384 m
.00375 .55384 L
s
0 .5738 m
.00375 .5738 L
s
0 .59377 m
.00375 .59377 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.875 translate 1 -1 scale
63.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.875 moveto
(\\310) show
69.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 7.875 moveto
(\\216) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.875 moveto
(\\310) show
81.000 13.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
0 .50364 Mdot
.0002 .05576 Mdot
.0004 .02819 Mdot
.0006 .0239 Mdot
.0008 .02275 Mdot
.001 .01594 Mdot
.0012 .02235 Mdot
.0014 .01801 Mdot
.0016 .02044 Mdot
.00179 .0199 Mdot
.00199 .01542 Mdot
.00219 .02118 Mdot
.00239 .01913 Mdot
.00259 .01705 Mdot
.00279 .01693 Mdot
.00299 .01633 Mdot
.00319 .01861 Mdot
.00339 .01931 Mdot
.00359 .0183 Mdot
.00379 .01624 Mdot
.00399 .01527 Mdot
.00419 .01718 Mdot
.00439 .01813 Mdot
.00459 .01795 Mdot
.00479 .0208 Mdot
.00498 .01938 Mdot
.00518 .01758 Mdot
.00538 .02088 Mdot
.00558 .02134 Mdot
.00578 .02762 Mdot
.00598 .02446 Mdot
.00618 .01844 Mdot
.00638 .01963 Mdot
.00658 .0202 Mdot
.00678 .01588 Mdot
.00698 .01543 Mdot
.00718 .01621 Mdot
.00738 .01694 Mdot
.00758 .01846 Mdot
.00778 .0204 Mdot
.00798 .01813 Mdot
.00817 .01705 Mdot
.00837 .01733 Mdot
.00857 .01992 Mdot
.00877 .01882 Mdot
.00897 .01688 Mdot
.00917 .01643 Mdot
.00937 .01874 Mdot
.00957 .01693 Mdot
.00977 .01758 Mdot
.00997 .01843 Mdot
.01017 .01796 Mdot
.01037 .02097 Mdot
.01057 .02028 Mdot
.01077 .01681 Mdot
.01097 .01585 Mdot
.01117 .0178 Mdot
.01136 .01626 Mdot
.01156 .01738 Mdot
.01176 .01888 Mdot
.01196 .01741 Mdot
.01216 .01645 Mdot
.01236 .01572 Mdot
.01256 .01667 Mdot
.01276 .01879 Mdot
.01296 .01528 Mdot
.01316 .02127 Mdot
.01336 .01688 Mdot
.01356 .01678 Mdot
.01376 .01796 Mdot
.01396 .01936 Mdot
.01416 .02038 Mdot
.01436 .01709 Mdot
.01455 .01642 Mdot
.01475 .01883 Mdot
.01495 .02092 Mdot
.01515 .02169 Mdot
.01535 .02111 Mdot
.01555 .01637 Mdot
.01575 .01762 Mdot
.01595 .02046 Mdot
.01615 .02027 Mdot
.01635 .01965 Mdot
.01655 .0178 Mdot
.01675 .01867 Mdot
.01695 .02033 Mdot
.01715 .01876 Mdot
.01735 .01987 Mdot
.01755 .02367 Mdot
.01774 .02124 Mdot
.01794 .0185 Mdot
.01814 .02206 Mdot
.01834 .02445 Mdot
.01854 .0198 Mdot
.01874 .03166 Mdot
.01894 .02626 Mdot
.01914 .02812 Mdot
.01934 .02087 Mdot
.01954 .02041 Mdot
.01974 .01648 Mdot
.01994 .02212 Mdot
.02014 .02067 Mdot
.02034 .01601 Mdot
.02054 .01737 Mdot
.02074 .01591 Mdot
.02094 .01763 Mdot
.02113 .01875 Mdot
.02133 .01756 Mdot
.02153 .01648 Mdot
.02173 .01557 Mdot
.02193 .01608 Mdot
.02213 .01564 Mdot
.02233 .01873 Mdot
.02253 .01779 Mdot
.02273 .01653 Mdot
.02293 .01763 Mdot
.02313 .01644 Mdot
.02333 .01631 Mdot
.02353 .01829 Mdot
.02373 .01792 Mdot
.02393 .0158 Mdot
.02413 .01951 Mdot
.02432 .01821 Mdot
.02452 .0164 Mdot
.02472 .01615 Mdot
.02492 .01659 Mdot
.02512 .01689 Mdot
.02532 .01652 Mdot
.02552 .01766 Mdot
.02572 .0165 Mdot
.02592 .01634 Mdot
.02612 .01649 Mdot
.02632 .01692 Mdot
.02652 .01847 Mdot
.02672 .01554 Mdot
.02692 .01647 Mdot
.02712 .01667 Mdot
.02732 .01527 Mdot
.02751 .01666 Mdot
.02771 .01855 Mdot
.02791 .01912 Mdot
.02811 .01901 Mdot
.02831 .01622 Mdot
.02851 .01742 Mdot
.02871 .01677 Mdot
.02891 .01878 Mdot
.02911 .01825 Mdot
.02931 .01504 Mdot
.02951 .01794 Mdot
.02971 .01846 Mdot
.02991 .01664 Mdot
.03011 .01683 Mdot
.03031 .01641 Mdot
.03051 .01543 Mdot
.0307 .01566 Mdot
.0309 .01569 Mdot
.0311 .01636 Mdot
.0313 .0175 Mdot
.0315 .01706 Mdot
.0317 .01808 Mdot
.0319 .01775 Mdot
.0321 .0179 Mdot
.0323 .01731 Mdot
.0325 .01778 Mdot
.0327 .01721 Mdot
.0329 .01822 Mdot
.0331 .01805 Mdot
.0333 .01722 Mdot
.0335 .0169 Mdot
.0337 .01758 Mdot
.03389 .01751 Mdot
.03409 .01862 Mdot
.03429 .02246 Mdot
.03449 .01961 Mdot
.03469 .01747 Mdot
.03489 .01666 Mdot
.03509 .01736 Mdot
.03529 .01795 Mdot
.03549 .01945 Mdot
.03569 .01767 Mdot
.03589 .01761 Mdot
.03609 .01624 Mdot
.03629 .0158 Mdot
.03649 .01739 Mdot
.03669 .01784 Mdot
.03689 .01617 Mdot
.03708 .01816 Mdot
.03728 .01828 Mdot
.03748 .01616 Mdot
.03768 .01884 Mdot
.03788 .01812 Mdot
.03808 .01733 Mdot
.03828 .01601 Mdot
.03848 .01733 Mdot
.03868 .01659 Mdot
.03888 .01886 Mdot
.03908 .01592 Mdot
.03928 .01907 Mdot
.03948 .022 Mdot
.03968 .01995 Mdot
.03988 .01728 Mdot
.04008 .03301 Mdot
.04028 .02141 Mdot
.04047 .01564 Mdot
.04067 .01959 Mdot
.04087 .01846 Mdot
.04107 .01807 Mdot
.04127 .02059 Mdot
.04147 .01712 Mdot
.04167 .0169 Mdot
.04187 .01654 Mdot
.04207 .01565 Mdot
.04227 .01599 Mdot
.04247 .01855 Mdot
.04267 .01995 Mdot
.04287 .0191 Mdot
.04307 .01655 Mdot
.04327 .01705 Mdot
.04347 .0194 Mdot
.04366 .0182 Mdot
.04386 .01943 Mdot
.04406 .0157 Mdot
.04426 .02444 Mdot
.04446 .02819 Mdot
.04466 .02688 Mdot
.04486 .02627 Mdot
.04506 .02053 Mdot
.04526 .03343 Mdot
.04546 .02717 Mdot
.04566 .03839 Mdot
.04586 .03801 Mdot
.04606 .01942 Mdot
.04626 .03866 Mdot
.04646 .02543 Mdot
.04666 .06387 Mdot
.04685 .05156 Mdot
.04705 .08207 Mdot
.04725 .12729 Mdot
.04745 .08385 Mdot
.04765 .09771 Mdot
.04785 .05043 Mdot
.04805 .18502 Mdot
.04825 .40482 Mdot
.04845 .42945 Mdot
.04865 .18456 Mdot
.04885 .1048 Mdot
.04905 .09655 Mdot
.04925 .11484 Mdot
.04945 .18766 Mdot
.04965 .11992 Mdot
.04985 .0906 Mdot
.05004 .10649 Mdot
.05024 .09067 Mdot
.05044 .0998 Mdot
.05064 .09003 Mdot
.05084 .07076 Mdot
.05104 .06731 Mdot
.05124 .05668 Mdot
.05144 .04829 Mdot
.05164 .03921 Mdot
.05184 .03598 Mdot
.05204 .03376 Mdot
.05224 .03024 Mdot
.05244 .0316 Mdot
.05264 .02535 Mdot
.05284 .03203 Mdot
.05304 .02365 Mdot
.05323 .01943 Mdot
.05343 .0336 Mdot
.05363 .03064 Mdot
.05383 .0282 Mdot
.05403 .02686 Mdot
.05423 .02533 Mdot
.05443 .02946 Mdot
.05463 .02722 Mdot
.05483 .02468 Mdot
.05503 .02851 Mdot
.05523 .02703 Mdot
.05543 .02059 Mdot
.05563 .02821 Mdot
.05583 .02797 Mdot
.05603 .02108 Mdot
.05623 .02138 Mdot
.05642 .02737 Mdot
.05662 .02701 Mdot
.05682 .02484 Mdot
.05702 .02829 Mdot
.05722 .02646 Mdot
.05742 .0226 Mdot
.05762 .02596 Mdot
.05782 .02278 Mdot
.05802 .02271 Mdot
.05822 .02418 Mdot
.05842 .02267 Mdot
.05862 .01966 Mdot
.05882 .02212 Mdot
.05902 .0217 Mdot
.05922 .02077 Mdot
.05942 .02171 Mdot
.05962 .02367 Mdot
.05981 .02425 Mdot
.06001 .0265 Mdot
.06021 .02133 Mdot
.06041 .01779 Mdot
.06061 .01894 Mdot
.06081 .02291 Mdot
.06101 .02449 Mdot
.06121 .0197 Mdot
.06141 .01685 Mdot
.06161 .02237 Mdot
.06181 .02175 Mdot
.06201 .02144 Mdot
.06221 .02119 Mdot
.06241 .02158 Mdot
.06261 .01892 Mdot
.06281 .01931 Mdot
.063 .01966 Mdot
.0632 .01672 Mdot
.0634 .01676 Mdot
.0636 .01678 Mdot
.0638 .02011 Mdot
.064 .02077 Mdot
.0642 .01721 Mdot
.0644 .01663 Mdot
.0646 .01762 Mdot
.0648 .01708 Mdot
.065 .01597 Mdot
.0652 .01795 Mdot
.0654 .01612 Mdot
.0656 .01704 Mdot
.0658 .01795 Mdot
.066 .01877 Mdot
.06619 .0173 Mdot
.06639 .01598 Mdot
.06659 .0163 Mdot
.06679 .01602 Mdot
.06699 .01543 Mdot
.06719 .01699 Mdot
.06739 .01575 Mdot
.06759 .01849 Mdot
.06779 .01781 Mdot
.06799 .0181 Mdot
.06819 .01789 Mdot
.06839 .02102 Mdot
.06859 .01768 Mdot
.06879 .01515 Mdot
.06899 .01835 Mdot
.06919 .01878 Mdot
.06938 .01662 Mdot
.06958 .01769 Mdot
.06978 .01814 Mdot
.06998 .01701 Mdot
.07018 .01625 Mdot
.07038 .02049 Mdot
.07058 .01933 Mdot
.07078 .01743 Mdot
.07098 .01584 Mdot
.07118 .0174 Mdot
.07138 .01759 Mdot
.07158 .0177 Mdot
.07178 .01837 Mdot
.07198 .01818 Mdot
.07218 .01676 Mdot
.07238 .01958 Mdot
.07257 .01861 Mdot
.07277 .01714 Mdot
.07297 .01972 Mdot
.07317 .01706 Mdot
.07337 .01962 Mdot
.07357 .01693 Mdot
.07377 .01957 Mdot
.07397 .0197 Mdot
.07417 .01703 Mdot
.07437 .01719 Mdot
.07457 .0192 Mdot
.07477 .01698 Mdot
.07497 .01741 Mdot
.07517 .01731 Mdot
.07537 .01854 Mdot
.07557 .01791 Mdot
.07576 .01864 Mdot
.07596 .01812 Mdot
.07616 .01578 Mdot
.07636 .01747 Mdot
.07656 .01564 Mdot
.07676 .01692 Mdot
.07696 .01697 Mdot
.07716 .01807 Mdot
.07736 .01776 Mdot
.07756 .01552 Mdot
.07776 .01685 Mdot
.07796 .01781 Mdot
.07816 .01743 Mdot
.07836 .01503 Mdot
.07856 .01677 Mdot
.07876 .01528 Mdot
.07896 .01649 Mdot
.07915 .01765 Mdot
.07935 .01553 Mdot
.07955 .01661 Mdot
.07975 .02283 Mdot
.07995 .02657 Mdot
.08015 .01846 Mdot
.08035 .01812 Mdot
.08055 .01681 Mdot
.08075 .0161 Mdot
.08095 .01992 Mdot
.08115 .01914 Mdot
.08135 .01583 Mdot
.08155 .01728 Mdot
.08175 .01581 Mdot
.08195 .0188 Mdot
.08215 .01679 Mdot
.08234 .0154 Mdot
.08254 .01618 Mdot
.08274 .01654 Mdot
.08294 .01733 Mdot
.08314 .01678 Mdot
.08334 .01784 Mdot
.08354 .01601 Mdot
.08374 .01663 Mdot
.08394 .01678 Mdot
.08414 .0191 Mdot
.08434 .01913 Mdot
.08454 .01549 Mdot
.08474 .01712 Mdot
.08494 .01663 Mdot
.08514 .01959 Mdot
.08534 .01662 Mdot
.08553 .01866 Mdot
.08573 .01881 Mdot
.08593 .01513 Mdot
.08613 .01604 Mdot
.08633 .01629 Mdot
.08653 .01577 Mdot
.08673 .01711 Mdot
.08693 .01588 Mdot
.08713 .01573 Mdot
.08733 .01609 Mdot
.08753 .01786 Mdot
.08773 .01626 Mdot
.08793 .0167 Mdot
.08813 .01639 Mdot
.08833 .01626 Mdot
.08853 .01666 Mdot
.08872 .01893 Mdot
.08892 .01731 Mdot
.08912 .01713 Mdot
.08932 .01553 Mdot
.08952 .02135 Mdot
.08972 .01938 Mdot
.08992 .01634 Mdot
.09012 .01909 Mdot
.09032 .01701 Mdot
.09052 .01582 Mdot
.09072 .01709 Mdot
.09092 .01796 Mdot
.09112 .01826 Mdot
.09132 .01645 Mdot
.09152 .01976 Mdot
.09172 .01602 Mdot
.09191 .02102 Mdot
.09211 .0175 Mdot
.09231 .0196 Mdot
.09251 .02162 Mdot
.09271 .02269 Mdot
.09291 .02276 Mdot
.09311 .02179 Mdot
.09331 .0185 Mdot
.09351 .0213 Mdot
.09371 .02087 Mdot
.09391 .03149 Mdot
.09411 .03059 Mdot
.09431 .02298 Mdot
.09451 .02421 Mdot
.09471 .02885 Mdot
.09491 .04598 Mdot
.0951 .03533 Mdot
.0953 .04072 Mdot
.0955 .07765 Mdot
.0957 .08203 Mdot
.0959 .06537 Mdot
.0961 .04503 Mdot
.0963 .04558 Mdot
.0965 .11323 Mdot
.0967 .12878 Mdot
.0969 .08464 Mdot
.0971 .02971 Mdot
.0973 .04298 Mdot
.0975 .06444 Mdot
.0977 .07817 Mdot
.0979 .06579 Mdot
.0981 .02745 Mdot
.0983 .03318 Mdot
.09849 .02806 Mdot
.09869 .04122 Mdot
.09889 .04609 Mdot
.09909 .04813 Mdot
.09929 .0395 Mdot
.09949 .04127 Mdot
.09969 .04766 Mdot
.09989 .04501 Mdot
.10009 .04807 Mdot
.10029 .05053 Mdot
.10049 .04709 Mdot
.10069 .04181 Mdot
.10089 .04019 Mdot
.10109 .03767 Mdot
.10129 .03484 Mdot
.10149 .03213 Mdot
.10168 .02783 Mdot
.10188 .02575 Mdot
.10208 .02574 Mdot
.10228 .02383 Mdot
.10248 .02221 Mdot
.10268 .01759 Mdot
.10288 .01804 Mdot
.10308 .01632 Mdot
.10328 .01895 Mdot
.10348 .02043 Mdot
.10368 .01742 Mdot
.10388 .01947 Mdot
.10408 .01595 Mdot
.10428 .02251 Mdot
.10448 .02166 Mdot
.10468 .01906 Mdot
.10487 .02043 Mdot
.10507 .01771 Mdot
.10527 .01905 Mdot
.10547 .01762 Mdot
.10567 .01758 Mdot
.10587 .01565 Mdot
.10607 .02119 Mdot
.10627 .01897 Mdot
.10647 .01841 Mdot
.10667 .01831 Mdot
.10687 .01839 Mdot
.10707 .01892 Mdot
.10727 .01987 Mdot
.10747 .0168 Mdot
.10767 .01612 Mdot
.10787 .01743 Mdot
.10806 .01742 Mdot
.10826 .01725 Mdot
.10846 .01622 Mdot
.10866 .01889 Mdot
.10886 .01699 Mdot
.10906 .01614 Mdot
.10926 .0155 Mdot
.10946 .01668 Mdot
.10966 .01666 Mdot
.10986 .01973 Mdot
.11006 .0152 Mdot
.11026 .0163 Mdot
.11046 .01645 Mdot
.11066 .01909 Mdot
.11086 .01697 Mdot
.11106 .01531 Mdot
.11125 .01587 Mdot
.11145 .01763 Mdot
.11165 .01685 Mdot
.11185 .0162 Mdot
.11205 .0165 Mdot
.11225 .01672 Mdot
.11245 .0153 Mdot
.11265 .01675 Mdot
.11285 .01731 Mdot
.11305 .01741 Mdot
.11325 .01545 Mdot
.11345 .01649 Mdot
.11365 .01734 Mdot
.11385 .01716 Mdot
.11405 .01549 Mdot
.11425 .01691 Mdot
.11444 .0171 Mdot
.11464 .01653 Mdot
.11484 .01704 Mdot
.11504 .01673 Mdot
.11524 .01713 Mdot
.11544 .01859 Mdot
.11564 .01829 Mdot
.11584 .01965 Mdot
.11604 .01613 Mdot
.11624 .01514 Mdot
.11644 .0157 Mdot
.11664 .01559 Mdot
.11684 .01826 Mdot
.11704 .01866 Mdot
.11724 .01816 Mdot
.11744 .01612 Mdot
.11764 .01545 Mdot
.11783 .01555 Mdot
.11803 .01885 Mdot
.11823 .01805 Mdot
.11843 .01741 Mdot
.11863 .0168 Mdot
.11883 .01525 Mdot
.11903 .01876 Mdot
.11923 .01663 Mdot
.11943 .01638 Mdot
.11963 .0198 Mdot
.11983 .02117 Mdot
.12003 .02751 Mdot
.12023 .02082 Mdot
.12043 .01839 Mdot
.12063 .01546 Mdot
.12083 .01588 Mdot
.12102 .01538 Mdot
.12122 .01582 Mdot
.12142 .01676 Mdot
.12162 .01533 Mdot
.12182 .01664 Mdot
.12202 .01793 Mdot
.12222 .01777 Mdot
.12242 .01786 Mdot
.12262 .01519 Mdot
.12282 .01719 Mdot
.12302 .01595 Mdot
.12322 .01853 Mdot
.12342 .01862 Mdot
.12362 .01517 Mdot
.12382 .01802 Mdot
.12402 .01671 Mdot
.12421 .01743 Mdot
.12441 .01505 Mdot
.12461 .01761 Mdot
.12481 .01814 Mdot
.12501 .01779 Mdot
.12521 .01559 Mdot
.12541 .01647 Mdot
.12561 .01667 Mdot
.12581 .01558 Mdot
.12601 .01646 Mdot
.12621 .01776 Mdot
.12641 .01809 Mdot
.12661 .01569 Mdot
.12681 .0186 Mdot
.12701 .01794 Mdot
.12721 .01716 Mdot
.1274 .0166 Mdot
.1276 .01709 Mdot
.1278 .01695 Mdot
.128 .01794 Mdot
.1282 .0153 Mdot
.1284 .01567 Mdot
.1286 .01629 Mdot
.1288 .01594 Mdot
.129 .01642 Mdot
.1292 .01727 Mdot
.1294 .01864 Mdot
.1296 .01807 Mdot
.1298 .01541 Mdot
.13 .01895 Mdot
.1302 .01642 Mdot
.1304 .01691 Mdot
.13059 .01653 Mdot
.13079 .01659 Mdot
.13099 .01661 Mdot
.13119 .01727 Mdot
.13139 .01728 Mdot
.13159 .01695 Mdot
.13179 .01782 Mdot
.13199 .01898 Mdot
.13219 .01832 Mdot
.13239 .01675 Mdot
.13259 .01976 Mdot
.13279 .0156 Mdot
.13299 .01803 Mdot
.13319 .01649 Mdot
.13339 .01773 Mdot
.13359 .01746 Mdot
.13378 .01864 Mdot
.13398 .01705 Mdot
.13418 .01859 Mdot
.13438 .01696 Mdot
.13458 .01599 Mdot
.13478 .01507 Mdot
.13498 .01837 Mdot
.13518 .01619 Mdot
.13538 .01629 Mdot
.13558 .01783 Mdot
.13578 .01835 Mdot
.13598 .01615 Mdot
.13618 .01829 Mdot
.13638 .01799 Mdot
.13658 .0175 Mdot
.13678 .01936 Mdot
.13698 .01788 Mdot
.13717 .01939 Mdot
.13737 .01994 Mdot
.13757 .0211 Mdot
.13777 .02236 Mdot
.13797 .02203 Mdot
.13817 .02264 Mdot
.13837 .02286 Mdot
.13857 .0181 Mdot
.13877 .02776 Mdot
.13897 .01763 Mdot
.13917 .03053 Mdot
.13937 .0295 Mdot
.13957 .02425 Mdot
.13977 .03363 Mdot
.13997 .01774 Mdot
.14017 .03244 Mdot
.14036 .03727 Mdot
.14056 .02531 Mdot
.14076 .05814 Mdot
.14096 .03339 Mdot
.14116 .04814 Mdot
.14136 .0549 Mdot
.14156 .03628 Mdot
.14176 .04387 Mdot
.14196 .02573 Mdot
.14216 .08321 Mdot
.14236 .10494 Mdot
.14256 .03925 Mdot
.14276 .06622 Mdot
.14296 .09505 Mdot
.14316 .13037 Mdot
.14336 .11335 Mdot
.14355 .0484 Mdot
.14375 .17815 Mdot
.14395 .2208 Mdot
.14415 .17972 Mdot
.14435 .13629 Mdot
.14455 .05915 Mdot
.14475 .15095 Mdot
.14495 .25091 Mdot
.14515 .21509 Mdot
.14535 .08889 Mdot
.14555 .08553 Mdot
.14575 .22385 Mdot
.14595 .29397 Mdot
.14615 .23252 Mdot
.14635 .09665 Mdot
.14655 .02896 Mdot
.14674 .0593 Mdot
.14694 .09685 Mdot
.14714 .12269 Mdot
.14734 .09844 Mdot
.14754 .06055 Mdot
.14774 .06043 Mdot
.14794 .05889 Mdot
.14814 .07686 Mdot
.14834 .10149 Mdot
.14854 .10763 Mdot
.14874 .10426 Mdot
.14894 .0954 Mdot
.14914 .10254 Mdot
.14934 .11525 Mdot
.14954 .1213 Mdot
.14974 .12083 Mdot
.14993 .11548 Mdot
.15013 .10648 Mdot
.15033 .1149 Mdot
.15053 .10222 Mdot
.15073 .08967 Mdot
.15093 .09168 Mdot
.15113 .07375 Mdot
.15133 .07348 Mdot
.15153 .06677 Mdot
.15173 .05282 Mdot
.15193 .05524 Mdot
.15213 .04692 Mdot
.15233 .03355 Mdot
.15253 .02764 Mdot
.15273 .01979 Mdot
.15293 .02483 Mdot
.15313 .01832 Mdot
.15332 .02406 Mdot
.15352 .01923 Mdot
.15372 .02113 Mdot
.15392 .02352 Mdot
.15412 .02424 Mdot
.15432 .02658 Mdot
.15452 .02224 Mdot
.15472 .02382 Mdot
.15492 .02474 Mdot
.15512 .02325 Mdot
.15532 .02545 Mdot
.15552 .02622 Mdot
.15572 .02644 Mdot
.15592 .02106 Mdot
.15612 .02298 Mdot
.15632 .02272 Mdot
.15651 .02482 Mdot
.15671 .02317 Mdot
.15691 .02158 Mdot
.15711 .02205 Mdot
.15731 .02101 Mdot
.15751 .02204 Mdot
.15771 .02318 Mdot
.15791 .02201 Mdot
.15811 .02338 Mdot
.15831 .01691 Mdot
.15851 .02079 Mdot
.15871 .02242 Mdot
.15891 .02013 Mdot
.15911 .02353 Mdot
.15931 .02409 Mdot
.15951 .01855 Mdot
.1597 .02325 Mdot
.1599 .03033 Mdot
.1601 .02267 Mdot
.1603 .02822 Mdot
.1605 .02671 Mdot
.1607 .0219 Mdot
.1609 .0176 Mdot
.1611 .02096 Mdot
.1613 .01889 Mdot
.1615 .01841 Mdot
.1617 .02143 Mdot
.1619 .01838 Mdot
.1621 .02004 Mdot
.1623 .02002 Mdot
.1625 .02157 Mdot
.1627 .02371 Mdot
.16289 .02583 Mdot
.16309 .01977 Mdot
.16329 .01888 Mdot
.16349 .01973 Mdot
.16369 .01855 Mdot
.16389 .02226 Mdot
.16409 .02127 Mdot
.16429 .01871 Mdot
.16449 .0205 Mdot
.16469 .01832 Mdot
.16489 .01697 Mdot
.16509 .01743 Mdot
.16529 .01752 Mdot
.16549 .01975 Mdot
.16569 .02009 Mdot
.16589 .02577 Mdot
.16608 .02265 Mdot
.16628 .02454 Mdot
.16648 .01886 Mdot
.16668 .02192 Mdot
.16688 .02468 Mdot
.16708 .02215 Mdot
.16728 .02114 Mdot
.16748 .02067 Mdot
.16768 .01783 Mdot
.16788 .01975 Mdot
.16808 .02092 Mdot
.16828 .02186 Mdot
.16848 .0187 Mdot
.16868 .01941 Mdot
.16888 .0185 Mdot
.16908 .02203 Mdot
.16927 .02159 Mdot
.16947 .02274 Mdot
.16967 .02102 Mdot
.16987 .01622 Mdot
.17007 .01894 Mdot
.17027 .02263 Mdot
.17047 .02629 Mdot
.17067 .0205 Mdot
.17087 .0204 Mdot
.17107 .02513 Mdot
.17127 .02293 Mdot
.17147 .02371 Mdot
.17167 .01883 Mdot
.17187 .01823 Mdot
.17207 .02192 Mdot
.17227 .02015 Mdot
.17247 .01691 Mdot
.17266 .02306 Mdot
.17286 .02352 Mdot
.17306 .0223 Mdot
.17326 .01928 Mdot
.17346 .02462 Mdot
.17366 .02208 Mdot
.17386 .02439 Mdot
.17406 .0233 Mdot
.17426 .02744 Mdot
.17446 .02114 Mdot
.17466 .01476 Mdot
.17486 .01896 Mdot
.17506 .02219 Mdot
.17526 .02128 Mdot
.17546 .01864 Mdot
.17566 .01821 Mdot
.17585 .01555 Mdot
.17605 .01729 Mdot
.17625 .01777 Mdot
.17645 .02323 Mdot
.17665 .02393 Mdot
.17685 .02274 Mdot
.17705 .01948 Mdot
.17725 .02137 Mdot
.17745 .02281 Mdot
.17765 .02328 Mdot
.17785 .01921 Mdot
.17805 .02464 Mdot
.17825 .01829 Mdot
.17845 .01991 Mdot
.17865 .0199 Mdot
.17885 .01728 Mdot
.17904 .023 Mdot
.17924 .01929 Mdot
.17944 .02308 Mdot
.17964 .01823 Mdot
.17984 .02412 Mdot
.18004 .01706 Mdot
.18024 .01541 Mdot
.18044 .01987 Mdot
.18064 .02363 Mdot
.18084 .02226 Mdot
.18104 .02445 Mdot
.18124 .01755 Mdot
.18144 .02068 Mdot
.18164 .02148 Mdot
.18184 .02535 Mdot
.18204 .0233 Mdot
.18223 .02411 Mdot
.18243 .01862 Mdot
.18263 .02507 Mdot
.18283 .02128 Mdot
.18303 .02734 Mdot
.18323 .02714 Mdot
.18343 .02002 Mdot
.18363 .02313 Mdot
.18383 .02952 Mdot
.18403 .02249 Mdot
.18423 .02745 Mdot
.18443 .01696 Mdot
.18463 .02411 Mdot
.18483 .02591 Mdot
.18503 .03315 Mdot
.18523 .02345 Mdot
.18542 .03364 Mdot
.18562 .02863 Mdot
.18582 .02833 Mdot
.18602 .03876 Mdot
.18622 .03107 Mdot
.18642 .04142 Mdot
.18662 .04678 Mdot
.18682 .0169 Mdot
.18702 .05227 Mdot
.18722 .03037 Mdot
.18742 .05172 Mdot
.18762 .04935 Mdot
.18782 .02522 Mdot
.18802 .0725 Mdot
.18822 .05443 Mdot
.18842 .04207 Mdot
.18861 .07487 Mdot
.18881 .03019 Mdot
.18901 .11966 Mdot
.18921 .09935 Mdot
.18941 .09377 Mdot
.18961 .1424 Mdot
.18981 .09525 Mdot
.19001 .06186 Mdot
.19021 .04553 Mdot
.19041 .19049 Mdot
.19061 .25035 Mdot
.19081 .13269 Mdot
.19101 .13281 Mdot
.19121 .23734 Mdot
.19141 .3123 Mdot
.19161 .33288 Mdot
.19181 .10742 Mdot
.192 .31933 Mdot
.1922 .5222 Mdot
.1924 .44203 Mdot
.1926 .31076 Mdot
.1928 .2257 Mdot
.193 .0731 Mdot
.1932 .20904 Mdot
.1934 .28353 Mdot
.1936 .17661 Mdot
.1938 .10501 Mdot
.194 .39093 Mdot
.1942 .60332 Mdot
.1944 .5559 Mdot
.1946 .26742 Mdot
.1948 .03078 Mdot
.195 .15561 Mdot
.19519 .36608 Mdot
.19539 .44396 Mdot
.19559 .29748 Mdot
.19579 .08863 Mdot
.19599 .05511 Mdot
.19619 .05226 Mdot
.19639 .12131 Mdot
.19659 .17031 Mdot
.19679 .17626 Mdot
.19699 .14576 Mdot
.19719 .09236 Mdot
.19739 .09118 Mdot
.19759 .13212 Mdot
.19779 .16856 Mdot
.19799 .17976 Mdot
.19819 .17144 Mdot
.19838 .15538 Mdot
.19858 .18479 Mdot
.19878 .21375 Mdot
.19898 .20725 Mdot
.19918 .20424 Mdot
.19938 .19001 Mdot
.19958 .16569 Mdot
.19978 .16511 Mdot
.19998 .13792 Mdot
.20018 .12631 Mdot
.20038 .11874 Mdot
.20058 .0986 Mdot
.20078 .09235 Mdot
.20098 .07869 Mdot
.20118 .06766 Mdot
.20138 .07113 Mdot
.20157 .05625 Mdot
.20177 .04754 Mdot
.20197 .0455 Mdot
.20217 .03343 Mdot
.20237 .0362 Mdot
.20257 .02879 Mdot
.20277 .01988 Mdot
.20297 .02076 Mdot
.20317 .0241 Mdot
.20337 .02421 Mdot
.20357 .02958 Mdot
.20377 .03125 Mdot
.20397 .03518 Mdot
.20417 .04067 Mdot
.20437 .02685 Mdot
.20457 .03671 Mdot
.20476 .03776 Mdot
.20496 .03084 Mdot
.20516 .03411 Mdot
.20536 .02782 Mdot
.20556 .03148 Mdot
.20576 .03951 Mdot
.20596 .02633 Mdot
.20616 .03161 Mdot
.20636 .03664 Mdot
.20656 .041 Mdot
.20676 .03907 Mdot
.20696 .03805 Mdot
.20716 .0386 Mdot
.20736 .03889 Mdot
.20756 .04186 Mdot
.20776 .04035 Mdot
.20795 .04323 Mdot
.20815 .04245 Mdot
.20835 .03459 Mdot
.20855 .03595 Mdot
.20875 .04082 Mdot
.20895 .04391 Mdot
.20915 .03874 Mdot
.20935 .03784 Mdot
.20955 .03899 Mdot
.20975 .03173 Mdot
.20995 .0368 Mdot
.21015 .04039 Mdot
.21035 .02901 Mdot
.21055 .03138 Mdot
.21075 .03505 Mdot
.21095 .02877 Mdot
.21115 .02297 Mdot
.21134 .02801 Mdot
.21154 .02755 Mdot
.21174 .02685 Mdot
.21194 .03636 Mdot
.21214 .0282 Mdot
.21234 .02441 Mdot
.21254 .02841 Mdot
.21274 .03035 Mdot
.21294 .02556 Mdot
.21314 .0232 Mdot
.21334 .0275 Mdot
.21354 .02562 Mdot
.21374 .02977 Mdot
.21394 .03307 Mdot
.21414 .02691 Mdot
.21434 .02158 Mdot
.21453 .02698 Mdot
.21473 .02697 Mdot
.21493 .0238 Mdot
.21513 .02067 Mdot
.21533 .02267 Mdot
.21553 .03002 Mdot
.21573 .02514 Mdot
.21593 .02761 Mdot
.21613 .02867 Mdot
.21633 .02287 Mdot
.21653 .02063 Mdot
.21673 .02338 Mdot
.21693 .02323 Mdot
.21713 .02057 Mdot
.21733 .0201 Mdot
.21753 .02126 Mdot
.21772 .01708 Mdot
.21792 .02151 Mdot
.21812 .01897 Mdot
.21832 .01998 Mdot
.21852 .01927 Mdot
.21872 .02543 Mdot
.21892 .02188 Mdot
.21912 .02273 Mdot
.21932 .02307 Mdot
.21952 .02363 Mdot
.21972 .02352 Mdot
.21992 .02192 Mdot
.22012 .02428 Mdot
.22032 .0196 Mdot
.22052 .01587 Mdot
.22072 .02386 Mdot
.22091 .02674 Mdot
.22111 .02297 Mdot
.22131 .02265 Mdot
.22151 .02679 Mdot
.22171 .02329 Mdot
.22191 .01952 Mdot
.22211 .02343 Mdot
.22231 .02358 Mdot
.22251 .01706 Mdot
.22271 .01958 Mdot
.22291 .0214 Mdot
.22311 .02172 Mdot
.22331 .01984 Mdot
.22351 .0192 Mdot
.22371 .02182 Mdot
.22391 .01608 Mdot
.2241 .02213 Mdot
.2243 .01945 Mdot
.2245 .02114 Mdot
.2247 .01577 Mdot
.2249 .01496 Mdot
.2251 .01893 Mdot
.2253 .01478 Mdot
.2255 .01985 Mdot
.2257 .02405 Mdot
.2259 .0193 Mdot
.2261 .01659 Mdot
.2263 .01941 Mdot
.2265 .01698 Mdot
.2267 .01728 Mdot
.2269 .0176 Mdot
.2271 .01521 Mdot
.22729 .01862 Mdot
.22749 .01786 Mdot
.22769 .01978 Mdot
.22789 .01921 Mdot
.22809 .01857 Mdot
.22829 .01627 Mdot
.22849 .01836 Mdot
.22869 .02243 Mdot
.22889 .02617 Mdot
.22909 .01868 Mdot
.22929 .0242 Mdot
.22949 .01769 Mdot
.22969 .0188 Mdot
.22989 .01965 Mdot
.23009 .02095 Mdot
.23029 .02232 Mdot
.23049 .02769 Mdot
.23068 .0183 Mdot
.23088 .01566 Mdot
.23108 .02203 Mdot
.23128 .02048 Mdot
.23148 .03008 Mdot
.23168 .02334 Mdot
.23188 .02693 Mdot
.23208 .0238 Mdot
.23228 .03136 Mdot
.23248 .02503 Mdot
.23268 .02972 Mdot
.23288 .021 Mdot
.23308 .02667 Mdot
.23328 .03394 Mdot
.23348 .02034 Mdot
.23368 .02596 Mdot
.23387 .03076 Mdot
.23407 .02693 Mdot
.23427 .04557 Mdot
.23447 .03008 Mdot
.23467 .04064 Mdot
.23487 .05363 Mdot
.23507 .01999 Mdot
.23527 .04042 Mdot
.23547 .03995 Mdot
.23567 .02896 Mdot
.23587 .05014 Mdot
.23607 .02482 Mdot
.23627 .06067 Mdot
.23647 .0566 Mdot
.23667 .02892 Mdot
.23687 .04533 Mdot
.23706 .05138 Mdot
.23726 .0667 Mdot
.23746 .05757 Mdot
.23766 .04945 Mdot
.23786 .09464 Mdot
.23806 .08635 Mdot
.23826 .04599 Mdot
.23846 .03118 Mdot
.23866 .0711 Mdot
.23886 .09023 Mdot
.23906 .06881 Mdot
.23926 .02659 Mdot
.23946 .07385 Mdot
.23966 .10519 Mdot
.23986 .10353 Mdot
.24006 .07739 Mdot
.24025 .03179 Mdot
.24045 .11819 Mdot
.24065 .1433 Mdot
.24085 .11102 Mdot
.24105 .07856 Mdot
.24125 .0751 Mdot
.24145 .06194 Mdot
.24165 .04101 Mdot
.24185 .04799 Mdot
.24205 .0342 Mdot
.24225 .05679 Mdot
.24245 .11814 Mdot
.24265 .15027 Mdot
.24285 .13021 Mdot
.24305 .06118 Mdot
.24325 .06038 Mdot
.24344 .14013 Mdot
.24364 .19552 Mdot
.24384 .17132 Mdot
.24404 .08495 Mdot
.24424 .02564 Mdot
.24444 .04592 Mdot
.24464 .08734 Mdot
.24484 .09976 Mdot
.24504 .0738 Mdot
.24524 .04603 Mdot
.24544 .02505 Mdot
.24564 .02709 Mdot
.24584 .04252 Mdot
.24604 .05142 Mdot
.24624 .05255 Mdot
.24644 .04346 Mdot
.24663 .0349 Mdot
.24683 .02797 Mdot
.24703 .04158 Mdot
.24723 .05887 Mdot
.24743 .05972 Mdot
.24763 .064 Mdot
.24783 .05748 Mdot
.24803 .0585 Mdot
.24823 .06882 Mdot
.24843 .06837 Mdot
.24863 .06786 Mdot
.24883 .07165 Mdot
.24903 .06499 Mdot
.24923 .06879 Mdot
.24943 .06556 Mdot
.24963 .05815 Mdot
.24983 .06449 Mdot
.25002 .06097 Mdot
.25022 .05815 Mdot
.25042 .05802 Mdot
.25062 .04773 Mdot
.25082 .04783 Mdot
.25102 .04462 Mdot
.25122 .03889 Mdot
.25142 .03621 Mdot
.25162 .02928 Mdot
.25182 .02556 Mdot
.25202 .02586 Mdot
.25222 .02463 Mdot
.25242 .02032 Mdot
.25262 .01765 Mdot
.25282 .01567 Mdot
.25302 .01544 Mdot
.25321 .0169 Mdot
.25341 .01947 Mdot
.25361 .01639 Mdot
.25381 .01621 Mdot
.25401 .01825 Mdot
.25421 .01985 Mdot
.25441 .0161 Mdot
.25461 .01969 Mdot
.25481 .02155 Mdot
.25501 .01574 Mdot
.25521 .021 Mdot
.25541 .02023 Mdot
.25561 .0209 Mdot
.25581 .01983 Mdot
.25601 .01839 Mdot
.25621 .02147 Mdot
.2564 .0219 Mdot
.2566 .01913 Mdot
.2568 .02012 Mdot
.257 .01905 Mdot
.2572 .01979 Mdot
.2574 .01706 Mdot
.2576 .02102 Mdot
.2578 .01718 Mdot
.258 .02348 Mdot
.2582 .02112 Mdot
.2584 .01621 Mdot
.2586 .02 Mdot
.2588 .01699 Mdot
.259 .02021 Mdot
.2592 .0217 Mdot
.2594 .02099 Mdot
.25959 .02292 Mdot
.25979 .02564 Mdot
.25999 .01871 Mdot
.26019 .02094 Mdot
.26039 .02415 Mdot
.26059 .02118 Mdot
.26079 .0214 Mdot
.26099 .01836 Mdot
.26119 .0226 Mdot
.26139 .01982 Mdot
.26159 .01759 Mdot
.26179 .01861 Mdot
.26199 .01828 Mdot
.26219 .01842 Mdot
.26239 .01699 Mdot
.26259 .02085 Mdot
.26278 .01953 Mdot
.26298 .01792 Mdot
.26318 .02007 Mdot
.26338 .0207 Mdot
.26358 .01906 Mdot
.26378 .01781 Mdot
.26398 .02097 Mdot
.26418 .02277 Mdot
.26438 .01586 Mdot
.26458 .02247 Mdot
.26478 .02362 Mdot
.26498 .02075 Mdot
.26518 .01777 Mdot
.26538 .0202 Mdot
.26558 .01867 Mdot
.26578 .01668 Mdot
.26597 .01701 Mdot
.26617 .01619 Mdot
.26637 .01726 Mdot
.26657 .01754 Mdot
.26677 .01829 Mdot
.26697 .01733 Mdot
.26717 .01536 Mdot
.26737 .01671 Mdot
.26757 .01871 Mdot
.26777 .017 Mdot
.26797 .01803 Mdot
.26817 .01925 Mdot
.26837 .01694 Mdot
.26857 .01744 Mdot
.26877 .01999 Mdot
.26897 .02047 Mdot
.26917 .01817 Mdot
.26936 .01671 Mdot
.26956 .01762 Mdot
.26976 .02054 Mdot
.26996 .01882 Mdot
.27016 .02127 Mdot
.27036 .02155 Mdot
.27056 .01755 Mdot
.27076 .01819 Mdot
.27096 .01577 Mdot
.27116 .01733 Mdot
.27136 .01703 Mdot
.27156 .01842 Mdot
.27176 .01793 Mdot
.27196 .0213 Mdot
.27216 .01708 Mdot
.27236 .0196 Mdot
.27255 .01748 Mdot
.27275 .01768 Mdot
.27295 .01719 Mdot
.27315 .01643 Mdot
.27335 .01902 Mdot
.27355 .01612 Mdot
.27375 .01774 Mdot
.27395 .01587 Mdot
.27415 .01971 Mdot
.27435 .01877 Mdot
.27455 .02247 Mdot
.27475 .01687 Mdot
.27495 .02105 Mdot
.27515 .02297 Mdot
.27535 .02652 Mdot
.27555 .01669 Mdot
.27574 .02358 Mdot
.27594 .01668 Mdot
.27614 .01854 Mdot
.27634 .02462 Mdot
.27654 .02577 Mdot
.27674 .01928 Mdot
.27694 .02683 Mdot
.27714 .02054 Mdot
.27734 .02349 Mdot
.27754 .02174 Mdot
.27774 .01801 Mdot
.27794 .02416 Mdot
.27814 .02688 Mdot
.27834 .02248 Mdot
.27854 .02684 Mdot
.27874 .02057 Mdot
.27893 .01969 Mdot
.27913 .0239 Mdot
.27933 .02759 Mdot
.27953 .0219 Mdot
.27973 .02986 Mdot
.27993 .02619 Mdot
.28013 .01832 Mdot
.28033 .02187 Mdot
.28053 .02081 Mdot
.28073 .01669 Mdot
.28093 .01961 Mdot
.28113 .02247 Mdot
.28133 .02373 Mdot
.28153 .01694 Mdot
.28173 .01964 Mdot
.28193 .0229 Mdot
.28212 .0259 Mdot
.28232 .01988 Mdot
.28252 .03247 Mdot
.28272 .0187 Mdot
.28292 .0215 Mdot
.28312 .0298 Mdot
.28332 .02391 Mdot
.28352 .02589 Mdot
.28372 .02787 Mdot
.28392 .02214 Mdot
.28412 .02478 Mdot
.28432 .01922 Mdot
.28452 .0283 Mdot
.28472 .04169 Mdot
.28492 .02771 Mdot
.28512 .02499 Mdot
.28531 .0347 Mdot
.28551 .0532 Mdot
.28571 .03902 Mdot
.28591 .05154 Mdot
.28611 .07523 Mdot
.28631 .06913 Mdot
.28651 .0422 Mdot
.28671 .02416 Mdot
.28691 .07046 Mdot
.28711 .11518 Mdot
.28731 .09545 Mdot
.28751 .02612 Mdot
.28771 .06663 Mdot
.28791 .09706 Mdot
.28811 .11339 Mdot
.28831 .11005 Mdot
.28851 .04841 Mdot
.2887 .06447 Mdot
.2889 .10549 Mdot
.2891 .08974 Mdot
.2893 .0896 Mdot
.2895 .13625 Mdot
.2897 .15523 Mdot
.2899 .13399 Mdot
.2901 .11081 Mdot
.2903 .07922 Mdot
.2905 .04313 Mdot
.2907 .12423 Mdot
.2909 .17016 Mdot
.2911 .12878 Mdot
.2913 .05332 Mdot
.2915 .0579 Mdot
.2917 .15994 Mdot
.29189 .23281 Mdot
.29209 .21283 Mdot
.29229 .1221 Mdot
.29249 .0481 Mdot
.29269 .06649 Mdot
.29289 .10491 Mdot
.29309 .13483 Mdot
.29329 .12143 Mdot
.29349 .07089 Mdot
.29369 .03426 Mdot
.29389 .03301 Mdot
.29409 .06482 Mdot
.29429 .08256 Mdot
.29449 .07292 Mdot
.29469 .04926 Mdot
.29489 .02051 Mdot
.29508 .03084 Mdot
.29528 .04507 Mdot
.29548 .0506 Mdot
.29568 .05464 Mdot
.29588 .04941 Mdot
.29608 .04415 Mdot
.29628 .03127 Mdot
.29648 .0551 Mdot
.29668 .06206 Mdot
.29688 .0584 Mdot
.29708 .06784 Mdot
.29728 .0583 Mdot
.29748 .05774 Mdot
.29768 .06444 Mdot
.29788 .05711 Mdot
.29808 .05958 Mdot
.29827 .06982 Mdot
.29847 .07093 Mdot
.29867 .07684 Mdot
.29887 .07577 Mdot
.29907 .07172 Mdot
.29927 .0879 Mdot
.29947 .07958 Mdot
.29967 .07946 Mdot
.29987 .08458 Mdot
.30007 .07501 Mdot
.30027 .07851 Mdot
.30047 .07169 Mdot
.30067 .06694 Mdot
.30087 .06925 Mdot
.30107 .06091 Mdot
.30127 .06114 Mdot
.30146 .05201 Mdot
.30166 .04883 Mdot
.30186 .04402 Mdot
.30206 .02917 Mdot
.30226 .03188 Mdot
.30246 .02784 Mdot
.30266 .02607 Mdot
.30286 .02313 Mdot
.30306 .02595 Mdot
.30326 .01993 Mdot
.30346 .02053 Mdot
.30366 .01789 Mdot
.30386 .02163 Mdot
.30406 .01894 Mdot
.30426 .01951 Mdot
.30446 .01839 Mdot
.30465 .02696 Mdot
.30485 .02383 Mdot
.30505 .0215 Mdot
.30525 .02026 Mdot
.30545 .02015 Mdot
.30565 .03212 Mdot
.30585 .02858 Mdot
.30605 .02026 Mdot
.30625 .02411 Mdot
.30645 .02321 Mdot
.30665 .02892 Mdot
.30685 .03641 Mdot
.30705 .0336 Mdot
.30725 .03225 Mdot
.30745 .03753 Mdot
.30765 .03322 Mdot
.30785 .03183 Mdot
.30804 .03342 Mdot
.30824 .02728 Mdot
.30844 .03028 Mdot
.30864 .0302 Mdot
.30884 .02875 Mdot
.30904 .03141 Mdot
.30924 .02738 Mdot
.30944 .03219 Mdot
.30964 .03281 Mdot
.30984 .02476 Mdot
.31004 .02307 Mdot
.31024 .02625 Mdot
.31044 .03167 Mdot
.31064 .03163 Mdot
.31084 .02677 Mdot
.31104 .02952 Mdot
.31123 .0237 Mdot
.31143 .0329 Mdot
.31163 .03286 Mdot
.31183 .02637 Mdot
.31203 .02114 Mdot
.31223 .0279 Mdot
.31243 .0312 Mdot
.31263 .02332 Mdot
.31283 .01904 Mdot
.31303 .02061 Mdot
.31323 .02358 Mdot
.31343 .01756 Mdot
.31363 .01695 Mdot
.31383 .01956 Mdot
.31403 .01865 Mdot
.31423 .01768 Mdot
.31442 .01646 Mdot
.31462 .01951 Mdot
.31482 .02082 Mdot
.31502 .01864 Mdot
.31522 .01907 Mdot
.31542 .01895 Mdot
.31562 .01674 Mdot
.31582 .01682 Mdot
.31602 .01697 Mdot
.31622 .01746 Mdot
.31642 .01815 Mdot
.31662 .02096 Mdot
.31682 .01839 Mdot
.31702 .02111 Mdot
.31722 .02192 Mdot
.31742 .01951 Mdot
.31761 .01644 Mdot
.31781 .01819 Mdot
.31801 .0197 Mdot
.31821 .02138 Mdot
.31841 .01652 Mdot
.31861 .02657 Mdot
.31881 .02414 Mdot
.31901 .01618 Mdot
.31921 .01866 Mdot
.31941 .02442 Mdot
.31961 .02419 Mdot
.31981 .01816 Mdot
.32001 .02173 Mdot
.32021 .0243 Mdot
.32041 .02842 Mdot
.32061 .02249 Mdot
.3208 .02218 Mdot
.321 .01848 Mdot
.3212 .02024 Mdot
.3214 .02042 Mdot
.3216 .02248 Mdot
.3218 .02211 Mdot
.322 .02115 Mdot
.3222 .02265 Mdot
.3224 .01905 Mdot
.3226 .01897 Mdot
.3228 .01912 Mdot
.323 .01929 Mdot
.3232 .01622 Mdot
.3234 .01816 Mdot
.3236 .01638 Mdot
.3238 .01951 Mdot
.32399 .01686 Mdot
.32419 .01802 Mdot
.32439 .01722 Mdot
.32459 .01647 Mdot
.32479 .01953 Mdot
.32499 .01791 Mdot
.32519 .01505 Mdot
.32539 .02368 Mdot
.32559 .01913 Mdot
.32579 .01872 Mdot
.32599 .01586 Mdot
.32619 .0215 Mdot
.32639 .01809 Mdot
.32659 .02308 Mdot
.32679 .01611 Mdot
.32699 .02425 Mdot
.32719 .01802 Mdot
.32738 .02373 Mdot
.32758 .02133 Mdot
.32778 .03368 Mdot
.32798 .02538 Mdot
.32818 .02406 Mdot
.32838 .02346 Mdot
.32858 .02214 Mdot
.32878 .03209 Mdot
.32898 .03801 Mdot
.32918 .03124 Mdot
.32938 .04313 Mdot
.32958 .03228 Mdot
.32978 .04497 Mdot
.32998 .03811 Mdot
.33018 .02586 Mdot
.33038 .04471 Mdot
.33057 .04089 Mdot
.33077 .04455 Mdot
.33097 .05801 Mdot
.33117 .04522 Mdot
.33137 .07038 Mdot
.33157 .04915 Mdot
.33177 .05579 Mdot
.33197 .08244 Mdot
.33217 .05879 Mdot
.33237 .04918 Mdot
.33257 .05516 Mdot
.33277 .09257 Mdot
.33297 .12008 Mdot
.33317 .06612 Mdot
.33337 .06722 Mdot
.33357 .12225 Mdot
.33376 .1244 Mdot
.33396 .10475 Mdot
.33416 .03788 Mdot
.33436 .12844 Mdot
.33456 .20666 Mdot
.33476 .15841 Mdot
.33496 .03836 Mdot
.33516 .10716 Mdot
.33536 .17201 Mdot
.33556 .17983 Mdot
.33576 .10115 Mdot
.33596 .05471 Mdot
.33616 .14194 Mdot
.33636 .1481 Mdot
.33656 .13318 Mdot
.33676 .11015 Mdot
.33695 .05311 Mdot
.33715 .05692 Mdot
.33735 .08155 Mdot
.33755 .06488 Mdot
.33775 .09997 Mdot
.33795 .18481 Mdot
.33815 .21221 Mdot
.33835 .16479 Mdot
.33855 .108 Mdot
.33875 .0714 Mdot
.33895 .02836 Mdot
.33915 .09071 Mdot
.33935 .08607 Mdot
.33955 .08815 Mdot
.33975 .05764 Mdot
.33995 .11457 Mdot
.34014 .26467 Mdot
.34034 .30992 Mdot
.34054 .23334 Mdot
.34074 .09786 Mdot
.34094 .04259 Mdot
.34114 .13559 Mdot
.34134 .22437 Mdot
.34154 .20434 Mdot
.34174 .11693 Mdot
.34194 .06914 Mdot
.34214 .07168 Mdot
.34234 .10687 Mdot
.34254 .1349 Mdot
.34274 .14337 Mdot
.34294 .123 Mdot
.34314 .07578 Mdot
.34333 .02042 Mdot
.34353 .08123 Mdot
.34373 .12583 Mdot
.34393 .11973 Mdot
.34413 .08585 Mdot
.34433 .04507 Mdot
.34453 .0524 Mdot
.34473 .0809 Mdot
.34493 .07264 Mdot
.34513 .05332 Mdot
.34533 .05379 Mdot
.34553 .0518 Mdot
.34573 .03249 Mdot
.34593 .06963 Mdot
.34613 .08163 Mdot
.34633 .06723 Mdot
.34653 .08627 Mdot
.34672 .09169 Mdot
.34692 .0839 Mdot
.34712 .10309 Mdot
.34732 .08963 Mdot
.34752 .08096 Mdot
.34772 .11895 Mdot
.34792 .11265 Mdot
.34812 .1087 Mdot
.34832 .13119 Mdot
.34852 .12647 Mdot
.34872 .14171 Mdot
.34892 .15208 Mdot
.34912 .15505 Mdot
.34932 .16221 Mdot
.34952 .13536 Mdot
.34972 .12436 Mdot
.34991 .12027 Mdot
.35011 .11352 Mdot
.35031 .10805 Mdot
.35051 .09131 Mdot
.35071 .09547 Mdot
.35091 .07456 Mdot
.35111 .05963 Mdot
.35131 .06585 Mdot
.35151 .05561 Mdot
.35171 .03949 Mdot
.35191 .04503 Mdot
.35211 .0372 Mdot
.35231 .03611 Mdot
.35251 .04046 Mdot
.35271 .02872 Mdot
.35291 .03084 Mdot
.3531 .03461 Mdot
.3533 .0422 Mdot
.3535 .04812 Mdot
.3537 .03217 Mdot
.3539 .02792 Mdot
.3541 .04528 Mdot
.3543 .03722 Mdot
.3545 .01768 Mdot
.3547 .02703 Mdot
.3549 .0223 Mdot
.3551 .02719 Mdot
.3553 .03093 Mdot
.3555 .03269 Mdot
.3557 .03781 Mdot
.3559 .03997 Mdot
.3561 .05626 Mdot
.35629 .0581 Mdot
.35649 .05121 Mdot
.35669 .04594 Mdot
.35689 .0545 Mdot
.35709 .06109 Mdot
.35729 .06424 Mdot
.35749 .04932 Mdot
.35769 .04914 Mdot
.35789 .05248 Mdot
.35809 .06132 Mdot
.35829 .06114 Mdot
.35849 .05574 Mdot
.35869 .05721 Mdot
.35889 .04921 Mdot
.35909 .05967 Mdot
.35929 .06174 Mdot
.35948 .06428 Mdot
.35968 .06386 Mdot
.35988 .05402 Mdot
.36008 .05195 Mdot
.36028 .05751 Mdot
.36048 .05507 Mdot
.36068 .046 Mdot
.36088 .05151 Mdot
.36108 .04291 Mdot
.36128 .05205 Mdot
.36148 .05114 Mdot
.36168 .0431 Mdot
.36188 .04854 Mdot
.36208 .04949 Mdot
.36228 .04351 Mdot
.36248 .04022 Mdot
.36267 .04034 Mdot
.36287 .03742 Mdot
.36307 .03381 Mdot
.36327 .04391 Mdot
.36347 .04234 Mdot
.36367 .04151 Mdot
.36387 .04662 Mdot
.36407 .03801 Mdot
.36427 .02649 Mdot
.36447 .02944 Mdot
.36467 .03363 Mdot
.36487 .02999 Mdot
.36507 .0226 Mdot
.36527 .02237 Mdot
.36547 .025 Mdot
.36567 .02378 Mdot
.36587 .02344 Mdot
.36606 .01684 Mdot
.36626 .01762 Mdot
.36646 .01631 Mdot
.36666 .02147 Mdot
.36686 .03003 Mdot
.36706 .02072 Mdot
.36726 .01945 Mdot
.36746 .02007 Mdot
.36766 .02156 Mdot
.36786 .02097 Mdot
.36806 .03365 Mdot
.36826 .01683 Mdot
.36846 .02616 Mdot
.36866 .01616 Mdot
.36886 .02337 Mdot
.36906 .01924 Mdot
.36925 .02108 Mdot
.36945 .02187 Mdot
.36965 .02808 Mdot
.36985 .01928 Mdot
.37005 .0276 Mdot
.37025 .02462 Mdot
.37045 .02488 Mdot
.37065 .01778 Mdot
.37085 .03457 Mdot
.37105 .0217 Mdot
.37125 .02805 Mdot
.37145 .02171 Mdot
.37165 .02946 Mdot
.37185 .02233 Mdot
.37205 .03862 Mdot
.37225 .02955 Mdot
.37244 .0358 Mdot
.37264 .0277 Mdot
.37284 .04416 Mdot
.37304 .02067 Mdot
.37324 .04526 Mdot
.37344 .02171 Mdot
.37364 .03721 Mdot
.37384 .01954 Mdot
.37404 .03759 Mdot
.37424 .01875 Mdot
.37444 .02452 Mdot
.37464 .02105 Mdot
.37484 .03296 Mdot
.37504 .02074 Mdot
.37524 .03177 Mdot
.37544 .01695 Mdot
.37563 .02416 Mdot
.37583 .02367 Mdot
.37603 .02922 Mdot
.37623 .01944 Mdot
.37643 .02526 Mdot
.37663 .02596 Mdot
.37683 .02874 Mdot
.37703 .02955 Mdot
.37723 .04395 Mdot
.37743 .016 Mdot
.37763 .04021 Mdot
.37783 .02691 Mdot
.37803 .03125 Mdot
.37823 .03846 Mdot
.37843 .03754 Mdot
.37863 .05237 Mdot
.37882 .06783 Mdot
.37902 .02416 Mdot
.37922 .06535 Mdot
.37942 .03632 Mdot
.37962 .03674 Mdot
.37982 .0487 Mdot
.38002 .03135 Mdot
.38022 .0758 Mdot
.38042 .08198 Mdot
.38062 .0262 Mdot
.38082 .04322 Mdot
.38102 .05715 Mdot
.38122 .0821 Mdot
.38142 .07203 Mdot
.38162 .05864 Mdot
.38182 .08143 Mdot
.38201 .08503 Mdot
.38221 .06737 Mdot
.38241 .0402 Mdot
.38261 .08133 Mdot
.38281 .13917 Mdot
.38301 .11207 Mdot
.38321 .04183 Mdot
.38341 .06009 Mdot
.38361 .0835 Mdot
.38381 .09794 Mdot
.38401 .0901 Mdot
.38421 .02957 Mdot
.38441 .07343 Mdot
.38461 .08904 Mdot
.38481 .06736 Mdot
.38501 .07753 Mdot
.38521 .09192 Mdot
.3854 .07692 Mdot
.3856 .06534 Mdot
.3858 .06404 Mdot
.386 .03036 Mdot
.3862 .08226 Mdot
.3864 .13575 Mdot
.3866 .12223 Mdot
.3868 .06272 Mdot
.387 .04223 Mdot
.3872 .05119 Mdot
.3874 .04558 Mdot
.3876 .01977 Mdot
.3878 .03684 Mdot
.388 .04065 Mdot
.3882 .02766 Mdot
.3884 .07724 Mdot
.38859 .10293 Mdot
.38879 .09009 Mdot
.38899 .05598 Mdot
.38919 .01807 Mdot
.38939 .06356 Mdot
.38959 .09318 Mdot
.38979 .09176 Mdot
.38999 .06575 Mdot
.39019 .02973 Mdot
.39039 .02396 Mdot
.39059 .05283 Mdot
.39079 .06825 Mdot
.39099 .06047 Mdot
.39119 .03606 Mdot
.39139 .02236 Mdot
.39159 .02244 Mdot
.39178 .03742 Mdot
.39198 .03952 Mdot
.39218 .02907 Mdot
.39238 .02367 Mdot
.39258 .02557 Mdot
.39278 .02017 Mdot
.39298 .02296 Mdot
.39318 .02937 Mdot
.39338 .02793 Mdot
.39358 .02683 Mdot
.39378 .02548 Mdot
.39398 .02355 Mdot
.39418 .0292 Mdot
.39438 .02598 Mdot
.39458 .02138 Mdot
.39478 .02313 Mdot
.39497 .01999 Mdot
.39517 .01693 Mdot
.39537 .02272 Mdot
.39557 .01719 Mdot
.39577 .01528 Mdot
.39597 .01923 Mdot
.39617 .02086 Mdot
.39637 .02137 Mdot
.39657 .02173 Mdot
.39677 .01913 Mdot
.39697 .02535 Mdot
.39717 .02485 Mdot
.39737 .02333 Mdot
.39757 .02375 Mdot
.39777 .02201 Mdot
.39797 .02156 Mdot
.39816 .02257 Mdot
.39836 .02224 Mdot
.39856 .02387 Mdot
.39876 .02387 Mdot
.39896 .02253 Mdot
.39916 .02081 Mdot
.39936 .02527 Mdot
.39956 .02252 Mdot
.39976 .02309 Mdot
.39996 .01801 Mdot
.40016 .02013 Mdot
.40036 .01868 Mdot
.40056 .01857 Mdot
.40076 .01956 Mdot
.40096 .01919 Mdot
.40116 .01744 Mdot
.40135 .01617 Mdot
.40155 .01869 Mdot
.40175 .01567 Mdot
.40195 .015 Mdot
.40215 .01615 Mdot
.40235 .01662 Mdot
.40255 .01753 Mdot
.40275 .01587 Mdot
.40295 .01603 Mdot
.40315 .01592 Mdot
.40335 .01657 Mdot
.40355 .01552 Mdot
.40375 .01641 Mdot
.40395 .01749 Mdot
.40415 .01543 Mdot
.40435 .01644 Mdot
.40455 .01868 Mdot
.40474 .01718 Mdot
.40494 .01704 Mdot
.40514 .01748 Mdot
.40534 .01683 Mdot
.40554 .01498 Mdot
.40574 .01726 Mdot
.40594 .01649 Mdot
.40614 .01667 Mdot
.40634 .01502 Mdot
.40654 .01587 Mdot
.40674 .01623 Mdot
.40694 .01642 Mdot
.40714 .01551 Mdot
.40734 .01534 Mdot
.40754 .01492 Mdot
.40774 .0157 Mdot
.40793 .01626 Mdot
.40813 .0151 Mdot
.40833 .01565 Mdot
.40853 .0171 Mdot
.40873 .01714 Mdot
.40893 .01628 Mdot
.40913 .01554 Mdot
.40933 .01738 Mdot
.40953 .01745 Mdot
.40973 .01604 Mdot
.40993 .021 Mdot
.41013 .01809 Mdot
.41033 .01827 Mdot
.41053 .01845 Mdot
.41073 .01678 Mdot
.41093 .01654 Mdot
.41112 .01854 Mdot
.41132 .01701 Mdot
.41152 .01626 Mdot
.41172 .01941 Mdot
.41192 .01534 Mdot
.41212 .01643 Mdot
.41232 .01855 Mdot
.41252 .0165 Mdot
.41272 .01616 Mdot
.41292 .01566 Mdot
.41312 .0163 Mdot
.41332 .01507 Mdot
.41352 .01681 Mdot
.41372 .01644 Mdot
.41392 .01835 Mdot
.41412 .01507 Mdot
.41431 .01644 Mdot
.41451 .01695 Mdot
.41471 .01565 Mdot
.41491 .01621 Mdot
.41511 .0171 Mdot
.41531 .01555 Mdot
.41551 .01705 Mdot
.41571 .0155 Mdot
.41591 .01549 Mdot
.41611 .01627 Mdot
.41631 .01601 Mdot
.41651 .01529 Mdot
.41671 .01604 Mdot
.41691 .01695 Mdot
.41711 .01616 Mdot
.41731 .01498 Mdot
.4175 .01599 Mdot
.4177 .01697 Mdot
.4179 .01718 Mdot
.4181 .01656 Mdot
.4183 .01688 Mdot
.4185 .0164 Mdot
.4187 .01492 Mdot
.4189 .01513 Mdot
.4191 .01772 Mdot
.4193 .01648 Mdot
.4195 .01618 Mdot
.4197 .01612 Mdot
.4199 .01571 Mdot
.4201 .01634 Mdot
.4203 .01532 Mdot
.4205 .01736 Mdot
.42069 .01619 Mdot
.42089 .01596 Mdot
.42109 .01557 Mdot
.42129 .01575 Mdot
.42149 .01594 Mdot
.42169 .01571 Mdot
.42189 .01666 Mdot
.42209 .0157 Mdot
.42229 .01592 Mdot
.42249 .01747 Mdot
.42269 .0164 Mdot
.42289 .01652 Mdot
.42309 .01699 Mdot
.42329 .01694 Mdot
.42349 .01599 Mdot
.42369 .01848 Mdot
.42389 .01557 Mdot
.42408 .01601 Mdot
.42428 .01553 Mdot
.42448 .01627 Mdot
.42468 .01653 Mdot
.42488 .018 Mdot
.42508 .01606 Mdot
.42528 .01637 Mdot
.42548 .01849 Mdot
.42568 .0166 Mdot
.42588 .01805 Mdot
.42608 .01593 Mdot
.42628 .01601 Mdot
.42648 .01716 Mdot
.42668 .01584 Mdot
.42688 .01617 Mdot
.42708 .01829 Mdot
.42727 .0149 Mdot
.42747 .0161 Mdot
.42767 .01815 Mdot
.42787 .01826 Mdot
.42807 .01776 Mdot
.42827 .01525 Mdot
.42847 .01937 Mdot
.42867 .01968 Mdot
.42887 .01745 Mdot
.42907 .01775 Mdot
.42927 .01889 Mdot
.42947 .01985 Mdot
.42967 .01824 Mdot
.42987 .01556 Mdot
.43007 .01722 Mdot
.43027 .01673 Mdot
.43046 .01874 Mdot
.43066 .01682 Mdot
.43086 .01995 Mdot
.43106 .02007 Mdot
.43126 .02078 Mdot
.43146 .01789 Mdot
.43166 .0167 Mdot
.43186 .0204 Mdot
.43206 .02115 Mdot
.43226 .02286 Mdot
.43246 .01752 Mdot
.43266 .01748 Mdot
.43286 .01882 Mdot
.43306 .01853 Mdot
.43326 .01792 Mdot
.43346 .02296 Mdot
.43365 .02633 Mdot
.43385 .02488 Mdot
.43405 .02628 Mdot
.43425 .02374 Mdot
.43445 .01728 Mdot
.43465 .02529 Mdot
.43485 .02826 Mdot
.43505 .0226 Mdot
.43525 .01767 Mdot
.43545 .02398 Mdot
.43565 .02756 Mdot
.43585 .02588 Mdot
.43605 .0225 Mdot
.43625 .02172 Mdot
.43645 .02172 Mdot
.43665 .01837 Mdot
.43684 .02619 Mdot
.43704 .0266 Mdot
.43724 .02596 Mdot
.43744 .01681 Mdot
.43764 .02558 Mdot
.43784 .03607 Mdot
.43804 .03787 Mdot
.43824 .03122 Mdot
.43844 .02421 Mdot
.43864 .01747 Mdot
.43884 .02633 Mdot
.43904 .03185 Mdot
.43924 .03035 Mdot
.43944 .02507 Mdot
.43964 .01996 Mdot
.43984 .01905 Mdot
.44003 .02524 Mdot
.44023 .02192 Mdot
.44043 .02281 Mdot
.44063 .019 Mdot
.44083 .01874 Mdot
.44103 .01652 Mdot
.44123 .01867 Mdot
.44143 .0195 Mdot
.44163 .01815 Mdot
.44183 .01627 Mdot
.44203 .01691 Mdot
.44223 .01584 Mdot
.44243 .01724 Mdot
.44263 .01837 Mdot
.44283 .0183 Mdot
.44303 .01809 Mdot
.44323 .01839 Mdot
.44342 .01606 Mdot
.44362 .01841 Mdot
.44382 .01513 Mdot
.44402 .01572 Mdot
.44422 .01692 Mdot
.44442 .01786 Mdot
.44462 .01614 Mdot
.44482 .01919 Mdot
.44502 .0161 Mdot
.44522 .01731 Mdot
.44542 .01667 Mdot
.44562 .01699 Mdot
.44582 .01696 Mdot
.44602 .01903 Mdot
.44622 .01839 Mdot
.44642 .01814 Mdot
.44661 .01776 Mdot
.44681 .01907 Mdot
.44701 .01795 Mdot
.44721 .01928 Mdot
.44741 .0192 Mdot
.44761 .01734 Mdot
.44781 .02018 Mdot
.44801 .02057 Mdot
.44821 .02182 Mdot
.44841 .02012 Mdot
.44861 .02048 Mdot
.44881 .02099 Mdot
.44901 .0198 Mdot
.44921 .01934 Mdot
.44941 .01899 Mdot
.44961 .01723 Mdot
.4498 .02045 Mdot
.45 .01723 Mdot
.4502 .02032 Mdot
.4504 .02011 Mdot
.4506 .01796 Mdot
.4508 .01776 Mdot
.451 .0174 Mdot
.4512 .01845 Mdot
.4514 .01663 Mdot
.4516 .01653 Mdot
.4518 .01623 Mdot
.452 .01863 Mdot
.4522 .01597 Mdot
.4524 .01685 Mdot
.4526 .01673 Mdot
.4528 .01597 Mdot
.45299 .01631 Mdot
.45319 .01594 Mdot
.45339 .01622 Mdot
.45359 .01673 Mdot
.45379 .0155 Mdot
.45399 .01548 Mdot
.45419 .01663 Mdot
.45439 .01844 Mdot
.45459 .01837 Mdot
.45479 .01537 Mdot
.45499 .01642 Mdot
.45519 .01615 Mdot
.45539 .01771 Mdot
.45559 .01758 Mdot
.45579 .0171 Mdot
.45599 .01632 Mdot
.45618 .01612 Mdot
.45638 .01676 Mdot
.45658 .01619 Mdot
.45678 .01662 Mdot
.45698 .01697 Mdot
.45718 .01557 Mdot
.45738 .01649 Mdot
.45758 .01599 Mdot
.45778 .01702 Mdot
.45798 .01752 Mdot
.45818 .01519 Mdot
.45838 .01619 Mdot
.45858 .01717 Mdot
.45878 .01755 Mdot
.45898 .01805 Mdot
.45918 .01736 Mdot
.45938 .01678 Mdot
.45957 .01587 Mdot
.45977 .01778 Mdot
.45997 .01649 Mdot
.46017 .01572 Mdot
.46037 .01677 Mdot
.46057 .01736 Mdot
.46077 .01821 Mdot
.46097 .0151 Mdot
.46117 .01553 Mdot
.46137 .01841 Mdot
.46157 .01965 Mdot
.46177 .01827 Mdot
.46197 .01605 Mdot
.46217 .01688 Mdot
.46237 .01684 Mdot
.46257 .0168 Mdot
.46276 .0153 Mdot
.46296 .01554 Mdot
.46316 .01589 Mdot
.46336 .01552 Mdot
.46356 .01531 Mdot
.46376 .01778 Mdot
.46396 .01845 Mdot
.46416 .01793 Mdot
.46436 .01736 Mdot
.46456 .01484 Mdot
.46476 .01559 Mdot
.46496 .01735 Mdot
.46516 .01773 Mdot
.46536 .01591 Mdot
.46556 .01629 Mdot
.46576 .01687 Mdot
.46595 .01606 Mdot
.46615 .01833 Mdot
.46635 .01527 Mdot
.46655 .01668 Mdot
.46675 .01531 Mdot
.46695 .01607 Mdot
.46715 .01602 Mdot
.46735 .01556 Mdot
.46755 .01566 Mdot
.46775 .01547 Mdot
.46795 .01579 Mdot
.46815 .01642 Mdot
.46835 .0158 Mdot
.46855 .01584 Mdot
.46875 .01553 Mdot
.46895 .01709 Mdot
.46914 .01729 Mdot
.46934 .01547 Mdot
.46954 .01718 Mdot
.46974 .01624 Mdot
.46994 .01621 Mdot
.47014 .015 Mdot
.47034 .01658 Mdot
.47054 .01993 Mdot
.47074 .01594 Mdot
.47094 .01495 Mdot
.47114 .01834 Mdot
.47134 .01715 Mdot
.47154 .01594 Mdot
.47174 .01644 Mdot
.47194 .01648 Mdot
.47214 .01475 Mdot
.47233 .01732 Mdot
.47253 .01765 Mdot
.47273 .01517 Mdot
.47293 .01532 Mdot
.47313 .01649 Mdot
.47333 .01572 Mdot
.47353 .0153 Mdot
.47373 .01849 Mdot
.47393 .01532 Mdot
.47413 .01644 Mdot
.47433 .01799 Mdot
.47453 .01622 Mdot
.47473 .01706 Mdot
.47493 .0155 Mdot
.47513 .01729 Mdot
.47533 .01902 Mdot
.47552 .01593 Mdot
.47572 .01574 Mdot
.47592 .01848 Mdot
.47612 .01932 Mdot
.47632 .01965 Mdot
.47652 .0179 Mdot
.47672 .022 Mdot
.47692 .02267 Mdot
.47712 .02179 Mdot
.47732 .01735 Mdot
.47752 .02045 Mdot
.47772 .02353 Mdot
.47792 .01974 Mdot
.47812 .02012 Mdot
.47832 .02586 Mdot
.47852 .02 Mdot
.47872 .02078 Mdot
.47891 .0164 Mdot
.47911 .01731 Mdot
.47931 .02243 Mdot
.47951 .02422 Mdot
.47971 .02186 Mdot
.47991 .02489 Mdot
.48011 .02118 Mdot
.48031 .0155 Mdot
.48051 .01829 Mdot
.48071 .01655 Mdot
.48091 .0216 Mdot
.48111 .01544 Mdot
.48131 .01877 Mdot
.48151 .01533 Mdot
.48171 .01877 Mdot
.48191 .02486 Mdot
.4821 .02502 Mdot
.4823 .02185 Mdot
.4825 .02152 Mdot
.4827 .01562 Mdot
.4829 .01741 Mdot
.4831 .02078 Mdot
.4833 .02161 Mdot
.4835 .01739 Mdot
.4837 .01895 Mdot
.4839 .02551 Mdot
.4841 .02851 Mdot
.4843 .02428 Mdot
.4845 .01903 Mdot
.4847 .0151 Mdot
.4849 .0169 Mdot
.4851 .01667 Mdot
.48529 .02302 Mdot
.48549 .02078 Mdot
.48569 .01875 Mdot
.48589 .02132 Mdot
.48609 .03089 Mdot
.48629 .03103 Mdot
.48649 .02564 Mdot
.48669 .02323 Mdot
.48689 .01612 Mdot
.48709 .02496 Mdot
.48729 .02611 Mdot
.48749 .02455 Mdot
.48769 .02086 Mdot
.48789 .01595 Mdot
.48809 .01672 Mdot
.48829 .01992 Mdot
.48848 .02261 Mdot
.48868 .02145 Mdot
.48888 .01836 Mdot
.48908 .01618 Mdot
.48928 .01712 Mdot
.48948 .02033 Mdot
.48968 .01847 Mdot
.48988 .01709 Mdot
.49008 .01811 Mdot
.49028 .01664 Mdot
.49048 .01843 Mdot
.49068 .0188 Mdot
.49088 .01901 Mdot
.49108 .01773 Mdot
.49128 .01671 Mdot
.49148 .01737 Mdot
.49167 .01659 Mdot
.49187 .01754 Mdot
.49207 .01807 Mdot
.49227 .01541 Mdot
.49247 .01752 Mdot
.49267 .01598 Mdot
.49287 .01617 Mdot
.49307 .0185 Mdot
.49327 .0162 Mdot
.49347 .01795 Mdot
.49367 .01654 Mdot
.49387 .01973 Mdot
.49407 .01735 Mdot
.49427 .0185 Mdot
.49447 .01994 Mdot
.49467 .01693 Mdot
.49486 .01734 Mdot
.49506 .0163 Mdot
.49526 .01503 Mdot
.49546 .01679 Mdot
.49566 .01784 Mdot
.49586 .01632 Mdot
.49606 .01713 Mdot
.49626 .01689 Mdot
.49646 .01705 Mdot
.49666 .01727 Mdot
.49686 .01526 Mdot
.49706 .01781 Mdot
.49726 .01591 Mdot
.49746 .01732 Mdot
.49766 .01658 Mdot
.49786 .01669 Mdot
.49806 .0157 Mdot
.49825 .01717 Mdot
.49845 .01646 Mdot
.49865 .01658 Mdot
.49885 .01825 Mdot
.49905 .01955 Mdot
.49925 .01686 Mdot
.49945 .01766 Mdot
.49965 .01947 Mdot
.49985 .02047 Mdot
.50005 .01966 Mdot
.50025 .01808 Mdot
.50045 .01573 Mdot
.50065 .01697 Mdot
.50085 .01652 Mdot
.50105 .01517 Mdot
.50125 .01563 Mdot
.50144 .01633 Mdot
.50164 .01808 Mdot
.50184 .01715 Mdot
.50204 .01537 Mdot
.50224 .0153 Mdot
.50244 .01607 Mdot
.50264 .01674 Mdot
.50284 .01567 Mdot
.50304 .01558 Mdot
.50324 .01614 Mdot
.50344 .01624 Mdot
.50364 .01501 Mdot
.50384 .01545 Mdot
.50404 .01606 Mdot
.50424 .01622 Mdot
.50444 .01547 Mdot
.50463 .01697 Mdot
.50483 .01542 Mdot
.50503 .01594 Mdot
.50523 .01494 Mdot
.50543 .01568 Mdot
.50563 .01566 Mdot
.50583 .01654 Mdot
.50603 .01633 Mdot
.50623 .0163 Mdot
.50643 .01577 Mdot
.50663 .01582 Mdot
.50683 .01782 Mdot
.50703 .01544 Mdot
.50723 .01647 Mdot
.50743 .01642 Mdot
.50763 .01543 Mdot
.50782 .01744 Mdot
.50802 .01695 Mdot
.50822 .01682 Mdot
.50842 .01569 Mdot
.50862 .01543 Mdot
.50882 .01642 Mdot
.50902 .01631 Mdot
.50922 .01624 Mdot
.50942 .01499 Mdot
.50962 .01657 Mdot
.50982 .01617 Mdot
.51002 .01582 Mdot
.51022 .01719 Mdot
.51042 .0169 Mdot
.51062 .01749 Mdot
.51082 .01755 Mdot
.51101 .01514 Mdot
.51121 .01529 Mdot
.51141 .01781 Mdot
.51161 .01586 Mdot
.51181 .01566 Mdot
.51201 .01845 Mdot
.51221 .01495 Mdot
.51241 .01667 Mdot
.51261 .01617 Mdot
.51281 .01547 Mdot
.51301 .01713 Mdot
.51321 .01537 Mdot
.51341 .01599 Mdot
.51361 .01592 Mdot
.51381 .01576 Mdot
.51401 .01605 Mdot
.5142 .0162 Mdot
.5144 .01668 Mdot
.5146 .01538 Mdot
.5148 .01517 Mdot
.515 .01517 Mdot
.5152 .01745 Mdot
.5154 .01796 Mdot
.5156 .01703 Mdot
.5158 .01601 Mdot
.516 .01692 Mdot
.5162 .01796 Mdot
.5164 .01613 Mdot
.5166 .01737 Mdot
.5168 .015 Mdot
.517 .01547 Mdot
.5172 .017 Mdot
.5174 .01601 Mdot
.51759 .01549 Mdot
.51779 .01799 Mdot
.51799 .01778 Mdot
.51819 .01515 Mdot
.51839 .01504 Mdot
.51859 .01563 Mdot
.51879 .0179 Mdot
.51899 .01609 Mdot
.51919 .01631 Mdot
.51939 .01709 Mdot
.51959 .01827 Mdot
.51979 .01754 Mdot
.51999 .02243 Mdot
.52019 .01846 Mdot
.52039 .01726 Mdot
.52059 .01569 Mdot
.52078 .01609 Mdot
.52098 .01637 Mdot
.52118 .01648 Mdot
.52138 .01503 Mdot
.52158 .01679 Mdot
.52178 .01706 Mdot
.52198 .01711 Mdot
.52218 .01622 Mdot
.52238 .01556 Mdot
.52258 .01759 Mdot
.52278 .01576 Mdot
.52298 .01624 Mdot
.52318 .0176 Mdot
.52338 .01563 Mdot
.52358 .01735 Mdot
.52378 .01681 Mdot
.52397 .01613 Mdot
.52417 .01803 Mdot
.52437 .01788 Mdot
.52457 .0175 Mdot
.52477 .01716 Mdot
.52497 .0189 Mdot
.52517 .02047 Mdot
.52537 .01867 Mdot
.52557 .01593 Mdot
.52577 .0175 Mdot
.52597 .02161 Mdot
.52617 .02074 Mdot
.52637 .0179 Mdot
.52657 .0185 Mdot
.52677 .0216 Mdot
.52697 .02173 Mdot
.52716 .0178 Mdot
.52736 .01757 Mdot
.52756 .01775 Mdot
.52776 .01793 Mdot
.52796 .01882 Mdot
.52816 .01603 Mdot
.52836 .01701 Mdot
.52856 .02019 Mdot
.52876 .01618 Mdot
.52896 .01776 Mdot
.52916 .0204 Mdot
.52936 .01733 Mdot
.52956 .01986 Mdot
.52976 .01782 Mdot
.52996 .01704 Mdot
.53016 .02007 Mdot
.53035 .02251 Mdot
.53055 .01846 Mdot
.53075 .02299 Mdot
.53095 .02105 Mdot
.53115 .01783 Mdot
.53135 .01621 Mdot
.53155 .01602 Mdot
.53175 .01822 Mdot
.53195 .01764 Mdot
.53215 .02149 Mdot
.53235 .02282 Mdot
.53255 .02144 Mdot
.53275 .01818 Mdot
.53295 .01606 Mdot
.53315 .02031 Mdot
.53335 .01767 Mdot
.53354 .01566 Mdot
.53374 .01518 Mdot
.53394 .01973 Mdot
.53414 .01531 Mdot
.53434 .02425 Mdot
.53454 .02318 Mdot
.53474 .0218 Mdot
.53494 .02034 Mdot
.53514 .01841 Mdot
.53534 .01932 Mdot
.53554 .02469 Mdot
.53574 .02555 Mdot
.53594 .02305 Mdot
.53614 .01731 Mdot
.53634 .01702 Mdot
.53654 .02068 Mdot
.53674 .02221 Mdot
.53693 .01944 Mdot
.53713 .01781 Mdot
.53733 .01667 Mdot
.53753 .02012 Mdot
.53773 .01646 Mdot
.53793 .01923 Mdot
.53813 .01754 Mdot
.53833 .01874 Mdot
.53853 .0153 Mdot
.53873 .01703 Mdot
.53893 .01849 Mdot
.53913 .0186 Mdot
.53933 .01746 Mdot
.53953 .01671 Mdot
.53973 .01521 Mdot
.53993 .01783 Mdot
.54012 .01586 Mdot
.54032 .01616 Mdot
.54052 .01773 Mdot
.54072 .01678 Mdot
.54092 .01701 Mdot
.54112 .01705 Mdot
.54132 .01601 Mdot
.54152 .01592 Mdot
.54172 .01699 Mdot
.54192 .01697 Mdot
.54212 .01792 Mdot
.54232 .01711 Mdot
.54252 .01664 Mdot
.54272 .01716 Mdot
.54292 .01582 Mdot
.54312 .01535 Mdot
.54331 .01684 Mdot
.54351 .01642 Mdot
.54371 .01499 Mdot
.54391 .01679 Mdot
.54411 .01856 Mdot
.54431 .01526 Mdot
.54451 .01617 Mdot
.54471 .01532 Mdot
.54491 .01497 Mdot
.54511 .01593 Mdot
.54531 .0167 Mdot
.54551 .01624 Mdot
.54571 .01688 Mdot
.54591 .01522 Mdot
.54611 .02486 Mdot
.54631 .01806 Mdot
.5465 .01878 Mdot
.5467 .01617 Mdot
.5469 .01836 Mdot
.5471 .01726 Mdot
.5473 .01806 Mdot
.5475 .01643 Mdot
.5477 .01643 Mdot
.5479 .017 Mdot
.5481 .01593 Mdot
.5483 .01631 Mdot
.5485 .01656 Mdot
.5487 .01705 Mdot
.5489 .01573 Mdot
.5491 .01748 Mdot
.5493 .01795 Mdot
.5495 .01716 Mdot
.54969 .01698 Mdot
.54989 .01731 Mdot
.55009 .01672 Mdot
.55029 .0177 Mdot
.55049 .01927 Mdot
.55069 .01816 Mdot
.55089 .01672 Mdot
.55109 .01658 Mdot
.55129 .01667 Mdot
.55149 .01593 Mdot
.55169 .01584 Mdot
.55189 .0157 Mdot
.55209 .01579 Mdot
.55229 .01519 Mdot
.55249 .01658 Mdot
.55269 .01592 Mdot
.55288 .01552 Mdot
.55308 .01636 Mdot
.55328 .01524 Mdot
.55348 .01617 Mdot
.55368 .01595 Mdot
.55388 .0157 Mdot
.55408 .01655 Mdot
.55428 .01648 Mdot
.55448 .01535 Mdot
.55468 .01571 Mdot
.55488 .01625 Mdot
.55508 .01735 Mdot
.55528 .01653 Mdot
.55548 .01583 Mdot
.55568 .01572 Mdot
.55588 .01578 Mdot
.55608 .01658 Mdot
.55627 .01627 Mdot
.55647 .01575 Mdot
.55667 .0165 Mdot
.55687 .01609 Mdot
.55707 .01619 Mdot
.55727 .01569 Mdot
.55747 .01549 Mdot
.55767 .01681 Mdot
.55787 .01532 Mdot
.55807 .01648 Mdot
.55827 .0164 Mdot
.55847 .01592 Mdot
.55867 .01529 Mdot
.55887 .01612 Mdot
.55907 .01784 Mdot
.55927 .01609 Mdot
.55946 .01594 Mdot
.55966 .01985 Mdot
.55986 .02224 Mdot
.56006 .01873 Mdot
.56026 .01889 Mdot
.56046 .0165 Mdot
.56066 .0158 Mdot
.56086 .01695 Mdot
.56106 .016 Mdot
.56126 .01649 Mdot
.56146 .01634 Mdot
.56166 .01619 Mdot
.56186 .0162 Mdot
.56206 .01506 Mdot
.56226 .01701 Mdot
.56246 .01524 Mdot
.56265 .01568 Mdot
.56285 .01547 Mdot
.56305 .0163 Mdot
.56325 .01736 Mdot
.56345 .01833 Mdot
.56365 .01607 Mdot
.56385 .01662 Mdot
.56405 .01512 Mdot
.56425 .01675 Mdot
.56445 .01712 Mdot
.56465 .01607 Mdot
.56485 .01626 Mdot
.56505 .0152 Mdot
.56525 .01574 Mdot
.56545 .01622 Mdot
.56565 .01502 Mdot
.56584 .01543 Mdot
.56604 .01624 Mdot
.56624 .01589 Mdot
.56644 .01687 Mdot
.56664 .01652 Mdot
.56684 .01713 Mdot
.56704 .01574 Mdot
.56724 .0153 Mdot
.56744 .01544 Mdot
.56764 .01683 Mdot
.56784 .01678 Mdot
.56804 .01602 Mdot
.56824 .01709 Mdot
.56844 .0151 Mdot
.56864 .01628 Mdot
.56884 .0165 Mdot
.56903 .0152 Mdot
.56923 .01962 Mdot
.56943 .01643 Mdot
.56963 .01643 Mdot
.56983 .01568 Mdot
.57003 .01799 Mdot
.57023 .01567 Mdot
.57043 .01579 Mdot
.57063 .01652 Mdot
.57083 .01615 Mdot
.57103 .0177 Mdot
.57123 .01547 Mdot
.57143 .01815 Mdot
.57163 .01677 Mdot
.57183 .01641 Mdot
.57203 .01513 Mdot
.57222 .01731 Mdot
.57242 .01597 Mdot
.57262 .01619 Mdot
.57282 .0159 Mdot
.57302 .01729 Mdot
.57322 .01592 Mdot
.57342 .0186 Mdot
.57362 .01817 Mdot
.57382 .01524 Mdot
.57402 .01737 Mdot
.57422 .01733 Mdot
.57442 .01705 Mdot
.57462 .01738 Mdot
.57482 .01782 Mdot
.57502 .01643 Mdot
.57522 .01857 Mdot
.57542 .01728 Mdot
.57561 .01527 Mdot
.57581 .01547 Mdot
.57601 .01562 Mdot
.57621 .01917 Mdot
.57641 .0173 Mdot
.57661 .01621 Mdot
.57681 .01843 Mdot
.57701 .01747 Mdot
.57721 .01538 Mdot
.57741 .01879 Mdot
.57761 .02019 Mdot
.57781 .02039 Mdot
.57801 .01902 Mdot
.57821 .01691 Mdot
.57841 .01636 Mdot
.57861 .01897 Mdot
.5788 .01993 Mdot
.579 .0169 Mdot
.5792 .02028 Mdot
.5794 .01786 Mdot
.5796 .01751 Mdot
.5798 .01801 Mdot
.58 .01736 Mdot
.5802 .01596 Mdot
.5804 .01517 Mdot
.5806 .01902 Mdot
.5808 .01685 Mdot
.581 .01775 Mdot
.5812 .01736 Mdot
.5814 .01588 Mdot
.5816 .0168 Mdot
.5818 .01721 Mdot
.58199 .01651 Mdot
.58219 .01629 Mdot
.58239 .01548 Mdot
.58259 .01717 Mdot
.58279 .01657 Mdot
.58299 .01879 Mdot
.58319 .01808 Mdot
.58339 .01607 Mdot
.58359 .01567 Mdot
.58379 .02086 Mdot
.58399 .02036 Mdot
.58419 .01893 Mdot
.58439 .01748 Mdot
.58459 .01759 Mdot
.58479 .01943 Mdot
.58499 .01891 Mdot
.58518 .01905 Mdot
.58538 .01922 Mdot
.58558 .01566 Mdot
.58578 .01888 Mdot
.58598 .01784 Mdot
.58618 .01764 Mdot
.58638 .01486 Mdot
.58658 .01693 Mdot
.58678 .01621 Mdot
.58698 .01567 Mdot
.58718 .01733 Mdot
.58738 .01816 Mdot
.58758 .01549 Mdot
.58778 .01652 Mdot
.58798 .01558 Mdot
.58818 .01668 Mdot
.58837 .01686 Mdot
.58857 .01718 Mdot
.58877 .01601 Mdot
.58897 .01585 Mdot
.58917 .01547 Mdot
.58937 .01622 Mdot
.58957 .01737 Mdot
.58977 .01622 Mdot
.58997 .01717 Mdot
.59017 .01765 Mdot
.59037 .01746 Mdot
.59057 .01601 Mdot
.59077 .01565 Mdot
.59097 .01577 Mdot
.59117 .0157 Mdot
.59137 .01722 Mdot
.59156 .01717 Mdot
.59176 .01586 Mdot
.59196 .01708 Mdot
.59216 .01622 Mdot
.59236 .0157 Mdot
.59256 .01636 Mdot
.59276 .01636 Mdot
.59296 .01741 Mdot
.59316 .01474 Mdot
.59336 .01532 Mdot
.59356 .01737 Mdot
.59376 .0161 Mdot
.59396 .01582 Mdot
.59416 .01592 Mdot
.59436 .0163 Mdot
.59456 .01698 Mdot
.59476 .0165 Mdot
.59495 .0152 Mdot
.59515 .01672 Mdot
.59535 .01592 Mdot
.59555 .01604 Mdot
.59575 .01529 Mdot
.59595 .01711 Mdot
.59615 .01584 Mdot
.59635 .0176 Mdot
.59655 .01578 Mdot
.59675 .01691 Mdot
.59695 .01667 Mdot
.59715 .01849 Mdot
.59735 .01605 Mdot
.59755 .01772 Mdot
.59775 .01574 Mdot
.59795 .01628 Mdot
.59814 .01644 Mdot
.59834 .01605 Mdot
.59854 .0162 Mdot
.59874 .01646 Mdot
.59894 .01657 Mdot
.59914 .0169 Mdot
.59934 .01603 Mdot
.59954 .01538 Mdot
.59974 .01477 Mdot
.59994 .02396 Mdot
.60014 .01837 Mdot
.60034 .01647 Mdot
.60054 .01841 Mdot
.60074 .01633 Mdot
.60094 .01544 Mdot
.60114 .01537 Mdot
.60133 .0157 Mdot
.60153 .01774 Mdot
.60173 .01669 Mdot
.60193 .01507 Mdot
.60213 .01633 Mdot
.60233 .01549 Mdot
.60253 .01636 Mdot
.60273 .01609 Mdot
.60293 .0154 Mdot
.60313 .01583 Mdot
.60333 .01488 Mdot
.60353 .01511 Mdot
.60373 .01561 Mdot
.60393 .01593 Mdot
.60413 .01592 Mdot
.60433 .01513 Mdot
.60452 .01542 Mdot
.60472 .01564 Mdot
.60492 .01662 Mdot
.60512 .01653 Mdot
.60532 .01641 Mdot
.60552 .01488 Mdot
.60572 .01566 Mdot
.60592 .01554 Mdot
.60612 .01597 Mdot
.60632 .01579 Mdot
.60652 .01522 Mdot
.60672 .01549 Mdot
.60692 .01519 Mdot
.60712 .0162 Mdot
.60732 .01673 Mdot
.60752 .01521 Mdot
.60771 .01517 Mdot
.60791 .0157 Mdot
.60811 .01543 Mdot
.60831 .01579 Mdot
.60851 .0174 Mdot
.60871 .01631 Mdot
.60891 .01547 Mdot
.60911 .01699 Mdot
.60931 .01556 Mdot
.60951 .01715 Mdot
.60971 .0154 Mdot
.60991 .01496 Mdot
.61011 .01674 Mdot
.61031 .01536 Mdot
.61051 .0156 Mdot
.61071 .0185 Mdot
.6109 .01701 Mdot
.6111 .01561 Mdot
.6113 .01675 Mdot
.6115 .01601 Mdot
.6117 .01675 Mdot
.6119 .0178 Mdot
.6121 .01687 Mdot
.6123 .01538 Mdot
.6125 .01634 Mdot
.6127 .01622 Mdot
.6129 .01578 Mdot
.6131 .01529 Mdot
.6133 .01507 Mdot
.6135 .01593 Mdot
.6137 .01652 Mdot
.6139 .01606 Mdot
.6141 .01728 Mdot
.61429 .01615 Mdot
.61449 .0163 Mdot
.61469 .01676 Mdot
.61489 .01584 Mdot
.61509 .01539 Mdot
.61529 .01631 Mdot
.61549 .01677 Mdot
.61569 .01496 Mdot
.61589 .01687 Mdot
.61609 .01686 Mdot
.61629 .01752 Mdot
.61649 .0152 Mdot
.61669 .01642 Mdot
.61689 .01665 Mdot
.61709 .01662 Mdot
.61729 .01681 Mdot
.61748 .01773 Mdot
.61768 .01671 Mdot
.61788 .0157 Mdot
.61808 .01555 Mdot
.61828 .01763 Mdot
.61848 .01657 Mdot
.61868 .01595 Mdot
.61888 .01531 Mdot
.61908 .01844 Mdot
.61928 .01947 Mdot
.61948 .0184 Mdot
.61968 .01585 Mdot
.61988 .01859 Mdot
.62008 .02227 Mdot
.62028 .01864 Mdot
.62048 .01627 Mdot
.62067 .01955 Mdot
.62087 .02254 Mdot
.62107 .02154 Mdot
.62127 .01626 Mdot
.62147 .01876 Mdot
.62167 .02022 Mdot
.62187 .0213 Mdot
.62207 .01861 Mdot
.62227 .01875 Mdot
.62247 .02099 Mdot
.62267 .01864 Mdot
.62287 .01957 Mdot
.62307 .01652 Mdot
.62327 .01566 Mdot
.62347 .01835 Mdot
.62367 .01486 Mdot
.62386 .01737 Mdot
.62406 .01739 Mdot
.62426 .01716 Mdot
.62446 .01712 Mdot
.62466 .01482 Mdot
.62486 .01681 Mdot
.62506 .01818 Mdot
.62526 .02177 Mdot
.62546 .01943 Mdot
.62566 .01566 Mdot
.62586 .02147 Mdot
.62606 .02088 Mdot
.62626 .01798 Mdot
.62646 .0199 Mdot
.62666 .02034 Mdot
.62686 .01609 Mdot
.62705 .01691 Mdot
.62725 .01655 Mdot
.62745 .01644 Mdot
.62765 .01774 Mdot
.62785 .01964 Mdot
.62805 .02091 Mdot
.62825 .01932 Mdot
.62845 .01963 Mdot
.62865 .01795 Mdot
.62885 .015 Mdot
.62905 .01708 Mdot
.62925 .01827 Mdot
.62945 .01756 Mdot
.62965 .01593 Mdot
.62985 .01929 Mdot
.63005 .02341 Mdot
.63024 .02159 Mdot
.63044 .01666 Mdot
.63064 .01975 Mdot
.63084 .01618 Mdot
.63104 .01725 Mdot
.63124 .01577 Mdot
.63144 .01788 Mdot
.63164 .01726 Mdot
.63184 .01626 Mdot
.63204 .01746 Mdot
.63224 .02032 Mdot
.63244 .02125 Mdot
.63264 .02113 Mdot
.63284 .01647 Mdot
.63304 .01663 Mdot
.63324 .0215 Mdot
.63344 .02228 Mdot
.63363 .02077 Mdot
.63383 .0172 Mdot
.63403 .01608 Mdot
.63423 .01663 Mdot
.63443 .02237 Mdot
.63463 .02087 Mdot
.63483 .01916 Mdot
.63503 .01657 Mdot
.63523 .01899 Mdot
.63543 .01814 Mdot
.63563 .01898 Mdot
.63583 .01801 Mdot
.63603 .01997 Mdot
.63623 .016 Mdot
.63643 .01667 Mdot
.63663 .01617 Mdot
.63682 .01548 Mdot
.63702 .016 Mdot
.63722 .01571 Mdot
.63742 .0164 Mdot
.63762 .01604 Mdot
.63782 .01761 Mdot
.63802 .01679 Mdot
.63822 .01659 Mdot
.63842 .01584 Mdot
.63862 .01657 Mdot
.63882 .01617 Mdot
.63902 .0158 Mdot
.63922 .01527 Mdot
.63942 .01601 Mdot
.63962 .01665 Mdot
.63982 .01872 Mdot
.64001 .01864 Mdot
.64021 .01889 Mdot
.64041 .0166 Mdot
.64061 .01598 Mdot
.64081 .01493 Mdot
.64101 .01771 Mdot
.64121 .01804 Mdot
.64141 .01649 Mdot
.64161 .01674 Mdot
.64181 .01537 Mdot
.64201 .0189 Mdot
.64221 .01936 Mdot
.64241 .01532 Mdot
.64261 .01655 Mdot
.64281 .01698 Mdot
.64301 .01538 Mdot
.6432 .01765 Mdot
.6434 .01624 Mdot
.6436 .01782 Mdot
.6438 .01665 Mdot
.644 .01524 Mdot
.6442 .01524 Mdot
.6444 .01514 Mdot
.6446 .0163 Mdot
.6448 .0162 Mdot
.645 .01492 Mdot
.6452 .01772 Mdot
.6454 .01592 Mdot
.6456 .0151 Mdot
.6458 .01515 Mdot
.646 .01558 Mdot
.6462 .01576 Mdot
.64639 .01666 Mdot
.64659 .01552 Mdot
.64679 .01666 Mdot
.64699 .01586 Mdot
.64719 .01768 Mdot
.64739 .01603 Mdot
.64759 .01563 Mdot
.64779 .01642 Mdot
.64799 .01592 Mdot
.64819 .01666 Mdot
.64839 .01644 Mdot
.64859 .0176 Mdot
.64879 .01686 Mdot
.64899 .01658 Mdot
.64919 .0177 Mdot
.64939 .01867 Mdot
.64958 .01877 Mdot
.64978 .01707 Mdot
.64998 .01658 Mdot
.65018 .01774 Mdot
.65038 .01612 Mdot
.65058 .01669 Mdot
.65078 .01658 Mdot
.65098 .01607 Mdot
.65118 .01741 Mdot
.65138 .0161 Mdot
.65158 .01777 Mdot
.65178 .01697 Mdot
.65198 .01584 Mdot
.65218 .01795 Mdot
.65238 .01568 Mdot
.65258 .01539 Mdot
.65278 .0156 Mdot
.65297 .01619 Mdot
.65317 .01508 Mdot
.65337 .01535 Mdot
.65357 .01663 Mdot
.65377 .01684 Mdot
.65397 .01526 Mdot
.65417 .01584 Mdot
.65437 .01682 Mdot
.65457 .0174 Mdot
.65477 .01653 Mdot
.65497 .0157 Mdot
.65517 .01677 Mdot
.65537 .01606 Mdot
.65557 .01622 Mdot
.65577 .0168 Mdot
.65597 .01643 Mdot
.65616 .01596 Mdot
.65636 .01507 Mdot
.65656 .01509 Mdot
.65676 .01619 Mdot
.65696 .01683 Mdot
.65716 .01516 Mdot
.65736 .01658 Mdot
.65756 .01604 Mdot
.65776 .01564 Mdot
.65796 .01643 Mdot
.65816 .01568 Mdot
.65836 .01526 Mdot
.65856 .01716 Mdot
.65876 .01742 Mdot
.65896 .01488 Mdot
.65916 .01774 Mdot
.65935 .01726 Mdot
.65955 .01593 Mdot
.65975 .01761 Mdot
.65995 .01687 Mdot
.66015 .01623 Mdot
.66035 .01617 Mdot
.66055 .01821 Mdot
.66075 .01943 Mdot
.66095 .01526 Mdot
.66115 .01614 Mdot
.66135 .01703 Mdot
.66155 .01777 Mdot
.66175 .01661 Mdot
.66195 .01486 Mdot
.66215 .01509 Mdot
.66235 .01533 Mdot
.66254 .01603 Mdot
.66274 .01522 Mdot
.66294 .01631 Mdot
.66314 .01699 Mdot
.66334 .01597 Mdot
.66354 .01749 Mdot
.66374 .01629 Mdot
.66394 .01633 Mdot
.66414 .01629 Mdot
.66434 .01788 Mdot
.66454 .01842 Mdot
.66474 .01561 Mdot
.66494 .01574 Mdot
.66514 .01504 Mdot
.66534 .01649 Mdot
.66554 .01534 Mdot
.66573 .01697 Mdot
.66593 .01786 Mdot
.66613 .01539 Mdot
.66633 .01657 Mdot
.66653 .01712 Mdot
.66673 .02158 Mdot
.66693 .01507 Mdot
.66713 .01774 Mdot
.66733 .01813 Mdot
.66753 .02066 Mdot
.66773 .01984 Mdot
.66793 .01744 Mdot
.66813 .01976 Mdot
.66833 .02246 Mdot
.66853 .01881 Mdot
.66873 .01852 Mdot
.66892 .02281 Mdot
.66912 .02397 Mdot
.66932 .01762 Mdot
.66952 .01931 Mdot
.66972 .01864 Mdot
.66992 .0224 Mdot
.67012 .02381 Mdot
.67032 .0186 Mdot
.67052 .02142 Mdot
.67072 .02233 Mdot
.67092 .01852 Mdot
.67112 .02251 Mdot
.67132 .01925 Mdot
.67152 .01828 Mdot
.67172 .01713 Mdot
.67192 .01686 Mdot
.67212 .01793 Mdot
.67231 .01826 Mdot
.67251 .02017 Mdot
.67271 .01901 Mdot
.67291 .01711 Mdot
.67311 .01906 Mdot
.67331 .02294 Mdot
.67351 .02346 Mdot
.67371 .02264 Mdot
.67391 .01842 Mdot
.67411 .01765 Mdot
.67431 .02517 Mdot
.67451 .01962 Mdot
.67471 .02213 Mdot
.67491 .02151 Mdot
.67511 .01919 Mdot
.67531 .01985 Mdot
.6755 .0174 Mdot
.6757 .01644 Mdot
.6759 .01994 Mdot
.6761 .02221 Mdot
.6763 .02413 Mdot
.6765 .02132 Mdot
.6767 .02545 Mdot
.6769 .02205 Mdot
.6771 .02112 Mdot
.6773 .01925 Mdot
.6775 .01889 Mdot
.6777 .01803 Mdot
.6779 .01652 Mdot
.6781 .02257 Mdot
.6783 .02443 Mdot
.6785 .02464 Mdot
.67869 .01956 Mdot
.67889 .0204 Mdot
.67909 .01731 Mdot
.67929 .01875 Mdot
.67949 .0188 Mdot
.67969 .01647 Mdot
.67989 .02307 Mdot
.68009 .01705 Mdot
.68029 .0197 Mdot
.68049 .02101 Mdot
.68069 .02367 Mdot
.68089 .02357 Mdot
.68109 .01836 Mdot
.68129 .01901 Mdot
.68149 .0258 Mdot
.68169 .02756 Mdot
.68188 .0227 Mdot
.68208 .01831 Mdot
.68228 .01719 Mdot
.68248 .02148 Mdot
.68268 .02213 Mdot
.68288 .02205 Mdot
.68308 .02142 Mdot
.68328 .02306 Mdot
.68348 .01766 Mdot
.68368 .02138 Mdot
.68388 .02002 Mdot
.68408 .01987 Mdot
.68428 .01616 Mdot
.68448 .02001 Mdot
.68468 .02067 Mdot
.68488 .019 Mdot
.68507 .01918 Mdot
.68527 .01708 Mdot
.68547 .01602 Mdot
.68567 .01753 Mdot
.68587 .0166 Mdot
.68607 .01743 Mdot
.68627 .01559 Mdot
.68647 .01684 Mdot
.68667 .01486 Mdot
.68687 .01795 Mdot
.68707 .01643 Mdot
.68727 .01569 Mdot
.68747 .01583 Mdot
.68767 .01583 Mdot
.68787 .01547 Mdot
.68807 .01523 Mdot
.68826 .01681 Mdot
.68846 .01544 Mdot
.68866 .01719 Mdot
.68886 .01597 Mdot
.68906 .0162 Mdot
.68926 .01565 Mdot
.68946 .01542 Mdot
.68966 .01845 Mdot
.68986 .01637 Mdot
.69006 .01544 Mdot
.69026 .01622 Mdot
.69046 .01631 Mdot
.69066 .01571 Mdot
.69086 .01704 Mdot
.69106 .01536 Mdot
.69126 .01602 Mdot
.69146 .01845 Mdot
.69165 .01594 Mdot
.69185 .01756 Mdot
.69205 .01525 Mdot
.69225 .01729 Mdot
.69245 .016 Mdot
.69265 .01609 Mdot
.69285 .01582 Mdot
.69305 .01628 Mdot
.69325 .01623 Mdot
.69345 .01694 Mdot
.69365 .01689 Mdot
.69385 .01582 Mdot
.69405 .01724 Mdot
.69425 .01565 Mdot
.69445 .01608 Mdot
.69465 .01702 Mdot
.69484 .01634 Mdot
.69504 .01739 Mdot
.69524 .01715 Mdot
.69544 .01494 Mdot
.69564 .01637 Mdot
.69584 .01651 Mdot
.69604 .01641 Mdot
.69624 .01731 Mdot
.69644 .01827 Mdot
.69664 .01548 Mdot
.69684 .01567 Mdot
.69704 .01603 Mdot
.69724 .01814 Mdot
.69744 .01665 Mdot
.69764 .01657 Mdot
.69784 .0179 Mdot
.69803 .01586 Mdot
.69823 .01723 Mdot
.69843 .01508 Mdot
.69863 .01684 Mdot
.69883 .01751 Mdot
.69903 .01665 Mdot
.69923 .01601 Mdot
.69943 .01795 Mdot
.69963 .01745 Mdot
.69983 .01495 Mdot
.70003 .0189 Mdot
.70023 .01833 Mdot
.70043 .0213 Mdot
.70063 .01792 Mdot
.70083 .01909 Mdot
.70103 .01744 Mdot
.70122 .02124 Mdot
.70142 .01685 Mdot
.70162 .01533 Mdot
.70182 .01697 Mdot
.70202 .01608 Mdot
.70222 .01694 Mdot
.70242 .01609 Mdot
.70262 .01492 Mdot
.70282 .01554 Mdot
.70302 .01671 Mdot
.70322 .0165 Mdot
.70342 .01605 Mdot
.70362 .01546 Mdot
.70382 .01612 Mdot
.70402 .01566 Mdot
.70422 .01594 Mdot
.70441 .01595 Mdot
.70461 .01666 Mdot
.70481 .01685 Mdot
.70501 .01723 Mdot
.70521 .01558 Mdot
.70541 .01774 Mdot
.70561 .01629 Mdot
.70581 .01559 Mdot
.70601 .01652 Mdot
.70621 .01475 Mdot
.70641 .01539 Mdot
.70661 .01672 Mdot
.70681 .01541 Mdot
.70701 .01658 Mdot
.70721 .01643 Mdot
.70741 .01634 Mdot
.7076 .0166 Mdot
.7078 .01643 Mdot
.708 .01653 Mdot
.7082 .015 Mdot
.7084 .016 Mdot
.7086 .01623 Mdot
.7088 .01698 Mdot
.709 .01613 Mdot
.7092 .01663 Mdot
.7094 .01524 Mdot
.7096 .01793 Mdot
.7098 .01639 Mdot
.71 .01648 Mdot
.7102 .01685 Mdot
.7104 .01645 Mdot
.7106 .01781 Mdot
.7108 .01634 Mdot
.71099 .01512 Mdot
.71119 .01685 Mdot
.71139 .01611 Mdot
.71159 .01588 Mdot
.71179 .0157 Mdot
.71199 .0152 Mdot
.71219 .01517 Mdot
.71239 .01517 Mdot
.71259 .01671 Mdot
.71279 .01488 Mdot
.71299 .01658 Mdot
.71319 .01947 Mdot
.71339 .01552 Mdot
.71359 .01755 Mdot
.71379 .01709 Mdot
.71399 .01865 Mdot
.71418 .01786 Mdot
.71438 .0187 Mdot
.71458 .01563 Mdot
.71478 .01708 Mdot
.71498 .01954 Mdot
.71518 .01627 Mdot
.71538 .01772 Mdot
.71558 .02039 Mdot
.71578 .02135 Mdot
.71598 .02331 Mdot
.71618 .01723 Mdot
.71638 .02122 Mdot
.71658 .02251 Mdot
.71678 .01897 Mdot
.71698 .0182 Mdot
.71718 .01794 Mdot
.71737 .02248 Mdot
.71757 .02374 Mdot
.71777 .02087 Mdot
.71797 .01685 Mdot
.71817 .0182 Mdot
.71837 .02028 Mdot
.71857 .01802 Mdot
.71877 .02499 Mdot
.71897 .01672 Mdot
.71917 .01709 Mdot
.71937 .01666 Mdot
.71957 .01659 Mdot
.71977 .02337 Mdot
.71997 .0219 Mdot
.72017 .01791 Mdot
.72037 .01732 Mdot
.72056 .0153 Mdot
.72076 .02449 Mdot
.72096 .02442 Mdot
.72116 .02061 Mdot
.72136 .01918 Mdot
.72156 .02074 Mdot
.72176 .02172 Mdot
.72196 .02531 Mdot
.72216 .02258 Mdot
.72236 .01992 Mdot
.72256 .02383 Mdot
.72276 .02082 Mdot
.72296 .01868 Mdot
.72316 .01876 Mdot
.72336 .02382 Mdot
.72356 .02252 Mdot
.72375 .02149 Mdot
.72395 .01971 Mdot
.72415 .01714 Mdot
.72435 .01825 Mdot
.72455 .02383 Mdot
.72475 .02364 Mdot
.72495 .02134 Mdot
.72515 .01969 Mdot
.72535 .02358 Mdot
.72555 .02126 Mdot
.72575 .01983 Mdot
.72595 .01926 Mdot
.72615 .01978 Mdot
.72635 .01563 Mdot
.72655 .01843 Mdot
.72675 .02105 Mdot
.72694 .02054 Mdot
.72714 .01935 Mdot
.72734 .01613 Mdot
.72754 .02144 Mdot
.72774 .02318 Mdot
.72794 .01831 Mdot
.72814 .01898 Mdot
.72834 .01943 Mdot
.72854 .01908 Mdot
.72874 .02097 Mdot
.72894 .01747 Mdot
.72914 .01795 Mdot
.72934 .02041 Mdot
.72954 .01529 Mdot
.72974 .02236 Mdot
.72994 .02352 Mdot
.73014 .02583 Mdot
.73033 .0224 Mdot
.73053 .01837 Mdot
.73073 .01804 Mdot
.73093 .02097 Mdot
.73113 .02552 Mdot
.73133 .02219 Mdot
.73153 .02035 Mdot
.73173 .01934 Mdot
.73193 .01872 Mdot
.73213 .02152 Mdot
.73233 .02036 Mdot
.73253 .0205 Mdot
.73273 .0168 Mdot
.73293 .0182 Mdot
.73313 .01902 Mdot
.73333 .01856 Mdot
.73352 .0198 Mdot
.73372 .01965 Mdot
.73392 .0163 Mdot
.73412 .01604 Mdot
.73432 .01765 Mdot
.73452 .01989 Mdot
.73472 .01551 Mdot
.73492 .0185 Mdot
.73512 .01507 Mdot
.73532 .01625 Mdot
.73552 .01764 Mdot
.73572 .01992 Mdot
.73592 .01683 Mdot
.73612 .01566 Mdot
.73632 .01518 Mdot
.73652 .01547 Mdot
.73671 .01672 Mdot
.73691 .01519 Mdot
.73711 .01608 Mdot
.73731 .01498 Mdot
.73751 .01593 Mdot
.73771 .01694 Mdot
.73791 .01598 Mdot
.73811 .01762 Mdot
.73831 .01599 Mdot
.73851 .01564 Mdot
.73871 .01585 Mdot
.73891 .01573 Mdot
.73911 .01596 Mdot
.73931 .01651 Mdot
.73951 .01703 Mdot
.73971 .01672 Mdot
.7399 .01946 Mdot
.7401 .01709 Mdot
.7403 .01931 Mdot
.7405 .018 Mdot
.7407 .01876 Mdot
.7409 .01744 Mdot
.7411 .01842 Mdot
.7413 .01633 Mdot
.7415 .01587 Mdot
.7417 .01628 Mdot
.7419 .01642 Mdot
.7421 .01641 Mdot
.7423 .01558 Mdot
.7425 .01574 Mdot
.7427 .01636 Mdot
.7429 .01555 Mdot
.74309 .01759 Mdot
.74329 .0169 Mdot
.74349 .01586 Mdot
.74369 .01618 Mdot
.74389 .01686 Mdot
.74409 .01697 Mdot
.74429 .01548 Mdot
.74449 .01544 Mdot
.74469 .01677 Mdot
.74489 .01615 Mdot
.74509 .01508 Mdot
.74529 .01574 Mdot
.74549 .01617 Mdot
.74569 .01547 Mdot
.74589 .01672 Mdot
.74609 .01832 Mdot
.74628 .01708 Mdot
.74648 .01578 Mdot
.74668 .01677 Mdot
.74688 .01528 Mdot
.74708 .01672 Mdot
.74728 .01563 Mdot
.74748 .01634 Mdot
.74768 .01623 Mdot
.74788 .01585 Mdot
.74808 .01709 Mdot
.74828 .0173 Mdot
.74848 .01626 Mdot
.74868 .01574 Mdot
.74888 .0178 Mdot
.74908 .01592 Mdot
.74928 .01538 Mdot
.74948 .01608 Mdot
.74967 .01507 Mdot
.74987 .01762 Mdot
.75007 .01655 Mdot
.75027 .01645 Mdot
.75047 .01639 Mdot
.75067 .01528 Mdot
.75087 .0161 Mdot
.75107 .01597 Mdot
.75127 .01653 Mdot
.75147 .0176 Mdot
.75167 .01602 Mdot
.75187 .0172 Mdot
.75207 .01742 Mdot
.75227 .01778 Mdot
.75247 .01613 Mdot
.75267 .01628 Mdot
.75286 .01697 Mdot
.75306 .01601 Mdot
.75326 .0163 Mdot
.75346 .01535 Mdot
.75366 .01539 Mdot
.75386 .01554 Mdot
.75406 .0157 Mdot
.75426 .01567 Mdot
.75446 .01651 Mdot
.75466 .01525 Mdot
.75486 .01841 Mdot
.75506 .01667 Mdot
.75526 .01767 Mdot
.75546 .01875 Mdot
.75566 .01573 Mdot
.75586 .01607 Mdot
.75605 .01694 Mdot
.75625 .01672 Mdot
.75645 .01621 Mdot
.75665 .01598 Mdot
.75685 .01618 Mdot
.75705 .01686 Mdot
.75725 .01548 Mdot
.75745 .01586 Mdot
.75765 .01694 Mdot
.75785 .01562 Mdot
.75805 .01716 Mdot
.75825 .01598 Mdot
.75845 .01589 Mdot
.75865 .01667 Mdot
.75885 .01838 Mdot
.75905 .01829 Mdot
.75924 .01604 Mdot
.75944 .01829 Mdot
.75964 .01531 Mdot
.75984 .01894 Mdot
.76004 .02054 Mdot
.76024 .01851 Mdot
.76044 .01619 Mdot
.76064 .01882 Mdot
.76084 .01585 Mdot
.76104 .01681 Mdot
.76124 .01905 Mdot
.76144 .02226 Mdot
.76164 .02119 Mdot
.76184 .01756 Mdot
.76204 .01721 Mdot
.76224 .02242 Mdot
.76243 .0225 Mdot
.76263 .02288 Mdot
.76283 .01565 Mdot
.76303 .02417 Mdot
.76323 .02482 Mdot
.76343 .02043 Mdot
.76363 .0188 Mdot
.76383 .02212 Mdot
.76403 .02412 Mdot
.76423 .02431 Mdot
.76443 .02367 Mdot
.76463 .02387 Mdot
.76483 .02526 Mdot
.76503 .02168 Mdot
.76523 .01836 Mdot
.76543 .02202 Mdot
.76563 .02198 Mdot
.76582 .02355 Mdot
.76602 .02024 Mdot
.76622 .01556 Mdot
.76642 .02147 Mdot
.76662 .02169 Mdot
.76682 .0223 Mdot
.76702 .02047 Mdot
.76722 .01675 Mdot
.76742 .01718 Mdot
.76762 .01771 Mdot
.76782 .02104 Mdot
.76802 .02229 Mdot
.76822 .02433 Mdot
.76842 .01878 Mdot
.76862 .01984 Mdot
.76882 .01811 Mdot
.76901 .02379 Mdot
.76921 .02759 Mdot
.76941 .02279 Mdot
.76961 .02338 Mdot
.76981 .02055 Mdot
.77001 .02211 Mdot
.77021 .02448 Mdot
.77041 .02779 Mdot
.77061 .02391 Mdot
.77081 .02184 Mdot
.77101 .02465 Mdot
.77121 .01788 Mdot
.77141 .01693 Mdot
.77161 .02419 Mdot
.77181 .03067 Mdot
.77201 .02743 Mdot
.7722 .02538 Mdot
.7724 .02269 Mdot
.7726 .01877 Mdot
.7728 .01763 Mdot
.773 .01876 Mdot
.7732 .01843 Mdot
.7734 .02079 Mdot
.7736 .02457 Mdot
.7738 .02781 Mdot
.774 .0287 Mdot
.7742 .02804 Mdot
.7744 .02824 Mdot
.7746 .02149 Mdot
.7748 .01922 Mdot
.775 .02436 Mdot
.7752 .0228 Mdot
.77539 .01834 Mdot
.77559 .01793 Mdot
.77579 .03053 Mdot
.77599 .03566 Mdot
.77619 .03482 Mdot
.77639 .03108 Mdot
.77659 .02442 Mdot
.77679 .02501 Mdot
.77699 .02438 Mdot
.77719 .0197 Mdot
.77739 .02215 Mdot
.77759 .02516 Mdot
.77779 .02257 Mdot
.77799 .02635 Mdot
.77819 .03346 Mdot
.77839 .03577 Mdot
.77858 .03238 Mdot
.77878 .02171 Mdot
.77898 .0174 Mdot
.77918 .03242 Mdot
.77938 .03798 Mdot
.77958 .03607 Mdot
.77978 .03132 Mdot
.77998 .02161 Mdot
.78018 .02732 Mdot
.78038 .02873 Mdot
.78058 .03503 Mdot
.78078 .03031 Mdot
.78098 .02763 Mdot
.78118 .02699 Mdot
.78138 .02762 Mdot
.78158 .0288 Mdot
.78177 .02978 Mdot
.78197 .02739 Mdot
.78217 .02629 Mdot
.78237 .02351 Mdot
.78257 .02614 Mdot
.78277 .0252 Mdot
.78297 .02394 Mdot
.78317 .02234 Mdot
.78337 .02151 Mdot
.78357 .02237 Mdot
.78377 .02163 Mdot
.78397 .02004 Mdot
.78417 .01952 Mdot
.78437 .01563 Mdot
.78457 .01891 Mdot
.78477 .02054 Mdot
.78497 .01926 Mdot
.78516 .01575 Mdot
.78536 .01612 Mdot
.78556 .01779 Mdot
.78576 .01772 Mdot
.78596 .01722 Mdot
.78616 .01692 Mdot
.78636 .0192 Mdot
.78656 .01653 Mdot
.78676 .01594 Mdot
.78696 .01856 Mdot
.78716 .01706 Mdot
.78736 .01701 Mdot
.78756 .01729 Mdot
.78776 .01683 Mdot
.78796 .01841 Mdot
.78816 .01587 Mdot
.78835 .01687 Mdot
.78855 .01807 Mdot
.78875 .01695 Mdot
.78895 .01553 Mdot
.78915 .01546 Mdot
.78935 .01793 Mdot
.78955 .01981 Mdot
.78975 .0161 Mdot
.78995 .01543 Mdot
.79015 .01719 Mdot
.79035 .01588 Mdot
.79055 .01802 Mdot
.79075 .02134 Mdot
.79095 .01634 Mdot
.79115 .01646 Mdot
.79135 .01714 Mdot
.79154 .0164 Mdot
.79174 .01594 Mdot
.79194 .01614 Mdot
.79214 .01561 Mdot
.79234 .01588 Mdot
.79254 .01689 Mdot
.79274 .01738 Mdot
.79294 .01582 Mdot
.79314 .018 Mdot
.79334 .01532 Mdot
.79354 .01578 Mdot
.79374 .01553 Mdot
.79394 .01815 Mdot
.79414 .01861 Mdot
.79434 .01816 Mdot
.79454 .01735 Mdot
.79473 .01591 Mdot
.79493 .01653 Mdot
.79513 .01762 Mdot
.79533 .01716 Mdot
.79553 .01994 Mdot
.79573 .01822 Mdot
.79593 .01834 Mdot
.79613 .02053 Mdot
.79633 .01986 Mdot
.79653 .01701 Mdot
.79673 .01711 Mdot
.79693 .01901 Mdot
.79713 .01772 Mdot
.79733 .01787 Mdot
.79753 .01715 Mdot
.79773 .01618 Mdot
.79792 .01589 Mdot
.79812 .01546 Mdot
.79832 .01673 Mdot
.79852 .01653 Mdot
.79872 .0163 Mdot
.79892 .01589 Mdot
.79912 .01553 Mdot
.79932 .01631 Mdot
.79952 .01765 Mdot
.79972 .01888 Mdot
.79992 .01595 Mdot
.80012 .01758 Mdot
.80032 .0152 Mdot
.80052 .01602 Mdot
.80072 .01891 Mdot
.80092 .01727 Mdot
.80111 .01894 Mdot
.80131 .01763 Mdot
.80151 .01573 Mdot
.80171 .01593 Mdot
.80191 .0173 Mdot
.80211 .01528 Mdot
.80231 .01479 Mdot
.80251 .01668 Mdot
.80271 .01673 Mdot
.80291 .01787 Mdot
.80311 .01726 Mdot
.80331 .01587 Mdot
.80351 .01702 Mdot
.80371 .01895 Mdot
.80391 .01677 Mdot
.80411 .01603 Mdot
.80431 .01668 Mdot
.8045 .01852 Mdot
.8047 .01863 Mdot
.8049 .01848 Mdot
.8051 .01518 Mdot
.8053 .01741 Mdot
.8055 .01782 Mdot
.8057 .01685 Mdot
.8059 .01825 Mdot
.8061 .01709 Mdot
.8063 .01769 Mdot
.8065 .01544 Mdot
.8067 .02032 Mdot
.8069 .02194 Mdot
.8071 .01695 Mdot
.8073 .0177 Mdot
.8075 .01934 Mdot
.80769 .01583 Mdot
.80789 .01987 Mdot
.80809 .02239 Mdot
.80829 .02147 Mdot
.80849 .01689 Mdot
.80869 .02023 Mdot
.80889 .02629 Mdot
.80909 .02068 Mdot
.80929 .01851 Mdot
.80949 .01979 Mdot
.80969 .0257 Mdot
.80989 .02647 Mdot
.81009 .02377 Mdot
.81029 .01955 Mdot
.81049 .02962 Mdot
.81069 .03038 Mdot
.81088 .02767 Mdot
.81108 .0175 Mdot
.81128 .02682 Mdot
.81148 .0292 Mdot
.81168 .02656 Mdot
.81188 .02092 Mdot
.81208 .02502 Mdot
.81228 .02756 Mdot
.81248 .02867 Mdot
.81268 .02554 Mdot
.81288 .02396 Mdot
.81308 .03182 Mdot
.81328 .02548 Mdot
.81348 .02165 Mdot
.81368 .02091 Mdot
.81388 .02558 Mdot
.81407 .02856 Mdot
.81427 .02837 Mdot
.81447 .01944 Mdot
.81467 .01521 Mdot
.81487 .01675 Mdot
.81507 .0186 Mdot
.81527 .02451 Mdot
.81547 .02523 Mdot
.81567 .02544 Mdot
.81587 .02488 Mdot
.81607 .01804 Mdot
.81627 .02502 Mdot
.81647 .03816 Mdot
.81667 .04231 Mdot
.81687 .03514 Mdot
.81707 .02935 Mdot
.81726 .03242 Mdot
.81746 .04026 Mdot
.81766 .04152 Mdot
.81786 .03214 Mdot
.81806 .03372 Mdot
.81826 .03316 Mdot
.81846 .02572 Mdot
.81866 .028 Mdot
.81886 .03647 Mdot
.81906 .03142 Mdot
.81926 .03458 Mdot
.81946 .03157 Mdot
.81966 .02582 Mdot
.81986 .01607 Mdot
.82006 .03422 Mdot
.82026 .03573 Mdot
.82045 .03685 Mdot
.82065 .03507 Mdot
.82085 .0375 Mdot
.82105 .03031 Mdot
.82125 .02723 Mdot
.82145 .02695 Mdot
.82165 .02124 Mdot
.82185 .02639 Mdot
.82205 .04798 Mdot
.82225 .05066 Mdot
.82245 .04758 Mdot
.82265 .0472 Mdot
.82285 .04506 Mdot
.82305 .03927 Mdot
.82325 .02456 Mdot
.82345 .02181 Mdot
.82365 .02384 Mdot
.82384 .01968 Mdot
.82404 .03344 Mdot
.82424 .04534 Mdot
.82444 .05035 Mdot
.82464 .03887 Mdot
.82484 .03315 Mdot
.82504 .03404 Mdot
.82524 .04102 Mdot
.82544 .03781 Mdot
.82564 .0307 Mdot
.82584 .03763 Mdot
.82604 .03358 Mdot
.82624 .03638 Mdot
.82644 .0302 Mdot
.82664 .02991 Mdot
.82684 .03394 Mdot
.82703 .02959 Mdot
.82723 .02069 Mdot
.82743 .03307 Mdot
.82763 .04484 Mdot
.82783 .04657 Mdot
.82803 .0412 Mdot
.82823 .035 Mdot
.82843 .02832 Mdot
.82863 .03711 Mdot
.82883 .04339 Mdot
.82903 .04498 Mdot
.82923 .0365 Mdot
.82943 .02984 Mdot
.82963 .03578 Mdot
.82983 .04374 Mdot
.83003 .04563 Mdot
.83022 .04396 Mdot
.83042 .03855 Mdot
.83062 .03853 Mdot
.83082 .03606 Mdot
.83102 .03853 Mdot
.83122 .03569 Mdot
.83142 .03427 Mdot
.83162 .03064 Mdot
.83182 .0344 Mdot
.83202 .03733 Mdot
.83222 .03352 Mdot
.83242 .02824 Mdot
.83262 .02319 Mdot
.83282 .02195 Mdot
.83302 .02002 Mdot
.83322 .02276 Mdot
.83341 .0228 Mdot
.83361 .02016 Mdot
.83381 .01727 Mdot
.83401 .02004 Mdot
.83421 .02089 Mdot
.83441 .01665 Mdot
.83461 .02389 Mdot
.83481 .02082 Mdot
.83501 .01793 Mdot
.83521 .02001 Mdot
.83541 .02464 Mdot
.83561 .0274 Mdot
.83581 .01948 Mdot
.83601 .01688 Mdot
.83621 .02206 Mdot
.83641 .02362 Mdot
.8366 .01832 Mdot
.8368 .01949 Mdot
.837 .01793 Mdot
.8372 .0192 Mdot
.8374 .01952 Mdot
.8376 .01809 Mdot
.8378 .02495 Mdot
.838 .02046 Mdot
.8382 .01816 Mdot
.8384 .02111 Mdot
.8386 .01895 Mdot
.8388 .0188 Mdot
.839 .0189 Mdot
.8392 .02182 Mdot
.8394 .01925 Mdot
.8396 .02246 Mdot
.83979 .0189 Mdot
.83999 .01828 Mdot
.84019 .02113 Mdot
.84039 .02203 Mdot
.84059 .02022 Mdot
.84079 .02524 Mdot
.84099 .01542 Mdot
.84119 .0241 Mdot
.84139 .02011 Mdot
.84159 .02195 Mdot
.84179 .01938 Mdot
.84199 .01956 Mdot
.84219 .02005 Mdot
.84239 .02244 Mdot
.84259 .02458 Mdot
.84279 .02359 Mdot
.84299 .01653 Mdot
.84318 .0212 Mdot
.84338 .02273 Mdot
.84358 .01902 Mdot
.84378 .01665 Mdot
.84398 .01588 Mdot
.84418 .01771 Mdot
.84438 .02336 Mdot
.84458 .02187 Mdot
.84478 .02357 Mdot
.84498 .02328 Mdot
.84518 .02521 Mdot
.84538 .02347 Mdot
.84558 .02125 Mdot
.84578 .02464 Mdot
.84598 .0228 Mdot
.84618 .02452 Mdot
.84637 .0213 Mdot
.84657 .02206 Mdot
.84677 .01759 Mdot
.84697 .01698 Mdot
.84717 .01974 Mdot
.84737 .02096 Mdot
.84757 .02122 Mdot
.84777 .02789 Mdot
.84797 .03475 Mdot
.84817 .03808 Mdot
.84837 .0304 Mdot
.84857 .03484 Mdot
.84877 .0355 Mdot
.84897 .02823 Mdot
.84917 .02846 Mdot
.84937 .02731 Mdot
.84956 .02943 Mdot
.84976 .02618 Mdot
.84996 .02198 Mdot
.85016 .02551 Mdot
.85036 .02427 Mdot
.85056 .02049 Mdot
.85076 .02529 Mdot
.85096 .02566 Mdot
.85116 .02859 Mdot
.85136 .02617 Mdot
.85156 .02272 Mdot
.85176 .02511 Mdot
.85196 .02541 Mdot
.85216 .02077 Mdot
.85236 .01918 Mdot
.85256 .02415 Mdot
.85275 .01923 Mdot
.85295 .01974 Mdot
.85315 .02266 Mdot
.85335 .02607 Mdot
.85355 .03031 Mdot
.85375 .02871 Mdot
.85395 .0279 Mdot
.85415 .0266 Mdot
.85435 .02187 Mdot
.85455 .02666 Mdot
.85475 .02761 Mdot
.85495 .02498 Mdot
.85515 .02541 Mdot
.85535 .02312 Mdot
.85555 .02415 Mdot
.85575 .02746 Mdot
.85594 .02411 Mdot
.85614 .01897 Mdot
.85634 .01847 Mdot
.85654 .0221 Mdot
.85674 .02398 Mdot
.85694 .02436 Mdot
.85714 .03757 Mdot
.85734 .03557 Mdot
.85754 .02559 Mdot
.85774 .02513 Mdot
.85794 .03023 Mdot
.85814 .03246 Mdot
.85834 .03011 Mdot
.85854 .02342 Mdot
.85874 .02702 Mdot
.85894 .03911 Mdot
.85913 .0435 Mdot
.85933 .03653 Mdot
.85953 .02265 Mdot
.85973 .04262 Mdot
.85993 .04122 Mdot
.86013 .029 Mdot
.86033 .02738 Mdot
.86053 .0349 Mdot
.86073 .03485 Mdot
.86093 .03484 Mdot
.86113 .02733 Mdot
.86133 .03202 Mdot
.86153 .02868 Mdot
.86173 .0231 Mdot
.86193 .01775 Mdot
.86213 .02647 Mdot
.86233 .03199 Mdot
.86252 .02603 Mdot
.86272 .02209 Mdot
.86292 .02331 Mdot
.86312 .02431 Mdot
.86332 .01838 Mdot
.86352 .03313 Mdot
.86372 .0345 Mdot
.86392 .02861 Mdot
.86412 .02665 Mdot
.86432 .02871 Mdot
.86452 .01927 Mdot
.86472 .03078 Mdot
.86492 .03918 Mdot
.86512 .03542 Mdot
.86532 .02689 Mdot
.86552 .02443 Mdot
.86571 .02756 Mdot
.86591 .03127 Mdot
.86611 .03411 Mdot
.86631 .0311 Mdot
.86651 .0314 Mdot
.86671 .0222 Mdot
.86691 .01579 Mdot
.86711 .02131 Mdot
.86731 .02604 Mdot
.86751 .03584 Mdot
.86771 .03968 Mdot
.86791 .03025 Mdot
.86811 .02321 Mdot
.86831 .02149 Mdot
.86851 .0229 Mdot
.86871 .02575 Mdot
.8689 .03089 Mdot
.8691 .03151 Mdot
.8693 .02578 Mdot
.8695 .02892 Mdot
.8697 .03331 Mdot
.8699 .03073 Mdot
.8701 .01907 Mdot
.8703 .02038 Mdot
.8705 .02446 Mdot
.8707 .03276 Mdot
.8709 .03556 Mdot
.8711 .03162 Mdot
.8713 .02938 Mdot
.8715 .02955 Mdot
.8717 .03708 Mdot
.8719 .03541 Mdot
.87209 .02664 Mdot
.87229 .02412 Mdot
.87249 .03181 Mdot
.87269 .03288 Mdot
.87289 .03082 Mdot
.87309 .02742 Mdot
.87329 .01841 Mdot
.87349 .02479 Mdot
.87369 .03691 Mdot
.87389 .04447 Mdot
.87409 .04046 Mdot
.87429 .02361 Mdot
.87449 .02353 Mdot
.87469 .02498 Mdot
.87489 .02007 Mdot
.87509 .0188 Mdot
.87528 .02176 Mdot
.87548 .02149 Mdot
.87568 .02598 Mdot
.87588 .02986 Mdot
.87608 .02436 Mdot
.87628 .02799 Mdot
.87648 .02549 Mdot
.87668 .01906 Mdot
.87688 .02827 Mdot
.87708 .0305 Mdot
.87728 .03408 Mdot
.87748 .02857 Mdot
.87768 .01891 Mdot
.87788 .02115 Mdot
.87808 .02834 Mdot
.87828 .02902 Mdot
.87847 .02157 Mdot
.87867 .01958 Mdot
.87887 .01936 Mdot
.87907 .02224 Mdot
.87927 .02374 Mdot
.87947 .02561 Mdot
.87967 .02862 Mdot
.87987 .02208 Mdot
.88007 .02333 Mdot
.88027 .02378 Mdot
.88047 .02544 Mdot
.88067 .02206 Mdot
.88087 .0206 Mdot
.88107 .01872 Mdot
.88127 .01805 Mdot
.88147 .02248 Mdot
.88167 .0219 Mdot
.88186 .02083 Mdot
.88206 .01766 Mdot
.88226 .0184 Mdot
.88246 .01645 Mdot
.88266 .01623 Mdot
.88286 .01768 Mdot
.88306 .01573 Mdot
.88326 .01951 Mdot
.88346 .01937 Mdot
.88366 .01623 Mdot
.88386 .01913 Mdot
.88406 .01697 Mdot
.88426 .0208 Mdot
.88446 .01671 Mdot
.88466 .01753 Mdot
.88486 .01896 Mdot
.88505 .02023 Mdot
.88525 .01964 Mdot
.88545 .01636 Mdot
.88565 .01644 Mdot
.88585 .01697 Mdot
.88605 .01543 Mdot
.88625 .01632 Mdot
.88645 .01789 Mdot
.88665 .01754 Mdot
.88685 .0176 Mdot
.88705 .01659 Mdot
.88725 .01856 Mdot
.88745 .01696 Mdot
.88765 .01579 Mdot
.88785 .0164 Mdot
.88805 .01775 Mdot
.88824 .02065 Mdot
.88844 .01965 Mdot
.88864 .02062 Mdot
.88884 .02014 Mdot
.88904 .02519 Mdot
.88924 .0201 Mdot
.88944 .01869 Mdot
.88964 .01708 Mdot
.88984 .01909 Mdot
.89004 .01937 Mdot
.89024 .02064 Mdot
.89044 .01735 Mdot
.89064 .01534 Mdot
.89084 .01544 Mdot
.89104 .01655 Mdot
.89124 .01657 Mdot
.89143 .01595 Mdot
.89163 .01736 Mdot
.89183 .01694 Mdot
.89203 .01703 Mdot
.89223 .01847 Mdot
.89243 .02074 Mdot
.89263 .02069 Mdot
.89283 .01675 Mdot
.89303 .01879 Mdot
.89323 .02071 Mdot
.89343 .01846 Mdot
.89363 .02213 Mdot
.89383 .02086 Mdot
.89403 .01693 Mdot
.89423 .01988 Mdot
.89443 .01895 Mdot
.89462 .01946 Mdot
.89482 .0188 Mdot
.89502 .01731 Mdot
.89522 .01647 Mdot
.89542 .01712 Mdot
.89562 .01884 Mdot
.89582 .01925 Mdot
.89602 .01982 Mdot
.89622 .02008 Mdot
.89642 .0181 Mdot
.89662 .01651 Mdot
.89682 .01826 Mdot
.89702 .01872 Mdot
.89722 .01826 Mdot
.89742 .02032 Mdot
.89762 .01709 Mdot
.89781 .01885 Mdot
.89801 .01733 Mdot
.89821 .0193 Mdot
.89841 .02089 Mdot
.89861 .0209 Mdot
.89881 .02018 Mdot
.89901 .02023 Mdot
.89921 .01694 Mdot
.89941 .01947 Mdot
.89961 .02207 Mdot
.89981 .02043 Mdot
.90001 .01686 Mdot
.90021 .02111 Mdot
.90041 .01703 Mdot
.90061 .01846 Mdot
.90081 .01777 Mdot
.90101 .01798 Mdot
.9012 .01626 Mdot
.9014 .01728 Mdot
.9016 .01672 Mdot
.9018 .01634 Mdot
.902 .01645 Mdot
.9022 .01545 Mdot
.9024 .01743 Mdot
.9026 .02022 Mdot
.9028 .01947 Mdot
.903 .02163 Mdot
.9032 .02291 Mdot
.9034 .02139 Mdot
.9036 .02187 Mdot
.9038 .01861 Mdot
.904 .02056 Mdot
.9042 .0186 Mdot
.90439 .01943 Mdot
.90459 .01703 Mdot
.90479 .01924 Mdot
.90499 .02023 Mdot
.90519 .0155 Mdot
.90539 .02216 Mdot
.90559 .02399 Mdot
.90579 .02074 Mdot
.90599 .01889 Mdot
.90619 .02194 Mdot
.90639 .02509 Mdot
.90659 .02645 Mdot
.90679 .01718 Mdot
.90699 .02485 Mdot
.90719 .02665 Mdot
.90739 .02202 Mdot
.90758 .01751 Mdot
.90778 .0206 Mdot
.90798 .02094 Mdot
.90818 .02228 Mdot
.90838 .0206 Mdot
.90858 .01912 Mdot
.90878 .02166 Mdot
.90898 .02106 Mdot
.90918 .02086 Mdot
.90938 .01853 Mdot
.90958 .01649 Mdot
.90978 .01776 Mdot
.90998 .01695 Mdot
.91018 .01793 Mdot
.91038 .01601 Mdot
.91058 .01706 Mdot
.91077 .01981 Mdot
.91097 .01806 Mdot
.91117 .01694 Mdot
.91137 .01757 Mdot
.91157 .01781 Mdot
.91177 .01856 Mdot
.91197 .0197 Mdot
.91217 .02081 Mdot
.91237 .02332 Mdot
.91257 .01849 Mdot
.91277 .01873 Mdot
.91297 .01973 Mdot
.91317 .02371 Mdot
.91337 .02222 Mdot
.91357 .02495 Mdot
.91377 .02325 Mdot
.91396 .02292 Mdot
.91416 .022 Mdot
.91436 .02188 Mdot
.91456 .02207 Mdot
.91476 .02167 Mdot
.91496 .01959 Mdot
.91516 .02121 Mdot
.91536 .0186 Mdot
.91556 .01967 Mdot
.91576 .02328 Mdot
.91596 .02074 Mdot
.91616 .02175 Mdot
.91636 .02059 Mdot
.91656 .01913 Mdot
.91676 .01926 Mdot
.91696 .0187 Mdot
.91715 .01605 Mdot
.91735 .01922 Mdot
.91755 .02287 Mdot
.91775 .02245 Mdot
.91795 .02502 Mdot
.91815 .02434 Mdot
.91835 .01986 Mdot
.91855 .0164 Mdot
.91875 .0185 Mdot
.91895 .0206 Mdot
.91915 .0222 Mdot
.91935 .01981 Mdot
.91955 .02187 Mdot
.91975 .02695 Mdot
.91995 .01879 Mdot
.92015 .02299 Mdot
.92035 .02024 Mdot
.92054 .0231 Mdot
.92074 .01908 Mdot
.92094 .01828 Mdot
.92114 .02128 Mdot
.92134 .01591 Mdot
.92154 .02 Mdot
.92174 .0212 Mdot
.92194 .02612 Mdot
.92214 .02481 Mdot
.92234 .02562 Mdot
.92254 .02468 Mdot
.92274 .02653 Mdot
.92294 .02337 Mdot
.92314 .02084 Mdot
.92334 .02005 Mdot
.92354 .02305 Mdot
.92373 .02063 Mdot
.92393 .0223 Mdot
.92413 .02197 Mdot
.92433 .02351 Mdot
.92453 .02161 Mdot
.92473 .02128 Mdot
.92493 .01979 Mdot
.92513 .02686 Mdot
.92533 .02561 Mdot
.92553 .02027 Mdot
.92573 .02383 Mdot
.92593 .02313 Mdot
.92613 .0225 Mdot
.92633 .02165 Mdot
.92653 .02553 Mdot
.92673 .02756 Mdot
.92692 .02392 Mdot
.92712 .0211 Mdot
.92732 .0216 Mdot
.92752 .02351 Mdot
.92772 .02288 Mdot
.92792 .02519 Mdot
.92812 .0235 Mdot
.92832 .02315 Mdot
.92852 .02516 Mdot
.92872 .02496 Mdot
.92892 .02375 Mdot
.92912 .02482 Mdot
.92932 .0225 Mdot
.92952 .02148 Mdot
.92972 .02021 Mdot
.92992 .02505 Mdot
.93011 .02146 Mdot
.93031 .02164 Mdot
.93051 .01983 Mdot
.93071 .01825 Mdot
.93091 .01899 Mdot
.93111 .01895 Mdot
.93131 .01735 Mdot
.93151 .01757 Mdot
.93171 .01648 Mdot
.93191 .01834 Mdot
.93211 .02025 Mdot
.93231 .01916 Mdot
.93251 .01616 Mdot
.93271 .01544 Mdot
.93291 .01556 Mdot
.93311 .0179 Mdot
.9333 .016 Mdot
.9335 .01777 Mdot
.9337 .0179 Mdot
.9339 .0164 Mdot
.9341 .01586 Mdot
.9343 .01607 Mdot
.9345 .01663 Mdot
.9347 .01788 Mdot
.9349 .01631 Mdot
.9351 .0185 Mdot
.9353 .01966 Mdot
.9355 .01696 Mdot
.9357 .01915 Mdot
.9359 .019 Mdot
.9361 .01541 Mdot
.9363 .01691 Mdot
.93649 .0177 Mdot
.93669 .01854 Mdot
.93689 .01742 Mdot
.93709 .01661 Mdot
.93729 .01585 Mdot
.93749 .01756 Mdot
.93769 .01741 Mdot
.93789 .01754 Mdot
.93809 .01541 Mdot
.93829 .01593 Mdot
.93849 .01932 Mdot
.93869 .0173 Mdot
.93889 .0168 Mdot
.93909 .0182 Mdot
.93929 .01669 Mdot
.93949 .01588 Mdot
.93969 .01679 Mdot
.93988 .0183 Mdot
.94008 .0173 Mdot
.94028 .01659 Mdot
.94048 .01826 Mdot
.94068 .01547 Mdot
.94088 .01727 Mdot
.94108 .01582 Mdot
.94128 .01644 Mdot
.94148 .01576 Mdot
.94168 .0166 Mdot
.94188 .01674 Mdot
.94208 .01657 Mdot
.94228 .01679 Mdot
.94248 .01668 Mdot
.94268 .01725 Mdot
.94288 .01644 Mdot
.94307 .01606 Mdot
.94327 .01496 Mdot
.94347 .01578 Mdot
.94367 .01554 Mdot
.94387 .0168 Mdot
.94407 .01595 Mdot
.94427 .01496 Mdot
.94447 .01807 Mdot
.94467 .01591 Mdot
.94487 .01549 Mdot
.94507 .01633 Mdot
.94527 .01686 Mdot
.94547 .01618 Mdot
.94567 .01678 Mdot
.94587 .01644 Mdot
.94607 .01671 Mdot
.94626 .01569 Mdot
.94646 .01758 Mdot
.94666 .01678 Mdot
.94686 .01995 Mdot
.94706 .02038 Mdot
.94726 .01933 Mdot
.94746 .01925 Mdot
.94766 .01776 Mdot
.94786 .01767 Mdot
.94806 .02087 Mdot
.94826 .01896 Mdot
.94846 .01853 Mdot
.94866 .01908 Mdot
.94886 .02028 Mdot
.94906 .02235 Mdot
.94926 .01912 Mdot
.94945 .02132 Mdot
.94965 .01942 Mdot
.94985 .02108 Mdot
.95005 .01842 Mdot
.95025 .01847 Mdot
.95045 .01874 Mdot
.95065 .01684 Mdot
.95085 .01776 Mdot
.95105 .01677 Mdot
.95125 .01649 Mdot
.95145 .01996 Mdot
.95165 .01748 Mdot
.95185 .01868 Mdot
.95205 .0178 Mdot
.95225 .01643 Mdot
.95245 .01863 Mdot
.95264 .01845 Mdot
.95284 .01813 Mdot
.95304 .01834 Mdot
.95324 .0173 Mdot
.95344 .01536 Mdot
.95364 .01814 Mdot
.95384 .01961 Mdot
.95404 .0186 Mdot
.95424 .01565 Mdot
.95444 .01582 Mdot
.95464 .01999 Mdot
.95484 .02027 Mdot
.95504 .02026 Mdot
.95524 .01526 Mdot
.95544 .02073 Mdot
.95564 .02044 Mdot
.95583 .0181 Mdot
.95603 .0171 Mdot
.95623 .02196 Mdot
.95643 .01829 Mdot
.95663 .01941 Mdot
.95683 .01824 Mdot
.95703 .0177 Mdot
.95723 .0193 Mdot
.95743 .01578 Mdot
.95763 .01696 Mdot
.95783 .01734 Mdot
.95803 .01571 Mdot
.95823 .01538 Mdot
.95843 .0177 Mdot
.95863 .01607 Mdot
.95883 .01924 Mdot
.95903 .01599 Mdot
.95922 .01731 Mdot
.95942 .01717 Mdot
.95962 .01828 Mdot
.95982 .02316 Mdot
.96002 .01698 Mdot
.96022 .01871 Mdot
.96042 .01797 Mdot
.96062 .01925 Mdot
.96082 .01913 Mdot
.96102 .0166 Mdot
.96122 .01736 Mdot
.96142 .02123 Mdot
.96162 .01822 Mdot
.96182 .01807 Mdot
.96202 .02107 Mdot
.96222 .02123 Mdot
.96241 .0227 Mdot
.96261 .01822 Mdot
.96281 .02032 Mdot
.96301 .02169 Mdot
.96321 .02016 Mdot
.96341 .02235 Mdot
.96361 .02286 Mdot
.96381 .02092 Mdot
.96401 .01862 Mdot
.96421 .01817 Mdot
.96441 .02116 Mdot
.96461 .02123 Mdot
.96481 .01975 Mdot
.96501 .01844 Mdot
.96521 .01841 Mdot
.96541 .01578 Mdot
.9656 .01621 Mdot
.9658 .01799 Mdot
.966 .01699 Mdot
.9662 .02018 Mdot
.9664 .02164 Mdot
.9666 .01995 Mdot
.9668 .02034 Mdot
.967 .01825 Mdot
.9672 .01922 Mdot
.9674 .01921 Mdot
.9676 .01541 Mdot
.9678 .01612 Mdot
.968 .01823 Mdot
.9682 .01708 Mdot
.9684 .01836 Mdot
.9686 .0209 Mdot
.96879 .01949 Mdot
.96899 .01959 Mdot
.96919 .01816 Mdot
.96939 .01665 Mdot
.96959 .01698 Mdot
.96979 .01529 Mdot
.96999 .01689 Mdot
.97019 .01794 Mdot
.97039 .0159 Mdot
.97059 .01621 Mdot
.97079 .01714 Mdot
.97099 .01898 Mdot
.97119 .01542 Mdot
.97139 .01976 Mdot
.97159 .01749 Mdot
.97179 .01985 Mdot
.97198 .01817 Mdot
.97218 .01755 Mdot
.97238 .01964 Mdot
.97258 .01541 Mdot
.97278 .01612 Mdot
.97298 .01823 Mdot
.97318 .01808 Mdot
.97338 .01536 Mdot
.97358 .0195 Mdot
.97378 .01979 Mdot
.97398 .01845 Mdot
.97418 .01794 Mdot
.97438 .01887 Mdot
.97458 .02163 Mdot
.97478 .02196 Mdot
.97498 .02217 Mdot
.97517 .01956 Mdot
.97537 .0196 Mdot
.97557 .01987 Mdot
.97577 .02034 Mdot
.97597 .01882 Mdot
.97617 .01848 Mdot
.97637 .01995 Mdot
.97657 .01921 Mdot
.97677 .01936 Mdot
.97697 .02305 Mdot
.97717 .02195 Mdot
.97737 .02163 Mdot
.97757 .0177 Mdot
.97777 .02173 Mdot
.97797 .02259 Mdot
.97817 .02016 Mdot
.97837 .0217 Mdot
.97856 .02038 Mdot
.97876 .021 Mdot
.97896 .02122 Mdot
.97916 .01999 Mdot
.97936 .0193 Mdot
.97956 .01504 Mdot
.97976 .01883 Mdot
.97996 .02029 Mdot
.98016 .01568 Mdot
.98036 .01856 Mdot
.98056 .01981 Mdot
.98076 .01603 Mdot
.98096 .01692 Mdot
.98116 .0178 Mdot
.98136 .01676 Mdot
.98156 .01602 Mdot
.98175 .01559 Mdot
.98195 .01665 Mdot
.98215 .01791 Mdot
.98235 .01631 Mdot
.98255 .01622 Mdot
.98275 .01681 Mdot
.98295 .01544 Mdot
.98315 .01669 Mdot
.98335 .01703 Mdot
.98355 .01636 Mdot
.98375 .017 Mdot
.98395 .01845 Mdot
.98415 .01681 Mdot
.98435 .01753 Mdot
.98455 .01691 Mdot
.98475 .01619 Mdot
.98494 .01667 Mdot
.98514 .01693 Mdot
.98534 .01693 Mdot
.98554 .016 Mdot
.98574 .01608 Mdot
.98594 .01557 Mdot
.98614 .01589 Mdot
.98634 .01663 Mdot
.98654 .01601 Mdot
.98674 .0158 Mdot
.98694 .01614 Mdot
.98714 .01648 Mdot
.98734 .01635 Mdot
.98754 .01553 Mdot
.98774 .01693 Mdot
.98794 .01595 Mdot
.98813 .01648 Mdot
.98833 .01565 Mdot
.98853 .01585 Mdot
.98873 .01759 Mdot
.98893 .01749 Mdot
.98913 .0156 Mdot
.98933 .01543 Mdot
.98953 .01566 Mdot
.98973 .01653 Mdot
.98993 .01742 Mdot
.99013 .01681 Mdot
.99033 .01617 Mdot
.99053 .01605 Mdot
.99073 .01727 Mdot
.99093 .01674 Mdot
.99113 .01566 Mdot
.99132 .01698 Mdot
.99152 .01843 Mdot
.99172 .01645 Mdot
.99192 .01698 Mdot
.99212 .0194 Mdot
.99232 .02129 Mdot
.99252 .02049 Mdot
.99272 .02021 Mdot
.99292 .0191 Mdot
.99312 .0199 Mdot
.99332 .01859 Mdot
.99352 .01679 Mdot
.99372 .01674 Mdot
.99392 .01583 Mdot
.99412 .01529 Mdot
.99432 .0184 Mdot
.99451 .01816 Mdot
.99471 .01618 Mdot
.99491 .0177 Mdot
.99511 .01515 Mdot
.99531 .01657 Mdot
.99551 .01872 Mdot
.99571 .01782 Mdot
.99591 .01885 Mdot
.99611 .01559 Mdot
.99631 .0181 Mdot
.99651 .01513 Mdot
.99671 .01767 Mdot
.99691 .01713 Mdot
.99711 .01958 Mdot
.99731 .01894 Mdot
.99751 .0199 Mdot
.99771 .02341 Mdot
.9979 .02136 Mdot
.9981 .0234 Mdot
.9983 .02158 Mdot
.9985 .0225 Mdot
.9987 .02125 Mdot
.9989 .02061 Mdot
.9991 .01894 Mdot
.9993 .01904 Mdot
.9995 .01552 Mdot
.9997 .016 Mdot
.9999 .02142 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOona
Ool00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00
ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00Dgoo10001Woo0P00
1goo0P005Goo1@001Goo0P001goo0P001goo0P004Goo1@0017oo10001Woo0P001goo0P003goo1P00
1Goo0P001goo0P001goo0P0047oo1P0017oo10001Woo0P001goo0P004Goo10001Woo0P001goo0P00
1goo0P00FWoo001BOol00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol0
01Ioo`03001oogoo00Aoo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol0019oo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0005Ool01000Oomoo`003goo00D0
07ooOomoo`0000Aoo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol0011oo`05001oogoo
Ool00003Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOol000moo`03
001oogoo009oo`03001oogoo009oo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol005Uo
o`00Egoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0COol00`00Oomoo`03
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00moo`03
001oogoo00Qoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol03Goo00<007oo
Ool017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0>
Ool00`00Oomoo`09Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo015oo`05
001oogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo05Ioo`00
Egoo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0COol00`00Oomoo`03Ool0
0`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo00moo`03001o
ogoo00Qoo`05001oogooOol00004Ool01@00Oomoogoo000017oo00<007ooOol03Woo00<007ooOol0
0goo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0?Ool0
0`00Oomoo`08Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo015oo`05001o
ogooOol00004Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo05Ioo`00DWoo
00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomoo`0COol00`00
Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`03001oogoo
00moo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00<007ooOol03goo00<007ooOol00Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogoo
Ool00004Ool00`00Oomoo`0@Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo00ioo`<000Aoo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo000017oo00<007ooOol0EWoo001BOol50004Ool00`00Oomoo`02Ool01@00Oomo
ogoo000017oo00<007ooOol04goo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`0000Ao
o`05001oogooOol00004Ool00`00Oomoo`0?Ool00`00Oomoo`03Ool50004Ool00`00Oomoo`02Ool0
1@00Oomoogoo000017oo00<007ooOol047oo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool0
1@00Oomoogoo000017oo00<007ooOol04Goo00@007ooOomoo`D000Aoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`0AOol01@00Oomoogoo000017oo00D007ooOomoo`0000Aoo`05001o
ogooOol00004Ool00`00Oomoo`1FOol0059oo`03001oogoo00Ioo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`0COol00`00Oomoo`03Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo00moo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo
009oo`05001oogooOol00004Ool00`00Oomoo`0@Ool01@00Oomoogoo000017oo00D007ooOomoo`00
00Aoo`05001oogooOol00004Ool00`00Oomoo`0AOol01@00Oomoogoo000027oo00<007ooOol00Woo
00D007ooOomoo`0000Aoo`03001oogoo015oo`05001oogooOol00004Ool01@00Oomoogoo000017oo
00D007ooOomoo`0000Aoo`03001oogoo05Ioo`00DWoo00<007ooOol01goo00@007ooOol000Eoo`04
001oogoo000DOol30006Ool01000Oomoo`001Goo00@007ooOol000Eoo`04001oogoo000@Ool30005
Ool00`00Oomoo`07Ool01000Oomoo`001Goo00@007ooOol000ioo`03001oogoo009oo`03001oogoo
009oo`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol000moo`03001oogoo009oo`05001o
ogooOol00009Ool01000Oomoo`001Goo00@007ooOol000moo`03001oogoo009oo`03001oogoo009o
o`04001oogoo0005Ool01000Oomoo`001Goo00@007ooOol001]oo`@001Qoo`03001oogoo01Aoo`03
001oogoo00Qoo`00DWoo1@001Woo0P001goo0P005Woo0P001goo0P001goo0P001goo0P004Woo0P00
1Goo1@001Woo0P001goo0P0047oo10001Woo0P001goo0P001goo0P004Goo100017oo1@001Woo0P00
1goo0P004Goo10001Woo0P001goo0P001goo0P007Woo00<007ooOol05Woo00<007ooOol05Woo00<0
07ooOol01goo000`Ool00`00Oomoo`3oOom2Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomo
o`07Ool0031oo`03001oogoo0?moob5oo`H000=oo`H000Eoo`@000Eoo`<00003Ool007oo00=oo`<0
011oo`03001oogoo00=oo`<0009oo`<0009oo`H000Eoo`03001oogoo00Ioo`00<7oo00<007ooOol0
ogoo8goo00<007ooOol01Woo00<007ooOol01Goo00<007ooOol00Woo00D007ooOomoo`0000=oo`80
00Aoo`<0011oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo009oo`05001oogooOol00005
Ool00`00Oomoo`06Ool0031oo`03001oogoo0?moob=oo`03001oogoo00Ioo`03001oogoo00Aoo`03
001oogoo00Ioo`03001oogoo00=oo`03001oogoo009oo`<0011oo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Ioo`00<7oo3P0017oo2@000Woo2P00
2Goo10002Goo1@0017oo200037oo0`004Goo300000=oo`0000005`0000=oo`0000009@000goo6@00
0goo2P001Woo0P001Goo0P000Woo1@0000=oo`0000000goo0P0000=oo`0000004`0037oo00<007oo
Ool01Woo00<007ooOol017oo1`000Woo00<007ooOol00goo00<007ooOol05Goo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol01Woo000`Oooo000J000<
Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Oomoo`03Ool01000Oomoo`001Goo00<007ooOol0
5Goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0
1Woo000`OolY00000goo0000000:0002Ool;0003Ool;00000goo0000000:00000goo00000002Ool8
00000goo0000002[000<Ool00`00Oomoo`06Ool20006Ool01@00Oomoogoo000017oo00@007ooOomo
o`8001Moo`03001oogoo00Aoo`8000=oo`05001oogooOol00004Ool00`00Oomoo`03Ool00`00Oomo
o`06Ool0031oo`L0009ooaX00003Ool0000000<00003Ool0000000X0009oobH00003Ool00000009o
o`h00003Ool0000000=oo`P00004Ool00000Ool:0004Ool90002Ool200000goo000000040002Ool2
0004Ool60007Ool70002Ool20002Ool80005Ool<00000goo0000000T00000goo0000000:00000goo
00000002000:Ool60003Ool300000goo000000020003Ool30006Ool300000goo0000000GOol00`00
Oomoo`03Ool00`00Ool000020004Ool60004Ool00`00Oomoo`07Ool0031oo`<00004Ool000000005
Ool60004Ool20002Ool40003Ool20003Ool@0002OolC00000goo000000040002Ool<0002Ool?0008
Ool30009Ool5000;Ool200000goo0000000=Ool20007Ool20008Ool60008Ool60007Ool70006OolH
0003Ool80007Ool20008Ool2000=Ool00`00Oomoo`0eOol00`00Oomoo`03Ool00`00Oomoo`0@Ool0
0`00Oomoo`07Ool0031oo`<0009oo`8000Aoo`H000Uoo`@000=oo`8000=oo`P0009oo`800003Ool0
000000X00003Ool0000000H000Eoo`@00003Ool0000001`000Uoo`<000]oo`8003Eoo`8001Ioo`H0
00Ioo`T00003Ool0000000T000Yoo`<0025oo`03001oogoo03Ioo`03001oogoo009oo`03001oogoo
00moo`03001oogoo00Qoo`00<7oo0P000goo0P0017oo1@002Woo100027oo0`0000=oo`0000000P00
1Goo2P000goo20001Woo0`0000=oo`0000001@000Woo0`000Woo3`002goo0P002goo0P00CWoo1@00
1Woo20000Woo2`00;goo0`00>Goo0P0077oo000`Ool00`00Oomoo`09Ool4000:Ool40009Ool2000:
Ool20003Ool50004Ool70007Ool2000017oo000007oo0P0017oo10000goo3@002goo0P00G7oo1000
27oo1P000Woo2`00RGoo000`Ool00`00Oomoo`09Ool4000:Ool40009Ool2000:Ool30003Ool30005
Ool70007Ool80004Ool600000goo0000000;000;Ool2001MOol20009Ool60003Ool9002:Ool0031o
o`03001oogoo01Moo`@000Uoo`800003Ool0000000Qoo`<00003Ool00000008000Eoo`L000Moo`L0
00Ioo`800003Ool0000000H00003Ool0000000@007Ioo`D000Moo`80009oo`8008Yoo`00<7oo00<0
07ooOol02Woo0`002Woo10002Goo1@0027oo0`0000=oo`0000001goo1`001goo1`001Woo0P000Woo
1`0000=oo`0000001000Mgoo1000Ugoo000`Ool00`00Oomoo`0:Ool3000;Ool2000:Ool50008Ool4
0009Ool50009Ool70006Ool600000goo000000020002Ool6001fOol3002HOol002moo`<000aoo`80
01Moo`800003Ool0000000Qoo`H000Moo`H000Qoo`L000Ioo`X000=oo`H00?mooa9oo`00;goo0P00
3Goo0P005goo10002Woo0P0000=oo`0000001goo1P002Woo1@001Woo10000Woo100017oo1@00ogoo
4Woo000`Ool00`00Oomoo`09Ool2000<Ool3000;Ool3000:Ool2000:Ool60009Ool60008Ool20002
Ool40003Ool6003oOolBOol0031oo`03001oogoo00Uoo`@000Yoo`<000Yoo`800003Ool0000000ao
o`8000Qoo`800003Ool0000000Qoo`L000Moo`T000=oo`H00?mooa9oo`00<7oo00<007ooOol02goo
0P005goo0P0000=oo`00000027oo0`0000=oo`00000027oo0P0000=oo`00000027oo1`001Woo1P00
1goo1P00ogoo4Woo000`Ool2000<Ool2000JOol20008Ool300000goo00000008Ool50008Ool60007
Ool80006Ool3003oOolDOol0031oo`03001oogoo01Moo`<000aoo`<000Qoo`80009oo`8000Qoo`@0
00Uoo`H000Yoo`800003Ool0000000Ioo`@00?mooa=oo`00<7oo00<007ooOol02Woo0P002goo0`00
2Woo10003Goo0P002Goo0P0037oo10001goo1`001goo1000ogoo4goo000`Ool00`00Oomoo`0:Ool2
000;Ool3000:Ool3000HOol4000<Ool30007Ool70007Ool3003oOolDOol0031oo`03001oogoo00Yo
o`<000]oo`8000]oo`@000Yoo`8000Yoo`@000Yoo`800003Ool0000000Uoo`D000Moo`@00?mooa=o
o`00<7oo00<007ooOol02Woo0`0067oo100027oo1P0027oo0P0037oo0P0000=oo`0000001goo1`00
27oo0`00ogoo4goo000`Ool2000;Ool2000HOol50008Ool2000017oo0000000027oo0P0037oo0P00
2Woo0P0000=oo`0000000P0027oo0`00ogoo4goo000`Ool00`00Oomoo`0:Ool3000GOol40009Ool2
0002Ool2000:Ool2000:Ool2000;Ool60008Ool2003oOolDOol0031oo`03001oogoo00Yoo`<001Mo
o`D000Qoo`H000Qoo`@000]oo`8000Yoo`D000Yoo`800?mooa=oo`000goo0P001goo0`001Woo0P00
1goo0P001Woo1@001Goo00<007ooOol02Woo0P0067oo1@002Goo0`002Woo0P0037oo0`002Woo1P00
2Goo0P00ogoo4goo0002Ool01000Oomoo`001Woo0`001Goo00@007ooOol000Eoo`04001oogoo0007
Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool2000JOol2000:Ool2000<Ool2000;Ool3000:Ool60007
Ool2003oOolEOol00003Ool007oo00=oo`03001oogoo00=oo`<000Aoo`03001oogoo009oo`05001o
ogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool3000:Ool2000;Ool2000<Ool3000HOol2
000;Ool3000;Ool200000goo00000007Ool2003oOolEOol00003Ool007oo00=oo`03001oogoo00Yo
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomo
o`0:Ool2000;Ool2000<Ool30009Ool200000goo0000000:Ool2000;Ool2000<Ool5003oOolNOol0
0003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomo
o`04Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool2000JOol20009Ool5000:Ool2000<Ool2000:Ool6
0008Ool2003oOolDOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool2000JOol2000;Ool3000H
Ool2000:Ool60008Ool2003oOolDOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009o
o`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool2000;Ool2
000;Ool2000>Ool2000:Ool2000<Ool2000:Ool2000017oo00000000ogoo7Woo0002Ool01000Oomo
o`003Woo00@007ooOol000Eoo`04001oogoo0005Ool30007Ool00`00Oomoo`0:Ool2000;Ool2000;
Ool2000<Ool4000:Ool2000;Ool3000:Ool300000goo0000003oOolNOol000=oo`80011oo`8000Mo
o`8000Moo`8000Moo`8002Ioo`8000]oo`@001Moo`<000]oo`D000Qoo`800?mooaAoo`00<7oo00<0
07ooOol09Goo0P003Goo0P002Woo0P002goo0`0037oo10001goo0`00ogoo57oo000`Ool00`00Oomo
o`0aOol200000goo0000000:Ool2000HOol60007Ool2003oOolEOol0031oo`03001oogoo035oo`@0
00]oo`8001Qoo`H00?mooaioo`00<7oo00<007ooOol09Goo0P0037oo0P002goo0P0067oo0P00ogoo
8Woo000`Ool00`00Oomoo`0UOol2000=Ool2000:Ool2000;Ool2000?Ool2003oOolNOol0031oo`80
03Aoo`<001Moo`8000]oo`80009oo`800?mooaioo`00<7oo00<007ooOol0<goo0P006Goo0P002Woo
0P000Woo0P00ogoo7Woo000`Ool00`00Oomoo`0dOol2000HOol2000;Ool200000goo0000003oOolN
Ool0031oo`03001oogoo03Aoo`8002Eoo`800?moob5oo`00<7oo00<007ooOol0<goo0`002goo0P00
2goo0P002Woo0P00ogoo8Woo000`Ool2000dOol3000;Ool2000;Ool2000:Ool2003oOolROol0031o
o`03001oogoo02Eoo`8000aoo`<002Aoo`800?moob9oo`00<7oo00<007ooOol09Goo0P003Goo0P00
97oo0P00ogoo8Woo000`Ool00`00Oomoo`0:Ool2000XOol2000UOol2003oOolQOol0031oo`03001o
ogoo00Yoo`8002Ioo`@002Eoo`800?moob5oo`00<7oo00<007ooOol0<Woo1000ogooB7oo000`Ool2
0012Ool2003oOolkOol0031oo`03001oogoo045oo`800?mooc]oo`00<7oo00<007ooOol0=7oo0P00
9Woo0P00ogoo87oo0003Ool20007Ool30006Ool20007Ool20005Ool60005Ool00`00Oomoo`0bOol4
000TOol4003oOolPOol0009oo`04001oogoo0006Ool30005Ool01000Oomoo`001Goo00@007ooOol0
00Eoo`05001oogooOol00005Ool00`00Oomoo`0bOol4000TOol3003oOolQOol00003Ool007oo00=o
o`03001oogoo00=oo`<000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`03Ool0
0`00Oomoo`06Ool3000UOol2000=Ool2000HOol2000;Ool2003oOolQOol00003Ool007oo00=oo`03
001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`04Ool00`00Oomoo`05
Ool00`00Oomoo`0UOol2000=Ool2000HOol2003oOol^Ool00003Ool007oo00=oo`03001oogoo00Yo
o`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`0UOol2003oOomGOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogoo
Ool00004Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0UOol2000;Ool2000XOol2003o
OolPOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool0
0`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`0UOol2000;Ool2000XOol2003oOolPOol0009o
o`04001oogoo000>Ool01000Oomoo`001Goo00@007ooOol000Aoo`03001oogoo009oo`03001oogoo
00=oo`03001oogoo02Eoo`8002Moo`8000aoo`800?moob1oo`000goo0P0047oo0P001goo0P001Woo
10001Woo0P009Woo0P002goo0P006Woo0P0037oo0P00ogoo87oo000`Ool00`00Oomoo`0bOol2003o
Oom:Ool0031oo`03001oogoo0?moogioo`00<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`0U
Ool2000;Ool2003oOom:Ool0031oo`03001oogoo02Eoo`8000]oo`800?moodYoo`00<7oo0P00ogoo
Ogoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo05aoo`800?moob1oo`00<7oo00<007oo
Ool0<goo0P009goo0P00ogoo87oo000`Ool00`00Oomoo`0cOol2003oOom9Ool0031oo`800?moogmo
o`00<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`0bOol2003oOom:Ool0031oo`03001oogoo
039oo`800?moodYoo`00<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`0UOol2003oOomGOol0
031oo`8002Ioo`8000aoo`800?moodUoo`00<7oo00<007ooOol0<goo0P00ogooBGoo000`Ool00`00
Oomoo`3oOomnOol000=oo`8000Moo`<000Ioo`8000Moo`8000Ioo`@000Ioo`03001oogoo0?moogio
o`000Woo00@007ooOol000Ioo`<000Eoo`04001oogoo0005Ool01000Oomoo`0017oo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol0<Woo0P00:7oo0P00ogoo87oo00000goo001oo`03Ool00`00
Oomoo`03Ool30004Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007oo
Ool00goo0`00<Woo0P00:7oo0P00ogoo87oo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomo
o`02Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0<Woo0P00
ogooBWoo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo
00<007ooOol00goo0`001Woo00<007ooOol0<Woo0P00ogooBWoo00000goo001oo`03Ool00`00Oomo
o`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol01Woo00<007ooOol00goo00<0
07ooOol0ogooOWoo00000goo001oo`03Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00<007ooOol01Woo00<007ooOol00goo00<007ooOol0ogooOWoo0002Ool01000Oomoo`00
3Woo00@007ooOol000Eoo`04001oogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`0bOol2003oOom:Ool000=oo`80011oo`8000Moo`8000Ioo`@000Ioo`8003=oo`800?moodYoo`00
<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogioo`00
<7oo00<007ooOol0ogooOWoo000`Ool2003oOomoOol0031oo`03001oogoo0?moogioo`00<7oo00<0
07ooOol0ogooOWoo000`Ool00`00Oomoo`0cOol2003oOom9Ool0031oo`03001oogoo03=oo`800?mo
odUoo`00<7oo00<007ooOol0ogooOWoo000`Ool2003oOomoOol0031oo`03001oogoo0?moogioo`00
<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo03=oo`800?mo
odUoo`00<7oo00<007ooOol0<goo0P00ogooBGoo000`Ool2003oOomoOol0031oo`03001oogoo0?mo
ogioo`00<7oo00<007ooOol02Woo0P00ogooLWoo0003Ool20007Ool30006Ool20007Ool20008Ool3
0005Ool00`00Oomoo`0:Ool2003oOombOol0009oo`04001oogoo0006Ool30005Ool01000Oomoo`00
1Goo00@007ooOol000Qoo`03001oogoo00Aoo`03001oogoo0?moogioo`0000=oo`00Ool00goo00<0
07ooOol00goo0`0017oo00<007ooOol00Woo00D007ooOomoo`0000Aoo`04001oogooOol60005Ool3
003oOomnOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004
Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol0ogooOWoo00000goo001oo`03Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00<007ooOol00Woo00@007ooOol0
00Ioo`03001oogoo0?moogioo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D0
07ooOomoo`0000Aoo`03001oogoo00=oo`03001oo`0000Ioo`03001oogoo0?moogioo`0000=oo`00
Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`03001oogoo00=oo`03
001oo`0000Ioo`03001oogoo00Yoo`800?moog9oo`000Woo00@007ooOol000ioo`04001oogoo0005
Ool01000Oomoo`001goo0P001Woo00<007ooOol02Woo0P00ogooLWoo0003Ool2000@Ool20007Ool2
0009Ool00`00Oomoo`04Ool2003oOomoOol0031oo`03001oogoo0?moogioo`00<7oo00<007ooOol0
<Woo0`00ogooBGoo000`Ool00`00Oomoo`0bOol3003oOom9Ool0031oo`03001oogoo0?moogioo`00
<7oo0P00ogooOgoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogioo`00<7oo00<0
07ooOol0ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogioo`00<7oo0P00
ogooOgoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogioo`00<7oo00<007ooOol0
ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogioo`00<7oo0P00ogooOgoo
000`Ool00`00Oomoo`3oOomnOol002moo`800?mooh1oo`000goo0P001goo0`001Woo0P001goo0P00
1Woo10001Goo0P00ogooP7oo0002Ool01000Oomoo`001Woo0`001Goo00@007ooOol000Eoo`04001o
ogoo0004Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`3oOomnOol00003Ool007oo00=o
o`03001oogoo00=oo`<000Aoo`03001oogoo009oo`05001oogooOol00004Ool00`00Oomoo`06Ool0
0`00Oomoo`03Ool3003oOomnOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05
001oogooOol00004Ool00`00Oomoo`06Ool00`00Oomoo`03Ool00`00Oomoo`3oOomnOol00003Ool0
07oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool01@00Oomoogoo0000
17oo00<007ooOol00goo00<007ooOol0<Woo0P00ogooBWoo00000goo001oo`03Ool00`00Oomoo`0:
Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00@007ooOomoo`D000Ioo`03001oogoo039oo`80
0?moodYoo`0000=oo`00Ool00goo00<007ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Ao
o`05001oogooOol0000:Ool00`00Oomoo`3oOomnOol0009oo`04001oogoo000>Ool01000Oomoo`00
1Goo00@007ooOol000Aoo`03001oogoo00Qoo`03001oogoo0?moogioo`000goo0P0047oo0P001goo
0P001Goo1@001Woo0P00ogooOgoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogio
o`00<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`8003Aoo`800?moodUo
o`00<7oo00<007ooOol0<goo0P00ogooBGoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo
0?moogioo`00<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`800?moogmo
o`00<7oo00<007ooOol0ogooOWoo000`Ool00`00Oomoo`3oOomnOol0031oo`03001oogoo0?moogio
o`00<7oo00<007ooOol0ogooOWoo000`Ool2003oOomoOol0031oo`03001oogoo0?moogioo`00<7oo
00<007ooOol0ogooOWoo000`Ool00`00Oomoo`0cOol2003oOom9Ool000=oo`8000Moo`<000Ioo`80
00Moo`8000Ioo`@000Ioo`03001oogoo03=oo`800?moodUoo`000Woo00@007ooOol000Ioo`<000Eo
o`04001oogoo0005Ool01000Oomoo`0017oo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
ogooOWoo00000goo001oo`03Ool00`00Oomoo`03Ool30004Ool00`00Oomoo`02Ool01@00Oomoogoo
000017oo00D007ooOomoo`0000Aoo`03001oogoo00=oo`<00?moogioo`0000=oo`00Ool00goo00<0
07ooOol02Woo00<007ooOol00Woo00D007ooOomoo`0000Aoo`05001oogooOol00004Ool00`00Oomo
o`03Ool00`00Oomoo`3oOomnOol00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05
001oogooOol00004Ool01000Oomoogoo0P000goo00<007ooOol0ogooQ7oo00000goo001oo`03Ool0
0`00Oomoo`0:Ool00`00Oomoo`02Ool01@00Oomoogoo000017oo00H007ooOomoo`00Ool3003oOon7
Ool00003Ool007oo00=oo`03001oogoo00Yoo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`02Ool00`00Oomoo`3oOon8Ool0009oo`04001oogoo000>Ool01000Oomoo`001Goo00@007oo
Ool000Eoo`800?moohUoo`000goo0P0047oo0P001goo0P0027oo0`00ogooQWoo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol002Moo`03001oogoo00moo`03001oogoo0?moogEoo`009goo00<0
07ooOol03goo00<007ooOol0ogooMGoo000WOol00`00Oomoo`0?Ool00`00Oomoo`3oOomeOol002Mo
o`03001oogoo00=oo`H000Ioo`03001oogoo0?moogEoo`009goo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol0ogooMGoo000WOol00`00Oomoo`05Ool00`00Oomoo`07Ool00`00Oomoo`3oOome
Ool002Moo`03001oogoo00Eoo`03001oogoo00Moo`03001oogoo0?moogEoo`009goo00<007ooOol0
1Goo00<007ooOol01goo00<007ooOol0ogooMGoo000WOol00`00Oomoo`05Ool00`00Oomoo`07Ool0
0`00Oomoo`3oOomeOol002Moo`03001oogoo00=oo`H000Ioo`03001oogoo0?moogEoo`009goo00<0
07ooOol01Goo00<007ooOol01goo00<007ooOol0ogooMGoo000WOol00`00Oomoo`05Ool00`00Oomo
o`07Ool00`00Oomoo`3oOomeOol0031oo`<00?moogioo`00;Woo00@007oo00000?moogmoo`00;goo
00@007ooOol00?moogioo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo
003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mo
ok5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo003oOonaOol00?mook5oo`00ogoo/Goo
003oOonaOol00001\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {-520, 0, 16, 0}}]
}, Open  ]],

Cell["\<\
A series of peaks are evident in the spectrum, which  represent \
harmonics that are important to the \"ahhh\" sound. There is also a broad \
spectrum of low-level noise in the data, evident up to quite large \
frequencies.  We can reduce this noise by applying a  high-frequency filter \
to the frequency data. We will simply multiply all the data by an exponential \
factor that reduces the amplitude of the high frequencies:\
\>", "Text",
  CellTags->"i:57"],

Cell[BoxData[
    \(\(lowerhalf = 
        Table[f\&~[\([n]\)] Exp[\(-n\)/600. ], {n, 1, nn/2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.81"],

Cell[TextData[{
  "We only run this filter over half of the data because the upper half of \
the spectrum corresponds to negative frequencies. To add in the \
negative-frequency half of the spectrum, it is easiest to simply use Eq. ",
  ButtonBox["(2.3.66)",
    ButtonData:>"(2.3.66)",
    ButtonStyle->"Hyperlink"],
  ", which is just a statement that the upper half of the spectrum is the \
complex conjugate of the lower half, written in reverse order:"
}], "Text"],

Cell[BoxData[
    \(\(upperhalf = Reverse[Conjugate[lowerhalf]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.82"],

Cell[TextData[{
  "However, the lower half includes the zero-frequency point, while the upper \
half excludes this point. [Frequencies run from 0 to ",
  Cell[BoxData[
      \(TraditionalForm\`\((N - 1)\) \[CapitalDelta]\[Omega]\)]],
  ".] This zero-frequency point is the last point in the upperhalf, at \
position ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            SubscriptBox[
              StyleBox["n",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], "last"], "=", 
            " ", \(Length[upperhalf]\)}],
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\(n\_last = \ Length[upperhalf]\) \)\(;\)\(\(upperhalf = 
        Delete[upperhalf, n\_last]\) \)\(;\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.83"],

Cell["\<\
We now join these two lists together to get our new spectrum:\
\>", \
"Text"],

Cell[BoxData[
    \(\(f\&~\_new\  = \ Join[lowerhalf, upperhalf];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.84"],

Cell[TextData[{
  "Since the length ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "of the original data was even, the new data has one less point, because in \
the above cut-and-paste process we have neglected the center point in the \
spectrum at the Nyquist frequency. This makes a negligible difference to the \
sound."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Length[f\&~\_new]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.85"],

Cell[BoxData[
    \(36863\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tAfter inverse Fourier-transforming, we can play this resulting sound \
data using the ",
  StyleBox["ListPlay",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command, choosing to play at the original sample rate of 22050 hertz \
(Cell ",
  ButtonBox["2.86",
    ButtonData:>"Cell 2.86",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text",
  CellTags->"i:104"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(ffiltered = \ InverseFourier[f\&~\_new];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(ListPlay[ffiltered, SampleRate \[Rule] \ samplerate]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.86"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
22050. 36863 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound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pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00Oo`00J@0000000`00
Oomoo`3oOomUOol100000003001oogoo0=1oo`800004Ool00000Ool200001Goo00000000Ool00P00
QGoo0@0000000`00Oomoo`2;Ool01@00Ool00000Ool0100017oo0P0000=oo`0000005goo1@0000Ao
o`00001oo`800004Ool00000Ool2000017oo000007oo1P0000Aoo`00001oo`800004Ool00000Ool3
000017oo000007oo0P0000Aoo`00001oo`80025oo`03001oo`0000Yoo`03001oogoo04]oo`400000
00<007ooOol0RGoo3@0000=oo`0000001P0037oo00D007oo000007oo00800003Ool0000000@00004
Ool00000Ool2000017oo000007oo0P0000Aoo`00001oo`l00003Ool0000000L00004Ool00000Ool2
00001Goo000007oo00005Goo0P0000Aoo`00001oo`800003Ool0000000@00004Ool00000Ool20000
17oo000007oo1P00@goo0@0000000`00Oomoo`1lOol00`00Oomoo`04OolN00001Goo00000000Ool0
@P0000Aoo`00001ooa800004Ool00000Ool200000goo0000000300000goo00000004000017oo0000
07oo1@0000=oo`000000100000Aoo`00001oo`800003Ool007oo03Yoo`40000000<007ooOol0O7oo
00H007ooOomoo`00Oon[000gOol100000003001oogoo07aookL0035oo`40000000<007ooOol0LWoo
0`0017oo`0002Goo00<007ooOol047oo00<007ooOol037oo0@0000000`00Ool0003o001T0001Ool1
00000003001oo`000?l005@00003Ool0000000d0005oo`40000000<007ooOol0NWoo^P00<7oo0@00
00000`00Oomoo`1lOol300000goo0000002`000bOol100000003001oogoo085oo`03001oo`0002D0
0003Ool0000000`00003Ool0000001H00004Ool00000Ool500000goo0000000400000goo00000018
00001Goo000007oo0000<goo0@0000000`00Oomoo`23Ool200000goo0000002K00001Goo000007oo
00000goo00@007ooOol003Eoo`40000000<007ooOol0Q7oo00@007ooOomooaL0009oo`03001oo`00
03X00003Ool0000000P0009oo`800004Ool00000Ool2000017oo000007oo1P0000Aoo`00001oo`80
00Eoo`06001oogoo001oo`001goo0P001Goo00<007ooOol0AGoo0@0000000`00Oomoo`2:Ool20000
0goo0000000?0005Ool2000017oo001oogoo0P004Woo00D007ooOol007oo00800004Ool00000Ool2
00000goo0000000A00000goo00000023Ool100000003001oogoo08]oo`05001oo`00001oo`050004
Ool2000eOol2000017oo000007oo0P0000Aoo`00001oo`8008Ioo`40000000<007ooOol0ogooIGoo
0@00003o001Y00000003001oogoo0?moofEoo`40000000<007ooOol0TGoo00<007oo00000Woo00D0
07ooOomoo`0003Ioo`05001oogoo001oo`02002<Ool100000003001oogoo095oo`03001oogoo00Io
o`03001oogoo03Yoo`03001oo`00009oo`03001oogoo08Eoo`40000000<007ooOol0UWoo00@007oo
Oomoo`8003Moo`800003Ool007oo00Aoo`03001oogoo08Eoo`40000000<007ooOol0TGoo00H007oo
000007oo0004Ool00`00Oomoo`0`Ool01@00Ool00000Ool00P0000Aoo`00Oomoo`800003Ool007oo
08Ioo`40000000<007ooOol0T7oo00D007ooOomoo`0003Uoo`03001oo`00009oo`03001oogoo00D0
009oo`03001oogoo08Aoo`40000000<007ooOol0T7oo00<007ooOol00goo00@007oo001oo`8003ao
o`<0009oo`03001oogoo08Aoo`40000000<007ooOol0T7oo0P000Woo00<007ooOol00P000Woo00<0
07ooOol0;goo0P0000=oo`00Ool00P0000Aoo`00001oo`<00004Ool000000025Ool100000003001o
ogoo08ioo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo02ioo`04001oo`00Ool50003Ool0
0`00Oomoo`27Ool100000003001oogoo08eoo`800005Ool007ooOol00002Ool300000goo0000000T
Ool00`00Oomoo`03Ool00`00Ool00004Ool01@00Ool00000Ool00P000Woo00<007ooOol00P0000=o
o`0000000P00Q7oo0@0000000`00Oomoo`2=Ool20002Ool00`00Ool00003Ool00`00Oomoo`0VOol0
0`00Oomoo`02Ool20002Ool00`00Oomoo`02000017oo000007oo0`000Woo0`000goo0P00QGoo0@00
00000`00Oomoo`2<Ool300000goo001oo`02Ool01000Oomoo`000Woo00@007ooOol001moo`04001o
ogoo0004Ool200000goo00000002Ool60003Ool200000goo00000002Ool200000goo00000023Ool1
00000003001oogoo08]oo`03001oo`0000=oo`03001oogoo00Aoo`04001oogoo000NOol01000Oomo
o`0017oo0P0000=oo`0000000Woo00@007ooOol000Ioo`04001oogoo0005Ool01@00Oomoogoo0000
Pgoo0@0000000`00Oomoo`2<Ool00`00Ool00004Ool01P00Oomoo`00Ool0009oo`03001oo`0001ao
o`04001oogoo0002Ool00`00Ool0000200000goo001oo`0300000goo00000004Ool2000017oo001o
ogoo0`0000=oo`000000QWoo0@0000000`00Oomoo`2;Ool00`00Oomoo`02Ool300000goo001oo`02
0002Ool01000Ool000001Woo00<007ooOol04Woo0P000Woo00<007oo0000100000=oo`00Ool00goo
1`0017oo00@007oo001oo`8000=oo`800003Ool007oo085oo`40000000<007ooOol0RWoo00@007oo
000000Ioo`04001oogooOol2000:Ool00`00Oomoo`03Ool00`00Oomoo`0:Ool01P00Ool00000Ool0
009oo`06001oogoo001oo`0017oo00<007oo00000goo00D007ooOomoo`00009oo`03001oogoo00=o
o`8000=oo`<0081oo`40000000<007ooOol0RWoo00D007oo001oo`0000=oo`04001oogoo0005Ool3
0006Ool00`00Oomoo`03Ool01@00Oomoogoo00001goo0P000Woo10001Goo00D007ooOol007oo0080
00Qoo`80009oo`03001oogoo00=oo`<00004Ool007oo0021Ool100000003001oogoo08Yoo`80009o
o`03001oogoo00800003Ool0000000eoo`800003Ool007oo009oo`05001oogooOol00007Ool20000
0goo001oo`020003Ool40002Ool00`00Oomoo`03Ool200000goo00000002Ool30002Ool01@00Oomo
ogoo00000Woo00D007oo001oo`00009oo`03001oogoo07]oo`40000000<007oo0000RGoo1@000Woo
0P0000=oo`000000100000Aoo`00001oo`8000Aoo`800005Ool007ooOol00004Ool00`00Oomoo`06
Ool01@00Ool00000Ool01@0000Aoo`00001oo`800005Ool00000001oo`020002Ool50002Ool01000
Ool000000Woo00X007oo000007oo001oo`00Ool002Aoo`03001oogoo00Uoo`03001oogoo04Yoo`40
000000<007ooOol0RGoo0P000goo00@007ooOol0009oo`03001oogoo00<00005Ool007ooOol0000:
Ool20002Ool00`00Oomoo`06Ool200001Goo001oogoo00002Woo00<007oo00000Woo00H007ooOol0
07oo0004Ool200000goo001oo`09Ool2000UOol00`00Oomoo`1FOol100000003001oogoo08aoo`D0
00Aoo`04001oo`000005Ool00`00Oomoo`02Ool01000Oomoo`000goo00<007oo00000P001goo0P00
0goo00H007oo000007oo0002Ool200000goo001oo`0400000goo001oo`0200000goo00000006Ool0
0`00Ool00003Ool2000017oo000000009Goo00<007ooOol02Goo00<007ooOol0BWoo0@0000000`00
Oomoo`27Ool01P00Ool00000Ool000Aoo`800004Ool007ooOol20003Ool30004Ool20004Ool90004
Ool20002Ool01@00Oomoo`00Ool01@000Woo0P0000Eoo`00001oo`00009oo`8000Aoo`8000=oo`04
001oo`00Ool:000SOol00`00Oomoo`0<Ool20018Ool100000003001oogoo08Moo`03001oogoo00=o
o`800003Ool007oo00=oo`03001oo`0000=oo`03001oogoo00Uoo`03001oo`0000800003Ool007oo
008000=oo`03001oo`00009oo`800003Ool007oo009oo`03001oo`00009oo`<000ioo`80009oo`04
001oogoo0002Ool00`00Oomoo`03Ool2000^Ool00`00Oomoo`02Ool00`00Oomoo`16Ool100000003
001oogoo08Moo`04001oo`000002Ool01000Ool007oo0P000goo0P000goo00<007ooOol027oo0P00
0goo0`0000Moo`00Oomoo`00Ool00002Ool4000AOol00`00Ool00004Ool00`00Oomoo`04Ool01000
Oomoo`001Goo00D007oo001oo`0000=oo`03001oogoo00Aoo`03001oogoo01Ioo`05001oogooOol0
0006Ool20002Ool20018Ool100000003001oogoo08Moo`03001oo`000080009oo`05001oogoo001o
o`020005Ool01@00Oomoogoo000017oo1@000Woo0P0000Aoo`00Oomoo`<00004Ool007oo0002Ool0
1@00Oomoogoo00001Goo00D007oo000007oo00<00005Ool007ooOol00002Ool00`00Oomoo`02Ool3
0002Ool40003Ool30002Ool01000Oomoo`001Woo00<007ooOol00goo00<007ooOol01goo00<007oo
Ool02Woo00<007ooOol017oo00T007oo001oo`00Ool007oo0000AGoo0@0000000`00Oomoo`27Ool0
0`00Oomoo`020003Ool20003Ool01P00Oomoogoo001oo`800003Ool007oo00Eoo`800003Ool00000
00l00005Ool00000001oo`040002Ool00`00Oomoo`080002Ool01P00Ool00000Ool000=oo`04001o
ogoo0003Ool01000Ool000000Woo0`000Woo00@007oo000000=oo`06001oogooOol007oo0P000Woo
00<007ooOol00Woo0`0017oo0P0000Aoo`00001oo`8000Aoo`80009oo`L004Eoo`40000000<007oo
Ool0Qgoo00<007oo00000Woo0P002Goo0`0027oo00@007oo001oo`D0009oo`800003Ool007oo0080
009oo`8000Aoo`03001oogoo00Eoo`03001oo`0000Uoo`03001oogoo00=oo`03001oogoo009oo`0;
001oogooOol007oo001oo`00Ool00002Ool01000Ool000000goo00<007ooOol00goo0P0000=oo`00
00000Woo00H007ooOomoo`00Ool20007Ool3000017oo001oo`000Woo1`000goo00<007ooOol0@goo
0@0000000`00Oomoo`2:Ool00`00Oomoo`0200000goo001oo`03Ool00`00Oomoo`03Ool01000Oomo
o`001Woo00<007ooOol01Goo00@007ooOol0009oo`<000Uoo`@00005Ool00000Ool00004Ool01@00
Oomoogoo000027oo00<007ooOol01goo0P0000=oo`0000000`0000=oo`00Ool00`0000=oo`00Ool0
17oo1@0017oo0P001Goo00<007ooOol00goo00<007ooOol00P0000=oo`0000000goo00<007oo0000
0P00AWoo0@0000000`00Oomoo`26Ool200000goo001oo`02Ool2000017oo000007oo0`0000Uoo`00
001oo`00Ool007oo00000Woo10000Woo0P0000=oo`0000000P0000=oo`000000100000=oo`00Ool0
0`0000=oo`0000000goo0P001Woo00H007ooOomoo`00Ool300001goo00000000Ool007oo00<00003
Ool007oo00=oo`06001oogooOol007oo1P0000Aoo`00001oo`800004Ool00000Ool60002Ool01@00
Ool00000Ool00P0000=oo`000000100000=oo`00Ool020000Woo0P0000=oo`00Ool00P00@Woo0@00
00000`00Oomoo`26Ool20002Ool00`00Oomoo`04Ool200000goo001oo`04Ool30004Ool01000Ool0
00000Woo0`000goo00<007oo00000P0000=oo`00Ool00Woo00@007ooOol0009oo`03001oo`0000=o
o`03001oogoo009oo`<00005Ool00000Ool00002Ool30009Ool01P00Ool00000Ool0009oo`800003
Ool000000080009oo`80009oo`03001oogoo00800004Ool007ooOol30002Ool300001Goo001oogoo
000027oo0P0000=oo`00Ool00Woo0`000goo00<007ooOol0@goo0@0000000`00Oomoo`29Ool20008
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`07Ool00`00Oomoo`02
000017oo000007oo0P000Woo00@007ooOol000Eoo`03001oogoo008000Eoo`8000ioo`03001oogoo
00<000=oo`800004Ool000000006Ool20002Ool01P00Ool00000Ool000=oo`03001oo`0000800003
Ool007oo0080009oo`80009oo`@00003Ool007oo009oo`@00004Ool000000011Ool100000003001o
ogoo08Ioo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Uoo`800003Ool007oo009oo`03
001oo`00009oo`800006Ool007oo001oo`000goo00<007oo00000goo100000Eoo`00Oomoo`0000=o
o`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0002Ool00`00Oomoo`0200001Goo001oogoo
00002Goo00<007ooOol00Woo0P000Woo00<007ooOol00P000goo1P0000Ioo`00Ool007oo0002Ool0
0`00Oomoo`03Ool00`00Ool00007Ool00`00Oomoo`03Ool20011Ool100000003001oogoo08Ioo`<0
0009Ool00000Ool007oo001oo`0000Eoo`06001oogooOol007oo1`000goo100000Moo`00000007oo
001oo`0300000goo001oo`03Ool00`00Oomoo`02Ool01@00Ool00000Ool00P0000Ioo`00000007oo
0002Ool01000Oomoo`000Woo100000Aoo`00Ool0009oo`06001oogooOol007oo0P0000Aoo`00001o
o`<00003Ool00000009oo`05001oo`00001oo`0:00001Goo00000000Ool02@0000Aoo`00001oo`<0
0004Ool00000Ool20002Ool01P00Ool00000Ool003moo`40000000<007ooOol0Q7oo00H007oo0000
07oo0002Ool01@00Ool007oo00000goo00<007oo00000P0000=oo`00Ool00goo0`000Woo00<007oo
Ool00goo0P0000Eoo`00001oo`00009oo`80009oo`03001oogoo00Uoo`05001oogooOol00003Ool0
0`00Ool00008Ool00`00Oomoo`05Ool01000Oomoogoo0P000Woo10000goo00<007oo00000goo00<0
07oo00000P000goo0P000Woo00@007ooOol0009oo`03001oogoo00Aoo`05001oo`00Ool00003Ool5
00001Goo001oo`00Ool00`0000Aoo`00Ool003moo`40000000<007ooOol0Q7oo00L007ooOomoo`00
Ool00002Ool200000goo001oo`0<Ool00`00Ool00003Ool01000Oomoogoo0P000Woo00P007ooOol0
07oo001oo`0027oo00@007ooOol000Uoo`800004Ool007oo000;Ool00`00Oomoo`06Ool40003Ool4
0002Ool20003Ool01000Oomoo`000goo00@007oo0000009oo`L000=oo`04001oo`00Ool2000017oo
001oo`0017oo00<007ooOol00`0000Aoo`00001oo`8003ioo`40000000<007ooOol0Q7oo00@007oo
001oo`<0009oo`05001oogooOol00002Ool2000017oo0000000017oo1@0000=oo`00Ool00P000Woo
00X007ooOol007oo001oo`00Ool000=oo`05001oo`00001oo`0200000goo00000004000017oo001o
o`001goo00@007oo000000=oo`04001oo`000002Ool00`00Oomoo`020004Ool:0002Ool2000017oo
001oogoo0P0000Eoo`00Ool007oo00@000=oo`<00005Ool00000001oo`0300001Woo000007oo001o
o`<00003Ool00000009oo`04001oo`00Ool300000goo001oo`0kOol100000003001oogoo08Aoo`80
00Qoo`06001oogoo001oo`001Woo0`0000Ioo`00Ool007oo0002Ool00`00Ool00004Ool01@00Oomo
ogoo000017oo0P0000Aoo`000000009oo`04001oogoo000;Ool01@00Oomoogoo00001Woo00<007oo
00001Woo00<007ooOol00goo00<007ooOol017oo00<007oo00000Woo0P0000=oo`0000000goo1@00
1Goo0P0000=oo`00Ool01Woo00<007ooOol00Woo00D007ooOomoo`0000Ioo`03001oo`0000@00003
Ool007oo03]oo`40000000<007ooOol0Q7oo00@007oo0000009oo`04001oo`000002Ool00`00Oomo
o`02Ool01000Oomoo`001Woo00D007oo001oo`00009oo`03001oogoo009oo`03001oogoo009oo`03
001oogoo00Aoo`04001oogoo000>Ool00`00Oomoo`07Ool00`00Ool00005Ool20005Ool200000goo
001oo`02Ool01000Oomoo`000goo00@007ooOol0009oo`03001oo`00009oo`04001oogooOol20000
1Goo000007oo00000Woo00<007ooOol00P0000Aoo`00001oo`80009oo`04001oogoo0002Ool20000
0goo00000002Ool2000017oo00000000?7oo0@0000000`00Oomoo`24Ool01@00Ool007oo00002goo
00@007ooOol000Eoo`05001oogooOol00005Ool30003Ool01000Oomoogoo100000Aoo`00001oo`80
00=oo`03001oogoo00Aoo`8000Ioo`03001oo`0000Eoo`03001oogoo00Uoo`03001oogoo0080009o
o`8000Eoo`03001oogoo0080009oo`03001oo`0000=oo`04001oogoo0004Ool00`00Oomoo`030002
Ool20003Ool200000goo001oo`03Ool30002Ool00`00Oomoo`03Ool01000Oomoo`00?7oo0@000000
0`00Oomoo`24Ool70002Ool200001Goo000007oo00001Woo0`0000=oo`00Ool00P000Woo00<007oo
00000P000Woo00@007oo001oo`8000=oo`03001oogoo00Eoo`D00003Ool007oo009oo`800004Ool0
0000Ool20002Ool01000Oomoo`000Woo00@007ooOol000=oo`05001oo`00001oo`020004Ool00`00
Ool0000300000goo0000000300001goo001oo`00Ool007oo00800006Ool00000Ool007oo100000=o
o`00Ool00P0017oo00D007ooOol007oo00800004Ool007ooOol>000kOol100000003001oogoo08Ao
o`04001oogoo0002Ool00`00Oomoo`02Ool01000Oomoo`0037oo00<007oo00001Goo00@007ooOol0
00Eoo`03001oogoo008000Ioo`03001oogoo00Eoo`03001oogoo00800004Ool007ooOol20005Ool0
0`00Oomoo`07Ool200000goo001oo`04Ool20004Ool00`00Oomoo`020004Ool20002Ool00`00Oomo
o`020004Ool01000Oomoogoo0P000goo0P0000=oo`0000000goo0P0000=oo`0000000Woo00D007oo
Oomoo`00009oo`D00003Ool0000003]oo`40000000<007ooOol0Q7oo00L007ooOol007oo001oo`02
0002Ool00`00Oomoo`03Ool01000Oomoo`0017oo0P0000=oo`00Ool00Woo00<007ooOol00Woo00<0
07ooOol00`001goo0P0000Eoo`00Oomoo`0000Ioo`05001oogoo001oo`030005Ool20004Ool01000
Oomoo`0037oo00T007ooOomoo`00Ool007oo00000goo00@007ooOol0009oo`03001oogoo00Eoo`03
001oogoo009oo`06001oo`00001oo`000goo0P001Goo00<007ooOol02Woo00@007ooOol0009oo`03
001oo`0003Uoo`40000000<007ooOol0Pgoo1@000Woo00<007ooOol00P000Woo00@007ooOol0009o
o`80009oo`03001oogoo0080000:Ool00000001oo`00Ool007oo0002Ool03000Oomoo`00Ool007oo
001oo`00Ool0009oo`04001oo`000002Ool02000Oomoo`00Ool007oo0003Ool20002Ool00`00Oomo
o`030002Ool20003Ool00`00Oomoo`04Ool20003Ool30005Ool01@00Ool00000Ool00P0000=oo`00
0000100000=oo`00Ool00P0000=oo`00000017oo00@007oo001oo`800003Ool0000000Eoo`800004
Ool00000Ool20002Ool00`00Oomoo`0400000goo0000000hOol100000003001oogoo08=oo`80009o
o`80009oo`03001oogoo00Eoo`03001oogoo00Aoo`80009oo`03001oo`0000=oo`04001oogoo0002
Ool01000Oomoo`000goo00@007ooOol000Yoo`8000aoo`05001oogooOol00008Ool01000Oomoo`00
1goo00D007ooOomoo`0000=oo`03001oo`0000=oo`03001oo`00009oo`04001oogoo0002Ool30002
Ool00`00Oomoo`06Ool01@00Oomoo`00Ool00P0000=oo`00Ool00Woo00<007oo000027oo0`0000Qo
o`00000007oo001oo`00=Woo0@0000000`00Oomoo`23Ool00`00Oomoo`04Ool01000Ool000000Woo
0P000Woo00D007ooOol007oo008000Eoo`03001oogoo009oo`03001oogoo00Qoo`04001oogoo000@
Ool20004Ool00`00Ool0000?Ool01@00Oomoogoo00001Woo00<007ooOol00Woo0P0000Eoo`00Oomo
o`0000=oo`03001oogoo00=oo`03001oo`0000Ioo`04001oogoo0004Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00P000Woo100000=oo`00Ool0=Goo0@0000000`00
Oomoo`23Ool01@00Oomoogoo00003Woo00<007oo000027oo00H007ooOol007oo0004Ool00`00Oomo
o`02Ool01000Ool0000017oo00<007ooOol00Woo00@007ooOomoo`800003Ool007oo00moo`03001o
ogoo009oo`03001oogoo009oo`04001oo`000002Ool20005Ool01`00Oomoogoo001oo`0000=oo`80
00Moo`04001oogoo0002Ool00`00Ool000020002Ool00`00Oomoo`020007Ool200000goo001oo`02
Ool20004Ool01000Ool000000Woo00<007oo0000=Woo0@0000000`00Oomoo`23Ool4000017oo0000
00000Woo0P0000=oo`0000000goo00<007oo000017oo10000goo0P0000Moo`00000007oo001oo`02
0005Ool2000017oo000007oo0P000Woo00<007oo00001Woo0P0000=oo`00Ool00goo00<007ooOol0
1Goo0P0000Eoo`00001oo`00009oo`800003Ool0000000Aoo`<00003Ool007oo009oo`800004Ool0
07oo0006Ool200001Goo001oo`00Ool0100000Eoo`00Oomoo`00009oo`03001oogoo00<00003Ool0
07oo008000=oo`800004Ool007ooOol2000017oo000007oo100000=oo`00Ool0=Goo0@0000000`00
Oomoo`24Ool00`00Ool00002Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20005Ool00`00Oomoo`05
Ool00`00Oomoo`03Ool00`00Ool00007Ool01P00Oomoogoo001oo`8000=oo`03001oogoo009oo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`80009oo`05001oogooOol00005Ool00`00
Oomoo`04Ool20007Ool00`00Oomoo`02Ool20004Ool300000goo001oo`02Ool01@00Oomoogoo0000
0goo0P000goo00@007ooOol000Eoo`03001oo`00009oo`04001oogoo0002Ool200001Goo000007oo
0000=Woo0@0000000`00Oomoo`23Ool20002Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomo
o`001goo0`0017oo00@007ooOol0009oo`80009oo`04001oogoo0007Ool30007Ool200001Goo0000
07oo00000Woo00<007ooOol02Goo00<007ooOol00goo00@007ooOol000Eoo`03001oo`00009oo`03
001oogoo00800003Ool007oo00Aoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo00Uoo`05
001oogooOol00008Ool2000017oo001oogoo0P00=Goo0@0000000`00Oomoo`23Ool00`00Oomoo`02
Ool00`00Ool00004Ool20003Ool01`00Oomoo`00Ool007oo00800003Ool000000080009oo`8000io
o`03001oogoo00=oo`@0009oo`03001oogoo00=oo`03001oogoo00=oo`8000Aoo`8000Eoo`03001o
ogoo00=oo`8000Aoo`<00003Ool007oo009oo`@00004Ool007ooOol200000goo00000003000017oo
000007oo0P0000Eoo`00001oo`0000Aoo`05001oo`00001oo`0200000goo0000000200000goo001o
o`04Ool01000Ool007oo0`000Woo0P0000=oo`00Ool00`00=7oo0@0000000`00Oomoo`23Ool01@00
Ool007oo00002Goo00<007ooOol00goo00<007ooOol01goo0P000goo0P000Woo00<007oo00001000
17oo0P0037oo00@007oo000000=oo`03001oogoo00Ioo`05001oogooOol00003Ool00`00Oomoo`08
Ool01000Oomoo`000goo00@007ooOol000Yoo`03001oogoo009oo`8000Ioo`05001oogooOol00004
Ool20005Ool200000goo00000004Ool00`00Oomoo`06Ool00`00Ool00002Ool00`00Oomoo`0bOol1
00000003001oogoo08=oo`03001oogoo0080009oo`<00003Ool007oo009oo`03001oogoo00Eoo`80
00Qoo`03001oogoo009oo`800003Ool007oo00Eoo`03001oogoo00eoo`03001oogoo00=oo`80009o
o`04001oogoo0002Ool00`00Oomoo`07Ool01000Oomoo`001goo00<007ooOol01Goo00<007ooOol0
1Goo00<007ooOol00goo0P000goo0`0000=oo`00Ool00goo00D007ooOol007oo00800003Ool00000
009oo`04001oogoo0002Ool20002Ool02000Ool007oo001oo`00Ool2000017oo00000000=7oo0@00
00000`00Oomoo`20Ool00`00Oomoo`0:Ool00`00Ool00003Ool01000Oomoogoo0P0000Aoo`00001o
o`<00003Ool007oo008000Eoo`04001oogoo0003Ool00`00Ool00008Ool00`00Oomoo`08Ool20003
Ool01@00Oomoogoo00002Goo00<007ooOol00P000goo00<007ooOol01Goo00<007oo000027oo0P00
0Woo00H007ooOol007oo0009Ool01000Oomoo`0017oo00<007ooOol017oo00D007ooOomoo`0000Mo
o`04001oogooOol300000goo00000002000eOol100000003001oogoo081oo`03001oo`000080000:
Ool007oo001oo`00Ool007oo0003Ool20009Ool200000goo001oo`02Ool200001Woo00000000Ool0
00Aoo`@0009oo`8000Moo`80000:Ool007ooOol007oo001oo`00Ool30003Ool300000goo00000005
Ool01@00Oomoogoo00000Woo0`0000=oo`0000000goo00<007ooOol01@0000=oo`00Ool00P000Woo
00D007oo001oo`0000Eoo`03001oo`0000<0009oo`8000Eoo`04001oogooOol200000goo00000006
0002Ool00`00Ool000040002Ool2000dOol100000003001oogoo081oo`04001oo`000002Ool20000
0goo00000002Ool01000Oomoo`0047oo00<007ooOol017oo00<007ooOol00Woo0P0027oo00<007oo
00000Woo00@007ooOol000=oo`03001oogoo00Moo`04001oogoo0005Ool00`00Ool00006Ool00`00
Oomoo`0;Ool00`00Oomoo`04Ool00`00Oomoo`05Ool01000Oomoo`000Woo00<007ooOol017oo0P00
2Woo00<007ooOol017oo00<007ooOol037oo1P00<goo0@0000000`00Oomoo`22Ool20003Ool00`00
Ool0000;Ool00`00Oomoo`020006Ool00`00Ool00002Ool00`00Oomoo`0<Ool01@00Ool007oo0000
27oo00H007ooOol007oo0008Ool00`00Oomoo`02Ool00`00Oomoo`0;Ool01@00Oomoogoo00000goo
00<007ooOol00Woo00<007ooOol01goo00<007ooOol017oo0P0000Eoo`00Oomoo`0000Aoo`03001o
ogoo008000=oo`03001oo`0000=oo`03001oogoo00=oo`03001oo`0000=oo`03001oogoo00=oo`05
001oogoo001oo`02000bOol100000003001oogoo081oo`03001oo`00009oo`8000Aoo`03001oo`00
009oo`80009oo`07001oogooOol007oo00000goo0P0000Aoo`00Ool0009oo`80009oo`800005Ool0
07ooOol00002Ool200000goo001oo`030002Ool01000Oomoogoo0P0000=oo`00Ool017oo00<007oo
00001Woo0P0017oo00<007ooOol01Goo00@007ooOomoo`80009oo`D0009oo`03001oo`0000=oo`08
001oo`00Ool007oo001oo`80009oo`07001oo`00Ool007oo00000goo00<007oo00000Woo0`0000Mo
o`00Oomoo`00Ool00003Ool20002Ool400000goo0000000300000goo00000003000bOol100000003
001oogoo081oo`03001oogoo00Eoo`03001oogoo015oo`03001oogoo00Eoo`03001oogoo009oo`04
001oogoo0006Ool20002Ool00`00Ool00003Ool200000goo001oo`03Ool2000:Ool2000<Ool00`00
Oomoo`06Ool00`00Oomoo`02Ool20006Ool01@00Oomoogoo00001Goo00<007ooOol00goo00<007oo
Ool01Woo0P001Woo0P000goo00<007ooOol00goo00<007ooOol00Woo00D007oo000007oo00L0039o
o`40000000<007ooOol0PWoo0`000Woo00<007ooOol02Woo100027oo00<007ooOol00P000Woo00<0
07ooOol047oo00D007ooOomoo`0000]oo`05001oogooOol0000:Ool00`00Oomoo`0:Ool01000Oomo
o`001Goo00D007ooOomoo`0000Eoo`03001oo`0000Eoo`80009oo`03001oogoo00Aoo`03001oo`00
00=oo`03001oogoo009oo`03001oogoo00]oo`8000Moo`03001oogoo03=oo`40000000<007ooOol0
Qgoo00<007ooOol017oo00<007ooOol017oo00<007ooOol01Woo0P000Woo00<007oo00000Woo00<0
07ooOol037oo00<007ooOol03Woo00<007oo00001Woo00<007ooOol00Woo00<007oo00002Goo0P00
00=oo`00Ool02Woo00H007oo000007oo0002Ool200000goo001oo`03Ool00`00Ool00004Ool01000
Ool007oo0P0017oo0P0000=oo`00000027oo00H007ooOol007oo0003Ool00`00Oomoo`06Ool00`00
Oomoo`0aOol100000003001oogoo081oo`D00003Ool007oo009oo`09001oogoo001oo`00Ool007oo
008000Eoo`8000Eoo`03001oogoo00=oo`03001oogoo009oo`@00003Ool007oo009oo`03001oogoo
00=oo`80009oo`800003Ool007oo009oo`800005Ool007ooOol00002Ool00`00Oomoo`08Ool40000
0goo001oo`02Ool00`00Oomoo`020005Ool00`00Oomoo`02Ool00`00Oomoo`040003Ool01`00Ool0
0000Ool007oo00<0009oo`03001oogoo00Aoo`8000Eoo`05001oo`00001oo`020002Ool01000Oomo
o`000Woo00D007ooOol007oo00800003Ool0000000<0039oo`40000000<007ooOol0P7oo0P0000Ao
o`00001oo`8000=oo`06001oogoo001oo`002Woo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool01Woo00<007oo00000Woo00<007ooOol01goo00@007ooOol0009oo`03001oogoo00Aoo`03001o
o`0000Eoo`<0009oo`03001oo`0000=oo`03001oogoo00Uoo`04001oogoo0003Ool200000goo001o
o`05Ool00`00Ool0000=Ool00`00Ool00002Ool00`00Oomoo`06Ool00`00Oomoo`04Ool00`00Ool0
0002Ool00`00Oomoo`08000bOol100000003001oogoo08Moo`04001oogooOol30009Ool00`00Ool0
0002Ool300001goo001oogoo001oo`0000=oo`8000=oo`04001oogoo0005Ool00`00Ool00002Ool0
0`00Oomoo`04Ool01000Oomoo`000Woo0P0000=oo`00Ool027oo00<007ooOol017oo00@007ooOol0
00Eoo`04001oogoo0002Ool00`00Oomoo`02000=Ool00`00Oomoo`07Ool00`00Oomoo`0:Ool01@00
Oomoogoo00000goo00H007oo000007oo0002Ool01000Oomoo`0027oo00<007ooOol0<7oo0@000000
0`00Oomoo`1lOol01000Oomoogoo0`000Woo0P0000Aoo`000000009oo`03001oo`0000<0009oo`04
001oogoo0002Ool00`00Ool00002Ool300000goo001oo`02000017oo0000000017oo00<007oo0000
0P000Woo00D007ooOol007oo008000Uoo`04001oogoo0002Ool01000Oomoo`000Woo00@007ooOol0
009oo`03001oo`0000=oo`80009oo`<00005Ool00000Ool00002Ool00`00Ool0000300000goo001o
o`03Ool01000Oomoo`000Woo0P000Woo00<007oo00000Woo0`0000=oo`00Ool00goo00D007oo001o
o`00009oo`8000Eoo`03001oogoo009oo`80009oo`800004Ool007oo0002Ool3000aOol100000003
001oogoo07aoo`07001oogooOol007oo000077oo00<007ooOol01Woo00<007ooOol00P001Woo00<0
07ooOol02Woo00<007ooOol01Goo00<007ooOol00P004Goo00<007ooOol02Goo00@007ooOol000Eo
o`04001oogoo0003Ool00`00Ool00005Ool01000Ool007oo0P0000Aoo`00Ool0009oo`80009oo`<0
00Ioo`8000Aoo`05001oo`00Ool00004Ool01@00Oomoogoo00000goo00<007ooOol0;goo0@000000
0`00Oomoo`20Ool00`00Oomoo`02000?Ool00`00Oomoo`07Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`07Ool01@00Ool007oo00001Woo0P0017oo00<007ooOol00goo00<007ooOol00Woo
00@007ooOol000=oo`03001oogoo009oo`8000Aoo`03001oogoo00Aoo`<000Aoo`03001oo`00009o
o`03001oogoo00=oo`05001oogooOol00002Ool00`00Oomoo`06Ool00`00Oomoo`03Ool01`00Oomo
ogoo001oo`00009oo`03001oogoo009oo`03001oogoo00Aoo`<0009oo`80009oo`04001oo`00000a
Ool100000003001oogoo07aoo`80009oo`04001oogoo0003Ool2000>Ool01000Oomoo`001Woo00<0
07ooOol02Goo00<007ooOol08Woo00D007ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo00=o
o`8000Aoo`03001oogoo00=oo`07001oogooOol007oo00000Woo0P0000=oo`00Ool067oo00@007oo
Ool000Uoo`800005Ool00000Ool0000bOol100000003001oogoo07aoo`800003Ool0000000D00003
Ool007oo00Aoo`04001oogooOol30005Ool00`00Oomoo`03Ool01000Oomoogoo0P000Woo00<007oo
Ool00goo0P000Woo00<007ooOol00`0000=oo`0000000goo00@007oo001oo`800007Ool007ooOol0
07oo00000goo00<007ooOol00P0000=oo`00Ool00goo00<007ooOol01goo0P001Goo00H007ooOol0
07oo0004Ool00`00Ool00005Ool00`00Oomoo`020002Ool01P00Oomoo`00Ool000Aoo`05001oo`00
001oo`020003Ool20004Ool01000Ool000000Woo0`000Woo00H007ooOomoo`00Ool2000017oo0000
0000<Goo0@0000000`00Oomoo`1lOol200000goo00000002Ool00`00Oomoo`0POol2000?Ool01000
Ool000000Woo0P000goo00D007ooOomoo`0000Ioo`03001oogoo01Ioo`05001oogooOol00004Ool2
0004Ool20002Ool00`00Ool00003Ool30003Ool01000Oomoo`0027oo0P0000=oo`00000037oo00@0
07ooOol000=oo`<000Aoo`03001oo`00035oo`40000000<007ooOol0O7oo00<007ooOol00P0000=o
o`0000000Woo0P002Goo00<007ooOol00P0017oo00D007oo001oo`00009oo`80009oo`05001oogoo
Ool0000DOol00`00Oomoo`09Ool00`00Ool00002Ool00`00Oomoo`02Ool01000Oomoo`002Goo00<0
07ooOol00Woo00@007ooOol000Eoo`04001oogooOol200000goo00000007Ool01`00Oomoogoo001o
o`00009oo`03001oogoo00Eoo`03001oogoo009oo`04001oogoo0009Ool01000Oomoo`000Woo0`00
0goo00<007oo00000P0000=oo`00Ool0;Woo0@0000000`00Oomoo`1lOol2000017oo000000000Woo
10000Woo0P000Woo100000=oo`0000000goo00@007oo000000Aoo`03001oo`0000800006Ool00000
001oo`000Woo10000Woo00H007oo001oo`00Ool40003Ool01000Oomoo`000Woo0P0000=oo`000000
2Woo00<007ooOol017oo0P000Woo00@007ooOomoo`@000Aoo`800003Ool00000009oo`03001oogoo
009oo`80009oo`<000=oo`03001oogoo009oo`03001oogoo009oo`04001oogoo0004Ool01000Ool0
07oo0P0000=oo`0000000Woo00H007oo000007oo0003Ool00`00Oomoo`0500001Goo000007oo0000
;goo0@0000000`00Oomoo`1lOol01000Oomoo`000Woo0P001goo00<007ooOol02Goo00<007ooOol0
0goo0P000Woo00<007ooOol027oo0P000goo00<007oo00004Woo00@007ooOol000Aoo`03001oo`00
00=oo`8000=oo`8000Aoo`03001oo`0000ioo`03001oo`00009oo`03001oogoo00Uoo`03001oogoo
00Eoo`04001oogooOol2000<Ool00`00Ool00002Ool00`00Oomoo`08Ool20004Ool200000goo001o
o`0^Ool100000003001oogoo07moo`8000=oo`03001oogoo00Aoo`04001oogoo0007Ool00`00Oomo
o`0<Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01P00Oomoo`00Ool000=oo`04001oogoo0007Ool0
0`00Oomoo`0KOol00`00Oomoo`09Ool00`00Oomoo`04Ool01P00Oomoo`00Ool000Aoo`05001oogoo
Ool00003Ool01000Ool000002Goo00@007oo000000ioo`03001oogoo00Aoo`04001oo`000002Ool0
0`00Oomoo`0]Ool100000003001oogoo07aoo`800003Ool007oo008000Ioo`80009oo`800003Ool0
07oo00=oo`03001oo`0000=oo`03001oogoo008000Yoo`08001oogooOol007oo001oo`8000moo`03
001oogoo00Uoo`03001oo`0000Aoo`03001oogoo009oo`05001oogooOol00008Ool00`00Oomoo`02
Ool01000Oomoogoo0P0000=oo`00Ool00Woo00D007oo001oo`00009oo`05001oogooOol00005Ool0
0`00Oomoo`06Ool00`00Oomoo`09Ool00`00Oomoo`02Ool50009Ool200000goo001oo`0^Ool10000
0003001oogoo07aoo`800006Ool00000001oo`0017oo00@007oo001oo`80009oo`05001oo`00Ool0
0003Ool01@00Oomoo`00Ool00`000goo0P000Woo00<007ooOol00P0000Eoo`00001oo`00009oo`03
001oogoo00Ioo`05001oogooOol00002Ool00`00Oomoo`0200001Goo000007oo00001Woo00<007oo
Ool017oo00@007oo0000009oo`04001oogooOol200000goo001oo`0200000goo001oo`04Ool20004
Ool01P00Oomoogoo001oo`8000Aoo`<00005Ool007ooOol00002Ool2000017oo000000001Goo00@0
07ooOol0009oo`04001oo`000007Ool00`00Oomoo`0200001Woo00000000Ool002moo`40000000<0
07ooOol0Ogoo0P0000=oo`0000000P0000=oo`00Ool03Woo00<007ooOol00Woo0P002Woo0P001goo
0P0000=oo`00Ool00P001goo00<007ooOol01Goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool01goo00<007ooOol00Woo0P001goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol01Goo
00D007ooOomoo`0000Eoo`800003Ool007oo00Aoo`05001oogooOol00004Ool00`00Oomoo`05Ool0
1000Oomoo`000goo100000Aoo`00000000=oo`03001oogoo02eoo`40000000<007ooOol0O7oo0P00
00=oo`00000067oo0P001Woo00L007ooOomoo`00Ool0000:Ool01@00Oomoogoo00002Goo00<007oo
Ool03goo00<007ooOol02goo00@007oo0000009oo`04001oogoo0005Ool00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool01000Oomoogoo0P001Goo00@007ooOol000eo
o`03001oogoo009oo`03001oogoo00Aoo`06001oo`00001oo`00;goo0@0000000`00Oomoo`1lOol5
0002Ool00`00Ool000020007Ool00`00Ool00004Ool01@00Oomoogoo00000Woo00<007ooOol00P00
0Woo00L007ooOomoo`00Ool00002Ool02000Oomoo`00Ool007oo0003Ool00`00Oomoo`02Ool00`00
Ool00002Ool20002Ool01000Ool007oo100000=oo`00Ool01Goo0P0000=oo`00Ool00P0000=oo`00
Ool01Woo0P0000Ioo`00Oomoo`00Ool30002Ool00`00Ool00005Ool01P00Oomoogoo001oo`80009o
o`03001oo`0000Aoo`800003Ool007oo00800004Ool007ooOol30004Ool01000Oomoo`000goo00@0
07ooOol0009oo`@0009oo`800003Ool007oo02ioo`40000000<007ooOol0OWoo1@0017oo00<007oo
Ool037oo00<007ooOol00P0000=oo`00000017oo00@007ooOomoo`8000Qoo`05001oo`00001oo`02
00000goo001oo`02Ool00`00Oomoo`02Ool200000goo0000000<Ool01@00Oomoogoo000017oo00@0
07oo000000Moo`03001oogoo00Aoo`03001oogoo009oo`800008Ool007oo001oo`00Ool000=oo`03
001oogoo009oo`80009oo`80009oo`05001oo`00Ool0000AOol00`00Ool00002Ool00`00Oomoo`04
Ool00`00Oomoo`04000_Ool100000003001oogoo07aoo`08001oo`00001oo`00Ool0019oo`04001o
ogooOol30003Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`020005Ool200000goo001o
o`03Ool01@00Oomoo`00Ool00`002Woo00<007ooOol00goo0P003Goo00<007ooOol01Goo00<007oo
Ool01Woo00D007ooOol007oo00<00008Ool007oo001oo`00Ool000Eoo`03001oogoo00Qoo`03001o
ogoo009oo`03001oogoo009oo`05001oo`00Ool00009Ool00`00Ool00002Ool00`00Oomoo`0^Ool1
00000003001oogoo07aoo`D000Eoo`05001oogooOol00002Ool01@00Oomoogoo00000Woo0P000Woo
00<007oo00000goo00<007ooOol00Woo00<007ooOol02Woo00<007ooOol00goo1P0000=oo`00Ool0
0Woo0`000Woo00<007ooOol017oo00<007ooOol01goo0P000Woo00H007oo000007oo000;Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool01`00Oomoogoo001oo`0000Ioo`03001oogoo00Moo`04001oogoo
0002Ool00`00Ool0000200000goo001oo`02Ool00`00Oomoo`08Ool30002Ool6000_Ool100000003
001oogoo07aoo`03001oo`0000800004Ool007oo0006Ool00`00Ool000020002Ool300000goo0000
0002Ool00`00Ool000020005Ool01000Ool000000Woo00<007ooOol00`0000Aoo`00001oo`<00003
Ool0000000D0009oo`<00004Ool007oo0002Ool00`00Oomoo`03Ool2000017oo001oo`000Woo00<0
07ooOol00P0000Eoo`00Oomoo`0000Aoo`80009oo`04001oo`000003Ool00`00Oomoo`02Ool01000
Ool000001Woo00<007ooOol02Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`H00004Ool007oo
Ool500000goo001oo`020002Ool4000_Ool100000003001oogoo07]oo`03001oo`0000D000]oo`03
001oogoo00=oo`800004Ool007oo0003Ool01@00Ool007oo00001goo0P000Woo00D007ooOol007oo
00800003Ool007oo009oo`@0009oo`8000=oo`<0009oo`03001oogoo00Aoo`03001oogoo00Eoo`03
001oo`0000Aoo`04001oo`00Ool2000>Ool01000Oomoo`000goo00<007oo00001Woo00<007ooOol0
0Woo00<007oo00001goo00@007ooOol0009oo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00
Oomoo`0200001Woo00000000Ool0031oo`40000000<007ooOol0Ngoo1@000goo0P0017oo0`0000Ao
o`00Ool000Uoo`06001oogoo001oo`001Woo00<007oo00000Woo1`000Woo00<007ooOol00goo00D0
07ooOol007oo008000Ioo`03001oo`0000Ioo`03001oogoo00=oo`80009oo`03001oo`0000=oo`03
001oo`0000eoo`8000Ioo`03001oogoo00Eoo`06001oogoo001oo`000Woo00<007oo00000Woo00H0
07ooOol007oo000?Ool00`00Oomoo`06Ool20002Ool00`00Oomoo`0200000goo001oo`0^Ool10000
0003001oogoo07]oo`H00006Ool00000Ool007oo0P0000Ioo`00Oomoo`00Ool200001Goo00000000
Ool01@0000=oo`00Ool00Woo0P0000=oo`0000001Goo100000=oo`0000000`0000Eoo`00001oo`00
009oo`800004Ool00000Ool300000goo000000040002Ool200000goo0000000500000goo00000002
Ool00`00Ool0000300000goo001oo`060004Ool300000goo00000003Ool20004Ool01000Oomoo`00
0Woo00@007oo001oo`800005Ool007ooOol00004Ool20004Ool200001Woo001oogoo001oo`80009o
o`04001oo`000006Ool01000Oomoogoo0`00;Woo0@0000000`00Oomoo`1kOol00`00Oomoo`03Ool0
0`00Ool00002Ool01000Oomoogoo10000Woo0`0017oo0P0000Eoo`00Oomoo`0000=oo`8000Eoo`80
00Aoo`03001oo`00009oo`03001oo`0000=oo`03001oogoo00Ioo`<00003Ool00000009oo`03001o
o`0000Eoo`04001oo`000005Ool00`00Oomoo`03Ool20002Ool00`00Ool0000:Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool01000Oomoo`000Woo00@007ooOomoo`8000Ioo`05001oogooOol00005Ool0
0`00Oomoo`03Ool00`00Oomoo`02Ool30004Ool3000017oo001oogoo1@00;Woo0@0000000`00Oomo
o`1kOol300000goo00000005Ool30003Ool20002Ool00`00Ool0000200001goo001oogoo001oo`00
00Moo`03001oogoo009oo`8000Qoo`03001oo`0000Moo`05001oogooOol00005Ool01000Ool00000
0Woo00L007ooOol007oo001oo`0200000goo001oo`03Ool20007Ool20003Ool00`00Ool00004Ool0
0`00Ool00002Ool01000Ool000001Woo00<007ooOol02Goo0P007Woo00<007oo00000Woo0P0000Ao
o`00000002ioo`40000000<007ooOol0Ngoo1`001Goo00<007ooOol00`000Woo0P0000Aoo`00001o
o`<000=oo`8000Aoo`06001oogoo001oo`0017oo0`0000Aoo`00001oo`800003Ool007oo0080009o
o`800004Ool000000002Ool01000Ool000000Woo00<007ooOol01Goo0P000Woo00D007ooOomoo`00
00=oo`03001oo`0000<0009oo`03001oogoo00Aoo`8000=oo`06001oo`00Ool007oo0P000Woo0P00
00Aoo`00Oomoo`80009oo`05001oogooOol00005Ool01@00Oomoo`00Ool00P001Goo00@007oo0000
00=oo`03001oo`0000]oo`04001oogooOol2000^Ool100000003001oogoo07Yoo`@00004Ool00000
Ool300000goo001oo`03Ool4000017oo000007oo0P0017oo00H007oo001oo`00Ool200000goo001o
o`03Ool01@00Ool00000Ool00P0000=oo`0000000Woo0P0000=oo`0000000P0000Eoo`00001oo`00
009oo`<00003Ool00000009oo`04001oo`000002Ool00`00Ool0000500000goo000000020002Ool0
1000Oomoogoo0P0000=oo`0000000Woo0P0000=oo`00Ool00P0000Aoo`00001oo`H000=oo`03001o
ogoo00Eoo`04001oogoo0002Ool30002Ool30004Ool00`00Oomoo`04Ool3000017oo001oogoo0P00
00=oo`0000000Woo00D007oo000007oo00H002eoo`40000000<007ooOol0NWoo0P0000=oo`000000
0P0000=oo`00Ool00Woo00@007ooOomoo`8000Aoo`03001oo`00009oo`03001oo`0000D000Aoo`03
001oogoo008000Aoo`03001oogoo00Qoo`80009oo`05001oogooOol00003Ool20005Ool00`00Oomo
o`020002Ool00`00Oomoo`04Ool00`00Oomoo`03Ool20002Ool20003Ool20004Ool20007Ool30000
17oo000007oo0P000Woo00D007ooOomoo`00015oo`03001oogoo00ioo`800005Ool007oo001oo`0:
000]Ool100000003001oogoo07Yoo`800003Ool007oo009oo`03001oogoo009oo`05001oogooOol0
0002Ool00`00Ool00006Ool2000017oo001oogoo100000=oo`00Ool017oo00<007oo00002Woo00X0
07ooOomoo`00Ool007oo001oo`800005Ool007ooOol00003Ool2000017oo000000002goo1P000goo
00<007ooOol01Woo0P000Woo00H007oo001oo`00Ool30008Ool30004Ool20003Ool01@00Oomoogoo
00001Goo00<007oo00000Woo0`0000=oo`00Ool02Woo00<007ooOol01Goo0`00;Woo0@0000000`00
Oomoo`1jOol400000goo00000002Ool50003Ool700001Woo00000000Ool0009oo`03001oo`0000@0
00=oo`05001oogoo001oo`0800001Goo000007oo00000Woo100000=oo`0000000`0000=oo`000000
0P0000Aoo`00001oo`80009oo`X0009oo`800004Ool00000Ool20002Ool20002Ool01P00Ool007oo
001oo`@00004Ool00000Ool4000017oo001oo`000Woo00@007oo000000Aoo`04001oo`00Ool20003
Ool00`00Ool000020002Ool01000Ool000000goo0P000Woo0P0000Aoo`00001oo`<00004Ool007oo
Ool7000/Ool100000003001oogoo07]oo`800005Ool007ooOol00003Ool200000goo000000030000
17oo001oogoo0P000Woo00D007ooOomoo`0000Aoo`03001oogoo009oo`03001oogoo009oo`@00003
Ool00000009oo`03001oo`0000=oo`03001oogoo00Moo`04001oogooOol30002Ool200000goo001o
o`02Ool01000Oomoogoo0P000Woo00<007ooOol00P001Goo1@0000Aoo`00Ool000=oo`03001oogoo
00<000=oo`0:001oo`00001oo`00Ool007oo0002Ool00`00Oomoo`03Ool200001Woo00000000Ool0
00=oo`04001oogoo0008Ool20002Ool00`00Oomoo`03Ool01P00Oomoogoo001oo`L002aoo`400000
00<007ooOol0NGoo0`0000Aoo`00Ool0009oo`800003Ool007oo009oo`80009oo`03001oogoo00Ao
o`05001oogoo001oo`0200001Goo001oogoo00000Woo00<007ooOol00P001Woo00<007oo00000Woo
00D007ooOomoo`00009oo`800008Ool007oo001oo`00Ool000Aoo`8000Eoo`03001oo`0000Eoo`05
001oo`00Ool00003Ool20002Ool01P00Ool007oo001oo`<000=oo`800003Ool0000000Eoo`06001o
o`00001oo`000goo00@007ooOol000=oo`800009Ool007ooOol007oo001oo`0000Eoo`80019oo`03
001oo`0000D00004Ool007oo000/Ool100000003001oogoo07Uoo`<000Aoo`8000=oo`D00004Ool0
00000002Ool01000Ool000000Woo0P001Woo00@007ooOol000Aoo`05001oo`00Ool00008Ool00`00
Oomoo`02Ool2000017oo0000000017oo00D007ooOomoo`00009oo`03001oogoo00@00003Ool007oo
00=oo`800003Ool007oo00Ioo`800003Ool007oo009oo`T000=oo`800004Ool007ooOol200001Goo
000007oo00000goo0`0017oo00<007oo00000`000Woo00<007ooOol00goo00<007ooOol01goo00<0
07oo00000Woo00<007ooOol00goo00@007oo001oo`H002aoo`40000000<007ooOol0NGoo20000Woo
00<007oo00001P0000=oo`00Ool00P0000Aoo`000000009oo`05001oogoo001oo`02000017oo001o
o`000goo2@0000=oo`0000000`0000=oo`0000000goo0`0000=oo`0000000Woo0`0000=oo`00Ool0
0P0000Aoo`00Oomoo`800003Ool0000000800004Ool000000002Ool20002Ool01@00Ool00000Ool0
0`0000=oo`0000000P0000Eoo`00000007oo00D00004Ool00000Ool;0002Ool200000goo00000003
000017oo0000000017oo00<007ooOol00`0000=oo`0000000Woo00@007oo000000=oo`06001oo`00
001oo`000Woo0P0000=oo`0000000P00;7oo0@0000000`00Oomoo`1mOol30002Ool00`00Oomoo`03
Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool20003Ool00`00Oomoo`030000
0goo001oo`02Ool01@00Ool007oo00001goo00<007ooOol017oo00D007oo001oo`00009oo`80009o
o`03001oogoo00Aoo`<00003Ool007oo00Qoo`@0009oo`04001oo`000006Ool00`00Oomoo`03Ool0
0`00Ool00003Ool400000goo0000000300000goo00000002Ool500000goo001oo`02Ool00`00Oomo
o`03Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Moo`800004Ool007ooOol4000/Ool10000
0003001oogoo07Uoo`D0009oo`800006Ool00000Ool007oo0`0000=oo`00Ool00goo00<007oo0000
0Woo00D007ooOomoo`0000Aoo`04001oogoo0002Ool01@00Ool007oo00000Woo00<007ooOol00goo
0`0017oo00<007ooOol00Woo00<007ooOol00Woo0`000Woo00<007ooOol00goo0`0017oo00D007oo
Oomoo`00009oo`03001oo`0000Aoo`06001oo`00001oo`000Woo0P0017oo0P0000=oo`00Ool017oo
00@007ooOol0009oo`800004Ool007ooOol30002Ool01000Oomoogoo0P0017oo00<007oo00000Woo
00<007ooOol00goo00<007ooOol017oo00D007ooOol007oo008000=oo`05001oogoo001oo`02000/
Ool100000003001oogoo07Uoo`P00003Ool007oo00<00006Ool007oo001oo`000Woo0P0000=oo`00
Ool00goo0P0000=oo`00000017oo0P0000=oo`0000001P000Woo00<007ooOol00goo0P0000Eoo`00
001oo`00009oo`80009oo`04001oo`000002Ool01000Oomoo`000Woo00<007oo00000goo00<007oo
00000P000Woo00<007oo00000Woo0P000Woo00D007oo001oo`00009oo`05001oo`00001oo`030000
17oo000007oo0`0000=oo`00Ool01`0000=oo`0000001`0000Aoo`00001oo`<00003Ool0000000Ao
o`04001oo`000003Ool200000goo001oo`0300001Goo00000000Ool00P0000=oo`0000001P00:goo
0@0000000`00Oomoo`1jOol4000017oo001oo`000goo00@007oo001oo`<00003Ool007oo008000=o
o`800003Ool0000000<000=oo`8000Aoo`04001oogoo0004Ool00`00Oomoo`06Ool01@00Ool007oo
00000goo0`001Goo00<007ooOol00Woo0P0000Eoo`00001oo`0000Moo`05001oogooOol00002Ool0
1000Oomoo`000Woo00<007oo00000goo00<007oo000017oo0P000Woo0P0000=oo`00Ool00Woo0`00
0Woo00@007oo001oo`8000=oo`<00003Ool0000000Qoo`800006Ool007oo001oo`000Woo00D007oo
Oomoo`00009oo`07001oogooOol007oo00000Woo1@00:goo0@0000000`00Oomoo`08Ool00`00Oomo
o`0;Ool30008Ool2000:Ool00`00Ool00002000:Ool00`00Oomoo`030005Ool2000:Ool00`00Oomo
o`0;Ool2000<Ool00`00Oomoo`07Ool30002Ool200001Goo001oo`00Ool00P0000=oo`00000027oo
0`0000Ioo`00001oo`00Ool30004Ool20002Ool01`00Oomoo`00Ool007oo00<000Eoo`03001oogoo
00=oo`<00003Ool0000000=oo`<000=oo`8000=oo`03001oogoo00Ioo`03001oogoo00Aoo`03001o
ogoo0080009oo`04001oo`000002Ool30002Ool200000goo001oo`04Ool30003Ool01@00Oomoo`00
Ool00`000Woo0P000goo100017oo0P002Goo00@007ooOol0009oo`04001oogoo0003Ool00`00Ool0
0002Ool00`00Ool00002000FOol00`00Oomoo`0BOol100000004001oo`000007Ool01@00Oomoogoo
00001Woo00<007ooOol00`0000=oo`00Ool01Goo0P000goo00<007ooOol017oo1@001Woo00<007oo
Ool00P000Woo0`000Woo00<007ooOol00P0000Aoo`000000009oo`80009oo`8000Yoo`@00003Ool0
0000009oo`04001oogooOol5000;Ool00`00Oomoo`020005Ool00`00Oomoo`03Ool00`00Ool00002
Ool20002Ool20004Ool01000Oomoo`000Woo00<007oo00000Woo1@0000=oo`0000000goo0P000Woo
00@007ooOol0009oo`04001oogoo0002Ool00`00Ool00003Ool01@00Oomoogoo00001goo00<007oo
00001Goo0`000goo00@007oo0000009oo`03001oogoo009oo`@00004Ool007ooOol20002Ool00`00
Ool00003Ool200000goo001oo`05Ool01@00Ool00000Ool00`0000=oo`00000017oo100000=oo`00
Ool00Woo0P000goo00<007ooOol01Woo00L007oo000007oo001oo`04000COol01000Oomoo`000goo
0P0017oo00<007ooOol027oo0@0000001000Ool000000goo00@007ooOomoo`800003Ool0000000=o
o`800003Ool007oo00H00004Ool007oo0002Ool60002Ool00`00Oomoo`080004Ool50002Ool30000
1Goo00000000Ool01P0000Eoo`00000007oo00D00005Ool007oo001oo`0700000goo00000002Ool:
00000goo001oo`04Ool40003Ool;00000goo0000000400000goo00000005Ool00`00Oomoo`030000
0goo001oo`0300000goo001oo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool200000goo00000002
Ool200001Woo001oogoo001oo`80009oo`800003Ool0000000800003Ool007oo00H00005Ool00000
Ool00002Ool30003Ool300000goo0000000600001Woo001oogoo001oo`<00003Ool0000000800003
Ool00000009oo`P00004Ool00000Ool30002Ool700001Goo00000000Ool00P0000=oo`0000000goo
0P0000=oo`00Ool00P0000Ioo`00001oo`00Ool3000BOol3000017oo001oogoo0`0000=oo`000000
1P0017oo0@000Goo0@0000001000Ool000000Woo0`000Woo0P0000=oo`0000000Woo1@0000=oo`00
00001P0000=oo`00Ool01`000Woo1`0000=oo`000000100000=oo`000000100000Eoo`00Ool007oo
00X00003Ool0000000<00009Ool00000001oo`00Ool007oo00L00003Ool00000009oo``000Aoo`L0
009oo`<0009oo`800005Ool007oo001oo`020004Ool01`00Ool007oo001oo`0000Uoo`@000Aoo`04
001oogoo0002Ool30002Ool00`00Oomoo`02000017oo001oogoo0P0000=oo`00Ool00Woo00<007oo
Ool00Woo00<007oo00000P0000=oo`00Ool027oo0`0000=oo`00Ool00Woo00<007ooOol01Goo00<0
07ooOol00P0000=oo`00Ool01Goo00<007oo00000goo00@007ooOomoo`80009oo`03001oo`00009o
o`800007Ool007ooOol007oo00000goo00@007oo0000009oo`80009oo`03001oo`0000]oo`03001o
ogoo00=oo`D000Yoo`03001oogoo00=oo`800003Ool007oo00H00003Ool0000000H000Aoo`40005o
o`40000000D007oo000007oo00@0009oo`800003Ool00000009oo`D00003Ool0000001400003Ool0
000000D00003Ool0000000T00007Ool007oo001oo`00Ool02P0000=oo`0000000`0000=oo`000000
0`0000=oo`0000001`0000=oo`0000000Woo1@0000=oo`000000100017oo00<007oo00000P000goo
0P0000=oo`00Ool00Woo0P0000Eoo`00Oomoo`0000Aoo`04001oogooOol20004Ool01P00Ool007oo
001oo`<0009oo`800003Ool007oo0080009oo`04001oogoo0003Ool00`00Ool00002Ool02000Ool0
0000Ool007oo0002Ool01`00Ool007oo001oo`0000Aoo`05001oogooOol00002Ool00`00Oomoo`03
Ool02000Oomoogoo001oo`00Ool3000017oo001oo`000Woo00<007ooOol00P002goo0`000Woo00@0
07ooOol000Aoo`8000=oo`05001oo`00Ool00002Ool02@00Ool00000Ool007oo001oo`030002Ool2
0003Ool00`00Oomoo`020006Ool40007Ool200000goo001oo`04Ool200000goo001oo`0600000goo
000000060004Ool10001Ool100000003001oo`0000H00003Ool007oo00D00003Ool0000000<00004
Ool00000Ool@00000goo0000000500000goo0000000900001goo00000000Ool007oo01000003Ool0
00000100009oo`D00003Ool0000000@000=oo`@00003Ool0000000T00003Ool0000000<0009oo`80
0003Ool007oo009oo`800005Ool007ooOol00002Ool200000goo0000000400000goo001oo`020002
Ool01`00Ool007oo001oo`0000=oo`<0009oo`03001oo`0000800003Ool0000000800006Ool007oo
Ool007oo0P000Woo0P0000Aoo`00001oo`P00003Ool00000009oo`03001oogoo00800003Ool00000
00=oo`<00003Ool0000000800005Ool007oo001oo`0500000goo000000070002Ool01000Ool007oo
0`000Woo00<007ooOol01@0000Aoo`00001oo`800004Ool000000002Ool50002Ool80006Ool30000
0goo000000020002Ool200000goo0000000600000goo00000008000017oo000007oo0@0000000`00
Ool0000600000goo001oo`0500000goo0000000600000goo0000000>00000goo0000000500000goo
0000000900001goo00000000Ool007oo00@00003Ool0000000T00003Ool000000100009oo`D00004
Ool00000Ool30002Ool60002Ool01000Ool000000goo00@007oo000000Aoo`03001oo`000080009o
o`800003Ool00000008000Eoo`04001oo`000002Ool01@00Ool007oo00000Woo00@007ooOol000Eo
o`03001oo`000080009oo`03001oogoo00=oo`03001oogoo009oo`800005Ool00000001oo`020005
Ool01P00Oomoo`00Ool000Eoo`03001oo`00008000Qoo`@00004Ool007ooOol200000goo00000002
Ool00`00Oomoo`02Ool00`00Ool00002Ool20002Ool01@00Oomoo`00Ool00P000Woo00<007ooOol0
0P000Woo00D007ooOol007oo00800005Ool00000Ool00002Ool30002Ool01000Oomoo`000Woo00@0
07oo001oo`8000Aoo`03001oo`0000800003Ool0000000H00003Ool0000000H00003Ool0000000P0
0004Ool00000Ool100000003001oo`0000P00003Ool0000000`00003Ool0000000h00003Ool00000
00D00003Ool0000000T00005Ool00000001oo`0600000goo0000000900000goo0000000;00000goo
000000020002Ool40002Ool200001Woo000007oo001oo`D00003Ool007oo009oo`03001oo`00009o
o`03001oogoo00=oo`03001oogoo00Aoo`<000Aoo`8000Aoo`<00003Ool0000000=oo`03001oogoo
00=oo`05001oogooOol00004Ool00`00Oomoo`02Ool20007Ool00`00Ool00002Ool20005Ool01000
Oomoo`000goo0P001Woo00<007ooOol00Woo00H007oo001oo`00Ool50002Ool00`00Ool00003Ool2
0002Ool20003Ool00`00Oomoo`030004Ool02000Oomoogoo001oo`00Ool2000017oo0000000017oo
0P000goo1@0000Aoo`00Oomoo`8000Aoo`03001oogoo00800003Ool000000080009oo`l00003Ool0
000000H00003Ool0000000P00004Ool00000Ool100000003001oo`0000P00005Ool00000001oo`0:
00000goo0000000<00000goo001oo`060002Ool;00001Goo00000000Ool01P000Woo2P0000=oo`00
00002`0000=oo`0000000P000Woo10000Woo0P0000=oo`0000000P0000=oo`0000000P0000Aoo`00
0000009oo`800006Ool007ooOol007oo0`0000Aoo`00001oo`8000aoo`03001oo`00008000=oo`03
001oo`0000Aoo`800003Ool00000009oo`800005Ool007ooOol00005Ool01000Oomoo`007Woo0P00
00=oo`00Ool01@0000=oo`00Ool01Woo0P001Goo00H007ooOol007oo0002Ool00`00Ool00002Ool0
0`00Oomoo`02Ool20002Ool200000goo00000004000017oo001oo`000Woo0`0000Aoo`00Ool000Ao
o`800004Ool007oo0005Ool500000goo0000000>00001Goo00000000Ool02`0000Ioo`00000007oo
0002Ool100000003001oo`0000P00005Ool00000001oo`0600001Goo00000000Ool03P0000=oo`00
00001P000Woo2`0000Eoo`00000007oo00<0009oo`03001oogoo00800003Ool0000000D00004Ool0
0000Ool:000017oo000007oo1`000Woo0P0000=oo`0000000P0000=oo`000000300000Aoo`00001o
o`<00004Ool007oo0004Ool200000goo000000040002Ool00`00Ool00002000017oo001oo`000Woo
0P000goo00<007ooOol00P0000=oo`0000000Woo00@007oo0000009oo`@00003Ool007oo00H000=o
o`80009oo`800003Ool0000000<0009oo`04001oo`00Ool300000goo0000000=00000goo00000002
Ool00`00Ool0000900001Goo001oo`00Ool0300000Eoo`00Ool007oo00800003Ool0000000T00006
Ool007ooOol007oo0P000Woo2@0000=oo`0000003P0000Eoo`00000007oo00/00006Ool00000001o
o`000Woo0@0000001000Ool007oo1`0000Eoo`00000007oo00D0009oo`80009oo`H00005Ool00000
001oo`0300000goo000000050003Ool;00001Goo00000000Ool00`000Woo00<007ooOol00P0000=o
o`0000000Woo0`0000Aoo`00Oomoo`L00003Ool00000009oo`03001oo`0000800004Ool000000002
Ool2000017oo000007oo1P0000Aoo`000000009oo`800003Ool007oo00<0009oo`06001oogoo001o
o`001Goo00@007ooOomoo`@00003Ool007oo00=oo`8000Qoo`04001oo`000004Ool40004Ool00`00
Ool00004Ool00`00Oomoo`02Ool00`00Oomoo`0600000goo001oo`020002Ool01000Oomoo`000Woo
00<007ooOol00P000Woo00<007ooOol00goo00H007oo000007oo0005Ool01@00Oomoogoo00000goo
00<007ooOol017oo0P000goo0P0000Aoo`00Ool000=oo`04001oogoo0003Ool200000goo001oo`02
0002Ool02P00Ool00000Ool007oo001oo`000goo00@007ooOol000=ooa<0009oo`<00003Ool00000
00P0009oo`D0009oo`40000000@007ooOomoo`H0009oo`<00003Ool0000000<0009oo`80009oo`H0
0005Ool00000001oo`020002Ool70004Ool600001Goo00000000Ool00`0000Aoo`000000009oo`03
001oogoo00800003Ool00000009oo`<000Aoo`L00003Ool00000009oo`03001oogoo00800003Ool0
000000=oo`800003Ool0000000L0009oo`80009oo`800003Ool00000009oo`80009oo`03001oogoo
009oo`04001oo`000004Ool00`00Ool00002Ool200000goo001oo`0200001Goo000007oo00000Woo
100017oo00@007ooOol000Eoo`03001oogoo00@000=oo`03001oo`00009oo`8000Aoo`04001oogoo
0006Ool01@00Ool007oo00000goo00D007ooOomoo`0000Aoo`03001oogoo00800003Ool0000000Mo
o`03001oogoo00=oo`800004Ool007ooOol300000goo001oo`06Ool4000017oo001oo`000Woo0P00
00Aoo`00Oomoo`800003Ool0000000800004Ool007oo0008Ool200000goo0000000@0002Ool30000
0goo00000004000017oo000000000Woo1@000Woo0@0000001000Oomoogoo1P000Woo0`0000=oo`00
00000`000Woo0P000Woo1P0000Eoo`00000007oo0080009oo`H000Eoo`H00005Ool00000001oo`03
000017oo000000000Woo00<007ooOol00P0000=oo`0000000Woo0`0017oo1`0000=oo`0000000Woo
00<007ooOol00P0000=oo`0000000goo0P0000=oo`0000003@000Woo20000Woo0P0027oo0P000goo
4P000goo00H007ooOol007oo0002Ool20002Ool01P00Ool007oo001oo`H000=oo`800006Ool00000
001oo`000Woo00H007ooOomoo`00Ool200000goo001oo`06000017oo000000000goo00@007ooOomo
o`H00003Ool0000000800003Ool0000000<00004Ool00000OolD00001Woo001oogoo001oo`l0009o
oaX0009oo`<00003Ool0000000<0009oo`<0009oo`D0009oo`40000000@007ooOomoo`<00003Ool0
0000009oo`80009oo`<00004Ool007ooOol20002Ool60002Ool200000goo001oo`02Ool300000goo
00000005Ool00`00Ool00003000017oo001oo`000Woo0P0000Aoo`000000009oo`03001oogoo00=o
o`80009oo`8000Eoo`L00003Ool007oo009oo`03001oogoo008000Ioo`03001oogoo00T00004Ool0
00000003Ool200000goo001oo`05Ool01@00Oomoogoo00000Woo00<007oo00000`0000Aoo`00Ool0
00=oo`800003Ool0000000=oo`04001oo`000002Ool200001Goo001oogoo00000Woo00@007ooOol0
009oo`800007Ool007ooOol007oo000017oo00<007oo00000goo00@007ooOomoo`800003Ool00000
008000Eoo`800003Ool007oo00Eoo`@00004Ool00000Ool20002Ool30002Ool200002Woo00000000
Ool007oo001oo`0027oo00<007ooOol00Woo0P0000=oo`00Ool00Woo00<007oo00000P0000Aoo`00
Oomoo`80009oo`T00007Ool007ooOol007oo00000Woo3P0000Aoo`00000000=oo`03001oogoo00D0
009oo`03001oo`0000=oo`@0009oo`40000000@007ooOomoo`80009oo`8000=oo`03001oogoo00<0
0004Ool007ooOol20002Ool300000goo00000002Ool20005Ool300000goo00000009Ool2000017oo
001oo`000Woo0P0000Aoo`000000009oo`03001oogoo00=oo`80009oo`8000Eoo`@00005Ool00000
Ool00003Ool00`00Oomoo`020006Ool00`00Oomoo`0:00000goo001oo`02Ool400000goo001oo`02
Ool20002Ool00`00Ool0000200000goo001oo`030005Ool01P00Ool00000Ool0009oo`03001oogoo
008000=oo`05001oogooOol00003Ool01@00Oomoo`00Ool00P000Woo0P0000=oo`00Ool00P0000Mo
o`00Oomoo`00Ool00005Ool00`00Oomoo`030002Ool01000Oomoo`0027oo0P000Woo0P0000=oo`00
Ool00Woo00<007ooOol00P0000Aoo`000000009oo`06001oogoo001oo`000goo00@007ooOol000Eo
o`80009oo`08001oogooOol007oo001oo`8000=oo`@0009oo`@00003Ool0000000800003Ool00000
00Eoo`03001oo`0000X00003Ool0000000800004Ool000000003Ool00`00Oomoo`050002Ool00`00
Oomoo`04Ool30002Ool100000004001oogooOol20002Ool20006Ool20005Ool20002Ool20002Ool2
0002Ool20005Ool30002Ool00`00Oomoo`07Ool200000goo001oo`03Ool2000017oo000000000Woo
00<007ooOol00goo0P000Woo0P001Goo100000Eoo`00001oo`0000=oo`03001oogoo008000Ioo`03
001oogoo00T00006Ool00000001oo`000Woo0P0000Aoo`00001oo`800004Ool007ooOol200000goo
000000030006Ool01000Oomoogoo0P000Woo00D007ooOomoo`00009oo`05001oogooOol00003Ool0
0`00Oomoo`03Ool01@00Oomoogoo00001Goo0P0000Eoo`00Ool007oo00H000ioo`03001oogoo00Eo
o`800004Ool00000Ool200000goo001oo`04Ool00`00Oomoo`020002Ool30002Ool300001Goo001o
o`00Ool010001goo00<007oo00000`000goo00<007ooOol0100000=oo`0000002P0000Eoo`00Ool0
07oo00800003Ool0000000`00004Ool000000003Ool00`00Oomoo`050002Ool00`00Oomoo`04Ool3
0002Ool100000004001oogooOol20002Ool20006Ool20005Ool20002Ool01000Oomoogoo0P000Woo
0P001Goo0`000Woo00<007ooOol01goo0P0000=oo`00Ool00goo0P0000Aoo`000000009oo`03001o
ogoo00=oo`80009oo`8000Eoo`800003Ool007oo00800003Ool007oo00Eoo`8000Ioo`03001oogoo
00<00003Ool0000000H00003Ool0000000@0009oo`08001oo`00Ool007oo001oo`<0009oo`80009o
o`@00006Ool007ooOol007oo1`000Woo1`0000=oo`0000001@000Woo0P0000=oo`0000000P0000Eo
o`00Ool007oo00@00005Ool007ooOol00002Ool20004Ool00`00Ool0000300000goo001oo`020000
17oo000007oo0P000Woo00D007ooOol007oo0080009oo`06001oogooOol007oo2`0000Aoo`00Ool0
009oo`04001oo`00Ool70005Ool:00000goo000000090002Ool;0002Ool7000017oo001oo`001Woo
0`0000Eoo`00Oomoo`0000Ioo`<0009oo`40000000@007ooOomoo`80009oo`8000Ioo`8000Eoo`80
00Ioo`80009oo`8000Eoo`<000aoo`800003Ool007oo00=oo`03001oogoo008000=oo`03001oogoo
00=oo`80009oo`8000Eoo`03001oogoo009oo`8000Qoo`8000Yoo`8000Aoo`8000Eoo`03001oo`00
00800003Ool0000000<00003Ool00000008000Eoo`06001oo`00001oo`0017oo00@007oo001oo`80
00Aoo`8000Aoo`04001oo`000002Ool01000Oomoogoo10000goo00<007ooOol00goo00<007ooOol0
0P0017oo00<007ooOol00P0000=oo`0000000`001Goo1@0017oo00@007ooOomoo`800004Ool00000
Ool30003Ool00`00Oomoo`05Ool01@00Ool00000Ool00`0000Eoo`00Oomoo`00009oo`08001oogoo
Ool007oo001oo`@000Aoo`03001oogoo00=oo`80009oo`05001oo`00001oo`0200000goo00000002
Ool00`00Ool000070003Ool6000017oo001oo`001Woo00D007ooOomoo`0000Uoo`<0009oo`400000
00@007ooOomoo`80009oo`8000Ioo`03001oogoo00Aoo`8000Ioo`80009oo`8000Eoo`<000aoo`04
001oogoo0004Ool01@00Oomoogoo00000goo00<007ooOol017oo00<007ooOol00P001Goo00<007oo
Ool00Woo0P0027oo0P002Woo0P001Goo00<007ooOol00P0000=oo`0000000`0000Yoo`00000007oo
001oo`00Ool0009oo`03001oogoo009oo`05001oogooOol00004Ool00`00Ool00002000027oo001o
o`00Ool007oo0007Ool00`00Oomoo`06Ool02000Oomoo`00Ool007oo0002Ool00`00Oomoo`03Ool0
1000Ool000000Woo00@007oo000000Aoo`04001oo`000003Ool01@00Oomoo`00Ool00`0000=oo`00
Ool00Woo00<007oo00000Woo1@000goo00<007oo00001goo0P000Woo0P0000=oo`0000000Woo0P00
0goo0P0000Ioo`00Oomoo`00Ool30003Ool300002goo000007oo001oo`00Ool007oo00000Woo00@0
07oo001oo`800003Ool00000008000Aoo`H00004Ool007oo0006Ool01@00Oomoogoo00002Goo0`00
0Woo0@0000001000Oomoogoo0P000Woo0P001Woo00<007ooOol017oo0P001Woo0P000Woo00<007oo
Ool017oo0P0047oo00<007ooOol01Woo00<007ooOol027oo00@007ooOol001Eoo`8000Yoo`8000Eo
oa0000=oo`800003Ool0000000<00004Ool007ooOol200000goo0000000300000goo000000050000
0goo0000000300000goo00000002Ool200000goo00000004Ool200000goo0000000200001Woo001o
o`00Ool000=oo`800003Ool00000008000=oo`05001oogooOol00002Ool01P00Oomoogoo001oo`80
0003Ool007oo00<00003Ool0000000<00003Ool007oo0080009oo`@00004Ool00000Ool400000goo
000000040002Ool20002Ool60002Ool600001Goo00000000Ool01@0000=oo`00Ool01P0000=oo`00
0000200017oo0`000Woo00D007oo001oo`0000Ioo`05001oogooOol00009Ool00`00Ool00002Ool1
00000003001oogoo00Ioo`03001oogoo00]oo`03001oogoo00Eoo`8000Uoo`8003ioo`03001oogoo
00Uoo`03001oogoo00=oo`04001oogooOol20002Ool3000017oo000007oo0P0027oo00<007ooOol0
0Woo00D007ooOol007oo00<000Eoo`80009oo`@000Moo`03001oo`0000=oo`04001oogoo0004Ool0
1@00Ool00000Ool00P0000Ioo`00Oomoo`00Ool2000017oo001oogoo0P0000=oo`00Ool00Woo00<0
07ooOol00P000goo0P0000Aoo`00001oo`@00003Ool007oo0080009oo`03001oo`0000=oo`80009o
o`@00003Ool00000009oo`03001oogoo00<000=oo`H00006Ool00000001oo`000Woo00P007oo0000
07oo001oo`000goo00@007oo001oo`800003Ool00000009oo`03001oo`0000D000Eoo`<0009oo`03
001oo`0000aoo`03001oogoo00Moo`03001oogoo009oo`40000000<007ooOol01Woo00<007ooOol0
2goo00<007ooOol01Goo0P002Goo0P00BGoo0P001Goo0P000Woo1@0000Aoo`00000000=oo`03001o
o`0000800004Ool007oo0004Ool00`00Oomoo`05Ool02000Ool00000Ool007oo0003Ool01000Ool0
07oo0P000goo00<007ooOol00goo00H007ooOomoo`00Ool20002Ool01000Ool000000goo00<007oo
00000Woo00<007oo000017oo00<007ooOol00P0000=oo`00Ool00P000goo00<007ooOol017oo00<0
07ooOol00P0017oo00<007ooOol01@0000Aoo`00Oomoo`800004Ool007ooOol20004Ool200000goo
0000000300000goo00000003Ool40002Ool500000goo0000000300000goo001oo`0300001Goo0000
0000Ool01P0000=oo`00Ool017oo0`004Goo00<007ooOol037oo0@0000000`00Oomoo`0LOol2001D
Ool20005Ool20002Ool300001Woo00000000Ool0009oo`03001oo`00008000=oo`04001oogoo0005
Ool20002Ool00`00Oomoo`02000:Ool20005Ool01@00Oomoo`00Ool00P000Woo00<007ooOol01goo
00H007oo000007oo0002Ool20003Ool02000Ool007oo001oo`00Ool20002Ool00`00Ool000020002
Ool01000Oomoogoo0P000goo0P000Woo0P000goo00<007ooOol00P000Woo00<007ooOol01Goo00<0
07oo00002Woo1P0000=oo`00Ool00P0017oo0P000Woo0P000Woo00@007ooOomoo`H00003Ool00000
008000Moo`03001oo`00021oo`40000000<007ooOol077oo0P00E7oo0P001Goo2`0000Aoo`00001o
o`@0009oo`<00003Ool0000000D00004Ool00000Ool400000goo00000005000017oo000007oo1@00
00Aoo`00000000=oo`03001oo`0000L00003Ool007oo00800006Ool00000Ool007oo1`0000Eoo`00
001oo`00009oo`03001oogoo00800003Ool0000000800003Ool0000000P00003Ool007oo00P00004
Ool00000Ool500000goo00000005000017oo000007oo100000Aoo`00001oo`<00005Ool00000001o
o`0;00000goo0000000400001Goo00000000Ool00P002Goo00<007ooOol07Woo0@0000000`00Oomo
o`1bOol00`00Oomoo`04Ool01000Oomoogoo0P000goo0P000Woo0P000Woo00@007ooOol000Aoo`<0
00=oo`800004Ool007ooOol300001Goo00000000Ool00P0000=oo`00Ool017oo0`000goo0`0017oo
0P000Woo00@007ooOol000=oo`03001oo`00008000Aoo`03001oogoo00<00003Ool0000000Moo`80
00Ioo`04001oo`00Ool2000017oo000000000goo00@007ooOol000Eoo`03001oo`0000D000Eoo`80
0004Ool007ooOol500000goo00000007Ool20002Ool40009Ool8000[Ool100000003001oogoo079o
o`03001oogoo00Aoo`8000=oo`8000=oo`800004Ool007oo0003Ool00`00Oomoo`02Ool01`00Ool0
07oo001oo`0000Aoo`80009oo`05001oogoo001oo`030002Ool01000Oomoogoo0P000Woo00D007oo
001oo`0000=oo`03001oogoo009oo`03001oogoo009oo`<000=oo`03001oogoo00Eoo`03001oogoo
00=oo`800004Ool00000Ool20002Ool200000goo00000003Ool2000017oo000000000Woo0P000Woo
0P000goo00<007ooOol00P0000=oo`00Ool00Woo0P0000=oo`00Ool017oo1@001Goo1`000Woo1@00
0Woo00<007oo00000P0000=oo`00000017oo00<007oo00000P00:goo0@0000000`00Oomoo`1kOol4
0002Ool700000goo001oo`0200001goo00000000Ool007oo00@00004Ool00000Ool300000goo001o
o`0;0003Ool01@00Ool00000Ool00P0000=oo`0000001`0000=oo`0000001P0000=oo`0000000`00
00=oo`0000000`0000=oo`00Ool00goo00<007ooOol040000goo1@000Woo1P0000Eoo`00000007oo
00@00003Ool0000000L00003Ool0000000D00003Ool0000000T00003Ool007oo00<00003Ool00000
00X002]oo`40000000<007ooOol0NWoo00<007ooOol0100000=oo`0000000P001Goo00<007oo0000
0Woo0P000Woo00<007ooOol00Woo00<007ooOol01Goo00T007oo001oo`00Ool007oo00001Woo00@0
07ooOol0009oo`8000=oo`03001oogoo00800003Ool0000000Aoo`<00003Ool00000009oo`04001o
ogoo0003Ool01@00Oomoogoo00000Woo00<007ooOol01Woo00@007ooOol0009oo`06001oogoo001o
o`001Goo0`0000=oo`0000000Woo0P0000=oo`0000000`001Goo00<007oo00000Woo00<007ooOol0
0P0000=oo`00Ool00`0017oo0`000Woo00@007oo0000009oo`03001oo`0000=oo`03001oo`0000D0
02]oo`40000000<007ooOol0Ngoo00<007oo00000P000Woo0`000goo0P0000Aoo`00Ool000=oo`03
001oo`00009oo`03001oo`00009oo`08001oo`00001oo`00Ool000=oo`03001oo`0000=oo`800005
Ool00000Ool00006Ool01000Ool000000Woo0`000Woo0`000goo00@007oo000000Qoo`03001oo`00
009oo`8000Yoo`03001oogoo00<000Aoo`800006Ool00000001oo`001Goo0P000Woo10000Woo0P00
1Goo00D007oo001oo`00009oo`<00004Ool007ooOol2000017oo001oogoo1P000goo2`00;Goo0@00
00000`00Oomoo`1jOol00`00Ool000030003Ool00`00Ool0000500000goo000000030004Ool00`00
Ool00003Ool20003Ool01@00Ool00000Ool01`0000=oo`0000000Woo00<007oo00000goo00<007oo
00000goo00<007ooOol00Woo00<007ooOol00P0000Aoo`00Oomoo`800003Ool007oo00Aoo`80009o
o`@0009oo`80009oo`<000=oo`07001oogooOol007oo00000goo1P0000Aoo`00Ool0009oo`800003
Ool007oo00Aoo`L00005Ool007oo001oo`020006Ool00`00Ool0000200000goo001oo`0300000goo
000000030002Ool600001Goo000007oo0000:goo0@0000000`00Oomoo`1jOol600000goo00000002
000017oo000007oo200000Eoo`00Ool007oo00800004Ool00000Ool5000017oo000007oo2P0000=o
o`0000000Woo00<007oo00000Woo00@007ooOomoo`800003Ool007oo00<00004Ool00000Ool30002
Ool00`00Ool0000200000goo000000020003Ool40002Ool00`00Ool000030002Ool200002Goo001o
o`00Ool007oo001oo`020003Ool8000017oo001oogoo1@0000=oo`0000000P0000=oo`0000004000
00=oo`0000000`0000=oo`0000000`000goo0`0000Eoo`00001oo`0002]oo`40000000<007ooOol0
O7oo0P000Woo0`0000=oo`0000000P000Woo00<007ooOol00Woo00@007oo0000009oo`03001oo`00
008000=oo`07001oo`00001oo`00Ool00P001Goo0P000Woo00<007ooOol00Woo0P0000=oo`000000
0Woo0P001Woo00T007ooOomoo`00Ool007oo00000Woo0`0000Aoo`00Ool000Aoo`@0009oo`04001o
o`00Ool2000017oo000007oo10000Woo00<007oo00000goo00@007oo0000009oo`800003Ool007oo
009oo`<00004Ool00000Ool300000goo00000002Ool00`00Ool00006000017oo001oogoo100000Ao
o`00Oomoo`80009oo`03001oogoo00D00004Ool007oo0002Ool00`00Oomoo`0YOol100000003001o
ogoo07Yoo`<00005Ool007ooOol00002Ool01@00Oomoo`00Ool00P0000=oo`00Ool017oo00D007oo
Oomoo`0000=oo`03001oogoo008000Aoo`08001oogoo001oo`00Ool000=oo`04001oo`00Ool20000
0goo00000005Ool00`00Oomoo`0200000goo001oo`020002Ool20002Ool01`00Oomoogoo001oo`00
009oo`03001oogoo00800003Ool007oo009oo`03001oogoo0080009oo`@00005Ool007ooOol00008
Ool20004Ool200000goo00000003Ool200000goo00000006Ool00`00Oomoo`03Ool2000017oo0000
00000Woo0P0000Qoo`00Ool007oo001oo`000Woo00@007oo001oo`800005Ool00000001oo`020000
0goo001oo`0ZOol100000003001oogoo07Yoo`800004Ool000000002Ool8000017oo000007oo0P00
00=oo`00Ool010000Woo0`000Woo00<007oo00002P000Woo0`0000=oo`00Ool00Woo0P000goo1000
00Eoo`00000007oo00800003Ool007oo00P0000:Ool007oo001oo`00Ool007oo0002Ool00`00Ool0
0009000017oo000000000Woo0P000Woo00@007oo000000Aoo`D00009Ool00000001oo`00Ool007oo
008000Eoo`05001oo`00001oo`0<00000goo000000020002Ool00`00Oomoo`0200000goo001oo`05
00001Goo000007oo0000:goo0@0000000`00Oomoo`1jOol00`00Ool0000200002Goo00000000Ool0
07oo001oo`030003Ool20004Ool200000goo000000020002Ool4000017oo001oogoo10000Woo00<0
07ooOol00goo10000goo00<007oo00000Woo0`0000Ioo`00Oomoo`00Ool20002Ool00`00Oomoo`02
Ool01000Oomoogoo0P000Woo00D007ooOomoo`0000Aoo`06001oo`00Ool007oo0`000goo00<007oo
Ool00Woo00@007ooOomoo`8000=oo`03001oogoo00800004Ool007oo0003Ool00`00Ool00005Ool0
1@00Oomoo`00Ool01P000Woo0P0000=oo`0000000P001goo1P0000=oo`0000000P0000=oo`000000
;Goo0@0000000`00Oomoo`1jOol20008Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo0P0000=o
o`00Ool00Woo00<007ooOol01Woo0P0000=oo`00Ool00Woo1@0000Eoo`00001oo`0000=oo`04001o
o`00Ool50002Ool20004Ool00`00Ool000050002Ool20003Ool2000:Ool01000Ool000000goo00<0
07ooOol00Woo100000=oo`00Ool00Woo00@007ooOol0009oo`03001oo`0000Moo`03001oo`00009o
o`800005Ool00000Ool00003Ool200000goo0000000200001Woo001oo`00Ool000Moo`03001oogoo
009oo`<00005Ool00000001oo`02000]Ool100000003001oogoo07Yoo`<00004Ool00000Ool20000
0goo00000002000017oo001oo`000Woo0P000Woo00H007ooOol007oo0003Ool40003Ool01000Ool0
00000goo0P0000Aoo`00000000Qoo`<000Eoo`800005Ool00000001oo`020002Ool200000goo001o
o`03Ool01P00Oomoogoo001oo`800005Ool007ooOol00004Ool300000goo001oo`020004Ool01000
Ool007oo0P000Woo00<007ooOol01goo00<007oo00000P0000Aoo`00Oomoo`800003Ool0000000Ao
o`8000Eoo`800003Ool0000000Aoo`03001oogoo008000=oo`04001oogooOol500000goo001oo`0]
Ool100000003001oogoo07Yoo`@0009oo`80009oo`04001oo`00Ool500001goo001oo`00Ool007oo
00<00003Ool0000000D00004Ool007ooOol500001Goo00000000Ool02`0000=oo`00Ool02P0000=o
o`0000000`0000=oo`0000000P0000Aoo`00001oo`X00003Ool0000000T00006Ool00000Ool007oo
0`0000=oo`00Ool00goo00<007oo00000Woo0P0000=oo`000000100000=oo`0000000Woo0P000Woo
100000Aoo`00Ool0009oo`800005Ool007ooOol00002Ool200000goo001oo`02Ool300000goo0000
000400000goo0000000]Ool100000003001oogoo07Yoo`<00003Ool007oo00=oo`<000=oo`8000Ao
o`<0009oo`03001oogoo00=oo`04001oogooOol200000goo00000005Ool2000017oo001oogoo1000
0Woo00@007ooOol0009oo`04001oo`00Ool5000027oo000007oo001oo`00Ool200000goo00000002
Ool00`00Oomoo`020005Ool40002Ool00`00Oomoo`0200000goo001oo`08Ool00`00Ool00002Ool2
00001Goo001oogoo00000Woo00<007oo000017oo0`0000Moo`00Oomoo`00Ool00002Ool30002Ool0
1000Ool0000017oo0P001goo00D007ooOol007oo00<00005Ool00000Ool0000^Ool100000003001o
ogoo07Yoo`@00003Ool007oo0080009oo`03001oogoo00P00003Ool007oo00]oo`06001oo`00001o
o`000Woo00<007ooOol00Woo0P0000Aoo`00Ool0009oo`03001oo`0000=oo`03001oogoo0080009o
o`06001oogoo001oo`000Woo0P000Woo0P000Woo00<007oo00001Goo0P0000=oo`0000000Woo0P00
00=oo`00Ool00P0000=oo`0000000`000Woo0P001Goo00@007ooOol0009oo`03001oo`00009oo`03
001oogoo009oo`<000=oo`03001oogoo009oo`800003Ool007oo00800003Ool00000008000=oo`03
001oogoo00=oo`03001oogoo00=oo`04001oogooOol2000017oo001oogoo0P00;Goo0@0000000`00
Oomoo`1jOol300000goo000000020002Ool01000Oomoogoo100000Ioo`00001oo`00Ool600001Woo
001oo`00Ool0009oo`P000Aoo`H00003Ool0000000T0009oo`D0009oo`<00004Ool00000Ool80000
0goo000000030002Ool90002Ool01000Ool000000Woo00D007oo000007oo00D00003Ool00000009o
o`03001oogoo00@0009oo`800004Ool00000Ool60003Ool01000Oomoo`0017oo00P007ooOomoo`00
Ool007oo10000goo100000Aoo`00001oo`8002eoo`40000000<007ooOol0NWoo00<007ooOol00P00
00Aoo`000000009oo`<0009oo`04001oo`000003Ool00`00Ool00005Ool200001Goo000007oo0000
1Goo1@001Woo00D007oo000007oo008000Aoo`04001oogooOol20002Ool01000Oomoo`000goo1000
0goo00H007oo000007oo0005Ool500000goo001oo`04Ool20007Ool01@00Oomoogoo00001Woo0`00
0goo00H007ooOol007oo0004Ool00`00Ool00009Ool01000Oomoogoo0P000Woo00@007ooOol000Qo
o`03001oogoo00800003Ool007oo009oo`03001oogoo02]oo`40000000<007ooOol0NWoo00L007oo
Oomoo`00Ool00009Ool00`00Oomoo`020005Ool00`00Oomoo`03000017oo001oo`000Woo0`001goo
00<007oo00000P0000=oo`00Ool00goo1@001Goo0`000goo0P001Goo00@007oo000000=oo`03001o
o`0000Aoo`80009oo`03001oogoo00P00004Ool00000Ool20004Ool01000Oomoogoo0P0000Ioo`00
Oomoo`00Ool30003Ool01000Ool000001Goo00H007oo000007oo0003Ool20003Ool01000Oomoogoo
0P0000=oo`00Ool01Goo00@007ooOomoo`<0009oo`04001oogoo000]Ool100000003001oogoo07Yo
o`04001oogooOol40007Ool00`00Oomoo`03Ool01000Ool000000Woo00P007ooOol007oo001oo`00
1Goo00<007ooOol00goo00<007oo00000goo0P0000=oo`00Ool01goo00D007oo001oo`0000Ioo`05
001oogoo001oo`02000017oo000000000goo0`000goo00<007oo00000Woo0`0000=oo`0000000P00
0Woo00<007ooOol017oo00<007oo00000Woo0P0000Ioo`00Ool007oo0006Ool01000Oomoo`000goo
00<007ooOol01Goo00<007oo00001Goo0P002goo00H007ooOol007oo0002Ool300000goo0000000`
Ool100000003001oogoo07aoo`D00003Ool000000080009oo`04001oo`000002Ool700000goo0000
000600001Goo00000000Ool01@0000=oo`0000000`000goo0`0000=oo`00Ool01@0000=oo`000000
0goo00@007oo001oo`<000Aoo`05001oo`00001oo`020002Ool400001Goo00000000Ool00`0000Eo
o`00000007oo00<0009oo`L00004Ool007ooOol20002Ool01000Ool007oo0`0000=oo`00Ool00P00
0goo00<007ooOol00P000Woo00P007ooOol007oo001oo`0017oo0P001Woo0`0000Aoo`00Oomoo`D0
0003Ool00000031oo`40000000<007ooOol0O7oo0`000Woo00@007ooOomoo`800003Ool007oo009o
o`05001oogooOol00003Ool2000:Ool20005Ool20004Ool00`00Ool00002Ool20002Ool5000017oo
001oogoo0P0000Qoo`00001oo`00Ool007oo300000=oo`0000000P000Woo00<007oo00000P002Woo
0P0000=oo`0000000Woo00@007ooOomoo`<00003Ool007oo009oo`03001oo`00009oo`04001oogoo
0002Ool200000goo00000002Ool00`00Oomoo`05Ool01000Oomoo`001goo0P000goo00H007ooOomo
o`00Ool300000goo0000000`Ool100000003001oogoo07ioo`<00003Ool007oo00Ioo`04001oogoo
0005Ool40002Ool01`00Ool007oo001oo`00009oo`<000Moo`<000Ioo`03001oogoo00Aoo`03001o
ogoo00=oo`03001oogoo00Yoo`04001oogoo0002Ool01000Oomoogoo100000Ioo`00Ool007oo0002
Ool00`00Ool00002Ool01@00Oomoogoo00000goo00<007oo00000goo00<007oo00000Woo00<007oo
00000P000Woo00@007ooOol000=oo`05001oo`00Ool00002Ool00`00Oomoo`020006Ool00`00Ool0
0002Ool00`00Oomoo`09Ool00`00Ool00002Ool00`00Oomoo`0^Ool100000003001oogoo07eoo`H0
0006Ool00000Ool007oo0P0000Eoo`00000007oo00<00003Ool0000000<00003Ool0000000<00003
Ool0000000800003Ool0000000800003Ool0000000=oo`D00003Ool00000009oo`03001oo`0000L0
0005Ool00000001oo`02000027oo001oogoo001oo`00Ool200000goo001oo`03000017oo000007oo
0P0000Aoo`00Oomoo`80009oo`03001oogoo009oo`<00007Ool007oo001oo`00Ool00P0000=oo`00
00000P000Woo00<007oo00001Woo00@007ooOol000Ioo`06001oogooOol007oo0P0000=oo`00Ool0
0Woo0P0000Aoo`00Oomoo`800003Ool0000000H00003Ool00000031oo`40000000<007ooOol0OGoo
00D007ooOomoo`0000Uoo`03001oo`0000800005Ool007oo001oo`030002Ool30002Ool00`00Oomo
o`06Ool20002Ool01000Oomoo`001Woo0`000Woo00<007ooOol01Goo00D007ooOomoo`0000=oo`80
0004Ool007ooOol300000goo001oo`07Ool20002Ool00`00Ool00006Ool30003Ool20004Ool00`00
Ool00003Ool200000goo001oo`04Ool00`00Ool00007Ool01@00Oomoogoo00002Goo00<007ooOol0
1Goo00<007ooOol017oo00<007oo00000Woo00<007ooOol0;goo0@0000000`00Oomoo`1lOol40000
17oo001oo`000Woo00<007oo00000Woo0`0000Eoo`00Oomoo`0000Eoo`8000=oo`04001oogooOol2
00001Goo001oogoo00000Woo00D007ooOomoo`0000=oo`04001oo`000002Ool20005Ool01`00Oomo
ogoo001oo`0000=oo`@0009oo`800005Ool00000001oo`030002Ool3000017oo001oo`000goo00<0
07oo00001Woo0P000Woo00<007oo00000goo00<007oo00000goo00<007ooOol02Goo00D007ooOomo
o`00009oo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`<000Ioo`800005Ool00000
Ool0000aOol100000003001oogoo07aoo`03001oo`0000@00003Ool00000009oo`03001oogoo0080
00=oo`800003Ool007oo00800004Ool000000002Ool01000Ool000000goo0P000goo00<007ooOol0
0Woo00L007oo000007oo001oo`02000017oo001oogoo0P000Woo00<007ooOol01Woo00<007oo0000
17oo1`000goo00@007ooOol000Aoo`05001oogoo001oo`03000017oo001oo`000Woo10000goo00@0
07ooOomoo`800005Ool007ooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`0:Ool00`00Oomoo`08
Ool00`00Oomoo`0300000goo001oo`0cOol100000003001oogoo07eoo`<00003Ool00000009oo`03
001oo`0000Aoo``00003Ool0000000<00004Ool007ooOol700000goo00000003000017oo00000000
0Woo00H007ooOomoo`00Ool200000goo0000000300001Goo001oo`00Ool00P0000Aoo`00001oo`<0
0004Ool00000Ool:0002Ool300000goo001oo`03Ool6000017oo000007oo0P0000Aoo`00Oomoo`80
009oo`@00009Ool00000001oo`00Ool007oo00<00005Ool007ooOol00002Ool90002Ool30004Ool0
1@00Ool00000Ool00P0000Eoo`00001oo`00035oo`40000000<007ooOol0O7oo1P000goo00@007oo
Oomoo`<00004Ool007oo0003Ool40005Ool00`00Oomoo`03Ool00`00Oomoo`02Ool400001Woo001o
ogoo001oo`<00003Ool0000000Aoo`<00003Ool00000009oo`08001oo`00Ool007oo001oo`8000Eo
o`800003Ool00000009oo`<000=oo`03001oogoo00Eoo`<000Eoo`03001oogoo00<000Eoo`03001o
o`0000800005Ool007ooOol00002Ool01000Oomoo`002Goo00<007ooOol027oo0`000Woo00@007oo
Ool000Aoo`05001oo`00Ool0000dOol100000003001oogoo07aoo`<0009oo`06001oogoo001oo`00
17oo00D007ooOol007oo00D0009oo`8000=oo`03001oogoo0080009oo`800005Ool007ooOol0000>
Ool60002Ool00`00Oomoo`03Ool500001Woo00000000Ool0009oo`80009oo`03001oogoo009oo`03
001oo`0000=oo`04001oo`000008Ool01000Oomoo`000goo00<007ooOol00`0000=oo`00Ool00Woo
10000Woo00<007ooOol047oo00<007ooOol01goo00<007oo00000Woo0P000Woo0P0000Eoo`00001o
o`00035oo`40000000<007ooOol0O7oo200000Eoo`00Oomoo`00009oo`03001oo`0000`000=oo`<0
0003Ool0000000D00006Ool00000Ool007oo100000Ioo`00Oomoo`00Ool200001Goo000007oo0000
0Woo1@000Woo00H007ooOomoo`00Ool800000goo001oo`07Ool20008Ool2000017oo001oo`0017oo
0`000Woo1@000Woo100017oo00<007oo00000goo00<007oo00000P0000Aoo`00Ool000Eoo`80009o
o`80009oo`03001oogoo00=oo`@00005Ool00000Ool0000aOol100000003001oogoo07ioo`D00005
Ool007ooOol00006Ool00`00Ool00002000027oo001oo`00Ool007oo0002Ool01P00Oomoo`00Ool0
00Aoo`H00003Ool00000009oo`800003Ool007oo00<000Aoo`80009oo`04001oogoo000;Ool00`00
Oomoo`04Ool01000Ool000000Woo0P0000=oo`0000000Woo00@007oo000000Eoo`03001oo`000080
0006Ool007ooOol007oo0P0000=oo`0000000Woo00<007ooOol00P000Woo00<007ooOol00goo00<0
07oo00000goo00L007ooOomoo`00Ool0000<Ool40002Ool200000goo0000000cOol100000003001o
ogoo07eoo`800003Ool007oo009oo`<000=oo`07001oogoo001oo`00Ool00P000Woo0P000Woo0`00
00Aoo`00Ool000Eoo`@00005Ool00000001oo`0200000goo001oo`04Ool20004Ool01000Oomoogoo
0`0000Ioo`00Oomoo`00Ool20002Ool00`00Ool00005Ool01@00Ool007oo00002Goo00@007oo0000
00Ioo`05001oogoo001oo`0200000goo000000030002Ool40002Ool00`00Oomoo`03Ool01000Oomo
o`001Woo00l007oo000007oo001oo`00Ool007oo001oo`00Ool00P000Woo00<007ooOol00Woo0`00
0Woo00<007oo0000<Goo0@0000000`00Oomoo`1mOol50002Ool20003Ool01P00Oomoo`00Ool0009o
o`800004Ool007ooOol3000:Ool30003Ool300000goo001oo`07Ool01000Oomoogoo0P001Woo0P00
0Woo00H007ooOol007oo0007Ool01000Oomoo`000Woo00<007oo00001Goo00@007ooOol000Aoo`80
009oo`04001oo`000002Ool01P00Ool00000Ool000=oo`L0009oo`800004Ool00000Ool2000<Ool0
1P00Oomoo`00Ool000=oo`03001oo`0000=oo`03001oo`0000800005Ool00000Ool0000aOol10000
0003001oogoo07eoo`800003Ool0000000@0009oo`05001oogoo001oo`0200000goo00000002Ool7
000017oo000007oo0P0000=oo`0000000Woo0P000Woo1P0000Aoo`00001oo`@000Ioo`04001oogoo
Ool30003Ool01000Oomoo`000goo00<007oo00000goo0`0000Aoo`00Ool0009oo`800003Ool00000
0080009oo`<00003Ool007oo0080009oo`L00003Ool0000000h00003Ool007oo009oo`L00005Ool0
07ooOol00003Ool00`00Oomoo`020002Ool01000Ool007oo1P0000Eoo`00001oo`00035oo`400000
00<007ooOol0OGoo00D007ooOomoo`00009oo`<00003Ool007oo00Eoo`<00003Ool007oo00Aoo`03
001oogoo00800004Ool007oo0003Ool00`00Oomoo`0200000goo00000002Ool00`00Ool000020000
0goo001oo`040002Ool01000Ool0000017oo00<007ooOol00goo00@007oo000000=oo`8000=oo`@0
009oo`80009oo`80009oo`03001oogoo00=oo`04001oogoo0002Ool01@00Ool00000Ool010000goo
1P0000=oo`00Ool00P0000Aoo`00Oomoo`800003Ool007oo00Eoo`03001oogoo00800004Ool007oo
0003Ool200001goo00000000Ool007oo00<00003Ool0000003=oo`40000000<007ooOol0PWoo00H0
07oo000007oo0005Ool01000Ool007oo0P000Woo0P0000=oo`00Ool00goo100000=oo`0000000Woo
00<007oo00000Woo0P0000Aoo`00001oo`800004Ool00000Ool2000017oo001oo`0017oo00D007oo
Ool007oo008000moo`04001oogoo0003Ool200000goo00000005Ool00`00Ool00002Ool2000017oo
000007oo0P0000Aoo`00001oo`@000=oo`03001oogoo00800004Ool00000Ool20004Ool00`00Oomo
o`0200000goo001oo`0200000goo001oo`0:Ool500001Goo000007oo0000=7oo0@0000000`00Oomo
o`21Ool2000017oo000000000Woo0P0000=oo`0000001Woo0P000Woo0P0000Aoo`00001oo`80009o
o`@000=oo`@00003Ool0000000<00004Ool00000Ool200000goo00000003Ool01000Ool0000017oo
00<007ooOol00`0000Eoo`00Oomoo`00009oo`04001oogoo0003Ool2000017oo000007oo0P0000=o
o`0000000P000Woo0P0000Aoo`00001ooaD00003Ool0000000<00003Ool0000000H0009oo`06001o
ogooOol007oo3`0000Eoo`00001oo`0003Aoo`40000000<007ooOol0PGoo0`0000Eoo`00Oomoo`00
009oo`@000Moo`03001oogoo00=oo`800004Ool00000Ool200000goo000000020002Ool200000goo
00000002Ool00`00Ool000070002Ool00`00Oomoo`04Ool01000Oomoo`000Woo00<007ooOol00Woo
00<007ooOol00Woo00<007oo00000P0017oo1@0000=oo`0000000Woo00D007ooOol007oo00800004
Ool00000Ool200000goo00000002Ool200000goo0000000900001Goo000007oo00000Woo00<007oo
Ool00P000Woo1@0000Aoo`00001oo`8000=oo`D00003Ool007oo00800003Ool007oo03=oo`400000
00<007ooOol0PGoo0P001Goo00@007ooOol000=oo`800005Ool007ooOol00002Ool20002Ool40002
Ool2000017oo000007oo0P0000=oo`0000000`0000Aoo`00001oo`80009oo`03001oogoo008000Ao
o`04001oo`000009Ool200000goo00000004Ool00`00Ool0000200000goo000000030003Ool01@00
Ool00000Ool00P000Woo00D007oo000007oo00P00008Ool00000001oo`00Ool000=oo`03001oo`00
00800004Ool00000Ool200000goo0000000700001Goo000007oo00000goo200000Eoo`00001oo`00
03Aoo`40000000<007ooOol0PGoo0P0000=oo`0000000P001Woo00@007ooOol0009oo`03001oogoo
00Aoo`80009oo`03001oo`0000800003Ool0000000=oo`04001oogooOol20005Ool01@00Ool00000
Ool00P000goo00H007oo000007oo0002Ool01@00Oomoo`00Ool00P0017oo00@007oo001oo`800003
Ool007oo00D00003Ool0000000<00003Ool0000000<00004Ool00000Ool2000017oo000007oo1@00
00Aoo`00001oo`80009oo`800003Ool0000000<00004Ool00000Ool200000goo00000002Ool50000
0goo0000000:00001Goo000007oo0000=goo0@0000000`00Oomoo`22Ool01@00Oomoogoo00000goo
00@007oo001oo`8000=oo`05001oogoo001oo`0900000goo00000003000017oo000007oo0P0000Ao
o`00001oo`800003Ool0000000P00003Ool0000000800003Ool000000080009oo`80009oo`03001o
ogoo00D00004Ool00000Ool200000goo000000030002Ool5000017oo000007oo0P0000Aoo`00001o
o`T00003Ool0000000`00003Ool0000000H00003Ool0000000@00004Ool00000Ool900001Goo0000
07oo0000=goo0@0000000`00Oomoo`22Ool01@00Ool00000Ool00P000Woo00<007ooOol01goo0P00
00Aoo`00001oo`H0009oo`05001oo`00001oo`020004Ool2000017oo000007oo0P0000Aoo`00Oomo
o`H00004Ool00000Ool20002Ool00`00Oomoo`06Ool00`00Oomoo`020002Ool01@00Ool00000Ool0
1P000Woo00D007oo000007oo00800003Ool0000000Aoo`03001oo`0000D00004Ool00000Ool30000
0goo001oo`020003Ool01000Ool000000Woo0P0000=oo`00Ool00`0000Aoo`00001oo`800003Ool0
000000@0009oo`06001oogoo001oo`00=goo0@0000000`00Oomoo`22Ool00`00Ool00002Ool30002
Ool01000Oomoo`000Woo00<007oo00000P0017oo0P000goo00@007oo0000009oo`@00005Ool007oo
Ool00002Ool200000goo001oo`02Ool600000goo001oo`02000017oo000007oo0P0000=oo`000000
0goo100000Aoo`00001oo`800003Ool0000000<000Eoo`04001oogoo0002Ool20002Ool01@00Ool0
0000Ool00P000Woo1@0000Ioo`00001oo`00Ool3000017oo000007oo0P0000=oo`000000100000=o
o`0000000P000Woo0P0000Aoo`00001oo`<0009oo`04001oogoo000lOol100000003001oogoo089o
o`03001oogoo009oo`03001oogoo00<000Aoo`04001oogooOol2000017oo000007oo300000=oo`00
00001P0000Aoo`00001oo``00003Ool0000000<000Aoo`T00003Ool0000000<00004Ool00000Ool2
00000goo0000000400000goo00000003000017oo000007oo0P0000=oo`0000000Woo00<007oo0000
3P0000Aoo`00001oo`H00003Ool0000000<00004Ool00000Ool200001Goo00000000Ool00P000Woo
00<007ooOol0>Woo0@0000000`00Oomoo`22Ool01P00Oomoo`00Ool000=oo`03001oogoo00<000Qo
o`05001oo`00Ool00002Ool00`00Ool00002Ool01000Oomoo`000Woo0P0000Eoo`00Oomoo`00009o
o`800005Ool00000001oo`08000017oo000007oo0P0000=oo`0000000Woo00<007ooOol01@000Woo
00<007oo0000100000Eoo`00000007oo00D00004Ool007ooOol2000017oo000007oo0P000Woo00<0
07oo00001P0000Eoo`00Ool007oo0080009oo`80009oo`04001oo`000002Ool500000goo00000002
Ool01000Oomoo`000Woo0P00?goo0@0000000`00Oomoo`27Ool20006Ool02@00Oomoo`00Ool007oo
001oo`0200000goo000000030003Ool01@00Oomoo`00Ool00`0000=oo`00Ool00goo0P0000=oo`00
00000P000Woo10000Woo0`0000=oo`0000000`0000Eoo`00000007oo00D00004Ool007ooOol20000
1Goo000007oo00003Goo00D007oo000007oo00800003Ool00000009oo`03001oo`0000<00003Ool0
000000<00003Ool0000000800004Ool00000Ool20003Ool00`00Ool000030002Ool00`00Oomoo`02
0005Ool00`00Oomoo`0nOol100000003001oogoo08Aoo`04001oogooOol20009Ool00`00Oomoo`03
Ool02000Ool00000Ool007oo0004Ool00`00Ool0000200000goo00000002Ool01000Oomoo`000Woo
100000Aoo`00001oo`800003Ool0000000@00004Ool00000Ool200000goo00000004000017oo0000
07oo0P0000Moo`00000007oo001oo`03000017oo000007oo0P0017oo0P000Woo00@007oo000000Uo
o`<00003Ool0000000<0009oo`05001oogooOol00005Ool40002Ool00`00Oomoo`020016Ool10000
0003001oogoo08Eoo`05001oo`00001oo`0300001Goo000007oo00000goo0P0000=oo`0000001000
00=oo`00Ool0100000Ioo`00Oomoo`00Ool5000017oo000007oo0P0000Aoo`00001oo`800004Ool0
0000Ool200001Goo00000000Ool00P0000=oo`0000000Woo2`0000=oo`0000000`0000Aoo`00001o
o`T00004Ool007ooOol200000goo00000007Ool2000017oo000007oo1P0000Eoo`00001oo`0000Ao
o`03001oo`0000<000Eoo`03001oogoo04Eoo`40000000<007ooOol0Qgoo00<007ooOol027oo0P00
00Aoo`00001oo`80009oo`<00003Ool007oo00=oo`06001oogoo001oo`0017oo00D007oo000007oo
00800004Ool00000Ool2000017oo000007oo0P0000=oo`000000100000=oo`0000001`0000Aoo`00
001oo`800003Ool00000009oo`08001oogoo001oo`00Ool000Aoo`800005Ool007ooOol0000;Ool2
00000goo00000002Ool500000goo001oo`09Ool00`00Oomoo`05Ool00`00Oomoo`15Ool100000003
001oogoo08Aoo`03001oogoo00=oo`03001oogoo00Qoo`800003Ool0000000=oo`03001oo`00009o
o`03001oogoo00=oo`03001oogoo00800004Ool007ooOol20005Ool01@00Oomoo`00Ool00P0000Ao
o`00001oo`<00004Ool00000Ool200000goo000000030002Ool200000goo001oo`02Ool01@00Ool0
0000Ool00P000Woo10000Woo00@007ooOol0009oo`03001oogoo00Uoo`800003Ool0000000=oo`80
0003Ool007oo00]oo`03001oogoo00Eoo`03001oogoo04Eoo`40000000<007ooOol0Q7oo0P0000Eo
o`00000007oo00800003Ool0000000@0009oo`05001oo`00001oo`0600001Goo00000000Ool01@00
0Woo0`0000Aoo`00001oo`800004Ool00000Ool2000017oo000007oo0P0000=oo`000000100000Ao
o`00001oo``00004Ool00000Ool2000017oo000007oo1P0000Eoo`00001oo`00009oo`03001oogoo
00Uoo`800003Ool0000001=oo`03001oogoo00Eoo`03001oogoo04Eoo`40000000<007ooOol0QGoo
00@007ooOol0009oo`8000Qoo`04001oogoo0003Ool00`00Ool00002Ool20002Ool01000Oomoo`00
0Woo0P0017oo00<007ooOol00goo0P000Woo00H007oo000007oo0002Ool01@00Ool007oo00000Woo
0P0000Ioo`00001oo`00Ool70002Ool01@00Ool00000Ool00P0000=oo`0000000`000Woo0P0000Eo
o`00Oomoo`0000aoo`03001oogoo06Aoo`40000000<007ooOol0Q7oo00H007ooOomoo`00Ool20002
Ool20002Ool20002Ool00`00Ool00003Ool01000Oomoo`000goo0`000goo0P0017oo00D007oo0000
07oo0080009oo`05001oo`00001oo`0200000goo001oo`03Ool4000017oo001oogoo0P0000Aoo`00
Oomoo`800005Ool00000001oo`02000017oo001oogoo0P0000=oo`000000100000Eoo`00001oo`00
00moo`03001oogoo06Aoo`40000000<007ooOol0Qgoo0P000Woo00<007ooOol00goo00<007oo0000
17oo0P000Woo00<007oo00000P0000=oo`00Ool00Woo0`000Woo00@007oo000000=oo`05001oo`00
001oo`02000017oo000007oo0P001Woo100000Aoo`00Oomoo`800004Ool007ooOol20002Ool20000
17oo000007oo0P0000Aoo`00001oo`80009oo`04001oogoo001iOol100000003001oogoo08Aoo`80
0003Ool0000000@00003Ool00000009oo`03001oogoo00800003Ool007oo00<00004Ool00000Ool5
0002Ool50002Ool01@00Ool00000Ool00P0000Aoo`00001oo`800003Ool0000000Qoo`800005Ool0
07ooOol00006Ool00`00Oomoo`02000017oo000007oo0P0000Aoo`00001oo`8000=oo`03001oo`00
07Uoo`40000000<007ooOol0QGoo00@007oo0000009oo`80009oo`80009oo`04001oogoo0002Ool0
1@00Oomoo`00Ool00`0000Aoo`00Oomoo`800004Ool00000Ool2000017oo001oogoo0P0000Eoo`00
Oomoo`00009oo`03001oogoo008000Uoo`03001oogoo009oo`03001oogoo00Moo`800004Ool007oo
Ool20002Ool01000Oomoo`000goo00<007ooOol0NGoo0@0000000`00Oomoo`24Ool01@00Oomoogoo
00000Woo00<007ooOol00P0000=oo`00Ool00Woo00@007ooOol000Eoo`04001oogooOol400000goo
00000005Ool20002Ool00`00Ool0000COol00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Ool00002
Ool200000goo001oo`06Ool00`00Oomoo`1iOol100000003001oogoo08Aoo`800003Ool0000000@0
0003Ool00000009oo`800005Ool00000Ool00002Ool2000017oo000007oo0P0000Ioo`00000007oo
0003Ool01000Ool000000Woo00<007oo00000Woo00<007ooOol07Woo00<007oo00000goo00<007oo
0000Pgoo0@0000000`00Oomoo`24Ool00`00Oomoo`03Ool300001Goo000007oo000017oo00@007oo
Ool000Eoo`03001oogoo009oo`800003Ool007oo00Eoo`8000Aoo`04001oogoo000POol00`00Ool0
0005Ool00`00Oomoo`21Ool100000003001oogoo08Eoo`03001oogoo00800004Ool00000Ool20002
Ool20002Ool00`00Oomoo`0200001goo001oogoo001oo`0000=oo`8000Moo`8000Aoo`04001oogoo
000ROol00`00Oomoo`03Ool00`00Oomoo`21Ool100000003001oogoo08Moo`@00003Ool007oo00<0
009oo`06001oo`00001oo`001Woo00<007oo00000goo00<007oo00001Woo00<007ooOol01Woo00<0
07ooOol07Woo00<007oo0000RGoo0@0000000`00Oomoo`25Ool00`00Ool0000300000goo001oo`02
00001Goo00000000Ool00P0000Ioo`00000007oo0004Ool01000Oomoogoo0`001Woo00<007ooOol0
9goo00<007ooOol0RGoo0@0000000`00Oomoo`25Ool00`00Ool000020002Ool01@00Ool00000Ool0
0`0017oo00D007ooOomoo`0000Aoo`03001oogoo0<1oo`40000000<007ooOol0QGoo00D007oo001o
o`00009oo`05001oo`00001oo`0300000goo001oo`05Ool00`00Oomoo`35Ool100000003001oogoo
08Eoo`03001oo`000080009oo`03001oo`0000D00004Ool00000Ool300000goo001oo`36Ool10000
0003001oogoo08Eoo`03001oo`0000Ioo`800004Ool000000002Ool00`00Oomoo`3;Ool100000003
001oogoo08Eoo`03001oo`0000Uoo`<00005Ool007ooOol0003;Ool100000003001oogoo08Eoo`03
001oo`0000Uoo`<0009oo`03001oo`0000800<Uoo`40000000<007ooOol0T7oo100000=oo`000000
0Woo00<007ooOol0b7oo0@0000000`00Oomoo`2@Ool01@00Ool00000Ool00P0000Aoo`00Ool00<Uo
o`40000000<007ooOol0TGoo0`0017oo0`00bGoo0@0000000`00Oomoo`2@Ool30002Ool2000017oo
00000000bGoo0@0000000`00Oomoo`2EOol00`00Oomoo`3<Ool100000003001oogoo09Eoo`03001o
ogoo00800<Yoo`40000000<007ooOol0UGoo00<007ooOol00P00bWoo0@0000000`00Oomoo`3oOomU
Ool100000?l006T00000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 359}, {221.375, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000002?oeHR000000000000000lQHF6QXJ6
QXJ6QXJ6QXJ7QhN8R8V9RX^;S8b<SHf=S8b<Rh^;RXZ:RHV9RHR8R8N7QhJ6QHF5
Q8B3Ph>3PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX>3Ph>3PX:2PX:2PH61PH61PH61
PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH:2
PX:2PX>3Ph>4Q8B5QHF6QXJ6QhN7R8R8R8V9RHZ:RXZ;Rh^;Rh^;RXZ:RXV9RHV8
R8R8R8R9RHV9RHV9R8R8R8R8R8R9RHV9RHV9RHV9RHV8R8R8QhN7QhN7QhN7QhN7
QhN7QhN7QhN8R8R8RHV9RHZ:RXZ:RXZ:RHV9RHV:RXZ:Rh^;Rh^<S8b=SHj?Si2A
TY>DUIFFUiNHV9RIVIVIVIVIVIRHUiNGUYJEUIFEUIFEUYJFUYNGUiNGUYJFUYFE
U9BCTY:AT8n?SXf<S8^:RXV9RHR8R8R8R8R8QhN7QhN6QXJ5QHF5QHF5QHF5QHF5
QHF5QHF5QHF5QHF5QHF5QHF5QHF5QHF5QHF5QHF6QXJ7QhN8RHV:RX^;S8b<S8b<
S8^;RXZ:RHV9R8R8R8R8R8R8RHV9RHV9RHZ:RXZ:RXZ:Rh^<SHf>Shn@T92ATI2@
T8n?SXj=S8^:RXV8R8N7QXJ6QHF5QHF5QHF5QHB4Q8B4Ph>3Ph>2PX:2PX:2PX:2
PX:2PX:2PX:2PX:2PX:3Ph>3PhB4Q8B5QHJ6QhN8R8V9RXZ:RXZ:RXZ;Rh^;S8b<
SHf>SXj>Shj>SXj>SXf=SHf<S8b;Rh^;Rh^;Rhb<SHf=SXj?Shn?Shn?SXj=SHb;
RhZ9R8R7QhJ6QXF5QHF5Q8B4Q8B4QHF5QHF5QXJ6QhN8R8R8RHV9RHV9RHV9RHV9
RHV9RHV:RXZ;Rhb=SHj?T96ATY>CTiBDU9BDU9BDU9BDUIFEUYJFUiNHV9RIVIVI
VIVJVYZIVIVIVIVIVIVIVIVIVIVIVIVIVIZJVYZJVi^KVi^KViZJVYZJVYZJVYVI
VIRHUiNGUYJEUIBDU9>CTi>CTY:CTi>CTi>CTi>BTY:ATI2@Shn?Shn?Shj>SXj=
SHb<RhZ:RHV9R8R8R8R8R8R8RHV9RHZ:Rh^;S8b=SHf=SHf=SHb<Rh^:RXV9RHR8
R8R8R8R8R8R8R8R8R8R8R8N7QhN8R8R8R8R8R8R8R8R8R8R8R8R8R8R8R8R8R8R8
R8R8R8R7QhN7QXJ6QXJ6QXF5QHF4Q8B4Ph>3Ph>2PX:2PX:2PX:2PX:2PX:2PX:2
PX61PH61PH61PH:2PX:2PX:2PX:3PX:2PX:2PX61PH61PH61PH61PH20P820P820
P820P820P861PH61PH61PH61PH61PH:2PX:2PX>3Ph>4Q8B5QHF6QXJ7QhN8R8V9
RXZ;Rhb<SHf=SHf=SHf<S8b;RhZ:RHV8R8N7QXJ6QHF5QHF5QHF5QHF5QXJ6QhN8
RHV:Rhb=SXj?T92ATI6ATI6@T8n?SXj>SHf=SHf=SHb<S8^;RXZ9RHR8R8N7QhN7
QhN8R8R9RHZ:Rhb<SHf>SXj>SXj=SHb<Rh^:RXV9RHV8R8V9RHV:RXZ:Rh^;Rh^;
Rh^:Rh^;Rhb<SHj>Si2@TI6BTY:BTY:BTY:BTY6ATI6@T92@T92?Shn?Shn?Shn?
Shn@T92@T92@Shn>SHb;RhZ9R8R7QhJ6QXJ5QHF5QHB4Q8B4Q8B3Ph>3Q8B4Q8B4
Q8B5QHF5QHF5QHF5QHF5Q8B4Q8>3Ph>3Ph>3Ph>3Ph>3Q8B4QHF5QXJ7QhN8R8R8
RHV9RHV9RHR8R8N7QXF5Q8B4Ph>3PX:2PX:2PH61PH61PH61PH61PH61PH61PH61
PH61PH61PH61PH61PH61PH61PH62PX:2PX:2Ph>3PhB4Q8B5QHF5QXJ7QhN8R8R8
R8R8R8R7QhN7QhN7QhN7R8R8RHZ:Rhb=SHj?T92ATI:BTi>DU9FEUIJFUYJFUYJF
UYJFUYNGUiRHV9RIVIVIVIVIVIRHV9RGUiJFUIFDU9>CTY:AT92?SXj=SHb<Rh^;
Rhb<S8f=SHj>SXn?SXj>SHf<Rh^:RXV9RHV9RHV9RHV9RXZ;S8b=SXn@TI6BTi>C
U9BDU9BDTi>CTi>CTi>CTi>CU9BDU9BDU9BDU9BDU9BDU9BDUIFEUYJFUYFEUIFD
U9BCTi>CTY:BTY6ATI6ATI6@T92@T92@T92@T96ATI6BTY:BTY:BTI6@T8n>SHf<
RhZ9RHR8QhN6QXJ5QHF5QHB4Q8B4Q8B5QHF5QHJ6QXN7R8R9RHV9RXZ:RXZ:RHV9
RHV8R8R8R8R8R8V9RHZ:Rhb<SHf>SXj>Shn?Shn?Shn?Shn?Shn?SXj>SXj>SXf=
SHf=SHf=SHf=SXj>SXn?Shn@T92?Shn?SXj>SHf=SHb<S8^;RXZ9R8R7QhJ6QHF5
Q8B4Q8B4Ph>3Ph>3Ph>3Ph>3Q8B4Q8B5QHF6QXJ7QhR8RHV:RX^;Rhb<S8f=SHf=
SHj>SXj?Shn@T92@T92?Shn?Shn?Shn@T96ATI:BTY:BTY6AT8n?SXf=S8b<Rh^;
RXZ:RHV8R8R7QhN6QXJ6QXJ6QXJ6QXJ6QXF5QHB4Q8B4Ph>3Ph>3Ph>3Ph>4Q8B4
Q8F5QHF6QXJ7QhR8R8V9RHZ:RX^;Rh^;Rhb<S8^;Rh^;RXZ:RXZ9RHV:RXZ:RX^;
Rh^<S8b<S8b<S8b<S8^;RhZ:RHV8R8N7QXJ6QHF5QHF5QHF5QHF5QHF6QXJ6QXJ6
QXJ6QXJ6QXJ7QhN7R8R8RHV9RHV:RXZ:RHV9RHR8R8N7QhJ6QXJ6QHF5QHB4Q8B3
Ph>3PX:2PX:2PX:1PH61PH61PH61PH61PH61PH62PX:2PX:2PX:3Ph>3Q8B4QHF6
QXJ7QhR8R8V9RHZ:RXZ;Rh^;Rh^;RhZ:RXZ:RXV9RHV:RHV9RHV9RHR8R8R8R8R8
RHV9RX^;S8b=SXj>Shn?Shn?T92@TI6BTY>CU9BEUYJFUiNGUiNGUiNGUiNGUiNH
V9RIVIZJVYZJVi^KVYZJVYZIVIRHUiJFUIBCTY6@Shj=S8b;RhZ:RXV9RHV8R8R8
R8R8R8R9RHV9RHV9RHV8R8N7QXJ5QHF4Q8B3Ph>3Ph>3Ph>2PX:2Ph>3Ph>3Ph>4
Q8B4QHF5QHJ6QXJ6QHF5QHJ6QXJ6QhN8R8V9RXZ:Rh^;Rh^:RXZ:RHV9RHV9RHV:
RXZ:RX^;Rh^;Rh^;RXZ9RHR7QhJ5QHB4Q8>3Ph:2PX:2PH61PH61PH61P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PX:2PX>3PhB4Q8B5
QHF5QHF4Q8B4Q8>3Ph>2PX:2PH61PH61PH60P820P820P820P820P820P820P820
P820P820P821PH61PH61PH61PH62PX:2PX>3PhB4Q8F5QXN7R8V9RXZ;Rh^;Rh^:
RXV9R8R7QhN7QXJ6QXJ6QXJ6QXJ7QhN7QhR8R8V9RX^<S8f>Si2ATY>CU9BDU9BD
U9BDTi>BTY6ATI2@Shn>SXj>SXj>SXj>SXf=SHf<S8^;RXZ9RHR8QhN6QXJ5QHF5
QHB4Q8B4Q8B4Q8>3Ph>3Ph>4Q8B4Q8B4QHF5QHF5Q8B4Q8B4Q8>3Ph>3Ph>3Ph>4
Q8B4Q8F5QXJ6QhN8R8V9RHZ:Rh^<SHf>Shn@TI6ATY:BTY:BTY6ATI2@Shn?SXj>
SHf<S8^:RXV8QhN6QXF5Q8B4Ph>3Ph:2PX:2PX:2PX61PH61PH61PH61PH61PH61
PH61PH61PX:2PX:2PX:3Ph>3Q8B4Q8F5QHJ6QXJ6QXJ6QXJ6QXN7QhR8RHV:RX^;
S8b<S8b=SHf=SHj>SXj?Shn@T92@T92@T92@T92@T92@T92@TI6ATI6AT92@Shn>
SXf=S8^;RXZ:RHV8R8R7QhN7QhJ6QXJ6QXJ6QXJ5QHF5Q8B4Q8B3Ph>3Ph>3Ph>3
Ph>3Ph>4Q8B4Q8B5QHF6QXN7R8R9RXZ;S8b=SHf=SXj>SXj>SXj>SXn?T92ATY:C
U9FFUYNGV9RIVIVIVIZJVYZJVYZKVi^KW9bLW9bMWIfMWIfMWYjMWIfMWIfMW9bL
W9^KViZJVYVIVIVIVIVIVYZJVYZJVIVIV9RHUiNFUIBDTi:AT8n>SHb<RhZ:RHV8
R8N7QhJ6QXF5QHF5QHF5QHF5QHJ6QXJ7QhR8RHZ:Rh^<S8b<S8^;RXZ9R8R7QhN6
QXJ6QXJ6QXJ6QXN7QhN7QhN7QXJ6QXF5QHF4Q8B4Ph>3Ph>3Ph>3Ph>3Ph>3PhB4
Q8B5QHJ6QhN8R8V:RXZ;Rh^;RXZ9RHR8QhN6QXF5QHB4Q8B4Q8B4Q8B4Q8B5QHF6
QXN7QhR8R8V9RHV9RHV9RHV9RHR8R8R7QhN7QXJ6QXJ5QHF6QXJ6QhN7R8V9RX^<
S8f>Shn@T92@T92@Shj>SHb<Rh^:RXV9RHV9RHV9RHZ:RXZ:RHV9R8R8QhN7QhN6
QXJ7QhN7QhN7QhR8R8N7QhN6QXJ5QHF5QHF5QHF5QHF5QHF5QHF4Q8B4Q8B4Q8B4
Q8B4QHF5QHJ6QhN8R8V9RXZ;Rh^<S8b<S8f=SHf=SXj>Shn@T96ATY:CU9BEUIJG
UiRHV9VIVIVIVIVIVIRHV9NGUiJFUYFEUIFDU9BCTi>CTi:BTY:BTY>CTi>CTi>C
Ti:BTI2?Shj=SHb;Rh^:RXZ:RHV9R8R7QhJ6QHF5Q8B4Q8>3Ph>3Ph>3Ph:2PX:2
PX:1PH61PH61PH61PH20P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P821PH61PH61PH62
PX:2PX:2PX:2PX:2Ph>3Ph>3Q8B4Q8F5QXJ7R8R9RX^<S8f>SXn?Si2@T92ATI6A
TI6ATI2@T92?Shj=SHb;RXZ9R8R7QhJ6QXJ6QXJ6QXJ7QhN8R8R8RHV9RHR8R8R8
R8N7QhJ6QXF5QHB4Q8>3Ph>2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2
PX:2PX:2PX:2PX:3Ph>3PhB4Q8F5QXJ7QhR9RHZ:Rh^;Rhb<Rh^;S8b<S8b=SHj>
SXj?Shn?T92@T92@T92@T92@T8n?Shn@T92@T92@T92@T92@Shn>SXj=S8b;RXZ9
R8N7QXJ5QHB4Q8B3Ph>3Ph>2PX:2PX:2PX:2PX:2PX:2PX:3Ph>3PhB4Q8B5QHF5
QHJ6QXJ7QhN8R8V9RHZ:RXZ;Rh^;S8b<SHf=SHb<S8b;RhZ:RXZ:RHV9RHV:RXZ:
RXZ:RXZ:RXV9R8R7QhJ6QXJ5QHF5QHF5QHF5QHF5QHB4Q8>3Ph>2PX:2PX:2PX:2
PX61PH62PX:2PX:2PX:2Ph>3PhB4Q8F5QHF5QHF5QHF4Q8B3Ph>3Ph:2PX:2PX:2
PX:2PX>3Ph>3PhB4Q8F5QHF5QXJ6QXF5QHF5QHF5QHJ6QXN7QhR8RHZ:Rhb<SHj>
Shn@T92ATI6BTY:CTi>CU9BDU9BCTi>CTY:BTI6ATI6ATI6ATI6ATY:BTY>CU9BE
UIJFUiNGV9RHV9VIVIVJVYZJVY^KVi^KVi^KViZJVYVIV9RGUiJFUIFEU9BCTi>B
TY:BTY:BTY:BTY:BTY:BTY:BTY:ATI6ATI6ATI2@T8n?SXj=SHb<S8b;Rhb<S8b<
SHf=SHf>SXj?Shn@T92@T92@T92@T96ATI6ATI6ATI6@T92@T92@T92@TI6BTY:C
TiBDU9FEUYJFUiNGUiNGUYJFUIFDU9BCTi>CTi>BTY:BTY6AT92?SXj=S8^:RHR8
QhN6QXF5QHB4Q8B4Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Q8B4Q8F5QXJ6QhR8RHZ:
Rh^<S8b=SHf=SHf=S8b;RhZ:RHV8R8N7QXJ6QHF5QHF5QHF5QHF5QXJ6QhN8R8V:
RX^<S8f>SXj?Shn?Shn?Shj>SHb<RhZ9RHR8QhN6QXJ6QHF5QHF4Q8B4Q8B4Q8B4
Q8F5QHF5Q8B4Q8B4Q8B4Q8B4Q8B5QHF6QXJ7QhR8R8V9RHZ:Rh^<S8f>Shn@TI6A
TY:BTI6AT92?Shj>SHf<S8^:RXV9R8R7QhN6QXJ5QHF5QHF4Q8B5QHF5QHF6QXJ6
QXJ6QXJ5QHF4Q8B4Ph>3Ph>3Ph>3Ph>3Ph>3PhB4Q8B4Q8B4Q8B5QHF5QXJ7QhR8
RHZ:Rhb<SHf=SHf=S8b<Rh^;Rh^;S8b<SHj>Si2@TI6ATY:BTi>CU9BDUIFEUIFD
U9BCTi:BTI2@Shj>SHb;RhZ9RHR8R8R8R8R8R8R9RHV:Rh^<SHf>SXj>SXj>SHf<
S8^;RXV9R8N7QXF5Q8B4Ph>3Ph:2PX:2PX61PH61PH61PH61PH61PH60P820P820
P820P820P820PH61PH61PH61PH61PH62PX:2PX>3Ph>3Q8B4Q8B5QHF5QHF5QHF5
QHF5QHF5QHF5QHF5QHJ6QXN7R8R9RHZ:RX^;Rh^;Rh^;Rh^:RXV9RHR8QhN6QXJ5
QHF4Q8B4Ph>3Ph>2PX:2PX:2PX:3Ph>3Ph>3Q8B4Q8B4Q8B4Q8>3Ph>3Ph>3Ph>3
Ph>3Ph>3Q8B4Q8B4Q8B4Q8B4Q8B5QHF6QXN7R8R9RHV9RHV9RHV9RHV9RHV9RHV9
RHV9R8R7QhJ6QHF4Q8>3Ph:2PX:1PH61PH61PH20P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820PH61PH61PH:2
PX:2PX:2PH61PH61PH20P820P820P820P820P820P820P820P820P820P821PH61
PH61PH62PX:2Ph>3Q8B5QHJ6QhR8RHZ;Rhb<SHf=SHf=S8b;RhZ9RHR7QhJ6QHF5
Q8B4Ph>3Ph:2PX:2PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61
PH:2PX:2Ph>3Q8B4QHF6QXJ6QXJ6QXJ6QHF5Q8B4Q8B4Q8B4Q8B4Q8B4QHF5QXJ7
QhR8RHZ:Rhb=SXj?T92@TI6ATI6@T92@T8n?Shn>SXj=SHb<Rh^;RXZ:RXZ:RXZ:
Rh^;S8b=SHj>SXj>SHf<Rh^:RHR8QhJ6QHF4Q8B3Ph>3Ph:2PX:2PX:2PX:2PX:2
PX:2PX:2PX>3Ph>3PhB4Q8B4Q8F5QHF5QXJ6QXJ6QhN7QhR8RHV:Rh^<SHf>Shn?
T92@T8n?Shn>SHf<RhZ:RHR7QhJ6QHF5Q8B4Q8B4Q8B4Q8B4Q8B4Q8F5QHF6QXN7
QhR8RHV9RHV9RHR8QhN7QXJ6QHF5QHF5QHF5QHJ6QXN7R8R9RXZ;S8f=SXn@T96A
TI6ATI6@T8n?SXf<S8^:RHV8R8N7QhN6QXJ6QXJ6QHF5QHF5Q8B4Q8B4QHF5QHF6
QXN7QhR8RHV9RXZ:RXZ:RXV9RHR8R8N7QhJ6QXJ6QhN7QhR8R8V9RXZ:RXZ;Rh^:
RXZ9RHV8R8R7QhN7QhN7QhN7R8R9RHZ:Rhb<SHj?Si2@TI6BTY:CTiBDUIFEUYJF
UiNGUiNGUiNGUYJEUIBDTi:BTI2@Shn>SXj>SXj>SXj?Si2@TI:BTY:CTi>BTY:A
TI2@Shn>SXj=SHf=S8b<Rh^:RXV8R8N7QXJ6QHF5QHF5Q8B4Q8B5QHF5QHF6QXJ7
QhN8R8R9RHZ:RX^;Rh^<S8b=SHf>SXn@T96BTY>CU9BEUIFFUYJFUYJFUYFEUIBD
Ti>BTY:BTI6ATI6ATI2@Shj=SHb;RXV9R8N7QXJ6QHF5QHF5QHF5QHF5QHF5QHF5
QHF5QHF5QHF5Q8B4Q8B4Q8B4QHF5QHJ6QhN8R8V9RXZ;Rhb<S8f=SHf=SHf=SHf=
S8b;RXZ9R8R7QXJ5QHB4Q8>3Ph>2PX:2PX:2PX:1PH61PH61PH61PH61PH61PH61
PH61PH:2PX:2PX:2PX:3Ph>3Q8B4QHF6QXJ7R8R8RHV9RHV9RHV9RHV9RHZ:Rhb<
SHj?T96BTY>DU9FEUIJFUYJFUiNGUiNHV9RHV9RHV9RHUiNGUYJEU9BCTY:AT8n?
SXf<S8^;Rh^:RXZ:Rh^;Rhb<SHf>SXj>Shn?SXj>SHf<Rh^:RHV8R8N7QhJ6QXJ6
QXF5QHF5Q8B4Q8>3Ph>3Ph:2PX:2PX:2PX:2PX:2PX>3Ph>3PhB4Q8F5QHJ6QhN7
QhR8R8R8RHV9RXZ;Rh^;S8b<S8b<S8b<S8b;RhZ:RHV8R8N7QXJ6QXF5QHF5QXJ6
QXN7QhR8RHV:RX^<S8f>SXn@T96ATY:BTY:BTY:BTI6@T8n>SXf<RhZ9R8R7QXJ5
QHB4Q8>3Ph>3PX:2PX:2PX:2PX:2PX:2PX:1PH61PH61PH60P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P861PH61PH61PH62PX:2PX:2PX:2PX:2PX:3Ph>3Ph>4Q8B5QHJ6QhR8
RHZ;Rhb<SHf>SXj>SXj=SHb;RhZ:RHR8QhN7QhJ6QXJ6QhN7QhR8R8V9RHZ:Rh^<
S8b=SHj>SXn?Shn@T92@T92@T92?Shn?Shn?Shn?Shn@T8n?Shn>SXj>SHf=SHf=
SHj>SXn@T96ATY>DU9FEUYJGUiNGUiNGUiNGUYJFUYFEUIFEUYJFUYNGUiNGUiNF
UYFEU9>CTY6@Shj=SHb;RhZ:RXZ:RHV9RHV9RHR8R8R7QhN7QhN7R8R8RHV9RX^;
S8f>Shn@TI6BTi>CU9BDU9BDTi>CTY:BTI2@Shn>SHf<S8b;Rh^;Rh^;S8b=SHj>
Shn@T96ATI6ATI6@Shn>SHb;RXV9R8N6QXF5Q8B4Ph>3Ph:2PX:2PX61PH61PH61
PH61PH20P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P821PH61PH62PX:2PX>3Ph>3Ph>3Ph:2
PX:2PH61PH61PH60P820P820P820P820P820P820P861PH61PH61PH:2PX:2PX>3
Ph>3PX:2PX:2PX:2PX:2PX:2PX:2PX:3Ph>3Ph>3Ph>3Q8B4Q8B5QHF6QXJ7QhN7
R8R8R8R8R8R8R8V9RHV:RX^;S8f>Si2ATY>DUIFFUiNGV9RHV9RHV9RHUiNFUYFE
U9>BTI6@Shj>SHb<Rh^:RXZ9RHV9RHZ:RX^;S8f=SXn@TI6BTi>CTi>CTi>BTY6A
T92?Shj>SXj=SHf=SXj>SXn?Si2@T96ATI:BTY:BTY:BTI6AT92@Shn>SXf=SHf=
SHj>Shn@TI6BTY>CTiBDU9BDU9>CTi>CTi>CTi>CTi>BTY6@T8n>SHb;RXZ9R8R7
QhJ6QHF5Q8B4Q8>3Ph>3Ph>3PX:2PX:2PX:3Ph>3Ph>3Q8B4Q8F5QHJ6QXJ6QXJ6
QXJ6QXJ6QXJ6QXJ6QhN7QhN8R8R8RHV9RHV9RHZ:RHV9RHV8R8R7QhN7QXJ6QXJ6
QXJ5QHF4Q8B3Ph>3PX:2PX:2PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61
PH61PX:2PX:2Ph>3PhB4QHF5QXJ6QhN7R8R8R8R8RHV9RHV:RXZ:RXZ:RXZ9RHV9
R8R8R8R8R8R8R8R8R8N7QhN7QhN7QhN7QhN7QXJ6QXJ7QhN7QhN7QhN7QhN7QhN7
QhN7QhR8R8R7QhN7R8R8R8R8R8R8R8N7QhN7QhN7QhN7R8R8RHV:Rh^<SHj?T96B
TiBEUIJFUiNGUiNGUiNFUYJFUIFEUIFEUIFDU9BDUIFDU9BDTi>CTY6AT92?Shj>
SHf<Rh^:RHV8R8N7QXJ6QHF5Q8B4Q8B3Ph>3Ph:2PX:2PX:2PX:2PX:2PX:2PX:2
Ph>3PhB4Q8F5QHF6QXJ5QHF5QHB4Q8B4Ph>3Ph>3Ph:2PX:2PX:1PH61PH61PH61
P820P820P820P820P820P820P820P820P820P820P861PH61PH61PH:2PX:2Ph>3
Q8B5QHF6QXJ6QXJ6QXJ6QXJ5QHF4Q8B4Q8B4Q8B4Q8B4Q8B5QHF5QHJ6QXJ6QXJ6
QXJ6QXJ6QXJ6QhN7R8R8RHV9RHV9RHV9RHV8R8R7QhN7QXJ6QXJ6QXJ6QXJ5QHF5
QHF5QHF5QHF4Q8B4Q8B4Ph>3Ph>3Ph>3PhB4Q8B4Q8F5QHF5QHF5QHF6QXJ7QhR8
R8V9RHV9RHR8R8R8R8N7QhN7QhN7QhN8R8R9RHZ:Rh^;S8b<SHf=SXj?Shn?T92@
T8n?SXj=S8^;RXV8R8N6QXJ5QHF5Q8B4Q8B5QHF5QHF5QHB4Q8B3Ph>3PX:2PX:1
PH61PH61PH61PH61PH61PH61PH61PH61PH:2PX:2PX:3Ph>3Ph>3PhB4Q8B5QHF6
QXJ6QXJ6QHF5QHF5QHF5QHF6QXJ7QhN7R8R8R8R8RHV9RHV9RHV:RXZ:RXV9RHV8
R8R7QhJ6QXF5Q8B4Q8>3Ph>3PX:2PX:2PX:2PX:2PX:2PH61PH61PH61PH61PH61
PH61PH61PH61PH61PH61PH61PH61PH61PH61PX:2PX:2PX>3Ph>4Q8B5QHF6QhN8
R8V:RX^<S8f>SXn?T92ATI:BTiBDUIFFUYJFUYJFUYJEUIBDTi>BTI6@Shn>SXj=
SHf=SHf<S8b;RhZ:RHR8QhN7QhJ6QXJ6QXJ6QhN7QhR8R8R8RHV9RHV9RHV9RXZ:
RXZ:Rh^;Rh^;Rh^<S8b=SHj?Si2@TI:CTiBEUIJFUiNHV9RHV9RHUiNGUYJEU9BC
TY:ATI6@T92@T8n?Shj>SXf=SHb<S8b<S8b<S8b<S8^;RXZ9R8R7QhJ6QHF5QHB4
Q8B4Q8B4Q8B4Q8F5QHF6QXJ6QXJ6QHF5Q8B4Q8>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3
Ph>3Ph>4Q8B4QHF5QXJ7QhR9RHZ:Rh^;RhZ:RXV8R8N7QXJ5QHB4Q8B4Ph>3Ph>3
PhB4Q8B4Q8F5QHJ6QXN7QhR8RHV:RXZ:Rh^;Rh^;Rh^;RXZ:RXV9RHR8QhN7QXJ6
QXF5QHF5Q8B4Ph>3Ph:2PX:2PX61PH61PH61PH61PH61PH61PH61PH61PH61PH61
PH61PH61PH61PH61PH61PH61PH61PH:2PX:2PX:2Ph>3Ph>4Q8B4QHF6QXN7R8V:
Rhb=SXn@TI6BTiBDUIJFUiNGV9RHV9RHV9RHV9RHV9RHV9RGUiNFUYJFUYJFUYJF
UYJFUYNGUiNGUiNGUiNFUYJEU9>CTY6@Shj=S8^;RXZ:RHV9RHV8R8R8R8N7QhN6
QXJ6QHF5QHF4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B5QHF5QXJ6QhR8RHZ:Rhb=SHj?
Shn@T92@T92?Shj>SHf<S8^;RXZ:RHV9RHV9RHV:RXZ;Rhb<SHf>SXn?Si2@T92@
T92@T92@T92@T92@T8n?Shj>SXf=SHf=S8b<S8b<Rh^;Rh^;Rh^;Rh^;Rh^;Rh^;
Rh^;RXZ9R8R7QXJ5QHB4Ph>3Ph:2PX:2PX61PH61PH61PH61PH20P820P820P820
P820P820P820P820P820P820P820P820P820P820PH61PH61PH62PX:2PX:2PX:2
PX:1PH61PH61PH61PH61PH61PH61PH61PH61PH62PX:2PX>3PhB4Q8F5QXJ7QhN7
QhN7QhJ6QHF5Q8B4Q8B3Ph>3Ph>4Q8B4Q8F5QHJ6QhN8RHV:RX^;S8b<SHf=SHf=
SHf=SHf=SHf=SHb<S8b<S8b<S8b<S8b<S8b<S8b<Rh^;RXV9R8N7QXF5QHB4Ph>3
Ph>2PX:2PX:2PX:2PX:2PX:2PX:2Ph>3PhB4Q8B5QHF5QHF5QHB4Q8B3Ph>3Ph>3
Ph>3Ph>3PhB4Q8B4Q8B4Q8B4Q8B4Q8>3Ph>3Ph>3PX:2PX:2PX:2PX:2PX:2PX:2
PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX>3Ph>4Q8B5QHF6QXN7QhN8R8R8R8R7QhN7
QXJ6QHF5QHF5QHF5QHF5QHF5Q8B4Q8B4Q8B4Q8F5QHF6QXN7QhR8RHV9RHV:RXZ:
RXZ:RXZ:RXV9RHV9RHV9RHV:RX^;S8b=SHf=SHf=S8b;RXZ9R8R7QhJ6QXJ5QHF5
QHF5QXJ6QXJ7QhR8RHZ:Rhb=SHj?Si2@TI6BTY>CU9FEUIJFUYJGUiNFUYJFUYFE
U9BCTi:BTI6@T92@T96ATI:BTi>DU9FEUIFEU9BDU9BCTi>CTi:BTY6ATI2@T92@
T92@T92@T92@Shn>SXf=S8b;RhZ:RHR8QhN7QXJ6QXF5QHF5Q8B4Q8B4Ph>3Ph>3
PhB4Q8B4Q8F5QHF5QHF5QXJ6QXJ6QXN7QhR8RHV:RXZ:RXZ:RXZ:RXZ:RXZ;Rh^;
S8b=SHj>SXn?Shn?Shn?Shn@T92@Shn?SXj=SHb;RhZ:RHV8R8R8R8R8RHV9RX^;
S8f=SXn@T96BTY:CTi>CTi>BTY:ATI2?Shj=SHb;RXV9R8N7QXJ5QHB4Q8B3Ph>3
Ph>2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2Ph>3Ph>3PhB4Q8F5QHJ6QhN8RHZ;
S8f>Si2@TI:BTi>CU9BDU9BCTi>CTi>CTY:BTY:ATI6ATI2@T8n?SXf=S8b<Rh^;
Rh^;Rh^;Rh^;Rh^;Rh^;Rh^;Rh^;RhZ:RXZ:RHV9R8R8QhN7QXJ6QXJ5QHF6QXJ6
QXN7R8R9RXZ;Rhb<SHf=SXj=SHf=S8b;Rh^:RXZ:RXZ:RXZ:RHV9RHV8R8R8QhN7
QXJ6QHF4Q8B4Q8>3Ph>3Ph>3Ph>3Q8B4Q8B4Ph>3Ph>3PX:2PX:2PX:2PX:2PX:2
PX:2PX>3Ph>3PhB4Q8F5QHJ6QhN8R8V9RX^;S8f=SXn?T96BTi>DUIFFUYNGUiNG
UiNGUYJEUIBCTY6@Shj=S8^:RHV8QhN6QXJ5QHF5QHF5QHF5QHF5QHJ6QhN7R8R9
RHZ:Rh^;Rh^:RXV9R8R7QhJ6QXF5QHF4Q8B4Q8B4Q8B4Q8B4Q8>3Ph>3Ph>2PX:2
PX:2Ph>3Ph>3Q8B4Q8F5QXJ6QhN8R8R8RHV9RHV:RXZ:Rh^;Rh^;Rh^:RXV8R8N7
QXF5QHB4Q8>3Ph>3PX:2PX:2PX:2PX:2PX:2PX>3Ph>3PhB4Q8F5QXJ7QhR9RHZ:
Rh^;Rh^;RXZ:RHV9RHR8R8R7QhN7R8R8RHV9RX^;S8f=SXj?Si2ATI:BTY>CTiBD
U9FEUIFEUIFEUIFEU9BCTi>BTY6@T8n?SXj=S8b;RXV8R8N6QXF5QHB4Q8>3Ph>3
PX:2PX:2PX:2PX:2PH61PH61PH61PH62PX:2PX:2PX:2PX>3Ph>4Q8B4QHF5QHJ6
QXJ7QhN8R8R9RHZ:RX^;Rhb<SHf=SXj>Shn?Shn@T92@T92@T92?Shn?SXj>SHf=
SHf=SHf=SHf=SHb<S8b;Rh^;Rh^:RXZ9RHV9R8R8R8R8R8N7QhJ6QHF4Q8B3Ph>2
PX:2PX61PH61PH61PH61P820P820P820P820P820P820P820P820P820P820P820
P820P820PH61PH61PH62PX:2Ph>3Ph>3Ph>3Ph>2PX:2PH61PH61PH61PH60P820
P820P820P861PH61PH61PH61PH62PX:2PX>3PhB4QHF5QXJ6QXJ6QXJ6QXJ6QXJ6
QXJ6QXJ5QHF5QHF5QHF5QHF6QXJ7QhR8R8V9RXZ:Rh^;S8b<Rh^;RhZ:RXZ9RHV9
RHV9RHV9RHV:RXZ:RXZ:RXZ:RXV9RHV9RHV8R8R8R8R8RHV9RHV9RHV9RHV9RHV9
RHV:RX^;S8f=SXn@TI6BTY:CTi>CTi>BTY:ATI2@Shn>SHf<RhZ:RHR8R8N7QhJ6
QXJ6QXJ7QhN7QhN7QhN7R8R8R8R8QhN7QhJ6QXJ5QHF5QHJ6QXJ6QhN7QhN7QhR8
R8R8R8R8R8V9RHV:RXZ:RXZ:RXZ:RXZ9RHV8R8N7QXJ5QHB4Q8>3Ph>2PX:2PX:2
PX61PH61PH61PH61PH61PH:2PX:2PX:3Ph>3Q8B4Q8B5QHF5QHB4Q8B4Q8B4Q8B4
QHF5QHJ6QXJ7QhN7QhN7QhR8R8R8R8R8R8R7QhJ6QXF5QHF5QHF5QHF5QHF6QXJ7
QhN8R8V9RX^;S8b<S8f=SHb<S8b<S8b<S8b<S8b<S8b<S8b<S8b=SHf>Si2ATI:C
U9FFUYNHV9RHVIVIVIVIVIRHV9RGUiJFUYFEUIFEUIFDU9BDU9BDU9>CTi>CTi:B
TY:BTY:BTY:CTi>CTi>CTi:BTY6ATI2@T8n?Shj>SXj>SXj>SXn?T92@TI6BTY:C
Ti>DU9BDU9>CTi>CTi>CTiBDU9BDUIFEUIJFUiNHV9VIVIVJVYZJVYVIVIVIVIVI
V9RHV9NGUYFEU9>BTY6@Shn>SXf=SHb<S8^;Rh^;Rh^;Rh^;Rh^;Rh^;RhZ:RXZ:
RXZ:RXZ:RXZ:RXZ:RXZ:RXZ:RXZ:RHV9R8R8QhN6QXJ5QHB4Q8>3Ph>2PX:2PX:2
PX61PH61PH61PH61PH61PH61PH61PH61PH61PX:2PX:2PX:3Ph>3Ph>3PhB4Q8B4
Q8F5QHF5QHF5QXJ6QXN7QhR8R8R8R8R8R8R8R8R8R8R8R8R8R8R8R8V9RHZ:RXZ:
RXZ9RHR8QhN6QXF5QHF4Q8B4Q8B4Q8F5QHF6QXJ7QhR9RHZ;Rhb=SHj>Shn?Shn?
Shj>SHf<S8^;RXZ:RHV9RHV9RHV9R8R8R8R7QhN7QXJ5QHF4Q8B4Ph>3Ph>3Ph>3
Ph>3Ph>3Ph>4Q8B4QHF5QXJ6QhN8R8V9RX^<S8f>SXn?T92@T92@T92@T92?Shn?
Shn?SXj>SXj>SXf=SHb<S8b<S8b<S8b<S8b<S8b;Rh^;RhZ:RXV9R8R7QhJ6QXF5
QHB4Q8B4Q8B4Q8B4Q8B5QHF5QHF6QXJ7QhR8RHV:RX^;S8b<S8b<S8^;RXV9R8N7
QXJ5QHF4Q8B4Q8>3Ph>3Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4Q8B4
Q8B4Q8B4Q8B4Q8F5QHJ6QXN7R8R8R8R8R8R8R8N7QhJ6QHF4Q8>3Ph:2PX:2PH61
PH61PH61PH61PH61PH61PH61PH61PH62PX:2PX:2PX:2PX:2PX61PH61PH61PH61
PH61PH61PH62PX:2PX:2PX:2PX:2PX61PH61PH61PH61PH61PH61PX:2PX:2PX:2
PX:2Ph>3Ph>3Q8B4Q8B4Ph>3Ph:2PX:2PX61PH61PH61PH61PH61PH61PH62PX:2
PX:2Ph>3PhB4QHF5QXJ6QhN7R8R8R8R9RHV9RHV9RHV9RHV9RHV:RXZ;Rh^<S8b=
SHf>SXn?T92ATI:CTiBDUIFEUIFEUIFEU9BDTi>CTY:BTY6ATI2@Shn>SXf=S8b<
Rh^;RhZ:RXZ:RXZ:RXZ9RHV9R8R8R8R7QhN6QXF5QHB4Ph>3Ph:2PX:2PX61PH61
PH61PH61PH61PH61P820P820P820P821PH61PH61PH61PH61PH:2PX:2Ph>3Q8B4
QHF6QXJ7QhN7QhJ6QXJ6QHF5QHB4Q8>3Ph>2PX:2PX:2PH61PH61PH61PH:2PX:2
PX:3Ph>3Q8B5QHF6QXJ6QXJ6QHF5Q8B4Ph>3Ph>3PX:2PX>3Ph>3Ph>4Q8B4Q8B4
Q8B4Q8>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3PhB4Q8B5QHF5QHF5QHB4Q8B4Q8>3
Ph>3Ph:2PX:2PX:2PX:2PX:2PX>3Ph>3PhB4Q8F5QHJ6QhR8RHZ;S8f=SXn@T96A
TI:BTi>CU9BDU9FEUIBDU9>BTY6@T8n>SHf=S8b<S8b<S8b<S8b<S8^;RXZ:RHV8
R8R8R8N7QhN7QhN7QhN7QXJ6QXF5QHF4Q8B4Q8F5QXN8RXb?TIBGVIbNWj2PX9nM
ViVFTi2>S8Z9R8R9RX^<SXnATY>DUIFEUIFEUIFEUIFEUIFEUIBCTY2>S8Z8QXF4
Ph>3Q8F7R8Z<SY2ATY:BTY:AT92?Shj>SXj?Shn@T92@T92@T92ATI:CU9JGVIZK
W9fMWIbKVYRFUI>BTI2?Shn@T96BTY>DU9BDU9>CTi:BTY:BTY:CTi>CTi:BTI2?
SHb;RXV9RHV9RHZ;S8b=SXj>SXj>SXj>SHf=SXj>Shn@T92ATI6AT92@T92?Si2@
T92ATI:BTY:BTY:BTI6ATI6ATI6ATI:BTY:BTY:BTY6ATI2@T92@T96ATI:BTY:B
TY:ATI2?Shj>SXf=SHf=SHj>SXj>SXj>SXj>SHf=SHf=SXj>Shn@TI6BTY:BTY:B
TY6ATI2@T92@T92@T92@T96ATI6ATY:BTi>CU9BDUIFEUIFEUIFDU9BCTi>BTY:B
TY:BTY:BTi>CTi>CTi>DU9BDU9BDU9BDU9>CTY6AT92?Shj>SXj?Shn?Si2@Shn?
SXj=SHb;Rh^:RXZ:RXZ:RXZ:Rh^:RXZ:RHV9RHR8R8R8R8R8R8R8R8V9RHZ:Rh^<
SHj?Si2ATI:BTY:BTY:ATI6@T92@T92@T96ATY:CTi>DU9BCTi>CTi>CTi>CTi>C
Ti>CTY:ATI2?Shj=SHb<S8b;Rh^;Rh^;Rh^;RXZ:RHV8R8R7QhN7QhN7QhN7QhN7
QhN7QhN7QhN7QhN8R8R9RHZ;S8b=SXn@TI:CU9BEUIJFUYJFUYJFUYJEUIFDTi>B
TI2@Shj=SHf<S8b<S8b=SHf=SXj>SXj>SXj>SXf=SHf=S8b<Rh^;RXV9R8N7QXJ5
QHF4Q8B5QHF5QXJ6QXN7QhN7R8R8R8R8R8R8R8R7QhN7QhN7QhN7QhN8R8V:Rh^<
SHj?T96BTiFFUiRIVibMWYnPX:2PX:2OWijLViZIV9NFUIFDU9BDU9BDUIFEUYJF
UYJGUiNFUYJFUIBDTi:@Shf<RXR6Q8:0OWajN7MeLg9aL71`LG9dMGQjOGn2Q8J7
R8V8R8J4PX1mNWQeM79aLG5aLW=eMgYlOh:5R8^?TYFIW:2SYZV/[[6c];Ff][Nf
][Je];>b/K2`[jj^[Jf][:b][Jf^[Zj^[Zf][:^YYjFSX9jKV9FCT8f:R8F2P7ej
N7IcLW1_KVi^Kg1bM7IhNWanOh20P7mnO7YhMG=aKfe[JVYZJFYZJf]/KFi_LG9d
MgUlP8B8S96EVIfQY:NYZjf^[Zn_[k2`/;6a/[:b/k>c/k>c/k>b/[:b/[:b/[6`
[ZbYYZ:NVIFASX^;RhjBUifU[;Bj`<C6a/>o^K6XWYB;PWYdKfaZJVY[K6a/JfYW
HemKEeABDE9DFEmVKWImQ8Z>T92=RH=lM6aUGUUFE5AEF5eQIfaaMWYmOh62Q8F7
RHb?TiNKWZ:UYjRXYjJSXIjLVYVIVifQYZbb^;g2a/W;c<_:b<G3`Knn_[jo`L;3
a<G4`l6n^[F_ZZBOViNCTI2?SXj>SHb:QhAoNWE_JF=NFUMEE5EFFEeQIVY_LgMi
NgamO7]iMgEbL6i/JVQWIVETI6=SHfATIFMYJfmbMW^0QX^@UIZMXJ>UYZJVYJ>R
X9jLViZJVY^LWInQY:JY[:ja];Jh^kfo`L?5alS9b/[:b/W8alK4`/2o_Kbk^[Zi
^;Nf]K>a[Z^WXijIUI2<R8B0OGYgMG9_K6QUHUiKFEMEEEIGFEeQIV]`MGUmOh61
P7ikMg9^JFAPG5UGEUIGF5YLGV5TIfY^LGEiOH66RhnDV9bPXjFVYjJUXj2MViRF
U9>CTiBGVIbPY:N[[[:d]kVk_Ko0`/?5a/O9bL[:bLS7aL?0_K^i]kFd];Bd]KJg
]kNg]K>`[:RSWINBS8N1OGQdL6]WHf1LF5ICDU5BE5MLHFM^MGb2QhZ<SH^8Pgad
K6ALE4i9AD=2@dE8C55EFUiRIVU/Kg9eNGf1QHV>TYFIVifMW9^HUI:>RXN5Ph>3
Q8N:SI6FVYjRYZV/[k:d]kZm`<?6bLc>d=7BdM3>c<[7a<;0_[jn_l32aLO9b/_;
b/O4_kZe[ZRRW9JAS8R4P7ahLfmYI5mIEE5>C4a>DEIMIFefOhN>U9NIVIJARh=k
LVUPF55<B4I4ADI8BTe@DUEHFeePI6Q/LGMmQ8^BV9jTZ:Z/ZjZWXinJUI2<RHN7
QhV;Si>GW:6VZZjb]KRk_L32aLO:cLoBe=GFemOFe]CCd]3?clo@dM;De]OHfMWH
emC@blFo^;6ZXi^DSHN0NG5ZHe]DCDI1?CXj>cm5CEMRKGV5T9VPYJNWY9jFSH9g
K61FCDDo>cPf=CHg>C/m@4=6BTiCF5iUK7AlQ8^BV9bOXJ6PWY^GThj:QhB3PX>4
QhZ=T9BGVYbNX::TYZRZ[K6d^;c0a<S:c<k>c/g<b/W8alO7bL_>d]KKgn?VjN_[
j^SUhM_EclO0^;2XX9R?QWedJV1FCD@l=S4^;Bld>T=>FVMePXjIXZR/[ZbYXi^A
QgaaIeaCBT<m=c<`;B/Z:R//;S4e>T18D5URK7J0R92FVYfNWI^GTXf8PWejMgEe
MWQjOX:7RhnCUYVLWZ6SYJR[[[6e^;c0`lK9blc=cLg=c<g=c]3BeMWMhNKZk_7d
mOKelo3/in;LeLo8`KZbZj>KTXUoMF]PETa3?3Hb<C8e>d==FFIcP8bGX:R/[Zj[
YYnFSH9hKF=ID4Q1>SD`;2TW9B@T9BLZ;cDlADiHHfiiPhbDVYjQXJ2MVI>=Qh5l
N7AbLG5bM7IiOH24QhZ=T9>FVIfQYJZ_]KZoa<S<cm;DeMKGemSIf]cNhNCWj^g`
loCem_GclNkZi^7Mem;=al:l]JjWWiJ=PgQ^HeQ>ACdg<c4a=3U0BUAPK7V5T9VQ
YZVZZ:FOUhj4NVmTFDm6?CH_:B@Q7Q`K6Q/M82DZ<CU1BeEPJgEoR92FVYfNWYbI
UI2;QX9nNgUiN7UkOH22QHR;SY2CUYVMX:FZ[kBj`<K<dMGJgN3RhnCUiNGVi^OX
j^c]ko3bl_;bl>k/j>CPfmK@blFo^K:/Y9bDRX1fJemDBClg<2/X:B`a>TAAGfil
RYNRZk6d];6/Y9^?PgIZGE56?3@/9R4M6QPF5QHH6QhS:S4kAE5MJWN4SiZRZJja
/Jn/Yj6JThb6P7ajN7QiO7n2QXZ?TYJJWZ6UZJfb]kg3bLoFfn7Vj^g_lO;blO3_
k^g]k>c/kNg^k^k^k^g[jNKSgmcGdlk8`kff[jNNUHYoLfIJCD4f;2DP7AhR:C<o
CEe]OXfLZ;6h^k^h/ZVNTXEgJUe@AC/b:bDP6aPF51<C5ALK82H_>4A@GVajQiBO
Z:nc]KBa[:FMU8^3O7IbKfm`LWIjOhB9SY>GVijQY:N[[k>i_/C;dMOMh^KYjnc/
jn[YinGThn;RhnCUi^OWj>OVi>7MfMG@b/Fo^;:[XibCRGmdJ5]>@C@Y7aLB3a4E
7RTgB5Y]Oi6Q[[W0`l>o^:nSUXMhJUa?@cP_9b4K5a<@3Pd=3Q0D6B4Z=45?GVem
S9^W/[[0`/:o^[:YX9J<PgafLFm^KW1dN7b1QXZ?U9RLXJFZ/;Fl`/W@e]gRin_^
l?7blO7`knk]kNg^k^o`lO;cl_;`k^cYiN7Mf=?>bL>l]JfUVi25N6]MCd8e:b8L
6ATM92lmCEmaQ9JW]/7:cm3=b;ndYiV:NfaNDDDj<BTR71LC3``;2``>4aTQ;3Q7
EVIgR9NV/[_2aLK3_[J]XiR=PgYcKVYXJ6Y]LGEjOhB8SI:FVinTZ[2f_LC;d]WP
iN[^lO?dm??clO3_k^g]kNg/k>c[j^SVhn3LfMC@blO2_KRb[:JNUXb1MFULCT4e
:b8L61TL92hlBee`PYBU/kk6bl_9`[V^XI>4MVQJCT<j<BXS7QTD40d;2PX<41DM
:3A2DF9cPi>R[[Nn`/:o^K6XWI:7OWE_JVMWJ6]_M7UnPhR=TIBHVijRYZ^a]kk5
c=?JhNK[ko;cm?Cdlo7`knk]k>_[j^[Yj>OUhn3MfMKAcLS3_[Rb[:FMU8YoM6MJ
C3lc:20I5QHI82/hB5Y/Oi:S/Kg6blc:a;baYIN8NF]MDDDk<RXR71HA3@T71PH7
2a4I8blnCUm`PY:Q[kW1aLO5`;ZaYibBR7mhLVm]KFiaMGUmPXJ:SY:EVIfRYjfc
^/;:dMWQingcmoWko?clno[hmoKemOCdlo;al>k[j>CPg=OBcLS2_KNaZZ>KTXQl
L6=FB3/^8a/E4Q8G7RThB5Y]PI>T/[k6b/_8`[V]X9:3M6IHC40f;BDM5a4<20@2
0@4420lH8c50DF=fR9VX]L37blc9a;bcZ9jCRH1hLVi[Jf]]Kg9fNGf1QHV>TiVO
YZjg_lSAf^7Yko?gnO_kn_Whm_Gdlo;bl_7alO3^k>[VhmkJe]7=bLC1_KVd[jVR
VY66NVaND44c9adE4A4D6bDc@eEXNhjO[[W2alS6`;R]X9:4MFMJCD8g;RHN5a0;
1@40000000@<5b<b@eEWNX^LZ[Fna<K5`K^cZYnERh9jM6m/Jf]/KW5dN7b0Q8V>
TiRNY:^c^l?<e=_SjNkcm_Sin_WhmoKem??blO3_kNcZinCQg][Fd/k;alC1_KZf
/JbVWYJ<P7AVF4Xl<2@K5A8C5alZ>4QJK7nAXJnk`lO9a/6i[j>ER7Y/Ge=8?SD/
9AhH4Pd91P@41@P>5R0]?4aNL8:CXk6la<W;bLBm]:ZOU8V0Mg5/JFMWJF]^LWIk
OhB8SI:HWZF/];c5cMKNi^gcn?_nooooo_gknOOelo7_kN[XiN;Og=SEdLk;b<G3
`;jk]k>^Z:2GSH5dIUQ:?2lT71HD5ATR;C];GFn1Tj:`^/75aL>m]:ZNTHAfJEeA
ASdd;2@M5Q0;1`<100442Q8M:SU:G6j0TZ6_^L76alG0^K2VVhn5Ng=/IfASHfEX
JfmcN7b1QX^AUYfTZk>laLgFg^K/l_KinoclnoWgm?;_kN_YinGShMoMf]SEdm3=
blS6`l6n^kRd[jVRVY25N6]MCd8e:R4K61PL8bdkBU]]Oi2P[[W1aLK4_[J/XIB7
NFaPE4Y0>30Y8adG4Ph;2@P9318I930oCf1bQ9JU/kk5b/_9a;bcZ9fBQgeeKf]Y
J6U[Kg=gNh24R8bAUIZPYZfd_LG>en3XkoGjo_ooooklnOKcl>gZj>KThn;PgmkL
f]SGeM?Aclg;bLO4`;bf/:ROU8QkKEm@@SDZ81XG5aXQ;3U8FF]mSYj/]ko4aLBo
^:nTV8aoLVIJD4Hm=2dV7aTC3`/81`P;41PS;ci?HG>6UjNe`<S<c/_6_kJ[WiB9
OgMaK6YYJF]^LWIkOhB8S96FW::X/;S1b]?Li>cbn?_nookln_Kckn_Wi>7Og]gL
g=cLg=cLfm[If=OEdm7?c<W5`K^d[:>ISH1bI5E6>2`Q61<A4QLO:SQ8FF]mSYj[
]Kc0`;jh/:JJSGmbI5Q<@CL^9AhG4@/70`0000873QLT<T9DIWV;W:bh`/S;b/O0
]jbQUHUnMFeWHf5QHVEXKG9gO8:8SYBJXJVa^L;;e=gUk?;fnO_jnOKck^[Uh=cI
emGDe=CEe]OIf]_LgMgMgMgMg=_Jf=KBc/S1^K2UVHamKem@@SDY7aPD51HL9C4o
CUm`PI6OZkBk_[jk]ZjTVHf0LVEICD4g;RDM5Q0;1`D30`D93aLR;Sa<GFioSij[
][g2`l:n]jnUVXn5Ng=/J6ETI6MZKgAjP8J=TiVPYjje_<C<dm_Qinc`l_?blNkZ
i^7Lf=CAclk>c]3BeMSKg^3Si>GVinKViNCRh=gJe]3:`[R^XYB6MfQHBC/^8aXD
4A4D6bDa?dmPLX:BX:be_;o0_KR`Yib?PWEXFdm4>S0X81XD40d:2PX=4ALO:CA2
D61`P8nMZK>k`<70_;J^Y9V>PgU`JFAPGf1SIfecNh::TYZQZ:ne_<77c=7EfMcN
h>3PgmgJem?@cL[8a/G6alS;c]7Ef=_NhNCVinSYjNWXinGRg][DcLJm/ZNKSX5c
IUQ;?c@[8ahJ6AXN92dg@TmMJWR5T9ZRYjZ[ZJBNUXb2MVYODdPo=RhW8QhJ61LF
5aPK7R<Y<CY4Ce]XM86=V:6Y[[6b/:bVWiN?QgmiM75`L7=gO8>:TIROYZba]KVk
_/32a<K8b/c>cm3Ad];BdM3?c/g=cLg>cm7Dem[MhNCWjN_]kNg/jnWVhmoJeLo8
`KVaZ9jDRWmdJEmEBd8j<bdY9RHW:Rlf?TQBGFUeOhVBVIfPXInLUY28OgE/HUUA
BT<m>3@a;R`[:RTY:R/^<SLnATmJIG5mRI>MYJb`/[:`[JRRW9JAS8R6QHF7RXjB
Ui^PY:NZ[Jn`/[>d][Rj_L34al[=d=?DeMKFe]GEe=CEeMOIfmkQi>OZkNk`l?3^
k>WVh]gHd/c6_kVbZZ>KTh^3NW9YHEQ@Ad0i<bl/:RX/<3HmADiHHfehPHV@U9NH
UiB@RX=kLf]SFeA=Ad8m>CDa;BXW9B<S8bDX;CDnB5ARKgf;V:>]];Zl_;Zf/JZS
W9F?RhN5QHJ8RhjBUYVMWj:TYJNXZZb^/KBg^ko3al[=cm7Bd];BdM7@dM7Be=KI
g=oRi>OYj^[Zj>KTh=cHe<o:a/6l][6[YIjGT8R0MfeTFU16?CD]:2@Q8B<X;SI0
BeQTLGb7TIRNXJ>RWi^ESXInMViVGUI?B48k=BlY8ahJ5aDF6AhU;ca:FVamSin_
^lK=dM;@blBl/ZVOUXj8Q860PH>5RHfAUIRKWZ2SYJNZ[K2d^;c1aL[>dMCEemOG
e]GDdm;Bd]?Eem[Mh>?Vj>[Zjn[Xi^?Pg=OCc/W4_kVd[ZRQVY>;Pg]bJ5mEBd8i
<BXT81hO8BD/=3i:EV9_NhJ?UifQXZ6OVYB=QGedJf9JDDU1>S8/9AlJ5Q@B4aDJ
8B/gA5=SM8BDXZni`<G6aL6k]:^RVI29PgikNW]lOh:6RXjBUIRKWZ2SYJR/[k>h
_<35bLc?dM;Cdm?BdM3@cm3Ad]GHfmkRiNS[kNk^k^cZin?NfMC>b<:l]JjWX9VB
RX9jLVYQF4m6?SD^9b8O7QlR9bhh@dmLJWN4T9ZRYjZ[ZJFOUhj4NFmTFU58@3Tb
;2HQ7ATF5ADF6AhV;c]8EfMhR9RV/kg4b<[8a;feZj6HSXJ0NgQgMgUmPHJ;T9BI
WJ2TYZV/[k:e^Kg1aLW=d=?Ee]KFeMCCd]7Ad]?Dem[MhNCWj^c^k^k]jnSTh=_F
d<_5_kVc[:JOV96:PWUaJ5mEC4<k<bdX9B@U:Bhf@4]GI75nRYFNYJZ][JZVX9V@
QgecJV5IDDY3?CLa;2LS81dL71hQ:30kAeEUMHFEXk2j`/O8al>m]JbRVI27PGai
N7QjOH65RHjBUYZNXJBWZZfa]KZn`lS=dMGGfM[Kf]WGeM?Ad=3@dM?Ef=_NhNCW
j>[ZjNSUh]oKe]7<al:m]k6[YIjGT8QoMVeSFDi4>c8[9B4O82<Y<3Y5DV1^NhRC
WJBY[:bZYYnHShIlLfUPF519@c`f<2/U81`H5QHG6b4Y=45?H721TZ6^^L35a/C0
^:nUVY26OGIaKVe^LGEjP8J;TIJKWj>WZZfa]KVn`lO<dMGHfmgMgMcKf=KCdLo>
c/k?dMCGf]gPhnGVinOWiN?Qg][Gd/k8`kff[jNNUH^1MVYODdPm<bXS7QXI6ahT
;3M2Cee[N8F@VZ6WZZ^YYJ2ITHQnMF]RFE18@CXc;BLQ71PE51<E6B0X<d1?Gg21
TJ2^^L;7b/W5_kN]XYN<PGUbK6UXJF]_M7Z0QhjEVj6W[K:h_L;7bloCemWKg=gL
fmWGe=7>c<[9b<S9blg?dmKIg=oRi>GWinOWi^CRgm_Fd<W2^K2UVXn3MVYNDTLl
<RXS7Q`K7B0W;cU4DEi/NXNCWJF/[k6`[JRQV8j4NVmUFe99@CXd;RTT81dK6AXK
7b@[=D1=G6]kRYVV/[_1aLG3_[J^Y9V?QGaeKf]ZJVa`MGZ1QhjEW::X[[>i_/?7
c=3Dem[LgMgMfmWGe=7>blW7a/K7b<[=dMCHg=oRiNOYj^[ZjNOThMgGdL[2^JnU
VHf1M6MJCD8g;BDN6QPI728Z=41=FfUgQI6LY:^^[jjZY9fDRWmdJUmFCDDm=c4/
9b<O71XI6AXM8BP`>dMDHW60SY^V/;Jj^kVd[JFLTXQnMVmZJ6MXJfmdNX68SYFK
X:FZ[[>g^ko2a/[>dM?Ee]OFeMCBclg:b<O6aLK8b/g@e=SLh>CWj^c^kno_kN_X
i=oId/W0]ZZNTHAfJ5Y=@3@Z8AXF51DI82Td@4mMKG^9UZ2Y[k:c/JfVWYF;P7EZ
GeI=ACdf<B/W8alM6aXJ71lU;3E0C5UXMhJDX:^d^[jn_;NaZ9jDRX1gL6]WIFEW
JVmdNX26SI>IWjBZ[kBj_/?7blkAdmCDe=?Bd<k<b/S7a/K6alS:cLoBeMSKg^7S
i^SYjn_/k>_Yi^?Melo6_;2TUXQjK5iAA3T_9R0L6a`P9RhhA55OKG^8U9nW[K6c
/ZnYXYV?QGY_I5Y@B40i<bhY9B8P7ahO8B@Z<CU4D5e[NHREXZff_L72`;be[J>H
SH=iLFYVHf9SIFU_MG^3RY6HWZBZ[kBh_<33a/S:c<g=cLg=c<c;b/[:b/[;c<g>
cm7CeMKHf]cNgn7SiNKWinKUh]oIdl_2]jbOTXAfJ5]>@SL]9AlK6Q/N92`f@TmL
JgV6TYfU[:na/:bWWiJ<PGI[H5I=A3df<2/W924O7AdN82<Y<3U3D5e[NXVGY:nh
_l;3`Kbe[::GS85gKfQSHF1QI6U^MGb4S9BKXZV_]KZo`lO:c<k?d=3@clo>cLc;
bl_;c<g>cm7CeMKHf]_Mg^3QhnCVinSYjNSVhmoJdl_2^:bPThIiJemBAc`c:bDR
820S:30iA51MJWR5TIbU[;2b/ZnYXYZ@QGY_I5YABD4k=C0/:BHT8R4Q8bHZ<3Q2
CU]YN8NEXjni`<G7a/>m]JbRV8j4O7I`KFa/KG1dNGj4RY6HWZF//k[0a/cAeMWL
gMkNgMcJemGCd<o>cLk>d=7De]SJg=kPhN?Ti^OXj^_[k>cZj>GPf]?:_k>WVH]l
KV1CAS/a:B<N71`O92Xc?DUFHg5nRiJPZ:fa/K2/YYjDRWicIeaAAclg<2XV8QlM
71`M7b8W;SI0C5UWMH>BWjZd_<73`[ni/ZVOUH^1NG9]JFMWJ6]_M7V0QXfDVZ6X
[kFk`LO<d=CGfM[Kf]WGeM?Ac/c;b/[:b/_=cm7CeMOHf]cNh>7Si>GVi^GThMgH
d/[0]ZZMSh5bI5E8>c0V7QPE51DI82Td@4iLJgZ8UJ2Y/;Be];2ZXYV>PgM[H5E;
@c/d;RTT8AhL6a/L7R<Y<3Y6Df5`OhjLZKBm`lK6`kjf[J>HSH=iLVaWIFAVJ6aa
Mgf4RY6HWjJ]/k[0a/_@e=OJfm_KfMSEd]3=blW8alS8b/c>d=?Eem[Lg^3Ri>KW
jN_/kNg/j^ORfm?9_[6SUHEfIUM9>blU7ALD4aDJ8BXf@e5PKgj=VJF^];Vj^KJ`
Z9nDRGe`IEU?AC`d;2HQ7ATG5QHH6b0W<3]7EFAcPi:Q[KS0a/S7a;jf[::FS85h
LF]WIVIXJfmeNh68SiFLXZR^];Zoa<S=d=CFf=WIf=OFe=;Aclk=c<c=c/oAd]CF
f=WKg=kOhN;Si>GVi^GSh=cGdLRo]:RKSGm`HU=6>BhT7ALE5ALM92hjB5IVMH>A
WJN_];Jf/jjWWY>8O71UFDm5?3@/9R0L61DC4Q<E61hV<3]9EfMgQiJT/;[1aLK4
_kR_YIZ?QGadKFUVIVMZKG9hOXB:T9JLXZN]/[Rm`/O<d=CFf=WIfMSFe=;@c/g<
c<c=c]3Be=KHf]_Mg^3QhnCUi^OWinGSh=_EcLBi[J2BQ7EVEdPk;bDM5a@D5adU
<3a:FVUiR9JR[;>h^[Zg/JZQUX]oLfMLDDLn=BdV81/F4a0?418F72@^>TQGIgN7
UZB`^L33a<6l]J^QUXb1N75[IfIVIf]_M7Z0QXbBUifRZ:fc^Kk3bLkBeMSJfmcK
f]WGeMCBdM3@dM;Ce=KHfM_Lg]oPhN7RhnCUi^KViN?Pg=K?a[b`XiF7N6UJC3lc
:1lI5A@E6AlW<Si<FVQgQ96KY:^_/K2]Z:6IShEjKfAICdDm=2dW8A`H5A@C51LL
8b/f@U1OKgj>W:Vc_<74`l2j/ZVNU8V0Mg5/JFMXJVicN7j3RHnEVYnTZ:fb]k_0
aLW=dMCFf=WJf]WIf=OFeMGEe]OGfM[Kg=gNgmoPhN;Si>GVinOViN?Of]C<`kR/
Wi63M6IGBCda9alJ5aHI7RD^>TMEHg:0SIRRZZnb/[2[YIfCRGibIeaAAche;RHP
6QHB3`h>41@J8bdiAeMWN8RHY[>ma<S8a/6i/:JKT8ElMFm/JVY/L7AjOhJ<TYNM
XZN//KNl`LK;d=GIgMoQh^?Rh^3Og]gLfm_Kg=gNgn3Qh^;Shn?Ti>CUiNKWinOV
i>7Mem37_K6SUHIgIeQ:?C4W7aTG5aTO9c0lBEMULh6=VJ:Y[[2a[jZTWIB:P7EZ
H5I<@cXb:bDO6QHC4A4B5Q/R;3M5Df=cPY:P[;Jm`L;0_;F]XiR>Q7]dKf]YJVa_
M7UoQH^AUY^PY:V]/KJj_l?7c<oBeMOHfMWHf=OEe=CCdm?DeMKGfM[Kg=gMg]oO
h>7Qh^?Shn;PgMWCc<Bj[Z:DQWMYFT`o<RPP6AHE5a/R;3M4DV5_OX^GXJV_/[>a
[JJOUH^0M6UNDdTo=RhW81XE4@h<2``@5A`V<Cm>GVioSifZ]Kc1`l6m]ZjTVHj4
Ng=/J6EUIVQ/L7EkPHJ<TYRNY:Z`][c2b<gAeMSJfmcKf]SGeM?BdM7Bd]CFemWK
g=gNg]kNg]gMgMkNgn3Ph=oMfMG>a[b`XiF5MVIFAcT]8aXE4Q8E6R8]>DIEI7:1
SYZT[;6d];>_ZJ6HSX=hKF9GC4<i<BTR71LC40l?4ADK8bdiAeIVMhNGYK6k`/O8
a/6j/:JKShAjLV]VI6=TIf]aMgf4RY6GWJ>Y[[>h_L;7bloBeMOIf][If=OFe=?B
d];BdmCEe]OHfMWJf][KfmcMg]oPhN;RhMoLem79_kBWVX]lK5e>@C@Y81TE51HJ
82Xe@DmNK7^8UInX[[:c/ZnZXYZ@QGY_HeU?AC`d;2DO6QDB40l@4QLN9c=0Cem`
PI:Q[k[3b<[9aKjeZYnCR7edKFQUIFIYKG=iP8J=TiRMXZN[[k>h_<75bLgAe=OI
f][JfMSGeMCCdm;CdmCEe]SIf]_LgMkOgn3QhN7QhN3NfmOAb/:h[:2BPgATEDHh
;24I4a0@4aTR;3U7EVEdPi2KY:^_/K2^ZJ:JTHIlLFMLDdU0>30Y8Q`F4Pl<30dA
5QhX=D=CI7F6UZFb_<?7alFo]jfRUh^0MVmYIFATIf]`MWb3RHnEVj2TZJfa][Zo
`lS<d=?Ff=[Jfm[If=OFeMGEeMGFf=WJg=gNgmoPh>7Qh^?Si>CThn7Nf]C=a;V^
XI>4MFIGBC/`9QhI5aLK8BTc@4eKJWR5TYbUZjn`/:bWX9R>Q7U^HeU?ASdd;BHO
6A@@3@/;30lE72Hb?diNKgn?WZZe_<72`Kff[ZBJT8ImMW1/JVU[KG5fNh25Ri2E
VYnSZ:jc^;k3bLkBe][Lg]kOg]gLfm[IfMWJfmcNh>;Si>GVi^KVi^KVi^GUiNCS
h=gIe<g4^ZnRUHIgJ5U;?C4W7aXH61`R:SE2D5i]NhVEWjR]/;6`[:JNUH^1MV]P
ETa3>c</9AlI510=2`/=41HN:3A2DV=dQIFS[kW0a<C1_;B[XIJ<PWUcKV]ZJfib
Mgb2R8jCV9bQYJV]/[Nl`LK;d=GIg=kPhN7PgmkLfm_Jf]_Lg]oQhnCVinOXj>OW
inKVi^GThn7OfmK@b;ndZ9Z<OFiNCd4d:B0J5QHH7RHa?D]JJGR6TYfV[K6b/ZnZ
Xi^BR7icJEmEC4<k<b/U7QTD40d<30lC6R@_?4]KK7f=W:Vd_<;4`knj/ZVOU8^2
NWE`KVi_LGEiOX>7S96FVYjRYj^`]KZoa<W>d]KHf]cLg=_Jf]WHf=SIf]cNgn7R
i>CUiNGUi>CShn;QhN3Ng=WDclS0]jbPThEfIeQ:?C4V7QTF5aXP:CA1Cei]NhVE
WjN]/;2^ZZBMU8^0MVaRFE18@3Pa:bDO6QHB410A4aTP:SE3DV9bPi:Q[KNn`/?1
_KN^YI^AR81iM75`LG=fNWn4RHjCUi^OXjJZ[K6e^[o3b<c@e=KHf][Jf][IfMSH
f=WJfmgNgn3Qh^;RhN7PgmkMg=_Jf=KCcl[3_;>XW8n1LV=CA3HY7QD?30dA628^
?DeNKWn=VZF]/[Bc[jZRVHj3N6eRF4m7?cPa:bDP6QHB3P`<3A0E7BLc@U9RM8FE
Y;2j`LG5`kjf[J>IShInN7=aL79dN7f2R8jCV9fQYJV]/KFj_lC9c];Gf]kPhN;R
h^7PgmkNg]kOh>;SiNKWj>SXj>OVi^GThn;RhMoNfmOBc<Bj[j6CQ7=RDD4b91T@
2`T;4ATU<d=EIWR8UjB^]KRi]k:[XYR=PWI[H5M>AChg<2XT7aTE4@h<30dA5alZ
=dEEIWN7UjFa^/74aL:n]jnVW9>;Q7ijN7MgNGaoPhN;Si>FVYjRYj^a][c2b<kC
f=cOhN;Sh^7PgmgLg=_Lg=gOh>7Si>CTi>?RhN3Og]gLg=[IemCAc<Fm]:RKSGe/
FdXj:adB2PH520hH9CE6F6YlSIbX/KNj^[J`Z9jCQgY^HeQ>ASdf<2TT7QTE4@h<
2``>4aXT<3e=GFioSifZ];_0`Knk]:bSVY27P7UeLW1`LWAhO824R8bAUIVNXZR]
/kVoaL_Ae][Mgn3Ph=kMfm[HemOGf=[KgMoQh^?Ti>CSh^;QhN3Ph>3Og]gJe]38
_kBWV8QgIE=1<B8F30H41P/E8C52EFUlSin]^<34aL:l]:VMT89eJ5]@AC`d;2HP
6QHA3P/:2@X=4QTS;Sa;FfalSI^X/[Zo`;nj]:^QUhf4NgA_K6]/KW5fNWn5RHjB
UYZNXZJZ[kFj`<K;dMGIg=kNg]kLfmWGe]GDeMGGf=[LgMoPhN7QhN7Qh>3Ph=oN
gM_He<k7_[>VV8UhIeI4=2@G3@D10@D=62HgBEeaQ9JV/kg3a/K2^k6VVH]mKf5D
BChe;2DN6A@@30X820T;41HO:CI4E6AeQYFS[kRn`L6o^K:YX9J<Pg]eL6e/KFma
MGUnPXN;T9BIWJ:X[[Bj`<K<dMKJg=kNgMcJf=KDd]7AdM;De]WKg^3Rhn?Thn?S
h^;Rh^;Rh^7PgMWDc<>hZib;NVQE@c8S5P`60`@:4b0_@5=WNXfN[;O0a<G3_[J/
XIB6NF]ODdPn=B`U7aTD40`:2@T;3aDM9c=1D61aPI6OZkFl`<6o^[>ZXIN=Pg]e
L6i]KW5dNGj3RHjBUiZNXJFX[;2e^[o4bLkBeMSIf][JfMOFe=?Bd]?DeMOIfmgN
h>7Qh^;Shn?Ti>GUiNCRgm_Fc/Fj[Ij>OF]HASDU5``400032QDT=DMKL8>FY[Bo
a/W9a/2g[9nAPgEWFTi3>C0X81XE40d:2@T:3A8J8bllBe]/OHfLZKBl`/?2_[N_
YIZ?QGadKf]ZJfeaMW^1QhbBUY^OXZJZ[K6f^l35bm3EfMcNh>3PgmgKfMOEe=?C
dmCFemWKg=gNgn3PhN7Qh^;Shn;Qh=gHd/_1]JNHQgARCS`Z6Pd300000@XH:3Y?
I7R<WZjj`lS:b<:j/:>FQgU[GE15>S4X8AXD3`/81PD620dC72Ld@eAUMXJFY;2i
_l;2_kVaYifBR7ifL6aZJV]^LWMmPXR=TIJJWZ:VZZnd^Ko4b/oDf=cNgmoNgM_H
e]CBdM3@dM;De]SJg=kOh>7RhnCTiNKWinOWiN;Nf=36^ZbLRgUVDd0^7Q460000
0P`H:3Y>HgR<Wjnla/c>cLW2^:bOTH9dIEQ;@3H/91`F40`91PH72@hE7RTfAEEV
MhNFY;2i_l;2_kZbZInDRH1gLFaYJ6U/L7AjP8F;TIJKX:FY[[>h_L;7c=3Df=[L
gMgLfmWGe]CCdm?DeMKHf]cNh>7RhnCTiNKWj>[[kNk^kN_XhmcCb;Z[VhUfHe0n
;AhB2@@21@`F93A7Ffn3UjRg`lcAd]3;`kR[WHmoL69DAc`a9alH4Pd91PD51`/@
628^>dYKJgb<VjRc^l32`Kfg[jFKTHMnMW1/JVY/Kg=hOH:8SI:GW:2UZJjb]kg2
alcAeMWKgMkNgM_Jf=KEe=?Ce=GFf=[Lg^3QhnCUi^OXjN[[k>g]k>_Xi=kGcL:d
YIF3LEm<>b/M4PX61PT@6bTiC5mcQYRX]/78c<c9`k^`XiF6MfUKCT8g;B@L5Q0;
20D41@L;4ATS;ce=GFinSYbX/[Vm_K^f[ZFJShAjLFYVHf9TJ6ecNH68SYFKX:BY
[;2c]k^o`lO;cm;EemWIfMWHemGDd];AdM7BdmGFf=WKg=gNg]oPhN;Si>GVi^GS
gm[Dbl6dYiN6MF=A@2lQ50/50P<841/Y>TaOLXBEY;6j`LC4`;ZbZ9b?PGAWFTi3
>2lW7aTC3P/820P;3aDN:3E3Df=cPi:PZkFk_knm^;6XWYB;PGYcKVa[K6ibMWb1
QhfBUibQYZ^`]KZoa<W>d]KIfmgMgMcJfMOEdm;AdM7Be=KHf]cMgn3Qh^?Si>GV
i^OXj>SWiN7LeLc2]JNHQgITDd8b8aL>20H72a<N;3a=H7:4U:>_^Ko2`[ni/JNK
SX5cIUU=@CL]91dF40`81PH72@hD72Lc@DmOKgn>VjNa]k^l^[F^YI^@QWacK6MT
HfAVJg1gOXF<TiZPYJZ^/kJj_/74al[<c/o@dM3@clk=c<c<c<c=c]3Be=KGfM_M
g]oQh^CUinSYj^[ZjNKRg=G<`KBVUXIeHe92<bDJ4@/82@`D7RXiBE]/OHjLZK>j
_[nm^;6XWI64MfYMDDDk<BTQ6aDA3P/;2`dA5QhW<Si<FfYiQiFQZk:g^KRe/:RP
UXf3NgA_JfUZK6mdNX27SIBJX:FZ[k>h_;o3al[=d=;DeMGEeMCCd]7@clo?cm3A
dmGGfM_Mgn3RhnGVj>WZjnc/k>[Xi=oHd<Jj[Ij?OfmNCSla9A/D3`d?51/V<d5A
HG:2TInZ/kRk^kRc[::GRgmbIUY?A3/c;2HP71TF51@D5QXO9Bhh@e1NK7^9UZ6[
/[Ni^;F_Z9nERh9jLVeZJ6U[KgEkPHR?UYbQYZ^_/kJi_;o2aLO:blg>clo?clk=
cLc<c<c=c]3AdmGGfM_Lg]oPh^?TiNKVinOVi>;NfM;:`;BWVHYkJe];?C0U6aDA
4A<I8B`iB5QXN8NEXJZb][Nf/jfUVi25NFeQET]2>C4Z91lJ5a@C4a@F6QlW;cY6
Df1_OHZFXJZ`];Je/JbUWIF=QGihM75`LG=gNh26Ri6FW:2UZJf`];Nk_/74alW;
c<k>c/k>cLg<c<_<c<g?d=;EemWKgMkPhN;Si>CUiNKUiN?QgMSBb/6fZYf>Og1Q
DD<f:R4J5A<E6B0Y=D=AHG20SYZU[K>f][B`ZJ6GSH5fJf1FC4<l=BlZ9R8P7QdN
7b4U:c8jA51LJGJ4T9bV[[Bh^KNd[jRPV928PGahMWIgNGf1QHZ?U9VMXJFX[:nb
][Vm`<C8blk@d]?De=CDdm?Bd];BdmCFemWKgMoQh^CUi^KWinOWinKUhn3Lem38
_[BWVXamKUm@@cH[8Q/H5aTN9S0mBeYYNHREXJ^b][Rg/jjVWI:7O71UFU17?SL`
:bHQ7Q/I61TJ7B4X;cU4DEi/NXREX:Za][Rg]:jWWYF<Pg]eLFi]Kg9fO8>9T9NM
XZN[[k:d][Rk_Ko2a<O9c<k@dM;Cdm?Cdm?CdmCDeMOHfM_Lg]oPhN7Rh^?Shn;R
h=oLfMC?b<2fZj2CQGMXFT`o<bPP6QHE5a`S;CU6E6=aOhbGX:JZ[:^XXibCRX1f
Jf5HCdM0>C@^:RDR7a`K6QXL7b@[=3i:EfAbP8fIXj^a];Bc[jVRVY::PgeiMGAd
MWUlP8F:SY>GVYjQY:R[[k:f^ko3al_>dM?EeMKEeMCCdm;BdmCEemWKgMoQh^?T
i>CThn?RhN3OgM_Gdlk8`;R^XYJ9NfeNDD@h;BDO71/M8RXc?daJJ7J3SiZRZ:b]
[:VTWIB;PGI/HUU@BD4k=C0/:2@R7ahN7b4T:S4jA51MJgV7U9nY/KJi^KNb[:FM
U8b5Og]hMgMiO825RXnDVIfQYJV/[k:e^Kc0`lO:cM3BdmCEeMCCdm;AdM7BdmGG
fM_Mh>7SiNKWinSXj>OWi^GSh=cHd/_3^JnSUhYmL6=FBT0g;bXV9BHY;cHoBUEQ
KWZ6T9VQYZVZZJJQVY:9P7E[HEQ?Ad0j=C0/:BHT8b8R8bHY;cDnB5=OK7V6TYfW
[[>e]K:^Z:6ITHV2OGQfMGEgNWj2Qh^?TiNKWZ6TYjZ^/[Jk`<G9cM7De]OHemOF
e=?Bd]7BdmGGfMcNh>;TiNKViNGThn7Og]cIe];>bL:k/ZRMTXEhJeiBAS/b:bDR
8B<V;3@mB5=OJgN2Ri>JWZ2QWibHTHZ2NW5XGeM@B48l=S4/:2@Q7ahM7R4U:c8l
Ae=PKWb9UJ2Y[k>d/k2ZY9bDS8AnN7EcLWAfNGj2QhbAUYZMXJBXZjnb][Zn`/K9
c<oAd]?Cdm;AdM3@cm3Ad]CFf=[Lg^3Qh^?Shn;RhN3NgM[HeM3;aKjf[J>HS81c
IeY?A3Xb:bHT92H[<CU3CUYVLWj9TYZOXjFTXYjHTHV1N6mVGUI?B48m>3<_:bPU
8b8R92L]=3e8E69`OXfJY[2h_/31_[Zc[:BKThb5PGelO7eoPXJ:SY:FVYjQYJR/
/;Bh_L76b/g@dmCEeMCCd]3?c/g=cLk@d]CGfMcNh>7Rhn?Rh^7PgmkMfm[Ge=3;
aKjf[J:GS81dJ5eBBD0h<Rh[:R/]<CLnAe1JI6miPX^CVIfOX9jKUi29PGQ_IEeD
C4Dn>38]:BHS81lO828V;3@nBEESLGn=VZJ`^;fo_kfh/ZZRVI69PgejN7MhNWf0
Q8R<TIFIWJ6UZJfb][^oa<O;cLoAdM7@clg<b/W8b<W:blg@d]CFf=[Kfm_Kfm[J
fMSGe]GDd/o;al6j/ZZPUXb1MV]QEdi6?SPc<2h^<3<h?TI>F69/Mh69TIRLWj2O
WIRCS8AkLfYQFE5:@cdg<BdY9B<Q8B8U:S0h@dmLJWV8UZ>^^;o3aL?0^[>ZX9N=
QGihM75`LG=fNGj3R8jCV9jSZ:fb]kc1aLW=cm7Ce=CCd]7@c/k=cLg>d=7Ce]SJ
g=kPhN7Rh^;Rh^7PgmkLfMKBcLO0^:nVW9:8OWAZH5M?Ad4k=S<a<C8e>T17D5US
KWR2Ri:HWInOWIZESXInMFaSFe=;A3hi<bl[:2DS8R8T9b/b>TA@GF]jR9JS[[Nm
`L;0_;F]Y9ZAR81iM75_Kg1cMgb1QX^@UIZOXjR//;Bi_L34al[<cLk?c/k=c<_:
bLS9bL[<c]3Be=KHf]_LgMgMgMgLfm[IemCAc/W4_[R`Z9nFSHAjL6MME4a4?CPd
<C0b=3ToAe1KIW5lQXnGWJ:TY::NV969P7M]I5]CBd<m=S4/9b<P7QdM7R8W;SQ3
D5i]O8^IY[6j_l;2`;^dZj:HSXEmMW5^KFe^LGAiOH:7S96FVj2UZZnd^Kk3al_>
dM?De=?BdLo>c<_:b/[;c<k@d]CFf=WJfm_Lg=_Kf]WHemGCd<g8`kff[ZFLTXQn
LfUOED]3>cD`;2XZ;2le?4A>F6A_NXF>UYbPXZ:PW9N@R7mfK6=JDTY3?CLb;RXX
9B@T9BP/<S]5D5e/NXVHYK6k`/O9b<Fo]jjTVY27OgUeLW5bM7QlPHN<TYNLXJJZ
[k>g^ko3al[=d=;Ce=CCd]7@c/g<c<_;c<g>d=;De]OIf]_Lg=cMgMcLfm[He]??
b/Fo^;2WWYB:P7I/HEQ>ACdf<B`Z:B/^<cY2C5MSKg^6T9VOY:JWYJ6KTh^1N6iT
Fe=;@cdg<RdY9R<Q8B4S9bdd?TUFI7>2TIj[]Kg2aLC1_;B/XYR?QWihM75`LG9e
NGf1QXZ?TiNKWjBX[K:g_<76b/kAdmGEeMCCdLo=blW8b<S8bL[<cLo@d]?De=GE
eMGEe=?BdLo<bLG0^[B/Y9^AQgebIeaBB3hf;bTU92@V:S0h@TaHIG5mR9:JX:BU
YJ:MUhn6OG=YH5M>Acli<bhZ9R<Q7alQ92T_>49>G6YiR9JS[[Nn`L;1_KJ^YI^A
R7mhLfm]KFi`M7QmPXN=TYJKX:FY[[>h_L;7bloCeMOHf=OFeM;@c/c;b/W9b/_<
c]3BdmGFemSIfM[Jf][Jf]WGeM7=b<6j/JRMTXMkKfAHCD<i<BXU8B0P8RL]=3i8
E5m[Mh:;TiVMWinLV9:;PgY`IUeDBd<l=S0[9b<Q7ahO82@X;cM1CEYXMXBBWZVb
^Kfo_KZd[JBKTXV1NWAaKfi_LWEjOhB9SiBIWZ>X[K6f^ko4b<c?d]CFe]KEdm7?
c<[8alG5aLK7bL_=cm;DeMOHfM[Jf][JfMSFe=7>b/Bn]jnWWI>8OG9WG556?3</
9R8P828W;CDoBeMTLGf9Ti^QYJJVXijHT8MnM6]QFE59@S`f<BdY9B<Q8B4T:2de
?dYGIGB3TIjZ];c0`l:o^[>ZXIR@R85lN7IfMgUlOhB8S96EVYjRYjba][_0aL[>
d]GHfM[If=KCd<g:b<K5a<C5alS;cLoAdmGGf=WIf][Jf][JfMOEd/k:a;fdZj:G
S81eJEeBB3he;RPT8R8T:2hf?dYFHVmkQY6IX:FXZ:JRW9F=PgU_IEaCBd<m=c4]
:BHT8b8S9RX_=d1;EfAbP8jKYk2h_L30_KVcZj>JTXZ3OWYgMWMhNgj2Qh^@UIVN
XjR]/[Nl`LK;cm?Ff=WJfMSFdm3=b/O5a<?3a<G7b/g?d]GHf]cNgn3PhN7PgmkL
fMGAblFm]J^QUhb0M6UMDTPn=RhY9B<S9BX`>49=FFEbOXVCW::VZ:RVXYbES8=i
KfIME4a5?SPc;RXV8b4P8B8V:c8kAE5OKG^9Uj>]]K^n_[bh/ZZRVI69PWeiMgIf
N7]nPXN;T9FIWZ:W[;6f^l35bLkBeMOIfMWHe]CAc/c:b<O7alS:c<kAe=OIg=kO
hN;Rhn?RhN3Ng=WEd<[3^k:YWY>8O71UFDi4>c</9bDT9BP^=Ci8E61/NHB?V9nT
Z:VXYJ2JTXZ1N6mVGUI?B48l=c8^:bPV9BDW:c4h@DaIIWB3TIjY/kZo`/:o^[B/
Y9^CRhAoNgUhNG]nPXJ;SiBIWZ:WZk2e^[k3b<c@e=OIf]_KfMSFdm7>c<[9b<S9
b/c>d=;EemWKg=kOgn3Ph=oNgM[Gdlk8`KV`YY^AQGY^HeQ>AC`e;bXX9bP[<3Lo
B5=OJWJ1RiBKX:>TXj2LUXn7OWI]IEeFD4U4?cXf<Rl/:RTY:Rdb>D5<EfAbOhfJ
YJnf^kjn_;RbZj>JTX^5Og]iN7QjO823Qhb@U9VMXZN//KJk`<G9cM7De]OGe]GC
d<g:alG3`/71`/C6bLc?d]GHfmgOh>3Qh>3Ng=[Gdlk8`[ZbZInERWicIeaAAS`d
;2LS8B4T:2lg@4]GHfmkQHjFVinPX9fIThb5O7A[He]DCDI0>cHa;2PU8R0O828W
;CDoBUMULh6>VZF^];Ri^;B_ZJ6ITHV2OGUfM7AeMgYnPXN;T9FJX:FZ/;Jk`LK;
d=CGfM[JfMSEdlo<bLK4`/71`L;4a/W<c]7De]SJfmcMgMgMg=[He=3;a;fdZYnD
R7]_HUI:?cD/9R4O7R0U:c<mB5AQKGV4SYJMXJ>TXYjIThb4Ng=ZHUYBBdDn>C<_
:RLT8R4Q8bL/<ca7Df1]NhRDWjR_];Ng]K6/YYnHTHZ4P7ajNGUjNgf0Q8N;SiBH
WJ>X[[Bj`<K;cm?Ff=WIf=OEd]3=b/S6a<?3`lC6alW;cLoBe=KHfM_LgMkNgM_I
eM39`[V_Y9R<Og9UF4a1=blX8b0P8BD[<S]6DEeYMH2:TiZOXZ>RWi^ESXImMFaT
G5A=Ad4k=S8^:bTW9RHX:c0f?TMBGVYgPhnJXj^`/kBc[jZTWIJ?R8=nNWQfMWMi
Ngj2QHV>TYNMXZR^];_1algBe][Mg]oOg]gKf=KCd<k<bl[:b/_<cLo@d]CEemSJ
fmgNg]oOg]cIeM3:`[V^XiN:OG1SETXo=RhX9B@V:Blh@DaHIG5mRI>KXZJYZJNT
WiVARH1hKfINEe19@chi=C4^:bXY:B/_=3Y3CEQTL7f:UZ2Y/;Fg^;Jb[JNPVI><
Qh9oO7]kO7j0PhJ9SI2DVIfRYjbb^;k4bLkBe]WKg=cLf]WGeM?Aclk<c<_;bl_<
c<g>cm3AdmGFf=[LgMkNgM[Gd/_3^ZnSUXUkKEmBAS/b:bHT92L/<ca7DUm/N8B?
VJ2VZJ^ZZ:>MUXj6OG=ZHUYBBd@n>C@`;B/Y:2T[;S<i@D]EHFejQY:LYJfb]KJd
/JfWXIZCSHN3OgakNW]lOX22QHR<Si>HWJ:X[[Bk`LO=d]OJgMkOg]gLf]SFe=;@
clk=c<_;b/[:bLW9b/[;c<k?dM;Cdm?Acl_5_[J/X9B7NFaNDD@i<2PS820R9blh
@dmLJGN3SYRPYZZ/ZjVTWYN?QWacJF1GCdM0>S@_:bPV92@U:2`b>D9<F6AaOXZF
X:V_];Jf];6[YIjGT8Z4OgajNGUjO7j1Q8R;Si>GW:6VZk6g_L?8c];Ff]cMg]gL
fmWGe]CCd]7AdM7AdM7@d<o>cLc<c<c=c]3Ad]?Cdm7=bL:j/:FIRge_H595>C0X
8b0P8bP`>DA@GFYgPhjGWZBWZJRVXYfGShMnMFaTFe9;@c`f<B`X9R@T9RT]=3a5
D5aYMX>?VjF]];Rj^[Rd[ZRQVY><QX5mNgYiNW]nP8>7RhnCV9fRZ:jd^Ko5b/oC
em[LgMgMgMcJfMSGe]KFe]KFe]GEe=?BdLo>cLg=cLk?dM;Cdm;@cLW2^k6VVXan
L65CAS/a:B@Q8B@Y<CY6DUi[N8>>UYfRYJJUXYfGT8R0MfiUG5=;@S/c;2HQ7ATH
5aPK82L_>TICH6ilRIFOZ:jb];Ba[JRQVY>=QX5lNGMfMGIgNG]nPHB8S92FVj6W
[[Fl`/W>dmOJg=gMgMcJf=KEe=?Bd];CdmCDe=CCd]7@clk>c/k?cm3Ad];Aclc8
`KZ`YYZ=Og5TETXo=RlZ:2P[<3M0BeIRKWZ5SiNMXZFVYJ>OVY><Q7]cJV5ID4Q1
>C<]:2@Q81lQ92T`>4=>FfQePhnKYJfd^;Zj^;B^Z:6ITX^5Og]hMWEeMWQjOH65
RXnEVj6W[[Bk`LO<dMGGf]_Kfm[If=KEe=?Cd];CdmCDe=CDe=?Bd]7AdM7Bd]?E
eMKFe=;>bL:j/:FIS7i`HeE9?SD]:2HV:2dd?DMBGV]gPXfFWJ>VZ:RVXYfFShMn
MFeTFe9:@c/e;bXV8R0O828V:c<lAU9OK7V6TYfV[[>e][Fa[:JOV96:Q7mkN7Ie
MWMhNgj1Q8R<TIJKX:J]/kVoaL[?dmKHfMWHemKDd]3?cLc<c<g=c/o@dM7Bd];A
dM7AdM7AdM7Ad<k;al:k]:ZPUHUlKf9EBClf;RTV9RP]=3a6DUiZMX6<U9^PY:FT
XIfGT8V0N6mVGUI>ASli<bdX924O7AhO8bP_=d5=FFIcP8bGXJV_/[Bc/JfWXI^D
SHR2OW]hMgMgN7YlOh>6RhnEVZ2V[K>j`<K;cm?Ff=WIfMSGe]CCdm;Bd]?DeMKG
emSHf=OGe]KEeMGEeMGEe=?Acl[5_[J]XYN;OW5TF4a2>C8]:RX[<3HnB5=NJWJ1
RiBKX:>UY::NV9::PWYaJ61GD4Q1>cD`:bLT8R4Q8RDY;cM0BeISL7f9UInX[kBg
^;Jd[jZTWYRBS8R4PGmnOWn0PXF8S92EVZ2V[;:h_lG:cmCGf]cMgMgLf]SFeM?B
dM7AdM;BdmCDe=CDdm;BdM7@d=3@d<o>cL[6`K^cZj2ERWe`HeM;@3L_:BHT9RT_
=T1:EV5]NH><U9VMWinMVYF?Qh1gKfINETi7@C/e<2`X9B<R8R<U:Blf?TMBGFUe
PHbFWZJ[[k6a[jbXY9nJUI2<RHN5Q8B4QXN9S8jAUIVMXZN//[Nm`lS=dMCGf]_L
g=_JfMSGe]GEe=CDe=GEeMKFe]KFeMGEeMCDdm;@c/_7`kff[ZFKT8AhJemBAc`c
;2LT92H[<S]6DEi[N8B>UijSYZJUXIbFSXImM6]RFU9;A3hh<bhZ9R<Q820R9BT`
=d5;Ef=_NhNAVZ:XZjf^[:ZVXYjIUI6=RhV7QhJ7QhR:Rhf@TiJKWjF[/KRnaL_A
e][Mgn7QhN3NgM_JfMSGemSHfM[KfmcLg=_Kf]WIf=SHemOFeMCAcLS2^k:WW8n2
M6IHBcld;2HR8R@Y<CY6Df5_OHZEWjN/[k2_ZjJOUhn5O79YH5M?B44j=2lZ9R<Q
824R9R/b>dE@G6UfPXjHXJR]/K:a[jbXXinJUI:>S8Z:RHV:RX^<SXnATiJIWJ:W
[;>i_lG;d=CGf]_Lfm[If=OEe=CCe=CEeMKGemSGemKEeMCCd];Bd];Bd]7?c<S2
^k:XW8n2LfEFBC`a:24M71hS:S<oC5UWMH:>VJ6WZjb[ZJBMUXf4NW1VG5=:@SXc
;2HQ7ATG5aLI7B<Z<ci9EV=`O8RCW:>X[:f/ZZJRWINBSHV6Ph61P862PhB6R8Z=
Si:FVYnTZJnf_<;7cM7DemWIfMWHemGDdm?Bd];Cdm?De=CCdm;AdM3@d=3@dM;C
dm?Bd<g8`[ZaYY^>PG=VF4a0=RhX92<U:2lg@DeIIW>0S9JOYZZ][JbXXYbCRX5g
KF=ID4Q0>C8/:2@Q7ahO8BDZ<SY4D5aYMX>?VZB//[Jh^;Fb[JNPVY>>RHF2PH20
PH>5R8^?TYJJWZ>X[K:g_L;7c=3Ce]SJfm_JfMSFeMCBd]7AdM7AdM7AdM7AdM7B
d]?DeMKGemSGe]?@blBl/jRLSh9dIUU<@3D/9B4O7b8X<3U4DEi[N8B?VJ2VZJZY
YZ6KThZ1MfaRFDm6?SL`:RDQ7Q/J6adP9B/c?DQCH6aiQI6KXjZ^/K:`[JVTWYRA
S8N2OgelNgamOh64Qh^>TYNKX:J[/KNm`/S<dMCFf=WIfMSGeM?Bd<o>c/g=c/k>
clo?d=3@dM;CdmCEe]OFe]CBc/W2^[6WW8n3MFQKCT8h;bLR81lR9Rdf@4aIIW=o
RYBLXZJXZ:JQViB<PWU_IE]BBD4i<R`W8alM6a/L7b<Y<3U3CUYVLgn:UIjV[;2b
/[6^ZZFPVYF@S8R5Ph:2PX>5QhZ=T9BIWJ>Y[kFl`/S>dmSKg^3Ph=oNg=[GeM?A
d<o>c/k>c/k?cm3@dM7BdmCEe]OHf=SFe=7<a[nf[:2DQgY/Ge95>S4Y8b0P8RH]
=T1<FFMdPHfGX:J[[Jf[YZ6ITHMmLfUOEDa4?3D_:RHR81hN7b8V:c8kA4mKIg=o
RiFNYJ^^/;2_ZjNRWIRCSXZ7QHB3PhB5QhV;SY6DV9bPYJZ_]K_0a/[?d]GGf=SH
emKDdm7@clo>c/o?d=7Ad]?Ce=CEeMKGf=WJf]_JfMODclW2^JnTUh]mKf9DB3`b
:R@Q7b4U:c<mB5ERKg^7TIZQYJRXYZ:MUXf4Ng5WGEA;@c`e;bXV8b0O7QlQ9BX`
>45;EV9]NHB?V:2VZZf][:ZVXIbGTXj9QXB2PX:3Q8J8Rhf@U9NKX:BY[[Bi_/?8
c<oBe=KFe]KEdm;Ad<o>c/k>c/o@d=7Bd];CdmCDeMGFe]OGemKDd/k9`k^bZ9jB
QGU/Ge=8?SD_:bTY;38i@deIIW=oRiFNYJV/[:^WXY^DRh9iL6MOETm8@C/f<Rh[
:BPX:Rda=Si6D5YULGb7TY^RZ:f_/:n/Z:BOVYFASHZ8QhJ6QhR:S8j@TiFHVinS
Yjba][c1a/_?d]GGf=WIfMSGe]GDdm?Cdm?DeMGEe]KFeMGEe=CDdm?Cd];@c/_8
`kbe[:>HSH5dIe]?@cTa:RHT92L/<ca6DUiZMX6;U9^PXZ>RWiZDSHEmM6]RFU9;
A3hh<bh[:2HT92HX;34h@4UDGVYeOhZCVj6VZ:ZYZ:FQWIRCSh^8QXB3Ph>4QXN:
S8nBUIVMXZN//KJl`LK;cm;De]OHemOFeMCCd];Bd];CdmCDeMGEeMGDe=CDe=CE
eMGDdm;?c<S2^k>ZX9F9OG5UFDi4>c@^:bX[;S<j@deHI6mkQHnGWJ6SXj:NVI>;
PgYaJ5mGCdQ1>cHa;R/X9bHW:2/_=3]3C5EPJgJ0RY>KXJFXZJVWY:2LUi>?RhV7
QHF5QXR9S8jAU9NJWZ:VZk2e^[o4bLkAeMOIf][JfMSGeMCCd];AdM7Bd]?Cdm?D
e=CCdm?Cdm?Cdm;Aclc8`kff[ZBJShAhKF5FBd8j<bl/;2ha=cm8DUeYM7n8TINL
X:6PWIVDSHInMFeUGEE>Ad4l=c<`;B/Y:BX[;S8h?dM@FVA_NH><U9^QY:NWYjFR
Wi^GU92>RhZ9RHV:Rhb>T9:DUYVMXJFZ[kBj_lG:c];EemSIf=OFeM?Ad<o>c/k>
cm3Ad];Ce=CDe=CDdm?Cdm;Ad<k<bLBo^K:YX9J;P7AXGE98?cLa;R`/;c@j@daG
HVehPX^CVIfOWijJUY29PGU`J61HDDY4?STe<Bl/:b/[;Blc>3m6CeQRK7J0RI:I
Wj>UYZJTXYnKUi>@SH^9R8N7R8V:Rhb>T9:EV9^OY:R^/kRn`lO;cm7Ce=CDdm7@
c/g<bl_;blc=c/o?d=7AdM7Ad];Bd];Bd]7@c/_8`kfg[jJMThQmLVMMDdY1>SDa
;bla=CY1BE=MIg5kQHfCV9^MWI^GTXb5OGA/I5aECTM2?CTe<S0_;Rd^<3<g?4=;
DeeWLWb6SiRNY:NYZZRVXinLV9BASXf<Rhb<SHn@TY>EUiVLWZ6UZJjc^;g2alc?
dmGFemOFeM?Bd<o=cLc<cLg>cm3@dM7AdM7@d=3?clk>cL_:alC0^[B]YIbCRGme
Jf5HCdQ1?3Tg=cTm@TQ@F65[MGj6SYBIW9jNW9VDSXN0N71XHEYCCDQ3?c/h=S@c
<S8c=STm@TU@FF9[MGj7SiJLX:>UYJBSX9jKV9FCTI2?SXj>SXj?Si2ATiFGVYjR
Yjba]kc2al_>dM?De=?BdLo=c<[9bLW9b/[;c<g>clo?clo?c/k=c<_:bLO4`Kfh
/jbUWIF<PgYaJ61GD4U3?SXh=cPj?T98D5QPJG9jPXR>TYBEU96=R89lM6eVGeQB
CDQ4@3dj>3He=3@d=SPl@DM>Ef1ZM7j8TIVPYJV[[:^ZZ:FQWY^HUI>AT92?Shn?
Si2ATYBFVIfQYZ^`][c1a/_>dM?EeMGDdm;Ad<o>cLg=c/k>clo@d=3?clk>cLg<
c<_:bLS6`l2l]k:/YIjFShInMViWH5UCCDU5@d92@dI9CUAKHfYbNH26RXj@T8n=
RHEoNG=]IV1KEU5=BDE2?c`j>3Lf=SLi?457CUMPJWAoR9:JXJN[[Zn_[ZbZYZ>P
W9ZGUI>BTI2?Si2@TI>EV9^PY:V_]K[0aLW=d=?DeMGDe=;Ad<o>c/k>c/k>clo?
c/k=c<_:bLS7a/K5a<;1_kbi]K6/YZ2ITX^3O7E]IV1IDdi9AD90@412ADU>E5]R
JG1gOH:6RHZ:RHJ3OWUdKVUSGUUEDDe9AD8o?3Xh=cLh>Ce1AdiFGVQbO8J?UijS
Z:^/[:^ZYjBQWY^HUI>AT8n>SHf=SXnATiJJWZ>X[K>h_L;6b/g?d=7Ad=3?c/g<
bl[9bLS8b<O7a/K5a<?2`L2o_kjn_Kfl^kZi][Ba[JVUX9^FTHb6PG]eL6YTGUQB
CTU6A4=3ADQ=DUUPJ71gOH>7RXb<RhR5PGehLVeXHeiJEU9>BTM4@Cln?Cdo@TM<
E5aUL7Z5SiVRZJnd]kVi^;Jc/:bXY:2MVYRFU9>BTY:BTiFGVIbPY:V^/kRm`/K:
cLo@dM7Ad<o=c<[9alK5aLC3`l;1`;nn_Kbj^KRg]kJe]KBc/[6_[J^XYJ6NVIFA
S8N2OGMbK6IPFUA>BDE1?chn@4=7CE=JHFU`MW^0PhF6QXB2Og]gLViYIF1LF5EA
CT]9AdE5ADI9C55GGVI_N86:Ti^RZ:b`/[:b/:j[Z:FQWYbJV9JEUIBDUIFFV9VK
WZ6TZ:b`]KVm`LC7bL_<c<_:b<K4`[nm^kZh]kJf][Fe]KFd];Bc/k:b/[6a/K2`
[jj]ZjVWY:6NVYJASHR3OWUdKVUTGUUDD4a9AdI6AdU=DEIKHFM]LWMkOX21PH1o
O7UfLViZIV=OG5UFDe5@CTi>Ce5DF5eSJW5iPHV@V9jTZ:b^/;2_[ZbZZ:FSXInM
W9^KVi^LW9jOXJ:UYjZ]/;>g^[k1a<K8bL[9bLS6a<:o_KZh]kFd/k>b/[:b/[:b
/K6a/;2_[jj^[Jf/ZjZYYjJTXIjKUi>?RhN2OWUeLFeXI65MFUMEDe5AD55BDeIH
FemRIVY]L79dMWMhN7QgMWEdLW1^KF]YIfIUI6ATI6EWJFa`LgQmPHJ;T9BHW9nQ
XjFVYZJVYZJVYJFUYJFUYZJWYjRYZZ^][[2a/kBf^;Vj^kbl_;^k^[Vg][Bc/K2^
[Jb[ZZVXZ:NWYZJVYZJVYZJVYJFTY:>QX9jKVIJCT8f9QX=oO7UfM75_KFYXIVAR
HEmMG5YIFEQHFEYKG5iPHVAVJ6Y[KFi`LG5bLW=cLg=bLW5aL6m_KVi^KVm`LWAf
N7]mP8>6R8^=Si6CU9JGV9VJVibMWYnPXJ:SY:FVZ:VZZjf^[k2a/[>c];Bd/k>b
/K2_[Zf/ZjZYZ:NWYZJUYJFUYJFUYJFUYJFUYJFUY:>RXInMViRETXn<RHJ4PGmm
NgYhMgIeM7=bLG1`Kfi]KFa/Jf][Jf][Jf][Jf]/K6e^KVm`LG9dMGIhNGYkO7am
OGemOGenOWioOh21PXB5QhR:S8j?TI>DUYNHVY^LWIjOX:6RXjBUYZNYZZb][k2b
/kBe][Jf]KFd/[2_[J^YYjJTXj:RXJ6QXJ6RXZ:SXjBTY:FUYZJVYZJVYJFSXZ2O
W9ZGUI:?S8Z7QH>1P7imOGakNgYjNWUiN7QhMgMgMgMgMgIfMWIeMGEdM7AdM7Ee
MWMhNGYkO7enOWmoOgmnOWinOWinOWn0PH:4QHN9RXb>Si2BTiBEUIJGUiRHVIVJ
Vi^LWIjOXJ:SYJJWZ:VZZj^[ZjZYZ:JUXj6PWYfKVYVIV9RHV9RHV9VJVY^LW9fN
WinPX:2PX9nOWYbKVIRFU9:@Shf<RXV8QhJ5QHB3PX:1P7moOWimOGemOGemOWio
Ogn0P821PH62PX>4Q8F6QhN8RHV9RHV9RHR7QhJ6QXF5QXJ6QhR9RX^<SHj?T92A
TY>CU9FFUYNHVIVJVY^KVibLW9bMWIfMWIfLW9bKViZIVIRGUYJEUIBDU9BEUIJF
UiRHVIVJVY^KVi^KVi^KVi^JVYZIV9RGUYFDU9>BTI6@T92@T92@T92@Shn>SXf<
S8^:RXZ9RHZ:RX^;S8b=SHj>Shn?T92ATI6BTY:CTi>CTi:BTY6AT92@T8n@T92@
TI6BTY:CTi>CTi>CTiBDUIFFUYNHVIVJVYZKVi^KVi^KVi^KViZJVIVHUiNFUIBC
Ti:BTI6ATI:BTY>CTiBDU9BDU9>CTi:BTY6ATI6ATI6@T8n?SXj>SHf=SHf=SHf>
SXj>Shn?Shj>SXf=SHf=SHf=SXj?T92ATY>DUIFFUYNGUiNHUiNGUiNFUYFEU9>C
TY:ATI6ATI6ATI:BTY:BTY:BTY:BTY:BTY>CU9BEUYJFUiNGUiNFUYJFUIFDU9>C
Ti:BTI6@T8n?SXj>SXj>SXj?Si2@TI6BTY:BTY:ATI2?Shj=S8b;RhZ:RHV9RHV9
RHV:RX^;S8f=SXn?T92ATI6ATI2@T8n?SXj>SXj>Shn@T96BTY>DU9BEUIFEUIFE
UIFEUYJFUYJEUIFDU9>CTY:ATI6ATI6ATI6BTI6ATI6ATI6ATI:BTY>CTi>CTi:B
TI2@Shj=S8^;RXZ9RHV8R8R8R8R9RHV:RX^;S8f>SXn@T96ATI6AT92?Shj=S8b;
RhZ:RHV9RHV9RHV:RX^;S8f=SXn?T92ATI6ATI6ATI2@T8n?Shn>Shn?Si2@T96A
TY:BTi>CTi>CTi>CTi>BTY:BTY6ATI2@T8n?Shj>SXj>SXj>SXn?Si2@T96ATI6B
TY:CTi>CTi>CTi>BTY6@T8n>SHb<RhZ:RXV9RHV9RHV9RXZ:Rhb<SHj>Si2@TI6A
TI6@T8n?SXj=S8b;RhZ:RXZ:RXZ:Rh^<S8f>Shn@TI6BTY:BTY:BTI6@T8n>SXf=
SHf=SHf>SXn?T96ATY>CU9BDU9BDU9BDTi>BTY6@T8n>SHb;RXZ9R8R8QhN7QhJ6
QXJ6QXN7QhN7QhN8R8R8R8R8R8R8R8N7QhJ6QXF5QHF5QHF5QHF5QHF5QHJ6QXN7
QhR9RHZ:Rh^<S8b<S8b<Rh^;RXZ:RXV9RXZ:RX^;S8f=SXn@TI:CU9FFUiNHV9VI
VYZJVi^KVi^KVi^KVi^LW9bLW9bLW9bLW9bLW9bLVi^KVYVIV9NGUYFDTi6@Shj=
SHb;RhZ:RXZ:RXZ:RX^;Rhb<S8b<Rh^;RXV9R8R7QhN6QXJ6QXF5QHF6QXJ6QXN7
QhR8RHV:RXZ;Rh^;Rh^;RXZ9RHV8R8N7QhN7QXJ6QXJ7QhN7R8R8RHV:RX^<S8f>
SXn@TI:CU9FFUiRHVIZJVi^KW9bLW9bLW9bMWIfMWIfMWIfMWIfMWIfLW9bKVi^J
VIVHUiJEU9>CTY6@T8n?Shn?T92@TI6BTY>CTi>CTi>CTi>CTi:BTY6AT92?SXj=
S8^;RXZ9RHV8R8R8R8R8R8R8R8R8QhN7QXJ6QHF5QHB4Q8B4Q8B4Q8B4Q8B4Q8B4
Q8B5QHF5QXJ6QhN8RHV:Rhb=SXn@TI:CTiBEUIJFUYNGUiNGUiNGUiJFUYJFUIFE
UYJFUYJGUiNGUiNGUYJEUIBCTi:ATI2@T92@T96ATY:CU9BEUYJFUiNGUiNFUYFE
U9>BTY6@Shj=SHb<Rh^;Rh^;S8b<SHj>Si2@TI6BTY:BTY:BTI2@Shj=S8^:RXV9
R8R7QhN6QXJ6QXJ6QXJ6QXJ7QhN8R8V9RX^<S8f>SXn?Si2@T92@T8n?Shj>SHf=
S8b<S8b<S8b=SHj?Si2ATY>DUIJFUiRHV9VIVIVIVIVIVIRHV9RHV9RIVIVIVIZJ
VYZJVYZJVYVIV9RGUiJEU9>BTI2?SXf<Rh^:RXZ9RHV9RHV9RHV9RHV9RHZ:RXZ:
RXZ:RXZ:RXV9RHR8QhN7QXJ6QXJ6QXJ6QhN7QhR8RHZ:Rh^<SHf>SXn?Shn?Shn>
SXf=S8^:RXV9R8R8QhN7QhN7QhR8R8V9RXZ;S8b=SXj?Shn?Shn>SXj=SHb<Rh^;
RXZ:RX^;Rh^<S8f=SXn?T96BTY>DUIJFUiNGV9RHV9RGUiNGUiNGUiNGV9RHVIVJ
VYZJVYZJVYZJVYVIVIRGUiJEU9>BTI2?SXf=S8^;RXZ:RHV9R8R8R8R8R8R9RHV:
RXZ;Rh^<S8f=SXj>SXn?Shn?Shj>SXf=SHb<S8b<S8b=SHf>SXn@T96ATY:CTi>C
TY:BTY6ATI2@T92@T8n?Shn>SXj>SXj>SXj>SXj>SXj>SXj>SXn?Shn?Shn?Shn?
Shn?Shn?Shn?T96ATY>DU9FFUYNGV9RHV9RHV9RGUiJFUIBDTi:AT92?Shn?Shn?
Si2@T92ATI6@T92?SXj=S8^:RXV8R8N7QXJ6QXF5QHF5QHF4Q8B4Q8B4Q8B4Q8B4
QHF5QXJ6QhN7R8R8R8V9R8R8R8R7QhJ6QXF5QHF4Q8B4Q8B4Q8B5QHF6QXJ7R8R9
RHZ:Rh^;Rh^:RXZ9R8R7QhJ6QXF5QHF5QHF5QHF6QXJ6QXJ6QHF5Q8B4Ph>3Ph:2
PX:2PX:2PX:2PX:2PX:2Ph>3Ph>3Ph:2PX:2PX61PH61PH61PH61PH61PH61PH61
PH61PX:2PX:2PX:2PX:2PX:3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3
PX:2PX:2PX:2PX:2PX:2PX:3Ph>3Ph>4Q8B4Q8B5QHF6QXJ7QhR8RHV:RXZ:Rh^;
Rh^;Rh^;Rh^;Rh^:RXZ:RXZ:Rh^;S8b=SXj?Shn?Shn?Shj>SHb<Rh^:RXV8R8N7
QXJ5QHF4Q8B4Q8B3Ph>3Ph>3Ph>4Q8B4Q8F5QHJ6QXN7R8V9RXZ:Rh^;Rh^:RXZ:
Rh^;S8b=SXj?T92ATI:BTY:BTY:ATI2@T8n?Shn?Shn>SXj>SXn?Shn@T96ATY:B
Ti>CTY:BTI6@Shj=SHb;RXZ9RHV9RHV9RHV9RXZ;S8b=SXj?Si2@T92@Shn>SHf<
RhZ9RHR7QhJ5QHF4Q8B4Ph>3Ph>3Ph>3Ph:2PX:2PX:2PH61PH61PH61PH61PH61
P820P820P820P820P820P820P820PH61PH61PH61PH61PH61PX:2PX:3Ph>4Q8B5
QHJ6QhN8R8R9RHV9RHR8R8R7QhJ6QXJ5QHF5QHF5QHJ6QXJ6QXJ6QXJ6QHF5QHJ6
QXJ6QHF5QHF5Q8B4Q8B4Q8B4Q8B4Q8F5QHF6QXN7QhR8R8R9RHV9RHV9R8R7QhJ6
QXF5QHB4Q8B4Q8B4Q8B4Q8B4Q8F5QHJ6QXN7R8V9RXZ:RXZ:RXZ:RXZ:RXZ:Rh^<
S8f>SXn@TI:BTiBEUIJFUiNGV9RHUiNGUiJFUIBDTi>BTY6ATI6ATI6ATY:CTi>D
U9BDUIFEUIFEUIFEUIFEUIFEUIBDTi>BTI2?SXf<RhZ9RHR7QhJ6QHF5Q8B4Q8B3
Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Ph>3Q8B4Q8B5QHF6QXN7R8V9RXZ;Rh^<S8b<S8b=
SHf=SXj>Shn@TI6BTi>DU9FEUIFEUIFEU9BDTi>BTY6AT8n?SXf<RhZ:RHR8QhN7
QXJ6QXJ6QXJ6QXJ6QXJ6QXJ5QHF4Q8B3Ph>3PX:2PX:2PH61PH61PH61PH61PH61
PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61
PH61PH61PH61PH61PH62PX:2PX:3Ph>3Q8B4QHF6QXN7QhN7R8R7QhN8R8R8R8V9
RX^;S8f>SXn@TI6BTY>CTi>BTY:BTI6ATI6@T92@T8n?Shn?Shn?Shj>SXf=SHf<
S8b<S8b<S8b;Rh^;RhZ:RXZ;Rh^;Rhb<S8b<S8b<S8f=SHf>SXj>SXn?Si2@TI6B
Ti>DU9FFUYNGV9VIVIZJVY^KVi^KVi^KVi^JVYZIVIRHUiJEUIBBTI2?SXf<Rh^:
RHV8R8R8R8R8R8R8R8V9RHV:RXZ9RHV9RHR8R8R8R8R8R8V8R8R8QhN7QXJ5QHB4
Q8B3Ph>3Ph>3Ph:2PX:2PX>3Ph>3Ph>3Q8B4Q8F5QHF6QXJ7QhR8RHV:RX^;S8b=
SHf=S8b<S8^;RhZ:RHV9RHV8R8R7QhN7QXJ6QXJ6QXJ6QXJ7QhN7R8R8R8R8QhN6
QXJ5QHB4Q8>3Ph>2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX>3Ph>4Q8B4Q8F5QHF5
QHB4Q8B4Q8B4Q8B4Q8F5QHJ6QXN8R8V:RX^<S8b=SHf=SHf=SHf=S8b<S8b;Rh^;
Rh^;Rh^;Rhb<SHf>SXn@T96BTY>CU9BDU9BDU9BCTi:BTI6@Shj=SHb;RXV9R8R7
QhJ6QXF5QHF4Q8B4Q8>3Ph>3Ph>3Q8B4Q8B4QHF5QHF5QHF4Q8B4Q8>3Ph>2PX:2
PX61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH61PH62PX:2
PX:3Ph>3Q8B4QHF6QhN8RHZ;S8f=SXn@T92ATI6ATI6AT92?Shj=SHb;RXV8QhN6
QXF5Q8B4Ph>3Ph>2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX:2PX>3Ph>3
PhB4Q8F5QXJ7QhR8RHZ:Rh^;S8b<S8b<S8b<S8b;Rh^;RhZ:RXZ9RHV9RHR8R8V9
RHV9RXZ:Rh^;S8b<S8^;Rh^;RXZ:RXV9RHR8R8R7QhN7QhJ6QXJ6QXJ6QXJ5QHF4
Q8B4Ph>3Ph>3Ph>3Ph>3Ph>4Q8B4Q8B4Q8B4Q8>3Ph>3PX:2PX:2PX:2PX:2PX:2
PX:2PX:2PX:3Ph>3Q8B5QHF6QXN7R8R8R8R8R8R7QhN7QhN7QhN7QhN7R8R8R8R8
RHV9RHV8R8R8R8R8R8R8R8V9RHV9RHV9RHV8R8R7QhJ6QHF4Q8B4Q8>3Ph>3Ph>3
Ph>3Ph>3Q8B4Q8F5QHJ6QhN8RHV:Rhb<SHf>SXj>SXj>SHf<Rh^:RXV9RHR8R8R9
RHV9RXZ;Rhb<SHf=SXj>SXj>SXj>SXj>SHf=SHf=SHf=SHf=SHf=SHf=SHf>SXj>
SXj>Shn?Shn?Shn?Shn?Shn?Shn?Shn?Si2@T92@T92@T92@T92@T92@T92@T92@
T92@T92@TI6ATI6ATI6@T92@T8n?Shj>SXf=SHf=SHf=SHf=SHf<S8b<Rh^;RXZ9
RHV8R8R7QhN7QhN7QhN7QhN7QhN8R8R8R8R8R8V9RHV:RXZ:RX^;S8b<SHf>SXj?
Shn?Shn@T92@T92ATI6ATY:BTY>CTi>DU9BDU9BDUIFEUYJFUiNGV9RHV9VIVIVI
VYZJVYZJVYZJVYZJVYVIVIRHV9RGUiNGUiJFUYJEUIFEUIBDU9BDU9BDU9BDUIFE
UIFEUIFDU9>CTY:ATI2@Shn?SXj>SXj>SXj>SXj>SXj>SXj>SXj>SXj>SXf=SHf=
SHf=SHf=SHf=SHf=SHf=SHj>SXj?Shn?T92@TI6ATY:CTiBDU9FEUYJFUiNGUiNH
V9RHV9RHV9RGUiNGUYJEUIFDU9>CTY:ATI2@Shn>SXj=SHf=SHf=S8b<S8^;RXZ:
RHV8R8R7QhN7QXJ6QXJ6QXJ6QXJ6QhN7R8R8R8V9RHV9RHV9RHV9RHR8R8N7QhJ6
QHF5Q8B4Ph>3Ph>3PX:2PX:2PX:2PX:2PX>3Ph>3Ph>3Q8B4Q8B4QHD\>"]},
  ImageCacheContents->"Sound"],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Sound  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Apart from the change in volume level (which can be adjusted using the ",
  StyleBox["PlayRange",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " option) the main difference one can hear is that some high frequencies \
have been removed from this sound sample, as we expected. The audio filtering \
that we have applied here using an FFT is a crude example of the sort of \
operations that are employed in modern signal-processing applications. Some \
other examples of the use of FFTs may be found in the exercises, and in Secs. \
",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:22"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["7.3",
    ButtonData:>{"Chapter7.nb", "c:31"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.3.6 Response of a Damped Oscillator to General Forcing. Green's \
Function for the Oscillator\
\>", "Subsubtitle",
  CellTags->{"i:54", "c:38"}],

Cell[TextData[{
  "We are now ready to use Fourier transforms to solve a physics problem: the \
response of a damped harmonic oscillator to a general forcing function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". Previously, only simple analytic forcing functions (Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:44"},
    ButtonStyle->"Hyperlink"],
  ") or periodic functions (Sec. ",
  ButtonBox["2.1",
    ButtonData:>"c:2",
    ButtonStyle->"Hyperlink"],
  ") were considered. Using Fourier transforms, we can now deal with any form \
of forcing."
}], "Text"],

Cell[TextData[{
  "\tIn order to obtain a particular solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  " to the forced damped oscillator equation, Eq. ",
  ButtonBox["(1.6.2)",
    ButtonData:>{"Chapter1.nb", "(1.6.2)"},
    ButtonStyle->"Hyperlink"],
  ", we act on the right and ",
  "left-hand",
  " sides of the equation with a Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(F\&^\), "(", 
            RowBox[{\(x\^\[DoublePrime]\), "+", 
              RowBox[{"\[Gamma]", 
                FormBox[\(x\^\[Prime]\),
                  "TraditionalForm"]}], "+", \(\[Omega]\_o\%2\ x\)}], ")"}], 
          "=", \(F\&^\ f\)}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.69)"],

Cell[TextData[{
  "Defining the Fourier transform of the forcing function as ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\  = \ \(F\&^\) f\)]],
  ", and that of the particular solution as ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~\_p = \(F\&^\) x\_p\)]],
  ", Eq. ",
  ButtonBox["(2.3.69)",
    ButtonData:>"(2.3.69)",
    ButtonStyle->"Hyperlink"],
  " is transformed from an ODE to a simple algebraic equation :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\(-\[Omega]\^2\)\  - \ \[ImaginaryI]\ \[Omega]\ \
\[Gamma]\  + \ \[Omega]\_o\%2)\) \(\(x\&~\_p\)(\[Omega])\) = \
\(f\&~\)(\[Omega])\)]],
  "."
}], "NE3",
  CellTags->"(2.3.70)"],

Cell[TextData[{
  "Here, we have applied Eq. ",
  ButtonBox["(2.3.18)",
    ButtonData:>"(2.3.18)",
    ButtonStyle->"Hyperlink"],
  " to the derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_p\)]],
  ". We may then divide by the bracket, ",
  StyleBox["assuming that the bracket is not zero",
    FontSlant->"Italic"],
  ", to obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\&~\_p\)(\[Omega])\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(f\&~\)(\[Omega])\)/\((\(-\[Omega]\^2\)\  - \ \
\[ImaginaryI]\ \[Omega]\ \[Gamma]\  + \ \[Omega]\_o\%2)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.71)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.3.71)",
    ButtonData:>"(2.3.71)",
    ButtonStyle->"Hyperlink"],
  " provides the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&~\_p\)(\[Omega])\)]],
  " of all  Fourier coefficients in the oscillator's response to the forcing. \
This equation shows that each Fourier mode in the response is excited ",
  "only",
  " by its corresponding mode in the forcing. This is very similar in form to \
the response to periodic forcing, Eq.  ",
  ButtonBox["(2.1.37)",
    ButtonData:>"(2.1.37)",
    ButtonStyle->"Hyperlink"],
  ", except that now the frequency varies continuously rather than in \
discrete steps."
}], "Text"],

Cell[TextData[{
  "\tIn order to determine the response in the time domain, an inverse \
transformation must be applied to Eq. ",
  ButtonBox["(2.3.71)",
    ButtonData:>"(2.3.71)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\(\( \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\) \(\(f\&~\)(\[Omega])\)\
\)\/\(\(-\[Omega]\^2\)\  - \ \[ImaginaryI]\ \[Omega]\ \[Gamma]\  + \ \[Omega]\
\_o\%2\)\) \[DifferentialD]\[Omega]\/\(2\ \[Pi]\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.72)"],

Cell[TextData[{
  "This is as far as we can go in general. Without knowing the form of the \
forcing function, we cannot evaluate the frequency integral required in Eq. \
",
  ButtonBox["(2.3.72)",
    ButtonData:>"(2.3.72)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tHowever, we can convert the frequency integral to a time integral by \
using the convolution theorem. Equation ",
  ButtonBox["(2.3.71)",
    ButtonData:>"(2.3.71)",
    ButtonStyle->"Hyperlink"],
  " can be seen to be a product of Fourier transforms; one transform is ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ", and the other is ",
  Cell[BoxData[
      \(TraditionalForm\`1/\((\(-\[Omega]\^2\)\  - \ \[ImaginaryI]\ \[Omega]\ \
\[Gamma]\  + \ \[Omega]\_o\%2)\) \[Congruent] \(g\&~\)(\[Omega])\)]],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\&~\_p\)(\[Omega]) = \(\(f\&~\)(\[Omega])\) \(\(g\
\&~\)(\[Omega])\)\)]],
  ", the convolution theorem implies that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t) = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( f(t\_o)\) \(g(
              t - t\_o)\) \[DifferentialD]t\_o\)]],
  ","
}], "NE3",
  CellTags->"(2.3.73)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`g(
          t)\  = \(\(F\&^\^\(-1\)\) \(\(g\&~\)(\[Omega])\)\(\ \)\)\)]],
  "is the inverse transform of ",
  Cell[BoxData[
      \(TraditionalForm\`g\&~\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAlthough the time integral in Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " is not necessarily easier to evaluate than the frequency integral in Eq. \
",
  ButtonBox["(2.3.72)",
    ButtonData:>"(2.3.72)",
    ButtonStyle->"Hyperlink"],
  ", Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " has some conceptual and practical advantages. From a practical point of \
view,  Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  "  deals only with ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", whereas Eq. ",
  ButtonBox["(2.3.72)",
    ButtonData:>"(2.3.72)",
    ButtonStyle->"Hyperlink"],
  " involves the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", which must be calculated separately. Thus, Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " saves us some work. Conceptually, the original differential equation is \
written in the time domain, and so is Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  "; so now there is no need to consider the frequency domain at all."
}], "Text"],

Cell[TextData[{
  "\tHowever, we do need to calculate the function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t - t\_o)\)]],
  ". But we need  do so only once, after which we can apply Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " to determine the response to any  forcing function. "
}], "Text"],

Cell[TextData[{
  "\tThe function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t - t\_o)\)]],
  " is called the ",
  StyleBox["Green's function",
    FontSlant->"Italic"],
  " for the oscillator. We will soon see that Green's functions play a very \
important role in determining the particular solution to both ODEs and PDEs. \
"
}], "Text"],

Cell[TextData[{
  "\tThe Green's function has a simple physical interpretation. If we take \
the forcing function in Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " to be a Dirac \[Delta]-function, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t\_o) = \[Delta](t\_o)\)]],
  ", then Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t) = g(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "In other words, the Green's function ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " is a response of the oscillator to a \[Delta]-function force at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". The total impulse (i.e. momentum change) imparted by the force is \
proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[Delta](t\_o)\) \[DifferentialD]t\_o = 1\)]],
  ", so this force causes a finite change in the velocity of the oscillator. \
To understand this physically, think of a tuning fork. At ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", we tap the tuning fork with an instantaneous force that causes it to \
oscillate. The Green's function is this response. For this reason, Green's \
functions are often referred to as ",
  StyleBox["response functions",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell["\<\
\tOf course, the tuning fork could already be oscillating when it \
is tapped, and that would correspond to a different particular solution to \
the problem. In general, then, there are many different possible Green's \
functions, each corresponding to different initial (or boundary) conditions. \
We will see that when Fourier transforms are used to determine the Green's \
function for the damped oscillator, this method picks out the particular \
solution where the oscillator is at rest before the force is applied.\
\>", \
"Text"],

Cell[TextData[{
  "\tBefore we proceed, it is enlightening to step back for a moment and \
contemplate Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  ". This equation is nothing more than another application of the \
superposition principle. We are decomposing the forcing function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  "  into a sum of \[Delta]-function forces, each occurring at separate times \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(t\_o\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". Each force produces its own response ",
  Cell[BoxData[
      \(TraditionalForm\`g(t - t\_o)\)]],
  ", which is superimposed on the other responses to produce the total \
response ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  "."
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  "\tPreviously, we decomposed the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " into individual Fourier modes. Equations ",
  ButtonBox["(2.3.72)",
    ButtonData:>"(2.3.72)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  " show that the response to the force can be thought of as either a linear \
superposition of sinusoidal oscillations in response to each separate Fourier \
mode in the force, or as a superposition of the responses to a series of \
separate \[Delta]-function forces. Fourier decomposition into modes, and \
decomposition into \[Delta]-function responses, are both useful ways to think \
about the response of a system to forcing. Both rely on the principle of \
superposition."
}], "Text"],

Cell[TextData[{
  "\tWe can determine the Green's function for the damped oscillator \
analytically by applying the inverse Fourier transform to the resonance \
function ",
  Cell[BoxData[
      \(TraditionalForm\`g\&~\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`g(
        t)\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \[ExponentialE]\^\
\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\/\(\(-\[Omega]\^2\)\  - \ \[ImaginaryI]\ \
\[Omega]\ \[Gamma]\  + \ \[Omega]\_o\%2\)\) \[DifferentialD]\[Omega]\/\(2\ \
\[Pi]\)\)]]], "NE3",
  CellTags->"(2.3.74)"],

Cell[TextData[{
  "To evaluate this integral, we must first simplify the integrand, noting \
that the denominator ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Omega]\^2\)\  - \ \[ImaginaryI]\ \[Omega]\ \
\[Gamma]\  + \ \[Omega]\_o\%2\)]],
  " can be written as ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[ImaginaryI]\ \[Omega] + \ 
            s\_1)\) \((\[ImaginaryI]\ \[Omega] + \ s\_2)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  " are the roots of the homogeneous polynomial equation discussed in Sec. ",
  ButtonBox["1.6.2",
    ButtonData:>{"Chapter1.nb", "c:38"},
    ButtonStyle->"Hyperlink"],
  ", and given by Eqs.  ",
  ButtonBox["(1.6.14)",
    ButtonData:>{"Chapter1.nb", "(1.6.14)"},
    ButtonStyle->"Hyperlink"],
  ". Then we may write Eq. ",
  ButtonBox["(2.3.74)",
    ButtonData:>"(2.3.74)",
    ButtonStyle->"Hyperlink"],
  " as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g(
          t)\  = \(1\/\(s\_2 - 
                s\_1\)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\( \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\)(
                1\/\(\[ImaginaryI]\ \[Omega] + s\_1\) - 
                  1\/\(\[ImaginaryI]\ \[Omega] + \ s\_2\))\) \[DifferentialD]\
\[Omega]\/\(2\ \[Pi]\)\)\)]],
  ","
}], "NE3",
  CellTags->"(2.3.75)"],

Cell[TextData[{
  "where we have separated the resonance function into its two components. It \
is best to perform each integral in Eq. ",
  ButtonBox["(2.3.75)",
    ButtonData:>"(2.3.75)",
    ButtonStyle->"Hyperlink"],
  " separately, and then combine the results. Integrals of this sort can be \
evaluated using ",
  StyleBox["InverseFourierTransform",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      InverseFourierTransform[1/\((I\ \[Omega] - a)\), \[Omega], t, 
          Assumptions -> Re[a] \[GreaterEqual] \ 0]/Sqrt[2\ Pi]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.87"],

Cell[BoxData[
    \(\(-\(1\/2\)\)\ \[ExponentialE]\^\(\(-a\)\ t\)\ \((1 + 
          Sign[t])\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Noting that ",
  Cell[BoxData[
      \(TraditionalForm\`\([1 + Sign(t)]\)/2 = \ h(t)\)]],
  ", the Heaviside step function, and taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"-", 
            FormBox[\(s\_1\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  " in the above integral, we then have"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(F\&^\^\(-1\)\) 
          1\/\(\[ImaginaryI]\ \[Omega] + \ s\_1\) = \ \(-e\^\(t\ s\_1\)\) \(h(
            t)\)\)\(,\)\)\)]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`Re[s\_1] \[LessEqual] \ \ 0\)]],
  ","
}], "NE3",
  CellTags->"(2.3.76)"],

Cell[TextData[{
  "with a similar result for the inverse transform involving ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  ". Since  Eq.  ",
  ButtonBox["(1.6.14)",
    ButtonData:>{"Chapter1.nb", "(1.6.14)"},
    ButtonStyle->"Hyperlink"],
  " implies that the real parts of ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\_2\)]],
  "  are identical, equaling the nonpositive quantity  ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Gamma]\)/2\)]],
  ", we can apply Eq. ",
  ButtonBox["(2.3.76)",
    ButtonData:>"(2.3.76)",
    ButtonStyle->"Hyperlink"],
  " to Eq. ",
  ButtonBox["(2.3.75)",
    ButtonData:>"(2.3.75)",
    ButtonStyle->"Hyperlink"],
  ", yielding"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(g(
        t)\  = \ \(\(h(
            t)\) \(\[ExponentialE]\^\(\(s\_1\) t\) - \
\[ExponentialE]\^\(\(s\_2\) t\)\)\/\(s\_1 - s\_2\) = \ \(h(
            t)\) \[ExponentialE]\^\(\(-\[Gamma]\)\ t/2\)\/\@\(\[Omega]\_o\%2 \
- \[Gamma]\^2\/4\)\ \ \ sin\ \(\@\(\[Omega]\_o\%2 - \[Gamma]\^2\/4\)\) 
          t\)\)\(,\)\)\)]]], "NE3",
  CellTags->{"(2.3.77)", "i:59"}],

Cell[TextData[{
  "where we have used Eq. ",
  ButtonBox["(1.6.14)",
    ButtonData:>{"Chapter1.nb", "(1.6.14)"},
    ButtonStyle->"Hyperlink"],
  ". A plot of this Green's function for particular choices of \[Gamma] and \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " is shown in Fig. ",
  ButtonBox["2.11",
    ButtonData:>"Fig. 2.11",
    ButtonStyle->"Hyperlink"],
  " This Green's function displays just the sort of behavior one would expect \
from an oscillator excited by a \[Delta]-function impulse. For ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ", nothing is happening. Suddenly, at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the oscillator begins to display decaying oscillations. Note that for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  " this oscillation is simply a homogeneous solution to the ODE, as given by \
Eq. ",
  ButtonBox["(1.6.17)",
    ButtonData:>{"Chapter1.nb", "(1.6.17)"},
    ButtonStyle->"Hyperlink"],
  ". This is expected, since for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  " the forcing has vanished, and the oscillator's motion decays freely \
according to the homogeneous ODE."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.195787 1.14559 [
[.0873 .18329 -6 -9 ]
[.0873 .18329 6 0 ]
[.21429 .18329 -6 -9 ]
[.21429 .18329 6 0 ]
[.46825 .18329 -3 -9 ]
[.46825 .18329 3 0 ]
[.59524 .18329 -3 -9 ]
[.59524 .18329 3 0 ]
[.72222 .18329 -3 -9 ]
[.72222 .18329 3 0 ]
[.84921 .18329 -3 -9 ]
[.84921 .18329 3 0 ]
[.97619 .18329 -6 -9 ]
[.97619 .18329 6 0 ]
[1.025 .19579 0 -6 ]
[1.025 .19579 10 6 ]
[.32877 .08123 -24 -4.5 ]
[.32877 .08123 0 4.5 ]
[.32877 .31035 -18 -4.5 ]
[.32877 .31035 0 4.5 ]
[.32877 .42491 -18 -4.5 ]
[.32877 .42491 0 4.5 ]
[.32877 .53946 -18 -4.5 ]
[.32877 .53946 0 4.5 ]
[.34127 .64303 -14 0 ]
[.34127 .64303 14 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .19579 m
.0873 .20204 L
s
[(-4)] .0873 .18329 0 1 Mshowa
.21429 .19579 m
.21429 .20204 L
s
[(-2)] .21429 .18329 0 1 Mshowa
.46825 .19579 m
.46825 .20204 L
s
[(2)] .46825 .18329 0 1 Mshowa
.59524 .19579 m
.59524 .20204 L
s
[(4)] .59524 .18329 0 1 Mshowa
.72222 .19579 m
.72222 .20204 L
s
[(6)] .72222 .18329 0 1 Mshowa
.84921 .19579 m
.84921 .20204 L
s
[(8)] .84921 .18329 0 1 Mshowa
.97619 .19579 m
.97619 .20204 L
s
[(10)] .97619 .18329 0 1 Mshowa
.125 Mabswid
.11905 .19579 m
.11905 .19954 L
s
.15079 .19579 m
.15079 .19954 L
s
.18254 .19579 m
.18254 .19954 L
s
.24603 .19579 m
.24603 .19954 L
s
.27778 .19579 m
.27778 .19954 L
s
.30952 .19579 m
.30952 .19954 L
s
.37302 .19579 m
.37302 .19954 L
s
.40476 .19579 m
.40476 .19954 L
s
.43651 .19579 m
.43651 .19954 L
s
.5 .19579 m
.5 .19954 L
s
.53175 .19579 m
.53175 .19954 L
s
.56349 .19579 m
.56349 .19954 L
s
.62698 .19579 m
.62698 .19954 L
s
.65873 .19579 m
.65873 .19954 L
s
.69048 .19579 m
.69048 .19954 L
s
.75397 .19579 m
.75397 .19954 L
s
.78571 .19579 m
.78571 .19954 L
s
.81746 .19579 m
.81746 .19954 L
s
.88095 .19579 m
.88095 .19954 L
s
.9127 .19579 m
.9127 .19954 L
s
.94444 .19579 m
.94444 .19954 L
s
.05556 .19579 m
.05556 .19954 L
s
.02381 .19579 m
.02381 .19954 L
s
.25 Mabswid
0 .19579 m
1 .19579 L
s
gsave
1.025 .19579 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 .08123 m
.34752 .08123 L
s
[(-0.1)] .32877 .08123 1 0 Mshowa
.34127 .31035 m
.34752 .31035 L
s
[(0.1)] .32877 .31035 1 0 Mshowa
.34127 .42491 m
.34752 .42491 L
s
[(0.2)] .32877 .42491 1 0 Mshowa
.34127 .53946 m
.34752 .53946 L
s
[(0.3)] .32877 .53946 1 0 Mshowa
.125 Mabswid
.34127 .10414 m
.34502 .10414 L
s
.34127 .12705 m
.34502 .12705 L
s
.34127 .14996 m
.34502 .14996 L
s
.34127 .17288 m
.34502 .17288 L
s
.34127 .2187 m
.34502 .2187 L
s
.34127 .24161 m
.34502 .24161 L
s
.34127 .26452 m
.34502 .26452 L
s
.34127 .28743 m
.34502 .28743 L
s
.34127 .33326 m
.34502 .33326 L
s
.34127 .35617 m
.34502 .35617 L
s
.34127 .37908 m
.34502 .37908 L
s
.34127 .40199 m
.34502 .40199 L
s
.34127 .44782 m
.34502 .44782 L
s
.34127 .47073 m
.34502 .47073 L
s
.34127 .49364 m
.34502 .49364 L
s
.34127 .51655 m
.34502 .51655 L
s
.34127 .05832 m
.34502 .05832 L
s
.34127 .0354 m
.34502 .0354 L
s
.34127 .01249 m
.34502 .01249 L
s
.34127 .56238 m
.34502 .56238 L
s
.34127 .58529 m
.34502 .58529 L
s
.34127 .6082 m
.34502 .6082 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -75 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(g) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(H) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(L) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.006 w
.02381 .19579 m
.06244 .19579 L
.10458 .19579 L
.14415 .19579 L
.18221 .19579 L
.22272 .19579 L
.26171 .19579 L
.28158 .19579 L
.30316 .19579 L
.31323 .19579 L
.32392 .19579 L
.33304 .19579 L
.33554 .19579 L
.33823 .19579 L
.33953 .19579 L
.34076 .19579 L
.34187 .20662 L
.34309 .22806 L
.35322 .38765 L
.36276 .50021 L
.36804 .54497 L
.37102 .56453 L
.37376 .57894 L
.37607 .58845 L
.37861 .59616 L
.37989 .59897 L
.38059 .60022 L
.38126 .6012 L
.38255 .60258 L
.38373 .60323 L
.38487 .60332 L
.3861 .60283 L
.38726 .60182 L
.38832 .60044 L
.3895 .59841 L
.39079 .59561 L
.39338 .58816 L
.39595 .57856 L
.3987 .56602 L
.40364 .53808 L
.42206 .39207 L
.44197 .21456 L
.45246 .13491 L
.45819 .09876 L
.46356 .07049 L
.46873 .04863 L
.47346 .03343 L
.47616 .02682 L
.47872 .02189 L
.48142 .0181 L
Mistroke
.48294 .01659 L
.48368 .01602 L
.48436 .01558 L
.48557 .01503 L
.48687 .01472 L
.48802 .01472 L
.48924 .01496 L
.49032 .0154 L
.49134 .01599 L
.49246 .01684 L
.49365 .01798 L
.49631 .02132 L
.49883 .02546 L
.50354 .03556 L
.51322 .06416 L
.52349 .10232 L
.54192 .17597 L
.55132 .20969 L
.56143 .2395 L
.56609 .25045 L
.57098 .2599 L
.57516 .26626 L
.57972 .2714 L
.58227 .27345 L
.58361 .2743 L
.58503 .27503 L
.58627 .27553 L
.58692 .27574 L
.58763 .27592 L
.58887 .27615 L
.59003 .27625 L
.59123 .27624 L
.59253 .27609 L
.59377 .27584 L
.59491 .2755 L
.59708 .27459 L
.59937 .27327 L
.60451 .26908 L
.60933 .26376 L
.62034 .24779 L
.63879 .21529 L
.64925 .19743 L
.65899 .18306 L
.66867 .17191 L
.67408 .16722 L
.67901 .16399 L
.68171 .16262 L
.68421 .16163 L
.68695 .16082 L
.68833 .16052 L
Mistroke
.68911 .16038 L
.68985 .16027 L
.69049 .16019 L
.69119 .16013 L
.6924 .16005 L
.69309 .16003 L
.69383 .16003 L
.69515 .16008 L
.69579 .16012 L
.69648 .16019 L
.69774 .16034 L
.69897 .16055 L
.7001 .16078 L
.70256 .16141 L
.7048 .16215 L
.70985 .1643 L
.71894 .16961 L
.73961 .18538 L
.74965 .19316 L
.76032 .20043 L
.76943 .20539 L
.77461 .20759 L
.77947 .20923 L
.78417 .21041 L
.78653 .21085 L
.78911 .21123 L
.79132 .21146 L
.79256 .21155 L
.79368 .21161 L
.79473 .21165 L
.79587 .21167 L
.79694 .21167 L
.79793 .21166 L
.79908 .21162 L
.80031 .21156 L
.80147 .21149 L
.80254 .2114 L
.80513 .21112 L
.8076 .21077 L
.81249 .20986 L
.81782 .20858 L
.8392 .20163 L
.85854 .1951 L
.86825 .19246 L
.87336 .19133 L
.87874 .19036 L
.88347 .18969 L
.88597 .18941 L
.88865 .18916 L
.89111 .18898 L
Mistroke
.89335 .18886 L
.89444 .18882 L
.89561 .18878 L
.89672 .18876 L
.89774 .18874 L
.89899 .18873 L
.90017 .18873 L
.90124 .18874 L
.9024 .18876 L
.90365 .18879 L
.90499 .18883 L
.9074 .18894 L
.90985 .18908 L
.91215 .18925 L
.91646 .18963 L
.92636 .19081 L
.93708 .19239 L
.97619 .19775 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Ha000`40O003h00O_Goo00<007ooOol0
ogooPGoo002mOol00`00Oomoo`3oOon1Ool00;eoo`03001oogoo0?mooh5oo`00_Goo00<007ooOol0
ogooPGoo002mOol00`00Oomoo`3oOon1Ool00;eoo`03001oogoo0?mooh5oo`00_Goo0`00AWoo1@00
ogoo=Woo002mOol00`00Oomoo`15Ool8003oOoldOol00;eoo`03001oogoo04Aoo`T00?moocAoo`00
_Goo00<007ooOol0A7oo2P00ogoo<goo002mOol00`00Oomoo`13Ool40003Ool5003oOolbOol00;eo
o`03001oogoo049oo`D000Aoo`@00?mooc9oo`00_Goo00<007ooOol0@Goo1@001Woo1000ogoo<Goo
002mOol00`00Oomoo`11Ool40007Ool4003oOolaOol00;eoo`03001oogoo045oo`<000Uoo`@00?mo
oc1oo`00_Goo00<007ooOol0@7oo10002Goo1000ogoo<7oo002mOol00`00Oomoo`10Ool4000:Ool3
003oOol`Ool00;eoo`03001oogoo041oo`<000]oo`@00?moobmoo`00_Goo0`00?goo10002goo1000
ogoo;goo002mOol00`00Oomoo`0oOol4000<Ool4003oOol^Ool00;eoo`03001oogoo03moo`<000eo
o`@00?moobioo`00_Goo00<007ooOol0?Woo10003Woo0`00ogoo;Woo002mOol00`00Oomoo`0nOol4
000>Ool4003oOol]Ool00;eoo`03001oogoo03ioo`<000moo`@00?moobeoo`00_Goo00<007ooOol0
?Goo100047oo0`00ogoo;Goo002mOol00`00Oomoo`0mOol4000@Ool4003oOol/Ool00;eoo`03001o
ogoo03eoo`<0015oo`@00?moobaoo`00_Goo00<007ooOol0?Goo0`004Woo0`00ogoo;7oo002mOol0
0`00Oomoo`0lOol4000BOol4003oOol[Ool00;eoo`03001oogoo03aoo`@0019oo`@00?moob]oo`00
_Goo0`00?7oo0`0057oo0`00ogoo:goo002mOol00`00Oomoo`0lOol3000DOol4003oOolZOol00;eo
o`03001oogoo03aoo`<001Aoo`@00?moobYoo`00_Goo00<007ooOol0>goo10005Goo0`00ogoo:Woo
002mOol00`00Oomoo`0kOol4000EOol3003oOolZOol00;eoo`03001oogoo03]oo`<001Ioo`@00?mo
obUoo`00_Goo00<007ooOol0>goo0`005Woo1000ogoo:Goo002FOol40008Ool30008Ool70009Ool0
0`00Oomoo`0kOol3000GOol3003oOolYOol009Eoo`03001oogoo009oo`03001oogoo00Eoo`<000]o
o`03001oogoo00Yoo`03001oogoo03Yoo`@001Moo`@00?moobQoo`00UGoo00<007ooOol00Woo00<0
07ooOol01Goo0`002goo00<007ooOol02Woo00<007ooOol0>Woo10005goo1000ogoo:7oo002DOol0
0`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`0jOol3000IOol3003oOolX
Ool008Qoo`T000=oo`03001oogoo00Aoo`03001oogoo019oo`03001oogoo00Yoo`@003Uoo`<001Uo
o`@00?moobMoo`00R7oo2@000goo00<007ooOol017oo00<007ooOol04Woo00<007ooOol02Woo00<0
07ooOol0>Woo0`006Goo1000ogoo9goo002DOol00`00Oomoo`04Ool00`00Oomoo`0BOol00`00Oomo
o`0:Ool00`00Oomoo`0iOol4000JOol3003oOolWOol009Aoo`03001oogoo00Aoo`03001oogoo019o
o`03001oogoo00Yoo`03001oogoo03Uoo`@001Yoo`@00?moobIoo`00U7oo00<007ooOol017oo00<0
07ooOol04Woo00<007ooOol02Woo00<007ooOol0>Goo0`006goo1000ogoo9Woo002EOol00`00Oomo
o`02Ool00`00Oomoo`0COol00`00Oomoo`0:Ool00`00Oomoo`0iOol3000LOol3003oOolVOol009Eo
o`03001oogoo009oo`03001oogoo011oo`@000aoo`03001oogoo03Uoo`<001aoo`@00?moobEoo`00
UWoo10005Goo0P0037oo00<007ooOol0>7oo100077oo1000ogoo9Goo002mOol00`00Oomoo`0hOol4
000MOol3003oOolUOol00;eoo`03001oogoo03Qoo`<001ioo`@00?moobAoo`00_Goo00<007ooOol0
>7oo0`007Woo1000ogoo97oo002mOol00`00Oomoo`0hOol3000OOol3003oOolTOol00;eoo`<003Mo
o`@001moo`<00?moobAoo`00_Goo00<007ooOol0=goo10007goo1000ogoo8goo002mOol00`00Oomo
o`0gOol3000POol4003oOolSOol00;eoo`03001oogoo03Moo`<0025oo`<00?moob=oo`00_Goo00<0
07ooOol0=goo0`008Goo0`00ogoo8goo002mOol00`00Oomoo`0gOol3000QOol4003oOolROol00;eo
o`03001oogoo03Ioo`@0025oo`@00?moob9oo`00_Goo00<007ooOol0=Woo10008Woo0`00ogoo8Woo
002mOol00`00Oomoo`0fOol3000SOol3003oOolROol00;eoo`03001oogoo03Ioo`<002=oo`<00?mo
ob9oo`00_Goo00<007ooOol0=Woo0`008goo1000ogoo8Goo002mOol00`00Oomoo`0fOol3000SOol4
003oOolQOol00;eoo`<003Ioo`<002Aoo`<00?moob5oo`00_Goo00<007ooOol0=Goo100097oo0`00
ogoo8Goo002mOol00`00Oomoo`0eOol4000TOol4003oOolPOol00;eoo`03001oogoo03Eoo`<002Eo
o`@00?moob1oo`00_Goo00<007ooOol0=Goo0`009Woo0`00ogoo87oo002mOol00`00Oomoo`0eOol3
000VOol3003oOolPOol00;eoo`03001oogoo03Eoo`<002Ioo`@00?mooamoo`00_Goo00<007ooOol0
=Goo0`009Woo1000ogoo7goo002mOol00`00Oomoo`0dOol4000WOol3003oOolOOol00;eoo`03001o
ogoo03Aoo`@002Moo`<00?mooamoo`00_Goo00<007ooOol0=7oo0`00:7oo1000ogoo7Woo002mOol0
0`00Oomoo`0dOol3000XOol4003oOolNOol00;eoo`<003Aoo`<002Uoo`<00?mooaioo`00_Goo00<0
07ooOol0=7oo0`00:Goo0`00ogoo7Woo002mOol00`00Oomoo`0dOol3000YOol4003oOolMOol0041o
o`D003Uoo`P003Moo`03001oogoo03Aoo`<000=oo`P001ioo`@001aoo`D003Yoo`@003eoo`@003Mo
o`L000Ioo`@003Aoo`00@Woo00<007ooOol0>Woo00<007ooOol00goo00<007ooOol0=Goo00<007oo
Ool0<goo100017oo00<007ooOol00goo00<007ooOol07Goo0`007Woo00<007ooOol0:7oo2`001Woo
00<007ooOol00Woo00<007ooOol0>Goo00<007ooOol00Woo00<007ooOol0=goo00<007ooOol01Woo
00<007ooOol00Woo00<007ooOol0<Goo0012Ool00`00Oomoo`0kOol00`00Oomoo`0jOol00`00Oomo
o`0cOol40005Ool00`00Oomoo`0ROol3000NOol00`00Oomoo`0VOolA00000goo001oo`05Ool00`00
Oomoo`0gOol00`00Oomoo`04Ool00`00Oomoo`0fOol00`00Oomoo`06Ool00`00Oomoo`02Ool00`00
Oomoo`0aOol003aoo`T003aoo`03001oogoo03Uoo`03001oogoo03=oo`<000Moo`03001oogoo025o
o`<001Qoo`T002AooaD000Ioo`03001oogoo03Moo`03001oogoo00Aoo`03001oogoo03Ioo`03001o
ogoo00Eoo`03001oogoo00Aoo`03001oogoo031oo`00<7oo2@0017oo00<007ooOol00Woo00<007oo
Ool0;Goo2@001goo00<007ooOol0>7oo00<007ooOol0<goo0`0027oo00<007ooOol087oo100067oo
00<007ooOol00Woo00<007ooOol08goo1`001goo2@001Goo00<007ooOol0=goo00<007ooOol017oo
00<007ooOol0=Woo00<007ooOol01Goo00<007ooOol017oo00<007ooOol0<7oo000`Ool90004Ool0
0`00Oomoo`02Ool00`00Oomoo`0]Ool90008Ool00`00Oomoo`0gOol00`00Oomoo`0cOol30009Ool0
0`00Oomoo`0OOol4000HOol00`00Oomoo`02Ool00`00Oomoo`0QOol7000=Ool60004Ool00`00Oomo
o`0hOol00`00Oomoo`02Ool00`00Oomoo`0gOol00`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomo
o`0`Ool003ioo`05001oogooOol00011Ool00`00Oomoo`0fOol00`00Oomoo`0cOol3000:Ool00`00
Oomoo`0OOol3000IOol01@00Oomoogoo00008Woo1P004Goo1P0000=oo`00Ool0>Woo1P00>Goo00<0
07ooOol01Goo00<007ooOol017oo00<007ooOol0<7oo000oOol01000Oomoo`00@Woo00<007ooOol0
=Goo00<007ooOol0<goo0`002goo00<007ooOol07Woo0`006Woo00@007ooOol0025oo`H001=oo`H0
03aoo`03001oogoo009oo`03001oogoo03Moo`03001oogoo00Eoo`03001oogoo00Aoo`03001oogoo
031oo`00?goo00@007ooOol0049oo`03001oogoo03Eoo`03001oogoo03=oo`<000]oo`03001oogoo
01ioo`@001Uoo`04001oogoo000QOol4000FOol6000jOol00`00Oomoo`04Ool00`00Oomoo`0fOol0
0`00Oomoo`05Ool00`00Oomoo`04Ool00`00Oomoo`0`Ool0041oo`03001oo`0003aoo`03001oogoo
00=oo`03001oogoo03Eoo`<0039oo`@000Eoo`03001oogoo00=oo`03001oogoo01ioo`@001Yoo`03
001oo`00021oo`@001Moo`03001oo`0000D003Qoo`03001oogoo00Aoo`03001oogoo03Ioo`03001o
ogoo00Ioo`03001oogoo009oo`03001oogoo035oo`00@Goo0P00?7oo0P000goo00<007ooOol0=Woo
00<007ooOol0<Woo10001Goo0P000goo00<007ooOol087oo0`006goo0P007goo1@0067oo2000>7oo
00<007ooOol00Woo00<007ooOol0=7oo100027oo00<007ooOol00Woo00<007ooOol0<Goo0011Ool2
000nOol3000iOol00`00Oomoo`0bOol30008Ool3000SOol3000KOol2000NOol5000KOol8000gOol4
000iOol20009Ool4000dOol00;eoo`03001oogoo039oo`<002ioo`@003Uoo`D001moo`H00;Ioo`00
_Goo00<007ooOol0<Woo0`00;Woo1000>7oo1@008Goo1P00]Goo002mOol00`00Oomoo`0bOol3000_
Ool3000hOol4000TOol6002cOol00;eoo`03001oogoo039oo`<002moo`@003Ioo`@002Ioo`H009Mo
o`D001Ioo`00_Goo00<007ooOol0<Woo0`00;goo1000=Goo1@009goo1P00@goo6000>Woo00<007oo
Ool00goo0P0057oo002mOol00`00Oomoo`0bOol3000`Ool3000dOol5000ZOol5000mOolR000eOol0
0`00Oomoo`0IOol00;eoo`03001oogoo035oo`@0031oo`<003Aoo`@002aoo`H003Moobd002ioo`03
001oogoo01Uoo`006GooYP00<Woo1000<7oo1000<Woo1000;Woo1P00<Goo400057oo6@008goo00<0
07ooOol06Goo000=Oooo003o0006000COol00`00Oomoo`0IOol001UoojH000ioo`03001oogoo00io
o`03001oogoo00eoo`03001oogoo00<000Yoo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo
00Aoo`<000Ioo`03001oogoo00ioo`03001oogoo00eoo`03001oogoo00Moo`@0009oo`03001oogoo
00ioo`03001oogoo00eoo`03001oogoo00aoo`H000aoo`03001oogoo00eoo`03001oogoo00Uoo`d0
00Qoo`03001oogoo00eoo`03001oogoo00eooa<001ioo`03001oogoo01Uoo`006Woo00<007ooOol0
3Goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol0
3Woo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol03Woo00<007ooOol037oo0`003Woo00<0
07ooOol03Woo00<007ooOol03Goo00<007ooOol00`002Woo00<007ooOol03Woo00<007ooOol03Goo
00<007ooOol017oo0`001Woo00<007ooOol03Woo00<007ooOol03Goo00<007ooOol01Woo10000goo
00<007ooOol03Woo00<007ooOol03Goo00<007ooOol03Goo1`002Woo00<007ooOol03Goo00<007oo
Ool01Woo2`003Goo00<007ooOol03Goo00<007ooOol03Goo00<007ooOol02Goo1`0077oo20005Woo
000jOol00`00Oomoo`0oOol00`00Oomoo`0mOol3000bOol3000:Ool00`00Oomoo`0UOol4000FOol0
0`00Oomoo`0FOol4000TOol00`00Oomoo`0?Ool7000NOol;0011Ool00`00Oomoo`0MOol00`00Oomo
o`0IOol003Yoo`03001oogoo03moo`03001oogoo03eoo`<0039oo`<000Yoo`03001oogoo02Eoo`@0
01Ioo`03001oogoo01Eoo`@002Eoo`03001oogoo011oo`T001Qoo`/0009oo`03001oogoo03moo`03
001oogoo01eoo`03001oogoo01Uoo`00_7oo0`00<Woo0`00<goo0`00;Goo1@00>Woo2@004goo2`00
Igoo00<007ooOol06Goo002lOol3000aOol4000cOol4000/Ool4000mOol:000>Ool:0026Ool00;ao
o`<0035oo`@003=oo`@002]oo`@0045oo``00003Ool0000000d008Uoo`00_7oo0`00<Goo0`00=Goo
0`00:goo1000@goo5`00S7oo002lOol3000aOol3000eOol4000YOol40017OolB002>Ool00;aoo`<0
035oo`<003Eoo`@002Uoo`@004aoo`D009Ioo`00_7oo1000<7oo0`00=Woo0`00:7oo1000j7oo002l
Ool4000`Ool3000fOol4000WOol4003XOol00;eoo`<0031oo`<003Ioo`@002Ioo`@00>Uoo`00_Goo
0`00;goo1000=goo0`009Goo1@00jGoo002mOol3000_Ool4000gOol4000TOol4003ZOol00;eoo`<0
02moo`<003Qoo`@002=oo`@00>]oo`00_Goo0`00;goo0`00>Goo0`008goo1000jgoo002mOol3000_
Ool3000iOol4000QOol4003/Ool00;eoo`<002moo`<003Uoo`@0021oo`D00>aoo`00_Goo0`00;goo
0`00>Woo0`0087oo1000kGoo002mOol3000_Ool3000jOol4000NOol4003^Ool00;eoo`<002ioo`@0
03Yoo`@001ioo`@00>ioo`00_Goo0`00;Woo1000>goo0`007Goo1000kgoo002mOol3000^Ool3000l
Ool4000KOol5003_Ool00;eoo`@002eoo`<003aoo`D001Yoo`@00?1oo`00_Goo1000;Goo0`00?Goo
10006Goo1000lGoo002mOol4000]Ool3000nOol4000HOol4003aOol00;eoo`@002eoo`<003ioo`@0
01Moo`@00?9oo`00_Goo1000;Goo0`00?goo10005Goo1@00lWoo002mOol4000]Ool3000oOol4000E
Ool4003cOol00;eoo`@002aoo`@0041oo`<001Aoo`@00?Aoo`00_Goo1000;7oo1000@7oo10004goo
1000m7oo002mOol4000/Ool30011Ool4000BOol4003eOol00;eoo`@002aoo`<0049oo`@0011oo`D0
0?Eoo`00_Goo1000;7oo0`00@Woo10003goo1@00mWoo002mOol4000/Ool30013Ool5000<Ool5003g
Ool00;eoo`@002aoo`<004=oo`H000Yoo`D00?Qoo`00_Goo1000;7oo0`00A7oo1P0027oo1@00nGoo
002mOol4000[Ool40016Ool50006Ool5003jOol00;eoo`@002]oo`@004Moo`H00003Ool0000000D0
0?]oo`00_Goo1000:goo0`00BGoo3000o7oo002mOol5000ZOol3001:Ool:003mOol00;eoo`D002Yo
o`<004]oo`L00?moo`00_Goo00<007oo00000P00:Woo0`00ogooDWoo002mOol00`00Ool00002000Z
Ool3003oOomBOol00;eoo`03001oo`00008002Yoo`<00?mooe9oo`00_Goo00<007oo00000P00:Goo
1000ogooDWoo002mOol5000YOol4003oOomBOol00;eoo`03001oo`00008002Uoo`<00?mooe=oo`00
_Goo00<007oo00000P00:Goo0`00ogooDgoo002mOol00`00Ool00002000YOol3003oOomCOol00;eo
o`03001oo`00008002Uoo`<00?mooe=oo`00_Goo00<007oo00000P00:Goo0`00ogooDgoo002mOol0
0`00Ool00002000YOol3003oOomCOol009Ioo`@000Qoo`<000Qoo`L000Uoo`03001oo`00008002Qo
o`@00?mooe=oo`00UGoo00<007ooOol00Woo00<007ooOol01Goo0`002goo00<007ooOol02Woo00<0
07oo00000P00:7oo1000ogooDgoo002EOol00`00Oomoo`02Ool00`00Oomoo`05Ool3000;Ool00`00
Oomoo`0:Ool00`00Ool00002000XOol3003oOomDOol009Aoo`03001oogoo00Aoo`03001oogoo019o
o`03001oogoo00Yoo`03001oo`0000<002Moo`<00?mooeAoo`00U7oo00<007ooOol017oo00<007oo
Ool04Woo00<007ooOol02Woo1P009goo0`00ogooE7oo002DOol00`00Oomoo`04Ool00`00Oomoo`0B
Ool00`00Oomoo`0:Ool00`00Oomoo`03000WOol3003oOomDOol009Aoo`03001oogoo00Aoo`03001o
ogoo019oo`03001oogoo00Yoo`03001oogoo00<002Moo`<00?mooeAoo`00U7oo00<007ooOol017oo
00<007ooOol04Woo00<007ooOol02Woo00<007ooOol00`009goo0`00ogooE7oo002DOol00`00Oomo
o`04Ool00`00Oomoo`0BOol00`00Oomoo`0:Ool00`00Oomoo`03000WOol3003oOomDOol009Eoo`03
001oogoo009oo`03001oogoo01=oo`03001oogoo00Yoo`03001oogoo00<002Ioo`@00?mooeAoo`00
UGoo00<007ooOol00Woo00<007ooOol047oo100037oo00<007ooOol00`009Woo1000ogooE7oo002F
Ool4000EOol2000<Ool00`00Oomoo`03000VOol3003oOomEOol00;eoo`03001oogoo00<002Ioo`<0
0?mooeEoo`00_Goo00<007ooOol00`009Woo0`00ogooEGoo002mOol00`00Oomoo`03000VOol3003o
OomEOol00;eoo`03001oogoo00<002Ioo`<00?mooeEoo`00_Goo1P009Woo0`00ogooEGoo002mOol0
0`00Oomoo`03000UOol4003oOomEOol00;eoo`03001oogoo00<002Eoo`@00?mooeEoo`00_Goo00<0
07ooOol0100097oo0`00ogooEWoo002mOol00`00Oomoo`04000TOol3003oOomFOol00;eoo`04001o
ogooOol3000TOol3003oOomFOol00;eoo`04001oogooOol3000TOol3003oOomFOol00;eoo`04001o
ogooOol3000TOol3003oOomFOol00;eoo`04001oogooOol3000TOol3003oOomFOol00;eoo`04001o
ogooOol3000SOol4003oOomFOol00;eoo`04001oogooOol3000SOol4003oOomFOol00;eoo`04001o
ogooOol3000SOol3003oOomGOol00;eoo`<00004Ool00000000SOol3003oOomGOol00;eoo`04001o
ogooOol3000SOol3003oOomGOol00;eoo`04001oogooOol3000SOol3003oOomGOol00;eoo`04001o
ogooOol3000SOol3003oOomGOol00;eoo`04001oogooOol3000SOol3003oOomGOol00;eoo`04001o
ogooOol3000SOol3003oOomGOol00;eoo`04001oogooOol3000ROol4003oOomGOol00;eoo`04001o
ogooOol3000ROol4003oOomGOol00;eoo`04001oogooOol4000QOol3003oOomHOol00;eoo`04001o
ogooOol4000QOol3003oOomHOol00;eoo`03001oogoo009oo`<0025oo`<00?mooeQoo`00_Goo00<0
07ooOol00Woo0`008Goo0`00ogooF7oo002mOol30002Ool3000QOol3003oOomHOol00;eoo`03001o
ogoo009oo`<0025oo`<00?mooeQoo`00_Goo00<007ooOol00Woo0`0087oo1000ogooF7oo002mOol0
0`00Oomoo`02Ool3000POol4003oOomHOol00;eoo`03001oogoo009oo`<0021oo`<00?mooeUoo`00
_Goo00<007ooOol00Woo0`0087oo0`00ogooFGoo002mOol00`00Oomoo`02Ool3000POol3003oOomI
Ool00;eoo`03001oogoo009oo`<0021oo`<00?mooeUoo`00_Goo00<007ooOol00Woo0`0087oo0`00
ogooFGoo002mOol00`00Oomoo`02Ool3000POol3003oOomIOol00;eoo`03001oogoo009oo`@001io
o`@00?mooeUoo`00_Goo0`000Woo10007Woo1000ogooFGoo002mOol00`00Oomoo`03Ool3000NOol3
003oOomJOol00;eoo`03001oogoo00=oo`<001ioo`<00?mooeYoo`00_Goo00<007ooOol00goo0`00
7Woo0`00ogooFWoo002mOol00`00Oomoo`03Ool3000NOol3003oOomJOol00;eoo`03001oogoo00=o
o`<001ioo`<00?mooeYoo`00_Goo00<007ooOol00goo0`007Woo0`00ogooFWoo002mOol00`00Oomo
o`03Ool3000MOol4003oOomJOol009Ioo`@000Qoo`<000Moo`P000Uoo`03001oogoo00=oo`<001eo
o`@00?mooeYoo`00UGoo00<007ooOol00Woo00<007ooOol01Goo0`0027oo00<007ooOol00goo00<0
07ooOol01goo00<007ooOol00goo0`007Goo0`00ogooFgoo002EOol00`00Oomoo`02Ool00`00Oomo
o`05Ool30009Ool00`00Oomoo`0<Ool00`00Oomoo`03Ool4000LOol3003oOomKOol009Aoo`03001o
ogoo00Aoo`03001oogoo015oo`03001oogoo00]oo`03001oogoo00=oo`@001aoo`<00?mooe]oo`00
U7oo00<007ooOol017oo00<007ooOol04Woo00<007ooOol02Woo10000goo0`0077oo0`00ogooFgoo
002DOol00`00Oomoo`04Ool00`00Oomoo`0COol00`00Oomoo`09Ool00`00Oomoo`04Ool3000LOol3
003oOomKOol009Aoo`03001oogoo00Aoo`03001oogoo01Aoo`03001oogoo00Qoo`03001oogoo00Ao
o`<001aoo`<00?mooe]oo`00U7oo00<007ooOol017oo00<007ooOol05Goo00<007ooOol01goo00<0
07ooOol017oo0`0077oo0`00ogooFgoo002DOol00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomo
o`07Ool00`00Oomoo`04Ool3000KOol4003oOomKOol009Eoo`03001oogoo009oo`03001oogoo011o
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Aoo`<001]oo`@00?mooe]oo`00UGoo00<0
07ooOol00Woo00<007ooOol047oo0P000goo00<007ooOol027oo00<007ooOol017oo0`006goo0`00
ogooG7oo002FOol4000EOol3000;Ool00`00Oomoo`04Ool3000KOol3003oOomLOol00;eoo`03001o
ogoo00Aoo`<001]oo`<00?mooeaoo`00_Goo00<007ooOol017oo0`006goo0`00ogooG7oo002mOol0
0`00Oomoo`04Ool4000JOol3003oOomLOol00;eoo`03001oogoo00Aoo`@001Yoo`<00?mooeaoo`00
_Goo0`001Goo0`006Goo1000ogooG7oo002mOol00`00Oomoo`05Ool3000IOol4003oOomLOol00;eo
o`03001oogoo00Eoo`<001Uoo`<00?mooeeoo`00_Goo00<007ooOol01Goo0`006Goo0`00ogooGGoo
002mOol00`00Oomoo`05Ool3000IOol3003oOomMOol00;eoo`03001oogoo00Eoo`<001Uoo`<00?mo
oeeoo`00_Goo00<007ooOol01Goo0`006Goo0`00ogooGGoo002mOol00`00Oomoo`05Ool3000IOol3
003oOomMOol00;eoo`03001oogoo00Eoo`<001Qoo`@00?mooeeoo`00_Goo00<007ooOol01Goo0`00
67oo1000ogooGGoo002mOol00`00Oomoo`05Ool4000GOol3003oOomNOol00;eoo`03001oogoo00Eo
o`@001Moo`<00?mooeioo`00_Goo0`001Woo0`005goo0`00ogooGWoo002mOol00`00Oomoo`06Ool3
000GOol3003oOomNOol00;eoo`03001oogoo00Ioo`<001Moo`<00?mooeioo`00_Goo00<007ooOol0
1Woo0`005goo0`00ogooGWoo002mOol00`00Oomoo`06Ool3000GOol3003oOomNOol00;eoo`03001o
ogoo00Ioo`<001Ioo`@00?mooeioo`00_Goo00<007ooOol01Woo0`005Woo1000ogooGWoo002mOol0
0`00Oomoo`06Ool3000FOol3003oOomOOol00;eoo`03001oogoo00Ioo`<001Ioo`<00?mooemoo`00
_Goo00<007ooOol01Woo10005Goo0`00ogooGgoo002mOol00`00Oomoo`06Ool4000EOol3003oOomO
Ool00;eoo`03001oogoo00Moo`<001Eoo`<00?mooemoo`00_Goo0`001goo0`005Goo0`00ogooGgoo
002mOol00`00Oomoo`07Ool3000DOol4003oOomOOol00;eoo`03001oogoo00Moo`<001Aoo`@00?mo
oemoo`00_Goo00<007ooOol01goo0`0057oo0`00ogooH7oo002mOol00`00Oomoo`07Ool3000DOol3
003oOomPOol00;eoo`03001oogoo00Moo`<001Aoo`<00?moof1oo`00_Goo00<007ooOol01goo0`00
57oo0`00ogooH7oo002mOol00`00Oomoo`07Ool4000COol3003oOomPOol00;eoo`03001oogoo00Mo
o`@001=oo`<00?moof1oo`00_Goo00<007ooOol027oo0`004Woo1000ogooH7oo002mOol00`00Oomo
o`08Ool3000BOol4003oOomPOol00;eoo`<000Qoo`<0019oo`<00?moof5oo`00_Goo00<007ooOol0
27oo0`004Woo0`00ogooHGoo002mOol00`00Oomoo`08Ool3000BOol3003oOomQOol00;eoo`03001o
ogoo00Qoo`@0015oo`<00?moof5oo`00_Goo00<007ooOol027oo10004Goo0`00ogooHGoo002mOol0
0`00Oomoo`09Ool3000AOol3003oOomQOol00;eoo`03001oogoo00Uoo`<0015oo`<00?moof5oo`00
_Goo00<007ooOol02Goo0`0047oo1000ogooHGoo002FOol40008Ool30009Ool4000;Ool00`00Oomo
o`09Ool3000@Ool4003oOomQOol009Eoo`03001oogoo009oo`03001oogoo00Eoo`<000Qoo`03001o
ogoo009oo`03001oogoo00Qoo`03001oogoo00Uoo`<0011oo`<00?moof9oo`00UGoo00<007ooOol0
0Woo00<007ooOol01Goo0`001goo00<007ooOol017oo00<007ooOol01goo00<007ooOol02Goo0`00
47oo0`00ogooHWoo002DOol00`00Oomoo`04Ool00`00Oomoo`0EOol00`00Oomoo`07Ool00`00Oomo
o`09Ool4000?Ool3003oOomROol009Aoo`03001oogoo00Aoo`03001oogoo01Eoo`03001oogoo00Mo
o`@000Qoo`@000moo`<00?moof9oo`00U7oo00<007ooOol017oo00<007ooOol057oo00<007ooOol0
27oo00<007ooOol02Woo0`003Woo1000ogooHWoo002DOol00`00Oomoo`04Ool00`00Oomoo`0AOol3
000;Ool00`00Oomoo`0:Ool3000>Ool4003oOomROol009Aoo`03001oogoo00Aoo`03001oogoo01Ao
o`03001oogoo00Qoo`03001oogoo00Yoo`<000ioo`<00?moof=oo`00U7oo00<007ooOol017oo00<0
07ooOol05Goo00<007ooOol01goo00<007ooOol02Woo0`003Woo0`00ogooHgoo002EOol00`00Oomo
o`02Ool00`00Oomoo`0FOol00`00Oomoo`07Ool00`00Oomoo`0:Ool3000>Ool3003oOomSOol009Eo
o`03001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00Yo
o`<000eoo`@00?moof=oo`00UWoo100057oo10002goo00<007ooOol02Woo0`003Goo1000ogooHgoo
002mOol00`00Oomoo`0:Ool4000<Ool3003oOomTOol00;eoo`03001oogoo00Yoo`@000aoo`<00?mo
ofAoo`00_Goo00<007ooOol02goo0`0037oo0`00ogooI7oo002mOol00`00Oomoo`0;Ool3000;Ool4
003oOomTOol00;eoo`<000]oo`<000]oo`@00?moofAoo`00_Goo00<007ooOol02goo0`002goo0`00
ogooIGoo002mOol00`00Oomoo`0;Ool3000;Ool3003oOomUOol00;eoo`03001oogoo00]oo`@000Yo
o`<00?moofEoo`00_Goo00<007ooOol02goo10002Woo0`00ogooIGoo002mOol00`00Oomoo`0<Ool3
0009Ool4003oOomUOol00;eoo`03001oogoo00aoo`<000Uoo`@00?moofEoo`00_Goo00<007ooOol0
37oo100027oo0`00ogooIWoo002mOol00`00Oomoo`0<Ool40008Ool3003oOomVOol00;eoo`03001o
ogoo00eoo`<000Qoo`<00?moofIoo`00_Goo00<007ooOol03Goo0`001goo1000ogooIWoo002mOol0
0`00Oomoo`0=Ool40006Ool4003oOomVOol00;eoo`<000eoo`@000Ioo`<00?moofMoo`00_Goo00<0
07ooOol03Woo0`001Woo0`00ogooIgoo002mOol00`00Oomoo`0>Ool30005Ool4003oOomWOol00;eo
o`03001oogoo00ioo`@000Aoo`@00?moofMoo`00_Goo00<007ooOol03Woo10000goo1000ogooJ7oo
002mOol00`00Oomoo`0?Ool30003Ool4003oOomXOol00;eoo`03001oogoo00moo`@0009oo`<00?mo
ofUoo`00_Goo00<007ooOol03goo100000=oo`0000000P00ogooJGoo002mOol00`00Oomoo`0@Ool8
003oOomYOol00;eoo`03001oogoo011oo`L00?moofYoo`00_Goo00<007ooOol04Goo1@00ogooJgoo
002mOol00`00Oomoo`3oOon1Ool00;eoo`<00?mooh5oo`00_Goo00<007ooOol0ogooPGoo002mOol0
0`00Oomoo`3oOon1Ool00;eoo`03001oogoo0?mooh5oo`00_Goo00<007ooOol0ogooPGoo002mOol0
0`00Oomoo`3oOon1Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00
ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomo
od9oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogooogoo@Woo002XOol5000=Ool0
0`00Oomoo`0>Ool00`00Oomoo`3oOomcOol00:eoo`03001oogoo00Uoo`03001oogoo011oo`03001o
ogoo0?moog9oo`00[Woo00<007ooOol027oo00<007ooOol047oo00<007ooOol0ogooLWoo002^Ool0
0`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`3oOomaOol00:Uoo`<0009oo`03001oogoo00Mo
o`03001oogoo00Ioo`D000Moo`03001oogoo0?moog5oo`00Ygoo0P000goo0`0027oo00<007ooOol0
1Woo00<007ooOol00goo0P001Woo00<007ooOol0ogooL7oo002WOol00`00Oomoo`03Ool20008Ool0
0`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3oOom`Ool00:Ioo`03001oogoo00Eoo`03001o
ogoo00Ioo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?moog1oo`00YWoo00<007ooOol0
1Goo00<007ooOol01Woo00<007ooOol01Woo00<007ooOol02goo00<007ooOol0ogooL7oo002VOol0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`0;Ool00`00Oomoo`3oOom`
Ool00:Moo`03001oogoo00=oo`8000Qoo`03001oogoo00Ioo`03001oogoo00]oo`03001oogoo0?mo
og1oo`00Ygoo0P000goo0`0027oo00<007ooOol017oo200027oo00<007ooOol0ogooL7oo002YOol3
0002Ool20008Ool00`00Oomoo`05Ool00`00Oomoo`0:Ool00`00Oomoo`3oOomaOol00;Qoo`03001o
ogoo00Eoo`03001oogoo00Yoo`03001oogoo0?moog5oo`00^Goo00<007ooOol017oo00<007ooOol0
2Goo00<007ooOol0ogooLWoo002iOol00`00Oomoo`0@Ool00`00Oomoo`3oOombOol00;Yoo`03001o
ogoo00ioo`03001oogoo0?moog=oo`00ogooogoo@Woo003oOoooOom2Ool00?mooomood9oo`00ogoo
ogoo@Woo003oOoooOom2Ool00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.875, 0}} -> {-5, 0, 0, 0}}],

Cell[TextData[{
  "Fig. 2.11  Green's function for the linear oscillator:  response  to a \
\[Delta]-function force. Here ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = 2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\  = \ 1\)]],
  "."
}], "Caption",
  CellTags->"Fig. 2.11"],

Cell[TextData[{
  "\tOne can see that the oscillator is stationary just before ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " (referred to as ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(0\^-\),
            "TraditionalForm"]}], TraditionalForm]]],
  "), but begins moving with a finite velocity directly after the forcing, at \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(0\^+\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". What determines  the initial velocity of the oscillator?"
}], "Text"],

Cell["\<\
\tSince the oscillator is responding to a \[Delta]-function force, \
the Green's function satisfies the differential equation\
\>", "Text",
  CellTags->"i:83"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g\^\[DoublePrime] + \[Gamma]\ g\^\[Prime] + \[Omega]\
\_o\%2\ g\  = \ \[Delta](t)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.78)"],

Cell[TextData[{
  "We can determine the initial velocity by integrating this equation from ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(0\^-\),
            "TraditionalForm"]}], TraditionalForm]]],
  " to ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(0\^+\),
            "TraditionalForm"]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(0\^-\)\%\(0\^+\)\((g\^\[DoublePrime] \
+ \[Gamma]\ g\^\[Prime] + \[Omega]\_o\%2\ g)\) \[DifferentialD]t = \(\
\[Integral]\_\(0\^-\)\%\(0\^+\)\ \(\[Delta](t)\) \[DifferentialD]t = 1\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.79)"],

Cell["\<\
Applying the fundamental theorem of calculus to the derivatives on \
the left-hand side, we have\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^\[Prime]\)(\(0\^+\)) - \
\(g\^\[Prime]\)(\(0\^-\)) + \[Gamma]\ [
            g(\(0\^+\)) - 
              g(\(0\^-\))] + \(\[Omega]\_o\%2\) \
\(\[Integral]\_\(0\^-\)\%\(0\^+\)\ g \[DifferentialD]t\) = 1\)]],
  "."
}], "NE3",
  CellTags->"(2.3.80)"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)]],
  " is continuous and ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^\[Prime]\)(\(0\^-\)) = 0\)]],
  ", the only term that is nonzero on the ",
  "left-hand",
  " side is ",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^\[Prime]\)(\(0\^+\))\)]],
  ", yielding the result for the initial slope of the Green's function,"
}], "Text"],

Cell[TextData[{
  " \t",
  Cell[BoxData[
      \(TraditionalForm\`\(g\^\[Prime]\)(\(0\^+\)) = 1\)]],
  "."
}], "NE3",
  CellTags->"(2.3.81)"],

Cell[TextData[{
  "In fact, if we take the limit of the derivative of Eq. ",
  ButtonBox["(2.3.77)",
    ButtonData:>"(2.3.77)",
    ButtonStyle->"Hyperlink"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`t \[Rule] \ \(0\^+\)\)]],
  ", we can obtain Eq. ",
  ButtonBox["(2.3.81)",
    ButtonData:>"(2.3.81)",
    ButtonStyle->"Hyperlink"],
  " directly from the Green's function itself."
}], "Text"],

Cell[TextData[{
  "\tRecalling our description of the Green's function as the response of a \
tuning fork to an impulse, we can now listen to the sound of this Green's \
function. In Cell ",
  ButtonBox["2.88",
    ButtonData:>"Cell 2.88",
    ButtonStyle->"Hyperlink"],
  " we take the frequency to be a high C (2093 Hz), with a damping rate of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 4\ hz\)]],
  " :"
}], "Text",
  CellTags->"i:60"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Play[UnitStep[t] Exp[\(-2\) t] Sin[2\ Pi\ 2093\ t], {t, \(-1\), 4}, 
        PlayRange \[Rule] {\(-1\), 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.88"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.952381 0.0147151 0.588604 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% Start of sampled sound
1 string
8192 40960 8
{ currentfile 1 index readhexstring pop }
 false 1 sampledsound
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
8080808080808080808080808080808080808080808080808080808080808080808080808080
80808080808080808080808080808080808080808080FF770091FD6503A2F95409B3F24411C2
EA351BD1DF2826DDD21C34E8C41243F1B50A52F8A40563FC930275FE820186FE700397FB5F07
A8F64F0DB8EE3F15C7E53120D5D9242CE0CC193AEABE1049F2AE0959F89E056AFC8D037BFD7B
038CFB6A059DF8590AAEF24911BDEA3B1ACBE02D25D8D42132E3C61740ECB70F4FF4A80960F8
970570FB860481FB750592F96408A3F4540EB3EE4415C2E5361FCFDA292BDCCE1E38E6C01546
EEB10E56F4A10866F8910677FA800588F96F0798F65E0BA9F14F11B8EA401AC6E03224D3D526
30DEC81C3EE8BA134CEFAB0D5CF59B086DF88A077DF979078EF7690A9EF3590EAEED4916BDE5
3B1FCADB2E29D7D02336E1C21944EAB41253F0A40C63F5940973F7840883F7730994F5630CA4
F05312B3E9451AC1E13723CED62B2FDACA203CE3BC174AEBAE1159F19E0C69F58E0979F67E09
89F56E0B99F25E10A9ED4E16B8E5401EC6DC3328D2D12834DDC41E42E5B61650ECA8105FF198
0C6FF4880A7FF5780B8FF3680E9FEF5813AEE94A1ABCE13C23C9D7302ED5CB253ADFBF1C47E7
B01556EDA10F65F1920C75F3820C85F3720D95F06211A4EC5316B3E5451EC1DC3828CDD22C33
D8C6223FE1B91A4DE8AA145CEE9B0F6BF18C0D7BF27C0D8BF16C0F9AEE5D14A9E84E1AB8E141
23C5D8342DD0CD2938DBC12045E3B31853EAA51362EE951071F0860E81F1760F91EF6712A0EB
5817AEE54A1EBCDD3D27C8D33132D3C8273EDDBB1E4BE5AD1759EA9F1368EE8F1077EF801087
EF711196EC6215A5E7531BB3E14522C0D8392CCCCE2E37D6C22443DFB51C51E6A7175FEB9913
6EEE8A117DEE7A118CED6B149BE95C18AAE44E1EB7DD4127C4D43531CFC92B3CD9BD2249E1B0
1B56E7A21665EB931374ED841283ED751392EB6616A0E7581BAEE04A22BBD93D2BC7CF3235D2
C42841DBB7204EE2AA1A5CE79C166AEB8D1479EC7E1388EB6F1597E86119A5E3531FB3DD4626
BFD43A30CBCA2F3AD4BF2647DDB21F54E3A41962E8961670EA88147FEB79158EE96A179CE65C
1CAAE04E22B7D9422BC3D03734CEC52D3FD7B9244CDEAD1E59E49F1967E8911676E9821684E9
731793E7651AA1E3571FAEDC4A26BBD53E2FC6CB3439D0C02A45D9B42351DFA71D5FE499196D
E78B177BE87D178AE76E1998E4601DA6DF5323B3D9462ABFD03B33C9C6313ED3BB284ADAAF21
57E0A21C64E5941972E7861881E777198FE5691B9DE25C20AADC4F26B7D5432EC2CC3838CCC2
2E43D5B6264FDCAA205CE19C1C6AE48E1A78E6801986E5721B94E3641EA1DF5723AED94B2ABA
D13F33C5C8353DCFBD2C48D7B12554DDA42061E1971C6FE4891A7DE57B1B8BE46D1D99E16021
A6DC5326B2D5472EBECD3C37C8C33241D1B82A4DD8AC2459DE9F1F67E2921C74E3841B82E476
1C90E2681F9DDE5B24AAD84F2AB6D14332C1C8393CCBBE3046D3B32952D9A7235FDE9A1F6CE1
8C1D79E37F1C87E2711E95DF6422A2DB5727AED54B2EBACD4036C4C43640CDBA2E4BD5AE2757
DAA22264DF951F71E1871E7FE17A1E8CE06C2099DD5F24A6D8532AB2D14732BDC93D3BC7C034
45CFB52C50D6A9265CDB9C2269DF8F1F76E0821F84E0752091DE68239EDA5B27AAD54F2EB6CE
4436C0C53A3FC9BB3249D1B02B55D7A42561DC97226EDE8A207BDF7D2088DF702295DC6325A2
D7572AAED14B31B9CA413AC3C13843CBB6304ED3AB2A5AD89F2566DC922273DE852180DE7821
8DDD6B249AD95F28A6D4532EB2CE4835BCC63E3EC5BC3548CDB22E53D4A6295FD99A256BDC8D
2278DD812285DD742392DB67269ED75B2BAAD14F31B5CA4539BFC23B42C8B8334CCFAD2D58D5
A12864D9952470DC89237DDC7C238ADB6F2596D86329A2D4572EAECE4C35B8C6423DC2BD3946
CAB33251D1A82C5CD69D2768D9902575DB842482DB77258ED96B279AD65F2BA6D15331B1CA49
38BBC23F41C4B9374BCCAF3056D2A42B61D698276DD98C257ADA7F2586DA732693D766299FD3
5B2EAACE5035B4C7463CBEBE3D45C6B5354FCDAA2F5AD39F2A66D6932772D987267ED97A268B
D86E2897D5622CA2D15731ADCA4C38B7C34340C0BA3B49C8B03354CFA62E5FD39A2A6BD78E27
77D8822783D876288FD66A2A9BD35E2FA6CE5334B1C7493CBABF4044C3B6394ECAAC3258D0A1
2D64D4962A6FD68A287BD77E2887D6722A93D4662D9FD05B32AACA5038B4C4463FBDBB3E48C5
B23752CBA8315DD09D2D68D4912A74D6852980D679298CD56D2B97D2622FA3CD5735ADC74D3B
B7C04443BFB73C4CC7AE3556CDA33061D1982C6DD48C2A78D5812A84D5752B90D3692E9BCF5E
32A6CA5438B0C44A3FB9BC4147C1B33A51C8A9345BCE9F2F66D1942C71D4882B7DD47C2B89D3
712D94D165309FCD5B35AAC7513BB3C04742BCB83F4BC3AF3855C9A5335FCE9A2F6AD18F2C76
D3842C81D3782C8DD26D2F98CF6232A3CA5738ADC44E3EB6BD4546BEB43D4FC5AB3759CBA132
64CF962F6FD18B2D7AD27F2D85D2742E91D069319CCC5E35A6C7543BB0C14B42B8B9434AC0B1
3C53C6A7365DCB9D3268CF922F73D1862E7ED27B2E8AD0703095CE65339FCA5B38A9C4513EB3
BD4845BBB5414EC2AD3A57C8A33561CC98316CCF8D2F77D1822E82D0772F8ECF6C3298CC6135
A3C7573BACC14E41B5BA4649BDB23F52C3A8395BC99F3466CD943170CF892F7BD07E2F87CF73
3191CD68349CC95E38A6C4543EAFBE4C45B8B6444DBFAE3D56C5A43860C99A346ACD903175CF
853080CF7A318ACE6F3395CB65369FC75B3BA9C15141B2BB4948BAB34251C0AA3C5AC6A03764
CA96336ECD8C3179CE813184CE76328ECC6B3599C96138A3C4583EACBE4F44B4B7474CBCAF40
54C2A63B5EC79C3668CA923372CC88327DCD7D3288CC723492CA68379CC65E3BA6C15541AFBB
4C47B7B4454FBDAB3F58C3A23A62C798366CCA8E3476CC843381CC79338BCB6E3596C864399F
C45B3EA9BE5244B1B84A4BB9B04353BFA83D5CC49E3966C8943670CA8A347ACB803485CB7535
8FC96B3799C6613BA3C15840ABBB4F47B3B4484EBAAD4157C0A43C60C59A386AC8903674CA86
347ECB7C3588CA713693C767399CC45E3EA6BF5543AEB84D4AB6B14652BCA9405BC1A03B64C6
96386EC88C3678CA823582CA78368CC86E3896C5643CA0C15B40A8BC5346B0B54B4EB8AE4455
BEA53F5EC29C3B68C6923871C888367CC97E3686C8743790C66A3A99C3613EA2BF5843ABB950
4AB3B24951B9AA4359BFA23E62C3983A6BC68F3875C885377FC87B3789C7713993C5673C9CC1
5E41A5BC5646ADB64E4DB5AF4754BBA7425DC09E3D66C4943A6FC68B3879C7813883C777398D
C56D3B96C3643E9FBE5B43A8B95349B0B34C50B6AB4658BCA34060C19A3D6AC4913A73C68739
7DC77D3987C6743A90C46A3D9AC06141A2BC5946AAB6514CB2AF4A53B8A8445BBD9F4064C196
3C6DC48D3A77C6833980C67A3A8AC4703C94C2673F9DBE5E43A5B95649ADB34F4FB4AC4857B9
A4435FBE9C3F68C2933C71C4893A7AC5803A84C5763B8EC36D3D97C064419FBC5B46A8B6544C
AFB04D52B5A9475ABBA14262BF983E6BC28F3C75C4863B7EC47C3B87C3733D91C16A3F9ABE61
43A2B95948AAB4524FB1AD4B56B7A6465DBC9D4166BF953E6FC28B3C78C3823C82C3793C8BC2
703E94BF67419DBC5E46A5B7574BACB15052B3AA4959B8A24461BD9A4169C0913E72C2883D7C
C37F3C85C2753E8EC06C4097BD64449FB95C48A7B4544EAEAE4E55B4A7485CB99F4464BD9640
6DC08E3E76C2843D7FC27B3D88C1723F91BF69429ABB6146A2B7594BA9B15251B0AB4C58B6A3
4760BA9B4368BE934070C08A3E79C1813E83C1783F8CC06F4194BD67449DB95E48A4B4574EAB
AE5054B2A84B5BB7A04663BB98426BBE8F4074C0873F7DC07E3F86C075408FBE6C4297BB6446
9FB75C4BA7B25550ADAB4F57B3A5495EB89D4566BC95426FBE8C4077C0833F80C07A4089BF72
4192BC69449AB96148A2B45A4DA9AF5353AFA94D5AB4A14861B99A446ABC914272BE89407BBF
804083BF77418CBD6F4395BB66469DB75F4BA4B25850ABAC5156B1A64C5DB69E4765B996446D
BC8E4275BE85417EBE7D4187BE74428FBC6C4597B964489FB45C4DA6AF5653ADA95059B2A24B
60B79B4768BA934470BC8B4279BE824181BE7A428ABC714492BA69479AB7614BA1B25A4FA8AD
5455AEA64E5CB39F4A63B798466BBA904473BC87427CBD7F4284BD76438DBB6E4595B866499C
B45F4DA4B05852AAAA5258B0A34D5FB49C4966B895466EBB8D4477BC84437FBC7C4387BB7444
90B96B4797B6644B9FB25D4FA6AD5655ACA7515BB1A14C62B599486AB8914572BB89447ABC81
4382BB79448ABA714692B869499AB4614DA1B05B52A8AB5557ADA44F5EB29E4B65B696486DB9
8E4575BA86447DBB7E4485BA76458DB96E4795B6664B9CB25F4FA3AD5954A9A8535AAFA24E61
B39B4A68B6934770B98B4578BA834580BA7B4588B9734790B76B4998B4644D9FB05D51A5AB57
57ABA5525DB09F4D64B4984A6BB7904773B988467BBA804583B978468BB8704893B6694B9AB2
624FA1AE5B54A7A85559ACA25060B19C4C67B495496EB78D4776B985467EB97D4686B875478E
B76E4A95B4664D9CB05F51A3AB5956A9A6545CAEA04F63B2994C6AB5924971B78A4779B88247
81B87A4789B7734990B56B4B98B2644F9EAE5D53A5A95859AAA3535FAF9D4E66B2964B6DB58F
4974B787477CB87F4784B777488BB6704A93B3694D9AB06251A0AC5C56A6A6565BABA15162B0
9A4D68B3934B70B58C4977B784487FB77C4887B675498EB56D4C95B2664F9CAE6053A2A95A58
A8A4555EAD9E5064B1974D6BB3904A73B589497AB6814882B67A4989B5724B91B36B4D98B064
519EAC5E55A4A7585BA9A15361AE9B4F67B1944C6EB48D4A75B586497DB67E4984B5774A8CB4
704C93B1694F9AAE6253A0AA5C58A6A5575DAA9F5263AF984F6AB2924C71B48A4A78B5834A80
B57C4A87B4744B8EB36D4E95B066519CAC6055A2A75A5AA7A25660AC9C5166AF964E6DB28F4C
74B4884B7BB5804A82B4794B8AB3724D91B16B4F98AE64539EAA5E57A3A5595DA8A05462AD99
5169B0934E70B28C4C77B4854B7EB47D4B85B4764C8CB26F4E93AF69519AAC6255A0A85D5AA5
A3585FAA9D5365AD97506BB0904E72B2894C79B3824B81B37B4C88B3744D8FB16D5095AE6653
9CAA6057A1A65B5CA6A05662AB9A5368AE94506EB18D4D75B2864C7CB37F4C83B3784D8AB171
4F91AF6B5197AC64559DA85F59A3A35A5EA89E5564AC98526AAF914F71B18B4D78B2844D7FB2
7D4D86B2764E8DB06F5093AE695399AA63579FA65D5BA4A15861A99B5467AC95516DAF8F4F74
B1884E7AB2814D81B27A4E88B1734F8FAF6D5295AC67559BA86159A1A45C5EA69F5763AA9954
69AD935170AF8C4F76B1854E7DB17F4E84B1784F8BB0715191AD6B5397AA65579DA65F5BA2A2
5A60A79C5666AA96536CAD905172AF8A4F79B1834E80B17C4F86B075508DAE6F5293AC695599
A863599FA45E5DA49F5962A89A5568AB94526EAE8E5075AF874F7BB0804F82B07A4F89AF7351
8FAD6D5395AA67579BA6615BA0A25C5FA59D5865A997556BAC915271AE8B5077AF844F7EB07E
4F85AF77508BAE715291AB6B5597A865599DA4605DA2A05B62A69B5767A995546DAC8F5273AE
88507AAF825080AF7B5087AE75528DAC6F5493AA695799A7635A9EA25E5FA39E5A64A798566A
AA935470AC8C5276AE86517CAF7F5083AE795189AD73538FAB6D5595A867589BA5625CA0A05D
61A49B5966A896566CAB905372AD8A5278AE84517FAE7D5185AD77528BAC715491AA6B5797A7
655A9CA3605EA19E5C63A5995869A894556EAB8E5374AD87527BAD815181AD7B5287AD75538E
AB6F5593A8695899A5645C9EA15F61A29C5B65A697576BA9915571AB8B5377AD85527DAD7F52
83AD79538AAB725490A96D5795A7675A9AA3625E9F9F5E63A39A5A68A795576DA98F5573AB89
5379AC83527FAD7C5386AC76548CAA705692A86B5897A5655C9CA16160A09D5D65A498596AA7
925670AA8C5475AB86537CAC805382AC7A5488AB74558EA96E5793A6695A99A3645E9D9F5F62
A29B5C67A595586CA8905672AA8A5478AB84547EAC7E5484AB78548AAA725690A86D5995A567
5C9AA163609F9D5E64A3985B69A693586FA88E5674AA88547AAB825480AB7C5486AA76558CA9
705792A66B5A97A3665E9CA06162A09B5D66A3965A6BA6915771A98B5676AA86557CAB805482
AA7A5588A974578EA76E5993A5695C98A2645F9D9E6064A1995C68A494596DA78F5773A98956
79AA83557FAA7D5584AA78568AA8725890A66D5A95A3685D9AA063619E9C5F66A2975C6AA592
5970A78D5775A987567BAA815581AA7B5687A976578CA7705992A56B5C97A2665F9B9E62639F
9A5E68A3955B6DA5905872A78A5777A985567DA97F5683A9795789A874588EA66E5A93A3695D
98A065619C9C6165A0985D6AA3935A6FA68E5874A888577AA983567FA97D5785A877588BA772
5990A56D5C95A2685F999E63639E9A6067A1965C6CA4915A71A68C5876A886577CA8805781A8
7B5787A775598CA6705B92A36B5D96A066619B9D62649F985F69A2945C6EA48F5A73A6895878
A784577EA87E5783A7795889A6735A8EA46E5C93A2695F989F65629C9B6166A0965E6BA2925B
70A58D5975A687587AA7825880A77C5885A777598BA5725B90A36D5D95A06860999D64649D99
6068A0945D6DA3905B72A58B5977A685587DA7805882A77A5987A6755A8DA4705C92A26B5F96
9F67629A9B63669E975F6AA1925D6FA38E5B74A5885979A683597FA67E5984A6785989A5735B
8EA36E5D93A06A60979D65649B9962689F955F6CA2915C71A48C5A76A586597BA6815981A67C
5986A5775A8BA4715C90A26D5F959F6862999B64659C98616AA0935E6EA28F5C73A48A5A78A5
845A7DA67F5983A57A5A88A4755B8DA3705D91A06B60969D67639A9A63679D96606BA0915E70
A38D5C75A4885A7AA5825A7FA57D5A84A5785B89A3735C8EA16E5F939F6A62979C66659B9862
699E945F6DA18F5D72A38B5B77A4865A7CA5805A81A57B5B86A4765C8BA2715E90A06D60949D
6963989A65679C96626B9F925F6FA18D5D74A3895B79A4845B7EA47F5B83A4795B88A3755D8D
A1705F919F6B61969C6765999964689D95616D9F905E71A28C5D76A3875B7BA4825B80A47D5B
85A3785C8AA2735E8EA06E60939E6A63979A66669A97636A9D93606EA08E5E73A28A5C78A385
5C7DA4805B82A37B5C87A3765D8BA1715F909F6D61949C6964989965689B95626C9E916070A0
8C5E75A2885C7AA3835C7FA37E5C83A3795D88A2745E8DA07060919E6C63959B68669997646A
9C93626E9F8F5F72A18B5E77A2865D7CA3815C80A37C5D85A2775E8AA1735F8E9F6E61939C6A
64979967689A96646B9D92616F9F8D5F74A1895E79A2845D7DA27F5D82A27A5D87A1765E8BA0
7160909E6D63949B6966989866699B94636D9D9060719F8C5F76A1875E7AA2825D7FA27D5D84
A2795E89A0745F8D9F7061919C6C64959968679996656B9B92626F9E8E6073A08A5F78A1855E
7CA2805D81A27C5E86A1775F8A9F73608E9E6E63929B6B65969867699994646C9C9162709E8C
6075A0885F79A1835E7EA17F5E83A17A5E87A076608C9E7162909C6D64949A6A679796666A9A
93636E9D8F61729F8B6077A0865F7BA1825E80A17D5E84A0785F899F74618D9D7063919B6C65
959869689895656C9B9163709D8D61749F896078A0845F7DA0805F81A07B5F86A077608A9E73
628E9C6F64929A6B679697686A9993656D9B9062719E8B61769F875F7AA0835F7FA07E5F83A0
7A60879F75618C9D7163909B6D6593986A689795676B9A92646F9C8E62739E8A61779F85607C
A0815F80A07D60859F7860899E74628D9C7064919A6C66949769699894666D9A9064719C8C62
759E8860799F84607D9F7F60829F7B60869E77618A9D73638E9B6F6592996B689596686B9892
656F9B8F63729D8B62769E86607B9F82607F9F7E60839F7961889E75628C9C7164909A6E6693
976A699694676C999165709B8D63749D8961789E85617C9F8060819F7C61859E7862899D7463
8D9B706591996C689496696B9793676E9A8F64729C8B63769D87617A9E83617E9E7F61829E7B
61869D77628A9C73648E9A6F6692976B699595686C9891666F9A8E64739C8A62779D86617B9E
8261809E7D61849E7962889C75638C9B716590996E6793966B6A9693686D989065719B8C6475
9C8862799D84617D9E8061819E7C62859D7863899C74648D9A706691986D6994956A6C979267
6F998E65739B8B63769C87627A9D83627F9D7E62839D7A62879C76638B9B73658E996F679296
6C6A9594696D979067709A8D65749B8963789C85627C9D8162809D7D62849C7963889B75648C
9A71668F986E6993956B6B9592686E988F66729A8B64769B87637A9C84627E9D7F62829D7B63
869C7864899B74658D99706790976D6A94946A6D96916870988D66739A8A64779B86637B9C82
637F9C7E63839C7A63879B76658B9A73668E986F6891956C6B9493696E978F6771998C65759A
8864799B84637D9C8063809C7D63849B7964889A75658C9971678F976E6A92946B6C9591696F
978E6773998A65769B87647A9B83637E9C7F63829C7B64869B7765899974668D98706890956D
6B93936A6E96906871988D66749A8965789B85647C9B81647F9B7E64839B7A64879A76668B99
73678E976F6991946C6C94926A6F968E6872988B66769A8865799B84647D9B8064819B7C6485
9A7865889975668C9871688F966E6B92936C6D95906970978D6774998A66779A86657B9B8264
7F9B7F64829B7B65869A77668A9874678D97706990946E6C93926B6F958F6972978C67759988
66799A85657C9A8164809A7D65849A7A65879976678B9873688E96706A91936D6D94916A7096
8E6873988A67769987667A9A83657E9A8065819A7C6585997866889875678C9772698F956F6C
92926C6E948F6A71968C6874988966789985667B9A82657F9A7E65839A7B66869977678A9774
688D96716A90946E6D93916B6F958E6972978B6876988866799984667D9A8065809A7D668499
7966879876688B9773698E95706B91926D6E93906B71958D6974978A67779886667B9983667E
997F6682997C6685987867899775688C96726A8F946F6C91916C6F948F6A72968C6875978867
789885667C9981667F997E6683997A67869877688A9674698D95716B90936E6E92906C70948D
6A73968A68769787677A9884667D99806681997D6784987967889776698B96736A8E94706C90
926D6F938F6B72958C6975968968789886677B9882677F987F6782987B678598786889967569
8C95726B8F936F6D91906D70938E6B73958B6976978868799884677C98816780987D6783987A
68879777698A96746A8D94716C8F926E6E928F6C71948C6A74968969779786687A9883677E98
806781987C6784977968889676698B95736B8E93706D90916E70928E6C72948B6A7596886978
9785687C9882677F987E6782977B68869778698995756A8C94726C8E926F6E91906D71938D6B
73958A6A769687687A9784687D97806880977D6883977A698796776A8A95746B8D93716D8F91
6F6F918E6D72938C6B75958969789686687B9783687E977F6881977C68859679698895766A8B
94736C8D92706E90906E70928D6C73948B6A76958869799684687C9781687F977E6883977B69
8696786A8995756B8C93726D8E91706F918F6D72938C6C7494896A779586697A9683697D9780
6881977D6984967A698795776A8A94746C8C92716E8F906F70918E6D73938B6B7594886A7895
85697B9682697F967F6982967C698596796A8894766B8B93736D8D91716F908F6E71928D6C74
938A6B7795876A7A9684697D96816980967E6983967B6A8695786B8994756C8B92726E8E9070
70908E6E72928B6C7594896B7895866A7B9683697E96806981967D6984957A6A8794776B8A93
746D8C91716F8F8F6F71918D6D73938A6C7694886B7995856A7C9582697F967F6982957C6A85
95796B8894766C8B92736E8D9071708F8E6F72918C6D7493896B7794866A7A95836A7D95806A
80957D6A83957A6A8694786B8993756D8B91726F8E8F7071908D6E73928B6D7693886B789485
6A7B95826A7E957F6A81957C6A8494796B8793776C8A92746E8C90726F8E8E7072908C6E7492
8A6C7793876B7994846A7C95816A7F957E6A82957B6B8594786C8893766D8A91736E8D907170
8F8D6F73918B6D7592896C7894866B7B94836B7D95806A80957D6B83947A6B8693786C899275
6E8B91736F8E8F7071908C6F74918A6D7693876C7994856B7C94826B7F947F6B81947C6B8494
796C8793776D8A91746E8C9072708E8E7072908B6E7592896D7793866C7A94846B7D94816B80
947E6B82947B6B8593786C8892766E8A91736F8D8F71718F8D6F73908A6E7692886D7893856C
7B94836B7E94806B81947D6B83937A6C8693786D8991756E8B9073708D8E71728F8C6F749189
6D7792876C7993846C7C94816B7F947F6B82947C6C8493796D8792776E8A91746F8C8F72718E
8D7073908B6F7591886D7892866C7A93836C7D93806B80937E6C83937B6C8592786D8891766E
8A9074708D8E71728E8C7074908A6E7691876D7992856C7C93826C7E937F6C81937D6C84937A
6D8692776E8991756F8B8F73718D8D71738F8B6F7590896E7792866D7A92846C7D93816C7F93
7E6C82937C6C8592796D8791776E8A9074708C8E72728E8C70748F8A6F7691886E7892856D7B
92836C7E93806C80937D6C83927B6D8592786E8891766F8A8F74718C8D72738E8B707590896F
7791876E7992846D7C92826C7F937F6C81927C6D84927A6D8691776E899075708B8E73728D8D
71738F8B707690886E7891866D7A92836D7D92816D80927E6D82927C6D8591796E8790776F89
8F74718C8E72728D8C71748F8A6F7790876E7991856D7B92826D7E92806D81927D6D83927B6E
8691786F889076708A8E74718C8D72738E8B70758F896F7791866E7A91846D7C92816D7F927F
6D81927C6D84917A6E8690776F898F75718B8E73728D8C71748E8A707690886F7891856E7B91
836D7D92806D80927E6D82917B6E8591796F87907770898E75718B8D73738D8B71758F897077
90876F7991846E7C91826D7E927F6D81917D6E83917B6E8690786F888F76708A8E74728C8C72
748E8A71768F886F7890866E7A91836E7D91816E7F917F6E82917C6E84917A6F86907770898F
75718B8D73738C8B72758E8970778F876F7990856E7B91836E7E91806E80917E6E83917B6E85
90796F878F7770898E75728B8C73748D8A71768E8870788F866F7A90846E7C91826E7F917F6E
81917D6E83907A6F86907870888F76718A8D74738C8B72748D8A71768F88707990856F7B9083
6E7D91816E80917E6E82917C6F84907A6F868F7771898E75728A8C74738C8B72758E8971778F
87707990846F7C90826E7E91806E80917D6F83907B6F858F7970878E7771898D75738B8C7374
8D8A72768E8870788F86707A90846F7D90816F7F907F6F81907D6F84907A70868F7871888E76
728A8D74738C8B73758D8971778E8770798F856F7B90836F7D90806F80907E6F82907C6F848F
7A70868E7871888D76728A8C74748C8A72768D8871788E86707A8F846F7C90826F7E90806F81
907D6F83907B70858F7971878E7772898D75738B8B73758C8972778E8771798F85707B8F836F
7D90816F7F907F6F81907C70848F7A70868E7871888D76728A8C75748B8A73768D8972778E87
71798F84707C8F826F7E90806F80907E6F828F7C70848F7A71868E7872888D76738A8B74758C
8A73768D8871788E86707A8F84707C8F81707F907F6F818F7D70838F7B70858E7971878D7772
898C75748B8B74758C8972778D8771798E85707B8F83707D8F81707F8F7E70828F7C70848F7A
71868E7872888D76738A8B75748B8A73768C8872788E86717A8E84707C8F82707E8F8070808F
7E70828F7C71848E7A71868D7872888C76748A8B74758B8973778D8772798E85717B8E83707D
8F81707F8F7F70818F7D70838E7B71858E7972878D7773898B75748A8A74768C8873788D8672
798E85717C8E82707E8F8070808F7E70828F7C71848E7A71868D7872888C7674898B75758B89
73778C8872788D86717A8E84717C8E82707E8F8070808F7D71838E7B71858E7972868D787388
8C76748A8A74768B8973778C8772798D85717B8E83717D8E81717F8E7F71818E7D71838E7B71
858D7972878C7773898B75758A8974768C8873788D86727A8D84717C8E82717E8E8071808E7E
71828E7C71848D7A72868D7873888C7774898A75758B8974778C8773798D85727B8E83717D8E
81717F8E7F71818E7D71838E7B72858D7972868C7873888B76758A8A75768B8873788C86727A
8D85727B8E83717D8E81717F8E7F71818E7D71838D7B72858D7973878C7774898A76758A8974
778B8773798C86727A8D84727C8E82717E8E8071808E7E71828D7C72848D7A72868C7873888B
7775898A75768A8874788C8773798C85727B8D83727D8E81717F8E7F71818E7D72838D7B7285
8C7973868C7874888A7675898975778B8874788C86737A8D84727C8D82727E8D8071808E7E72
828D7C72838D7B73858C7973878B7775888A76768A8875778B8773798C85737B8D83727D8D82
727E8D8072808D7E72828D7C72848C7A73868C7874878B7775898975768A8874788B86737A8C
84737B8D83727D8D81727F8D7F72818D7D72838D7B73858C7973868B7874888A767689897577
8B8774798C86737A8C84727C8D82727E8D8072808D7E72828D7C72848C7B73858C7974878B77
75888976768A8875788B8674798C85737B8C83727D8D81727F8D7F72818D7E72828C7C73848C
7A74868B7874878A7776898976778A8774788B86747A8C84737C8C82727E8D81727F8D7F7281
8D7D73838C7B73858B7974868B787588897776898875788A8774798B85737B8C83737C8C8272
7E8D8072808D7E73828C7C73848C7B74858B7974878A777588897677898875788B86747A8B84
737B8C83737D8C81737F8C7F73818C7D73828C7C73848B7A74868B7875878A7776898876778A
8775798B85747A8B84737C8C82737E8C8073808C7F73818C7D73838C7B74858B7974868A7875
88897777898875788A8674798B85747B8C83737D8C81737E8C8073808C7E73828C7C73848B7B
74858B7975878A787688887677898775798A86747A8B84747C8C82737D8C81737F8C7F73818C
7D73838C7C74848B7A74868A797587897776888876788A8775798A85747B8B83747C8C82737E
8C8073808C7E73818C7D74838B7B74858B7A75868A787688897777898776788A86757A8B8474
7B8B83747D8C81737F8C7F73808C7E73828B7C74848B7B75858A797587897876888876788987
75798A85757A8B84747C8B82747E8C80737F8C7F73818B7D74838B7C74848A7A75868A797687
897777888776788986757A8A85747B8B83747D8B82747E8B8073808B7E74828B7D74838B7B75
858A7A758689787687887777898776798A86757A8A84747C8B82747D8B81747F8B7F74818B7E
74828B7C74848A7B75858A79768789787788887778898676798A85757B8A83747C8B82747E8B
8074808B7F74818B7D74838B7B75848A7A758689797687887777888776798986757A8A84757B
8B83747D8B81747F8B8074808B7E74828B7C74838A7B75858A7A768689787787887778888776
798985757B8A84757C8B82747E8B81747F8B7F74818B7D74828B7C75848A7B75858979768688
7877888777788986767A8A85757B8A83757D8B82747E8B8074808B7E74818B7D75838A7B7584
8A7A768689797787887878888777798985767A8A84757C8A83757D8B81747F8B7F74808B7E74
828A7C75838A7B7585897A7686887877878777788886767A8985767B8A83757C8A82757E8B80
747F8B7F74818A7D75828A7C75848A7B768589797786887878888777798886767A8984757B8A
83757D8A81757E8A8075808A7E75818A7D75838A7B7584897A76868879778787787888867779
8985767B8984757C8A82757D8A81757F8A7F75808A7E75828A7C7583897B7685897A77868878
78878777798886777A8985767B8A83757D8A82757E8A8075808A7F75818A7D75828A7C768489
7B768588797786877878878677798885767A8984767C8A83757D8A81757F8A8075808A7E7582
8A7D7583897B7684897A7786887977878778788886777A8885767B8983767C8A82757E8A8175
7F8A7F75818A7E75828A7C7683897B7685887A7786887978878778798885777A8984767B8983
767D8A81757E8A8075808A7F75818A7D7582897C7684897B7785887977868778788786777988
85777B8984767C8982767D8A81757F8A8075808A7E7582897D7683897B7684887A7785887978
878778798786777A8884767B8983767D8982767E8A80757F8A7F75818A7E7682897C7683897B
7785887A7786877978878678798885777A8884767C8983767D8981767E8A8075808A7E768189
7D7683897C7684887B7785887978868778798786777A8885777B8983767C8982767E8981767F
897F7680897E7682897D7683897B7784887A7785877978868678798785777A8884777C898376
7D8982767E8980767F897F7681897E7682897C7683887B7785887A78868779798786787A8885
777B8884777C8982767D8981767F89807680897E7681897D7683897C7784887B778587797886
8679798785787A8884777B8883767D8982767E8981767F897F7680897E7682897D7683887B77
84887A78858779798686787A8785777B8884777C8883767D8981767E89807680897F7681897D
7682887C7783887B7785877A78868679798786787A8784777B8883777C8882767E8981767F89
807680897E7681897D7783887C7784887B7885877A78868679798785787A8884777C8883777D
8882767E8980767F897F7681897E7682887D7783887B7784877A78858779798686787A878578
7B8884777C8882777D8981767F89807680897F7681887D7782887C7783887B7885877A788686
79798685787A8784787B8883777D8882777E8881767F897F7680897E7781887D7783887C7784
877B7885877A798686797A8785787B8784777C8883777D8881777E8880777F887F7781887E77
82887D7783887B7884877A78858679798685797A8784787B8783777C8882777D8881777F8880
7780887E7781887D7782887C7783877B7884877A798586797A8685787B8784787C8883777D88
82777E8880777F887F7780887E7782887D7783887C7884877B7885867A798685797A8685787B
8783787C8882777D8881777E88807780887F7781887E7782887C7783877B7884877A79858679
7A8685797A8784787B8783787D8882777E8881777F88807780887E7781887D7782877C788387
7B7884867A798586797A8685797B8784787C8783777D8881777E8880777F887F7780887E7782
887D7883877C7884877B7985867A798685797A8684787B8783787C8782777D8881777F888077
80887F7781887E7782877C7883877B7884867A7985867A7A8685797B8684787C8783787D8782
777E8881777F887F7780887E7781887D7882877C7883877B7984867A798585797A8684797B87
83787C8782787D8781777E8880777F887F7781887E7882877D7883877C7884867B7985867A7A
8585797B8684797C8783787D8782787E8781777F88807780887F7781877D7882877C7883877B
7984867B7985857A7A8684797B8684787C8783787D8782787E8780777F887F7780877E788187
7D7882877C7883867B7984867A7A8585797A8684797B8683787C8782787D8781787E87807880
877F7881877E7882877D7883877C7984867B7985857A7A8585797B8684797C8783787D878278
7E8781787F87807880877E7881877D7882877C7883867B7984867B7A85857A7A8684797B8683
797C8782787D8781787E8780787F877F7880877E7881877D7882877C7983867B7984857A7A85
857A7B8684797C8683787D8782787E8781787F87807880877F7881877E7882877D7883867C79
84867B7A85857A7A8584797B8683797C8683787D8782787E8781787F877F7880877E7881877D
7882877C7983867B7984857B7A85857A7B8584797B8683797C8682787D8781787E8780787F87
7F7880877E7881877D7882867C7983867B7A84857A7A85847A7B8684797C8683797D8782787E
8781787F87807880877F7881877E7882867D7983867C7984867B7A84857A7B85847A7B868379
7C8682797D8781787E8780787F877F7880877E7881877D7982867C7983867C7984857B7A8585
7A7B8584797C8683797D8682797E8781787F87807880877F7881877E7882867D7982867C7983
867B7A84857A7A85847A7B8583797C8682797D8682797E8781787F87807880877F7881877E79
82867D7983867C7984857B7A84857A7B85847A7C8683797C8682797D8681797E8780787F877F
7880877E7981867D7982867C7983867C7A84857B7A85847A7B85837A7C8683797D8682797E86
81797F87807880877F7981867E7982867D7982867C7983857B7A84857B7B85847A7B8583797C
8682797D8681797E8680797F867F7980867F7981867E7982867D7983867C7A84857B7A84847A
7B85847A7C8583797D8682797E8681797E8680797F867F7980867E7981867D7982867C798385
7C7A84857B7B84847A7B85837A7C8682797D8682797E8681797F86807980867F7981867E7982
867D7982867C7A83857B7A84847B7B85847A7C85837A7C8682797D8681797E8680797F867F79
80867E7981867E7982867D7A83857C7A84857B7B84847A7B85837A7C8583797D8682797E8681
797F86807980867F7980867E7981867D7982857C7A83857C7A84847B7B84847A7C85837A7C85
82797D8681797E8681797F86807980867F7981867E7982867D7A82857C7A83857B7B84847B7B
85837A7C85837A7D8582797E8681797E8680797F867F7980867E7981867E7982857D7A83857C
7A83847B7B84847B7B85837A7C85827A7D8682797E8681797F86807980867F7980867E798186
7D7A82857C7A83857C7A84847B7B84847A7C85837A7D85827A7D8681797E8680797F86807980
867F7981867E7982857D7A82857C7A83857B7B84847B7B84837A7C85837A7D85827A7E868179
7F8680797F867F7980867E7981867D7A82857D7A83857C7A83847B7B84847B7C85837A7C8582
7A7D8581797E8681797F86807980867F7981867E7A81857D7A82857C7A83857C7B84847B7B84
837B7C85837A7D85827A7E8581797E8680797F867F7980867F7981857E7A82857D7A82857C7A
83847C7B84847B7C84837A7C85827A7D85827A7E8581797F8680797F867F7980857E7A81857D
7A82857D7A83857C7B83847B7B84837B7C84837A7D85827A7D85817A7E85807A7F8680798086
7F7A81857E7A81857D7A82857C7A83847C7B84847B7C84837B7C85827A7D85827A7E85817A7E
85807A7F857F7A80857E7A81857E7A82857D7A82857C7B83847C7B84847B7C84837B7C85827A
7D85817A7E85817A7F85807A80857F7A80857E7A81857D7A82857D7A83847C7B83847B7B8483
7B7C84837A7D85827A7E85817A7E85807A7F85807A80857F7A81857E7A81857D7A82857C7B83
847C7B83847B7C84837B7C84827A7D85827A7E85817A7F85807A7F857F7A80857E7A81857E7A
82857D7A82847C7B83847C7B84837B7C84837B7D85827A7D85817A7E85817A7F85807A80857F
7A80857E7A81857D7A82857D7B83847C7B83847B7C84837B7C84827B7D85827A7E85817A7E85
807A7F857F7A80857F7A81857E7A81857D7A82847C7B83847C7B83837B7C84837B7D84827A7D
85817A7E85817A7F85807A7F857F7A80857E7A81857E7A82857D7B82847C7B83847C7C84837B
7C84837B7D84827A7E85817A7E85807A7F85807A80857F7A81857E7A81857D7A82847D7B8384
7C7B83837C7C84837B7C84827B7D84827A7E85817A7F85807A7F857F7A80857F7A81857E7A81
847D7B82847D7B83847C7C83837B7C84837B7D84827B7D85817A7E85817A7F85807A80857F7A
80857E7A81857E7B82847D7B82847C7B83837C7C83837B7C84827B7D84827B7E85817A7E8580
7A7F85807A80857F7A81857E7A81847D7B82847D7B83847C7C83837C7C84837B7D84827B7D84
817B7E85817A7F85807A7F857F7A80857F7A81857E7B82847D7B82847D7B83847C7C83837B7C
84827B7D84827B7E84817A7E85807A7F85807A80857F7A80857E7A81847E7B82847D7B82847C
7B83837C7C83837B7D84827B7D84827B7E84817A7E85807A7F857F7A80857F7A81847E7B8184
7D7B82847D7B83847C7C83837C7C84837B7D84827B7D84817B7E84817A7F85807A7F857F7A80
857E7B81847E7B82847D7B82847D7B83837C7C83837C7C84827B7D84827B7E84817B7E84807A
7F85807A80857F7B80847E7B81847E7B82847D7B82847C7C83837C7C83837B7D84827B7D8481
7B7E84817B7F84807B7F847F7B80847F7B81847E7B81847D7B82847D7B82837C7C83837C7C83
827B7D84827B7E84817B7E84807B7F84807B80847F7B80847E7B81847E7B82847D7B82847D7C
83837C7C83837C7D84827B7D84827B7E84817B7E84807B7F84807B80847F7B80847E7B81847E
7B82847D7B82837C7C83837C7C83827C7D84827B7D84817B7E84817B7F84807B7F847F7B8084
7F7B81847E7B81847D7B82847D7C82837C7C83837C7D83827B7D84827B7E84817B7E84807B7F
84807B80847F7B80847E7B81847E7B82847D7B82837D7C83837C7C83827C7D83827B7D84817B
7E84817B7F84807B7F847F7B80847F7B81847E7B81847E7B82847D7C82837C7C83837C7C8382
7C7D84827B7E84817B7E84817B7F84807B7F847F7B80847F7B81847E7B81847D7B82837D7C82
837C7C83837C7D83827C7D84817B7E84817B7E84807B7F84807B80847F7B80847E7B81847E7B
82847D7C82837D7C83837C7C83827C7D83827B7D84817B7E84817B7F84807B7F847F7B80847F
7B81847E7B81847E7B82837D7C82837D7C83837C7D83827C7D83827B7E84817B7E84807B7F84
807B80847F7B80847F7B81847E7B81847D7C82837D7C82837C7C83827C7D83827C7D84817B7E
84817B7F84807B7F84807B80847F7B80847E7B81847E7B82837D7C82837D7C83837C7D83827C
7D83827C7E84817B7E84817B7F84807B7F847F7B80847F7B81847E7B81847E7C82837D7C8283
7D7C83827C7D83827C7D83817C7E84817B7E84807B7F84807B80847F7B80847F7B81847E7B81
837D7C82837D7C82837C7D83827C7D83827C7E83817B7E84817B7F84807B7F847F7B80847F7B
80847E7B81837E7C82837D7C82837D7C82827C7D83827C7D83827C7E83817B7E84807B7F8480
7B7F847F7B80847F7B81847E7C81837E7C82837D7C82837D7C83827C7D83827C7D83817C7E83
817B7F84807B7F84807B80847F7B80847E7B81837E7C81837D7C82837D7C82837C7D83827C7D
83827C7E83817C7E84817B7F84807B7F847F7B80847F7B80847E7C81837E7C82837D7C82837D
7C82827C7D83827C7D83817C7E83817C7E84807B7F84807B80847F7B80847F7B81837E7C8183
7E7C82837D7C82837D7D83827C7D83827C7E83817C7E83817C7F84807B7F84807B80847F7B80
837E7C81837E7C81837D7C82837D7C82827D7D83827C7D83827C7E83817C7E83807C7F84807B
7F847F7B80837F7C80837E7C81837E7C81837D7C82837D7D82827C7D83827C7D83817C7E8381
7C7E83807C7F83807C80837F7C80837F7C81837E7C81837E7C82837D7C82827D7D82827C7D83
827C7E83817C7E83817C7F83807C7F837F7C80837F7C80837E7C81837E7C81837D7C82837D7D
82827D7D83827C7D83817C7E83817C7E83807C7F83807C7F837F7C80837F7C81837E7C81837E
7C81837D7C82827D7D82827D7D83827C7E83817C7E83817C7F83807C7F83807C80837F7C8083
7F7C81837E7C81837E7C82837D7D82827D7D82827C7D83817C7E83817C7E83807C7F83807C7F
837F7C80837F7C80837E7C81837E7C81837D7C82827D7D82827D7D83827C7E83817C7E83817C
7E83807C7F83807C7F837F7C80837F7C81837E7C81837E7C81837D7D82827D7D82827D7D8382
7C7E83817C7E83817C7F83807C7F83807C80837F7C80837F7C81837E7C81837E7C82827D7D82
827D7D82827C7D83817C7E83817C7E83807C7F83807C7F837F7C80837F7C80837E7C81837E7C
81837D7D82827D7D82827D7D82827C7E83817C7E83817C7F83807C7F83807C80837F7C80837F
7C81837E7C81837E7C81837D7D82827D7D82827D7D83817C7E83817C7E83807C7F83807C7F83
807C80837F7C80837F7C81837E7C81837E7C82827D7D82827D7D82827D7E83817C7E83817C7E
83807C7F83807C7F837F7C80837F7C80837E7C81837E7C81837D7D82827D7D82827D7D82817C
7E83817C7E83817C7F83807C7F83807C80837F7C80837F7C81837E7C81837E7C81827D7D8282
7D7D82827D7D82817C7E83817C7E83807C7F83807C7F837F7C80837F7C80837F7C81837E7C81
837E7D82827D7D82827D7D82827D7E83817C7E83817C7F83807C7F83807C7F837F7C80837F7C
80837E7C81837E7C81827E7D82827D7D82827D7D82817D7E83817C7E83817C7F83807C7F8380
7C80837F7C80837F7C81837E7C81827E7D81827D7D82827D7D82827D7E82817D7E83817C7E83
807C7F83807C7F837F7C80837F7C80837E7C81837E7D81827E7D82827D7D82827D7D82817D7E
82817C7E83817C7F83807C7F83807C80837F7C80837F7C80837E7C81827E7D81827E7D82827D
7D82827D7E82817D7E82817C7E83807C7F83807C7F83807C80837F7C80837F7C81837E7D8182
7E7D81827D7D82827D7D82817D7E82817D7E83817C7F83807C7F83807C7F837F7C80837F7C80
837E7C81827E7D81827E7D82827D7D82827D7E82817D7E82817D7E83817C7F83807C7F83807C
80837F7C80837F7C80837E7D81827E7D81827E7D82827D7D82827D7E82817D7E82817D7E8380
7C7F83807C7F837F7C80837F7C80837F7C81827E7D81827E7D81827D7D82827D7D82817D7E82
817D7E82817C7F83807C7F83807C7F837F7C80837F7C80837E7D81827E7D81827E7D81827D7D
82827D7E82817D7E82817D7E82807C7F83807C7F83807C80837F7C80837F7D80827E7D81827E
7D81827E7D82827D7D82817D7E82817D7E82817D7F82807C7F83807C7F837F7C80837F7C8082
7F7D81827E7D81827E7D81827D7D82827D7E82817D7E82817D7E82817D7F82807C7F83807C80
837F7C80837F7D80827E7D81827E7D81827E7D81827D7D82817D7E82817D7E82817D7E82807D
7F82807C7F83807C80837F7D80827F7D80827E7D81827E7D81827E7D82827D7E82817D7E8281
7D7E82817D7F82807D7F82807D7F827F7D80827F7D80827F7D81827E7D81827E7D81827E7D82
817D7E82817D7E82817D7E82807D7F82807D7F82807D80827F7D80827F7D80827E7D81827E7D
81827E7D81827D7D82817D7E82817D7E82817D7F82807D7F82807D7F827F7D80827F7D80827F
7D81827E7D81827E7D81827E7D82827D7E82817D7E82817D7E82817D7F82807D7F82807D7F82
7F7D80827F7D80827F7D81827E7D81827E7D81827E7D82817D7E82817D7E82817D7E82807D7F
82807D7F82807D80827F7D80827F7D80827E7D81827E7D81827E7D81827D7E82817D7E82817D
7E82817D7F82807D7F82807D7F827F7D80827F7D80827F7D81827E7D81827E7D81827E7D8181
7D7E82817D7E82817D7E82807D7F82807D7F82807D80827F7D80827F7D80827F7D81827E7D81
827E7D81827E7E82817D7E82817D7E82817D7F82807D7F82807D7F82807D80827F7D80827F7D
80827E7D81827E7D81827E7D81817D7E82817D7E82817D7E82817D7F82807D7F82807D7F827F
7D80827F7D80827F7D81827E7D81827E7D81827E7E81817D7E82817D7E82817D7E82807D7F82
807D7F82807D80827F7D80827F7D80827F7D81827E7D81827E7D81817E7E82817D7E82817D7E
82817D7F82807D7F82807D7F827F7D80827F7D80827F7D80827E7D81827E7D81827E7E81817E
7E82817D7E82817D7E82807D7F82807D7F82807D7F827F7D80827F7D80827F7D81827E7D8182
7E7D81817E7E81817D7E82817D7E82817D7F82807D7F82807D7F82807D80827F7D80827F7D80
827F7D81827E7D81827E7D81817E7E81817D7E82817D7E82807D7F82807D7F82807D7F827F7D
80827F7D80827F7D80827E7D81827E7D81827E7E81817E7E82817D7E82817D7E82807D7F8280
7D7F82807D80827F7D80827F7D80827F7D81827E7D81827E7D81817E7E81817E7E82817D7E82
817D7F82807D7F82807D7F82807D80827F7D80827F7D80827F7D81827E7D81827E7E81817E7E
81817D7E82817D7E82807D7F82807D7F82807D7F827F7D80827F7D80827F7D80827E7D81827E
7D81817E7E81817E7E82817D7E82817D7F82807D7F82807D7F82807D80827F7D80827F7D8082
7F7D81827E7D81827E7E81817E7E81817E7E82817D7E82807D7F82807D7F82807D7F827F7D80
827F7D80827F7D80827F7D81827E7D81817E7E81817E7E81817D7E82817D7E82807D7F82807D
7F82807D7F827F7D80827F7D80827F7D80827E7D81827E7E81817E7E81817E7E81817D7E8281
7D7F82807D7F82807D7F82807D80827F7D80827F7D80827F7D81827E7D81817E7E81817E7E81
817E7E82817D7E82807D7F82807D7F82807D7F827F7D80827F7D80827F7D80827F7D81827E7E
81817E7E81817E7E81817E7E82817D7F82807D7F82807D7F82807D80827F7D80827F7D80827F
7D80827E7D81817E7E81817E7E81817E7E81817D7E82807D7F82807D7F82807D7F82807D8082
7F7D80827F7D80827F7D81827E7E81817E7E81817E7E81817E7E81817D7F82807D7F82807D7F
82807D7F827F7D80827F7D80827F7D80827F7D81817E7E81817E7E81817E7E81817E7E81817D
7F82807D7F82807D7F82807D80827F7D80827F7D80827F7D80827E7E81817E7E81817E7E8181
7E7E81817E7E82807D7F82807D7F82807D7F82807D80827F7D80827F7D80827F7D81817E7E81
817E7E81817E7E81817E7E81817E7F82807D7F82807D7F82807D7F827F7D80827F7D80827F7D
80827F7E81817E7E81817E7E81817E7E81817E7E81807D7F82807D7F82807D7F82807D80827F
7D80827F7D80827F7D80817E7E81817E7E81817E7E81817E7E81817E7F81807D7F82807D7F82
807D7F827F7D80827F7D80827F7D80817F7E81817E7E81817E7E81817E7E81817E7E81817E7F
81807D7F82807D7F82807D7F827F7D80827F7D80827F7E80817F7E81817E7E81817E7E81817E
7E81817E7E81807E7F82807D7F82807D7F82807D80827F7D80827F7D80817F7E80817E7E8181
7E7E81817E7E81817E7E81817E7F81807E7F82807D7F82807D7F827F7D80827F7D80827F7E80
817F7E81817E7E81817E7E81817E7E81817E7E81807E7F81807E7F82807D7F82807D80827F7D
80827F7D80817F7E80817F7E81817E7E81817E7E81817E7E81817E7F81807E7F81807E7F8280
7D7F82807D80827F7D80817F7E80817F7E80817E7E81817E7E81817E7E81817E7E81807E7F81
807E7F81807E7F82807D7F827F7D80827F7E80817F7E80817F7E81817E7E81817E7E81817E7E
81817E7E81807E7F81807E7F81807E7F82807D80827F7E80817F7E80817F7E80817F7E81817E
7E81817E7E81817E7E81817E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E8081
7F7E80817E7E81817E7E81817E7E81817E7E81807E7F81807E7F81807E7F81807E7F817F7E80
817F7E80817F7E80817F7E81817E7E81817E7E81817E7E81817E7F81807E7F81807E7F81807E
7F81807E80817F7E80817F7E80817F7E80817F7E81817E7E81817E7E81817E7E81807E7F8180
7E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817E7E81817E7E81817E7E81
817E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E81817E7E
81817E7E81817E7E81817E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F
7E80817F7E81817E7E81817E7E81817E7E81807E7F81807E7F81807E7F81807E7F817F7E8081
7F7E80817F7E80817F7E80817E7E81817E7E81817E7E81817E7F81807E7F81807E7F81807E7F
81807E80817F7E80817F7E80817F7E80817F7E80817E7E81817E7E81817E7E81807E7F81807E
7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E81817E7E81817E7E8181
7E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817E7E81
817E7E81817E7E81807E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E
80817F7E80817E7E81817E7E81817E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F
7E80817F7E80817F7E80817F7E81817E7E81817E7E81817E7F81807E7F81807E7F81807E7F81
807E80817F7E80817F7E80817F7E80817F7E80817E7E81817E7E81817E7E81807E7F81807E7F
81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817E7E81817E7E81817E
7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E8181
7E7E81817E7E81807E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80
817F7E80817E7E81817E7E81817E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E
80817F7E80817F7E80817F7E80817E7E81817E7E81807E7F81807E7F81807E7F81807E7F8180
7E7F817F7E80817F7E80817F7E80817F7E80817F7E81817E7E81817E7F81807E7F81807E7F81
807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817F7E81817E7E81817E7F
81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E80817E
7E81817E7E81807E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E8081
7F7E80817F7E81817E7E81817E7F81807E7F81807E7F81807E7F81807E7F81807E80817F7E80
817F7E80817F7E80817F7E80817F7E81817E7E81807E7F81807E7F81807E7F81807E7F81807E
7F817F7E80817F7E80817F7E80817F7E80817F7E80817E7E81817E7F81807E7F81807E7F8180
7E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817F7E80817E7E81807E7F81
807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E80817F7E
81817E7F81807E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F
7E80817F7E80817E7E81807E7F81807E7F81807E7F81807E7F81807E7F81807E80817F7E8081
7F7E80817F7E80817F7E80817F7E80817E7F81807E7F81807E7F81807E7F81807E7F81807E7F
817F7E80817F7E80817F7E80817F7E80817F7E80817F7E81817E7F81807E7F81807E7F81807E
7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817F7E80817F7E81807E7F8180
7E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817F7E80
817E7F81807E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E
80817F7E80817F7E81807E7F81807E7F81807E7F81807E7F81807E7F81807E80817F7E80817F
7E80817F7E80817F7E80817F7E80817F7F81807E7F81807E7F81807E7F81807E7F81807E7F81
807E80817F7E80817F7E80817F7E80817F7E80817F7E80807E7F81807E7F81807E7F81807E7F
81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E80817F7F80807E7F81807E
7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817F7E8080
7F7F81807E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80
817F7E80817F7F80807F7F81807E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E
80817F7E80817F7E80817F7E80807F7F80807E7F81807E7F81807E7F81807E7F81807E7F8180
7E80817F7E80817F7E80817F7E80817F7E80817F7F80807F7F81807E7F81807E7F81807E7F81
807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E80817F7F80807F7F81807E7F
81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7E80817F7E80807F
7F80807E7F81807E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E8081
7F7E80817F7F80807F7F80807E7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E80
817F7E80817F7E80817F7E80807F7F80807F7F81807E7F81807E7F81807E7F81807E7F81807E
80817F7E80817F7E80817F7E80817F7E80817F7F80807F7F80807F7F81807E7F81807E7F8180
7E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7E80807F7F80807F7F80807E7F81
807E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80817F7F80807F7F
80807F7F80807E7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F
7E80807F7F80807F7F80807F7F81807E7F81807E7F81807E7F81807E7F817F7E80817F7E8081
7F7E80817F7E80817F7F80807F7F80807F7F80807F7F81807E7F81807E7F81807E7F81807E80
817F7E80817F7E80817F7E80817F7E80807F7F80807F7F80807F7F80807E7F81807E7F81807E
7F81807E7F81807E80817F7E80817F7E80817F7E80817F7F80807F7F80807F7F80807F7F8080
7E7F81807E7F81807E7F81807E7F817F7E80817F7E80817F7E80817F7E80807F7F80807F7F80
807F7F80807F7F81807E7F81807E7F81807E7F81807E80817F7E80817F7E80817F7E80817F7F
80807F7F80807F7F80807F7F80807F7F81807E7F81807E7F81807E7F817F7E80817F7E80817F
7E80817F7E80807F7F80807F7F80807F7F80807F7F80807E7F81807E7F81807E7F81807E7F81
7F7E80817F7E80817F7E80817F7F80807F7F80807F7F80807F7F80807F7F80807E7F81807E7F
81807E7F81807E80817F7E80817F7E80817F7E80807F7F80807F7F80807F7F80807F7F80807F
7F80807E7F81807E7F81807E7F817F7E80817F7E80817F7E80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F81807E7F81807E7F81807E80817F7E80817F7E80817F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F81807E7F81807E7F81807E80817F7E80817F7E
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F81807E7F81807E7F817F
7E80817F7E80817F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807E7F81
807E7F81807E80817F7E80817F7E80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807E7F81807E7F817F7E80817F7E80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807E7F81807E7F817F7E80817F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F81807E80817F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F8080
7F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80
807F7F80807F7F80807F7F807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F
80807F7F80807F7F80807F7F80807F7F80807F80807F7F80807F7F80807F7F80807F7F80807F
7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F807F7F80807F7F80807F7F8080
7F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F7F80807F80
pop
% End of sampled sound
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006`00012Q000`40O003h00Oo`00/@0000000`00
Oomoo`3oOon]Ool100000003001oogoo05Aoo`L00?mooe9oo`40000000<007ooOol0E7oo3P00ogoo
Bgoo0@0000000`00Oomoo`1DOolF003oOom3Ool100000003001oogoo05Aooal00?moocYoo`400000
00<007ooOol0E7oo;000ogoo;Goo0@0000000`00Oomoo`1DOoln003oOolKOol100000003001oogoo
05Aooel00?Uoo`40000000<007oo0000o`00[0000Goo0@0000000`00Oomoo`1DOon^002ZOol10000
0003001oogoo05Aooe@00?moo`Eoo`40000000<007oo0000E7oo>@00ogoo87oo0@0000000`00Oomo
o`1DOolY003oOol`Ool100000003001oogoo05Aooa`00?mooceoo`40000000<007ooOol0E7oo4`00
ogooAWoo0@0000000`00Oomoo`1DOol<003oOom=Ool100000003001oogoo05Aoo`D00?mooeAoo`40
000000<007ooOol0ogoo[Goo0@00003o002a00000003001oogoo0?moojeoo`40000000<007ooOol0
E7oo00<007ooOol0ogooEWoo0@0000000`00Oomoo`1DOol00`00Oomoo`3oOomFOol100000003001o
ogoo05Aoo`800?mooeMoo`40000000<007ooOol0EGoo00<007ooOol0ogooEGoo0@0000000`00Oomo
o`1DOol3003oOomFOol100000003001oogoo05Ioo`03001oogoo0?mooeAoo`40000000<007ooOol0
EGoo0P00ogooEWoo0@0000000`00Oomoo`1EOol3003oOomEOol100000003001oogoo05Aoo`800003
Ool007oo0?mooeAoo`40000000<007ooOol0E7oo0`0000=oo`00Ool0ogooDgoo0@0000000`00Oomo
o`1FOol3003oOomDOol100000003001oogoo05Moo`800?mooeAoo`40000000<007ooOol0EGoo0P00
00=oo`000000ogooDgoo0@0000000`00Oomoo`1FOol01000Ool00000ogooDgoo0@0000000`00Oomo
o`1EOol00`00Oomoo`02003oOomCOol100000003001oogoo05Eoo`03001oo`0000<00?mooe9oo`40
000000<007ooOol0E7oo1@0000=oo`00Ool0ogooDGoo0@0000000`00Oomoo`1DOol02000Oomoo`00
Ool007oo003oOomAOol100000003001oogoo05Ioo`03001oo`0000@00?mooe1oo`40000000<007oo
Ool0EGoo0P0000=oo`00Ool00`00ogooD7oo0@0000000`00Oomoo`1GOol20002Ool2003oOom@Ool1
00000003001oogoo05Eoo`04001oo`00Ool200000goo0000003oOom?Ool100000003001oogoo05Uo
o`80009oo`03001oogoo0?moodeoo`40000000<007ooOol0EGoo00<007oo00000goo0`00ogooCgoo
0@0000000`00Oomoo`1EOol500000goo00000002003oOom>Ool100000003001oogoo05Aoo`03001o
ogoo00=oo`800003Ool000000?moodioo`40000000<007ooOol0E7oo00P007oo001oo`00Ool007oo
1000ogooCGoo0@0000000`00Oomoo`1LOol4003oOom=Ool100000003001oogoo05Ioo`D00003Ool0
07oo00800?moodeoo`40000000<007ooOol0EWoo0P000goo0P0000Aoo`0000000?moodaoo`400000
00<007ooOol0EGoo00P007oo001oo`00Ool007oo1000ogooC7oo0@0000000`00Oomoo`1EOol00`00
Oomoo`05Ool20002Ool00`00Oomoo`3oOom9Ool100000003001oogoo05Uoo`@0009oo`<00?mood]o
o`40000000<007ooOol0Egoo0`000Woo1`00ogooBWoo0@0000000`00Oomoo`1EOol20003Ool01000
Ool007oo1@00ogooBWoo0@0000000`00Oomoo`1EOol01000Oomoo`001Goo00<007oo00000`00ogoo
BGoo0@0000000`00Oomoo`1DOol00`00Ool00004Ool400001Goo000007oo0000ogooBGoo0@000000
0`00Oomoo`1DOol01000Oomoogoo100000=oo`00Ool01P00ogooB7oo0@0000000`00Oomoo`1FOol2
00000goo001oo`04Ool00`00Ool0000200000goo001oo`3oOom6Ool100000003001oogoo05aoo`H0
0004Ool00000003oOom7Ool100000003001oogoo05Ioo`80009oo`<000=oo`@00003Ool000000?mo
odIoo`40000000<007ooOol0EGoo00@007ooOomoo`8000=oo`04001oo`00Ool200000goo0000003o
Oom6Ool100000003001oogoo05Eoo`05001oogooOol00002Ool00`00Oomoo`03Ool00`00Ool00003
003oOom5Ool100000003001oogoo05Moo`800004Ool007ooOol900000goo001oo`3oOom4Ool10000
0003001oogoo05Moo`04001oogooOol20006Ool6003oOom4Ool100000003001oogoo05Ioo`03001o
o`00009oo`0:001oogooOol007oo001oo`00Ool4003oOom4Ool100000003001oogoo05Eoo`04001o
ogooOol20002Ool01000Oomoogoo10000Woo0`00ogoo@goo0@0000000`00Oomoo`1EOol20002Ool0
0`00Ool00002Ool300000goo001oo`06003oOom3Ool100000003001oogoo05Qoo`8000=oo`8000=o
o`80009oo`D00?mood9oo`40000000<007ooOol0E7oo00@007ooOomoo`80009oo`05001oogooOol0
0003Ool20002Ool4003oOom1Ool100000003001oogoo05Aoo`03001oogoo00=oo`80009oo`03001o
ogoo00<00003Ool0000000D00?mood5oo`40000000<007ooOol0EWoo0P001goo0P001Woo00<007oo
00000`00ogoo@7oo0@0000000`00Oomoo`1GOol02000Oomoo`00Ool007oo0004Ool2000017oo001o
ogoo0P0000=oo`00Ool0ogoo?goo0@0000000`00Oomoo`1FOol01000Ool000000goo00@007ooOomo
o`T00004Ool00000003oOoloOol100000003001oogoo05Yoo`03001oo`00009oo`06001oogoo001o
o`000goo00<007oo00001000ogoo?Woo0@0000000`00Oomoo`1EOol01000Oomoo`000Woo00<007oo
Ool00Woo0P000goo00<007oo00000Woo00<007oo00000P00ogoo?Woo0@0000000`00Oomoo`1EOol0
1P00Ool00000Ool0009oo`@00003Ool0000000d00?moocaoo`40000000<007ooOol0FGoo00<007oo
00000Woo00@007oo001oo`80009oo`05001oo`00Ool00002Ool4003oOollOol100000003001oogoo
05Ioo`06001oogooOol007oo0P000goo00D007ooOol007oo00/00?moocaoo`40000000<007ooOol0
EGoo00D007ooOomoo`00009oo`08001oo`00Ool007oo001oo`<00007Ool007oo001oo`00Ool01000
ogoo>goo0@0000000`00Oomoo`1EOol30007Ool01000Oomoogoo0P0017oo0`0000Aoo`00001oo`<0
0?moocYoo`40000000<007ooOol0FGoo0`000Woo00<007ooOol00P000Woo00<007oo0000200000Ao
o`0000000?moocUoo`40000000<007ooOol0F7oo00D007ooOomoo`0000Eoo`04001oogooOol20000
0goo001oo`02Ool200000goo00000002003oOoliOol100000003001oogoo05Aoo`03001oogoo00=o
o`0>001oogoo001oo`00Ool007oo001oo`00Ool0009oo`L00004Ool00000003oOolhOol100000003
001oogoo05Aoo`04001oo`000008Ool01000Oomoogoo0P000Woo0`0000Aoo`00001oo`L00?moocMo
o`40000000<007ooOol0Egoo100000=oo`00Ool00Woo0P0000Aoo`00Oomoo`<00003Ool007oo00Eo
o`H00?moocIoo`40000000<007ooOol0EWoo00<007ooOol00Woo00D007oo001oo`00009oo`<00004
Ool007oo0002Ool:00000goo001oo`3oOoleOol100000003001oogoo05Qoo`04001oogoo0002Ool0
0`00Ool00004Ool20002Ool400001Goo001oo`00Ool01P00ogoo=Goo0@0000000`00Oomoo`1NOol0
1000Oomoo`000Woo00P007ooOol007oo001oo`000Woo2`00ogoo=7oo0@0000000`00Oomoo`1EOol0
0`00Ool00002Ool00`00Oomoo`03Ool00`00Ool000020003Ool20002Ool400000goo001oo`07003o
OolcOol100000003001oogoo05Moo`<00004Ool000000007Ool00`00Ool00002Ool40005Ool00`00
Ool00005003oOolbOol100000003001oogoo05Yoo`04001oogooOol2000017oo001oo`000Woo0P00
0Woo00<007oo00000Woo3000ogoo<Woo0@0000000`00Oomoo`1FOol00`00Oomoo`03Ool00`00Oomo
o`03Ool2000017oo001oogoo0`000Woo0P0000Moo`00Ool007oo001oo`06003oOolaOol100000003
001oogoo05Uoo`03001oogoo009oo`03001oogoo00Aoo`04001oogoo0002Ool200000goo001oo`02
Ool7000017oo00000000ogoo<7oo0@0000000`00Oomoo`1EOol300000goo0000000300001Goo0000
0000Ool00P0000=oo`0000001@0000=oo`0000000P0000=oo`0000002P00ogoo;Woo0@0000000`00
Oomoo`1HOol00`00Oomoo`05Ool00`00Oomoo`020007Ool200000goo001oo`030002Ool01000Ool0
07oo1P00ogoo;Goo0@0000000`00Oomoo`1JOol00`00Ool00005Ool00`00Oomoo`03000017oo001o
ogoo0P000Woo00@007oo001oo`X00003Ool000000?moobaoo`40000000<007ooOol0E7oo00<007oo
Ool027oo00<007ooOol00Woo00H007ooOomoo`00Ool20002Ool30003Ool30002Ool00`00Ool00006
003oOol[Ool100000003001oogoo05Moo`D00004Ool00000Ool300001Goo001oogoo00000Woo0P00
00=oo`00Ool00goo0P0000=oo`00Ool01`0000Aoo`0000000?moob]oo`40000000<007ooOol0E7oo
00<007oo000017oo00@007ooOol000Eoo`800004Ool000000002Ool01000Ool007oo0P0000=oo`00
Ool00P000goo00@007oo001oo`H00?moobUoo`40000000<007ooOol0H7oo00<007ooOol00goo00@0
07ooOomoo`<000=oo`800003Ool0000000800003Ool0000000X00?moobUoo`40000000<007ooOol0
EWoo00<007oo00000Woo00<007ooOol01Goo00<007oo00000Woo00H007ooOomoo`00Ool20002Ool3
000037oo000007oo001oo`00Ool007oo001oo`@00?moobQoo`40000000<007ooOol0G7oo1@0000Ao
o`00001oo`@0009oo`03001oogoo00800003Ool007oo009oo`04001oogooOol=003oOolWOol10000
0003001oogoo05Qoo`800003Ool007oo00Eoo`03001oo`0000Aoo`800003Ool00000009oo`05001o
o`00Ool00002Ool400000goo001oo`09003oOolVOol100000003001oogoo05Eoo`<0009oo`05001o
o`00Ool00007Ool00`00Oomoo`03Ool200000goo00000002Ool00`00Ool000020002Ool600000goo
00000006003oOolTOol100000003001oogoo065oo`03001oo`0000Eoo`03001oogoo009oo`04001o
ogooOol2000017oo001oogoo100000=oo`0000002`00ogoo8goo0@0000000`00Oomoo`1OOol30000
0goo0000000700000goo00000002Ool01@00Oomoo`00Ool00`000Woo100000Eoo`00Ool007oo00L0
0?moob9oo`40000000<007ooOol0EWoo00<007ooOol01@000Woo00<007oo00001goo00<007ooOol0
0goo0P0000Aoo`00Oomoo`800003Ool007oo00800003Ool0000000`00?moob5oo`40000000<007oo
Ool0FGoo00<007ooOol027oo00@007ooOol000Eoo`03001oo`00009oo`03001oo`0000<00004Ool0
0000Ool400000goo0000000;003oOolOOol100000003001oogoo05Ioo`8000aoo`800003Ool00000
00@00005Ool00000Ool00003Ool01@00Oomoo`00Ool02@0000Eoo`00Ool007oo00H00?mooamoo`40
000000<007ooOol0EGoo00P007ooOol007oo001oo`000Woo00P007oo000007oo001oo`001goo00H0
07ooOomoo`00Ool40002Ool200000goo0000000300000goo0000000;003oOolMOol100000003001o
ogoo05Eoo`03001oogoo00Eoo`8000Uoo`06001oogoo001oo`000Woo00@007ooOol0009oo`07001o
o`00001oo`00Ool00`0000Eoo`00000007oo00`00?mooaaoo`40000000<007ooOol0Fgoo00H007oo
Ool007oo0002Ool01000Ool007oo100000Aoo`00001oo`800003Ool000000080009oo`06001oogoo
Ool007oo2@0000=oo`0000002@00ogoo6Woo0@0000000`00Oomoo`1DOol00`00Oomoo`0400000goo
001oo`02Ool01@00Ool00000Ool00P000goo00D007oo001oo`00009oo`05001oo`00001oo`020000
0goo0000000K003oOolGOol100000003001oogoo05Eoo`03001oogoo00Eoo`<0009oo`05001oo`00
Ool00002Ool3000017oo000007oo0P0000=oo`000000100000=oo`0000000goo1@0000=oo`000000
4000ogoo5Woo0@0000000`00Oomoo`1DOol01@00Oomoogoo00000Woo0P002Goo0P0000=oo`00Ool0
1goo00@007ooOol000Aoo`03001oogoo00D0009oo`03001oo`0000@00003Ool0000000/00?mooaAo
o`40000000<007ooOol0EWoo00<007ooOol00Woo00<007ooOol00goo00<007oo00000P000Woo00<0
07oo00000Woo00@007oo001oo`T00006Ool007oo001oo`000Woo1`0000=oo`0000000P0000=oo`00
00002@00ogoo4goo0@0000000`00Oomoo`1IOol01P00Oomoo`00Ool0009oo`03001oogoo00Moo`80
0005Ool00000Ool00004Ool00`00Ool00003Ool70002Ool00`00Ool0000200000goo0000000?003o
OolAOol100000003001oogoo05Qoo`03001oo`0000Aoo`800006Ool007ooOol007oo0`000Woo00D0
07oo001oo`00009oo`05001oo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`0500000goo0000
000200000goo0000000>003oOol?Ool100000003001oogoo05Ioo`8000Eoo`04001oogoo0004Ool0
0`00Ool00007Ool200001Goo00000000Ool00P0000Aoo`00001oo`<00003Ool0000000D0009oo`80
0003Ool0000001800?moo`eoo`40000000<007ooOol0EGoo00<007ooOol00goo0`001Woo00D007oo
001oo`00009oo`<00007Ool007ooOol007oo00000Woo00D007oo001oo`0000=oo`04001oo`00Ool2
0002Ool2000017oo000007oo100000=oo`0000000P0000=oo`0000002@00ogoo2goo0@0000000`00
Oomoo`1IOol20006Ool200000goo001oo`03Ool2000017oo001oo`000Woo00<007oo00001@0000Eo
o`00000007oo00D00003Ool0000000@00003Ool0000000D00003Ool0000000800003Ool0000000X0
0?moo`Uoo`40000000<007ooOol0FGoo00<007ooOol00goo00<007ooOol01Goo0P0000=oo`00Ool0
17oo0`002Woo00D007oo001oo`0000=oo`03001oo`00009oo`T00003Ool0000000800003Ool00000
00/00?moo`Moo`40000000<007ooOol0EWoo00<007ooOol00goo00<007oo000017oo00@007oo0000
00Ioo`800004Ool007oo0002Ool00`00Ool0000200000goo0000000;000017oo000007oo10000Woo
0P0000=oo`0000000P0000=oo`0000003@00ogoo17oo0@0000000`00Oomoo`1GOol01000Oomoo`00
0Woo00@007ooOol0009oo`03001oogoo00=oo`<000Moo`@00007Ool007ooOol007oo00000Woo0P00
00=oo`000000100000Eoo`00001oo`00009oo`800003Ool0000000D00003Ool0000000h00?moo`9o
o`40000000<007ooOol0EWoo00<007oo00000Woo00@007ooOol000=oo`07001oo`00Ool007oo0000
17oo00@007oo001oo`8000Moo`03001oo`0000800006Ool007oo001oo`000Woo00@007oo001oo`80
0003Ool0000000<00003Ool0000001P00?ioo`40000000<007ooOol0EGoo00<007ooOol017oo00L0
07ooOomoo`00Ool00004Ool200000goo001oo`02Ool30002Ool00`00Ool0000500001Woo001oogoo
001oo`H00003Ool0000000L00004Ool00000OolK003lOol100000003001oogoo05Uoo`8000Aoo`03
001oogoo00Aoo`03001oogoo009oo`800003Ool007oo00=oo`80009oo`04001oo`00Ool200001Woo
00000000Ool0009oo`04001oo`00Ool200000goo0000000V003hOol100000003001oogoo05Qoo`03
001oogoo009oo`8000Aoo`8000Aoo`03001oogoo00=oo`800004Ool007oo0003Ool00`00Ool00002
Ool00`00Ool000070002Ool01@00Ool007oo00000Woo0P0000=oo`00Ool0300000=oo`0000004P00
mWoo0@0000000`00Oomoo`1GOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Ool00003Ool20004
Ool00`00Ool00003Ool00`00Ool000030003Ool400001goo001oo`00Ool007oo00800003Ool00000
00@00004Ool00000Ool200000goo0000000Q003bOol100000003001oogoo05]oo`04001oogoo0002
Ool01`00Oomoogoo001oo`0000=oo`<000=oo`800008Ool007ooOol007oo001oo`8000=oo`D0009o
o`04001oo`00Ool200001Goo00000000Ool00P0000=oo`0000009`00kWoo0@0000000`00Oomoo`1D
Ool20002Ool01000Oomoo`0017oo00<007oo00000Woo00P007ooOol007oo001oo`000Woo10000Woo
0P0000Ioo`00001oo`00Ool200001Woo000007oo001oo`800008Ool00000Ool007oo001oo`H00004
Ool00000Ool600000goo0000000P003ZOol100000003001oogoo05Aoo`03001oo`00009oo`80000;
Ool00000001oo`00Ool007oo001oo`0200000goo00000002Ool200000goo0000000;00000goo0000
000300000goo0000000200000goo00000010003QOol100000003001oogoo05Qoo`03001oogoo009o
o`05001oogooOol00003Ool20004Ool01`00Oomoogoo001oo`0000=oo`80009oo`04001oo`000002
Ool00`00Oomoo`0200000goo001oo`0200001Goo001oo`00Ool00`0000Aoo`00001oo`X00003Ool0
000000800003Ool0000002X00=]oo`40000000<007ooOol0EWoo0P000goo0P000Woo00<007ooOol0
0goo00@007ooOomoo`80009oo`04001oo`000002Ool20002Ool01000Oomoo`000Woo00<007oo0000
0P0000Uoo`00000007oo001oo`00Ool00`0000=oo`0000001P0000=oo`000000?P00e7oo0@000000
0`00Oomoo`1JOol00`00Oomoo`02Ool01@00Oomoogoo00000Woo00D007oo001oo`0000=oo`05001o
ogoo001oo`020002Ool20003Ool30002Ool4000017oo001oo`000Woo10000Woo1@0000=oo`00Ool0
AP00cGoo0@0000000`00Oomoo`1EOol01@00Oomoogoo00000goo0P0000=oo`00Ool00Woo00<007oo
Ool00P000goo00L007ooOomoo`00Ool00002Ool20002Ool20002Ool2000017oo001oogoo0`0000=o
o`00Ool00P000Woo1@0000=oo`000000100000=oo`0000000`0000=oo`0000000P0000=oo`000000
@P00`goo0@0000000`00Oomoo`1IOol00`00Oomoo`06Ool01@00Oomoogoo000017oo0P000Woo0P00
0Woo0P000Woo0`0000Moo`00Ool007oo001oo`0300001goo00000000Ool007oo00<00004Ool00000
Ool200000goo0000000;00000goo0000001@002gOol100000003001oogoo05Ioo`05001oogooOol0
0002Ool2000017oo001oo`000goo00@007ooOol000=oo`04001oogooOol20002Ool20002Ool40002
Ool20002Ool200001goo001oo`00Ool007oo00@00003Ool0000000800003Ool0000000<00003Ool0
000006T00:Eoo`40000000<007ooOol0Egoo00D007ooOomoo`0000Moo`80009oo`80009oo`80009o
o`04001oo`000002Ool20002Ool20003Ool01@00Oomoogoo00000Woo00P007oo001oo`00Ool007oo
0P0000=oo`000000100000Eoo`00000007oo00H00003Ool0000000d00003Ool00000070008Qoo`40
000000<007ooOol0F7oo00D007ooOomoo`00009oo`05001oogooOol00003Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo0P000Woo0P000Woo0P000Woo0`0000=oo`0000000Woo0`0000=oo`000000
5@0000Eoo`00000007oo00@00005Ool00000001oo`3k0001Ool100000003001oo`0005D00003Ool0
07oo009oo`04001oogoo0003Ool01@00Oomoogoo00000Woo00<007oo00000goo00<007ooOol00P00
0Woo0P000Woo0P000Woo0P000Woo0`0000=oo`0000000Woo0`0000=oo`0000001P0000=oo`000000
300000Eoo`00000007oo00@00005Ool00000001oo`3i0001Ool100000003001oogoo05Eoo`05001o
ogooOol00003Ool01@00Oomoogoo00000goo0P000Woo0P000Woo00@007ooOol0009oo`80009oo`80
0004Ool007oo0003Ool03@00Oomoo`00Ool007oo001oo`00Ool007oo00@00004Ool00000Ool30000
0goo0000000D00000goo0000001b0028Ool100000003001oogoo05Aoo`05001oogooOol00003Ool0
2@00Ool007oo001oo`00Ool00002Ool01@00Oomoogoo00000goo00@007ooOomoo`80009oo`800004
Ool007ooOol20002Ool30002Ool01P00Ool007oo001oo`800005Ool00000001oo`0600000goo0000
0002OolC00000goo0000001C002UOol100000003001oogoo05Moo`05001oogooOol00008Ool00`00
Oomoo`06Ool20002Ool20002Ool20002Ool01P00Ool007oo001oo`<00005Ool00000001oo`030000
0goo001oo`0200001Goo00000000Ool00P0000=oo`0000002`0000=oo`000000CP00]goo0@000000
0`00Oomoo`1GOol01000Oomoogoo0P0000Ioo`00Ool007oo0002Ool20002Ool20003Ool00`00Ool0
0002Ool20002Ool3000017oo000007oo0P000Woo0P0000=oo`00Ool00`000Woo00D007oo000007oo
00D00003Ool0000000d00003Ool0000004000<=oo`40000000<007ooOol0F7oo00<007ooOol01Woo
00H007ooOomoo`00Ool2000017oo001oo`000goo00<007oo00000Woo0P000goo00@007oo001oo`<0
00=oo`03001oo`0000=oo`<0009oo`800004Ool00000Ool800000goo0000000o003=Ool100000003
001oogoo05Aoo`8000=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo0P000Woo00<007oo
00000goo0P000Woo00P007oo001oo`00Ool007oo0P000Woo00P007oo001oo`00Ool007oo1@0000=o
o`0000000P0000=oo`000000?P00e7oo0@0000000`00Oomoo`1JOol00`00Oomoo`02Ool01000Oomo
ogoo0P000goo00<007ooOol00Woo00@007oo001oo`@0009oo`<000=oo`800004Ool007ooOol40003
Ool00`00Ool000020002Ool500000goo0000000200000goo0000000A00000goo0000000O003KOol1
00000003001oogoo05Ioo`03001oo`00009oo`8000=oo`03001oogoo00=oo`05001oogoo001oo`02
0003Ool00`00Oomoo`02Ool20002Ool01P00Ool00000Ool0009oo`@0009oo`<00005Ool007oo001o
o`0E00000goo0000000T003QOol100000003001oogoo05Ioo`80009oo`03001oogoo00800007Ool0
07oo001oo`00Ool00`0000Moo`00Ool007oo001oo`050002Ool500000goo001oo`0700000goo0000
000m003VOol100000003001oogoo05Uoo`04001oogooOol20004Ool01000Oomoo`000goo00H007oo
Ool007oo0003Ool00`00Ool000020003Ool200001Woo00000000Ool0009oo`<00003Ool0000000@0
0003Ool0000000@00003Ool0000002@00>moo`40000000<007ooOol0EGoo00@007ooOomoo`8000Ao
o`07001oogooOol007oo00000goo00<007oo00001Goo0P001Goo0`0000Ioo`00Oomoo`00Ool20000
1Goo000007oo00000Woo100000=oo`000000100000Aoo`00001oo`D00003Ool0000001T00?9oo`40
000000<007ooOol0EGoo00<007ooOol00goo00<007ooOol00goo00<007ooOol00Woo0P001Goo0P00
17oo100000Ioo`00Oomoo`00Ool20004Ool01@00Oomoo`00Ool00P0000Aoo`00001oo`<00004Ool0
0000Ool200001goo00000000Ool007oo01P00?Ioo`40000000<007ooOol0EWoo0P0017oo0P0017oo
00<007oo00000goo0`000goo00D007oo001oo`00009oo`800003Ool0000000=oo`03001oogoo00D0
0005Ool00000001oo`09000017oo000007oo0P0000=oo`0000006000n7oo0@0000000`00Oomoo`1H
Ool00`00Ool00002Ool01000Oomoo`000goo00<007oo00000goo00<007oo00000Woo00@007oo0000
00Aoo`04001oo`00Ool500001Woo001oo`00Ool0009oo`800004Ool007oo0002Ool2000017oo0000
07oo0P0000=oo`0000005@00o7oo0@0000000`00Oomoo`1NOol01@00Oomoogoo00000Woo00@007oo
Ool0009oo`<000Eoo`H00006Ool007ooOol007oo2@0000Aoo`00001oo`P00004Ool00000OolF003n
Ool100000003001oogoo05Aoo`03001oo`00009oo`04001oogoo0003Ool00`00Oomoo`02Ool01000
Ool0000017oo00P007oo000007oo001oo`000goo00<007oo00000P0000Ioo`00000007oo0002Ool0
0`00Ool0000>00000goo0000000B003oOol2Ool100000003001oogoo05Eoo`04001oogoo0002Ool0
1000Oomoo`000Woo00<007ooOol00goo00<007oo00000Woo00<007ooOol00goo0`000Woo00<007oo
00001goo1`0000=oo`00Ool07P00ogoo17oo0@0000000`00Oomoo`1DOol00`00Oomoo`04Ool20006
Ool20006Ool2000017oo001oo`000Woo00<007oo00001@0000=oo`0000001`0000Eoo`00000007oo
00800003Ool0000001L00?moo`Moo`40000000<007ooOol0Egoo00<007ooOol00goo0P001Woo0P00
00Aoo`00Ool0009oo`<00003Ool007oo00Eoo`06001oogoo001oo`000Woo00D007ooOol007oo0080
009oo`800004Ool00000OolE003oOol9Ool100000003001oogoo05Qoo`8000Eoo`800003Ool007oo
00=oo`8000Ioo`03001oo`0000D00004Ool00000Ool=00000goo0000000200000goo0000000B003o
Ool;Ool100000003001oogoo05Yoo`03001oo`0000Eoo`05001oo`00Ool00002Ool300001goo0000
07oo001oo`00009oo`05001oo`00Ool00003Ool00`00Ool00002Ool00`00Oomoo`0500000goo0000
000200000goo0000000200000goo00000009003oOol=Ool100000003001oogoo05Eoo`03001oogoo
00=oo`06001oogoo001oo`000Woo00<007oo000027oo00D007oo000007oo008000=oo`05001oo`00
001oo`080002Ool2000017oo000007oo4@00ogoo3goo0@0000000`00Oomoo`1FOol00`00Ool00004
Ool00`00Oomoo`03Ool00`00Ool0000300001Woo001oo`00Ool0009oo`04001oo`00Ool70003Ool0
0`00Ool0000500001Goo00000000Ool04000ogoo4Goo0@0000000`00Oomoo`1GOol01`00Oomoo`00
Ool007oo008000Uoo`800003Ool007oo00Ioo`04001oogoo0002Ool00`00Ool0000200001Woo0000
07oo001oo`X00003Ool0000000P00?mooa=oo`40000000<007ooOol0FGoo00<007ooOol00goo00X0
07oo000007oo001oo`00Ool0009oo`04001oo`00Ool200001Goo00000000Ool00P0000Ioo`000000
07oo0002Ool00`00Ool0000300000goo0000000300000goo0000000:003oOolDOol100000003001o
ogoo05Ioo`03001oogoo008000Uoo`8000Yoo`06001oogoo001oo`000Woo00@007ooOomoo`@00004
Ool00000Ool500000goo0000000;003oOolFOol100000003001oogoo05]oo`<0009oo`03001oogoo
00Aoo`<00005Ool00000Ool00004Ool4000027oo000007oo001oo`00Ool600000goo001oo`0>003o
OolGOol100000003001oogoo05Eoo`<000Eoo`03001oo`0000<0009oo`03001oo`00009oo`03001o
ogoo00<00003Ool00000009oo`05001oo`00001oo`0200000goo0000000E003oOolIOol100000003
001oogoo05Qoo`07001oo`00Ool007oo00000Woo00<007oo00001`000Woo0P0000Aoo`00001oo`@0
009oo`03001oogoo0080009oo`<00003Ool0000000/00?mooaaoo`40000000<007ooOol0FGoo00<0
07oo00003Goo00<007oo00001Goo00<007ooOol00Woo0P0000Aoo`000000009oo`800003Ool00000
00d00?mooaeoo`40000000<007ooOol0EWoo00<007oo00000goo00<007oo00000goo00D007oo001o
o`0000Moo`04001oogooOol3000017oo000000000Woo0P000Woo1@0000=oo`00Ool01`00ogoo7goo
0@0000000`00Oomoo`1DOol00`00Oomoo`04Ool01000Ool007oo0P0000=oo`0000001Woo00D007oo
000007oo00800004Ool00000Ool200000goo00000003Ool2000017oo000007oo2`00ogoo7goo0@00
00000`00Oomoo`1FOol00`00Oomoo`0<Ool60002Ool01000Oomoo`000goo10000Woo0P000goo3@00
ogoo8Goo0@0000000`00Oomoo`1DOol00`00Oomoo`020002Ool01P00Oomoo`00Ool0009oo`03001o
ogoo009oo`04001oogoo0002Ool00`00Oomoo`0200000goo00000002Ool01000Oomoogoo100000Eo
o`00Ool007oo00H00?moob9oo`40000000<007ooOol0FGoo0`002Woo00<007ooOol00goo00H007oo
000007oo0003Ool300000goo00000003Ool<003oOolSOol100000003001oogoo05eoo`800005Ool0
0000001oo`0200000goo000000030003Ool00`00Oomoo`0300001Woo000007oo001oo`@00003Ool0
000000L00?moobAoo`40000000<007ooOol0FWoo00<007oo00000Woo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol00P000Woo00@007oo001oo`8000=oo`D00003Ool0000000800?moobIoo`40
000000<007ooOol0EGoo00@007ooOol000Uoo`03001oo`0000=oo`05001oo`00001oo`020002Ool0
1000Ool007oo0P0000=oo`00Ool03000ogoo9goo0@0000000`00Oomoo`1FOol200000goo001oo`05
Ool00`00Oomoo`02Ool01000Ool007oo0`000Woo00@007oo001oo`800003Ool00000008000=oo`04
001oo`00Ool5003oOolXOol100000003001oogoo05Uoo`D00005Ool00000001oo`0200001Goo001o
ogoo00000Woo0P0000=oo`00Ool00goo00D007ooOol007oo00L00003Ool0000000800?moobQoo`40
000000<007ooOol0EWoo00<007ooOol027oo00<007ooOol00Woo00@007ooOomoo`@0009oo`<0009o
o`<000=oo`03001oo`0000H00?moobUoo`40000000<007ooOol0GWoo00<007ooOol00goo00@007oo
Oomoo`8000Aoo`80009oo`04001oo`00Ool:00000goo0000003oOolZOol100000003001oogoo05Yo
o`03001oo`0000Eoo`800004Ool000000003Ool200001Woo000007oo001oo`<0009oo`04001oo`00
Ool2000017oo00000000ogoo:goo0@0000000`00Oomoo`1EOol5000017oo000007oo0`0000Eoo`00
Oomoo`00009oo`03001oogoo008000=oo`800004Ool007ooOol:003oOol]Ool100000003001oogoo
05eoo`03001oogoo00=oo`05001oogoo001oo`03000017oo000000000goo0P0000Eoo`00Ool007oo
00L00?moobeoo`40000000<007ooOol0F7oo00@007ooOol000Aoo`08001oogoo001oo`00Ool0009o
o`800005Ool00000Ool00003Ool7000017oo00000000ogoo;Woo0@0000000`00Oomoo`1FOol00`00
Oomoo`02Ool01@00Oomoo`00Ool00`0000Aoo`00Oomoo`L00003Ool0000000d00?moobmoo`400000
00<007ooOol0E7oo00<007oo00001@0000Aoo`00Ool0009oo`03001oogoo00<00003Ool007oo00D0
0007Ool007oo001oo`00Ool01@00ogoo<Goo0@0000000`00Oomoo`1GOol00`00Oomoo`02Ool00`00
Oomoo`04Ool2000017oo001oogoo0`000Woo2@0000Aoo`0000000?mooc9oo`40000000<007ooOol0
E7oo00<007ooOol00goo00<007ooOol00goo0P0000=oo`00Ool00Woo0P000Woo0P0000=oo`00Ool0
17oo00<007ooOol01000ogoo<Woo0@0000000`00Oomoo`1HOol00`00Oomoo`02Ool00`00Ool00002
0002Ool01@00Ool007oo00000Woo100000Eoo`00Ool007oo00H00?mooc=oo`40000000<007ooOol0
EGoo00<007ooOol00Woo10001Goo00<007oo00000goo0P0017oo1@0000=oo`0000000P00ogoo=7oo
0@0000000`00Oomoo`1EOol300000goo001oo`03Ool01@00Oomoogoo00000goo0`0000=oo`000000
0P0000Eoo`00Ool007oo00800003Ool000000?moocEoo`40000000<007ooOol0FGoo00@007ooOol0
00Aoo`07001oo`00Ool007oo00000Woo00<007oo00002P00ogoo=Woo0@0000000`00Oomoo`1FOol0
0`00Oomoo`05Ool20003Ool20003Ool200000goo001oo`03Ool00`00Oomoo`04003oOolfOol10000
0003001oogoo05Yoo`@0009oo`05001oo`00Ool00002Ool00`00Ool00002000017oo000007oo1P00
ogoo=goo0@0000000`00Oomoo`1GOol30007Ool01000Oomoogoo0P000Woo00<007oo0000100000=o
o`0000000P00ogoo>7oo0@0000000`00Oomoo`1EOol00`00Ool00002Ool03000Oomoogoo001oo`00
Ool007oo001oo`<00006Ool007ooOol007oo1@00ogoo>Goo0@0000000`00Oomoo`1EOol00`00Oomo
o`06Ool20003Ool01@00Oomoo`00Ool00`0000=oo`0000001P00ogoo>Goo0@0000000`00Oomoo`1H
Ool01P00Oomoo`00Ool000Aoo`04001oo`000002Ool00`00Ool0000200000goo00000003003oOolj
Ool100000003001oogoo05Ioo`07001oogooOol007oo00000goo00D007ooOol007oo00<00005Ool0
07oo001oo`05003oOolkOol100000003001oogoo05Moo`<000Eoo`03001oo`0000=oo`03001oo`00
00X00?mooc]oo`40000000<007ooOol0E7oo00@007oo0000009oo`04001oogoo0004Ool00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool00002003oOollOol100000003001oogoo05aoo`03001oo`00
009oo`0;001oo`00001oo`00Ool007oo001oo`05003oOollOol100000003001oogoo05Aoo`04001o
ogooOol500000goo0000000300000goo0000000:003oOolmOol100000003001oogoo05Eoo`800003
Ool00000009oo`8000=oo`<000=oo`03001oo`0000D00?moocioo`40000000<007ooOol0EGoo00<0
07ooOol00goo00<007ooOol00Woo00<007ooOol02`00ogoo?goo0@0000000`00Oomoo`1FOol01000
Oomoo`0017oo0P000Woo0P0000Aoo`00Ool0009oo`<00?mood1oo`40000000<007ooOol0F7oo00<0
07oo00000Woo00@007ooOol000Eoo`03001oo`0000800003Ool007oo0?moocmoo`40000000<007oo
Ool0Egoo00D007ooOomoo`0000Eoo`L00004Ool00000003oOom1Ool100000003001oogoo05Eoo`04
001oogoo0002Ool20002Ool00`00Ool00002Ool01@00Ool00000Ool00`00ogoo@Goo0@0000000`00
Oomoo`1EOol00`00Oomoo`02Ool01000Oomoo`001Goo00@007ooOomoo`@00?mood9oo`40000000<0
07ooOol0F7oo0P0017oo0P0000Eoo`00Ool007oo00800003Ool000000?mood=oo`40000000<007oo
Ool0EWoo0P000Woo00<007oo00000goo2P00ogoo@goo0@0000000`00Oomoo`1FOol01000Oomoogoo
0P000Woo00H007oo001oo`00Ool5003oOom4Ool100000003001oogoo05Moo`03001oo`00009oo`80
00Ioo`800003Ool000000?moodAoo`40000000<007ooOol0E7oo00D007ooOomoo`0000Eoo`H00004
Ool00000003oOom5Ool100000003001oogoo05Aoo`05001oogooOol00002Ool00`00Oomoo`05Ool0
0`00Ool00002003oOom5Ool100000003001oogoo05Ioo`04001oogoo0003Ool01P00Ool007oo001o
o`@00?moodIoo`40000000<007ooOol0EGoo00<007ooOol00Woo0P001Goo0P0000Aoo`0000000?mo
odIoo`40000000<007ooOol0EGoo0P0000=oo`00Ool00Woo1@0000Eoo`00001oo`000?moodMoo`40
000000<007ooOol0Egoo00@007ooOol000Eoo`03001oo`0000<00?moodMoo`40000000<007ooOol0
Egoo0P000goo00@007oo001oo`800003Ool000000?moodQoo`40000000<007ooOol0EGoo00@007oo
Oomoo``00?moodQoo`40000000<007ooOol0EWoo0P001Goo00@007oo0000009oo`03001oogoo0?mo
odMoo`40000000<007ooOol0Egoo00D007oo001oo`0000=oo`@00?moodYoo`40000000<007ooOol0
EWoo00<007oo00000goo0`0000Aoo`0000000?moodYoo`40000000<007ooOol0E7oo00@007ooOomo
o`@0009oo`800003Ool007oo0?moodYoo`40000000<007ooOol0EWoo00<007ooOol00goo00<007oo
00000`00ogooBgoo0@0000000`00Oomoo`1DOol02000Oomoogoo001oo`00Ool5003oOom<Ool10000
0003001oogoo05Eoo`8000Aoo`<00003Ool000000?moodaoo`40000000<007ooOol0Egoo10000Woo
0`00ogooCGoo0@0000000`00Oomoo`1KOol00`00Ool00002003oOom=Ool100000003001oogoo05Eo
o`06001oo`00Ool007oo0P0000=oo`000000ogooCGoo0@0000000`00Oomoo`1JOol00`00Ool00002
003oOom>Ool100000003001oogoo05Eoo`H0009oo`800?moodioo`40000000<007ooOol0EWoo00H0
07ooOomoo`00Ool2003oOom?Ool100000003001oogoo05Qoo`03001oo`0000<00?moodmoo`400000
00<007ooOol0E7oo00<007oo00000Woo00<007oo00000P00ogooCgoo0@0000000`00Oomoo`1GOol2
000017oo001oo`00ogooD7oo0@0000000`00Oomoo`1DOol400001Goo000007oo0000ogooD7oo0@00
00000`00Oomoo`1GOol00`00Ool00003003oOom@Ool100000003001oogoo05Eoo`@00003Ool00000
0?mooe5oo`40000000<007ooOol0EGoo0P000Woo0P00ogooDWoo0@0000000`00Oomoo`1FOol00`00
Ool00002003oOomBOol100000003001oogoo05Moo`<00?mooe=oo`40000000<007ooOol0E7oo00<0
07oo00000`00ogooDgoo0@0000000`00Oomoo`1DOol2000017oo001oo`00ogooDgoo0@0000000`00
Oomoo`1FOol00`00Ool0003oOomDOol100000003001oogoo05Eoo`800003Ool007oo0?mooe=oo`40
000000<007ooOol0EWoo0`00ogooE7oo0@0000000`00Oomoo`1EOol3003oOomEOol100000003001o
ogoo05Ioo`800?mooeEoo`40000000<007ooOol0E7oo0`00ogooEWoo0@0000000`00Oomoo`1DOol3
003oOomFOol100000003001oogoo05Ioo`03001oogoo0?mooeAoo`40000000<007ooOol0EGoo00<0
07ooOol0ogooEGoo0@0000000`00Oomoo`1DOol2003oOomGOol100000003001oogoo05Aoo`800?mo
oeMoo`40000000<007ooOol0E7oo00<007ooOol0ogooEWoo0@0000000`00Oomoo`1DOol00`00Oomo
o`3oOomFOol100000003001oogoo0?moojeoo`400000o`00/@000000\
\>"],
  ImageRangeCache->{{{0, 431}, {265.875, 0}} -> {0, 0, 0, 0}},
  ImageSoundCache->{{{0, 431}, {265.875, 0}} -> GraphicsData["MacintoshSound",
   "\<\
00400@050000X001P540000001@00000002P0200000000000000000lP820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820P820
P820P820P820P820P820P820P820P820P83oM`2AoFD3X_UD2K?bA172jSDKdMlX
9]gB73CXa193lKD:D_RT1F?lT`9eoX81Q_i`0iOkG`NXmTl=^>ho5LOU<B3EfB@/
h<`I>^Zn44Wb[PUIn9h5J_b=0g_mN`><nfX5WOQI2ZkbBA6mjS/Jbn0]9MSD8C;S
aQM0k;L?CoBX2F3hU`E`nhH4PO]e1I;iI0RSm5@>/ni45L;U=Qo?fRT[g<hN>>K0
5DK^/@iFm:48I_RA1WOjP0F8nFl7V?IN2jWaCa6hjT0Ja^0b9=?E9S3Nb1`nj;XC
C>n[3EceV`Q]n8X7OOUi1hkgJ@ZNleT>[^e95[gU>ao:fbhYem0S=^726DCZ]19C
l:@<HoFD2G?gQ0R3mg<9U?ES3:C`Da:cjDDJ`N4g8lkF:boJbR0lhk`GB^^^4EWa
WPaYmHh9NOIn2HWeKP^IlUh@ZNe>5[SU@1k6g3<Xd]4X==g47T;U]QI@k:P@Go6H
36odR0YomGP;So=X3Yo_F1>^jDXJ_>4l8lWG<2kEbbDjgklLAnN`5EK]X@mUlI8<
MO>238GcLPfEl68AY>aC5[?UAAk1g3PXcM8/<mS68SoQ^AY=j:XDG>jK3f_aS0ek
lW`=Ro5/3i[^GABYj4hJ^>518lGH=2g@cBThfl4PAN>c65?ZYA=RkYD@LO263X7a
MPnAkfLBX>]H5jkUBQjlgCdWb=<a<]?89ckM^ai;iJdGFNZO4fS^Sa1gkh0@Qnma
4IK/HQFUie<K/n558/3H>Bc<cRhge/8T@mne757VYaMOjiTCK^j:4Gg^NQ6<kF/D
VnUL6:[TCQjggD4Wa=@e<Lo9:ccI_B99hK0KE^NR5VG[Ta=dkH@BPnee4i;[IQJP
iePK[^1:8[_I?B_7cc8ed/@X@M^g84kRZQYLii`FJ^^=57W/OQ>8jflEUnQQ6JGS
DancgDHV_m@j<<_:;c[D_bI7gK8OE>>T6F;XUQI`jXPDOn]i5HkYJQNLiU`LZ^1>
8[OI@R_3d3Ldc/D]?mNi94cN[AiIi9lIInRA5WKYPQJ4jG<GTnMU6Z7SEan^g4XV
^mDn;lK;=3W@`2Y5fK@SDMnW7EoTVAU]ih/GNnQm5h[WKQVHi60MY]mC8k?IARZo
d3/cbLHa?]>k:4[J[b5Gh:8LI>FD6G;WQQR1igLISnEY6igRG22Zg4lV]mE3;/;<
>3S<`Ri3eKHVCmbZ85cQW1aZi8hJN>J06HKULQ^Dhf@NXMmG8jkIBbZjdClcaLPe
?Lnm;4SG/BEDgJ@PHN6G76oTRAYmiG/KRnA]7IWQH26Vg5<V/]E7;[k=?3O8`c91
dKPZCMR/95WNWamWhY8LM>>46h;TMQb@hVPOWMiK9:[HCbZfdD<b`LPi?<^n<4KC
/bUBfJLSGmjJ7fcQS1eihglLQn9a7YGOI2:RfeLW[]E;;[[=@3K4a3I0cKX^BmF^
9eOJXR9TgiDOLN677WoQNQj<h6`PVMeO9:KHDbZbdDLb_LTm>lO0=4G?]Ba@eZTV
G=^L8VWOSamfh88OQ>1e897NJ2>NfU/WZ]E?;[K>A3K0aCXobK/bBM6`:eGGY2EQ
g9LRK]j:87_OOB28gg0RUMaS9J;GEbZ^dD/a^LY1>/?1>4?;]S1>dj/ZF]RO9FKL
TR9cgXDQP=ih8HgMJbBJfElXY]AC;[;>B3FlaShnaK`eB<fb;U?DYRUOfIXUJmb=
8WSMPB:5gG@ST]]W9YkGFb^ZdDla]LY5>Ko2>d;8^3=<cjd]F=FQ:6CIUBA`g8TS
OMal8h[KKbFFf6<YX]AG;Zk>C3FhaT8m`[diA/Zc<U7AZ2aLeYdWJ=V@9GGKQ2B2
fgLUS]U[9i[FGb^VdE<a/LY9>;_2?d74^CM;c:l`E]:T:f7FV2M]fH`UN]Yo9HKJ
LbJCefHYWm=K;Z[>D3FdadHl_[hmALJe=Do=ZRmJdilZI]JC9g;IQbInfGXVRmQ^
:9OEHRbRdELa[LY<>;O3@d30^S]9b;0cE<nV;UoCVRY[ehhWMmR29h?HMRR?eVXZ
Vm=N;jK>DcBaadTl^[m0A<>f>Dk:[39Hd:4]I=BF:VoFRRQkeghXQmIb:Y?DIRfO
d5/bZ/Y@>;C4ASnm^ci8aK8gD/^X<Eg@WBeXe94ZM=J5:H3FNBV<eFd[Um9R;j?=
EcF]addk]l14@kng?4c7[SEFcJ<`HM6H;6gDS2YheH4ZQ=Ee:i3CJBjKcehbY/YD
>;34BSni_457`K<jDLRY=5_>WbmVdI@/LMB8:ggDO2^9dg4]U=5U<9o=FcFZae4k
/l17@[bh?d_3[cQEbJDcGljJ;f[ASbafdh@/PM=h;8gBKBnHcf8bXlYG>:g4CSjf
_DE6_[@mClF[=eW;XC9TciH_Km6;;G[BObf5dW@^TM1Y<Ic<GSFVae@k/<5;@[Ri
@d[0/CaCaZLfGL^M<VS?TRmcdHH^O]9k;X[@L32EcVDcWlYK>:W4DCjc_DQ5^kE1
C/:]>UO8XcEQc9PaK<n=;gOAPRj2d7L_S/m/<YS<HCFSaeLk[<5>@KFjATVm/SmB
`jPiFlVO=6K=U35`chT_Nm1n;hO?Lc6AcFPdW<UN>:K4E3j__Ta5^;I4CKn^?EK5
Y3QPbIXdJ/f@<GG?QC20cgXaR/i_<iG;ICJOae/kZL5A@K:kBDRj/d9A`:XlF/JP
=fC:US=^cH`aNLj1<HC>MS:>c6/eVLUQ>:?4F3j/_Tm4];M7C;b_@5C2YS]Nai`f
J<ZB<g;<R39mcGdbR<ab=9;:J3NLaUhkY/5E@JnkC4Ng]4E?_J/oF<>R>V;7V3I/
bXhdM/b4<h7<NC>;bfheU/QT>Io4FcjY_U94/KQ:BkV`@e>oZ3eLa9hiI/RD=W3:
RSAjbh0dQL]e=Ho9JcNIaV4kXl5H@:^kCdNc]4Q>^Ze1El2T?635VSQZb90fM<Z6
=7k;O3F8bW4fTlMW>Ic4GSjV_eE3[[Q=B[JaAU:lZD1K`J0kI<JF>6k8S3IhbX8e
P/Yh=Xc8KSRFaF@lX<5K@:RlDdJ`]D]>^:i4EKjU?ek2W3]XaY8hLLR8=Wc9OSJ6
b7@gT<IZ>YW3HCjR_eQ3ZkU@B[>bBE6iZT=I_j8nH/>H>V_6ScQeb8DgOlQk=hW7
LCVCaFLlW<5N@JFlETJ]]Ti=]Jm7E;^W@Ug0WSeVa9@jKlJ;>7W7PCR3agLiSLE]
>iK3I3jO_U]3Z;UCBK2cC52fZdIH_:=0H<6J?F[4TCYcaXLiOLMm>HO6M3Z@a6Xm
V/1Q@J:lFDJZ]U5</Zm:DkRXA5^mWd1T`IHlKLB=>WO6PcV0aWXjR/A`?9C2IcnM
_Ui3YKUFBJfcCdnd[4QG^JA3GkjL?fS2Tcaaa8TjN/F0>XC5MS^>`fdmUl1T@Inl
FdJX]UA<[k1=D[FYAeZkXD9R_iPnJl:??7G4QS]na7`kQl=c?I71JSnJ_V53X[UI
B:ZdDTna[D]F]jI6GKbM@FJoUCi_`X/lN<>2?8;3NCb;`W0nU;mW@IflGTJU]eM;
[;5@D[>ZBEVhXTAQ_IY1JL2A?W;2R3el`gllQL9e?Xk0K42G_FA4WkULB:NdE4j^
[TiE]:M8G;VOA6BmUT1]`8hnM/:4?Go2Ncf8`G8oTKmY@YZkHDJR]eU;ZK5BDK2[
C5RfXdMP^Y]3J;jC@730RSii`H4nPl5h?hc0Kd6D_FM4WKUNB:BdEdj[[U1D/ZQ;
FkNPAV>kV49[_Xm0M<27?gg0OSn6`7E0Ski/@YNkI4JO]ea;Yk9ED:f[CeNcYDUN
^9e5I[bE@VnnS41g`8<oP<1j@8VoLT6B_6U4V[UQB::dFTfY[e=C[jU=F[BQB66i
VTAZ_952L[j9@7^oP423_gM1S;e_@iFkITJM]em;Y;9HD:^/DEJaYTaM]Yi7IKVF
A6flST9e_XE1O[im@HNnM4:?_6a5UkUTB9ndG4fV[eIC[JU@FK:RBf2gVdMX^Y=4
L;b;@WVnPT61_WY2R[aaA9:jJDNJ]f5;XK9JCjR]E5F^YTiL/im:HkNHAV^jT4Ac
_8M2O;eo@XBmMT>=^fi5UKQVBIbdGdfT/5QBZZYBF;2SCEndW4UV^9E6K[^=A7Nl
Q4=o_7a3Qk]dA92iJdNG]VA;Wk9MCjJ]EUF/Ye5K/J5<H[FIB6ZhTDEb^hU4N[b1
@h:kNDB:^W56T[QYBIZdHDfQ/5]BZ:]EEjfTCejbWT]U]YI8KKV>AGFjQTAm^gi4
QKYfAHfiKTNE]VI;W;9OCj>]FEBYZ5=J[j9>HK>KBVRfTdM`^H]5N;Z3AH2jNdF8
^G=7T;M[BIRdI4fO/5eAYJ]GEj^UDUf`WdeT]9Q:JkN@Ag>iR4Ik^X15PkUhAX^h
L4RC]VU;V[9RCj6^FeBWZ5EI[:9@H;6LC6NdUDU^]he7M[V5AWjiODJ6^7E7S[M^
BYFdITfL/5mAXj]IEZVVE5b^X4mS/YU<J[FBBG6gRTMi^897PKQjAhVgLdV@]F];
V;9TCij^GE>UZEQIZZ=CGjnMCVJbUT]]]Hm9M;N7AgbhOdN4]gM8RkI`BY>cJDfJ
/69AX:aLEZJVEU^[XE5R/9Y=J;>CBg2eS4Ug]hA8OkMlB8NfMDV>]Fe<UK9VCib^
H5>RZEYHZ:AEGZfND6BaUde[/i1:LkF9BGZfPDR2]WY9RKEbBi6cJdfH/6AAWZaN
EJBWF5^YXE=Q[Y]?Ik6DC6jdSDYe]HI9OKInBHBeMdZ<]71<Tk5YCiZ^HU>PZUaH
YZEGGJZODV>_V4mZ/Y9<LKB:BWRePdZ0]Ga:QkAdBhjcKDjE/6IAW:aPEJ:WFUZW
XUIP[9aAIZnFCVfbSdad]8Q;NkF0BX:dND^:/g9=TK5[CiR^I5>NZUiGXjEIGJRP
E6:]VE5Y/9=>L;:<C7NdQD]n]7e;QKAfC8bbKdjC[fUAVZaREJ2XGEZUXeQOZYeC
IJfGD6^`T4ib/XU<NK>2Bh6cNdb8/gA=Sk5]D9F^IU>LZV1GXJIKG:JPEV:[VU=X
[YA@K[6=CGFbQTal/gm<Pk=hCHZaLDnA[f]AUjaTEIfXGeVSXeYNZ9iEI:bHDVZ_
TDma/H]=N;:4CGnbODf6/WI>SK1_D9>^JE>IZV=GWjIMFjBQF66YVeAW[9EAKJn?
CgBaR4ij/X5=PK9jCXRaLdn?[feBUJaWEI^XHEVQY5aNYYmGHjZIE6V]Te5`[ha?
M[65CWfaOdj4/GQ?Rk1aDI6]Je>GZVEGWJIOFj:RFV2WW5IVZYICK:f@DG:_RTmi
/H=>P;5lChJ`ME2=[VmBTjaYEIVXHeVOY5iMY9mIHZRJEFR[U59^[Xi@MJn7Cg^`
P4n2/7Y?RJmcDHn]KE>EZVMGVjIQFj2RG5nUWEQUZIMEJjbADW6^Re1g[hA?O[1n
ChF_Me2;[W5BTJ][EINXIEVMY61MXZ1KHZJKEfNYUEA][8mBLjj8D7Z_PU20[g]@
QjieDXf/KeBCZVUGVJMSFYjRGUnSWUYTYiQFJZZCE72/S59f[XIAO:moD8>^NE69
[G=CSj]]EIFXIeRKYF9LX:1MHJBKFFJXUUI/Zi1CLZf:DWR^Q55o[WeAQJegDX^/
LEBAZV]GUjMUFYbSH5jQWUaSYIUHJJRDEFj[SU=d[HMBNjf1DH6]Ne:7[GECSZ]_
EI>XJERIYFALWZ5OHJ:LFfFVUeM[ZI5ELJ^;DgN]QE9m[GmBPjeiDhZ[LUB@ZFeG
UJMWFYZSHUjOWeiSXiYJJ:NEEffYSeEcZhUCNJb3DWn]O5>6[7IDS:Y`EY:XJeRG
YFELW:5QH:2MGFFTV5UZYi9FL:Z<E7F[QU=l[81CPZajE8R[M5F>ZFiGTjIYFYVS
I5jMWemRXY]LIjFEF6bXT5IbZXYDN:^4E7j/OUB4ZgQDRZYbEY2XKEVEYFMLVZ5S
H9nMGVBSV5]YYY=HKjR>EWBZR5AjZh9DP:]lE8JZMUF<ZG1GTZI[FYNSIUjLX65R
X9]MIZ>FFV^VTEMaZH]FMZZ6EGb[P5B2ZWYER:UdEhjWKUVCYFULV:9TGifNH6BQ
VEaXY9AIKJN?Eg>YREIiZX=EOjYmEHBZN5J:Z79HT:I]FYFSJ5fJX6=QWYaOIZ:G
G6ZUTUU`YheGMJV7EW^ZPEF1ZW]FQjUfEhbWL5VBYF]LUj9VGi^NHV>OVUiXXiEK
KJF@F7:WRUMgZHEFOJUoEX>YNEN9Z7AHSZI^FY>SJEfHX6EQW9aQIJ2HGFZSTeY_
YXiHM:R8EgZYPeIoZGeGQJQgF8^WLUV@YFeLUJ9XGiVNHf>NVV1WXIILK:BAFW6V
S5QfZ8IGO:R0Eh6XNeN7YgEIS:I`Fi:SJefFX6IQVieRI9nHGfVRU5a^Y8mJLjJ9
F7RWQ5MnZ7iGPjMiF8VVLeZ>Y6iLTj9YGiROIF:LVf5VX9INJj:BFg2USEUeYXMH
NZN2F82WO5R5YgMIRjEbFi2SKEfEX6QPVIeTI9fIH6RPU5e]Xi1KLZF;FGNVQEQm
Yh1HPZMjFHNVMEZ=Y71LTZ9[GiJOIf:JVf=VWYMOJZ6BGFnSSU]dYHQINJJ3FGnV
OUV4YWQIRJEcFhjSKUfCX6YPUieUI9^IHVROUEm/XY5LLJB<FWJUQUUkYX5IPJIl
FHJUMeZ;Y75LT:9]GiFOJ6:IVfAUW9QQJZ2CGVjRSeacY8YJN:F4FWfVOeV3YGYJ
R:AeFhfSL5fAX6]PUYeWHiZJHfNMUV1[X95NL:>=G7FTR5YjYH9JOjEmFXBUN5^9
Xg=LSZ5^Gi>OJV:GW6IUViQRJIjDGffQSeebXh]KMjB6FWbUP5Z1YG]KQZAfG8^R
LEj@X6ePU9eYHiRJIFNLUV9[Wi9OKj6=GGBSRE]iY8AKOZAoFh>TNE^8XgEMSJ5`
Gi6OJf6FW6MUVIUTJ9fEHFfOT5iaXXaMMZ>7Fg^TPU^0Y7eKQJ=hG8ZRLej>X6iP
TiiZHiNJIVJJUf=ZWI=PKZ2>GW>RRUahXhELOJB0Fh:SNeb7XgIMRj5aGi2OKF6D
W6UTV9UUJ9^EHVbNTF1`X8aNMJ:8G7ZSPeaoXgiLPj=iGHRRM5j=X71PTIi/HiFK
J6JIUfAZW9=RKYn?Gg:QReigXXIMO:>1G82SO5f5XWMNRZ5cGhjOKV6CW6YTUiUW
J9ZFI6^MTV5_WheOM:69GWVRQ5emXWmMPZ9jGHNQMUj;X75PT9i]HiBKJFJHV6IY
ViASKIf@H76OS5mfXHMNNZ:2GGnROEf4XWUNRJ1dGhfOL66AW6aTUIUXIiVFIF^K
TV9_WXiPLj2:GgRQQEilXX1MPJ9lGXJQMen:Wg=PSYi^Hi:KJfFFV6MYVIATK9bA
HW2NS61eX8QONJ63GWjQOej3XGYNQj1fH8bNLF:@W6eTU9YZIiNFIVZJTf=^WHmQ
LYn;H7NPQUmkXH9NP:5mGXBPN5n9WgAQSIe`Hi6KK6FEV6UXV9EUK9^AHg2MSF5d
WhUPN:24GgfPP5n1X7]OQZ1gH8ZNLf:>W6mTTYY[IiJGJ6ZITfE]Vi1RLIj;HGJO
QemjX8=OOj1nGh>PNV27WgEQS9eaHi2KKFFCV6YXUiEWJiZBI6nLSV9cWXYQMin5
H7bPPEn0X7ePQImhH8VNM6:=W71TTIY/IYBGJFVHU6I]VY1TLIb<HWFNR61iWhAP
OImoH8:ONf26WWMQRYecHhjKKfFBVF]XUIIXJiRBIFnKSf=bWH]RMYj6H7^OPV1o
WgiPPimiHHRNMF:<W75TT9Y^IY>GJVVFU6M/VI5UL9^=HgBMRF5hWXEQO9n0H86O
O665WWQRRIedHhfKL6FAVFaXU9IYJiNCIfjJSfAbW8]SMYf7HGZNPf5nWWmQPYik
HHJMMf::W7=TSYY_IY:GJfVEUFQ/V95VKiZ>I7>LRV9gWHIQNij2HH2NOF64WWUR
R9aeHhbKLFF@VFiWTiI[JYJCJ6fHT6EaVhaTMIb8HWVMQ65mWX1QPIilHXFMN6>9
W7ATSIY`IY6HKFVDUFY/Ui9WKiV>IG>KRf=fW8MRNYf3HWnMOV:3WGYRQiafHh^K
LfF>VFmWTYI/JYFDJFfGT6M`VXeUM9^9HgRLQF9lWH5RP9emHXBLNF>8VgETS9Ya
IXnHKVVCUF][UI9XKYR?IW:JRfAfVhMSNYb4HWjMOf:2WG]SQYahI8VKM6F=VG1W
T9M]JYBDJVfFTFQ`V8eVLiZ:I7NKQV=kW89SOianHh>LNV>7VgIURiYcIXjHKfRA
UFa[U9=YKYN?Ig6IS6EeVXQTNI^4HgfLP6>0W7eSQ9]iI8RJMFF<VG5WSiM^JY:D
JfbETFU_UhiWLiV:IGJKQfAjVh=SOYaoHh:LNfB6VgMURIUdIXfHL6R@UFe[Ti=Z
KYJ@J76HSFIdVXUUN9^5I7bKPFAoVgiTPi]jI8NJMVJ;VG=WSYM_JI6DK6bDTVY_
UXiXLYR;IWJJR6EiVhATOI^0I86KO6B5VWQUR9UeIXbHLFR?UVi[TY=/KIF@JG2G
SFMdVHYVMiZ6IG^KPVAoVgmTPY]kIHJJMfJ:V7AWSIM`JI2DKVbCTV]_UHmYLYN<
IgFIR6IiVXEUO9Z1I82JOFF4VWYUQiUfIh^HLfR>UW1ZTI=]KIBAJW2FSVQcV8YW
MYV7IWZJPfEnVX1UPIYlIHFIN6J8V7EWS9MbJHnEKfbBTVa^U8mZLIJ<J7BHRFIh
VHEVNiZ2IGnJOVF3VW]VQYUgIhZGM6R=UW5ZT9A^KI>AJfnESVUbUh]XMYR8IWVI
Q6ImVX1UP9YmIXBINFJ7V7IXRiMcJHjEL6^ATVe^Ti1[LIF=JGBGRVMgV8IVNiV3
IWjIOfJ2VGaVQIQhIhVGMFR<UW9ZSiA_K96AK6nDSfYbUXaXMIN8IgRHQFIlVH5V
OiUnIX>INVN6V7MXRYIdJHfELF^@Tfi^TY1/L9B=JW>FRVQfUhMWNYR4IWfIP6J1
VGeWQ9QiIhRGMVV;UW=ZSYA`K92BKFnCSf]bUHaYMIJ9J7RHQVMkV89WOiQoIh:H
NfN5V7QXRIIeJHbELV^?Tfm]TI1]L9>>Jg>ERfUfUhQXNIR4IgbHPFN0V7eWPiQj
J8NGMfV:UWAZSIAaK8nBKVjBSfaaU8aZM9J9JGNGQVQjV8=WOYR0Ih6HO6N4UgUX
R9IfJH^ELf^>Tg1]T95^L9:>K7:DRfYeUXQYN9N5J7bHPVMoV7iWPYMkJ8JGN6V9
UGEZS9AbK8jBKfjAT6eaThe[LiF:JWJFQfQjUhAXOIN0J82GOFR3UgYYQiIgJXZE
M6^=Tg5]Si5_Ki6>KG:CS6]eUHUYN9J6J7^GPfQnUgmXPIMlJ8FFNFV8UGIZRiAc
K8fBL6j@T6i`TXe/LiB;JWJER6UiUXAXO9N1J7nGOVR3Ug]YQYIhJXVEMF^<Tg9]
SY5`Ki6?KG:CS6adU8UZMiF6JGZFPfUmUh1XPIMmJHBFNVV7UGMZRYAdK8bBLFj?
T6m`THi]Li>;JgFDR6YhUHEYNiJ2JGnFOfV2UWaYQIIiJXRDMV^;Tg=]SI5aKi2?
KW6BSFadThY[MiF7JWZFQ6UmUX5YP9InJH>FNfZ6UGQ[RIAeK8^BLVj>T71`T8i^
LY:;K7FDRF]hUHIZNiJ3JGjFP6V1UWeYQ9EjJXNDMf^:TgA]S95aKhn?Kg6ASFec
ThY/MYB8JgVEQFYlUH9YOiIoJH:EO6Z5UGU[R9AfK8^BLfj=T75`Shi_LY6<KGBC
RF]gU8IZNYF3JWfEP6Z0UGeZPiEjJXJDN6^9TgE]Ri5bKhj?L76@SFicTX]]MY>8
JgRDQFYkUH9ZOYEoJX6EO6Z4U7U[Qi=gK8ZBM6j<T79_SXi`LY2<KWBBRVagThM[
NIB4JWbEPFYoUGiZPYEkJhFDN6b8TgI]RY5cKXf@LG2?SFmcTH]]MI:9K7RDQV]k
U8=[OIF0JX2EOF^3U7Y[QY=hK8VBMFj;TG=_SXm`LI2<KgBARVefThM/NIB5JgbD
PV]oU7m[PIAlJhBDNFb7TgM]RY5dKXb@LW2>SW1bT8]^MI:9KGNCQVajU8A[OIB1
Jh2DOV^2U7][QI=hK8RBMVj:TG=_SHmaLHn=Kg>@RVifTXQ]N9>5K7^DPf]nU81[
PIAmJh>CNVb6TgQ]RI5eKX^@Lg2=SW5bSha_M969KGNBQfaiThA/O9B1JgnDOf^2
U7a/Q9=iKHNBMfj:TGA_S8mbLHj=L7>@RfmeTHQ]N9:6K7ZCPfamTh1[P9=nK8>C
Nfb5TWQ]R95fKXZ@M72=SW5bSXa`M92:KWJAQfeiTXE/O9>2K7jCOfb1Tge/Q9=j
KHJBMfj9TGE_RhmcLHf=LG>?RfmeT8U^Mi:6KGZBQ6amTh5/Oi=nK8:CO6b5TWU]
Qi5gKXZ@M72<SW9bSXa`M8n:KgJAR6ihTXE]Ni:3K7jCP6b0Tge/Pi9kKHFBN6j8
TGI_RXmdLHb=LW>>Rg1eT8U_Mi67KWVBQ6elTX9/Oi=oK86BO6f4TWY]QY5gKXV@
MG2;SW=bSHeaLhn;L7J@R6ihTHI]NY:3KGfBPFf0TWi]PY9lKHFANFj7T7M_RHmd
LHb>LW:=S75dShY_Mi27KWVAQFekTX9]OY:0KH6BOFf3TW]^QY5hKhR@MW2:SWAa
S8ebLhj;L7F?RFmgTHI^NY64KGbBPFeoTWm]PI9lKHBANVj6T7M_RHmeLH^>Lg:=
S75dSXY`MY28KgRAQFikTH=]OI:0KH2BOVf2TG]^QI5iKhN@Mg29SWEaRhecLhf;
LGF?RG1gT8M_NI64KWbAPVenTWm]PI5mKX>ANfj6T7Q_R8mfL8Z>M7:<S79dSXYa
MXn8KgR@QVijTH=^OI61KWnAOfj2TGa^Q95jKhJ@Mg29SgEaRhecLhb;LWF>RG1g
ShM_NI25KW^APfinTH1^P95nKX>ANfj5T7U_QhmgL8V>MG:;S7=dSHYaMXj8L7R?
QVmjT8A^O962KWnAOfj1TGe^Pi1jKhJ@N728SgIaRXedLhb;LWB=RW5fShQ`NI25
Kg^@PfimTH5^P95nKX:AO6n4T7Y_QXmgLHV>MG::S7AcS8]bMHj9LGN?Qg1iT8A_
O922KWjAP6j0TGe_Pi1kKhF?NG27SWMaRHeeLh^<LgB=RW9fSXQ`N8n6L7Z@Q6mm
T85_Oi1oKh6@OFn4T7Y`QXmhLHR>MW::SGAcS8]cMHf9LGN>Qg1iShE_Ni23Kgf@
P6n0T7i_PY1lKhB?NW26SWQaR8efLXZ<M7B<RW9fSHQaN8j6L7Z?Q6mlT89_OY20
Kh6@OFn3T7]`QHmiLHN>Mg:9SGEcRh]cMHb9LWN>Qg5iShE`Nhn3Kgf@PFmoT7m_
PI1lL8B?NW26SWQaR8efLXZ<MGB;RW=fSHUbMhj7LGV?Q71lSh9_OY20Kh2@OVn2
Sga`Q8mjLHJ>N7:8SGIcRX]dMHb:LgJ=R75hSXI`NXn4L7b?PG1oT7m_PHmmL8>?
Ng25SWUaQhegLXV<MGB;RgAeS8UbMhf7LGV>QG1kSh=`OHn1L7n?OW22Sga`Q8mj
LHJ>N7:8SGIcRX]eM8^:LgJ<R79hSXIaNXj4L7b?PW1nSh1`P8mnL8:?O764SWYa
QXehLXR<MWB:RgAeRhUcMhf7LWV>QG5kSX=`OHn1L7n?Og21Sge`PhikLHF>NG:7
SGMcRH]eM8Z:M7J<R7=hSHIbNHj5LGb>PW1nSh1`P8mnL8:?O764SWYaQXehLXR<
MWB9RgEeRhUcMhb8LWR=QW5jSXAaO8j2L7j?P720SgeaPhikLHF>NG:6SGQcR8af
M8Z:M7J;RG=gS8MbNHf5LG^>Pg5mSX5aOhioLH6>OG63SW]aQHeiLXN<Mg>9RgEe
RXUdMXb8LgR=QW9jSHAaO8j2LGj>P760SWiaPXilLHB=NW:6SGQcR8agM8V:MGF;
RGAgS8McNHf5LW^>Pg5mSX5aOhioLH6>OG63SW]bQHeiLXJ<N7>8RgIeRXYeMX^8
LgR<QW9jSHEbNhj3LGf>PG5oSWmaPHimLH>=Ng:5SGUcQhagM8V:MWF:RGAgRhMc
NHb6LWZ=Q79lSX9aOXj0LH2>OW62SGabQ8ejLXJ<N7>8RgMeRHYeMXZ8M7R<Qg=i
S8EbNhf3LWf>PG5oSWmaPHimLX>=Ng:5S7UcQXahM8R:MWF9RGEgRhQdN8b6LgZ=
Q79lSH9bOXf0LH2>OW:2SGabPhekLhF<NG>7RgMeR8YfMXZ8MGN;Qg=iS8EcNhf3
LWf=PW9nSH1bP8enLX:=O7:4S7YcQXahM8N;MgF9RGEfRXQdN8^6LgZ<Q7=kSH=b
OHf1LWn=Og:1SGebPhekLhF<NG>6RgQdR8YfMXV9MGN;QgAiS8IcNXb4LWb=PW9n
SH1bP8enLX:=O7:4S7]cQHaiM8N;MgF8RGIfRXQeN8^6M7V<QG=kS8=bOHf1LWn=
Og:1SGibPXalLhB<NWB6RgQdQhYgMXV9MWN:QgAhRhIdNXb4Lgb<PW9nSH5bOheo
LX6=OG>3S7]cQH]iM8J;N7F8RGMfRHQeN8Z7M7V;QG=kS8=cO8b2LWj=P7:0SGic
PXalLhB<NgB5RgUdQhYgMHR9MWN9R7EhRhIdNX^4Lg^<Pg=mS85cOhaoLh6<OG>2
S7acQ8]jM8J;N7F7RWMfRHQfMhZ7MGV;QGAjRhAcO8b2Lgj<P7>0S7mcPHamLh><
NgB5RgUdQXYhMHR9MgN9R7EhRXIdNH^5M7^<Pg=mS85cOXb0Lh2<OW>2S7acQ8]k
M8F;NGF7RWQfR8QfMhV7MGV:QWAjRhAdO8b2Lgf<PG=oS7mcPHamLh><O7B4RgYd
QXYiMHN9MgJ8R7IhRXMeNHZ5M7^;PgAlS89cOXb0Lh2<OW>1S7edPh]kM8F;NWF6
RWQfR8UgMhV7MWR:QWEjRhAdNh^3M7f<PG=oS7mcP8anLh:;O7B4Rg]eQHYiMHN9
N7J8R7IhRHMeNHZ5MGZ;Q7AlRh9dOXb0Lgn<Og>1RgedPh]lM8B:NWF6RWUfQhUg
MhR7MWR9QWEjRXEdNh^3M7f;PWAnRh1cP8]nM8:;OGB3Rg]eQHYjMHJ9N7J7R7Mg
RHMfNHZ6MGZ:Q7AlRh9dOH^1M7n;OgB1RgidPX]lM8B:NgF5RWUfQhUhMhR8MgR9
QWIiRXEeNhZ3M7b;PWAnRh1dP8]oM86;OGB3Rg]eQ8YjMHJ9NGJ7R7MgR8MfNHV6
MGZ:Q7EkRh=dOH^1M7n;P7B0RgidPX]lM8>:NgF5RWYfQXUhMhN8MgR8QgIiRHEe
NhZ4MGb;PWAnRh5dOh]oM86;OGB2RgaeQ8YkMHF9NGJ6R7QgR8MgN8V6MWZ:QGEk
RX=eOH^2M7j;P7B0RgidPH]mMH>:NgF4RWYfQXUiMhN8N7R8QgMiRHEfNXZ4MGb:
PgEmRh5dOh]oM82;OWB2RWaePhYkMHF9NWJ6R7QgQhMgN8R6MWZ9QGIkRX=eO8Z2
MGj;P7AoRgmdPHYmMH::O7F4RW]fQHUiMhJ8N7R8QgMiR8IfNXV4MG^:PgEmRX5e
OXZ0MH2:OWF1RWeePhYkMHB9NWJ6R7UgQhMhN8R6MgV9QGIkRHAeO8Z2MGf:PGEo
RWmeP8YnMH::O7F3RG]fQHUjMhJ8N7R7QgMiR8IgNXV5MW^:PgEmRX9eOXZ0MH2:
OgF1RWeePXYlMXB9NgJ5R7UgQXMhN8N6MgV8QGIjRHAfO8Z3MGf:PGEoRX1eP8Yn
MH::OGF3RG]fQ8UjMhJ8NGN7QgQhR8IgNXR5MW^9PgIlRX9eOXZ1MGn:OgF1RWie
PXYlMX>9NgJ5R7YgQXQiN8N7N7V8QGMjRHAfNhV3MWf:PGEnRX1eP8YoMH6:OGF2
RGafQ8UkMhF8NGN6QgQhQhIgNHR5Mg^9Q7IlRH9fOHZ1MGn:P7F0RWiePXUmMX>9
NgJ4R7YgQHQiN8N7N7V7QWMjR8AfNhV3MWf9PWInRX1eOhYoMH6:OWJ2RGafPhUk
MhF8NWN6QgUhQhIhNHR5MgZ8Q7IlRH=fOHV1MWj:P7F0RWifPHUmMX>9O7J4R7]g
QHQiN8J7N7V7QWMjR8EgNhV3MWb9PWInRH5fOhUoMX29OWJ2RGefPhUkMhB8NWN5
QgUhQXIhNHN5MgZ8Q7MlRH=fOHV2MWj9P7IoRGmfPHUnMX:9O7J3R7]gQHQjN8J7
NGV7QWQjR8EgNhR4Mgb9PWImRH5fOhV0MX29OWJ1RGefPhUlMhB8NgN5QgUhQXIi
NHN5N7Z8Q7MkR8=fOHV2MWj9PGIoRGmfP8UnMX:9OGJ3R7]gQ8QjN8F7NGV6QWQj
QhEgNhR4Mgb8PgImRH5fOXV0MX29OgJ1RGefPXQlMh>8NgN5QgYhQXIiNHN6N7Z7
Q7MkR8=gO8R2MWj9PGIoRH1fP8UnMX69OGN3R7agQ8QkN8F7NWR6QWUiQhEhNXR4
Mgb8PgMmR89fOXV0MWn9OgJ1RGifPXQmMh>8NgN4QgYhQHMiNHJ6N7Z7QGQkR8Ag
O8R2Mgf9PGIoRH1fP8UoMX68OGN2R7agPhQkN8F7NWR6QWUiQXEhNXN4N7^8PgMm
R89gOXR1MWn9OgJ0RGigPHQmMh>8O7N4Qg]hQHMjNHJ6NGZ7QGQkQhAgO8R3Mgf8
PGMnR81gOhQoMh68OWN2R7egPhQkN8B7NWR5QWUiQXEiNXN4N7^7PgMlR89gOHR1
Mgn8P7N0R7igPHQmMh:8O7N3Qg]hQ8MjNHF6NGZ6QGQkQhAhO8R3Mgf8PWMnR81g
OhQoMh28OWN2R7egPhQlN8B7NgR5QWYiQXEiNXJ5N7^7PgQlR89gOHR1Mgj8P7N0
R7mgPHQnMh:8O7N3Qg]hQ8MjNHF6NGZ6QGUjQhAhNhN3N7f8PWMnR85gOhR0Mh28
OWN1R7egPXMlN8>7NgR4QWYiQHIiNXJ5NG^7Q7QlQh=gOHR1Mgj8P7MoR7mgP8Qn
Mh:8OGR3QgahQ8MkNHF6NWV6QGUjQXAhNhN3N7b7PWMmR85gOhR0Mh28OgN1R7ig
PXMlN8>7NgR4QWYiQHIjNXJ5NG^6Q7QlQh=hOHN2Mgj8PGMoR7mgP8QnMh68OGR2
QgahPhMkNHB6NWV5QGUjQXAiNhN3N7b7PWQmQh5gOXR0Mgn8OgN1R7ihPXMmN8>7
O7R4QW]iQHIjNXF5NG^6Q7UlQh=hOHN2N7j7PGMoR81gP8QoMh67OGR2QgahPhMk
NHB6NgV5QGYjQXAiNhJ4N7b7PgQmQh9hOXN0Mgn8OgN0QgihPHMmN8:7O7R3QW]i
Q8IjNXF5NGZ6Q7UkQX=hO8N2N7f7PGQnQh1hP8MoN867OWR2QgehPhMlNHB6NgV5
QGYjQHEiNhJ4NGb7PgQmQh9hOXN1N7n7P7R0QgihPHMmN8:7O7R3QW]iQ8IkNXF5
NWZ6Q7UkQX=iO8N2N7f7PGQnQh1hOhMoN827OWR1QgehPXMlNH>6NgV4QGYjQHEj
NhJ4NGb6PgQmQh9hOXN1N7n7P7R0QgmhPHMnN8:7OGR3QWaiQ8IkNXF5NWZ5Q7Uk
QX=iO8J3N7f7PWQnQh5hOhMoN827OWR1QgehPXMlNH>6NgV4QG]jQHEjNhF4NG^6
PgUlQX9hOHN1N7j7P7QoQgmhP8MnN867OGR2QWaiPhIkNXB5NWZ5Q7YkQXAiO8J3
NGf7PWQnQh5hOhN0N827OgR1QgihPXImNH>6O7V4QW]jQ8EjNhF4NW^6PgUlQX9i
OHN1N7j7P7QoQgmhP8MnN867OGV2QWaiPhIlNHB5NgZ5QGYkQHAiO8J3NGf6PWUn
Qh5hOhN0N827OgR1QgihPXImNH:6O7V3QW]jQ8EjNXF4NW^5PgUlQX9iOHJ2NGj7
PGQoQh1hP8MoN867OWV2QWeiPhIlNHB5NgZ4QGYkQHAjO8J3NGb6PWUmQX5iOXN0
N7n7OgR0QgiiPHImNH:6O7V3QWajQ8EkNXF4NW^5PgYlQX=iOHJ2NGj6PGUoQh1h
P8MoNH66OWV2QWeiPXIlNH>5NgZ4QG]kQHAjNhF3NGb6PWUmQX5iOXJ0NGn6OgV0
QWmiPHInNH:6OGV3QWajQ8EkNXB4NW^5Q7YlQH=iOHJ2NGj6PGUnQX1iOhIoNH26
OWV1QWeiPXIlNH>5O7Z4QG]kQ8AjNhF3NWb6PWUmQX9iOXJ1NGn6P7V0QWmiPHIn
NH:6OGV2QWajPhEkNXB4Ng^5Q7YlQH=jO8J2NGf6PGUnQX1iOhIoNH26OWV1QWii
PXImNX>5O7Z4QG]kQ8AjNhF3NWb5PgUmQX9iOXJ1NGn6P7V0QWmiP8InNH66OGV2
QGajPhElNXB4Ng^4Q7YlQH=jO8F2NGf6PGUnQX5iOhJ0NH26OgV1QWiiPXImNX:5
O7Z3QG]kQ8AkNhF3NWb5PgYmQH9iOXJ1NGj6P7UoQWmiP8InNH66OWV2QGejPhEl
NX>4Ng^4Q7]kQH=jO8F2NWf6PWUnQX5iOhJ0NH26OgV0QWiiPHImNX:5O7Z3QGaj
Q8AkNhB4NWb5PgYmQH9jOHJ1NGj6P7UoQX1iP8IoNH66OWV2QGejPXElNX>5Ng^4
Q7]kQ8=jO8F3NWf5PWYnQX5iOhJ0NGn6OgV0QWiiPHImNX:5OGZ3QGajPhAkNhB4
Ngb5PgYlQH9jOHF1NGj6PGUoQX1iP8IoNH66OWZ1QGejPXElNX>5O7^4Q7]kQ8=k
O8F3NWf5PWYnQH5iOXJ0NGn6OgV0QWmiPHEnNX:5OGZ2QGajPhAlNhB4Ngb4PgYl
QH9jOHF2NWj5PGUoQX1iOhIoNH25OWZ1QGejPXEmNX>5O7^3Q7]kQ8=kO8B3NWf5
PWYmQH5jOXF0NWn6P7V0QWmjPHEnNX65OGZ2QGajPhAlNhB4Ngb4Pg]lQH9jOHF2
NWj5PGYnQH1jOhEoNX25OWZ1QGijPXEmNX:5O7^3Q7akQ8AkO8B3Ngb5PWYmQH5j
OXF1NWn5P7Z0QGmjP8EnNX65OGZ2QGejPhAlNh>4Ng^4Pg]lQ8=jOHF2NWj5PGYn
QH1jOhF0NX25OgZ1QGijPHEmNX:5O7^3Q7akPhAkO8B3Ngb4PWYmQH9jOXF1NWn5
P7YoQGmjP8EnNX65OWZ2QGejPXAlNh>4O7^4Pg]lQ8=kOHF2NWf5PGYnQH5jOhF0
NX25OgZ0QGijPHEmNX:5OG^3Q7akPhAkO8B3Ngb4PW]mQH9jOXF1NWj5P7YoQGmj
P8EoNX65OWZ1QGejPXAlNh>4O7^3Pg]lQ8=kOHB2NWf5PGYnQH5jOhF0NWn5OgZ0
QGijPHEnNX:5OG^2Q7akPhAlO8B3Ngb4Pg]mQ89jOXF1NWj5P7YoQH1jP8EoNX65
OWZ1QGejPXAmNh>4O7^3PgalQ8=kO8B2Ngf4PWYnQH5jOhF0NWn5OgZ0QGmjPHEn
NX64OG^2Q7ekPhAlO8>3Ngb4Pg]mQ89kOHF1NWj5PGYoQH1jP8EoNX25OWZ1QGik
PXAmNh:4O7^3PgalPh=kO8B2Ngf4PW]nQH5jOXF0NWn5P7Z0QGmjPHEnNX64OG^2
Q7ekPhAlO8>3O7b4Pg]mQ89kOHB1Ngj5PGYoQH1jOhEoNX25OgZ1QGikPXAmNh:4
OG^3Q7alPh=kO8B2Ngf4PW]nQ85jOXF0NWn5P7Z0QGmjP8EnNX64OW^2Q7ekPXAl
Nh>3O7b3Pg]mQ89kOHB2Ngj4PGYnQH1jOhEoNX25OgZ1Q7ikPHAmNh:4OG^3Q7al
Ph=lO8B3Ngf4PW]mQ85kOXB1NWn5P7YoQGmjP8EnNh64OW^2Q7ekPXAmNh>3O7b3
PgalQ89kOHB2Ngj4PG]nQ81jOhF0NX25Og^0Q7ikPHAnNh:4OG^2Q7alPh=lO8>3
Ngf4PW]mQ85kOXB1Ngn4P7]oQ7mkP8AoNh64OW^1Q7ekPXAmNh:3O7b3PgalPh9k
OHB2Ngj4PG]nQ81kOhB0Nh24Og^0Q7ikPHAnNh:4OG^2Q7elPh=lO8>3O7f4PW]m
Q89kOXB1Ngj4P7]oQ81kP8AoNh24OW^1Q7ikPXAmNh:3O7b3PgalPh9lOHB2Ngf4
PG]nQ85kOhB0Ngn4Og^0Q7mkPHAnNh64OG^2Q7elPX=lO8>3O7f3PW]mQ89kOXB1
Ngj4P7]oQ81kP8AoNh24OW^1Q7ikPXAmNh:3OGb3PgalPh9lOH>2Ngf4PG]nQ85k
OhB0Ngn4Og^0Q7mkPHAnNh64OW^2Q7elPX=lO8>3O7b3PWamQ89kOXB1Ngj4PG]o
Q81kOhAoNh24Og^1Q7ikPHAmNh:3OGb2PgalPh=lOH>2O7f4PG]nQ85kOXB0Ngn4
P7^0Q7mkP8AnNh64OW^2Q7elPX=mO8>3O7b3PWamPh9kOHB1Ngj4PG]oQ81kOhAo
Nh24Og^1Q7ikPHAnNh:3OGb2PgelPh=lOH>2O7f3PW]nQ85kOXB0Ngn4P7^0Q7mk
P8AoNh64OW^1Q7elPX=mO8:3O7b3PWamPh9lOHB1Ngj4PG]oQ81kOhB0Nh24Og^0
Q7ikPHAnNh:3OGb2PgelPh=lOH>2O7f3PWanQ85kOXB1Ngn4P7]oQ7mkP8AoNh64
OW^1Q7ilPX=mO8:3OGb3PWamPh9lOH>1O7j4PG]nQ81kOhB0Nh24Og^0Q7mkPHAn
Nh63OGb2PgelPX=lOH>2O7f3PWanPh5kOXB1Ngn4P7]oQ7mkP8AoNh24OW^1Pgil
PX=mO8:3OGb2PWamPh9lOH>2O7j3PG]nQ81kOhB0Ngn4Og^0Q7mkPHAnO863OWb2
PgelPX=mO8>2O7f3PWamPh5lOX>1Ngn4P7]oQ81kP8AoNh24OW^1PgilPH=mO8:3
OGb2PgamPh9lOH>2O7j3PGanQ85kOhB0Ngn4Og^0Q7mkP8AnO863OWb2PgelPX=m
O8:2O7f3PWamPh5lOX>1O7j4P7]oQ81kP8AoNh24Og^1PgilPH=nO8:3OGb2Pgem
Ph9lOH>2O7j3PGanPh5lOhB0Ngn4P7^0Q7mkP8=nO863OWb1PgelPX=mO8:2OGf3
PWamPh9lOX>1O7j3P7aoQ81kOhAoNh23Ogb0PgilPH=nO863OGb2PgemPX9lOH>2
O7f3PGanPh5lOX>0O7n3P7b0PgmlP8=oO863OWb1PgilPX=mO8:2OGf2PWamPh9l
OX>1O7j3PGaoPh1lOh=oO823Ogb0PgilPH=nO863OGb2PgemPX9mOH>2O7f3PGan
Ph5lOX>0O7n3P7aoPgmlP8=oO863OWb1PgilPH=mO8:2OGf2PWemPh9lOX>1O7j3
PGaoPh1lOh>0O823Ogb0PgmlPH=nO863OWb2PgemPX9mOH:2O7f3PGanPh5lOX>0
O7n3P7aoPgmlP8=oO823OWb1PgilPH=mO8:2OGf2PWemPh9lOX>1O7j3PGanPh1l
Oh>0O7n3Ogb0PgmlPH=nO863OWb1PgemPX9mOH:2OGf3PWanPh5lOX>1O7n3P7ao
Ph1lP8=oO823Ogb1PgilPH=nO8:2OGf2PWemPX9lOH>1O7j3PGanPh1lOh>0O7n3
Ogb0PgmlP8=nO863OWb1PgemPX9mOH:2OGf2PWanPh5lOX>1O7n3P7aoPh1lP8=o
O823Ogb1PgilPH=nO863OGf2PWemPX9mOH>1O7j3PGanPh1lOh>0O7n3P7b0Pgml
P8=oO863OWb1PgilPX9mOH:2OGf2PWenPh5lOX>1O7j3P7aoPh1lOh=oO823Ogb0
PgilPH=nO863OGf2PWemPX9mOH:1O7j3PGanPh5lOh>0O7n3P7b0PgmlP8=oO863
OWb1PgilPH9mOH:2OGf2PWemPX5lOX>1O7j3P7aoPh1lOh=oO823Ogb0PgmlPH=n
O863OWf2PWemPX9mOH:2OGj3PGanPh5lOh>0O7n3P7aoPgmlP8=oO823OWb1Pgil
PH9nOH:2OGf2PWemPX5mOX>1O7j3PGaoPh1lOh>0O823Ogb0PgmlPH=nO862OWf1
PWemPX9mOH:2OGj2PGenPh5lOX>0O7n3P7aoPgmlP8=oO823OWb1PgimPH9nOH:2
OGf2PWemPX5mOX:1O7j3PGaoPh1lOh>0O823Ogb0PgmlP8=nO862OWf1PWimPX9m
OH:2OGj2PGenPX5lOX>0O7n3P7aoPh1lP8=oO823Ogb1PgimPH9nOH62OGf2PWem
PX5mOX:1OGj3PGaoPh1lOh>0O7n3Ogb0PgmlP8=nO862OWf1PWimPX9mOH:2OGj2
PGenPX5mOX>1O7n3P7aoPh1lP8=oO823Ogb0PgimPH9nOH62OWf2PWemPX9mOX:1
OGj2PGenPh1lOh>0O7n3Ogb0PgmlP8=oO862OWf1PWimPH9mOH:2OGf2PGenPX5m
OX:1O7n3P7aoPh1lOh=oO823Ogb0PgimPH9nOH62OWf1PWemPX9mOX:1OGj2PGen
PX1lOh>0O7n3P7b0PgmlP8=oOH22OWf1PWimPH9nOH:2OGf2PGenPX5mOX:1OGn2
P7aoPh1lOh=oO823Ogb0PWmmPH9nOH62OWf1PWemPX9mOX:1OGj2PGenPX5mOh:0
O7n3P7b0PgmlP8=oOH22OWf1PWimPH9nOH62OGf2PGenPX5mOX:1OGj2P7eoPX1l
Oh>0O823Ogf0PWmmP89nOH62OWf1PWimPX9mOX:1OGj2PGenPX5mOh:0OGn2P7eo
PWmmP89oOH22Ogf1PWimPH9nOH62OWf2PGenPX5mOX:1OGj2P7eoPX1mOh:0OH22
Ogf0PWmmP89nOH62OWf1PWimPH9mOH:1OGj2PGenPX5mOh:0OGn2P7eoPWmmP89o
OH22Ogf1PWimPH9nOH62OWf2PWenPX5mOX:1OGj2PGeoPX1mOh:0OGn2Ogf0PWmm
P89oOH62OWf1PWimPH9nOH:1OGj2PGenPX5mOX:0OGn2P7eoPX1mP89oOH22Ogf0
PWimPH9nOH62OWf1PWenPX5mOX:1OGj2PGeoPX1mOh:0OGn2Ogf0PWmmP89oOH62
OWf1PWimPH9nOH61OGj2PGenPX5mOX:0OGn2P7eoPX1mP89oOH22Ogf0PWmmPH9n
OH62OWf1PWinPX5mOX:1OGj2PGeoPX1mOh:0OGn2P7f0PWmmP89oOH22OWf1PWim
PH9nOH61OGj2PGenPX5mOX:1OGn2P7eoPX1mOh9oOH22Ogf0PWmmPH9nOH62OWf1
PWinPH5mOX:1OGj2PGenPX1mOh:0OGn2P7f0PWmmP89oOH22Ogf1PWimPH9nOH61
OWj2PGenPX5mOX:1OGn2P7eoPX1mOh9oOH22Ogf0PWmmP89nOH62OWf1PWinPH5n
OX:1OGj2PGenPX1mOh:0OGn2P7eoPWmmP89oOH22Ogf1PWimPH9nOH61OWj1PGen
PX5mOX:1OGn2P7eoPX1mOh:0OH22Ogf0PWmmP89oOH62OWf1PWimPH5nOX61OGj2
PGenPX1mOh:0OGn2P7eoPWmmP89oOH22Ogf0PWimPH9nOH62OWj1PGinPX5mOX:1
OGj2P7eoPX1mOh:0OH22Ogf0PWmmP89oOH62OWf1PWimPH5nOX61OWj2PGenPX5m
Oh:0OGn2P7eoPX1mP89oOH22Ogf0PWmmPH9nOH62OWj1PGinPH5mOX:1OGj2P7eo
PX1mOh:0OGn2Ogf0PWmmP89oOH22OWf1PWimPH5nOX61OWj2PGenPX5mOh:0OGn2
P7eoPX1mP89oOH22Ogf0PWmmPH9nOH62OWj1PGinPH5nOX:1OGj2P7eoPX1mOh:0
OGn2Ogf0PWmmP89oOH22Ogf1PWimPH5nOX61OWj1PGenPX5mOX:0OGn2P7eoPX1m
Oh9oOH22Ogf0PWmmP89nOH62OWj1PGinPH5nOX61OGj2PGeoPX1mOh:0OGn2P7f0
PWmmP89oOH22Ogf1PWimPH5nOX61OWj1PGinPX5mOX:0OGn2P7eoPX1mOh9oOH22
Ogf0PWmmP89oOH62OWj1PGinPH5nOX61OWj2PGeoPX1mOh:0OGn2P7f0PWmmP89o
OH22Ogf0PWimPH5nOX61OWj1PGinPH5mOX:0OGn2P7eoPX1mOh:0OH22Ogf0PWmm
P89oOH62OWj1PGinPH5nOX61OWj1PGeoPX1mOh:0OGn2P7eoPWmmP89oOH22Ogf0
PWmmPH5nOX61OWj1PGinPH5nOX61OGn2P7eoPX1mOh:0OH22Ogf0PWmmP89oOH22
OWj1PGinPH5nOX61OWj1PGinPX1mOh:0OGn2P7eoPX1mP89oOH22Ogf0PWmmPH5n
OX61OWj1PGinPH5nOX61OWn2P7eoPX1mOh:0OGn2Ogf0PWmmP89oOH22Ogj1PGin
PH5nOX61OWj1PGinPH1mOh:0OGn2P7eoPX1mP89oOH22Ogf0PWmmP85nOX61OWj1
PGinPH5nOX61OWn1P7eoPX1mOh:0OGn2Ogf0PWmmP89oOH21Ogj1PGinPH5nOX61
OWj1PGinPH5nOh60OGn2P7eoPX1mOh9oOH22Ogf0PWmnP85oOX61OWj1PGinPH5n
OX61OWj1P7ioPX1mOh:0OGn2P7f0PWmmP89oOH21Ogj0PGinPH5nOX61OWj1PGin
PH5nOh60OWn2P7eoPX1mOh9oOH22Ogf0PWmnP85oOX61OWj1PGinPH5nOX61OWj1
P7ioPH1nOh:0OGn2P7f0PWmmP89oOH21Ogj0PGmnPH5nOX61OWj1PGinPH5nOh60
OWn1P7ioPX1mOh:0OH22Ogf0PGmnP85oOX21OWj1PGinPH5nOX61OWj1P7ioPH1n
Oh60OWn2P7eoPWmmP89oOX21Ogj0PGmnPH5nOX61OWj1PGinPH5nOX60OWn1P7io
PH1nOh:0OH22Ogj0PGmnP85oOX21Ogj1PGinPH5nOX61OWj1PGioPH1nOh60OWn1
P7ioPGmnP85oOX21Ogj0PGmnP85nOX61OWj1PGinPH5nOX60OWn1P7ioPH1nOh60
OWn1Ogj0PGmnP85oOX21Ogj1PGinPH5nOX61OWj1PGioPH1nOh60OWn1P7ioPH1n
P85oOX21Ogj0PGmnP85oOX61OWj1PGinPH5nOX60OWn1P7ioPH1nOh60OWn1Ogj0
PGmnP85oOX21Ogj0PGinPH5nOX61OWj1PGioPH1nOh60OWn1P7ioPH1nP85oOX21
Ogj0PGmnP85oOX61OWj1PGinPH5nOX61OWn1P7ioPH1nOh60OWn1P7j0PGmnP85o
OX21Ogj0PGmnPH5nOX61OWj1PGinPH1nOh60OWn1P7ioPH1nOh5oOX21Ogj0PGmn
P85oOX21OWj1PGinPH5nOX61OWn1P7ioPH1nOh60OWn1P7j0PGmnP85oOX21Ogj0
PGmnP85nOX61OWj1PGinPH1nOh60OWn1P7ioPH1nOh5oOX21Ogj0PGmnP85oOX21
Ogj1PGinPH5nOX61OWn1P7ioPH1nOh60OWn1P7ioPGmnP85oOX21Ogj0PGmnP85n
OX61OWj1PGinPH1nOh60OWn1P7ioPH1nOh60OX21Ogj0PGmnP85oOX21Ogj0PGin
PH5nOX61OWn1P7ioPH1nOh60OWn1P7ioPGmnP85oOX21Ogj0PGmnP85oOX61OWj1
PGinPH5nOh60OWn1P7ioPH1nOh60OX21Ogj0PGmnP85oOX21Ogj0PGinPH5nOX61
OWj1P7ioPH1nOh60OWn1P7ioPH1nP85oOX21Ogj0PGmnP85oOX21OWj1PGinPH5n
Oh60OWn1P7ioPH1nOh60OWn1Ogj0PGmnP85oOX21Ogj0PGmnPH5nOX61OWj1P7io
PH1nOh60OWn1P7ioPH1nP85oOX21Ogj0PGmnP85oOX21OWj1PGinPH5nOh60OWn1
P7ioPH1nOh60OWn1Ogj0PGmnP85oOX21Ogj0PGmnP85nOX61OWj1P7ioPH1nOh60
OWn1P7ioPH1nOh5oOX21Ogj0PGmnP85oOX21Ogj1PGinPH5nOh60OWn1P7ioPH1n
Oh60OWn1P7j0PGmnP85oOX21Ogj0PGmnP85oOX61OWj1PGioPH1nOh60OWn1P7io
PH1nOh5oOX21Ogj0PGmnP85oOX21Ogj0PGinPH5nOX60OWn1P7ioPH1nOh60OWn1
P7j0PGmnP85oOX21Ogj0PGmnP85oOX61OWj1PGioPH1nOh60OWn1P7ioPH1nOh60
OX21Ogj0PGmnP85oOX21Ogj0PGmnPH5nOX60OWn1P7ioPH1nOh60OWn1P7ioPGmn
P85oOX21Ogj0PGmnP85oOX21OWj1PGioPH1nOh60OWn1P7ioPH1nOh60OX21Ogj0
PGmnP85oOX21Ogj0PGmnP85nOX60OWn1P7ioPH1nOh60OWn1P7ioPGmnP85oOX21
Ogj0PGmnP85oOX21Ogj1PGioPH1nOh60OWn1P7ioPH1nOh60OWn1Ogj0PGmnP85o
OX21Ogj0PGmnP85nOX60OWn1P7ioPH1nOh60OWn1P7ioPH1nP85oOX21Ogj0PGmn
P85oOX21Ogj0PGioPH1nOh60OWn1P7ioPH1nOh60OWn1Ogj0PGmnP85oOX21Ogj0
PGmnP85oOX61OWn1P7ioPH1nOh60OWn1P7ioPH1nP85oOX21Ogj0PGmnP85oOX21
Ogj0PGmnPH1nOh60OWn1P7ioPH1nOh60OWn1P7j0PGmnP85oOX21Ogj0PGmnP85o
OX21OWn1P7ioPH1nOh60OWn1P7ioPH1nOh5oOX21Ogj0PGmnP85oOX21Ogj0PGmn
PH1nOh60OWn1P7ioPH1nOh60OWn1P7j0PGmnP85oOX21Ogj0PGmnP85oOX21Ogn1
P7ioPH1nOh60OWn1P7ioPH1nOh60OX21Ogj0PGmnP85oOX21Ogj0PGmnP81nOh60
OWn1P7ioPH1nOh60OWn1P7ioPGmnP85oOX21Ogj0PGmnP85oOX21Ogn0P7ioPH1n
Oh60OWn1P7ioPH1nOh60OX21Ogj0PGmnP85oOX21Ogj0PGmnP81oOh60OWn1P7io
PH1nOh60OWn1P7ioPGmnP85oOX21Ogj0PGmnP85oOX21Ogn0P7moPH1nOh60OWn1
P7ioPH1nOh60OWn1Ogj0PGmnP85oOX21Ogj0PGmnP81oOh20OWn1P7ioPH1nOh60
OWn1P7ioPH1nP85oOX21Ogj0PGmnP85oOX21Ogn0P7moPH1nOh60OWn1P7ioPH1n
Oh60OWn1Ogj0PGmnP85oOX21Ogj0PGmnP85oOh20Ogn1P7ioPH1nOh60OWn1P7io
PH1nP85oOX21Ogj0PGmnP85oOX21Ogj0P7moP81nOh60OWn1P7ioPH1nOh60OWn1
P7j0PGmnP85oOX21Ogj0PGmnP85oOh20Ogn0P7ioPH1nOh60OWn1P7ioPH1nOh5o
OX21Ogj0PGmnP85oOX21Ogj0P7moP81oOh60OWn1P7ioPH1nOh60OWn1P7j0PGmn
P85oOX21Ogj0PGmnP85oOh20Ogn0P7moPH1nOh60OWn1P7ioPH1nOh5oOX21Ogj0
PGmnP85oOX21Ogj0P7moP81oOh20OWn1P7ioPH1nOh60OWn1P7ioPGmnP85oOX21
Ogj0PGmnP85oOh20Ogn0P7moP81nOh60OWn1P7ioPH1nOh60OX21Ogj0PGmnP85o
OX21Ogj0P7moP81oOh20Ogn1P7ioPH1nOh60OWn1P7ioPGmnP85oOX21Ogj0PGmn
P85oOh20Ogn0P7moP81oOh60OWn1P7ioPH1nOh60OX21Ogj0PGmnP85oOX21Ogj0
P7moP81oOh20Ogn0P7ioPH1nOh60OWn1P7ioPH1nP85oOX21Ogj0PGmnP85oOh20
Ogn0P7moP81oOh20OWn1P7ioPH1nOh60OWn1Ogj0PGmnP85oOX21Ogj0P7moP81o
Oh20Ogn0P7moPH1nOh60OWn1P7ioPH1nP85oOX21Ogj0PGmnP85oOh20Ogn0P7mo
P81oOh20Ogn1P7ioPH1nOh60OWn1Ogj0PGmnP85oOX21Ogj0P7moP81oOh20Ogn0
P7moP81nOh60OWn1P7ioPH1nOh5oOX21Ogj0PGmnP85oOh20Ogn0P7moP81oOh20
Ogn0P7ioPH1nOh60OWn1P7j0PGmnP85oOX21Ogj0P7moP81oOh20Ogn0P7moP81o
Oh20OWn1P7ioPH1nOh5oOX21Ogj0PGmnP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
PH1nOh60OWn1P7j0PGmnP85oOX21Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn1
P7ioPH1nOh60OX21Ogj0PGmnP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh60
OWn1P7ioPGmnP85oOX21Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7ioPH1n
Oh60OX21Ogj0PGmnP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20OWn1P7io
PGmnP85oOX20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81nOh60OWn1
Ogj0PGmoP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moPH1nP85o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh1oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7n0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0P7moP81oOh20Oh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oOh20Ogn0P7moP7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81o
Oh20Ogn0P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7mo
P81oOh20Ogn0P7moP81oP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0
P7moP81oOh20Ogn0Ogn0P7moP81oOh20Ogn0P7moP81oOh20Ogn0P7moP81oOh20
Ogn0P7moP81oP0\>"]},
  ImageCacheContents->"Sound"]
}, Open  ]],

Cell[TextData[{
  " \tThe Green's function technique can also be employed to solve for the \
particular solution of  the general ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th-order linear ODE with constant coefficients, Eq. ",
  ButtonBox["(1.6.7)",
    ButtonData:>{"Chapter1.nb", "(1.6.7)"},
    ButtonStyle->"Hyperlink"],
  ". Acting with a  Fourier transform on this equation yields "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\&~\_p\)(\[Omega])\)\ \ \((\(-\[ImaginaryI]\)\
\ \[Omega] - \ s\_1)\) \((\(-\[ImaginaryI]\)\ \[Omega] - \ 
                  s\_2)\) ... \) \((\(-\[ImaginaryI]\)\ \[Omega] - 
              s\_N)\)\  = \ \(f\&~\)(\[Omega])\)]],
  ","
}], "NE3",
  CellTags->"(2.3.82)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`s\_1, \(\(...\) \(s\_N\)\)\)]],
  " are the roots of the characteristic polynomial for the homogeneous ODE, \
described in Sec. ",
  ButtonBox["1.6.2",
    ButtonData:>{"Chapter1.nb", "c:38"},
    ButtonStyle->"Hyperlink"],
  ". Solving for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\&~\_p\)(\[Omega])\)\(\ \)\)\)]],
  ", taking the inverse transform, and using the convolution theorem, we are \
again led to Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  ". Now, however, the Green's function is given by the following inverse \
transform :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g(t) = \(F\&^\^\(-1\)\) 
          1\/\(\((\(-\[ImaginaryI]\)\ \[Omega] - \ s\_1)\) \
\((\(-\[ImaginaryI]\)\ \[Omega] - \ s\_2)\) ... \) . \((\(-\[ImaginaryI]\)\ \
\[Omega] - s\_N)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.83)"],

Cell[TextData[{
  " This inverse transformation can be performed by separating the resonance \
function in Eq. ",
  ButtonBox["(2.3.83)",
    ButtonData:>"(2.3.83)",
    ButtonStyle->"Hyperlink"],
  " into individual resonances as in Eq. ",
  ButtonBox["(2.3.75)",
    ButtonData:>"(2.3.75)",
    ButtonStyle->"Hyperlink"],
  ", assuming no degeneracies occur (i.e., ",
  Cell[BoxData[
      \(TraditionalForm\`s\_i\  \[NotEqual] \ s\_j\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`i \[NotEqual] \ j\)]],
  "):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`g(
          t)\  = \(-\(\[Sum]\+\(i = 1\)\%N\(\( F\&^\^\(-1\)\) \(1\/\(\
\[ImaginaryI]\ \[Omega] + 
                    s\_i\)\) \(1\/\(\[Product]\+\(j = 1\[IndentingNewLine]
                      j \[NotEqual] \ i\)\%N\((s\_i - 
                        s\_j)\)\)\)\(\ \)\)\)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.84)"],

Cell[TextData[{
  "If we further assume that none of the system's modes are unstable, so that \
",
  Cell[BoxData[
      \(TraditionalForm\`Re\ s\_i\ \  < \ 0\)]],
  " for all ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ", we can apply Eq. ",
  ButtonBox["(2.3.76)",
    ButtonData:>"(2.3.76)",
    ButtonStyle->"Hyperlink"],
  " to obtain the Green's function"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`g(
          t) = \(h(
            t)\) \(\[Sum]\+\(i = 1\)\%N\ \[ExponentialE]\^\(\(\ \)\(\(s\_i\) \
t\)\)\/\(\[Product]\+\(j = 1\[IndentingNewLine]
                  j \[NotEqual] \ i\)\%N\((s\_i - s\_j)\)\)\)\)], "NE3"], 
    "NE3"],
  StyleBox[".", "NE3"]
}], "NE3",
  CellTags->"(2.3.85)"],

Cell["\<\
 The case of a system exhibiting unstable oscillations, or the case \
of degeneracy, can also be easily handled using similar techniques, and is \
left to the exercises. \
\>", "Text"],

Cell[TextData[{
  "\tWe have finally solved the problem, posed back in Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:33"},
    ButtonStyle->"Hyperlink"],
  ",  of determining the response of an oscillator (or, more generally, a \
linear ODE of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th-order with constant coefficients) to a forcing function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " with arbitrary time dependence. Equation ",
  ButtonBox["(2.3.85)",
    ButtonData:>"(2.3.85)",
    ButtonStyle->"Hyperlink"],
  " shows that the response to a \[Delta]-function force at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " is a sum of the solutions ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\ \)\(\(s\_i\) t\)\)\)]],
  "to the homogeneous equation. This response, the Green's function for the \
system, can be employed to determine the response to an arbitrary force by \
applying Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAs a simple example, say the forcing ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " grows linearly with time, starting at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \(\(t\)\(\ \ \)\(h(t)\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Then Eq.  (",
  ButtonBox["2.3.73",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  ") implies that a particular solution to this forcing is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t) = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( t\_o\) \(h(
              t\_o)\) \(g(t - t\_o)\) \[DifferentialD]t\_o\)]],
  "."
}], "NE3",
  CellTags->"(2.3.86)"],

Cell[TextData[{
  "Substituting Eq. ",
  ButtonBox["(2.3.85)",
    ButtonData:>"(2.3.85)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(2.3.86)",
    ButtonData:>"(2.3.86)",
    ButtonStyle->"Hyperlink"],
  ", we find that a series of integrals of the form\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( 
              t\_o\) \(h(t\_o)\)\ \(h(
            t - t\_o)\) \(\[ExponentialE]\^\(\(\ \)\(\(s\_i\)(
                t - t\_o)\)\)\) \[DifferentialD]t\_o\)]],
  " must be performed.  The step functions in the integrand limit the range \
of integration to ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"0", "<", 
            FormBox[\(t\_o < t\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ", so each integral results in\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Integral]\_0\%t\( 
                t\_o\) \(\[ExponentialE]\^\(\(\ \)\(\(s\_i\)(
                  t - t\_o)\)\)\) \[DifferentialD]t\_o\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[ExponentialE]\^\(\(s\_i\) t\) - \((1 + \ \
\(s\_i\) t)\)\)\/s\_i\%2\)]],
  ".\nFinally, the total response is the sum of these individual terms:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t) = \[Sum]\+\(i = 1\)\%N\ \(\[ExponentialE]\^\(\(s\_i\) t\) - \((1 \
+ \ \(s\_i\) t)\)\)\/\(\(s\_i\%2\) \(\[Product]\+\(j = 1\[IndentingNewLine]
                  j \[NotEqual] \ i\)\%N\((s\_i - s\_j)\)\)\), \ t > 0\)]],
  ". "
}], "NE3",
  CellTags->{"(2.3.87)", "i:61"}],

Cell[TextData[{
  "We see that part of the response increases linearly with time, tracking \
the increasing applied force as one might expect. However, another part of \
the response is proportional to a sum of decaying homogeneous solutions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(s\_i\) t\)\)]],
  ".  The particular solution given by Eq. ",
  ButtonBox["(2.3.87)",
    ButtonData:>"(2.3.87)",
    ButtonStyle->"Hyperlink"],
  " is the one for which the system is at rest before the forcing begins."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 2.3", "Subsubtitle",
  CellTags->{"Ex. 2.3", "c:39"}],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Find the Fourier transform for the following functions. Use time \
transform conventions for functions of ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", and space transform conventions for functions of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". Except where indicated, do the required integrals by hand. (You may \
check your results using ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = \(h(t)\)\ \(\[ExponentialE]\^\(\(-a\)\ t\)\) 
          sin\ \(\[Omega]\_o\) t, \ a > 0, \)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is the Heaviside step function"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ t\ \ for\  - a < t < a, \ 
      and\ zero\ otherwise\)]],
  " "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(\(f(t)\)\(=\)\),
              "TraditionalForm"], "cos", " ", \(\[Omega]\_o\), " ", "t"}]}], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-a\) < t < a, \ and\ zero\ otherwise\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(d) ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`f(x)\  = x/\(\((1\  + \ x\^2)\)\(.\)\(\ \ \)\)\)]],
  " (You may use ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " to help with the required integral.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          x)\  = \ \(\(\[ExponentialE]\^\(-x\^2\)\)\(.\)\)\)]],
  " (You may use ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  " to help with the required integral.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Verify by hand that the inverse transform of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  " found in Exercise (1) returns to the listed functions. [You may use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to help check integrals, and you may also use Eq. ",
  ButtonBox["(2.3.76)",
    ButtonData:>"(2.3.76)",
    ButtonStyle->"Hyperlink"],
  " without proving it by hand.]"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Plot the Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\(f\&~\)(\[Omega])\)\(|\)\)\)]],
  " arising from Exercise (1)(c), taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\  = \ 3\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`a = \ 10, 20, 30\)]],
  ". Comment on the result. What will ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  " converge to in the limit as ",
  Cell[BoxData[
      \(TraditionalForm\`a \[Rule] \ \ \[Infinity]\)]],
  "?"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Starting with a Fourier sine series, Eq. ",
  ButtonBox["(2.2.10)",
    ButtonData:>"(2.2.10)",
    ButtonStyle->"Hyperlink"],
  ", prove the relations for a Fourier sine transform, Eqs. ",
  ButtonBox["(2.3.10)",
    ButtonData:>"(2.3.10)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Repeat Exercise (1)(a) using a cosine transform on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < \[Infinity]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " Repeat Exercise (1)(d) using a sine transform on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < \[Infinity]\)]],
  ". Use ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to help with the integral."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]/\((\[ImaginaryI]\ \[Nu]\  + \ \
\[Omega])\)\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu] > 0\)]],
  ") be the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\^\[Prime]\)(t)\)]],
  ". Find ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " by hand. "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " Find the value of the integral ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[ExponentialE]\^\(\(-\[Nu]\)\  | t\_o | \)\) 
          cos\ \[Omega]\_o\ \((t - t\_o)\) \[DifferentialD]t\_o\)]],
  " using the convolution theorem. Use paper and pencil methods to do all \
required transforms and inverse transforms."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)",
    FontWeight->"Bold"],
  " Show that the following functions approach  Dirac \[Delta] functions  \
and/or their derivatives, and find the coefficients of these \
\[Delta]-functions:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(t)\), "=", 
          RowBox[{
            UnderscriptBox["lim", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["t",
                      FontSlant->"Italic"]}]], "\[Rule]", "0"}]], 
            RowBox[{"t", " ", 
              RowBox[{
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"h", "(", 
                      RowBox[{"t", "+", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["t",
                              FontSlant->"Italic"]}]]}], ")"}], "-", 
                    RowBox[{"h", "(", 
                      RowBox[{"t", "-", 
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["t",
                              FontSlant->"Italic"]}]]}], ")"}]}], "}"}], "/", 
                
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "3"]}]}]}]}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{\(f(t)\), " ", "=", 
            RowBox[{
              RowBox[{
                UnderscriptBox["lim", 
                  RowBox[{
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]], "\[Rule]", "0"}]], "   ", 
                RowBox[{
                  RowBox[{"exp", "[", 
                    
                    RowBox[{\(-\((9 - 12\ t - 2\ t\^2 + 4\ t\^3 + t\^4)\)\), 
                      "/", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["t",
                              FontSlant->"Italic"]}]], "2"]}], "]"}], "/"}]}],
               "|", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], "|"}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 
        lim\_\(\(\[CapitalDelta]\[Omega]\)\(\[Rule]\)\(\[Infinity]\)\(\ \
\)\)\((\[CapitalDelta]\[Omega]\ t\ cos\ \[CapitalDelta]\[Omega]\ t - 
                sin\ \[CapitalDelta]\[Omega]\ t)\)/t\^2\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(Hint: in each case, consider the integral ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(t\_o - \[Epsilon]\)\%\(t\_o + \
\[Epsilon]\)\(f(t)\) \(g(t)\) \(\(\[DifferentialD]t\)\(\ \)\)\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["for some function ",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`g(t)\)],
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[" . Also, it is useful to plot the functions to see what they look \
like.)",
    FontColor->RGBColor[0, 0, 1]]
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Evaluate the following integrals by hand:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-10\)\%0\ \ \(t\^5\) \(\[Delta](
            t\^3 + 8)\) \[DifferentialD]t\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \
\[Delta](cos\ \ t)\)/t\^2 \[DifferentialD]t\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_3\%\[Infinity]\( \[Delta](sin\ t\^2)\)/
            t\^2 \[DifferentialD]t\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " Evaluate the following generalized Fourier and inverse-Fourier integrals \
by hand:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity] 
          cos\ \[Omega]\ t \[DifferentialD]\[Omega]\/\[Pi]\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b) ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity] t\/\(\
\[ImaginaryI]\ a + t\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \
\(\(\[DifferentialD]t\)\(\ \ \ \)\)\)]],
  "  ( ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " real, ",
  Cell[BoxData[
      \(TraditionalForm\`a > 0\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["(c) ",
    FontWeight->"Bold"],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(-i\)\ \
\[Omega]\ \ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\) \
\[DifferentialD]\[Omega]\/\(2  \[Pi]\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity] 
          t\ \(h(t)\)\ \(\[ExponentialE]\^\(\[ImaginaryI]\ \[Omega]\ t\)\) \(\
\(\[DifferentialD]t\)\(\ \)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is the Heaviside step function."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Infinity]\( 
            tanh(\[Omega]\ T)\)\ \ sin\ \[Omega]\ t \
\[DifferentialD]\[Omega]\/\[Pi]\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((T > 0)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " Prove ",
  StyleBox["Parseval's theorem",
    FontSlant->"Italic"],
  ": for any function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " with a Fourier transform ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ","
}], "Text",
  CellTags->"i:113"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\(|\)\(f(
              t)\)\( | \^2\)\(\[DifferentialD]t\)\) = \[Integral]\_\(-\
\[Infinity]\)\%\[Infinity]\(\(|\)\(\(f\&~\)(\[Omega])\)\( | \^2\)\(\
\[DifferentialD]\[Omega]/2  \[Pi]\)\)\)]],
  "."
}], "NE3",
  CellTags->"(2.3.88)"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " The uncertainty principle of Fourier analysis, Eq. ",
  ButtonBox["(2.3.24)",
    ButtonData:>"(2.3.24)",
    ButtonStyle->"Hyperlink"],
  ", can be made more precise by defining the width of a real function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " as follows. Let the square of the width of the function be ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "2"], " ", "=", 
          " ", \(\[Integral]\(t\^2\) \(\(f\^2\)(
                t)\) \[DifferentialD]t/\(\[Integral]\(\(f\^2\)(
                      t)\) \[DifferentialD]t\)\)}], TraditionalForm]]],
  ". (We square the function because it may be negative in some regions.) \
Thus, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " is the root mean square (rms) width of ",
  Cell[BoxData[
      \(TraditionalForm\`f\^2\)]],
  ". \n\tNow define the rms width ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\)]],
  " of the Fourier transform function, ",
  Cell[BoxData[
      \(TraditionalForm\`\(f\&~\)(\[Omega])\)]],
  ", in the same manner: ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\^2 = \[Integral]\(\(\(\
\[Omega]\^2\)(\(|\)\(\(f\&~\)(\[Omega])\)\(|\))\)\^2\) \[DifferentialD]\
\[Omega]/\(\[Integral]\(\((\(|\)\(\(f\&~\)(\[Omega])\)\(|\))\)\^2\) \
\[DifferentialD]\[Omega]\)\)]],
  ". (We take the absolute value of ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\)]],
  " because it may be complex.)"
}], "Text",
  CellTags->"i:106"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Omega]\^2 = \[Integral]\(\((\
\[DifferentialD]f/\[DifferentialD]t)\)\^2\) \[DifferentialD]t/\(\[Integral]\(\
\(f\^2\)(t)\) \[DifferentialD]t\)\)]],
  ". (Hint: Use Eq. ",
  ButtonBox["(2.3.88)",
    ButtonData:>"(2.3.88)",
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Consider the function ",
  Cell[BoxData[
      \(TraditionalForm\`u(t)\  = \ 
        t\ \(f(t)\)\  + \ \[Lambda]\ \[DifferentialD]f/\[DifferentialD]t\)]],
  ". Show that  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Integral]\(\(u\^2\)(t)\) \[DifferentialD]t\), "=", 
          RowBox[{
            RowBox[{"(", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "2"], 
                "+", \(\(\[Lambda]\^2\) \[CapitalDelta]\[Omega]\^2\), "-", 
                "\[Lambda]"}], 
              ")"}], \(\[Integral]\(\(f\^2\)(t)\) \[DifferentialD]t\)}]}], 
        TraditionalForm]]],
  ". (Hint: ",
  Cell[BoxData[
      \(TraditionalForm\`f\ \[DifferentialD]f/\[DifferentialD]t = \((1/
              2)\)\ \[DifferentialD]\ f\^2/\[DifferentialD]t\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\(\(u\^2\)(
              t)\) \[DifferentialD]t \[GreaterEqual] \ 0\)]],
  " for all real ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", prove that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{"\[CapitalDelta]\[Omega]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}], "\[GreaterEqual]", 
            " ", \(1/2\)}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(2.3.89)"],

Cell[TextData[{
  "(Hint: The quadratic function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " in part (b) cannot have distinct real roots.) Equation ",
  ButtonBox["(2.3.89)",
    ButtonData:>"(2.3.89)",
    ButtonStyle->"Hyperlink"],
  " is an improved version of the uncertainty principle, and is directly \
analogous to Heisenberg's uncertainty principle ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalDelta]E", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}], "\[GreaterEqual]", 
          " ", \(\[HBar]/2\)}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`E\)]],
  " is the energy."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Show that equality in Eq. ",
  ButtonBox["(2.3.89)",
    ButtonData:>"(2.3.89)",
    ButtonStyle->"Hyperlink"],
  " is achieved only for Gaussian functions, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(f\_o\) \(exp(\(-a\)\ t\^2)\), \ 
      a > 0\)]],
  ". Thus, Gaussians exhibit the \"minimum uncertainty\" in that the product \
",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]\[Omega]", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " is minimized. (Hint: Show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[CapitalDelta]\[Omega]", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}], "=", " ", \(1/2\)}], 
        TraditionalForm]]],
  " only if ",
  Cell[BoxData[
      \(TraditionalForm\`u(t) = 0\)]],
  ",  and use this equation to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ". )"
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " One can perform discrete Fourier transforms and inverse transforms on \
smooth data simply by discretizing the Fourier and inverse Fourier integrals. \
"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Take a numerical Fourier transform of the smooth function ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(-t\^2\)\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) \[LessEqual] \ t \[LessEqual] \ 3\)]],
  " by using Eqs. ",
  ButtonBox["(2.3.53)",
    ButtonData:>"(2.3.53)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.54)",
    ButtonData:>"(2.3.54)",
    ButtonStyle->"Hyperlink"],
  ", taking \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0.1 and \[CapitalDelta]\[Omega] =0.4. with \[Omega] in the range",
  Cell[BoxData[
      \(TraditionalForm\`\(-6\) \[LessEqual] \ \[Omega] \[LessEqual] \ 6\)]],
  ".   Compare the  result with the exact Fourier transform, found \
analytically, by plotting both on the same graph vs. frequency. (This \
requires you to determine the frequency associated with the position of a \
given element in the transformed data.) "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Take the inverse transform of the data found in part a) using Eqs. ",
  ButtonBox["(2.3.55)",
    ButtonData:>"(2.3.55)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.3.56)",
    ButtonData:>"(2.3.56)",
    ButtonStyle->"Hyperlink"],
  ". Does the result return to the original function? Plot the difference \
between the original function and this result. "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat (a) and (b), but take the range of \[Omega] to be ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) \[LessEqual] \ \[Omega] \[LessEqual] \ 3\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " Using a discrete Fourier transform  that you create yourself (not a fast \
Fourier transform), analyze the noisy data in Table ",
  ButtonBox["2.2",
    ButtonData:>"Table 2.2",
    ButtonStyle->"Hyperlink"],
  " and determine the main frequencies present, in hertz. The time between \
samples is \[CapitalDelta]t=0.0005 s. "
}], "Text"],

Cell["Table 2.2:  Data for Exercise (14) ", "Text",
  CellTags->"Table 2.2"],

Cell["\<\
f = {3.42637, 2.26963, -1.70619, -2.65432, 0.24655, 1.40931, \
0.470959, -0.162041, -0.336245, -0.225337, -0.112631, 0.447789, -0.667762, \
-1.21989, 0.269703, 2.32636, 2.01974, -2.38678, -3.75246, 0.298622, 3.86088, \
2.27861, -1.77577, -2.46912, 0.134509, 1.02331, 0.715012, -0.339313, \
0.0948633, -0.0859965, 0.0371488, 0.347241, -0.353479, -1.47499, -0.15022, \
2.68935, 1.88084, -2.08172, -3.83105, 0.0629925, 3.87223, 2.13169, -1.64515, \
-2.42553, -0.288646, 1.4674, 0.315207, -0.480925, -0.216251, 0.144092, \
-0.00670936, 0.382902, -0.495702, -1.38424, 0.256142, 2.22556, 2.02433, \
-2.33588, -3.60477, -0.163791, 3.55462, 2.17247, -1.94027, -2.41668, \
-0.0176065, 1.05511, 0.489467, -0.515668, -0.122057, -0.112292, -0.0326432, \
0.489771, -0.690393, -1.27071, 0.274066, 2.29677, 1.97186, -2.3131, -3.99321, \
-0.228793, 3.95866, 1.84941, -1.95499, -2.2549, 0.104038, 1.29127, 0.769865, \
-0.362732, -0.271452, -0.0638439, 0.0734938, 0.0774499, -0.333983, -1.56588, \
-0.193863, 2.37758, 1.92296, -2.12179, -3.87906, -0.21919, 3.96223, 2.01793, \
-2.05241, -2.7803, -0.296432, 1.18286, 0.687172, -0.449909, -0.193565, \
0.191591, 0.310403, 0.437337, -0.706701, -1.35889, -0.0630913, 2.54978, \
1.79384, -2.21964, -3.88036, -0.127792, 3.882, 2.32878, -1.56785, -2.6985, \
0.219771, 1.32518, 0.669142, -0.44272, 0.123107, -0.15768, 0.375066, \
-0.0682963, -0.467915, -1.3636, -0.235336, 2.28427, 1.80534, -1.83133, \
-3.58337, 0.0344805, 3.42263, 2.21493, -1.86957, -2.62763, -0.159368, \
1.50048, 0.48287, -0.453638, -0.172236, -0.124694};\
\>", "Input",
  Evaluatable->True,
  ShowCellTags->True,
  CellTags->"Cell 2.89"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " A Fourier series or transform is a way to decompose a function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " in terms of complex orthogonal basis functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\
\)]],
  ". The method relies on the orthogonality of these basis functions. A \
discrete Fourier transform can be thought of as a way to decompose vectors ",
  StyleBox["f ",
    FontWeight->"Bold"],
  " of dimension ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "  complex orthogonal basis vectors.  The ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  "th basis vector is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["e",
              FontWeight->"Bold",
              FontSlant->"Plain"], \((m)\)], 
          "=", \({1, \[ExponentialE]\^\(\(-2\)\ \[Pi]\ m\ \[ImaginaryI]/N\), \
\[ExponentialE]\^\(\(-4\)\ \[Pi]\ m\ \[ImaginaryI]/N\), \(\(...\)\(.\)\), \
\[ExponentialE]\^\(\(-2\) \[Pi]\ m\ \(\[ImaginaryI](N - 1)\)/N\)}\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show directly that these basis vectors are orthogonal with respect to the \
following  inner product defined for two vectors ",
  StyleBox["f",
    FontWeight->"Bold"],
  " and ",
  StyleBox["g",
    FontWeight->"Bold"],
  ": ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox["g",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], " ", "=", " ", 
          RowBox[{
            SuperscriptBox[
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "*"], "\[CenterDot]", 
            StyleBox["g",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". [Hint: Use the following sum: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 0\)\%\(N - 1\)x\^N = \(1 - x\^N\)\/\(1 \
- x\)\)]],
  "]"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that the decomposition of a vector ",
  StyleBox["f ",
    FontWeight->"Bold"],
  "in terms of these basis vectors,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{\(\[Sum]\+\(m = 0\)\%\(N - 1\)\), 
            RowBox[{\(f\&~\_m\), 
              SuperscriptBox[
                StyleBox["e",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \((m)\)]}]}]}], TraditionalForm]]],
  ", leads directly to Eq. ",
  ButtonBox["(2.3.63)",
    ButtonData:>"(2.3.63)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the orthogonality of these basis vectors to determine the \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`f\&~\_m\)]],
  ", and compare the result with Eq. ",
  ButtonBox["(2.3.59)",
    ButtonData:>"(2.3.59)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " A data file on the disk accompanying this book, entitled ",
  StyleBox["aliendata.txt",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", contains a (simulated) recording made by a (simulated) scientist \
listening for alien communications from nearby stars. Read in this datafile \
from the cd of this book using the command ",
  StyleBox["<<aliendata.txt",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". (A ",
  StyleBox["Directory",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and/or ",
  StyleBox["SetDirectory",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command may also be necessary.) Within this file is a data list of the \
form ",
  StyleBox["f = {",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "...",
  StyleBox["}",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Reading in the file defines the data list ",
  StyleBox["f",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Use ",
  StyleBox["ListPlay",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " to play the data  as a sound. Take the samplerate to be 22,050 hertz."
}], "Text",
  CellTags->"i:100"],

Cell["\<\
\tAs you can hear, the data is very noisy. By taking a Fourier \
transform,  find a way to remove this noise by applying an appropriate filter \
function to the  Fourier-transformed data. What is the aliens' message? Are \
they peaceful or warlike?\
\>", "Text"],

Cell["\<\
\t[Caution: This data file is rather large. When manipulating it, \
always end your statements with a semicolon to stop any output of the \
file.]\
\>", "Text"],

Cell[TextData[{
  StyleBox["(18)(a)",
    FontWeight->"Bold"],
  " A damped harmonic oscillator  is driven by a force of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\)\(\ \)\(=\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(h(t)\) t\^2\ \(Exp(\(-t\))\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is a Heaviside step function. The oscillator satisfies the equation"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + 2  x\^\[Prime] + 4  x = 
        f(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Use pencil-and-paper methods involving Fourier transforms and inverse \
transforms to find the response of the oscillator, ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ", assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x' \((0)\) = 1\)]],
  ". Plot the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat the analysis of part (a) for force of the form ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \(h(t)\)\ t\ sin\ 4  t\)]],
  ". Instead of Fourier methods, this time use the Green's function for this \
equation. Plot the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  " Use Fourier transform techniques to find and plot the current in amperes \
as a function of time in the circuit of Fig. ",
  ButtonBox["2.12",
    ButtonData:>"Fig. 2.12",
    ButtonStyle->"Hyperlink"],
  " when the switch is closed at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  "."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007_0001L2000`400?l00000o`00003oooooooo`
ooooo`00ooooooo`ooooo`00ooooooo`ooooo`00ooooooo`ooooo`00ooooooo`ooooo`00ooooooo`
ooooo`00ooooooo`ooooo`00ooooooo`ooooo`00ooooooo`ooooo`00ooooooo`ooooo`003?oooooo
0?ooomL0oooo3Oooool000coooooUP3oool5000000030820P03oool0oooo00X0oooo00<000000?oo
o`3oool0o`3oool/0?ooo`gooooo000<oooooiD0oooo00<0P8200000000000001@0000000`30`<00
oooo0?ooo`040?ooo`030410@0000000000000@0000000<0@4100?ooo`3oool0103oool00`30`<00
P82000000004000000030820P030`<00oooo00H0oooo00<0`<300000000000000`0000000`10@400
P8200?ooo`070?ooo`H0P82000<0`<300?ooo`3oool01P3oool50820P?00oooo3Oooool000cooooo
U03oool:000000D0oooo2P0000050?ooo`T0000000<0P8200?ooo`3oool0103oool8000000030820
P03oool0oooo00@0oooo200000060?ooo`030820P0000000000000D00000k`3oool=ooooo`003?oo
oonB0?ooo`050410@0000000000000000010@4000`3oool00`20P800@41000000002000000030<30
`03oool0`<3000@000001020P8001@10@4000000000000000000P8200080oooo00@0@41000000000
000000001020P803000000050820P03oool0oooo0<30`020P8000`0000030820P0@0000000D0`<30
0?ooo`3oool0oooo0820P00:000000050<30`03oool0oooo0?ooo`20P8002@0000000`10@400oooo
0?ooo`3[0?ooo`gooooo000<oooooi80oooo100000060?ooo`@0000000D0oooo0820P00000000000
0820P0060?ooo`@0000000<0oooo0000000000000P0000000`20P800oooo0?ooo`030?ooo`<00000
00<0P8200?ooo`0000000`0000050?ooo`040820P0000000000000000080oooo100000000`20P800
oooo0?ooo`020?ooo`@000000P3oool00`20P800000000000002000000<0oooo1@00003/0?ooo`go
oooo000<oooooi40oooo00@0@410000000000000P820203oool00`10@40000000000000300000003
0820P03oool0oooo00H0oooo0`0000001@10@400000000000010@400P82000H0oooo00D0`<300000
0000000000000820P002000000030410@030`<00oooo00D0oooo00D0P82000000000000000000820
P003000000030820P03oool0oooo00@0oooo00D0@410000000000000@4100?ooo`04000000030<30
`03oool0oooo0080oooo00D0`<3000000000000000000410@03[0?ooo`gooooo000<oooooi40oooo
0`00000:0?ooo`D000002P3oool5000000X0oooo1@0000000`20P800oooo0?ooo`060?ooo`030820
P0000000000000<000002@3oool6000000030820P03oool0oooo00H0oooo0`00002_0?ooo`030820
P0000000000000@00000=@3oool=ooooo`003?oooon@0?ooo`<000002`3oool01@20P80000000000
00000000`<3000X0oooo00D0@41000000000000000000410@00:0?ooo`050820P000000000000000
0020P8002P3oool4000000030410@03oool0oooo00P0oooo1@0000090?ooo`040<30`00000000000
0820P:`0oooo00<0`<300820P00000001P0000000`10@400P8200?ooo`0b0?ooo`gooooo000<oooo
ohl0oooo00@0`<30000000000000P820303oool3000000/0oooo00D0`<3000000000000000000820
P00;0?ooo`<000002`3oool01020P800000000000000000;0?ooo`040<30`00000000000000000/0
oooo00<0P820000000000000Z`3oool=00000380oooo3Oooool000coooooS`3oool00`20P8000000
0000000<0?ooo`@000002`3oool01@20P8000000000000000000P82000X0oooo1000000;0?ooo`04
0820P00000000000000000/0oooo00@0P820000000000000P820303oool300000:T0oooo00<0P820
0000000000003000000a0?ooo`gooooo000<ooooohl0oooo00<0@410000000000000303oool40000
00030820P03oool0oooo00P0oooo00<0@4100000000000000P00000:0?ooo`D000002P3oool40000
00030<30`03oool0oooo00P0oooo00@0P820000000000000@410303oool00`20P80000000000002Y
0?ooo`l0000000<0P8200?ooo`3oool0;P3oool=ooooo`003?oooon?0?ooo`80000000<0P8200?oo
o`3oool02P3oool4000000030820P03oool0oooo00P0oooo1@0000090?ooo`030820P00000000000
00<000002P3oool4000000030820P03oool0oooo00P0oooo1000000<0?ooo`040820P00000000000
0820P:L0oooo00<0P8200000000000003P00000`0?ooo`gooooo000<ooooohh0oooo0`0000000`30
`<00oooo0?ooo`090?ooo`030820P000000000000080000000<0@4100?ooo`3oool01`3oool60000
00030<30`03oool0oooo00H0oooo00<0@4100000000000000`0000000`30`<00oooo0?ooo`060?oo
o`030<30`000000000000080000000<0P8200?ooo`3oool0203oool5000000`0oooo0P0000000`20
P800oooo0?ooo`2U0?oooa400000<03oool=ooooo`003?oooon>0?ooo`<00000303oool01020P800
00000000003oool2000000T0oooo0`0000001020P800000000000020P8080?ooo`80000000D0P820
0?ooo`00000000000820P0080?ooo`030820P0000000000000<000002@3oool6000000`0oooo0P00
00000`20P800oooo0?ooo`2U0?oooa400000<03oool=ooooo`003?ooool[0?oooed0P82000<0`<30
0?ooo`3oool00`3oool3000000`0oooo00@0P820000000000000oooo0P0000090?ooo`<0000000@0
oooo000000000000P820203oool3000000040?ooo`00000000000820P0P0oooo00@0P82000000000
0000P8200P0000090?ooo`8000000P20P802000000030820P03oool0oooo00T0oooo00<0@4100000
00000000YP3oool00`20P80000000000000?000000030820P03oool0oooo02d0oooo3Oooool000co
oooo:@3oool00`30`<00P8200000001L000000030820P03oool0oooo00<0oooo0`00000<0?ooo`04
0410@000000000000?ooo`8000002@3oool3000000040820P000000000000820P0P0oooo0`000000
103oool0000000000020P8080?ooo`040820P000000000000820P08000002@3oool200000080P820
0P0000000`20P800oooo0?ooo`090?ooo`030820P0000000000000`0oooo[00000000`20P800oooo
0?ooo`0]0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000G@0000050?ooo`<00000303o
ool2000000030820P03oool00000008000001`3oool01@20P80000000000003oool0P82000800000
00<0P8200?ooo`3oool01P3oool3000000040?ooo`00000000000820P0P0oooo00@0P82000000000
0000P8200P0000090?ooo`80000000D0P82000000000000000000820P00;0?ooo`030820P0000000
000000X0oooo00<0P820000000000000Z`0000000`20P800oooo0?ooo`0]0?ooo`gooooo000<oooo
obT0oooo00<0P820000000000000FP3oool00`20P8000000000000050?ooo`<00000303oool20000
00030820P03oool00000008000001`3oool00`20P8000000000000020?ooo`80000000<0P8200?oo
o`3oool01P3oool2000000050820P03oool0000000000020P800203oool2000000030?ooo`20P800
0000008000001`3oool01@20P80000000000003oool0P8200080000000<0P8200?ooo`3oool02@3o
ool00`20P80000000000000:0?ooo`030820P0000000000009X0P8204@0000000`30`<00oooo0?oo
o`0]0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000FP3oool00`20P800000000000005
0?ooo`<00000303oool2000000030820P03oool00000008000001`3oool00`20P800000000000002
0?ooo`80000000<0P8200?ooo`3oool01P3oool2000000050820P03oool0000000000020P800203o
ool2000000030?ooo`20P8000000008000001`3oool00`20P8000000000000020?ooo`80000000<0
P8200?ooo`3oool02@3oool00`20P80000000000000:0?ooo`030820P0000000000009X0oooo4@00
000`0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000FP3oool00`20P800000000000005
0?ooo`<00000303oool2000000030820P03oool00000008000001`3oool00`20P800000000000002
0?ooo`80000000<0P8200?ooo`3oool01P3oool2000000050820P03oool0000000000020P800203o
ool2000000030?ooo`20P8000000008000001`3oool00`20P8000000000000020?ooo`80000000<0
P8200?ooo`3oool02@3oool00`20P80000000000000:0?ooo`80000000<0@4100?ooo`3oool0V03o
ool00`20P80000000000000=000000030410@03oool0oooo02h0oooo3Oooool000cooooo:@3oool0
0`20P80000000000001J0?ooo`030820P0000000000000D0oooo0`00000<0?ooo`040820P0000000
00000?ooo`<00000203oool3000000040?ooo`00000000000820P0P0oooo0`000000103oool00000
00000020P8080?ooo`80000000<0oooo0820P00000000P0000070?ooo`030820P000000000000080
oooo0P0000000`20P800oooo0?ooo`090?ooo`030820P0000000000000X0oooo0P0000000`20P800
oooo0?ooo`2I0?ooo`l0000000<0P8200?ooo`3oool0;P3oool=ooooo`003?oooolY0?ooo`030820
P0000000000005X0oooo00@0`<30000000000000`<30103oool3000000`0oooo00@0P82000000000
0000oooo0`0000080?ooo`<0000000@0oooo000000000000P820203oool3000000040?ooo`000000
00000820P0P0oooo00@0P820000000000000P8200P0000000`20P800oooo0?ooo`060?ooo`800000
00D0P8200?ooo`00000000000820P00;0?ooo`030820P0000000000000X0oooo0P0000000`20P800
oooo0?ooo`2I0?ooo`030820P0000000000000/0000000<0P8200?ooo`3oool0;`3oool=ooooo`00
3?oooolY0?ooo`030820P0000000000005/0oooo0P0000000`20P800oooo0?ooo`020?ooo`<00000
303oool01020P80000000000003oool2000000T0oooo0`0000000`20P8000000000000090?ooo`H0
000000<0P8200?ooo`3oool01P3oool01020P800000000000020P802000000T0oooo0P0000001@20
P800oooo000000000000P82000/0oooo00<0P8200000000000002P3oool2000000030820P03oool0
oooo09X0oooo3@00000b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000F`3oool20000
00030820P03oool0oooo0080oooo00@0P820000000000000P8202`3oool00`30`<00000000000003
000000T0oooo0`0000000`10@4000000000000090?ooo`80000000@0@41000000000000000002@3o
ool00`20P800000000000002000000030410@03oool0oooo00L0oooo0P0000001@20P80000000000
00000000`<3000/0oooo0P0000000`10@400oooo0?ooo`070?ooo`040820P000000000000820P9d0
oooo00<0`<300820P00000001P0000000`10@400P8200?ooo`0b0?ooo`gooooo000<ooooobT0oooo
00<0P820000000000000F`3oool3000000D0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`D00000
2P3oool5000000T0oooo00<0P8200000000000000`0000090?ooo`030<30`0000000000000800000
00<0P8200?ooo`3oool01`3oool00`20P800000000000003000000`0oooo0P0000000`20P800oooo
0?ooo`070?ooo`<00000X03oool01030`<00P8200820P010@4030820P3D0oooo3Oooool000cooooo
:@3oool00`20P80000000000001L0?ooo`<00000103oool3000000`0oooo100000000`20P800oooo
0?ooo`080?ooo`@0000000<0P8200?ooo`3oool0203oool5000000X0oooo100000000`20P800oooo
0?ooo`080?ooo`D00000303oool2000000030820P03oool0oooo00L0oooo0`00003L0?ooo`gooooo
000<ooooobT0oooo00<0P820000000000000G03oool01010@400000000000030`<030?ooo`040820
P000000000000<30`0`0oooo0`0000000`20P800oooo0?ooo`080?ooo`050410@000000000000000
0030`<002P3oool01020P800000000000000000;0?ooo`040410@00000000000000000/0oooo1000
000<0?ooo`040820P000000000000<30`0P0oooo00@0`<300000000000000000g03oool=ooooo`00
3?oooolY0?ooo`030820P0000000000005`0oooo00@0P820000000000000P820103oool200000003
0820P03oool0oooo00X0oooo0`00000;0?ooo`040820P00000000000000000`0oooo0`00000;0?oo
o`040820P00000000000000000/0oooo00@0P820000000000000P820303oool00`20P80000000000
00090?ooo`030820P000000000000=d0oooo3Oooool000cooooo:@3oool00`20P80000000000001M
0?ooo`80000000<0@4100?ooo`3oool00`3oool2000000`0oooo0`0000000`20P800oooo0?ooo`08
0?ooo`050820P0000000000000000020P8002P3oool4000000/0oooo00D0P8200000000000000000
0<30`00:0?ooo`040820P000000000000410@0/0oooo00@0P820000000000000P8202@3oool20000
00030410@03oool0oooo0</0oooo00<0@41000000030`<003@3oool=ooooo`003?oooolY0?ooo`03
0820P0000000000005d0oooo0`0000050?ooo`030820P0000000000000X0oooo1@00000:0?ooo`D0
00002@3oool00`20P800000000000003000000X0oooo100000000`20P800oooo0?ooo`080?ooo`04
0820P00000000000000000/0oooo0`00000:0?ooo`80000000<0P8200?ooo`3oool0bP3oool01020
P800000000000000000=0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000G@3oool01020
P80000000000000000040?ooo`040<30`000000000000820P0P0oooo00<0`<300000000000000`00
00000`20P800oooo0?ooo`060?ooo`H0000000<0`<300?ooo`3oool01P3oool6000000030<30`03o
ool0oooo00H0oooo00<0`<300000000000000`0000090?ooo`030820P0000000000000<000002@3o
ool01010@400000000000020P8090?ooo`<0000000<0`<300?ooo`3oool0b@3oool01@20P8000000
000000000000`<3000d0oooo3Oooool000cooooo:@3oool00`20P80000000000001N0?ooo`<00000
1@3oool3000000P0oooo1`0000000`20P800oooo0?ooo`040?ooo`050820P0000000000000000020
P8000`0000070?ooo`050820P000000000000820P03oool00P0000000`20P800oooo0?ooo`060?oo
o`040820P000000000000820P0<00000203oool6000000030820P03oool0oooo00H0oooo0`000009
0?ooo`040820P0000000000000000</0oooo00@0P82000000000000000003`3oool=ooooo`003?oo
oolY0?ooo`030820P0000000000005h0oooo00@0P820000000000000P820103oool01030`<000000
0000000000060?ooo`<0000000<0@4100?ooo`20P8000P0000000`10@400oooo0?ooo`040?ooo`<0
000000<0P8200?ooo`3oool00P0000000`20P800oooo0?ooo`040?ooo`060410@000000000000<30
`03oool0@4100P0000000`30`<00oooo0?ooo`040?ooo`<0000000<0oooo0<30`00000000P000000
0`20P800oooo0?ooo`040?ooo`030410@000000000000080P8200P0000000`10@400oooo0?ooo`05
0?ooo`<0000000<0P8200?ooo`3oool01`3oool00`10@40000000000003;0?ooo`050820P0000000
000000000030`<003`3oool=ooooo`003?oooolY0?ooo`030820P0000000000005l0oooo00@0@410
000000000000P820103oool01@20P8000000000000000000P82000<0oooo00D0@410000000000000
00000<30`0020?ooo`040410@00000000000000000@0oooo00<0@410000000000000103oool01030
`<00000000000010@4030?ooo`050<30`0000000000000000020P8000`3oool2000000030410@020
P800oooo00<0oooo00@0@410000000000000`<300P3oool01@20P8000000000000000000`<3000@0
oooo00@0P820000000000000P8200P3oool01030`<0000000000000000050?ooo`040410@0000000
0000000000T0oooo00@0`<30000000000000P820bP3oool01@10@4000000000000000000`<300100
oooo3Oooool000cooooo:@3oool00`20P80000000000001O0?ooo`030820P0000000000000800000
103oool01P20P8000000000000000000P8200?ooo`@00000103oool00`20P8000000000000020000
00030?ooo`20P8000000008000001P3oool4000000030820P03oool000000080000000<0P8200?oo
o`3oool00`3oool3000000030820P03oool0oooo00@00000103oool01020P800000000000020P803
0?ooo`040820P00000000000000000@0oooo100000030?ooo`@000002P3oool3000000030820P03o
ool0oooo0<L0oooo1000000B0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000H03oool0
0`20P800000000000002000000040<30`03oool0oooo0<30`0P0000000<0`<300?ooo`3oool00`3o
ool00`20P800@41000000005000000030<30`03oool0oooo00@0oooo00<0`<300000000000000P00
00001020P800000000000010@4060?ooo`060820P0000000000000000020P800@4100`0000000`30
`<00oooo0?ooo`020?ooo`030<30`000000000000080000000D0P82000000000000000000410@006
0?ooo`060410@000000000000410@03oool0P8200`0000000`30`<00oooo0?ooo`070?ooo`040820
P000000000000820P<T0oooo00D0@41000000000000000000<30`00B0?ooo`gooooo000<ooooobT0
oooo00<0P820000000000000HP3oool4000000050820P03oool0oooo0?ooo`20P8001@0000090?oo
o`H000002@3oool6000000P0oooo1`0000080?ooo`030820P0000000000000@00000203oool70000
00X0oooo00@0P820000000000000P820b@3oool4000001@0oooo3Oooool000cooooo:@3oool00`20
P80000000000001S0?ooo``0000000<0@4100820P020P800103oool00`30`<00P8200410@0050000
00030410@030`<00oooo00@0oooo00<0`<300820P00000001P0000000`20P800oooo0?ooo`050?oo
o`030820P0000000000000<0000000<0`<300?ooo`3oool01P3oool00`30`<000000000000030000
00030820P03oool0oooo00H0oooo00<0P8200000000000000`0000000`20P800oooo0?ooo`060?oo
o`030<30`020P800000000800000b@3oool01@10@4000000000000000000`<3001@0oooo3Oooool0
00cooooo:@3oool00`20P80000000000001T0?oooaP0000000<0P8200000000000004`0000030?oo
o`X00000103oool00`20P800000000000006000000030820P03oool0oooo00<0oooo2P0000060?oo
o`D0000000<0P8200?ooo`3oool0aP3oool01020P800000000000000000F0?ooo`gooooo000<oooo
obT0oooo00<0P820000000000000I@3oool01030`<00P8200820P010@4030820P0040<30`03oool0
P8200410@0X0000000D0P8200?ooo`3oool0P8200410@009000000040410@020P800`<300820P0`0
000000<0P8200?ooo`20P8003@0000000`20P80000000000000<000000030820P0000000000000D0
00000P20P804000000030410@020P800oooo0<L0oooo00D0P82000000000000000000<30`00F0?oo
o`gooooo000<ooooobT0oooo00<0P820000000000000L@3oool00`30`<00P8200820P0040820P0H0
oooo00<0`<300820P020P8001@20P8000`30`<00oooo0?ooo`040?ooo`@0P82000H0@41000000000
000000000410@030`<050?ooo`030<30`020P800@41000H0000000<0P8200<30`03oool00P3oool0
0`20P800000000000006000000030410@020P800`<300080oooo00<0`<300820P000000020000000
0`10@400P8200?ooo`380?ooo`040410@000000000000410@1P0oooo3Oooool000cooooo:@3oool0
0`20P80000000000002l0?ooo`030820P0000000000000<00000b`3oool4000001T0oooo3Oooool0
00cooooo:@3oool00`20P80000000000003o0?ooohd0oooo00D0@41000000000000000000<30`00I
0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooon<0?ooo`@000006`3oool=oooo
o`003?oooolY0?ooo`030820P000000000000?l0ooooR`3oool01@10@4000000000000000000`<30
01/0oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooohX0oooo00@0P82000000000
000000007@3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooR@3oool01@20P800
0000000000000000`<3001d0oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooohP0
oooo00@0P82000000000000000007`3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0
ooooQ`3oool01@20P8000000000000000000`<3001l0oooo3Oooool000cooooo:@3oool00`20P800
00000000003o0?ooohH0oooo00D0@41000000000000000000<30`00P0?ooo`gooooo000<ooooobT0
oooo00<0P820000000000000o`3ooon50?ooo`@000008P3oool=ooooo`003?oooolY0?ooo`030820
P000000000000?l0ooooQ03oool01@10@4000000000000000000`<300280oooo3Oooool000cooooo
:@3oool00`20P80000000000003o0?oooh<0oooo1000000T0?ooo`gooooo000<ooooobT0oooo00<0
P820000000000000o`3ooon20?ooo`050410@0000000000000000030`<00903oool=ooooo`003?oo
oolY0?ooo`030820P000000000000?l0ooooP@3oool01020P800000000000000000V0?ooo`gooooo
000<ooooobT0oooo00<0P820000000000000o`3ooon00?ooo`050820P0000000000000000030`<00
9P3oool=ooooo`003?oooolY0?ooo`030820P000000000000;/0oooo3`0000000`20P800oooo0?oo
o`0S0?ooo`d000001P3oool4000000030820P03oool0oooo00d0oooo00<0P8200000000000001`00
00040?ooo`T0000000<0P8200?ooo`3oool0C@3oool01020P800000000000000000X0?ooo`gooooo
000<ooooobT0oooo00<0P820000000000000_03oool01@30`<000000000000000000P82000H0oooo
00@0`<300410@000000000009P3oool00`10@400000000000009000000050820P03oool0oooo0?oo
o`30`<000`0000001@10@400P8200820P010@400P82000l0oooo00<0P8200410@00000000P000000
0`20P800oooo0?ooo`060?ooo`060820P0000000000000000020P800`<30D03oool01@20P8000000
000000000000`<3002P0oooo3Oooool000cooooo:@3oool00`20P80000000000002n0?ooo`800000
00<0P8200?ooo`3oool01`3oool00`10@400P8200?ooo`0U0?ooo`030820P0000000P82000L0P820
0P0000030?ooo`030<30`020P800P82000D0oooo00<0P8200410@03oool03P3oool01020P8000000
00000000000:0?ooo`<00000D@3oool01@10@4000000000000000000`<3002T0oooo3Oooool000co
oooo:@3oool00`20P80000000000002n0?ooo`030820P0000000000000T0oooo00<0P8200000003o
ool09P3oool00`20P80000000?ooo`070?ooo`0300000020P800oooo00X0oooo00<0P8200000003o
ool03@3oool01020P800000000000000000:0?ooo`<00000D03oool4000002/0oooo3Oooool000co
oooo:@3oool00`20P80000000000002n0?ooo`040820P000000000000<30`0T0oooo00<0P8200<30
`03oool09P3oool00`20P800@4100?ooo`070?ooo`030<30`03oool0oooo00T0oooo00<0`<300000
0020P8003@3oool01020P800000000000000000:0?ooo`<00000C`3oool01@10@400000000000000
0000`<3002/0oooo3Oooool000cooooo:@3oool00`20P80000000000002o0?ooo`80000000<0P820
0?ooo`3oool0203oool00`20P800oooo0?ooo`0V0?ooo`030820P0000000oooo01<0oooo00<00000
0820P03oool0303oool01020P800000000000000000:0?ooo`<00000CP3oool01020P80000000000
0000000]0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000_`3oool2000000030820P03o
ool0oooo0380oooo00<0P8200410@03oool04P3oool2000000d0oooo00@0P8200000000000000000
2P3oool3000004d0oooo00D0P82000000000000000000<30`00]0?ooo`gooooo000<ooooobT0oooo
00<0P820000000000000_`3oool00`20P80000000000000e0?ooo`80P8204P3oool2000000d0oooo
00@0P82000000000000000002P3oool3000004`0oooo00@0P8200000000000000000;`3oool=oooo
o`003?oooolY0?ooo`030820P000000000000;l0oooo00<0P820000000000000503ooolA00000100
oooo00<0`<3000000020P800403oool00`20P80000000000000=0?ooo`040820P000000000000000
00X0oooo0`00001;0?ooo`050820P0000000000000000030`<00;`3oool=ooooo`003?oooolY0?oo
o`030820P000000000000;l0oooo00@0`<300000000000000000=@3oool00`30`<0000000<30`00>
0?ooo`040820P000000000000410@0d0oooo00@0P82000000000000000002P3oool300000480oooo
00<0P8200410@00000001@0000001@10@4000000000000000000`<300300oooo3Oooool000cooooo
:@3oool00`20P8000000000000300?ooo`<00000=P3oool2000000d0oooo00D0P820000000000000
00000820P00=0?ooo`030820P0000000000000h00000@@3oool00`20P80000000000000900000380
oooo3Oooool000cooooo:@3oool00`20P8000000000000300?ooo`040820P000000000000820P3H0
oooo00<000000820P03oool02P3oool00`20P800000000000002000000h0oooo00@0P82000000000
000000002P20P803000003l0oooo00<0`<300000000000002`00000b0?ooo`gooooo000<ooooobT0
oooo00<0P820000000000000`@3oool2000000030820P03oool0oooo03@0oooo0P0000090?ooo`H0
00003`3oool01020P800000000000000000:0?ooo`<00000?`3oool00`20P80000000000000<0000
0340oooo3Oooool000cooooo:@3oool00`20P8000000000000310?ooo`80000000<0@4100?ooo`3o
ool0403ooolA000001<0oooo00<0P82000000020P8001@3oool7000000030820P030`<00oooo00h0
oooo00@0P82000000000000000002P3oool3000003l0oooo3`0000000`20P800oooo0?ooo`0^0?oo
o`gooooo000<ooooobT0oooo00<0P820000000000000`@3oool00`20P80000000000000f0?ooo`03
0820P0000000000000H0oooo1@00000B0?ooo`040820P00000000000000000X0oooo0`00000n0?oo
o`030820P0000000000000h00000<03oool=ooooo`003?oooolY0?ooo`030820P000000000000<40
oooo00@0P820000000000000P820;03oool00`10@400oooo0?ooo`060?ooo`030820P00000000000
00H0oooo00<0@41000000020P800503oool01020P800000000000000000:0?ooo`<00000?P3ooolA
00000300oooo3Oooool000cooooo:@3oool00`20P8000000000000320?ooo`<00000;03oool00`00
0000oooo0?ooo`060?ooo`<000001P3oool00`20P80000000?ooo`0D0?ooo`040820P00000000000
000000X0oooo0`00000n0?oooa40000000<0P8200?ooo`3oool0;@3oool=ooooo`003?oooolY0?oo
o`030820P000000000000<80oooo0`0000000`30`<00oooo0?ooo`0Y0?ooo`030820P0000000`<30
00D0oooo00@0P820000000000000@4101`3oool00`000000P8200?ooo`0C0?ooo`040820P0000000
0000000000X0oooo0`00000m0?oooa80000000<0P8200?ooo`3oool0;@3oool=ooooo`003?oooolY
0?ooo`030820P000000000000<80oooo00@0P820000000000000P820;03oool3000000<0P8201000
00000`30`<00oooo0?ooo`050?ooo`030820P0000000P82000D0P8203P3oool01020P80000000000
0000000:0?ooo`<00000?@3ooolB000000030820P03oool0oooo02d0oooo3Oooool000cooooo:@3o
ool00`20P8000000000000330?ooo`80000000<0P8200?ooo`3oool0:`3oool8000000X0oooo1`00
00000`20P800oooo0?ooo`0;0?ooo`040820P00000000000000000X0oooo0`00000m0?oooa800000
00<0P8200?ooo`3oool0;@3oool=ooooo`003?oooolY0?ooo`030820P000000000000<80oooo00D0
P82000000000000000000820P00/0?ooo`030<30`020P800@41000<0000000<0P8200<30`03oool0
2@3oool00`20P800000000000004000000030410@03oool0oooo00P0oooo00<0`<300820P0000000
1@0000020820P0@0oooo0P20P805000000030410@020P800`<3003X0oooo4@0000000`30`<00oooo
0?ooo`0]0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000`03oool900000:00oooo4@00
000`0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomZ0?ooo`030<30`0000000
000000d0000000<0@4100?ooo`3oool0;P3oool=ooooo`003?oooolY0?ooo`030820P00000000000
0?l0ooooJ`3oool?000000030820P03oool0oooo02h0oooo3Oooool000cooooo:@3oool00`20P800
00000000003o0?ooof/0oooo00<0P8200000000000002`0000000`20P800oooo0?ooo`0_0?ooo`go
oooo000<ooooobT0oooo00<0P820000000000000o`3ooom]0?ooo`/0000000<0P8200?ooo`3oool0
<03oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooKP3oool00`20P80000000000
0005000000030410@020P800oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o
0?ooog80oooo00D0`<300?ooo`00000000000820P00d0?ooo`gooooo000<ooooobT0oooo00<0P820
000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?oo
o`030820P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000co
oooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`go
oooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0
<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03o
ool0oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P000000
0`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?oo
o`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0
ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P8000000
0000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0
P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY
0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool0
00cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?oo
o`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3o
ool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820
P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P00
00000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd
0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P00000000000
0?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P800
00000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo
00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oo
oolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Ooo
ool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b
0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?oo
o`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool200000003
0820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo
0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3o
oomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P0000000
00000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20
P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0
oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`00
3?oooolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo
3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?oo
o`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P820
0?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool20000
00030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0
oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000
o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000
000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool0
0`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<oooo
obT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=oooo
o`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380
oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo
0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0
P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool2
000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?oo
og@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P82000000000
0000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820
P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3o
ool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<
ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=
ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03oool0oooo
0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800
oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`800000
00<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03o
ool2000000030820P03oool0oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o
0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P8200000
00000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`03
0820P000000000000?l0ooooM03oool2000000030820P03oool0oooo0380oooo3Oooool000cooooo
:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20P800oooo0?ooo`0b0?ooo`gooooo
000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80000000<0P8200?ooo`3oool0<P3o
ool=ooooo`003?oooolY0?ooo`030820P000000000000?l0ooooM03oool2000000030820P03oool0
oooo0380oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?ooog@0oooo0P0000000`20
P800oooo0?ooo`0b0?ooo`gooooo000<ooooobT0oooo00<0P820000000000000o`3ooomd0?ooo`80
000000<0P8200?ooo`3oool0<P3oool=ooooo`003?oooolY0?ooo`030820P000000000000?l0oooo
J03oool<0820P080000000<0@4100820P020P8003020P80V0?ooo`gooooo000<ooooobT0oooo00<0
P820000000000000o`3ooomX0?oooad000009P3oool=ooooo`003?oooolY0?ooo`030820P0000000
00000?l0ooooJ03ooolM000002H0oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?oo
oj/0oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?oooj/0oooo3Oooool000cooooo
:@3oool00`20P80000000000003o0?oooj/0oooo3Oooool000cooooo:@3oool00`20P80000000000
003o0?oooj/0oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?oooj/0oooo3Oooool0
00cooooo:@3oool00`20P80000000000003o0?oooj/0oooo3Oooool000cooooo:@3oool00`20P800
00000000003o0?oooj/0oooo3Oooool000cooooo:@3oool00`20P80000000000003o0?oooj/0oooo
3Oooool000cooooo:@20P8000`10@40000000000000V0820P0030<30`03oool0oooo0?l0ooooPP3o
ool=ooooo`003?oooomB000000030820P03oool0oooo0?l0ooooPP3oool=ooooo`003?oooomB0000
00030820P03oool0oooo0?l0ooooPP3oool=ooooo`003?oooooo0?ooomL0oooo3Oooool000cooooo
o`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oooooo0?ooomL0oooo3Oooool0
00coooooo`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oooooo0?ooomL0oooo
3Oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oooooo0?oo
omL0oooo3Oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oo
oooo0?ooomL0oooo3Oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=oooo
o`003?oooooo0?ooomL0oooo3Oooool000coooooo`3ooomY0?ooofd0000000<0P820ooooooooool0
2oooool000coooooo`3ooomY0?ooofd0000000<0P820ooooooooool02oooool000coooooo`3ooomY
0?ooofd0P82000<0`<30ooooooooool02oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0
ooooXP3oool00`20P80000000000000b0?ooo`gooooo000<ooooool0ooooXP3oool00`20P8000000
0000000b0?ooo`gooooo000<ooooool0ooooXP3oool00`20P80000000000000b0?ooo`gooooo000<
ooooool0ooooXP3oool00`20P80000000000000b0?ooo`gooooo000<oooooe80000000<0P8200?oo
o`3oool0o`3ooom=0?ooo`030820P000000000000380oooo3Oooool000coooooDP0000000`20P800
oooo0?ooo`3o0?ooodd0oooo00<0P820000000000000<P3oool=ooooo`003?oooomB0820P0030<30
`03oool0oooo0?l0ooooC@3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`20
P83o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc
0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20
P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P82000000000
0000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo
3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<
ooooob`0oooo0`00001`0?ooo`030410@0000000`<300?l0oooo00<0P820000000000000<P3oool=
ooooo`003?ooool/0?ooo`<00000L03oool2000000030820P03oool0oooo0?d0oooo00<0P8200000
00000000<P3oool=ooooo`003?ooool/0?ooo`<00000L03oool200000?l0oooo0@3oool00`20P800
00000000000b0?ooo`gooooo000<ooooob`0oooo0`00001`0?ooo`800000S`3oool00`20P800oooo
0?ooo`1B0?ooo`030820P030`<00oooo01T0oooo00<0P820000000000000<P3oool=ooooo`003?oo
ool/0?ooo`<00000L03oool00`000000oooo0?ooo`2>0?ooo`0300000020P800oooo03<0oooo1`00
00000`20P800oooo0?ooo`0E0?ooo`0300000020P800oooo01T0oooo00<0P820000000000000<P3o
ool=ooooo`003?ooool/0?ooo`<00000703oool00`30`<00P8200820P0030820P0030<30`03oool0
oooo04/0oooo00<000000?ooo`3oool0SP3oool2000000030820P03oool0oooo03<0oooo00@0@410
000000000000P820603oool00`20P80000000000000J0?ooo`030820P000000000000380oooo3Ooo
ool000cooooo;03oool3000001/0oooo0`0000040?ooo`030820P0000000oooo02@0oooo00<0P820
0000000000001@0000070?ooo`@0000000<0P8200?ooo`3oool04@3oool00`20P800oooo0820P002
000000030820P03oool0oooo00<0oooo0`0000020?ooo`T0000000<0P8200?ooo`3oool0MP3oool2
000003D0oooo00<0P8200000000000006@3oool00`20P80000000000000J0?ooo`030820P0000000
00000380oooo3Oooool000cooooo;03oool3000001T0oooo00@0`<30000000000000`<301`3oool2
0820P2D0oooo00@0P820000000000000@410203oool01010@400000000000010@4020820P0030000
0020P800oooo0100oooo0P20P8001@000000@4100820P020P80000000080oooo00@0`<3000000000
0000@4100P20P8030?ooo`060820P0000000000000000020P800`<30NP3oool2000000030410@03o
ool0oooo0380oooo00<0P8200000000000006@3oool4000001T0oooo00<0P820000000000000<P3o
ool=ooooo`003?ooool/0?ooo`<000006@3oool2000000/0oooo00<000000?ooo`3oool08`3oool2
000000030820P03oool0oooo00H0oooo0P0000000`20P800oooo0?ooo`020?ooo`030820P0000000
oooo00l0oooo0`0000001`20P800oooo0?ooo`3oool0P8200?ooo`20P8000P0000020?ooo`030820
P03oool0oooo0080oooo0`00001l0?ooo`<0000000<0P8200?ooo`3oool0<@3oool00`20P8000000
0000000H0?ooo`030820P00000000000008000006@3oool00`20P80000000000000b0?ooo`gooooo
000<ooooob`0oooo0`00000H0?ooo`80000000<0P8200?ooo`3oool02P3oool00`10@400oooo0?oo
o`0R0?ooo`80000000<0P8200?ooo`3oool03P3oool00`20P800@4100?ooo`0>0?ooo`<00000103o
ool00`20P800oooo0410@00200000080oooo00<0P8200?ooo`3oool00P3oool3000007`0oooo0P00
00000`20P800@4100?ooo`0b0?ooo`030820P0000000000001P0oooo00H0@410000000000000P820
00000020P80H0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool3000001L0oooo
00<0P820000000000000<P3oool2000000030820P03oool0oooo00l0oooo00<0@4100000003oool0
3@3oool3000000@0oooo00<0`<300000000000000P0000020?ooo`030<30`03oool0oooo0080oooo
0`00001l0?ooo`80000000@0P8200<30`0000000`<30<@3oool00`20P80000000000000G0?ooo`04
0820P0000000000000000080oooo00<000000?ooo`3oool05P3oool00`20P80000000000000b0?oo
o`gooooo000<ooooob`0oooo0`00000G0?ooo`030820P000000000000380oooo0P0000000`20P800
oooo0?ooo`0?0?ooo`030820P0000000oooo00d0oooo0`0000050?ooo`@000001`3oool3000007`0
oooo0P0000001020P800oooo0?ooo`20P80a0?ooo`030820P0000000000001L0oooo0`0000030?oo
o`030000003oool0oooo01H0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<0
00005`3oool300000380oooo0P0000000`20P800oooo0?ooo`0?0?ooo`030820P0000000P82000d0
oooo0`0000050?ooo`040820P00000000000000000L0oooo0`00001l0?ooo`030820P00000000000
0080oooo0P20P80@0?ooo`030820P0000000000000h000003`3oool00`20P80000000000000F0?oo
o`040<30`000000000000410@0<0oooo00<0P8200000003oool05P3oool00`20P80000000000000b
0?ooo`gooooo000<ooooob`0oooo0`00000G0?ooo`80000000<0P8200?ooo`3oool0<03oool20000
00030820P03oool0oooo00l0oooo00<0P82000000020P8003@3oool3000000H0oooo0`0000070?oo
o`<000001P3oool00`20P800oooo0?ooo`1c0?ooo`030820P0000000000000<0oooo00<000000820
P03oool0;P3oool00`20P80000000000000F0?ooo`040820P000000000000820P0@0oooo00<00000
0820P03oool05@3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000G0?oo
o`<000004P3oool@000000030820P03oool0oooo00d0oooo0P0000000`20P800oooo0?ooo`0?0?oo
o`80000000<0P8200?ooo`3oool02`3oool3000000H0oooo0`0000070?ooo`<000001P3oool00`20
P800oooo0?ooo`1c0?ooo`030820P0000000000000@0oooo00<0P8200?ooo`3oool0;@3oool00`20
P80000000000000F0?ooo`<0000000<0`<300?ooo`3oool00P3oool00`000000P8200?ooo`0E0?oo
o`030820P000000000000380oooo3Oooool000cooooo;03oool3000001L0oooo0`00000b0?ooo`80
000000<0P8200?ooo`3oool03P3oool3000000030820P03oool0oooo00/0oooo0`0000060?ooo`<0
00001`3oool3000000H0oooo00<000000?ooo`3oool0L`3oool00`20P8000000000000050?ooo`03
0000003oool0oooo02`0oooo00<0P8200000000000005@3oool4000000H0oooo00<000000?ooo`3o
ool0503oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000G0?ooo`<00000
<P3oool2000000030820P03oool0oooo00d0oooo00@0@41000000000000000003P3oool3000000H0
oooo0`0000070?ooo`<000001@20P8000`10@40000000?ooo`1d0?ooo`030820P0000000000000D0
oooo0P20P80]0?ooo`030820P0000000000001D0oooo0`0000000`20P800oooo0?ooo`040?ooo`03
0410@020P800oooo01@0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000
5`3oool00`20P80000000000000b0?ooo`80000000<0P8200?ooo`3oool0303oool4000000l0oooo
0`0000060?ooo`<000001`3oool:000007D0oooo00<0P8200000000000001P3oool00`20P800oooo
0?ooo`0;0?ooo`030820P0000000000000h000003`3oool00`20P80000000000000D0?ooo`040820
P00000000000000000L0oooo00<0P8200000003oool0503oool00`20P80000000000000b0?ooo`go
oooo000<ooooob`0oooo0`00000G0?ooo`040820P000000000000<30`340oooo0P0000000`20P800
oooo0?ooo`090?ooo`80P820100000000`10@400oooo0?ooo`0=0?ooo`<000001P3oool3000000L0
oooo0`0000050?ooo`030<30`0000000oooo07@0oooo00@0`<30000000000000P8201P3oool00`00
0000`<300?ooo`0:0?ooo`030<30`020P800P82000h0P8203`3oool00`20P80000000000000D0?oo
o`040410@00000000000000000L0oooo00<0`<3000000030`<00503oool00`20P80000000000000b
0?ooo`gooooo000<ooooob`0oooo0`00000H0?ooo`80000000<0P8200?ooo`3oool03`3oool@0000
00030820P03oool0oooo00d0oooo0P0000000`20P800oooo0?ooo`060?ooo`030820P00000000000
00@0000000<0@4100820P03oool03`3oool3000000H0oooo0`0000070?ooo`<000001P3oool00`10
@400oooo0?ooo`1d0?ooo`80000000<0P8200?ooo`3oool01@3oool00`20P800oooo0?ooo`0Y0?oo
o`030820P0000000000001<0oooo00@0P82000000000000000002@3oool00`20P800@4100?ooo`0C
0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool3000001P0oooo0`00000a0?oo
o`80000000<0P8200?ooo`3oool01`3oool5000002H0oooo0`0000060?ooo`030820P03oool0oooo
07@0oooo0P0000000`20P800oooo0?ooo`060?ooo`030820P03oool0oooo02P0oooo00<0P8200000
000000004`3oool3000000030820P03oool0oooo00P0oooo00<000000?ooo`3oool04P3oool00`20
P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000I0?ooo`030410@0000000P82000d0
oooo00<0`<300?ooo`3oool0803oool2000000030820P03oool0oooo00L0oooo00<0P82000000020
P800:03oool3000007d0oooo0P0000000`20P800oooo0?ooo`060?ooo`030410@03oool0oooo02P0
oooo00<0P8200000000000004P3oool01@20P8000000000000000000`<3000X0oooo00<0@4100<30
`03oool04P3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000I0?ooo`03
0820P0000000000000d0oooo00<0P8200?ooo`3oool0803oool2000000030820P03oool0oooo00P0
oooo00<000000?ooo`3oool09`3oool3000007d0oooo0P0000000`20P800oooo0?ooo`060?ooo`03
0820P0000000oooo02P0oooo00<0P8200000000000004P3oool01020P800000000000000000;0?oo
o`80P8204`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000J0?ooo`03
0410@0000000P82000`0oooo00<000000?ooo`3oool0803oool2000000030820P03oool0oooo00P0
oooo0P20P80X0?ooo`<000002@3oool00`000000oooo0?ooo`1a0?ooo`80000000<0@4100?ooo`3o
ool01`3oool00`000000@4100?ooo`0T0?ooo`030820P010@400P82000<000004@3oool00`30`<00
000000000002000000/0oooo00<0P82000000020P8004P3oool00`20P80000000000000b0?ooo`go
oooo000<ooooob`0oooo0`00000K0?ooo`800000303oool00`000000oooo0?ooo`0P0?ooo`800000
00<0P8200?ooo`3oool0203oool00`20P80000000?ooo`0W0?ooo`<00000203oool00`20P8000000
0?ooo`1b0?ooo`<000002@3oool3000002L0oooo0`00000A0?ooo`D0000000<0P8200?ooo`3oool0
203oool3000000030820P03oool0oooo00l0oooo00<0P820000000000000<P3oool=ooooo`003?oo
ool/0?ooo`<00000703oool00`10@40000000<30`0090?ooo`80000000<0P8200?ooo`3oool0703o
ool00`10@400P82000000002000000030820P03oool0oooo00T0oooo1`0000000`20P800oooo0?oo
o`0O0?ooo`<000001`3oool00`20P800@4100000001`0?ooo`030<30`020P800@41000@000000P20
P8040?ooo`030<30`010@400000000<0000000<0P8200<30`03oool09@3oool00`20P800oooo0?oo
o`0=0?ooo`030<30`020P800P82000H0P82000<0`<300?ooo`3oool0103oool00`30`<00P8200820
P0040820P100oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<000007@3oool0
1020P800@4100820P030`<060?ooo`040410@000000000000820P200oooo0P20P8000`000000P820
0?ooo`0:0?ooo`030820P0000000000000D0000000<0`<300?ooo`3oool06`3oool20820P0h00000
hP3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000P0?ooo`800000103o
ool500000?l0ooooB03oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00000R
0?ooo`D0P82000@0`<300?ooo`3oool0P820o`3ooom80?ooo`030820P000000000000380oooo3Ooo
ool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<oooo
ob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<0
0000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0oooo
L`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0
P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P0000000
00000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?oo
o`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`00
3?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03o
ool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o
0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?oo
o`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P800
00000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000
<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Ooo
ool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<oooo
ob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<0
0000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0oooo
L`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0
P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P0000000
00000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?oo
o`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`00
3?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03o
ool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o
0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?oo
o`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P800
00000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000
<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Ooo
ool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<oooo
ob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<0
0000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0oooo
L`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0
P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P0000000
00000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?oo
o`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`00
3?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03o
ool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o
0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?oo
o`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P800
00000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000
<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Ooo
ool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<oooo
ob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<0
0000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0oooo
L`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0
P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P0000000
00000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P80000000000000b0?oo
o`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`00
3?ooool/0?ooo`<00000o`3ooomc0?ooo`030820P000000000000380oooo3Oooool000cooooo;03o
ool300000?l0ooooL`3oool00`20P80000000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o
0?ooog<0oooo00<0P820000000000000<P3oool=ooooo`003?ooool/0?ooo`<00000o`3ooomc0?oo
o`030820P000000000000380oooo3Oooool000cooooo;03oool300000?l0ooooL`3oool00`20P800
00000000000b0?ooo`gooooo000<ooooob`0oooo0`00003o0?ooog<0oooo00<0P820000000000000
<P3oool=ooooo`003?ooool/0?ooo`<000007P3oool00`000000oooo0?ooo`0a0?ooo`800000<`3o
ool200000380oooo00<0P820000000000000<P3oool00`20P80000000?ooo`1o0?ooo`030820P000
000000000380oooo3Oooool000cooooo;03oool3000001d0P8200`0000000`30`<00oooo0?ooo`0]
0?ooo`030<30`000000000000080000000<0`<300?ooo`3oool0;@3oool01@30`<00000000000000
0000@4100300oooo00D0P82000000000000000000410@00`0?ooo`050820P000000000000410@03o
ool0OP20P8001@10@400000000000020P800`<300300oooo3Oooool000cooooo;03ooolT000002l0
oooo1P00000_0?ooo`H00000;P3oool00`20P800000000000004000002h0oooo00H0P82000000000
000000000820P03ooon2000000030820P03oool0oooo02h0oooo3Oooool000cooooo;@3oool00`20
P80000000000000Q000000030<30`03oool0oooo02T0oooo00@0`<3000000000000000000P10@403
000000030<30`03oool0oooo02T0oooo00D0`<3000000000000000000410@003000000030410@03o
ool0oooo02X0oooo00D0P82000000000000000000820P003000000030410@03oool0oooo02X0oooo
00D0P82000000000000000000820P0020?oooh80000000<0P8200?ooo`3oool0;P3oool=ooooo`00
3?ooool]0?ooo`030820P0000000000001d0000000<0P8200000000000000P00000[0?ooo`@00000
0P3oool4000002/0oooo100000020?ooo`<0000000<0P8200?ooo`3oool0:03oool01@20P8000000
000000000000P8200080oooo1000000Z0?ooo`050820P0000000000000000020P8000`3ooon20000
00030820P03oool0oooo02h0oooo3Oooool000coooooC`3oool01010@400000000000010@40X0?oo
o`050<30`0000000000000000010@400103oool01@10@4000000000000000000`<3002P0oooo00@0
@410000000000000@4100`3oool01@30`<000000000000000000P82002P0oooo00D0P82000000000
000000000820P0030?ooo`050<30`0000000000000000010@400:03oool01@30`<00000000000000
0000P8200;L0oooo3Oooool000coooooD03oool01@20P8000000000000000000`<3002D0oooo00D0
P82000000000000000000820P0060?ooo`050820P0000000000000000030`<009@3oool01@30`<00
0000000000000000P82000H0oooo00@0@410000000000000@4109P3oool01@10@400000000000000
0000`<3000H0oooo00D0@41000000000000000000<30`00U0?ooo`050820P0000000000000000030
`<00^03oool=ooooo`003?oooomA0?ooo`040820P00000000000000002@0oooo00D0P82000000000
000000000820P0080?ooo`040820P00000000000000002D0oooo0`0000000`20P800oooo0?ooo`06
0?ooo`@00000903oool4000000T0oooo1000000T0?ooo`040820P0000000000000000;X0oooo3Ooo
ool000coooooDP3oool01@10@4000000000000000000`<300240oooo00D0`<300000000000000000
0820P00:0?ooo`050820P0000000000000000030`<008@3oool01@30`<000000000000000000@410
00T0oooo00D0`<3000000000000000000410@00R0?ooo`050410@0000000000000000030`<002P3o
ool01010@400000000000010@40R0?ooo`050820P0000000000000000030`<00^P3oool=ooooo`00
3?oooomC0?ooo`@000008@3oool3000000030820P03oool0oooo00X0oooo00@0P820000000000000
00008@3oool4000000`0oooo1000000P0?ooo`040820P00000000000000000d0oooo1000000P0?oo
o`050820P0000000000000000020P800^`3oool=ooooo`003?oooomD0?ooo`050410@00000000000
00000030`<007@3oool01@30`<000000000000000000P82000h0oooo00D0@4100000000000000000
0<30`00M0?ooo`050<30`0000000000000000010@4003@3oool01@30`<000000000000000000@410
01h0oooo00D0P82000000000000000000<30`00>0?ooo`040410@000000000000410@1h0oooo00D0
P82000000000000000000820P02l0?ooo`gooooo000<oooooeD0oooo1000000M0?ooo`<0000000<0
P8200?ooo`3oool03P3oool4000001d0oooo1000000@0?ooo`<0000000<0P8200?ooo`3oool06P3o
ool01020P800000000000000000A0?ooo`@00000703oool01@20P8000000000000000000P8200;d0
oooo3Oooool000coooooEP3oool01010@400000000000010@40J0?ooo`050<30`000000000000000
0010@4004P3oool01@10@4000000000000000000`<3001X0oooo00@0@410000000000000@4104@3o
ool01@30`<000000000000000000P82001X0oooo00D0P82000000000000000000<30`00A0?ooo`05
0<30`0000000000000000010@4006P3oool01@30`<000000000000000000P8200;h0oooo3Oooool0
00coooooE`3oool01@20P8000000000000000000`<3001L0oooo00D0P82000000000000000000820
P00D0?ooo`050820P0000000000000000020P8005`3oool01@30`<000000000000000000P82001@0
oooo00@0@410000000000000P820603oool01@10@4000000000000000000`<3001@0oooo00D0@410
00000000000000000<30`00G0?ooo`050820P0000000000000000030`<00_`3oool=ooooo`003?oo
oomH0?ooo`040820P00000000000000001H0oooo00D0P82000000000000000000820P00F0?ooo`05
0820P0000000000000000020P8005P3oool3000000030820P03oool0oooo01@0oooo0`00000G0?oo
o`@000005`3oool4000001H0oooo00@0P8200000000000000000`@3oool=ooooo`003?oooomI0?oo
o`050410@0000000000000000030`<004`3oool01@30`<000000000000000000P82001P0oooo00D0
P82000000000000000000<30`00C0?ooo`050<30`0000000000000000010@4005`3oool01@30`<00
0000000000000000`<3001@0oooo00D0@41000000000000000000<30`00H0?ooo`040410@0000000
00000410@1@0oooo00D0P82000000000000000000<30`0310?ooo`gooooo000<oooooeX0oooo1000
000C0?ooo`<0000000<0P8200?ooo`3oool0603oool01020P800000000000000000C0?ooo`@00000
6P3oool3000001<0oooo00@0P82000000000000000006`3oool400000180oooo00D0P82000000000
000000000820P0320?ooo`gooooo000<oooooe/0oooo00D0@41000000000000000000<30`00?0?oo
o`050<30`0000000000000000020P800703oool01@20P8000000000000000000`<3000l0oooo00D0
`<3000000000000000000410@00K0?ooo`050<30`0000000000000000030`<00403oool01@20P800
0000000000000000`<3001`0oooo00@0@410000000000000@410403oool01@20P800000000000000
0000P8200<<0oooo3Oooool000coooooG03oool4000000l0oooo0`0000000`20P800oooo0?ooo`0L
0?ooo`040820P00000000000000000l0oooo1000000N0?ooo`<000003`3oool01020P80000000000
0000000O0?ooo`@000003P3oool01@20P8000000000000000000P8200<@0oooo3Oooool000cooooo
G@3oool01@10@4000000000000000000`<3000/0oooo00D0`<3000000000000000000410@00P0?oo
o`050410@0000000000000000030`<002`3oool01@30`<000000000000000000@41001l0oooo00D0
`<3000000000000000000<30`00<0?ooo`050820P0000000000000000030`<007`3oool01@30`<00
0000000000000000@41000`0oooo00D0P82000000000000000000820P0350?ooo`gooooo000<oooo
oeh0oooo1000000;0?ooo`@000008P3oool4000000/0oooo1000000R0?ooo`<000002`3oool01@20
P8000000000000000000P8200280oooo1000000:0?ooo`050820P0000000000000000020P800aP3o
ool=ooooo`003?oooomO0?ooo`040410@000000000000410@0P0oooo00D0`<300000000000000000
0410@00T0?ooo`050410@0000000000000000030`<00203oool01010@400000000000010@40S0?oo
o`040<30`000000000000410@0T0oooo00D0P82000000000000000000820P00S0?ooo`050<30`000
0000000000000010@400203oool01@30`<000000000000000000P8200<L0oooo3Oooool000cooooo
H03oool01@20P8000000000000000000`<3000D0oooo00D0P82000000000000000000820P00V0?oo
o`050820P0000000000000000030`<001@3oool01@30`<000000000000000000P82002H0oooo00@0
@410000000000000`<301P3oool01@10@4000000000000000000`<3002H0oooo00D0@41000000000
000000000<30`0050?ooo`050820P0000000000000000030`<00b03oool=ooooo`003?oooomQ0?oo
o`040820P00000000000000000@0oooo00D0P82000000000000000000820P00X0?ooo`040820P000
00000000000000D0oooo0`0000000`20P800oooo0?ooo`0V0?ooo`<000001@3oool4000002T0oooo
100000040?ooo`040820P0000000000000000<X0oooo3Oooool000coooooHP3oool01`10@4000000
000000000000`<300?ooo`30`<000`0000000`20P800oooo0?ooo`0X0?ooo`070820P00000000000
00000030`<00oooo0<30`003000000030410@03oool0oooo02L0oooo00D0`<300000000000000000
0<30`0020?ooo`050410@0000000000000000030`<00:P3oool01010@400000000000010@4020?oo
o`050820P0000000000000000030`<00bP3oool=ooooo`003?oooomS0?ooo`@0000000D0oooo0000
0000000000000820P00/0?ooo`050820P000000000000000003oool01000000/0?ooo`<0000000<0
oooo0820P00000000P00000]0?ooo`@0000000D0P82000000000000000000820P03;0?ooo`gooooo
000<ooooof@0oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`0/0?ooo`030410@000
0000000000<0000000<0@4100?ooo`3oool0:`3oool00`30`<00000000000004000000030<30`03o
ool0oooo02`0oooo00<0@4100000000000000`0000000`20P800oooo0?ooo`3:0?ooo`gooooo000<
ooooofD0oooo100000000`20P800oooo0?ooo`0^0?ooo`D00000<03oool400000340oooo10000000
0`20P800oooo0?ooo`3;0?ooo`gooooo000<ooooofH0oooo00<0@41000000010@400<P3oool00`10
@40000000410@00a0?ooo`040<30`000000000000<30`340oooo00@0`<30000000000000P820cP3o
ool=ooooo`003?oooooo0?ooomL0oooo3Oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0
ooooe`3oool=ooooo`003?oooooo0?ooomL0oooo3Oooool000coooooo`3ooooG0?ooo`gooooo000<
ooooool0ooooe`3oool=ooooo`003?oooooo0?ooomL0oooo3Oooool000coooooo`3ooooG0?ooo`go
oooo000<ooooool0ooooe`3oool=ooooo`003?oooooo0?ooomL0oooo3Oooool000coooooo`3ooooG
0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oooooo0?ooomL0oooo3Oooool000cooooo
o`3ooooG0?ooo`gooooo000<ooooohl0oooo1`0000000`20P800oooo0?ooo`040?ooo`030820P000
000000000080000000<0P8200?ooo`3oool04@3oool<000000030820P03oool0oooo00X0oooo00<0
P8200000000000001P0000030?ooo`P00000l`3oool=ooooo`003?oooon@0?ooo`050820P0000000
000000000020P800203oool01@10@400000000000020P800`<3001@0oooo00<0`<30000000000000
2@0000000`10@400oooo0?ooo`0:0?ooo`030820P0000000000000H000000`3oool800000?<0oooo
3Oooool000coooooT@3oool00`20P8000000000000090?ooo`80000000<0P8200?ooo`3oool05P3o
ool;000000`0oooo00<0P8200000000000001P0000030?ooo`P00000l`3oool=ooooo`003?oooonA
0?ooo`040<30`000000000000820P0L0oooo00@0P820000000000000P820603oool00`30`<000000
0<30`0060?ooo`030<30`010@400P82000/0oooo00<0P82000000020P8001020P8000`10@4000000
0?ooo`020?ooo`0300000020P800P82000@0P82000<000000?ooo`3oool0l@3oool=ooooo`003?oo
oonB0?ooo`80000000<0P8200?ooo`3oool01@3oool3000001/0oooo00<0@4100<30`03oool01P3o
ool00`20P800oooo0?ooo`090?ooo`030820P03oool0oooo00@0oooo00<0P8200000003oool00P3o
ool00`000000oooo0?ooo`040?ooo`030820P03oool0oooo0?40oooo3Oooool000coooooTP3oool0
0`20P8000000000000060?ooo`030820P0000000000001d0oooo00<000000?ooo`3oool04@3oool0
0`20P800oooo0?ooo`020?ooo`040820P00000000000000000<0oooo0`0000040?ooo`030820P03o
ool0oooo0?40oooo3Oooool000coooooTP3oool00`20P8000000000000060?ooo`030820P0000000
000001d0oooo00<0`<3000000030`<00503oool00`20P8000000000000020820P0@0oooo00H0`<30
0820P010@40000000410@020P83e0?ooo`gooooo000<oooooi<0oooo0`0000050?ooo`80000000<0
P8200?ooo`3oool07@3oool00`000000oooo0?ooo`0A0?ooo`040820P000000000000820P0T0oooo
0`0000000`20P800oooo0?ooo`3b0?ooo`gooooo000<oooooi<0oooo0`0000050?ooo`80000000<0
P8200?ooo`3oool00`3ooolA000000T0oooo00<0@41000000030`<00403oool01020P80000000000
0020P80;0?ooo`040410@000000000000<30`?<0oooo3Oooool000coooooT`3oool3000000@0oooo
0`00000Q0?ooo`0300000020P800oooo00l0oooo0P0000000`20P800oooo0?ooo`0;0?ooo`800000
00<0P8200?ooo`3oool0l@3oool=ooooo`003?oooonD0?ooo`80000000@0P8200?ooo`3oool0oooo
0`00000R0?ooo`0300000020P800oooo00d0oooo00@0P820000000000000P8203@3oool300000?<0
oooo3Oooool000coooooU03oool9000000030820P03oool0oooo01l0oooo00<0P8200000003oool0
3@3oool3000000l0oooo0`00003b0?ooo`gooooo000<oooooi@0oooo00<0P820000000000000103o
ool01@30`<00P820000000000000@41001l0oooo00<0P82000000020P8003@3oool3000000l0oooo
0`00003b0?ooo`gooooo000<oooooi@0oooo00@0P820000000000000P8201P3oool01@20P8000000
00000030`<00oooo01400000303oool2000000d0oooo0`00000?0?ooo`<00000lP3oool=ooooo`00
3?oooonE0?ooo`<000001`3oool3000001h0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`<00000
3`3oool300000?80oooo3Oooool000coooooU@3oool3000000L0oooo00@0P820000000000000`<30
4`3oool20820P0P0oooo0P0000000`20P800oooo0?ooo`0:0?ooo`040410@000000000000<30`0d0
oooo00@0P820000000000000P820lP3oool=ooooo`003?oooonF0?ooo`80000000<0P8200?ooo`3o
ool0103oool01020P800000000000020P80C0?ooo`030820P0000000oooo00H0oooo00@0P8200000
00000000P820303oool01020P800000000000020P80=0?ooo`<00000l`3oool=ooooo`003?oooonF
0?ooo`80000000<0P8200?ooo`3oool0103oool01020P800000000000020P80D0?ooo`0300000010
@400oooo00D0oooo00@0@410000000000000`<30303oool01030`<00000000000010@40<0?ooo`04
0<30`000000000000410@?<0oooo3Oooool000coooooUP3oool2000000030820P03oool0oooo00@0
oooo00@0P820000000000000P8205@3oool2000000040820P03oool0oooo0820P0@000003`3oool3
000000/0oooo0`00003d0?ooo`gooooo000<oooooiH0oooo00<0P8200000000000001P3oool00`10
@40000000000000F0?ooo`030410@0000000000000H0000000<0`<300?ooo`3oool03@3oool01030
`<00000000000010@4080?ooo`050<30`0000000000000000030`<00m03oool=ooooo`003?oooonE
0?ooo`050820P0000000000000000030`<000`3oool01@30`<00P820000000000000`<3001L0oooo
0P20P804000000030820P03oool0oooo0100oooo00<0`<300820P00000000P0000040820P0050410
@0000000000000000020P800mP3oool=ooooo`003?oooonD0?ooo`/00000=`3oool700000?T0oooo
3Oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oooooo0?oo
omL0oooo3Oooool000coooooo`3ooooG0?ooo`gooooo000<ooooool0ooooe`3oool=ooooo`003?oo
oooo0?ooomL0oooo3Oooool000coooooo`3ooooG0?ooo`gooooo003ooooooo3ooooo003ooooooo3o
oooo003ooooooo3ooooo003ooooooo3ooooo003ooooooo3ooooo003ooooooo3ooooo003ooooooo3o
oooo003ooooooo3ooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{165.125, 122.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 2.12.", "Caption",
  CellTags->"Fig. 2.12"],

Cell[TextData[{
  StyleBox["(20)(a)",
    FontWeight->"Bold"],
  " Find the Green's function for the following ODE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = \(x\^\[DoublePrime]\)\^\[DoublePrime] + 
          2 \( x\^\[DoublePrime]\)\^\[Prime] + 6  x\^\[DoublePrime] + 
          5  x\^\[Prime] + 2  x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the Green's function found from part (a) to determine the solution ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) 
          x = \(h(t)\)\ t\ \(\[ExponentialE]\^\(-t\)\) cos\ \ t\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(
          0) = \(\(x\^\[Prime]\)(
            0) = \(\(x\^\[DoublePrime]\)(
              0) = \(\(\(x\^\[DoublePrime]\)\^\[Prime]\)(0) = 0. \)\)\)\)]],
  " Plot the solution. "
}], "Text"],

Cell[TextData[{
  StyleBox["(21)(a)",
    FontWeight->"Bold"],
  " The FFT can be used to solve numerically for particular solutions to \
differential equations with constant coefficients.  This method is quite \
useful and important for solving certain types of PDEs numerically, such as \
Poisson's equation under ",
  StyleBox["periodic boundary conditions ",
    FontSlant->"Italic"],
  "(see Chapters ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  "), but can also be used to solve ODEs.  For example, consider the \
following ODE: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + x\^\[Prime] + x = \(h(t)\) 
          t\ \(\[ExponentialE]\^\(-t\)\) sin\ 3  t\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Find a particular solution on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 4\)]],
  " using an FFT . To do so, first discretize time as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"t", "=", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(n = 0\), ",", 
          "1", ",", "2", ",", "...", ",", \(N - 1\)}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 41\)]],
  ", taking \[CapitalDelta]",
  StyleBox["t",
    FontSlant->"Italic"],
  " = 0.1. Make a table of the forcing function at these times, and take its \
FFT.  Then, use what you know about Fourier transforms to determine a \
discretized  form for the transform of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x\&~\)]],
  ". Take the inverse FFT of this data and plot the resulting particular \
solution vs. time on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " This particular solution is periodic, with period ",
  Cell[BoxData[
      \(TraditionalForm\`T = 4.1\)]],
  ",  since the FFT is equivalent to a Fourier series solution with this \
periodicity. This solution is correct only in the first period, from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  "; the analytic particular solution is not periodic, but should match the \
FFT solution in ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < T\)]],
  ".  To prove this, note that  this particular solution satisfies  ",
  StyleBox["periodic boundary conditions",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 
        x(T), \(x\^\[Prime]\)(0) = \(x\^\[Prime]\)(T)\)]],
  ". Solve the ODE  analytically for these boundary conditions using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and plot the result on top of the FFT result from part (a) on ",
  Cell[BoxData[
      \(TraditionalForm\`0 \[LessEqual] \ t \[LessEqual] \ T\)]],
  "."
}], "Text",
  CellTags->"i:81"],

Cell[TextData[{
  StyleBox["(22)(a)",
    FontWeight->"Bold"],
  " The periodic \[Delta]-function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(t)\)]],
  " with period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " given  by  Eq. ",
  ButtonBox["(2.3.48)",
    ButtonData:>"(2.3.48)",
    ButtonStyle->"Hyperlink"],
  " has Fourier components of equal amplitude over all frequencies, playing \
",
  StyleBox["continuously",
    FontSlant->"Italic"],
  ". Do you think that the hairs in your ear responsible for hearing \
frequencies at around, say, 500 Hz, are being excited continuously by the  \
500-Hz frequencies in the \[Delta]-function, or only when there is a chirp? \
Explain your reasoning in several sentences, with diagrams if necessary. \
(Hint: Hairs respond to a ",
  StyleBox["range of frequencies",
    FontSlant->"Italic"],
  " around their resonance peak, not just a single frequency. What is the \
effect on the amplitude of the hair's motion  of adding together these \
different frequency components in the forcing? Think about constructive and \
destructive interference. )"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find a particular solution for the response of a damped oscillator (a \
model of one of the hairs) to a periodic \[Delta]-function using Green's \
functions. The oscillator satisfies  ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime] + \ \[Gamma]\ x\^\[Prime] + \(\
\[Omega]\_o\%2\) x = \(\[Delta]\^\((P)\)\)(t)\)]],
  " . Plot the result over a time of ",
  Cell[BoxData[
      \(TraditionalForm\`5\ T\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_\(\(o\)\(\ \)\)\) T = 60\)]],
  " and for (i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ T = 0.01\)]],
  "  (ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ T = 0.1\)]],
  ", (iii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ T = 1\)]],
  ". (iv) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ T = 1\)]],
  "0. Roughly how large must ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ T\)]],
  " be for each response to a \[Delta] function kick to be easily \
distinguishable from others?"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Create and play a periodic \[Delta]-function with different values of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", from 1/10 to 1/200 s. Determine the smallest value of ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " for which you can distinguish the chirps. Use the result of part (b) \
along with this result to crudely estimate a value of \[Gamma] for the human \
auditory system."
}], "Text"],

Cell[TextData[{
  StyleBox["(23)(a)",
    FontWeight->"Bold"],
  " Play the following periodic \[Delta]-function for which the phases have \
been randomized:"
}], "Text",
  CellTags->"i:47"],

Cell[BoxData[
    \(T\  = \ 0.2; \ 
    1\  + \ 2 
         Sum[\ Cos[2\ Pi\ n\ \ t/T + \ 2\ Pi\ Random[]], {n, 1, 
            300}];\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.90"],

Cell["\<\
Does this still sound like a periodic \[Delta]-function?  \
Previously, we found that randomizing the phases of the Fourier components in \
a waveform made no difference to the sound a waveform makes. Can you explain \
why there is a difference now? (Hint: Think about destructive \
interference.)\
\>", "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The modes in a Fourier series or transform have  amplitudes that are \
constant in time, but somehow the series or transform is able to produce \
sounds whose loudness (amplitude) varies in time, as in a periodic \
\[Delta]-function. Given the results of part (a), explain in a few words how \
this is accomplished."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Reduce the period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Delta]\^\((P)\)\)(t)\)]],
  " to a value below that found in part (c) of the previous exercise.  Does \
randomizing the phases make as much difference to the sound as for part (a)? \
Why or why not?"
}], "Text"],

Cell[TextData[{
  StyleBox["(24) ",
    FontWeight->"Bold"],
  "Three coupled oscillators are initially at rest on a surface (at ",
  Cell[BoxData[
      \(TraditionalForm\`t = \(-\[Infinity]\)\)]],
  "). Their equilibrium positions are ",
  Cell[BoxData[
      \(TraditionalForm\`x\_\(1  o\) = 2, \ x\_\(2  o\) = 1, 
      x\_\(3  o\) = 0. \)]],
  " The oscillators satisfy the equations"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\^\[DoublePrime] = \(\(\(-2\) \((x\_1 - x\_2 - 
                1)\)\)\(\ \)\(-\)\(\ \)\(x\_1\^\[Prime]\)\(\ \)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\_2\^\[DoublePrime] = \(-2\) \((x\_2 - x\_1 + 
                1)\)\  - \ x\_2\^\[Prime]\  - 
          2 \((x\_2 - x\_3 - 1)\)\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\^\[DoublePrime] = \(\(\(-2\) \((x\_3 - x\_2 + 
                1)\)\)\(\ \)\(-\)\(\ \)\(x\_3\^\[Prime]\)\(\ \)\(+\)\(\ \)\(f(
            t)\)\(\ \)\)\)]],
  ".\n The third oscillator in the chain is given a bump, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t) = 6  \[ExponentialE]\^\(\(-4\) | t | \)\)]],
  ". Use Fourier transform methods to solve for the motion of the \
oscillators. Plot the motion of all three oscillators as an animation by \
plotting their positions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_i\)(t)\)\(\ \)\)\)]],
  " as a set of ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "s at times from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) < t < 9\)]],
  " in units of 0.2."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4 Green's Functions ", "Subtitle",
  CellTags->{"Sec. 2.4", "i:62", "c:40"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["2.4.1 Introduction", "Subsubtitle",
  CellTags->"c:41"],

Cell[TextData[{
  "Consider a dynamical system described by a general ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "th-order inhomogeneous linear ODE, such as Eq. ",
  ButtonBox["(1.6.1)",
    ButtonData:>{"Chapter1.nb", "(1.6.1)"},
    ButtonStyle->"Hyperlink"],
  ". In operator notation this ODE can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(x(t)\) = f(t)\)]],
  "."
}], "NE4",
  CellTags->"(2.4.1)"],

Cell[TextData[{
  "The ",
  ButtonBox["Green's function",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Green.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  "  can be used to find a particular solution to this ODE. The Green's \
function is a function of two arguments, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"g", "(", 
            RowBox[{"t", ",", 
              FormBox[\(t\_o\),
                "TraditionalForm"]}], ")"}]}], TraditionalForm]]],
  ". This function satisfies "
}], "Text",
  CellTags->"i:85"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(g(t, t\_o)\) = \[Delta](t - t\_o)\)]],
  "."
}], "NE4",
  CellTags->"(2.4.2)"],

Cell[TextData[{
  "According to this equation,  ",
  Cell[BoxData[
      \(TraditionalForm\`g(t, t\_o)\)]],
  " is the response of the system to a \[Delta]-function forcing at time ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(t\_o\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe Green's function can be used to obtain a particular solution to Eq. \
",
  ButtonBox["(2.4.1)",
    ButtonData:>"(2.4.1)",
    ButtonStyle->"Hyperlink"],
  " by means of the following integral:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t)\  = \ \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( g(t, 
              t\_o)\) \(f(t\_o)\) \[DifferentialD]t\_o\)]],
  "."
}], "NE4",
  CellTags->"(2.4.3)"],

Cell[TextData[{
  "We have already seen a similar equation for the particular solution  in \
terms of a Green's function for an ODE with constant coefficients, Eq. ",
  ButtonBox["(2.3.73)",
    ButtonData:>"(2.3.73)",
    ButtonStyle->"Hyperlink"],
  ". There, the Green's function was written as ",
  Cell[BoxData[
      \(TraditionalForm\`g(t - t\_o)\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`g(t, t\_o)\)]],
  ", because when the ODE has constant coefficients the origin of time can be \
displaced to any arbitrary value, so only the time ",
  StyleBox["difference ",
    FontSlant->"Italic"],
  "between ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " is important in determining the response at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " to an impulse at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe can easily show that Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  " satisfies the ODE, Eq. ",
  ButtonBox["(2.4.1)",
    ButtonData:>"(2.4.1)",
    ButtonStyle->"Hyperlink"],
  ". Acting with ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " on Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(L\&^\) \(\(x\_p\)(t)\)\), " ", "=", " ", 
          
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( L\&^\) \(g(
                  t, t\_o)\) \(f(t\_o)\) \[DifferentialD]t\_o\), "=", 
            RowBox[{
              RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
                
                RowBox[{\(\[Delta](t - t\_o)\), Cell[
                  ""], \(f(t\_o)\), \(\[DifferentialD]t\_o\)}]}], 
              "=", \(f(t)\)}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where we have used Eq. ",
  ButtonBox["(2.4.2)",
    ButtonData:>"(2.4.2)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe have not yet specified initial or boundary conditions that go along \
with Eq. ",
  ButtonBox["(2.4.2)",
    ButtonData:>"(2.4.2)",
    ButtonStyle->"Hyperlink"],
  " for defining the Green's function.  In initial-value problems, it is \
convenient to choose the initial condition that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g\)\(=\)\(0\)\(\ \)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(t < t\_o\)\(,\)\)\)]],
  " so that the system is at rest when the impulse is applied ."
}], "Text",
  CellTags->"i:63"],

Cell[TextData[{
  "\t For boundary-value problems, other choices are made in order to satisfy \
boundary conditions, as we will see in Sec. ",
  ButtonBox["2.4.4",
    ButtonData:>"c:47",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\t The time integral in Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  " runs all the way from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)]],
  " to \[Infinity], so it seems that we need to know everything about both \
the past and future of the forcing function to determine ",
  Cell[BoxData[
      \(TraditionalForm\`x\_p\)]],
  " at the present time. However, the choice ",
  Cell[BoxData[
      \(TraditionalForm\`g = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < t\_o\)]],
  " implies that the integral in Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  " really runs only from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", so only past times are necessary. Also, in typical problems there is \
usually an initial time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i\)]],
  " (possibly far in the past) before which the forcing can be taken equal to \
zero (i.e. the beginning of the experiment). For these choices the integral \
really runs only from ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ": "
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t)\  = \[Integral]\_\(t\_i\)\%t\ \(g(t, t\_o)\) \(f(
              t\_o)\) \[DifferentialD]t\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  " We can see that this particular solution will be zero for ",
  Cell[BoxData[
      \(TraditionalForm\`t < t\_i\)]],
  ", since ",
  Cell[BoxData[
      \(TraditionalForm\`g(t, t\_o) = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < t\_o\)]],
  ". Thus, this particular solution is the one for which the system is at \
rest before the forcing begins."
}], "Text"],

Cell[TextData[{
  "\t We will now consider how to construct a solution to Eq. ",
  ButtonBox["(2.4.2)",
    ButtonData:>"(2.4.2)",
    ButtonStyle->"Hyperlink"],
  " for the Green's function.  There are several methods for doing so. We \
have already seen one method using Fourier transforms in Sec. ",
  ButtonBox["2.3.6",
    ButtonData:>"c:38",
    ButtonStyle->"Hyperlink"],
  ", applicable to ODEs with constant coefficients. Here, we consider a \
general analytic method for any linear ODE, where the Green's function is \
written as a sum of homogeneous solutions to the ODE. We also discuss \
numerical methods for determining the Green's function. In Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ", we will consider another analytic method, applicable only to \
boundary-value problems, in which we decompose ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " in terms of operator eigenmodes, resulting in the ",
  StyleBox["bilinear equation ",
    FontSlant->"Italic"],
  "for the Green's function",
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.4.2 Constructing the Green's Function from Homogeneous \
Solutions\
\>", "Subsubtitle",
  CellTags->{"i:64", "c:42"}],

Cell[CellGroupData[{

Cell["Second-Order ODEs", "Section",
  CellTags->"c:43"],

Cell["\<\
In this subsection we will construct the Green's function for a \
linear second-order ODE using homogeneous solutions. We will then discuss a \
generalization of the solution that is applicable to higher-order ODES. \
\
\>", "Text"],

Cell[TextData[{
  "\tFor a general linear second-order ODE of the form of Eq. ",
  ButtonBox["(1.6.1)",
    ButtonData:>{"Chapter1.nb", "(1.6.1)"},
    ButtonStyle->"Hyperlink"],
  ", the Green's function satisfies"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\(L\&^\) \(g(t, t\_o)\)\), "\[Congruent]", 
          RowBox[{
            RowBox[{
              FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
                MultilineFunction->None], \(g(t, t\_o)\)}], "+", 
            RowBox[{\(\(u\_1\)(t)\), 
              FractionBox["\[PartialD]", \(\[PartialD]t\),
                MultilineFunction->None], \(g(t, t\_o)\)}], " ", 
            "+", \(\(\(u\_o\)(t)\) \(g(t, t\_o)\)\)}]}], " ", 
        "=", \(\(\[Delta](t - t\_o)\)\(.\)\)}], TraditionalForm]]]], "NE4",
  CellTags->"(2.4.4)"],

Cell[TextData[{
  "Assuming that we are solving an initial-value problem, we will take the \
initial condition that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(g(t, t\_o)\),
            "TraditionalForm"], "=", "0"}], TraditionalForm]]],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`t \[LessEqual] \ t\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWhen ",
  Cell[BoxData[
      \(TraditionalForm\`t > t\_o\)]],
  ", the Green's function satisfies the homogenous ODE ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(g(t, t\_o)\) = 0\)]],
  ", and therefore ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " can be written as a sum of the two independent homogeneous solutions to \
the ODE (see Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:38"},
    ButtonStyle->"Hyperlink"],
  "):"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(g(t, t\_o)\), "=", " ", 
          RowBox[{\(C\_1\ \(\(x\_1\)(t)\)\), "+", 
            FormBox[\(C\_2\ \(\(x\_2\)(t)\)\),
              "TraditionalForm"]}]}], ",", "   ", 
        RowBox[{"t", ">", " ", 
          RowBox[{
            FormBox[\(t\_o\),
              "TraditionalForm"], "."}]}]}], TraditionalForm]]]], "NE4",
  CellTags->"(2.4.5)"],

Cell[TextData[{
  "We are then left with the task of determining the constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\ and\ C\_2\)]],
  ". One equation for these constants can be found by applying the initial \
condition that the system is at rest before the impulse is applied, so that \
",
  Cell[BoxData[
      \(TraditionalForm\`g = 0\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = t\_o\)]],
  ".Applying this condition to Eq. ",
  ButtonBox["(2.4.5)",
    ButtonData:>"(2.4.5)",
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(g(t\_o, t\_o)\), "=", 
        RowBox[{"0", "=", " ", 
          RowBox[{\(C\_1\ \(\(x\_1\)(t\_o)\)\), "+", 
            RowBox[{
              FormBox[\(C\_2\ \(\(x\_2\)(t\_o)\)\),
                "TraditionalForm"], "."}]}]}]}], TraditionalForm]]]], "NE4",
  CellTags->"(2.4.6)"],

Cell[TextData[{
  "To obtain one more equation for the constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\ and\ C\_2\)]],
  ", we integrate Eq. ",
  ButtonBox["(2.4.4)",
    ButtonData:>"(2.4.4)",
    ButtonStyle->"Hyperlink"],
  " from a time just before ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\_o\%-\)\)]],
  ", to a time just after ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\_o\%+\)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Integral]\_\(t\_o\%-\)\%\(t\_o\%+\)\), 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{
                    FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
                      MultilineFunction->None], \(g(t, t\_o)\)}], "+", 
                  RowBox[{\(\(u\_1\)(t)\), 
                    FractionBox["\[PartialD]", \(\[PartialD]t\),
                      MultilineFunction->None], \(g(t, t\_o)\)}], " ", 
                  "+", \(\(\(u\_o\)(t)\) \(g(t, t\_o)\)\)}], 
                ")"}], \(\[DifferentialD]t\)}]}], " ", 
          "=", \(\[Integral]\_\(t\_o\%-\)\%\(t\_o\%+\)\(\[Delta](
                  t - t\_o)\) \[DifferentialD]t = 1. \)}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(u\_1\)(t)\)\(\ \)\)\)]],
  "are both continuous at ",
  Cell[BoxData[
      \(TraditionalForm\`t = t\_o\)]],
  ", we can replace them by their values at ",
  Cell[BoxData[
      FormBox[
        RowBox[{"t", "=", 
          FormBox[\(t\_o\),
            "TraditionalForm"]}], TraditionalForm]]],
  "and take them outside the integral. We can then apply the fundamental \
theorem of calculus to the integral of the derivatives, yielding"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox[
                RowBox[{
                  RowBox[{
                    FractionBox["\[PartialD]", \(\[PartialD]t\),
                      MultilineFunction->None], \(g(t, t\_o)\)}], 
                  SubscriptBox[
                    StyleBox["|",
                      FontSize->14], \(t = \(t\_o\%+\)\)], 
                  RowBox[{
                    RowBox[{"-", 
                      FractionBox["\[PartialD]", \(\[PartialD]t\),
                        MultilineFunction->None]}], \(g(t, t\_o)\)}], 
                  SubscriptBox[
                    StyleBox["|",
                      FontSize->14], \(t = \(t\_o\%-\)\)], " ", "+"}],
                "TraditionalForm"], 
              RowBox[{
                FormBox[\(\(u\_1\)(t\_o)\),
                  "TraditionalForm"], 
                "[", \(g(\(t\_o\%+\), t\_o) - g(\(t\_o\%-\), t\_o)\), "]"}]}],
             "+", \(\(\(u\_o\)(
                t\_o)\) \(\[Integral]\_\(t\_o\%-\)\%\(t\_o\%+\)\(g(t, 
                    t\_o)\) \[DifferentialD]t\)\)}], "=", "1."}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g\)\(=\)\(0\)\(\ \)\)\)]],
  "at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"t", "\[LessEqual]", " ", 
            FormBox[\(t\_o\),
              "TraditionalForm"]}], ","}], TraditionalForm]]],
  "all terms on the ",
  "left-hand",
  " side vanish except for the first term, yielding"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox["\[PartialD]", \(\[PartialD]t\),
                MultilineFunction->None], \(g(t, t\_o)\)}], 
            SubscriptBox[
              StyleBox["|",
                FontSize->14], \(t = \(t\_o\%+\)\)]}], "=", "1"}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Substituting for ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " using Eq. ",
  ButtonBox["(2.4.5)",
    ButtonData:>"(2.4.5)",
    ButtonStyle->"Hyperlink"],
  " yields the second equation for ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ","
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(C\_1\ \(\(x\_1\^\[Prime]\)(t\_o)\)\), "+", 
          FormBox[\(C\_2\ \(\(x\_2\^\[Prime]\)(t\_o)\)\),
            "TraditionalForm"]}], "=", "1."}], TraditionalForm]]]], "NE4",
  CellTags->"(2.4.7)"],

Cell[TextData[{
  "We may now solve for ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " using Eqs. ",
  ButtonBox["(2.4.6)",
    ButtonData:>"(2.4.6)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.7)",
    ButtonData:>"(2.4.7)",
    ButtonStyle->"Hyperlink"],
  ". The result is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`g(t, 
        t\_o) = \(\(\(x\_2\)(t\_o)\) \(\(x\_1\)(t)\) - \(\(x\_1\)(t\_o)\) \
\(\(x\_2\)(t)\)\)\/\(W(t\_o)\), \ \ t > \ t\_o, \)]]], "NE4",
  CellTags->"(2.4.8)"],

Cell[TextData[{
  "where  the function ",
  Cell[BoxData[
      \(TraditionalForm\`W(t)\)]],
  " is the ",
  StyleBox["Wronskian",
    FontSlant->"Italic"],
  ",",
  " defined as ",
  Cell[BoxData[
      \(TraditionalForm\`W(
          t) \[Congruent] \(\(x\_1\^\[Prime]\)(t)\) \(\(x\_2\)(
              t)\) - \(\(\(x\_2\^\[Prime]\)(t)\) \(\(x\_1\)(t)\)\(\ \)\)\)]],
  ". "
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  "\tIf the Wronskian ",
  Cell[BoxData[
      \(TraditionalForm\`W(t\_o)\)]],
  " is zero for some value of ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ", then according to Eq. ",
  ButtonBox["(2.4.8)",
    ButtonData:>"(2.4.8)",
    ButtonStyle->"Hyperlink"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is undefined. However, one can show (although we will not do so here) \
that the Wronskian is always nonzero if the homogeneous solutions ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  " are linearly independent. A proof of this statement can be found in any \
elementary book on ODEs, such as ",
  ButtonBox["Boyce and DiPrima (1969)",
    ButtonData:>{"Chapter1.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  " (see the references at the end of Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  "). "
}], "Text"],

Cell["\tFor completeness, we also note our initial condition:", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`g(t, t\_o) = 
      0, \ \ t < \ \ \(\(t\_o\)\(.\)\)\)]]], "NE4",
  CellTags->"(2.4.9)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.4.8)",
    ButtonData:>"(2.4.8)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.9)",
    ButtonData:>"(2.4.9)",
    ButtonStyle->"Hyperlink"],
  " are a solution for the Green's function  for a general second-order ODE. \
This solution requires that we already know the independent homogeneous \
solutions to the ODE,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)]],
  ". These solutions can often be found analytically, using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " for example, but we could also use numerical solutions to the homogeneous \
ODE, with two different sets of initial conditions so as to obtain \
independent numerical approximations to  ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_2\)(t)\)]],
  ". Examples of both analytic and numerical methods for finding homogeneous \
solutions can be found in the exercises at the end of Sec. ",
  ButtonBox["1.6",
    ButtonData:>{"Chapter1.nb", "c:47"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(2.4.8)",
    ButtonData:>"(2.4.8)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.9)",
    ButtonData:>"(2.4.9)",
    ButtonStyle->"Hyperlink"],
  " can now be used in Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  " to obtain a particular solution to Eq. ",
  ButtonBox["(2.4.1)",
    ButtonData:>"(2.4.1)",
    ButtonStyle->"Hyperlink"],
  ". Since ",
  Cell[BoxData[
      \(TraditionalForm\`g(t, t\_o) = 0\)]],
  " for  ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o > t\)]],
  ", we obtain "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(x\_p\)(
        t)\  = \ \(\[Integral]\_\(-\[Infinity]\)\%\(\(\ \)\(t\)\)\(g(t, 
              t\_o)\) \(f(t\_o)\) \[DifferentialD]t\_o = \(\(x\_1\)(
              t)\) \(\[Integral]\_\(-\[Infinity]\)\%\(\(\ \
\)\(t\)\)\(\(\(\(x\_2\)(t\_o)\) \(f(t\_o)\)\)\/\(W(
                      t\_o)\)\) \[DifferentialD]t\_o\) - \(\(x\_2\)(
              t)\) \(\[Integral]\_\(-\[Infinity]\)\%\(\(\ \
\)\(t\)\)\(\(\(\(x\_1\)(t\_o)\) \(f(t\_o)\)\)\/\(W(
                      t\_o)\)\) \(\(\[DifferentialD]t\_o\)\(.\)\)\)\)\)]]], \
"NE4",
  CellTags->"(2.4.10)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.4.10)",
    ButtonData:>"(2.4.10)",
    ButtonStyle->"Hyperlink"],
  " is a form for the particular solution to the ODE that can also be found \
in elementary textbooks, based on the method of variation of parameters. Here \
we have used Green's-function techniques to obtain the same result. Note that \
one can add to Eq. ",
  ButtonBox["(2.4.10)",
    ButtonData:>"(2.4.10)",
    ButtonStyle->"Hyperlink"],
  " any homogeneous solution to the ODE in order to obtain other particular \
solutions. Equation ",
  ButtonBox["(2.4.10)",
    ButtonData:>"(2.4.10)",
    ButtonStyle->"Hyperlink"],
  " is the particular solution for which the system is at rest before the \
forcing begins."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Section",
  CellTags->"c:44"],

Cell["\<\
 As an example of the Green's function technique applied to a \
second-order ODE with time-varying coefficients, let us construct the Green's \
function for the operator \
\>", "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x = 
        x\^\[DoublePrime] - 
          n\ x\^\[Prime]/t, \ \ \ n\  \[NotEqual] \ \(-1. \)\)]]
}], "Text"],

Cell["\<\
One can verify by substitution that this operator has two \
independent homogeneous solutions\
\>", "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_1\)(t)\  = \ 
        1, \[IndentingNewLine]\(x\_2\)(t)\  = \ 
        t\^\(n + 1\)/\(\((n + 1)\)\(.\)\)\)]],
  "\nThen the Wronskian is "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(W(
          t) = \(\(\(x\_1\^\[Prime]\)(t)\) \(\(x\_2\)(
                t)\) - \(\(x\_2\^\[Prime]\)(t)\) \(\(x\_1\)(t)\) = \(0\  - \ 
              1\ t\^n = \(-t\^n\)\)\)\)\(,\)\)\)]],
  "\nand Eq. ",
  ButtonBox["(2.4.8)",
    ButtonData:>"(2.4.8)",
    ButtonStyle->"Hyperlink"],
  " for the Green's function becomes"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`g(t, 
          t\_o) = \(1\/\(n + 1\)\) \((\(t(t\/t\_o)\)\^n - 
              t\_o)\), \ \ \ t > \ \(\(t\_o\)\(.\)\)\)]],
  "\t"
}], "Text"],

Cell[TextData[{
  "\tWe can use this Green's function to obtain a particular solution to ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(x(t)\) = f(t)\)]],
  ". Let's take the case ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ \(t\^\[Alpha]\) \(h(t)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is the Heaviside step function. Then the particular solution given by Eq. \
(",
  ButtonBox["2.4.3",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ") is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_p\)(
          t)\  = \(\[Integral]\_\(-\[Infinity]\)\%\(\(\ \)\(t\)\)\(g(t, 
                t\_o)\) \(t\_o\%\[Alpha]\) \(h(
                t\_o)\) \[DifferentialD]t\_o\  = \ \[Integral]\_0\%\(\(\ \
\)\(t\)\)\(1\/\(n + 1\)\)[\(t(t\/t\_o)\)\^n - 
                  t\_o] \(t\_o\%\[Alpha]\) \
\[DifferentialD]t\_o\)\)\(,\)\)\)]],
  "\nwhere on the ",
  "right-hand",
  " side we have assumed that ",
  Cell[BoxData[
      \(TraditionalForm\`t > \ 0\)]],
  " in order to set ",
  Cell[BoxData[
      \(TraditionalForm\`h(t\_o) = 1\)]],
  ". If ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(t < 0\)\)\)]],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`h(t\_o) = 0\)]],
  " for the entire range of integration, and ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t) = 0\)]],
  ". This is expected, since the Green's function has built in the initial \
condition that the system is at rest before forcing begins."
}], "Text"],

Cell["\<\
\t  For this simple forcing function the integral can be performed \
analytically, yielding\
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(
          t)\  = \ \(\((1 + n)\) t\^\(2 + \[Alpha]\)\)\/\(\((2 + \[Alpha])\) \
\((1 + \[Alpha] - n)\)\), \ t > \ \ 0. \)]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Nth-Order ODEs", "Section",
  CellTags->"c:45"],

Cell[TextData[{
  "\t The Green's function for a general linear ODE of order ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "can also be determined in terms of homogeneous solutions. The Green's \
function satisfies "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{
                
                FractionBox[\(\[DifferentialD]\^N 
                    x\), \(\[DifferentialD]t\^N\),
                  MultilineFunction->None], "+", " ", 
                RowBox[{\(\(u\_\(N - 1\)\)(t)\), 
                  
                  FractionBox[\(\[DifferentialD]\^\(N - 1\)x\), \(\
\[DifferentialD]t\^\(N - 1\)\),
                    MultilineFunction->None]}], "+"}], "..."}], "+", " ", 
            RowBox[{\(\(u\_1\)(t)\), 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], " ", "+", 
            " ", \(\(\(u\_o\)(t)\) x\)}], "=", \(\[Delta](t - t\_o)\)}], 
        TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(2.4.11)"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`t < \ t\_o\)]],
  " we again apply Eq. ",
  ButtonBox["(2.4.9)",
    ButtonData:>"(2.4.9)",
    ButtonStyle->"Hyperlink"],
  " as our initial condition. For ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(t > \ t\_o\),
            "TraditionalForm"]}], TraditionalForm]]],
  " the Green's function is a sum of the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " independent homogeneous solutions, "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`g(t, 
        t\_o) = \ \[Sum]\+\(n = 1\)\%N\( C\_n\) \(\(x\_n\)(
            t)\), \ \ \ t > \(\(t\_o\)\(.\)\)\)]]], "NE4",
  CellTags->"(2.4.12)"],

Cell[TextData[{
  "We now require ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " equations for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\ coefficients\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n\)]],
  ". One such equation is obtained by integrating the ODE  across the \
\[Delta]-function from ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\_o\%-\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\_o\%+\)\)]],
  ". As with the case of the second",
  "-order",
  " ODE, only the highest derivative survives this operation, with the \
result"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            
            FractionBox[\(\[DifferentialD]\^\(N - 
                    1\)\), \(\[DifferentialD]t\^\(N - 1\)\),
              MultilineFunction->None], \(g(t, t\_o)\)}], 
          SubscriptBox[
            StyleBox["|",
              FontSize->14], \(t = \(t\_o\%+\)\)]}], "=", "1."}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.13)"],

Cell[TextData[{
  "Only this derivative exhibits a jump in response to the \[Delta]-function. \
All lower derivatives are continuous, and therefore equal zero as a result of \
Eq. (",
  ButtonBox["2.4.9",
    ButtonData:>"(2.4.9)",
    ButtonStyle->"Hyperlink"],
  "):"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\^n\), \(\[DifferentialD]t\^n\),
                MultilineFunction->None], \(g(t, t\_o)\)}], 
            SubscriptBox[
              StyleBox["|",
                FontSize->16], \(t = \(t\_o\%+\)\)]}], "=", "0"}], 
        ",", \(n = 1\), ",", "2", ",", "...", ",", \(N - 2. \)}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.14)"],

Cell["Also, the Green's function itself is continuous, ", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`g(t\_o, t\_o) = 0. \)]]], "NE4",
  CellTags->"(2.4.15)"],

Cell[TextData[{
  "When Eq. ",
  ButtonBox["(2.4.12)",
    ButtonData:>"(2.4.12)",
    ButtonStyle->"Hyperlink"],
  " is used in Eqs. ",
  ButtonBox["(2.4.13)",
    ButtonData:>"(2.4.13)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(2.4.15)",
    ButtonData:>"(2.4.15)",
    ButtonStyle->"Hyperlink"],
  ", the result is ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " equations for the ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " unknowns ",
  Cell[BoxData[
      \(TraditionalForm\`C\_n\)]],
  ". Solving these coupled linear equations allows us to determine the \
Green's function in terms of the homogeneous solutions to the ODE. For the \
case of an ODE with constant coefficients, the result returns us to Eq. ",
  ButtonBox["(2.3.85)",
    ButtonData:>"(2.3.85)",
    ButtonStyle->"Hyperlink"],
  ". Knowledge of the Green's function, in turn, allows us to determine any \
particular solution. We leave specific examples of this procedure to the \
exercises."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.4.3 Discretized Green's Function I : Initial-Value Problems by \
Matrix Inversion.\
\>", "Subsubtitle",
  CellTags->{"i:70", "c:46"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  " can be thought of as an equation involving  a linear integral operator, \
",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  ". This operator is defined by ",
  "its",
  " action on any function ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ":"
}], "Text",
  CellTags->"i:108"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\^\(-1\)\) 
          f \[Congruent] \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( g(t, 
              t\_o)\)\ \(f(t\_o)\) \[DifferentialD]t\_o\)]],
  ". "
}], "NE4",
  CellTags->"(2.4.16)"],

Cell[TextData[{
  "\tWe have already encountered other linear integral operators: the Fourier \
transform and its inverse  are both integral operators, (see. Sec. ",
  ButtonBox["2.3.3",
    ButtonData:>"c:22",
    ButtonStyle->"Hyperlink"],
  "). The  operator  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  " appears in the particular solution given in Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ", which may be written as "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x\_p = \(L\&^\^\(-1\)\) \(\(f\)\(.\)\)\)]]], "NE4",
  CellTags->"(2.4.17)"],

Cell[TextData[{
  "We call this operator ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\)\^\(-1\)\)]],
  " because it is the ",
  StyleBox["inverse",
    FontSlant->"Italic"],
  " of the differential operator ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\)\)]],
  ". We can see this by operating on Eq. ",
  ButtonBox["(2.4.16)",
    ButtonData:>"(2.4.16)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\)\)]],
  ", and using Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(L\&^\^\(-1\)\) 
          f = \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( L\&^\) \(g(t, 
                t\_o)\)\ \(f(
                t\_o)\) \[DifferentialD]t\_o = \
\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\( \[Delta](t - t\_o)\)\ \(f(
                  t\_o)\) \[DifferentialD]t\_o = \(\(f(t)\)\(.\)\)\)\)\)]],
  "\nThis shows that ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  "has the correct property for an inverse: ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) L\&^\^\(-1\)\)]],
  "returns without change any function to which it is applied."
}], "Text"],

Cell[TextData[{
  "\tWe can see that ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  " is the inverse of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " in another way. The ODE that ",
  Cell[BoxData[
      \(TraditionalForm\`x\_p\)]],
  " satisfies is ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\_p = f\)]],
  ". If we apply ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  "to both sides, we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\^\(-1\)\) \(L\&^\) 
          x\_p = \(\(L\&^\^\(-1\)\) f = x\_p\)\)]],
  ", where in the last step we used Eq. ",
  ButtonBox["(2.4.17)",
    ButtonData:>"(2.4.17)",
    ButtonStyle->"Hyperlink"],
  ".  This shows that ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\^\(-1\)\) L\&^\)]],
  " also returns without change any function to which it is applied. Since"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) \(L\&^\^\(-1\)\) 
          x\_p = \(\(L\&^\^\(-1\)\) \(L\&^\) x\_p = x\_p\)\)]],
  ","
}], "NE4",
  CellTags->"(2.4.18)"],

Cell[TextData[{
  "for a function ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_p\)(t)\)]],
  ", this again proves that ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  "is the inverse of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tNote, however, that there seems to be something wrong with Eq. ",
  ButtonBox["(2.4.18)",
    ButtonData:>"(2.4.18)",
    ButtonStyle->"Hyperlink"],
  ". There are  functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  " for which ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\_h = 0\)]],
  ": the general homogeneous solutions to the ODE. For such functions,  ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\^\(-1\)\) \(L\&^\) x\_h\  = \ 
        0 \[NotEqual] x\_h\)]],
  ". In fact, one might think that since ",
  Cell[BoxData[
      \(TraditionalForm\`\(L\&^\) x\_h = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  "cannot even exist, since matrices that have a finite nullspace do not have \
an inverse (and we already know that by discretizing time ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " can be thought of as a matrix). "
}], "Text"],

Cell[TextData[{
  "\tThe resolution to this paradox follows by considering the discretized \
form of the Green's function. By discretizing the ODE, we can write it as a \
matrix equation, and solve it via matrix inversion. In this approach, the \
operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " becomes a matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  ", and the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  " is simply the inverse of this matrix, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SuperscriptBox[
            StyleBox["L",
              FontSlant->"Plain"], 
            StyleBox[\(-1\),
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " ."
}], "Text"],

Cell[TextData[{
  "\t We examined this procedure for homogeneous initial-value problems in \
Sec. ",
  ButtonBox["1.6.3",
    ButtonData:>{"Chapter1.nb", "c:41"},
    ButtonStyle->"Hyperlink"],
  ". Adding the inhomogeneous term is really a very simple extension of the \
previous discussion.  As an example, we will solve the first-order ODE"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(L\&^\ x\), "=", 
            RowBox[{
              RowBox[{
                FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                  MultilineFunction->None], "+", \(\(\(u\_o\)(t)\) x\)}], 
              "=", \(f(t)\)}]}], ",", "  ", \(x(0) = x\_o\)}], 
        TraditionalForm]]],
  ".  "
}], "NE4",
  CellTags->"(2.4.19)"],

Cell[TextData[{
  "A discretized version of the ODE  can be found using Euler's method, Eq. \
",
  ButtonBox["(1.4.7)",
    ButtonData:>{"Chapter1.nb", "(1.4.7)"},
    ButtonStyle->"Hyperlink"],
  ". Defining ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", " ", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", Euler's method implies"
}], "Text",
  CellTags->"i:90"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(x(0) = x\_o\), ",", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{
            FractionBox[\(x(t\_n) - x(t\_\(n - 1\))\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]], "-", 
            " ", \(\(\(u\_o\)(t\_\(n - 1\))\) \(x(t\_\(n - 1\))\)\)}], 
          "=", \(f(t\_\(n - 1\))\)}], ",", " ", \(n > 0. \)}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.20)"],

Cell["These linear equations can be written as a matrix equation,", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], "=", 
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(2.4.21)"],

Cell[TextData[{
  "where the vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["x",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["=",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["{",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[\(x(0)\),
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], \(x(t\_1)\), ",", \(x(t\_2)\), ",", 
                "..."}], "}"}]}], ","}], TraditionalForm]]],
  " and the vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain",
            FontSlant->"Plain"], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontWeight->"Plain",
                FontSlant->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"]}]], 
          StyleBox[\({x\_o, f(t\_o), f(t\_1),  ... }\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " contains the force ",
  StyleBox["and ",
    FontSlant->"Italic"],
  " initial condition.  The matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is a discretized version of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["L",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontSlant->"Plain"], 
          RowBox[{"(", "\[NoBreak]", GridBox[{
                {"1", "0", "0", "0", "..."},
                {
                  RowBox[{
                    RowBox[{\(-1\), "/", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["t",
                            FontSlant->"Italic"]}]]}], 
                    "+", \(\(u\_o\)(t\_o)\), " "}], 
                  RowBox[{"1", "/", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], "0", "0", "..."},
                {"0", 
                  RowBox[{
                    RowBox[{\(-1\), "/", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["t",
                            FontSlant->"Italic"]}]]}], 
                    "+", \(\(u\_o\)(t\_1)\)}], 
                  RowBox[{"1", "/", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], "0", "..."},
                {"0", "0", 
                  RowBox[{
                    RowBox[{\(-1\), "/", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["t",
                            FontSlant->"Italic"]}]]}], 
                    "+", \(\(u\_o\)(t\_2)\), " "}], 
                  RowBox[{"1", "/", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["t",
                          FontSlant->"Italic"]}]]}], "..."},
                {"\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                  "\[VerticalEllipsis]", "\[VerticalEllipsis]", 
                  "\[DescendingEllipsis]"}
                }], "\[NoBreak]", ")"}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(2.4.22)"],

Cell[TextData[{
  "A similar matrix was introduced for the homogeneous equation, in Sec. \
1.6.3 [see Eq. ",
  ButtonBox["(1.6.21)",
    ButtonData:>{"Chapter1.nb", "(1.6.21)"},
    ButtonStyle->"Hyperlink"],
  "]. The only difference here is that we have multiplied by ",
  Cell[BoxData[
      FormBox[
        RowBox[{"1", "/", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " "}], TraditionalForm]]],
  "everywhere but in the first row, so that Eq. ",
  ButtonBox["(2.4.21)",
    ButtonData:>"(2.4.21)",
    ButtonStyle->"Hyperlink"],
  " has the same form as Eq. ",
  ButtonBox["(2.4.19)",
    ButtonData:>"(2.4.19)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe can solve Eq. ",
  ButtonBox["(2.4.20)",
    ButtonData:>"(2.4.20)",
    ButtonStyle->"Hyperlink"],
  " for the unknown vector ",
  StyleBox["x ",
    FontWeight->"Bold"],
  " by using matrix inversion:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["x",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{
            SuperscriptBox[
              StyleBox["L",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(-1\)], "\[CenterDot]", 
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(2.4.23)"],

Cell[TextData[{
  " Note the resemblance of this equation to Eq. ",
  ButtonBox["(2.4.17)",
    ButtonData:>"(2.4.17)",
    ButtonStyle->"Hyperlink"],
  ".  The matrix inverse appearing in Eq. ",
  ButtonBox["(2.4.23)",
    ButtonData:>"(2.4.23)",
    ButtonStyle->"Hyperlink"],
  " is a discretized version of the inverse operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tFrom a theoretical perspective, it is important to note that both the \
forcing ",
  "and ",
  "the initial condition are included in Eqs. ",
  ButtonBox["(2.4.21)",
    ButtonData:>"(2.4.21)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.23)",
    ButtonData:>"(2.4.23)",
    ButtonStyle->"Hyperlink"],
  ". The initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = x\_o\)]],
  " is built into the forcing function.  If we wish to solve the ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " equation for a given initial condition, all that we need do is set all \
elements of ",
  StyleBox["f ",
    FontWeight->"Bold"],
  " but the first equal to zero. In this case Eq. ",
  ButtonBox["(2.4.21)",
    ButtonData:>"(2.4.21)",
    ButtonStyle->"Hyperlink"],
  " returns to the form of Eq. ",
  ButtonBox["(1.6.21)",
    ButtonData:>{"Chapter1.nb", "(1.6.21)"},
    ButtonStyle->"Hyperlink"],
  ". We can see now that ",
  StyleBox["there is no difference between finding a  solution to the \
homogeneous equation and finding a solution to the inhomogeneous equation",
    FontSlant->"Italic"],
  ". After all, the matrix inversion technique is really just Euler's method, \
and Euler's method is the same whether or not the ODE is homogeneous."
}], "Text"],

Cell[TextData[{
  "\tWe have seen how the forcing contains the inhomogeneous initial \
conditions for the discretized form of the ODE; but is this also possible for \
the actual ODE itself?  The answer is yes. For instance, to define the \
initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = x\_o\)]],
  " in the previous first",
  "-order",
  " ODE, we  can use a \[Delta]-function:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\ 
              x/\[DifferentialD]t\  + \ \(\(u\_o\)(t)\)\ x = 
        f(t)\  + \ \(x\_o\) \(\[Delta](t)\)\)]],
  "."
}], "NE4",
  CellTags->"(2.4.24)"],

Cell[TextData[{
  "If we integrate from ",
  Cell[BoxData[
      \(TraditionalForm\`\(0\^-\)\ to\ \(0\^+\)\)]],
  ", we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`x(\(0\^+\)) - x(\(0\^-\)) = x\_o\)]],
  ". Now let us ",
  StyleBox["assume that",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = 0\ for\ t < 0\)]],
  ". [This is the homogeneous initial condition associated with ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(L\&^\^\(-1\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ": see Eq. ",
  ButtonBox["(2.4.16)",
    ButtonData:>"(2.4.16)",
    ButtonStyle->"Hyperlink"],
  ", and recall that ",
  Cell[BoxData[
      \(TraditionalForm\`g = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < t\_o\)]],
  ".] We then arrive at the proper initial condition, ",
  Cell[BoxData[
      \(TraditionalForm\`x(\(0\^+\)) = x\_o\)]],
  ". Furthermore, for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  " the ODE returns to its previous form, Eq. ",
  ButtonBox["(2.4.19)",
    ButtonData:>"(2.4.19)",
    ButtonStyle->"Hyperlink"],
  ". By solving Eq. ",
  ButtonBox["(2.4.24)",
    ButtonData:>"(2.4.24)",
    ButtonStyle->"Hyperlink"],
  " with a homogeneous initial condition, we obtain the same answer as is \
found from Eq. ",
  ButtonBox["(2.4.19)",
    ButtonData:>"(2.4.19)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tTherefore, we can think of  ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  "as the inverse of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(provided\ that\),
          FontSlant->"Italic"], TraditionalForm]]],
  " the ODE is solved using ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " initial conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`x(t) = 0\ for\ t < 0\)]],
  ". The equation ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\ x = \ f\)]],
  "  specifies both the ODE ",
  "and",
  " the initial conditions at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = \(0\^+\)\)]],
  ". The inhomogeneous initial conditions are contained in the ",
  "forcing function",
  StyleBox[" f, ",
    FontSlant->"Italic"],
  "as in Eq. (",
  ButtonBox["2.4.24",
    ButtonData:>"(2.4.24)",
    ButtonStyle->"Hyperlink"],
  ")",
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text"],

Cell[TextData[{
  "\tWith homogeneous initial conditions  attached to the ODE, it is no \
longer true that nontrivial solutions ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  " exist for which ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\ x\_h = 0\)]],
  "; the only solution to this equation is ",
  Cell[BoxData[
      \(TraditionalForm\`x\_h = 0\)]],
  ".  Thus, the nullspace of ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\)]],
  " is the empty set, and the operator does have an inverse. This resolves \
the apparent contradiction discussed in relation to Eq. ",
  ButtonBox["(2.4.18)",
    ButtonData:>"(2.4.18)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tFurthermore, application of ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(L\&^\^\(-1\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  " via Eq. ",
  ButtonBox["(2.4.16)",
    ButtonData:>"(2.4.16)",
    ButtonStyle->"Hyperlink"],
  " no longer provides only a particular solution; it provides the full \
solution to the problem,",
  StyleBox[" including the initial condition",
    FontSlant->"Italic"],
  ".  We can now see that the previous distinction between particular and \
homogeneous solutions to the ODE is artificial: ",
  "both",
  " can be obtained from the Green's function via Eq. ",
  ButtonBox["(2.4.16)",
    ButtonData:>"(2.4.16)",
    ButtonStyle->"Hyperlink"],
  ". For the above example of a first-order ODE, Eq. ",
  ButtonBox["(2.4.24)",
    ButtonData:>"(2.4.24)",
    ButtonStyle->"Hyperlink"],
  " implies that the general homogeneous solution for this first-order ODE is \
the Green's function itself: ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t) = x\_o\ \(G(t, 0)\)\)]],
  ". This should not be surprising, given that the Green's function can be \
constructed from homogeneous solutions, as we saw in the previous section. "
}], "Text"],

Cell[TextData[{
  "\tLet us now discuss  Eq. ",
  ButtonBox["(2.4.23)",
    ButtonData:>"(2.4.23)",
    ButtonStyle->"Hyperlink"],
  " as a numerical method for obtaining the solution to the ODE. Now specific \
examples of the functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\)(t)\)]],
  " must be chosen, and the solution can be found only over a finite time \
interval. Let us choose ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\)(t) = t\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\  = \ 1\)]],
  ", and find the particular solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 3\)]],
  ", taking a step size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.05"}], 
        TraditionalForm]]],
  " with an initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o = 0\)]],
  ".  Then, as discussed in Sec. ",
  ButtonBox["1.6.3",
    ButtonData:>{"Chapter1.nb", "c:41"},
    ButtonStyle->"Hyperlink"],
  ", the operator can be constructed using Kronecker \[Delta]-functions using \
the following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands:"
}], "Text"],

Cell[BoxData[{
    \(\(Clear[u, \[CapitalDelta]t];\)\), "\n", 
    \(\[CapitalDelta]t\  = \ 0.05; u[n_]\  = \ \[CapitalDelta]t\ n; \ 
    M = 60;\), "\n", 
    \(\(L = 
        Table[KroneckerDelta[n, m]/\[CapitalDelta]t - 
            KroneckerDelta[n, m + 1] \((1/\[CapitalDelta]t - \ u[m])\), {n, 
            0, M}, {m, 0, M}];\)\), "\n", 
    \(\(L[\([1, 1]\)] = 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.91"],

Cell["The discretized force-initial-condition function is ", "Text"],

Cell[BoxData[{
    \(\(f\  = \ Table[1, {i, 0, M}];\)\), "\n", 
    \(\(f[\([1]\)] = 0;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.92"],

Cell[TextData[{
  "Then we can solve for ",
  StyleBox["x",
    FontWeight->"Bold"],
  " via "
}], "Text"],

Cell[BoxData[
    \(\(x = \ Inverse[L] . f;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.93"],

Cell[TextData[{
  "and we can plot the solution by creating a table of ",
  Cell[BoxData[
      \(TraditionalForm\`\((t, x)\)\)]],
  " data values and using a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", as shown in Cell ",
  ButtonBox["2.94",
    ButtonData:>"Cell 2.94",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Table[{n\ \[CapitalDelta]t, \ x[\([n + 1]\)]}, {n, 0, 
          M}];\)\), "\n", 
    \(\(sol\  = \ ListPlot[%];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.94"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.753804 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16548 -18 -4.5 ]
[.01131 .16548 0 4.5 ]
[.01131 .31624 -18 -4.5 ]
[.01131 .31624 0 4.5 ]
[.01131 .467 -18 -4.5 ]
[.01131 .467 0 4.5 ]
[.01131 .61776 -18 -4.5 ]
[.01131 .61776 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16548 m
.03006 .16548 L
s
[(0.2)] .01131 .16548 1 0 Mshowa
.02381 .31624 m
.03006 .31624 L
s
[(0.4)] .01131 .31624 1 0 Mshowa
.02381 .467 m
.03006 .467 L
s
[(0.6)] .01131 .467 1 0 Mshowa
.02381 .61776 m
.03006 .61776 L
s
[(0.8)] .01131 .61776 1 0 Mshowa
.125 Mabswid
.02381 .05241 m
.02756 .05241 L
s
.02381 .0901 m
.02756 .0901 L
s
.02381 .12779 m
.02756 .12779 L
s
.02381 .20317 m
.02756 .20317 L
s
.02381 .24086 m
.02756 .24086 L
s
.02381 .27855 m
.02756 .27855 L
s
.02381 .35393 m
.02756 .35393 L
s
.02381 .39162 m
.02756 .39162 L
s
.02381 .42931 m
.02756 .42931 L
s
.02381 .50469 m
.02756 .50469 L
s
.02381 .54238 m
.02756 .54238 L
s
.02381 .58007 m
.02756 .58007 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .01472 Mdot
.03968 .05241 Mdot
.05556 .09 Mdot
.07143 .12732 Mdot
.0873 .16416 Mdot
.10317 .20036 Mdot
.11905 .23573 Mdot
.13492 .2701 Mdot
.15079 .30332 Mdot
.16667 .33524 Mdot
.18254 .36572 Mdot
.19841 .39463 Mdot
.21429 .42188 Mdot
.23016 .44735 Mdot
.24603 .47098 Mdot
.2619 .4927 Mdot
.27778 .51247 Mdot
.29365 .53025 Mdot
.30952 .54603 Mdot
.3254 .55981 Mdot
.34127 .57161 Mdot
.35714 .58145 Mdot
.37302 .58939 Mdot
.38889 .59547 Mdot
.40476 .59977 Mdot
.42063 .60236 Mdot
.43651 .60332 Mdot
.45238 .60275 Mdot
.46825 .60075 Mdot
.48413 .59742 Mdot
.5 .59286 Mdot
.51587 .58719 Mdot
.53175 .58051 Mdot
.54762 .57294 Mdot
.56349 .56458 Mdot
.57937 .55553 Mdot
.59524 .5459 Mdot
.61111 .53578 Mdot
.62698 .52527 Mdot
.64286 .51446 Mdot
.65873 .50342 Mdot
.6746 .49224 Mdot
.69048 .48099 Mdot
.70635 .46972 Mdot
.72222 .4585 Mdot
.7381 .44737 Mdot
.75397 .43639 Mdot
.76984 .42559 Mdot
.78571 .415 Mdot
.80159 .40465 Mdot
.81746 .39458 Mdot
.83333 .38478 Mdot
.84921 .37529 Mdot
.86508 .36611 Mdot
.88095 .35724 Mdot
.89683 .34869 Mdot
.9127 .34046 Mdot
.92857 .33254 Mdot
.94444 .32494 Mdot
.96032 .31765 Mdot
.97619 .31066 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool004Uoo`<000Ioo`8000Eoo`@002Uoo`D002Moo`D000Aoo`8000Eoo`@002Qoo`D002Qoo`D000Eo
o`8000Eoo`@002Uoo`<000aoo`00B7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo02Qoo`03
001oogoo02Uoo`03001oogoo00Aoo`8000Uoo`03001oogoo02Ioo`04001oogoo000YOol01000Oomo
o`001Goo0P002Goo00<007ooOol09Goo00D007ooOomoo`0000]oo`00B7oo00D007ooOomoo`00011o
o`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo00moo`03001oogoo02Moo`03001oogoo02Yo
o`03001oogoo011oo`03001oogoo02Uoo`03001oogoo00Uoo`00B7oo00D007ooOomoo`00011oo`03
001oogoo02Qoo`03001oogoo02Uoo`03001oogoo00moo`03001oogoo02Qoo`03001oogoo02Yoo`03
001oogoo00moo`03001oogoo02Uoo`03001oogoo00Uoo`00B7oo00D007ooOomoo`0000aoo`@002]o
o`03001oogoo02Uoo`03001oogoo00]oo`@002aoo`03001oogoo02Yoo`03001oogoo00Yoo`@002Yo
o`8000aoo`00B7oo00D007ooOomoo`0000aoo`03001oogoo02aoo`03001oogoo02Uoo`03001oogoo
00]oo`03001oogoo02eoo`03001oogoo02Yoo`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo
00Uoo`00B7oo00D007ooOomoo`0000aoo`03001oogoo02aoo`03001oogoo02Uoo`03001oogoo00]o
o`03001oogoo02Uoo`05001oogooOol0000XOol01@00Oomoogoo000037oo00<007ooOol0:Goo00D0
07ooOomoo`0000]oo`00BGoo0`003Goo1000:Goo0`00:Goo0`003Goo1000:Goo0`00:Woo0`003Goo
1000:Goo0`0037oo003oOomYOol001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo
000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Goo0P00ogooBWoo000FOooo
001>0005Ool001ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Yoo`007Woo00<007ooOol0<Woo00<007ooOol0<Woo00<007oo
Ool0<Goo00<007ooOol0<Woo00<007ooOol0<Woo00<007ooOol0<Woo00<007ooOol02Woo000NOol0
0`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol0
0`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol0
0`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol2
0003Ool2003oOom4Ool001ioo`03001oogoo009oo`800?moodAoo`007Woo00<007ooOol0ogooB7oo
000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo
000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo
000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo
000NOol00`00Oomoo`07Ool2003oOoloOol001ioo`8000Qoo`800?moocmoo`007Woo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`8000eoo`800?moocYoo`007Woo00<007ooOol0
37oo0P00ogoo>Woo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<0
07ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<0
07ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`0017oo0`00
1Woo0P0017oo1@001Woo00<007ooOol0ogooB7oo0003Ool01@00Oomoogoo00001Goo0P001Goo00@0
07ooOol000Ioo`03001oogoo0?moodQoo`000goo00D007ooOomoo`0000eoo`03001oogoo00Ioo`03
001oogoo015oo`800?moocEoo`000goo00D007ooOomoo`0000ioo`03001oogoo00Eoo`<0015oo`80
0?moocEoo`000goo00D007ooOomoo`0000moo`03001oogoo00Aoo`03001oogoo0?moodQoo`000goo
00D007ooOomoo`0000moo`03001oogoo00Aoo`03001oogoo0?moodQoo`000goo00D007ooOomoo`00
00]oo`05001oogooOol00006Ool00`00Oomoo`3oOom8Ool000Aoo`<000eoo`<000Moo`03001oogoo
0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo
0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo
0?moodQoo`007Woo00<007ooOol05goo0P00ogoo;goo000NOol2000HOol2003oOol_Ool001ioo`03
001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03
001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03
001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03
001oogoo0?moodQoo`007Woo00<007ooOol077oo0P00ogoo:Woo000NOol00`00Oomoo`0LOol2003o
OolZOol001ioo`800?moodUoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool0
01ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool0
01ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3oOom8Ool0
01ioo`03001oogoo025oo`800?moobEoo`007Woo00<007ooOol08Goo0P00ogoo9Goo000NOol00`00
Oomoo`3oOom8Ool001ioo`800?moodUoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3o
Oom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`3o
Oom8Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol00`00Oomoo`0W
Ool2003oOolOOol001ioo`03001oogoo02Moo`800?mooamoo`0017oo0`001Woo0P001Woo0`001Woo
00<007ooOol0ogooB7oo0003Ool01@00Oomoogoo00001Goo0P001goo00<007ooOol01Goo00<007oo
Ool0ogoo>Woo0P0037oo0003Ool01@00Oomoogoo00002goo1@001Woo00<007ooOol0ogoo>Woo0P00
37oo0003Ool01@00Oomoogoo00002goo00@007ooOol000Moo`<00?moocAoo`80019oo`000goo00D0
07ooOomoo`0000aoo`03001oo`0000Moo`03001oogoo0?moocAoo`80019oo`000goo00D007ooOomo
o`0000aoo`03001oo`0000Moo`03001oogoo0?moobmoo`8001Moo`000goo00D007ooOomoo`0000eo
o`8000Moo`03001oogoo0?moobmoo`8001Moo`0017oo0`003goo00<007ooOol01Goo00<007ooOol0
ogooB7oo000NOol00`00Oomoo`3oOolZOol2000LOol001ioo`03001oogoo02aoo`800?]oo`8001ao
o`007Woo00<007ooOol0;7oo0P00ogoo6Woo000NOol00`00Oomoo`3oOolUOol2000QOol001ioo`03
001oogoo0?moobEoo`80025oo`007Woo00<007ooOol0ogoo7goo0P009goo000NOol00`00Oomoo`3o
OolOOol2000WOol001ioo`800?moodUoo`007Woo00<007ooOol0ogoo6Woo0P00;7oo000NOol00`00
Oomoo`3oOolJOol2000/Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0<Goo0P00hGoo
0P00<Goo000NOol00`00Oomoo`0aOol2003QOol2000aOol001ioo`03001oogoo0?moodQoo`007Woo
00<007ooOol0ogoo47oo0P00=Woo000NOol00`00Oomoo`3oOol@Ool2000fOol001ioo`03001oogoo
0?moodQoo`007Woo00<007ooOol0ogoo2Woo0P00?7oo000NOol00`00Oomoo`3oOol:Ool2000lOol0
01ioo`03001oogoo0?moodQoo`007Woo0P00ogooBGoo000NOol00`00Oomoo`0fOol2003<Ool20011
Ool001ioo`03001oogoo03Ioo`800<aoo`80045oo`007Woo00<007ooOol0ogooB7oo000NOol00`00
Oomoo`3oOol20016Ool001ioo`03001oogoo0?moo`8004Ioo`007Woo00<007ooOol0ogooB7oo000N
Ool00`00Oomoo`3iOol2001<Ool001ioo`03001oogoo0?Uoo`8004aoo`007Woo00<007ooOol0ogoo
B7oo000NOol00`00Oomoo`0lOol2003oOol:Ool001ioo`03001oogoo03aoo`800;Ioo`80055oo`00
7Woo0P00mGoo0P00DGoo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0>moo`8005Ioo`00
7Woo00<007ooOol0kgoo0P00EWoo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQo
o`007Woo00<007ooOol0@Goo0P00Ygoo0P00Fgoo000NOol00`00Oomoo`11Ool2002WOol2001KOol0
01ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo0004Ool30006Ool20005Ool30007
Ool00`00Oomoo`3TOol2001QOol000=oo`05001oogooOol00005Ool20004Ool01@00Oomoogoo0000
1Woo00<007ooOol0i7oo0P00HGoo0003Ool01@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03
001oogoo0?moodQoo`000goo00D007ooOomoo`0000]oo`05001oogooOol00006Ool3003oOom8Ool0
00=oo`05001oogooOol0000;Ool40007Ool00`00Oomoo`16Ool2002GOol2001VOol000=oo`05001o
ogooOol0000;Ool00`00Oomoo`08Ool00`00Oomoo`16Ool2002GOol2001VOol000=oo`05001oogoo
Ool0000<Ool00`00Oomoo`07Ool00`00Oomoo`3oOom8Ool000Aoo`<000ioo`<000Ioo`03001oogoo
0=Yoo`8006]oo`007Woo00<007ooOol0fWoo0P00Jgoo000NOol00`00Oomoo`3oOom8Ool001ioo`03
001oogoo0?moodQoo`007Woo00<007ooOol0Bgoo0P00R7oo0P00L7oo000NOol00`00Oomoo`1;Ool2
0028Ool2001`Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo000NOol2003@
Ool2001fOol001ioo`03001oogoo0<moo`8007Ioo`007Woo00<007ooOol0ogooB7oo000NOol00`00
Oomoo`1AOol2001gOol2001kOol001ioo`03001oogoo055oo`8007Moo`8007]oo`007Woo00<007oo
Ool0ogooB7oo000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0<Eoo`80081oo`007Woo00<0
07ooOol0aGoo0P00P7oo000NOol00`00Oomoo`1FOol2003_Ool001ioo`03001oogoo05Ioo`8006Mo
o`8008Ioo`007Woo00<007ooOol0_goo0P00QWoo000NOol00`00Oomoo`3oOom8Ool001ioo`800?mo
odUoo`007Woo00<007ooOol0Fgoo0P00GGoo0P00Rgoo000NOol00`00Oomoo`1KOol2001MOol2002;
Ool001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0]Goo0P00T7oo000NOol00`00Oomoo`1Q
Ool2001BOol2002@Ool001ioo`03001oogoo065oo`800>Aoo`007Woo00<007ooOol0/7oo0P00UGoo
000NOol00`00Oomoo`2`Ool2002EOol001ioo`03001oogoo06Ioo`800=moo`007Woo00<007ooOol0
IWoo0P00@Woo0P00Vgoo000NOol00`00Oomoo`2ZOol2002KOol001ioo`800:Ioo`800:1oo`007Woo
00<007ooOol0Jgoo0P00>7oo0P00X7oo000NOol00`00Oomoo`1[Ool2003JOol001ioo`03001oogoo
071oo`8002ioo`800:Eoo`007Woo00<007ooOol0L7oo0P00:Goo0P000goo0P00YGoo000NOol00`00
Oomoo`1fOol2000SOol2002ZOol001ioo`03001oogoo07Ioo`8001eoo`800;1oo`007Woo00<007oo
Ool0Ngoo0P004goo0P000goo0P00/7oo000NOol00`00Oomoo`1kOol20003Ool20003Ool20004Ool2
0003Ool2002eOol001ioo`03001oogoo081oo`8000=oo`8000Aoo`800;Yoo`0017oo0`001Woo0P00
1Goo0`001goo00<007ooOol0ogooB7oo0003Ool01@00Oomoogoo00001Goo0P0017oo00D007ooOomo
o`0000Ioo`03001oogoo0?moodQoo`000goo00D007ooOomoo`0000]oo`05001oogooOol00006Ool0
0`00Oomoo`3oOom8Ool000=oo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo0`00ogooB7oo
0003Ool01@00Oomoogoo000037oo0`00ogooDWoo0003Ool01@00Oomoogoo00002goo00D007ooOomo
o`000?mooe5oo`000goo00D007ooOomoo`0000]oo`05001oogooOol0003oOomAOol000Aoo`<000eo
o`<00?mooe9oo`00ogooJGoo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
The exact solution to this equation with the  initial condition \
x[0] = 0 is in terms of a special function called an error function:\
\>", \
"Text",
  CellTags->"i:105"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear[x];\)\), "\n", 
    \(x[t_]\  = 
      x[t] /. \(DSolve[{\(x'\)[t]\  + \ t\ x[t]\  \[Equal] \ 1, 
              x[0] \[Equal] 0}, x[t], t]\)[\([1]\)]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.95"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(t\^2\/2\)\)\ \@\(\[Pi]\/2\)\ Erfi[
        t\/\@2]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In Cell ",
  ButtonBox["2.96",
    ButtonData:>"Cell 2.96",
    ButtonStyle->"Hyperlink"],
  " we plot this solution and compare it with the numerics."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Plot[x[t], {t, 0, 3}, DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[%, sol, DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 2.96"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.0147151 0.753804 [
[.18254 .00222 -9 -9 ]
[.18254 .00222 9 0 ]
[.34127 .00222 -3 -9 ]
[.34127 .00222 3 0 ]
[.5 .00222 -9 -9 ]
[.5 .00222 9 0 ]
[.65873 .00222 -3 -9 ]
[.65873 .00222 3 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[.01131 .16548 -18 -4.5 ]
[.01131 .16548 0 4.5 ]
[.01131 .31624 -18 -4.5 ]
[.01131 .31624 0 4.5 ]
[.01131 .467 -18 -4.5 ]
[.01131 .467 0 4.5 ]
[.01131 .61776 -18 -4.5 ]
[.01131 .61776 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .01472 m
.18254 .02097 L
s
[(0.5)] .18254 .00222 0 1 Mshowa
.34127 .01472 m
.34127 .02097 L
s
[(1)] .34127 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1.5)] .5 .00222 0 1 Mshowa
.65873 .01472 m
.65873 .02097 L
s
[(2)] .65873 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(2.5)] .81746 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(3)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.05556 .01472 m
.05556 .01847 L
s
.0873 .01472 m
.0873 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.15079 .01472 m
.15079 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.24603 .01472 m
.24603 .01847 L
s
.27778 .01472 m
.27778 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.37302 .01472 m
.37302 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.43651 .01472 m
.43651 .01847 L
s
.46825 .01472 m
.46825 .01847 L
s
.53175 .01472 m
.53175 .01847 L
s
.56349 .01472 m
.56349 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.62698 .01472 m
.62698 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.72222 .01472 m
.72222 .01847 L
s
.75397 .01472 m
.75397 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.84921 .01472 m
.84921 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.9127 .01472 m
.9127 .01847 L
s
.94444 .01472 m
.94444 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .16548 m
.03006 .16548 L
s
[(0.2)] .01131 .16548 1 0 Mshowa
.02381 .31624 m
.03006 .31624 L
s
[(0.4)] .01131 .31624 1 0 Mshowa
.02381 .467 m
.03006 .467 L
s
[(0.6)] .01131 .467 1 0 Mshowa
.02381 .61776 m
.03006 .61776 L
s
[(0.8)] .01131 .61776 1 0 Mshowa
.125 Mabswid
.02381 .05241 m
.02756 .05241 L
s
.02381 .0901 m
.02756 .0901 L
s
.02381 .12779 m
.02756 .12779 L
s
.02381 .20317 m
.02756 .20317 L
s
.02381 .24086 m
.02756 .24086 L
s
.02381 .27855 m
.02756 .27855 L
s
.02381 .35393 m
.02756 .35393 L
s
.02381 .39162 m
.02756 .39162 L
s
.02381 .42931 m
.02756 .42931 L
s
.02381 .50469 m
.02756 .50469 L
s
.02381 .54238 m
.02756 .54238 L
s
.02381 .58007 m
.02756 .58007 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.06244 .106 L
.10458 .20242 L
.14415 .28716 L
.18221 .36112 L
.22272 .4298 L
.26171 .48484 L
.30316 .53063 L
.32392 .54858 L
.34309 .56223 L
.36173 .57288 L
.37125 .57734 L
.3815 .58143 L
.3917 .58478 L
.40103 .58723 L
.41042 .58911 L
.41501 .58983 L
.41933 .59039 L
.42436 .59089 L
.42658 .59106 L
.42892 .59121 L
.43148 .59134 L
.43261 .59138 L
.43383 .59142 L
.43514 .59145 L
.43636 .59147 L
.43711 .59148 L
.43781 .59149 L
.43845 .59149 L
.43914 .59149 L
.44028 .59148 L
.44134 .59147 L
.44251 .59145 L
.44377 .59142 L
.44502 .59138 L
.44634 .59133 L
.44869 .59121 L
.45291 .59092 L
.45753 .5905 L
.46281 .58988 L
.4678 .58917 L
.47714 .58749 L
.49809 .58225 L
.5181 .57551 L
.53655 .56796 L
.57596 .54835 L
.61384 .52611 L
.65418 .50016 L
.69301 .47411 L
.73429 .4463 L
Mistroke
.77405 .42017 L
.81229 .39617 L
.85299 .37221 L
.89217 .35087 L
.9338 .33015 L
.97392 .31205 L
.97619 .31109 L
Mfstroke
.008 w
.02381 .01472 Mdot
.03968 .05241 Mdot
.05556 .09 Mdot
.07143 .12732 Mdot
.0873 .16416 Mdot
.10317 .20036 Mdot
.11905 .23573 Mdot
.13492 .2701 Mdot
.15079 .30332 Mdot
.16667 .33524 Mdot
.18254 .36572 Mdot
.19841 .39463 Mdot
.21429 .42188 Mdot
.23016 .44735 Mdot
.24603 .47098 Mdot
.2619 .4927 Mdot
.27778 .51247 Mdot
.29365 .53025 Mdot
.30952 .54603 Mdot
.3254 .55981 Mdot
.34127 .57161 Mdot
.35714 .58145 Mdot
.37302 .58939 Mdot
.38889 .59547 Mdot
.40476 .59977 Mdot
.42063 .60236 Mdot
.43651 .60332 Mdot
.45238 .60275 Mdot
.46825 .60075 Mdot
.48413 .59742 Mdot
.5 .59286 Mdot
.51587 .58719 Mdot
.53175 .58051 Mdot
.54762 .57294 Mdot
.56349 .56458 Mdot
.57937 .55553 Mdot
.59524 .5459 Mdot
.61111 .53578 Mdot
.62698 .52527 Mdot
.64286 .51446 Mdot
.65873 .50342 Mdot
.6746 .49224 Mdot
.69048 .48099 Mdot
.70635 .46972 Mdot
.72222 .4585 Mdot
.7381 .44737 Mdot
.75397 .43639 Mdot
.76984 .42559 Mdot
.78571 .415 Mdot
.80159 .40465 Mdot
.81746 .39458 Mdot
.83333 .38478 Mdot
.84921 .37529 Mdot
.86508 .36611 Mdot
.88095 .35724 Mdot
.89683 .34869 Mdot
.9127 .34046 Mdot
.92857 .33254 Mdot
.94444 .32494 Mdot
.96032 .31765 Mdot
.97619 .31066 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gQ000`40O003h00OogooJGoo003oOomY
Ool004Uoo`<000Ioo`8000Eoo`@002Uoo`D002Moo`D000Aoo`8000Eoo`@002Qoo`D002Qoo`D000Eo
o`8000Eoo`@002Uoo`<000aoo`00B7oo00D007ooOomoo`0000Eoo`8000Uoo`03001oogoo02Qoo`03
001oogoo02Uoo`03001oogoo00Aoo`8000Uoo`03001oogoo02Ioo`04001oogoo000YOol01000Oomo
o`001Goo0P002Goo00<007ooOol09Goo00D007ooOomoo`0000]oo`00B7oo00D007ooOomoo`00011o
o`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo00moo`03001oogoo02Moo`03001oogoo02Yo
o`03001oogoo011oo`03001oogoo02Uoo`03001oogoo00Uoo`00B7oo00D007ooOomoo`00011oo`03
001oogoo02Qoo`03001oogoo02Uoo`03001oogoo00moo`03001oogoo02Qoo`03001oogoo02Yoo`03
001oogoo00moo`03001oogoo02Uoo`03001oogoo00Uoo`00B7oo00D007ooOomoo`0000aoo`@002]o
o`03001oogoo02Uoo`03001oogoo00]oo`@002aoo`03001oogoo02Yoo`03001oogoo00Yoo`@002Yo
o`8000aoo`00B7oo00D007ooOomoo`0000aoo`03001oogoo02aoo`03001oogoo02Uoo`03001oogoo
00]oo`03001oogoo02eoo`03001oogoo02Yoo`03001oogoo00Yoo`03001oogoo02eoo`03001oogoo
00Uoo`00B7oo00D007ooOomoo`0000aoo`03001oogoo02aoo`03001oogoo02Uoo`03001oogoo00]o
o`03001oogoo02Uoo`05001oogooOol0000XOol01@00Oomoogoo000037oo00<007ooOol0:Goo00D0
07ooOomoo`0000]oo`00BGoo0`003Goo1000:Goo0`00:Goo0`003Goo1000:Goo0`00:Woo0`003Goo
1000:Goo0`0037oo003oOomYOol001ioo`03001oogoo0?moodQoo`007Woo00<007ooOol0ogooB7oo
000NOol00`00Oomoo`3oOom8Ool001ioo`03001oogoo0?moodQoo`007Goo0P00ogooBWoo000FOooo
001>0005Ool001ioo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Qo
o`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Mo
o`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Qo
o`03001oogoo00Qoo`03001oogoo00Yoo`007Woo0P00<goo00<007ooOol0<Woo00<007ooOol0<Goo
00<007ooOol0<Woo00<007ooOol0<Woo00<007ooOol0<Woo00<007ooOol02Woo000NOol2003oOom9
Ool001ioo`03001oo`000?moodQoo`007Woo00<007oo0000ogooB7oo000NOol00`00Ool0003oOom8
Ool001ioo`04001oogoo003oOom7Ool001ioo`04001oogoo003oOom7Ool001ioo`05001oogooOol0
003oOom6Ool001ioo`05001oogooOol0003oOom6Ool001ioo`03001oogoo009oo`03001oogoo0?mo
od=oo`007Woo0P000goo0P00ogooA7oo000NOol00`00Oomoo`02Ool2003oOom4Ool001ioo`03001o
ogoo00=oo`03001oogoo0?mood9oo`007Woo00<007ooOol00goo00<007ooOol0ogoo@Woo000NOol0
0`00Oomoo`04Ool00`00Oomoo`3oOom1Ool001ioo`03001oogoo00Aoo`03001oogoo0?mood5oo`00
7Woo00<007ooOol01Goo00<007ooOol0ogoo@7oo000NOol00`00Oomoo`05Ool00`00Oomoo`3oOom0
Ool001ioo`03001oogoo00Eoo`03001oogoo0?mood1oo`007Woo00<007ooOol01Woo00<007ooOol0
ogoo?goo000NOol00`00Oomoo`06Ool00`00Oomoo`3oOoloOol001ioo`03001oogoo00Moo`03001o
ogoo0?moocioo`007Woo00<007ooOol01goo0P00ogoo?goo000NOol20008Ool2003oOoloOol001io
o`03001oogoo00Qoo`03001oogoo0?mooceoo`007Woo00<007ooOol027oo00<007ooOol0ogoo?Goo
000NOol00`00Oomoo`09Ool00`00Oomoo`3oOollOol001ioo`03001oogoo00Uoo`03001oogoo0?mo
ocaoo`007Woo00<007ooOol02Woo00<007ooOol0ogoo>goo000NOol00`00Oomoo`0:Ool00`00Oomo
o`3oOolkOol001ioo`03001oogoo00]oo`03001oogoo0?moocYoo`007Woo00<007ooOol02goo00<0
07ooOol0ogoo>Woo000NOol00`00Oomoo`0<Ool00`00Oomoo`3oOoliOol001ioo`03001oogoo00ao
o`03001oogoo0?moocUoo`007Woo00<007ooOol037oo00<007ooOol0ogoo>Goo000NOol2000=Ool2
003oOoljOol001ioo`03001oogoo00aoo`800?moocYoo`007Woo00<007ooOol03Woo00<007ooOol0
ogoo=goo000NOol00`00Oomoo`0>Ool00`00Oomoo`3oOolgOol001ioo`03001oogoo00moo`03001o
ogoo0?moocIoo`007Woo00<007ooOol03goo00<007ooOol0ogoo=Woo000NOol00`00Oomoo`0?Ool0
0`00Oomoo`3oOolfOol001ioo`03001oogoo011oo`03001oogoo0?moocEoo`007Woo00<007ooOol0
47oo00<007ooOol0ogoo=Goo000NOol00`00Oomoo`0AOol00`00Oomoo`3oOoldOol000Aoo`<000Io
o`8000Aoo`D000Ioo`03001oogoo015oo`03001oogoo0?moocAoo`000goo00D007ooOomoo`0000Eo
o`8000Eoo`04001oogoo0006Ool00`00Oomoo`0BOol00`00Oomoo`3oOolcOol000=oo`05001oogoo
Ool0000=Ool00`00Oomoo`06Ool00`00Oomoo`0AOol2003oOoleOol000=oo`05001oogooOol0000>
Ool00`00Oomoo`05Ool3000AOol3003oOoldOol000=oo`05001oogooOol0000?Ool00`00Oomoo`04
Ool00`00Oomoo`0COol00`00Oomoo`3oOolbOol000=oo`05001oogooOol0000?Ool00`00Oomoo`04
Ool00`00Oomoo`0COol00`00Oomoo`3oOolbOol000=oo`05001oogooOol0000;Ool01@00Oomoogoo
00001Woo00<007ooOol057oo00<007ooOol0ogoo<Goo0004Ool3000=Ool30007Ool00`00Oomoo`0D
Ool00`00Oomoo`3oOolaOol001ioo`03001oogoo01Eoo`03001oogoo0?mooc1oo`007Woo00<007oo
Ool05Goo00<007ooOol0ogoo<7oo000NOol00`00Oomoo`0FOol00`00Oomoo`3oOol_Ool001ioo`03
001oogoo01Ioo`03001oogoo0?moobmoo`007Woo00<007ooOol05Woo00<007ooOol0ogoo;goo000N
Ool00`00Oomoo`0GOol00`00Oomoo`3oOol^Ool001ioo`03001oogoo01Moo`800?moobmoo`007Woo
0P0067oo0P00ogoo;goo000NOol00`00Oomoo`0HOol00`00Oomoo`3oOol]Ool001ioo`03001oogoo
01Uoo`03001oogoo0?moobaoo`007Woo00<007ooOol06Goo00<007ooOol0ogoo;7oo000NOol00`00
Oomoo`0JOol00`00Oomoo`3oOol[Ool001ioo`03001oogoo01Yoo`03001oogoo0?moob]oo`007Woo
00<007ooOol06goo00<007ooOol0ogoo:Woo000NOol00`00Oomoo`0KOol00`00Oomoo`3oOolZOol0
01ioo`03001oogoo01]oo`03001oogoo0?moobYoo`007Woo00<007ooOol077oo00<007ooOol0ogoo
:Goo000NOol00`00Oomoo`0LOol00`00Oomoo`3oOolYOol001ioo`03001oogoo01aoo`800?moobYo
o`007Woo00<007ooOol077oo0P00ogoo:Woo000NOol2000OOol00`00Oomoo`3oOolWOol001ioo`03
001oogoo01ioo`03001oogoo0?moobMoo`007Woo00<007ooOol07goo00<007ooOol0ogoo9Woo000N
Ool00`00Oomoo`0OOol00`00Oomoo`3oOolVOol001ioo`03001oogoo021oo`03001oogoo0?moobEo
o`007Woo00<007ooOol087oo00<007ooOol0ogoo9Goo000NOol00`00Oomoo`0QOol00`00Oomoo`3o
OolTOol001ioo`03001oogoo025oo`03001oogoo0?moobAoo`007Woo00<007ooOol08Woo00<007oo
Ool0ogoo8goo000NOol00`00Oomoo`0QOol2003oOolUOol001ioo`03001oogoo025oo`800?moobEo
o`007Woo00<007ooOol08goo00<007ooOol0ogoo8Woo000NOol2000TOol00`00Oomoo`3oOolROol0
01ioo`03001oogoo02Aoo`03001oogoo0?moob5oo`007Woo00<007ooOol097oo00<007ooOol0ogoo
8Goo000NOol00`00Oomoo`0UOol00`00Oomoo`3oOolPOol001ioo`03001oogoo02Eoo`03001oogoo
0?moob1oo`007Woo00<007ooOol09Woo00<007ooOol0ogoo7goo000NOol00`00Oomoo`0VOol00`00
Oomoo`3oOolOOol001ioo`03001oogoo02Moo`03001oogoo0?mooaioo`007Woo00<007ooOol09goo
0P00ogoo7goo000NOol00`00Oomoo`0WOol2003oOolOOol000Aoo`<000Ioo`8000Ioo`<000Ioo`03
001oogoo02Qoo`03001oogoo0?mooaeoo`000goo00D007ooOomoo`0000Eoo`8000Moo`03001oogoo
00Eoo`03001oogoo02Uoo`03001oogoo0?moo`eoo`<000aoo`000goo00D007ooOomoo`0000]oo`D0
00Ioo`03001oogoo02Uoo`03001oogoo0?moo`Yoo`<00003Ool0000000aoo`000goo00D007ooOomo
o`0000]oo`04001oogoo0007Ool3000ZOol00`00Oomoo`3oOol7Ool2000BOol000=oo`05001oogoo
Ool0000<Ool00`00Ool00007Ool00`00Oomoo`0ZOol00`00Oomoo`3oOol5Ool4000BOol000=oo`05
001oogooOol0000<Ool00`00Ool00007Ool00`00Oomoo`0[Ool00`00Oomoo`3oOol1Ool3000FOol0
00=oo`05001oogooOol0000=Ool20007Ool00`00Oomoo`0/Ool00`00Oomoo`3mOol4000GOol000Ao
o`<000moo`03001oogoo00Eoo`03001oogoo02aoo`03001oogoo0?]oo`8001]oo`007Woo00<007oo
Ool0;Goo00<007ooOol0n7oo0`0077oo000NOol00`00Oomoo`0/Ool2003hOol200000goo0000000L
Ool001ioo`03001oogoo02aoo`<00?Eoo`80025oo`007Woo00<007ooOol0;Woo00<007ooOol0lWoo
0`008Goo000NOol00`00Oomoo`0_Ool00`00Oomoo`3_Ool200000goo0000000QOol001ioo`03001o
ogoo02moo`03001oogoo0>aoo`<002Ioo`007Woo00<007ooOol0<7oo00<007ooOol0jWoo0`009goo
000NOol2000aOol00`00Oomoo`3XOol2000ZOol001ioo`03001oogoo035oo`03001oogoo0>Eoo`80
02aoo`007Woo00<007ooOol0<Goo00<007ooOol0hgoo1000;7oo000NOol00`00Oomoo`0bOol00`00
Oomoo`3QOol00`00Oomoo`0^Ool001ioo`03001oogoo035oo`800>5oo`80035oo`007Woo00<007oo
Ool0<Goo0`00gWoo1000<Goo000NOol00`00Oomoo`0cOol00`00Oomoo`3JOol2000eOol001ioo`03
001oogoo03Aoo`03001oogoo0=Moo`<003Ioo`007Woo00<007ooOol0=Goo00<007ooOol0eGoo00@0
07oo000003Ioo`007Woo00<007ooOol0=Goo00<007ooOol0dgoo0P00>Woo000NOol00`00Oomoo`0f
Ool00`00Oomoo`3@Ool2000lOol001ioo`03001oogoo03Ioo`03001oogoo0<ioo`@003aoo`007Woo
00<007ooOol0=goo00<007ooOol0c7oo00<007ooOol0?Woo000NOol2000iOol00`00Oomoo`39Ool2
0011Ool001ioo`03001oogoo03Ioo`<00<Uoo`@0045oo`007Woo00<007ooOol0=Woo0P0000=oo`00
Ool0aWoo00<007ooOol00P00@Goo000NOol00`00Oomoo`0iOol00`00Oomoo`33Ool20016Ool001io
o`03001oogoo03Yoo`03001oogoo0<1oo`@004Ioo`007Woo00<007ooOol0>goo00<007ooOol0_Woo
00<007ooOol00P00AWoo000NOol00`00Oomoo`0kOol00`00Oomoo`2lOol2001;Ool001ioo`03001o
ogoo03aoo`03001oogoo0;Uoo`<004aoo`007Woo00<007ooOol0?7oo00<007ooOol0^7oo00@007oo
000004aoo`007Woo00<007ooOol0?Goo00<007ooOol0]Goo0P00D7oo000NOol00`00Oomoo`0lOol3
002eOol00`00Oomoo`1@Ool001ioo`03001oogoo03aoo`<00;=oo`@0055oo`007Woo0P00@7oo00<0
07ooOol0[goo00<007ooOol00P00DGoo000NOol00`00Oomoo`0oOol00`00Oomoo`2]Ool2001FOol0
01ioo`03001oogoo041oo`03001oogoo0:]oo`<005Ioo`007Woo00<007ooOol0@Goo00<007ooOol0
ZGoo00@007oo000005Ioo`007Woo00<007ooOol0@Goo00<007ooOol0Ygoo0P00FWoo000NOol00`00
Oomoo`12Ool00`00Oomoo`2UOol00`00Oomoo`1JOol001ioo`03001oogoo045oo`<00:Aoo`@005]o
o`007Woo00<007ooOol0@Goo0`00Xgoo00<007ooOol00P00Fgoo000NOol00`00Oomoo`14Ool00`00
Oomoo`2NOol2001POol001ioo`03001oogoo04Eoo`03001oogoo09aoo`03001oogoo061oo`0017oo
0`001Woo0P001Goo0`001goo00<007ooOol0AWoo00<007ooOol0VGoo1000HGoo0003Ool01@00Oomo
ogoo00001Goo0P0017oo00D007ooOomoo`0000Ioo`03001oogoo04Ioo`03001oogoo09Moo`80009o
o`80065oo`000goo00D007ooOomoo`0000]oo`05001oogooOol00006Ool00`00Oomoo`17Ool00`00
Oomoo`2EOol00`00Oomoo`1UOol000=oo`05001oogooOol0000;Ool01@00Oomoogoo00001Woo0`00
B7oo00<007ooOol0TWoo0P00J7oo0003Ool01@00Oomoogoo00002goo10001goo00<007ooOol0AWoo
0`00Tgoo00<007ooOol00P00IWoo0003Ool01@00Oomoogoo00002goo00<007ooOol027oo00<007oo
Ool0AWoo0P0000=oo`00Ool0Sgoo0P000goo0P00IWoo0003Ool01@00Oomoogoo000037oo00<007oo
Ool01goo00<007ooOol0BWoo00<007ooOol0S7oo00<007ooOol0Jgoo0004Ool3000>Ool30006Ool0
0`00Oomoo`1:Ool00`00Oomoo`2;Ool01000Ool00000Jgoo000NOol00`00Oomoo`1;Ool00`00Oomo
o`28Ool20002Ool2001[Ool001ioo`03001oogoo04aoo`03001oogoo08Ioo`03001oogoo06moo`00
7Woo00<007ooOol0C7oo00<007ooOol0QGoo00<007ooOol0L7oo000NOol00`00Oomoo`1;Ool30024
Ool200000goo0000001`Ool001ioo`03001oogoo04]oo`800003Ool007oo085oo`04001oogooOol2
001`Ool001ioo`03001oogoo04moo`03001oogoo07ioo`03001oogoo07Aoo`007Woo00<007ooOol0
D7oo00<007ooOol0Ngoo0P00Mgoo000NOol2001BOol00`00Oomoo`1hOol200000goo0000001fOol0
01ioo`03001oogoo059oo`03001oogoo07Ioo`04001oogooOol2001fOol001ioo`03001oogoo05=o
o`03001oogoo07=oo`8007aoo`007Woo00<007ooOol0DGoo0P0000=oo`00Ool0LGoo0P0000=oo`00
0000Ngoo000NOol00`00Oomoo`1AOol20002Ool00`00Oomoo`1]Ool20003Ool2001kOol001ioo`03
001oogoo05Ioo`03001oogoo06]oo`03001oogoo081oo`007Woo00<007ooOol0Egoo00<007ooOol0
J7oo0P00Pgoo000NOol00`00Oomoo`1HOol00`00Oomoo`1UOol20003Ool20020Ool001ioo`03001o
ogoo05Uoo`03001oogoo06=oo`03001oogoo00=oo`80081oo`007Woo00<007ooOol0EWoo0P000Woo
0P00HGoo0P00R7oo000NOol00`00Oomoo`1FOol20004Ool00`00Oomoo`1MOol00`00Oomoo`020026
Ool001ioo`03001oogoo05eoo`03001oogoo05Yoo`8000=oo`8008Ioo`007Woo00<007ooOol0GWoo
00<007ooOol0F7oo00<007ooOol0Rgoo000NOol2001POol00`00Oomoo`1EOol2002>Ool001ioo`03
001oogoo05]oo`8000=oo`03001oogoo05=oo`04001oogooOol2002;Ool001ioo`03001oogoo05]o
o`8000Aoo`80055oo`8000Aoo`8008]oo`007Woo00<007ooOol0Hgoo00<007ooOol0C7oo0P00Tgoo
000NOol00`00Oomoo`1TOol2001:Ool20003Ool2002@Ool001ioo`03001oogoo065oo`8000=oo`03
001oogoo04Aoo`<000Eoo`80091oo`007Woo00<007ooOol0HGoo0P0017oo0P00@Woo0P00VWoo000N
Ool00`00Oomoo`1YOol00`00Oomoo`0mOol20005Ool2002EOol001ioo`03001oogoo06Yoo`8003]o
o`8000Moo`8009Eoo`007Woo00<007ooOol0IWoo0P0017oo00<007ooOol0=Goo0`00X7oo000NOol0
0`00Oomoo`1VOol20005Ool3000bOol20006Ool2002KOol001ioo`03001oogoo071oo`<002eoo`80
00Qoo`8009]oo`007Woo0P00M7oo00<007ooOol09goo0`001Goo0P00X7oo000NOol00`00Oomoo`1[
Ool20007Ool3000ROol40008Ool2002POol001ioo`03001oogoo06]oo`8000Yoo`<001aoo`<00:io
o`007Woo00<007ooOol0L7oo0P0027oo1@004Goo1P002Woo0P00YGoo000NOol00`00Oomoo`1`Ool2
000=OolA000;Ool20003Ool2002UOol001ioo`03001oogoo07Ioo`8002=oo`800:Yoo`007Woo00<0
07ooOol0MWoo0P007Goo0P00/7oo000NOol00`00Oomoo`1kOol2000COol20003Ool2002`Ool001io
o`03001oogoo07]oo`8000=oo`8000=oo`8000Aoo`8000=oo`800;Eoo`007Woo00<007ooOol0P7oo
0P000goo0P0017oo0P00^Woo0004Ool30006Ool20005Ool30007Ool00`00Oomoo`3oOom8Ool000=o
o`05001oogooOol00005Ool20004Ool01@00Oomoogoo00001Woo00<007ooOol0ogooB7oo0003Ool0
1@00Oomoogoo00002goo00D007ooOomoo`0000Ioo`03001oogoo0?moodQoo`000goo00D007ooOomo
o`0000]oo`05001oogooOol00006Ool3003oOom8Ool000=oo`05001oogooOol0000<Ool3003oOomB
Ool000=oo`05001oogooOol0000;Ool01@00Oomoogoo0000ogooDGoo0003Ool01@00Oomoogoo0000
2goo00D007ooOomoo`000?mooe5oo`0017oo0`003Goo0`00ogooDWoo003oOomYOol00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, 0, 0, 0}}]
}, Open  ]],

Cell["\<\
The match is reasonably good, and could be improved by taking a \
smaller step size, or by using a higher-order method to discretize the ODE.\
\
\>", "Text"],

Cell[TextData[{
  "\tHigher-order inhomogeneous  ODES  can also be written in the matrix form \
of Eq. (",
  ButtonBox["2.4.21",
    ButtonData:>"(2.4.21)",
    ButtonStyle->"Hyperlink"],
  " ) and solved by matrix inversion. Examples can be found in the exercises, \
and in Sec. ",
  ButtonBox["2.4.5",
    ButtonData:>"(2.4.5)",
    ButtonStyle->"Hyperlink"],
  " where boundary-value problems will be considered."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4.4 Green's Function for Boundary-Value Problems", "Subsubtitle",
  CellTags->{"i:65", "c:47"}],

Cell[TextData[{
  "Green's functions are often used to find particular solutions to \
inhomogeneous linear ",
  "boundary-value",
  " problems. For example, Green's functions play a very important role in \
solutions to electrostatics problems. Such problems typically involve \
solution of Poisson's equation, Eq. ",
  ButtonBox["(1.1.10)",
    ButtonData:>{"Chapter1.nb", "(1.1.10)"},
    ButtonStyle->"Hyperlink"],
  ", for the potential ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  "  due to a given charge distribution ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Rho]", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ", in the presence of conductors that determine the boundary conditions for \
the potential. "
}], "Text"],

Cell[TextData[{
  "\tPoisson's equation is a PDE, so its complete solution via Green's \
function techniques will be left to Chapters ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ". However, it is enlightening to use a Green's function for Poisson's \
equation in the case where there is only variation in one direction. If we \
call this direction ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  then Poisson's equation is the following ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            OverscriptBox[
              FormBox["L",
                "TraditionalForm"], "^"], \(\[Phi](x)\)}], 
          "=", \(\[Rho](x)\)}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(2.4.25)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          FormBox["L",
            "TraditionalForm"], "^"], TraditionalForm]]],
  " is a second-order linear differential operator in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  "whose form depends on the geometry of the system. For example, for \
Cartesian coordinates, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\&^\), "=", 
          FractionBox[\(\[PartialD]\^2\), \(\[PartialD]x\^2\),
            MultilineFunction->None]}], TraditionalForm]]],
  ", whereas for spherical coordinates with ",
  Cell[BoxData[
      \(TraditionalForm\`x = \ r\)]],
  ", we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{\(L\&^\), "=", 
                FractionBox[\(\[PartialD]\^2\), \(\[PartialD]x\^2\),
                  MultilineFunction->None]}],
              "TraditionalForm"], "+", " ", 
            RowBox[{\(2\/x\), 
              FractionBox["\[PartialD]", \(\[PartialD]x\),
                MultilineFunction->None]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAssuming that there are conductors at ",
  Cell[BoxData[
      \(TraditionalForm\`x = a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`x = b\)]],
  " (assuming ",
  Cell[BoxData[
      \(TraditionalForm\`a < b\)]],
  ") with fixed potentials ",
  Cell[BoxData[
      \(TraditionalForm\`V\_a\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\_b\)]],
  " respectively, the boundary conditions are "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](a) = V\_a, \ \ \[Phi](b) = V\_b\)]],
  "."
}], "NE4",
  CellTags->"(2.4.26)"],

Cell[TextData[{
  "When solving Eqs. ",
  ButtonBox["(2.4.25)",
    ButtonData:>"(2.4.25)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.26)",
    ButtonData:>"(2.4.26)",
    ButtonStyle->"Hyperlink"],
  " analytically, as usual we break the solution into a homogeneous and a \
particular solution: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = \[Phi]\_h + \ \[Phi]\_p\)]],
  ". The homogeneous solution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_h\)]],
  " satisfies the boundary conditions without the source term:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            OverscriptBox[
              FormBox["L",
                "TraditionalForm"], "^"], \(\(\[Phi]\_h\)(x)\)}], "=", "0"}], 
        ",", "    ", \(\[Phi](a) = V\_a\), ",", "  ", \(\[Phi](b) = V\_b\), 
        ","}], TraditionalForm]]]], "NE4",
  CellTags->"(2.4.27)"],

Cell["and the particular solution satisfies the inhomogeneous ODE,", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            OverscriptBox[
              FormBox["L",
                "TraditionalForm"], "^"], \(\(\[Phi]\_p\)(x)\)}], 
          "=", \(\[Rho](x)\)}], ",", 
        "   ", \(\(\[Phi]\_p\)(
            a) = \ \(\(\(\[Phi]\_p\)(b)\)\(=\)\(0.\)\(\ \ \)\)\)}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.28)"],

Cell[TextData[{
  "The particular boundary conditions chosen here are termed ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " boundary conditions. Such boundary conditions have the property that, for \
the forcing function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 0\)]],
  ", a solution to Eq. ",
  ButtonBox["(2.4.28)",
    ButtonData:>"(2.4.28)",
    ButtonStyle->"Hyperlink"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_p = 0\)]],
  ". We will have much more to say about homogeneous boundary conditions in \
Chapters ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:82"],

Cell[TextData[{
  "\tThe  Green's function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x, x\_o)\)]],
  " is used to determine the particular solution to Eq. ",
  ButtonBox["(2.4.28)",
    ButtonData:>"(2.4.28)",
    ButtonStyle->"Hyperlink"],
  ". The ",
  "Green's",
  " function is the solution to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              OverscriptBox[
                FormBox["L",
                  "TraditionalForm"], "^"], \(g(x, x\_o)\)}], 
            "=", \(\[Delta](x - x\_o)\)}], ",", 
          "    ", \(g(a, x\_o) = \(g(b, x\_o) = 0\)\)}], TraditionalForm]]],
  ".   "
}], "NE4",
  CellTags->"(2.4.29)"],

Cell[TextData[{
  "Then Eq. (",
  ButtonBox["2.4.3",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ") implies that the particular solution is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_p\)(
          x)\  = \ \[Integral]\_a\%b\( g(x, x\_o)\) \(\[Rho](
              x\_o)\) \[DifferentialD]x\_o\)]],
  "."
}], "NE4",
  CellTags->"(2.4.30)"],

Cell[TextData[{
  "The boundary conditions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Phi]\_p\)(
          a) = \ \(\(\(\[Phi]\_p\)(b)\)\(=\)\(0\)\(\ \ \)\)\)\)\)]],
  " are satisfied because ",
  Cell[BoxData[
      \(TraditionalForm\`g(a, x\_o) = \(g(b, x\_o) = 0\)\)]],
  " for all values of ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ". "
}], "Text"],

Cell["\<\
\tWe can construct the Green's function for this problem by using \
solutions to the homogeneous ODE in a manner analogous to the method used for \
initial-value problems, discussed previously. The only change is that the \
boundary conditions on the Green's function are now different.  \
\>", "Text"],

Cell[TextData[{
  "\tThe second",
  "-order",
  " ODE has two independent homogeneous solutions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_1\)(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\_2\)(x)\)]],
  ". We construct the Green's function by choosing two different linear \
combinations of these two solutions that match the boundary conditions in \
different regions. For ",
  Cell[BoxData[
      \(TraditionalForm\`x < x\_o\)]],
  ", we choose the linear combination "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&_\_1\)(
          x) = \(\[Phi]\_1\)(
            x)\  - \ \(\(\(\[Phi]\_1\)(a)\)\/\(\(\[Phi]\_2\)(
                  a)\)\) \(\(\[Phi]\_2\)(x)\)\)]],
  ","
}], "NE4",
  CellTags->"(2.4.31)"],

Cell[TextData[{
  "and for ",
  Cell[BoxData[
      \(TraditionalForm\`x > x\_o\)]],
  " we choose the combination"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&_\_2\)(
          x) = \(\[Phi]\_1\)(
            x)\  - \ \(\(\(\[Phi]\_1\)(b)\)\/\(\(\[Phi]\_2\)(
                  b)\)\) \(\(\[Phi]\_2\)(x)\)\)]],
  "."
}], "NE4",
  CellTags->"(2.4.32)"],

Cell[TextData[{
  "These combinations are chosen so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&_\_1\)(a) = \(\(\[Phi]\&_\_2\)(b) = 
          0\)\)]],
  ".Then the ",
  "Green's",
  " function is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(g(x, x\_o)\), "=", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->16], 
            StyleBox[GridBox[{
                  {\(\(C\_1\) \(\(\[Phi]\&_\_1\)(x)\), \ \ \ \ x < x\_o, \)},
                  {\(\(C\_2\) \(\(\[Phi]\&_\_2\)(x)\), \ \ \ \ x > x\_o, \)}
                  }],
              ShowAutoStyles->True]}],
          (#&)]}], TraditionalForm]]]], "NE4",
  CellTags->"(2.4.33)"],

Cell[TextData[{
  "where the constants ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " must still be determined. This ",
  "Green's",
  " function satisfies the boundary conditions given in Eq. ",
  ButtonBox["(2.4.29)",
    ButtonData:>"(2.4.29)",
    ButtonStyle->"Hyperlink"],
  ", and also satisfies the ODE for ",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[NotEqual] \ x\_o\)]],
  ", since ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            OverscriptBox[
              FormBox["L",
                "TraditionalForm"], "^"], \(g(x, x\_o)\)}], "=", "0"}], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x\  \[NotEqual] \ x\_o\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tTo complete the solution, we need values for the constants  ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  " . These are determined by the condition that the ",
  "Green's",
  " function is continuous at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ", so that"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\(C\_1\) \(\(\[Phi]\&_\_1\)(
          x\_o)\) = \(C\_2\) \(\(\[Phi]\&_\_2\)(x\_o)\)\)\(,\)\)\)]]], "NE4",
  CellTags->"(2.4.34)"],

Cell[TextData[{
  "Also, a second equation is provided by  the usual jump condition on the \
first derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ", obtained by integration of Eq. ",
  ButtonBox["(2.4.29)",
    ButtonData:>"(2.4.29)",
    ButtonStyle->"Hyperlink"],
  " from ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_o\%-\)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_o\%+\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox["\[PartialD]", \(\[PartialD]x\),
                MultilineFunction->None], \(g(x, x\_o)\)}], 
            SubscriptBox[
              StyleBox["|",
                FontSize->14], \(x = \(x\_o\%+\)\)], 
            RowBox[{
              RowBox[{"-", 
                FractionBox["\[PartialD]", \(\[PartialD]x\),
                  MultilineFunction->None]}], \(g(x, x\_o)\)}], 
            SubscriptBox[
              StyleBox["|",
                FontSize->14], \(x = \(x\_o\%-\)\)]}], "=", "1"}], 
        TraditionalForm]]],
  ".\nSubstitution of Eq. ",
  ButtonBox["(2.4.33)",
    ButtonData:>"(2.4.33)",
    ButtonStyle->"Hyperlink"],
  " then yields"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(C\_2\) \(\(\[Phi]\&_\_2\^\[Prime]\)(
              x\_o)\) - \(C\_1\) \(\(\[Phi]\&_\_1\^\[Prime]\)(x\_o)\) = 1\)], 
    "NE4"], "NE4"],
  StyleBox[".", "NE4"]
}], "NE4",
  CellTags->"(2.4.35)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.4.34)",
    ButtonData:>"(2.4.34)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.35)",
    ButtonData:>"(2.4.35)",
    ButtonStyle->"Hyperlink"],
  " can be solved for ",
  Cell[BoxData[
      \(TraditionalForm\`C\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2\)]],
  ". The solution is"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(g(x, x\_o)\), "=", 
        TagBox[
          RowBox[{
            StyleBox["{",
              ShowAutoStyles->False,
              FontSize->24], 
            StyleBox[GridBox[{
                  {
                    RowBox[{
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{
                            FormBox[\(\(\[Phi]\&_\_2\)(x\_o)\),
                              "TraditionalForm"], 
                            FormBox[\(\(\[Phi]\&_\_1\)(x)\),
                              "TraditionalForm"]}], \(W(x\_o)\)]}], ",", 
                      "   ", \(x < x\_o\), ","}]},
                  {
                    RowBox[{
                      RowBox[{"-", 
                        FractionBox[
                          RowBox[{
                            FormBox[\(\(\[Phi]\&_\_1\)(x\_o)\),
                              "TraditionalForm"], 
                            FormBox[\(\(\[Phi]\&_\_2\)(x)\),
                              "TraditionalForm"]}], \(W(x\_o)\)]}], ",", 
                      "   ", \(x > x\_o\), ","}]}
                  }],
              ShowAutoStyles->True]}],
          (#&)]}], TraditionalForm]]]], "NE4",
  CellTags->{"(2.4.36)", "i:66"}],

Cell[TextData[{
  "where the Wronskian ",
  Cell[BoxData[
      \(TraditionalForm\`W(
          x)\  = \(\(\[Phi]\&_\_1\^\[Prime]\)(x)\) \(\(\[Phi]\&_\_2\)(
              x)\) - \(\(\(\[Phi]\&_\_2\^\[Prime]\)(x)\) \(\(\[Phi]\&_\_1\)(
              x)\)\(\ \)\)\)]],
  " again makes an appearance [see Eq. ",
  ButtonBox["(2.4.8)",
    ButtonData:>"(2.4.8)",
    ButtonStyle->"Hyperlink"],
  "]. Equation ",
  ButtonBox["(2.4.36)",
    ButtonData:>"(2.4.36)",
    ButtonStyle->"Hyperlink"],
  " can be used in Eq. ",
  ButtonBox["(2.4.30)",
    ButtonData:>"(2.4.30)",
    ButtonStyle->"Hyperlink"],
  " to determine the particular solution for any given charge density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ". An alternative description of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " in terms of ",
  "eigenmodes",
  "  can be found in Chapter 4; see Eq. ",
  ButtonBox["(4.3.16)",
    ButtonData:>{"Chapter4.nb", "(4.3.16)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:67"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2.4.5 Discretized Green's Functions II: Boundary-Value Problems by \
Matrix Inversion\
\>", "Subsubtitle",
  CellTags->{"i:69", "c:48"}],

Cell[CellGroupData[{

Cell["Theory for Second-order ODEs", "Section",
  CellTags->"c:49"],

Cell[TextData[{
  "Equation (",
  ButtonBox["2.4.30",
    ButtonData:>"(2.4.30)",
    ButtonStyle->"Hyperlink"],
  ") can be thought of as an operator equation,"
}], "Text",
  CellTags->"i:109"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_p = \(L\&^\^\(-1\)\) \[Rho]\)]],
  ","
}], "NE4",
  CellTags->"(2.4.37)"],

Cell[TextData[{
  "involving the linear integral operator ",
  Cell[BoxData[
      \(TraditionalForm\`L\&^\^\(-1\)\)]],
  " defined by"
}], "Text"],

Cell[TextData[{
  StyleBox[Cell[BoxData[
      \(TraditionalForm\`\(L\&^\^\(-1\)\) \[Rho] = \ \[Integral]\_a\%b\( g(x, 
              x\_o)\) \(\[Rho](x\_o)\) \[DifferentialD]x\_o\)], "NE4"], 
    "NE4"],
  StyleBox[".", "NE4"]
}], "NE4",
  CellTags->"(2.4.38)"],

Cell[TextData[{
  "This subsection discusses the matrix inverse method that follows from \
discretization of Eq. (",
  ButtonBox["2.4.37",
    ButtonData:>"(2.4.37)",
    ButtonStyle->"Hyperlink"],
  "). This method,  discussed previously for initial-value problems, is \
really most useful for determining the solution to boundary-value problems. \
We will apply this method to a general second-order ODE of the form"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(L\&^\ \[Phi]\), "=", 
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\^2\), \(\[DifferentialD]x\^2\),
                MultilineFunction->None], "\[Phi]"}], "+", 
            RowBox[{\(\(u\_1\)(x)\), 
              FractionBox["\[DifferentialD]", \(\[DifferentialD]x\),
                MultilineFunction->None], " ", "\[Phi]"}], 
            "+", \(\(\(u\_o\)(x)\) \[Phi]\)}], " ", "=", \(\[Rho](x)\)}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.39)"],

Cell["with boundary conditions", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi](a) = 
      V\_a, \ \ \[Phi](b) = \(\(V\_b\)\(.\)\)\)]]], "NE4",
  CellTags->"(2.4.40)"],

Cell[TextData[{
  "We solve this problem numerically on a grid of positions, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"x", " ", "=", " ", 
          RowBox[{\(x\_n\), "=", 
            RowBox[{"a", " ", "+", " ", 
              RowBox[{"n", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " "}]}]}]}], 
        TraditionalForm]]],
  "specified by the step size ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(\((b - a)\)/M\)}], 
        TraditionalForm]]],
  ". Then Eq. ",
  ButtonBox["(2.4.39)",
    ButtonData:>"(2.4.39)",
    ButtonStyle->"Hyperlink"],
  " becomes a matrix equation that can be solved directly by matrix \
inversion."
}], "Text"],

Cell[TextData[{
  "\tFirst, we need to discretize the differential equation. To do so, we use \
a ",
  StyleBox["centered-difference ",
    FontSlant->"Italic"],
  "scheme. For the first derivative, this involves the approximation"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\[Phi]\), \(\[DifferentialD]x\),
              MultilineFunction->None], " ", \((x\_n)\)}], " ", 
          "\[TildeEqual]", 
          FractionBox[
            RowBox[{
              RowBox[{"\[Phi]", "(", 
                RowBox[{\(x\_n\), "+", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ")"}], " ", "-", 
              RowBox[{"\[Phi]", "(", 
                RowBox[{\(x\_n\), "-", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], ")"}], " "}], 
            RowBox[{"2", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]]}], "=", 
        RowBox[{
          
          FractionBox[\(\(\[Phi](x\_\(n + 1\))\)\(\ \)\(-\)\(\[Phi](
                x\_\(n - 1\))\)\(\ \)\), 
            RowBox[{"2", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]], "."}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.41)"],

Cell[TextData[{
  "In the limit that \[CapitalDelta]",
  StyleBox["x",
    FontSlant->"Italic"],
  " approaches zero, this approximation clearly approaches the slope of \
\[Phi] at",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"x", "=", 
            FormBox[\(x\_n\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". Other schemes could also be used (Table ",
  ButtonBox["2.3",
    ButtonData:>"Table 2.3",
    ButtonStyle->"Hyperlink"],
  "), such as the scheme used in Euler's method. This is called a \
forward-difference scheme:"
}], "Text",
  CellTags->"i:92"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\[Phi]\), \(\[DifferentialD]x\),
                MultilineFunction->None], " ", \((x\_n)\)}], " ", 
            "\[TildeEqual]", 
            FractionBox[
              RowBox[{
                RowBox[{"\[Phi]", "(", 
                  RowBox[{\(x\_n\), "+", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]]}], ")"}], " ", 
                "-", \(\[Phi](x\_n)\), " "}], 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]]}], "=", 
          
          FractionBox[\(\(\[Phi](x\_\(n + 1\))\)\(\ \)\(-\)\(\[Phi](
                x\_n)\)\(\ \)\), 
            RowBox[{" ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(2.4.42)"],

Cell["One might also choose the backward-difference scheme, ", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\[Phi]\), \(\[DifferentialD]x\),
                MultilineFunction->None], " ", \((x\_n)\)}], " ", 
            "\[TildeEqual]", 
            FractionBox[
              RowBox[{\(\[Phi](x\_n)\), " ", "-", 
                RowBox[{"\[Phi]", "(", 
                  RowBox[{\(x\_n\), "-", " ", 
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]]}], ")"}], " "}], 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]]}], "=", 
          
          FractionBox[\(\(\[Phi](x\_n)\)\(\ \)\(-\)\(\[Phi](
                x\_\(n - 1\))\)\(\ \)\), 
            RowBox[{" ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]]}], ","}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.43)"],

Cell["\<\
but centered-differencing is the most accurate of the three methods \
(see the exercises). For the second derivative, we again use a centered \
difference,\
\>", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          
          FractionBox[\(\[DifferentialD]\^2 \[Phi]\), \
\(\[DifferentialD]x\^2\),
            MultilineFunction->None], \((x\_n)\)}], "=", 
        RowBox[{
          FractionBox[
            RowBox[{
              RowBox[{
                
                FractionBox[\(\[DifferentialD]\[Phi]\), \(\[DifferentialD]x\),
                  
                  MultilineFunction->None], \((x\_\(n + 1/2\))\)}], "-", 
              RowBox[{
                
                FractionBox[\(\[DifferentialD]\[Phi]\), \(\[DifferentialD]x\),
                  
                  MultilineFunction->None], \((x\_\(n - 1/2\))\)}]}], 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]], "=", 
          RowBox[{
            
            FractionBox[\(\[Phi](x\_\(n + 1\)) - 
                2\ \(\[Phi](x\_n)\) + \[Phi](x\_\(n - 1\))\), 
              SuperscriptBox[
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], "2"]], "."}]}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.44)"],

Cell[TextData[{
  " Higher-order derivatives can also be differenced in this fashion. Several \
of these derivatives are given in Table ",
  ButtonBox["2.4",
    ButtonData:>"Table 2.4",
    ButtonStyle->"Hyperlink"],
  ". These difference forms are derived in the ",
  ButtonBox["Appendix",
    ButtonData:>{"Appendix.nb", None},
    ButtonStyle->"Hyperlink"],
  ".  However, the first and second derivatives are all that we require here. \
"
}], "Text",
  CellTags->"i:75"],

Cell[BoxData[
    FormBox[
      StyleBox[GridBox[{
            {
              RowBox[{"Table", " ", "2", 
                RowBox[{".3", ".", " ", 
                  
                  StyleBox[Cell[
                    "Different Forms for Finite-Differenced First \
Derivatives:", "ColumnHead"],
                    PageWidth->500]}]}], 
              StyleBox["",
                PageWidth->300]},
            {
              StyleBox[Cell[TextData[Cell[BoxData[
                    FormBox[
                      RowBox[{
                        RowBox[{
                          
                          FractionBox[\(\[DifferentialD]\[Phi]\), \(\
\[DifferentialD]x\),
                            MultilineFunction->None], " ", \((x\_n)\)}], " ", 
                        "\[TildeEqual]", 
                        
                        FractionBox[\(\(\[Phi](
                              x\_\(n + 1\))\)\(\ \)\(-\)\(\[Phi](
                              x\_n)\)\(\ \)\), 
                          RowBox[{" ", 
                            StyleBox[
                              RowBox[{"\[CapitalDelta]", 
                                StyleBox["x",
                                  FontSlant->"Italic"]}]]}]]}], 
                      TraditionalForm]]]], "TableText"],
                PageWidth->300], 
              StyleBox[Cell["Forward difference", "TableText"],
                PageWidth->300]},
            {
              StyleBox[Cell[TextData[Cell[BoxData[
                    FormBox[
                      RowBox[{
                        RowBox[{
                          
                          FractionBox[\(\[DifferentialD]\[Phi]\), \(\
\[DifferentialD]x\),
                            MultilineFunction->None], " ", \((x\_n)\)}], " ", 
                        "\[TildeEqual]", 
                        
                        FractionBox[\(\(\[Phi](x\_n)\)\(\ \)\(-\)\(\[Phi](
                              x\_\(n - 1\))\)\(\ \)\), 
                          RowBox[{" ", 
                            StyleBox[
                              RowBox[{"\[CapitalDelta]", 
                                StyleBox["x",
                                  FontSlant->"Italic"]}]]}]]}], 
                      TraditionalForm]]]], "TableText"],
                PageWidth->300], 
              StyleBox[Cell["Backward difference", "TableText"],
                PageWidth->300]},
            {
              StyleBox[Cell[TextData[Cell[BoxData[
                    FormBox[
                      RowBox[{
                        RowBox[{
                          
                          FractionBox[\(\[DifferentialD]\[Phi]\), \(\
\[DifferentialD]x\),
                            MultilineFunction->None], " ", \((x\_n)\)}], " ", 
                        "\[TildeEqual]", 
                        
                        FractionBox[\(\(\[Phi](
                              x\_\(n + 1\))\)\(\ \)\(-\)\(\[Phi](
                              x\_\(n - 1\))\)\(\ \)\), 
                          RowBox[{"2", " ", 
                            StyleBox[
                              RowBox[{"\[CapitalDelta]", 
                                StyleBox["x",
                                  FontSlant->"Italic"]}]]}]]}], 
                      TraditionalForm]]]], "TableText"],
                PageWidth->300], 
              StyleBox[Cell["Centered difference", "TableText"],
                PageWidth->300]}
            },
          ColumnSpacings->1.8,
          ColumnAlignments->{Left}],
        PageWidth->200], NullForm]], "Table",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->{"i:74", "Table 2.3"}],

Cell["", "Text"],

Cell[BoxData[
    FormBox[
      RowBox[{GridBox[{
            {\(Table  2  .4 . \ Centered - 
                Difference\ Forms\ for\ \(\(SomeDerivatives\)\( . \^a\)\)\)},
            {GridBox[{
                  {GridBox[{
                        {Cell[TextData[Cell[BoxData[
                              FormBox[
                                RowBox[{
                                  RowBox[{
                                    
                                    FractionBox[\(\[DifferentialD]\[Phi]\), \
\(\[DifferentialD]x\),
                                      MultilineFunction->None], 
                                    " ", \((x\_n)\)}], " ", "\[TildeEqual]", 
                                  
                                  FractionBox[\(\(\[Phi](
                                        x\_\(n + 1\))\)\(\ \)\(-\)\(\[Phi](
                                        x\_\(n - 1\))\)\(\ \)\), 
                                    RowBox[{"2", " ", 
                                      StyleBox[
                                        RowBox[{"\[CapitalDelta]", 
                                        StyleBox["x",
                                        FontSlant->"Italic"]}]]}]]}], 
                                TraditionalForm]]]], "ColumnHead"]},
                        {Cell[TextData[Cell[BoxData[
                              FormBox[
                                RowBox[{
                                  RowBox[{
                                    
                                    FractionBox[\(\[DifferentialD]\^2 \
\[Phi]\), \(\[DifferentialD]x\^2\),
                                      MultilineFunction->None], \((x\_n)\)}], 
                                  "\[TildeEqual]", 
                                  
                                  FractionBox[\(\[Phi](x\_\(n + 1\)) - 
                                      2\ \(\[Phi](x\_n)\) + \[Phi](
                                        x\_\(n - 1\))\), 
                                    SuperscriptBox[
                                      StyleBox[
                                        RowBox[{"\[CapitalDelta]", 
                                        StyleBox["x",
                                        FontSlant->"Italic"]}]], "2"]]}], 
                                TraditionalForm]]]], "TableText"]},
                        {Cell[TextData[Cell[BoxData[
                              FormBox[
                                RowBox[{
                                  RowBox[{
                                    
                                    FractionBox[\(\[DifferentialD]\^3 \
\[Phi]\), \(\[DifferentialD]x\^3\),
                                      MultilineFunction->None], \((x\_n)\)}], 
                                  "\[TildeEqual]", 
                                  
                                  FractionBox[\(\[Phi](x\_\(n + 2\)) - 
                                      2\ \(\[Phi](x\_\(n - 1\))\) + 
                                      2\ \(\[Phi](x\_\(n - 1\))\) - \[Phi](
                                        x\_\(n - 2\))\), 
                                    RowBox[{"2", " ", 
                                      SuperscriptBox[
                                        StyleBox[
                                        RowBox[{"\[CapitalDelta]", 
                                        StyleBox["x",
                                        FontSlant->"Italic"]}]], "3"]}]]}], 
                                TraditionalForm]]]], "TableText"]},
                        {Cell[TextData[Cell[BoxData[
                              FormBox[
                                RowBox[{
                                  RowBox[{
                                    
                                    FractionBox[\(\[DifferentialD]\^4 \
\[Phi]\), \(\[DifferentialD]x\^4\),
                                      MultilineFunction->None], \((x\_n)\)}], 
                                  "\[TildeEqual]", 
                                  
                                  FractionBox[\(\[Phi](x\_\(n + 2\)) - 
                                      4\ \(\[Phi](x\_\(n + 1\))\) + 
                                      6 \( \[Phi](x\_n)\) - 
                                      4\ \(\[Phi](x\_\(n - 1\))\) + \[Phi](
                                        x\_\(n - 2\))\), 
                                    SuperscriptBox[
                                      StyleBox[
                                        RowBox[{"\[CapitalDelta]", 
                                        StyleBox["x",
                                        FontSlant->"Italic"]}]], "4"]]}], 
                                TraditionalForm]]]], "TableText"]},
                        {Cell[TextData[Cell[BoxData[
                              FormBox[
                                RowBox[{
                                  RowBox[{
                                    
                                    FractionBox[\(\[DifferentialD]\^5 \
\[Phi]\), \(\[DifferentialD]x\^5\),
                                      MultilineFunction->None], \((x\_n)\)}], 
                                  "\[TildeEqual]", 
                                  
                                  FractionBox[\(\[Phi](x\_\(n + 3\)) - 
                                      4 \( \[Phi](x\_\(n + 2\))\) + 
                                      5 \( \[Phi](x\_\(n + 1\))\) - 
                                      5\ \(\[Phi](x\_\(n - 1\))\) + 
                                      4 \( \[Phi](x\_\(n - 2\))\) - \[Phi](
                                        x\_\(n - 3\))\), 
                                    RowBox[{"2", 
                                      SuperscriptBox[
                                        StyleBox[
                                        RowBox[{"\[CapitalDelta]", 
                                        StyleBox["x",
                                        FontSlant->"Italic"]}]], "4"]}]]}], 
                                TraditionalForm]]]], "TableText"]}
                        },
                      ColumnAlignments->{Left}]},
                  {
                    RowBox[{
                      RowBox[{
                        FractionBox[\(\[DifferentialD]\^6 \[Phi]\), 
                          RowBox[{"\[DifferentialD]", 
                            SuperscriptBox[
                              StyleBox["x",
                                FontSlant->"Italic"], "6"]}],
                          MultilineFunction->None], 
                        RowBox[{"(", 
                          StyleBox[\(x\_n\),
                            FontSlant->"Italic"], ")"}]}], "\[TildeEqual]", 
                      FractionBox[
                        RowBox[{
                          RowBox[{"\[Phi]", 
                            RowBox[{"(", 
                              SubscriptBox[
                                StyleBox["x",
                                  FontSlant->"Italic"], 
                                RowBox[{
                                  StyleBox["n",
                                    FontSlant->"Italic"], "+", "3"}]], 
                              ")"}]}], 
                          "-", \(6 \( \[Phi] \((x\_\(n + 2\))\)\)\), "+", 
                          RowBox[{"15", "\[Phi]", 
                            RowBox[{"(", 
                              SubscriptBox[
                                StyleBox["x",
                                  FontSlant->"Italic"], 
                                RowBox[{
                                  StyleBox["n",
                                    FontSlant->"Italic"], "+", "1"}]], 
                              ")"}]}], "-", 
                          RowBox[{"20", "\[Phi]", 
                            RowBox[{"(", 
                              StyleBox[\(x\_n\),
                                FontSlant->"Italic"], ")"}]}], "+", 
                          RowBox[{"15", " ", "\[Phi]", 
                            RowBox[{"(", 
                              SubscriptBox[
                                StyleBox["x",
                                  FontSlant->"Italic"], 
                                RowBox[{
                                  StyleBox["n",
                                    FontSlant->"Italic"], "-", "1"}]], 
                              ")"}]}], "-", 
                          RowBox[{"6", "\[Phi]", 
                            RowBox[{"(", 
                              SubscriptBox[
                                StyleBox["x",
                                  FontSlant->"Italic"], 
                                RowBox[{
                                  StyleBox["n",
                                    FontSlant->"Italic"], "-", "2"}]], 
                              ")"}]}], "+", 
                          RowBox[{"\[Phi]", 
                            RowBox[{"(", 
                              SubscriptBox[
                                StyleBox["x",
                                  FontSlant->"Italic"], 
                                RowBox[{
                                  StyleBox["n",
                                    FontSlant->"Italic"], "-", "3"}]], 
                              ")"}]}]}], 
                        SuperscriptBox[
                          StyleBox[
                            RowBox[{"\[CapitalDelta]", 
                              StyleBox["x",
                                FontSlant->"Italic"]}]], "4"]]}]}
                  },
                ColumnAlignments->{Left}]}
            }], 
        "\[IndentingNewLine]", \(\(\(\[IndentingNewLine]\)\(\ \)\)\^a\), 
        "All", " ", "forms", " ", "shown", " ", "are", " ", "accurate", " ", 
        "to", " ", "order", " ", 
        FormBox[
          SuperscriptBox[
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "2"],
          "TraditionalForm"]}], NullForm]], "Table",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->{"i:73", "Table 2.4"}],

Cell[TextData[{
  "\tUsing these centered-difference forms for the first and second \
derivatives, Eq. ",
  ButtonBox["(2.4.39)",
    ButtonData:>"(2.4.39)",
    ButtonStyle->"Hyperlink"],
  " becomes a series of coupled linear equations for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x\_n)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              
              FractionBox[\(\[Phi](x\_\(n + 1\)) - 
                  2\ \(\[Phi](x\_n)\) + \[Phi](x\_\(n - 1\))\), 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], "2"]], "+", 
              RowBox[{\(\(u\_1\)(x\_n)\), 
                FormBox[
                  
                  FractionBox[\(\(\[Phi](x\_\(n + 1\))\)\(\ \)\(-\)\(\[Phi](
                        x\_\(n - 1\))\)\(\ \)\), 
                    RowBox[{"2", " ", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["x",
                            FontSlant->"Italic"]}]]}]],
                  "TraditionalForm"]}], 
              "+", \(\(\(u\_o\)(x\_n)\) \(\[Phi](x\_n)\)\)}], 
            "=", \(\[Rho](x\_n)\)}], ",", "  ", \(0 < n < M\)}], 
        TraditionalForm]]],
  ". "
}], "NE4",
  CellTags->"(2.4.45)"],

Cell[TextData[{
  "As indicated, this equation is correct only at interior points. At the end \
points ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n = M\)]],
  " we have the boundary conditions"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Phi](x\_o) = 
      V\_a, \ \ \ \[Phi](x\_M) = \(\(V\_b\)\(.\)\)\)]]], "NE4",
  CellTags->"(2.4.46)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(2.4.45)",
    ButtonData:>"(2.4.45)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.46)",
    ButtonData:>"(2.4.46)",
    ButtonStyle->"Hyperlink"],
  " provide ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " equations in the ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " unknowns ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x\_n)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(n = 0, 1, 2,  ... , M\)\)\)]],
  ". We can write these equations as a matrix equation, and solve this \
equation directly by matrix inversion. When written as a matrix equation, \
Eqs. ",
  ButtonBox["(2.4.45)",
    ButtonData:>"(2.4.45)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.46)",
    ButtonData:>"(2.4.46)",
    ButtonStyle->"Hyperlink"],
  " take the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["L",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["\[Phi]",
              FontWeight->"Bold"]}], "=", 
          StyleBox["\[Rho]",
            FontWeight->"Bold"]}], TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(2.4.47)"],

Cell["where ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Phi]",
            FontWeight->"Bold"], 
          "=", \({\[Phi](x\_o), \[Phi](x\_1), \(\(...\)\(.\)\), \[Phi](
              x\_M)}\)}], TraditionalForm]]],
  ", \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[Rho]",
              FontWeight->"Bold"], 
            "=", \({V\_a, \[Rho](x\_1), \[Rho](
                x\_2), \(\(...\)\(.\)\(\[Rho](x\_\(M - 1\))\)\), V\_b}\)}], 
          ","}], TraditionalForm]]]
}], "NE4",
  CellTags->"(2.4.48)"],

Cell[TextData[{
  "and the ",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  "-by-",
  Cell[BoxData[
      \(TraditionalForm\`M + 1\)]],
  " matrix  ",
  StyleBox["L ",
    FontWeight->"Bold"],
  " is determined in terms of Kronecker \[Delta]-functions for the interior \
points as follows:"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\(\(L\)\(\ \)\)\_\(n\ m\)\), "=", " ", 
        RowBox[{
          
          RowBox[{\((\[Delta]\_\(n + 1, m\) - \ 
                2  \[Delta]\_\(n\ m\)\  + \[Delta]\_\(n - 1, m\))\), "/", 
            SuperscriptBox[
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], "2"]}], "+", " ", 
          RowBox[{\(\(u\_1\)(x\_n)\), 
            
            RowBox[{\((\[Delta]\_\(n + 1, m\)\  - \ \[Delta]\_\(n - 1, m\))\),
               "/", 
              RowBox[{"(", 
                RowBox[{"2", " ", 
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]]}], " ", ")"}]}]}], " ", "+", 
          " ", \(\[Delta]\_\(n\ m\)\ \(\(u\_o\)(x\_n)\)\)}]}], 
      TraditionalForm]]]], "NE4",
  CellTags->"(2.4.49)"],

Cell["\<\
 A 4-by-4 version of the resulting matrix is displayed below:\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(M = 3; \ 
    L\  = \ Table[
        KroneckerDelta[n, m] \((u\_o[n] - 2/\[CapitalDelta]x^2)\)\  + \ 
          KroneckerDelta[n + 1, 
              m] \((1/\[CapitalDelta]x^2 + \ 
                u\_1[n]/\((2\ \[CapitalDelta]x)\))\)\  + \ 
          KroneckerDelta[n - 1, 
              m] \((1/\[CapitalDelta]x^2\  - \ 
                u\_1[n]/\((2  \[CapitalDelta]x)\))\), {n, 0, M}, {m, 0, 
          M}];\), "\n", 
    \(MatrixForm[L]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.97"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-\(2\/\[CapitalDelta]x\^2\)\) + 
                u\_o[0]\), \(1\/\[CapitalDelta]x\^2 + 
                u\_1[0]\/\(2\ \[CapitalDelta]x\)\), "0", "0"},
            {\(1\/\[CapitalDelta]x\^2 - 
                u\_1[1]\/\(2\ \[CapitalDelta]x\)\), \
\(\(-\(2\/\[CapitalDelta]x\^2\)\) + u\_o[1]\), \(1\/\[CapitalDelta]x\^2 + 
                u\_1[1]\/\(2\ \[CapitalDelta]x\)\), "0"},
            {
              "0", \(1\/\[CapitalDelta]x\^2 - 
                u\_1[2]\/\(2\ \[CapitalDelta]x\)\), \
\(\(-\(2\/\[CapitalDelta]x\^2\)\) + u\_o[2]\), \(1\/\[CapitalDelta]x\^2 + 
                u\_1[2]\/\(2\ \[CapitalDelta]x\)\)},
            {"0", 
              "0", \(1\/\[CapitalDelta]x\^2 - 
                u\_1[3]\/\(2\ \[CapitalDelta]x\)\), \
\(\(-\(2\/\[CapitalDelta]x\^2\)\) + u\_o[3]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell["\<\
While the middle rows are correct, the first and last rows must be \
changed to provide the right boundary conditions:\
\>", "Text"],

Cell[BoxData[{
    \(L[\([1, 1]\)]\  = \ 1; \ L[\([1, 2]\)] = 0;\), "\n", 
    \(L[\([M + 1, M + 1]\)] = \ 1; \ L[\([M + 1, M]\)] = 0;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.98"],

Cell["Now the matrix takes the form", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[L]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.99"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0"},
            {\(1\/\[CapitalDelta]x\^2 - 
                u\_1[1]\/\(2\ \[CapitalDelta]x\)\), \
\(\(-\(2\/\[CapitalDelta]x\^2\)\) + u\_o[1]\), \(1\/\[CapitalDelta]x\^2 + 
                u\_1[1]\/\(2\ \[CapitalDelta]x\)\), "0"},
            {
              "0", \(1\/\[CapitalDelta]x\^2 - 
                u\_1[2]\/\(2\ \[CapitalDelta]x\)\), \
\(\(-\(2\/\[CapitalDelta]x\^2\)\) + u\_o[2]\), \(1\/\[CapitalDelta]x\^2 + 
                u\_1[2]\/\(2\ \[CapitalDelta]x\)\)},
            {"0", "0", "0", "1"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "When this matrix is used in Eq. ",
  ButtonBox["(2.4.47)",
    ButtonData:>"(2.4.47)",
    ButtonStyle->"Hyperlink"],
  "  together with Eq. ",
  ButtonBox["(2.4.48)",
    ButtonData:>"(2.4.48)",
    ButtonStyle->"Hyperlink"],
  ", the first and last equations now provide the correct boundary \
conditions, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x\_o) = 
        V\_a, \ \ \[Phi](x\_M) = \(\(V\_b\)\(.\)\)\)]],
  " "
}], "Text"],

Cell[TextData[{
  "\tThese boundary conditions are contained in the discretized forcing \
function ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontWeight->"Bold"], TraditionalForm]]],
  ". One can also write the boundary conditions directly into the forcing \
function of the undiscretized ODE using \[Delta]-functions, in analogy to Eq. \
(",
  ButtonBox["2.4.24",
    ButtonData:>"(2.4.24)",
    ButtonStyle->"Hyperlink"],
  "):"
}], "Text",
  CellTags->"i:76"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\^2\), \(\[DifferentialD]x\^2\),
                MultilineFunction->None], "\[Phi]"}], "+", 
            RowBox[{\(\(u\_1\)(x)\), 
              FractionBox["\[DifferentialD]", \(\[DifferentialD]x\),
                MultilineFunction->None], " ", "\[Phi]"}], 
            "+", \(\(\(u\_o\)(x)\) \[Phi]\)}], " ", 
          "=", \(\[Rho](
              x) + \(V\_a\) \(\(\[Delta]\^\[Prime]\)(
                x - a)\) - \(V\_b\) \(\(\[Delta]\^\[Prime]\)(x - b)\)\)}], 
        TraditionalForm]]],
  ","
}], "NE4",
  CellTags->"(2.4.50)"],

Cell[TextData[{
  "with homogeneous boundary conditions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", " ", "=", 
          RowBox[{\(0\ for\ x\), "<", \(a\ and\ x\), "<", 
            RowBox[{"b", ".", Cell[""]}]}]}], TraditionalForm]]],
  " The proof that this is equivalent to Eqs. ",
  ButtonBox["(2.4.39)",
    ButtonData:>"(2.4.39)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.40)",
    ButtonData:>"(2.4.40)",
    ButtonStyle->"Hyperlink"],
  " is left as an exercise. The full solution, satisfying the nonzero \
boundary conditions, is then determined by applying the Green's function to \
the new forcing function using Eq. ",
  ButtonBox["(2.4.30)",
    ButtonData:>"(2.4.30)",
    ButtonStyle->"Hyperlink"],
  ". Again, we see that there is no real difference between homogeneous \
solutions to the ODE and inhomogeneous solutions: both can be written in \
terms of the Green's function. In fact, a general homogeneous solution can be \
determined directly in terms of the Green's function by applying Eqs(2.4.37) \
and ",
  ButtonBox["(2.3.42)",
    ButtonData:>"(2.3.42)",
    ButtonStyle->"Hyperlink"],
  " to the forcing function in Eq. ",
  ButtonBox["(2.4.50)",
    ButtonData:>"(2.4.50)",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = 0\)]],
  ". The result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Phi]\_h\)(x)\), "=", 
          
          RowBox[{\(\(-V\_a\) \(\[DifferentialD]\/\[DifferentialD]x\_o\) \(G(
                x, x\_o)\)\), 
            SubscriptBox[
              StyleBox["|",
                FontSize->14], \(x\_o = 
                a\)], \(\(+V\_b\) \(\[DifferentialD]\/\[DifferentialD]x\_o\) \
\(G(x, x\_o)\)\), 
            SubscriptBox[
              StyleBox["|",
                FontSize->14], \(x\_o = b\)]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(2.4.51)"],

Cell[TextData[{
  "One can see now why we have spent so much time discussing the particular \
solutions to ODEs as opposed to the homogeneous solutions: there is really no \
difference between them. Both types of solutions can be determined using the \
Green's function method. ",
  StyleBox["Boundary or initial conditions are just another type of forcing, \
concentrated at the edges of the domain.",
    FontSlant->"Italic"],
  " In later chapters we will often use this idea, or variations of it, to \
determine homogeneous solutions to boundary and initial-value problems."
}], "Text",
  CellTags->"i:77"],

Cell[TextData[{
  "\tNow that we have the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", we can solve  the boundary-value problem ",
  ButtonBox["(2.4.47)",
    ButtonData:>"(2.4.47)",
    ButtonStyle->"Hyperlink"],
  " in a single step by matrix inversion:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Phi]",
            FontWeight->"Bold"], "=", 
          RowBox[{
            SuperscriptBox[
              StyleBox["L",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(-1\)], "\[CenterDot]", 
            StyleBox["\[Rho]",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  "."
}], "NE4",
  CellTags->"(2.4.52)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(2.4.52)",
    ButtonData:>"(2.4.52)",
    ButtonStyle->"Hyperlink"],
  "  a very elegant numerical solution to the general linear ",
  "boundary-value",
  " problem. It is somewhat analogous to finding the Green's function and \
applying Eq. ",
  ButtonBox["(2.4.37)",
    ButtonData:>"(2.4.37)",
    ButtonStyle->"Hyperlink"],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  ", obtaining  the particular solution that equals zero on the boundaries.  \
However, in the Green's function method one must then add in a homogeneous \
solution to include the nonzero boundary conditions; but this is not \
necessary in Eq. ",
  ButtonBox["(2.4.52)",
    ButtonData:>"(2.4.52)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:78"],

Cell[TextData[{
  "\tA closer analytic analogy to Eq. ",
  ButtonBox["(2.4.52)",
    ButtonData:>"(2.4.52)",
    ButtonStyle->"Hyperlink"],
  "  is the application of Eq. ",
  ButtonBox["(2.4.37)",
    ButtonData:>"(2.4.37)",
    ButtonStyle->"Hyperlink"],
  "  to the forcing function of Eq. ",
  ButtonBox["(2.4.50)",
    ButtonData:>"(2.4.50)",
    ButtonStyle->"Hyperlink"],
  ", which also has the nonzero boundary conditions built into the forcing \
function."
}], "Text"],

Cell[TextData[{
  "\t The matrix-inversion method has several distinct advantages compared to \
the shooting method discussed in Sec. ",
  ButtonBox["1.5",
    ButtonData:>{"Chapter1.nb", "c:29"},
    ButtonStyle->"Hyperlink"],
  ", where initial guesses had to be made (which might be poor) and where the \
ODE had to be solved many times in order to converge to the correct boundary \
conditions. However, there are also several drawbacks to the matrix \[Dash] \
inversion technique for boundary-value problems. First, the method works only \
for linear boundary-value problems, whereas the shooting method works for any \
boundary-value problem. Second, the matrix form of the operator",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(L\&^\)\)\)]],
  " can be quite complicated, particularly for high-order ODEs. Third, matrix \
inversion is a computationally time-consuming operation, although very fast \
codes that can be run on mainframes do exist. Using ",
  StyleBox["Mathematica,",
    FontSlant->"Italic"],
  "  the matrix inverse of a general 700-by-700 matrix takes roughly half a \
minute on a reasonably fast PC (as of summer 2001). This is fast enough for \
many problems. Furthermore, there are specialized methods of taking the \
inverse that rely on the fact that only terms near the diagonal of ",
  Cell[BoxData[
      FormBox[
        StyleBox["L",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " are nonzero (the matrix is ",
  StyleBox["sparse",
    FontSlant->"Italic"],
  "). These methods are already built into ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", and will not be discussed in detail here. "
}], "Text"],

Cell[TextData[{
  "\tThere is another  important point to make concerning the matrix-inverse \
solution provided by Eq. ",
  ButtonBox["(2.4.52)",
    ButtonData:>"(2.4.52)",
    ButtonStyle->"Hyperlink"],
  ". We know that for reasonable ",
  StyleBox["initial-value ",
    FontSlant->"Italic"],
  "problems, (\"reasonable\" in the sense of ",
  ButtonBox["Theorem 1.1",
    ButtonData:>"(1.2.1)",
    ButtonStyle->"Hyperlink"],
  ") a solution always exists and is unique . On the other hand, we know from \
Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", None},
    ButtonStyle->"Hyperlink"],
  " that for ",
  StyleBox["boundary-value ",
    FontSlant->"Italic"],
  "problems the solution need not exist, and need not be unique. However,  we \
have now seen that the solutions to both initial-value and boundary-value \
problems consist of inverting a matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  " and acting on a vector (called  ",
  StyleBox["\[Rho] ",
    FontWeight->"Bold"],
  "for our boundary-value problem",
  StyleBox[", ",
    FontWeight->"Bold"],
  "and",
  StyleBox[" f ",
    FontWeight->"Bold"],
  "for the  initial-value problem of Sec. ",
  ButtonBox["2.4.3",
    ButtonData:>"c:46",
    ButtonStyle->"Hyperlink"],
  ").",
  StyleBox[" ",
    FontWeight->"Bold"],
  " There seems to be no obvious difference between the solutions of initial- \
 and boundary-value problems when they are written in the form of a matrix \
equation. Why is one case solvable and the other not (necessarily)? The \
answer lies in the form of the matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  " for each case. For boundary-value problems  the changes that we have to \
make to the first and last few rows of ",
  StyleBox["L",
    FontWeight->"Bold"],
  ",",
  StyleBox[" ",
    FontWeight->"Bold"],
  "required in order to satisfy the boundary conditions, can lead (for \
certain parameter choices) to the matrix having a zero determinant. In this \
event the matrix inverse does not exist (see Sec. ",
  ButtonBox["9.5.2",
    ButtonData:>{"Chapter9.nb", "c:18"},
    ButtonStyle->"Hyperlink"],
  "), and the solution, if any, cannot be written in the form of Eq. ",
  ButtonBox["(2.4.52)",
    ButtonData:>"(2.4.52)",
    ButtonStyle->"Hyperlink"],
  ". For examples of how this can happen, see Exercises (10)(e) and (f)."
}], "Text",
  CellTags->"i:79"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Section",
  CellTags->"c:50"],

Cell[TextData[{
  "As an example of the matrix-inversion method, let's solve for the \
potential between two conducting spheres, with radii ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{"1", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"b", "=", 
          RowBox[{"2", 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " respectively. The inner sphere is at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(V\_a\)\(=\)\),
            "TraditionalForm"], " ", "5000", " ", 
          StyleBox["V",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", and the outer sphere is grounded, ",
  Cell[BoxData[
      \(TraditionalForm\`V\_b = 0\)]],
  ". Between the spheres is a uniform charge density of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Rho]0\  = \ 10\^\(-6\)\),
            "TraditionalForm"], " ", 
          RowBox[{
            StyleBox["C",
              FontSlant->"Plain"], "/", 
            FormBox[
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "3"],
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". The potential satisfies the 1D Poisson equation"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[PartialD]\^2\), \(\[PartialD]r\^2\),
                MultilineFunction->None], "\[Phi]"}], "+", 
            RowBox[{\(2\/r\), " ", 
              FractionBox["\[PartialD]", \(\[PartialD]r\),
                MultilineFunction->None], "\[Phi]"}]}], 
          "=", \(-\(\[Rho]\_0\/\[Epsilon]\_o\)\)}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "so we take ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(r) = 2\/r\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_0\)(r)\  = \ 0\)]],
  " in Eq. ",
  ButtonBox["(2.4.45)",
    ButtonData:>"(2.4.45)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThe following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " code will solve this problem, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  " grid points. First, we define the grid ",
  Cell[BoxData[
      \(TraditionalForm\`r\_n\)]],
  " and set up the functions  ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_o\)(r)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(u\_1\)(r)\)]],
  " on the grid:"
}], "Text"],

Cell[BoxData[{
    \(a\  = \ 1; \ b\  = \ 2; \ M = 40;\), "\n", 
    \(\(\[CapitalDelta]x = \ \((b - a)\)/M\ ;\)\), "\n", 
    \(\(r[n_]\ \  = \ a\  + \ n\ \[CapitalDelta]x;\)\), "\n", 
    \(\(u\_o[n_]\  = \ 0;\)\), "\n", 
    \(\(u\_1[n_]\  = \ 2/r[n];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.100"],

Cell[TextData[{
  "We then reconstruct the matrix ",
  StyleBox["L",
    FontWeight->"Bold"],
  ",",
  " now using the full 41 by 41 form:"
}], "Text"],

Cell[BoxData[{
    \(\(\(L\  = \ 
        Table[KroneckerDelta[n, m] \((u\_o[n] - 2/\[CapitalDelta]x^2)\)\  + \ 
            KroneckerDelta[n + 1, 
                m] \((1/\[CapitalDelta]x^2 + \ 
                  u\_1[n]/\((2\ \[CapitalDelta]x)\))\)\  + \ 
            KroneckerDelta[n - 1, 
                m] \((1/\[CapitalDelta]x^2\  - \ 
                  u\_1[n]/\((2  \[CapitalDelta]x)\))\), {n, 0, M}, {m, 0, 
            M}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(L[\([1, 1]\)]\  = \ 1; \ L[\([1, 2]\)] = 0;\), "\n", 
    \(L[\([M + 1, M + 1]\)] = \ 1; L[\([M + 1, M]\)] = 0;\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.101"],

Cell[TextData[{
  "Next, we set up the vector ",
  StyleBox["\[Rho]",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\[Epsilon]\_o = \ 8.85\ 10^\(-12\); V\_a = \ 5000; \ 
    V\_b = \ 0; \ \[Rho]0 = 10^\(-6\);\), "\n", 
    \(\(\[Rho] = \ Table[\(-\[Rho]0\)/\[Epsilon]\_o, {n, 0, M}];\)\), "\n", 
    \(\(\[Rho][\([1]\)] = V\_a;\)\), "\n", 
    \(\(\[Rho][\([M + 1]\)] = V\_b;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.102"],

Cell["\<\
Finally, the electrostatic potential is determined by matrix \
inversion:\
\>", "Text"],

Cell[BoxData[
    \(\(\[Phi]\  = \ Inverse[L] . \[Rho];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.103"],

Cell[TextData[{
  "It may be easily verified (using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", for example)  that the exact solution  for the potential is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r) = \(-5000\) + 
          10000\/r + \(7\ \[Rho]\_o\)\/\(6\ \[Epsilon]\_o\) - \[Rho]\_o\/\(r\ \
\[Epsilon]\_o\) - \(r\^2\ \[Rho]\_o\)\/\(6\ \[Epsilon]\_o\)\)]],
  " (in SI units).  We compare the exact result with the numerical solution \
in Cell ",
  ButtonBox["2.104",
    ButtonData:>"Cell 2.104",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(sol\  = \ Table[{r[n], \[Phi][\([n + 1]\)]}, {n, 0, M}];\)\), "\n", 
    \(\(p1\  = \ 
        ListPlot[sol, \ DisplayFunction \[Rule] \ Identity];\)\), "\n", 
    \(\(\[Phi]exact[r_]\  = \ \(-5000\) + 
          10000\/r + \(7\ \[Rho]0\)\/\(6\ \[Epsilon]\_o\) - \[Rho]0\/\(r\ \
\[Epsilon]\_o\) - \(r\^2\ \[Rho]0\)\/\(6\ \[Epsilon]\_o\);\)\), "\n", 
    \(\(p2\  = \ 
        Plot[\[Phi]exact[r], {r, 1, 2}, 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction, \ 
        PlotLabel \[Rule] "\<electrostatic potential between two charged \
spheres\>", AxesLabel \[Rule] {"\<r\>", "\< \>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 2.104"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.928571 0.952381 0.0147151 3.60046e-05 [
[.21429 .00222 -9 -9 ]
[.21429 .00222 9 0 ]
[.40476 .00222 -9 -9 ]
[.40476 .00222 9 0 ]
[.59524 .00222 -9 -9 ]
[.59524 .00222 9 0 ]
[.78571 .00222 -9 -9 ]
[.78571 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .10473 -24 -4.5 ]
[.01131 .10473 0 4.5 ]
[.01131 .19474 -24 -4.5 ]
[.01131 .19474 0 4.5 ]
[.01131 .28475 -24 -4.5 ]
[.01131 .28475 0 4.5 ]
[.01131 .37476 -30 -4.5 ]
[.01131 .37476 0 4.5 ]
[.01131 .46477 -30 -4.5 ]
[.01131 .46477 0 4.5 ]
[.01131 .55478 -30 -4.5 ]
[.01131 .55478 0 4.5 ]
[.02381 .64303 -5 0 ]
[.02381 .64303 5 12 ]
[.5 .63053 -155 0 ]
[.5 .63053 155 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.21429 .01472 m
.21429 .02097 L
s
[(1.2)] .21429 .00222 0 1 Mshowa
.40476 .01472 m
.40476 .02097 L
s
[(1.4)] .40476 .00222 0 1 Mshowa
.59524 .01472 m
.59524 .02097 L
s
[(1.6)] .59524 .00222 0 1 Mshowa
.78571 .01472 m
.78571 .02097 L
s
[(1.8)] .78571 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10473 m
.03006 .10473 L
s
[(2500)] .01131 .10473 1 0 Mshowa
.02381 .19474 m
.03006 .19474 L
s
[(5000)] .01131 .19474 1 0 Mshowa
.02381 .28475 m
.03006 .28475 L
s
[(7500)] .01131 .28475 1 0 Mshowa
.02381 .37476 m
.03006 .37476 L
s
[(10000)] .01131 .37476 1 0 Mshowa
.02381 .46477 m
.03006 .46477 L
s
[(12500)] .01131 .46477 1 0 Mshowa
.02381 .55478 m
.03006 .55478 L
s
[(15000)] .01131 .55478 1 0 Mshowa
.125 Mabswid
.02381 .03272 m
.02756 .03272 L
s
.02381 .05072 m
.02756 .05072 L
s
.02381 .06872 m
.02756 .06872 L
s
.02381 .08672 m
.02756 .08672 L
s
.02381 .12273 m
.02756 .12273 L
s
.02381 .14073 m
.02756 .14073 L
s
.02381 .15873 m
.02756 .15873 L
s
.02381 .17674 m
.02756 .17674 L
s
.02381 .21274 m
.02756 .21274 L
s
.02381 .23074 m
.02756 .23074 L
s
.02381 .24875 m
.02756 .24875 L
s
.02381 .26675 m
.02756 .26675 L
s
.02381 .30275 m
.02756 .30275 L
s
.02381 .32075 m
.02756 .32075 L
s
.02381 .33876 m
.02756 .33876 L
s
.02381 .35676 m
.02756 .35676 L
s
.02381 .39276 m
.02756 .39276 L
s
.02381 .41077 m
.02756 .41077 L
s
.02381 .42877 m
.02756 .42877 L
s
.02381 .44677 m
.02756 .44677 L
s
.02381 .48278 m
.02756 .48278 L
s
.02381 .50078 m
.02756 .50078 L
s
.02381 .51878 m
.02756 .51878 L
s
.02381 .53678 m
.02756 .53678 L
s
.02381 .57279 m
.02756 .57279 L
s
.02381 .59079 m
.02756 .59079 L
s
.02381 .60879 m
.02756 .60879 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -216 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(electrostatic) show
147.000 13.000 moveto
(potential) show
207.000 13.000 moveto
(between) show
255.000 13.000 moveto
(two) show
279.000 13.000 moveto
(charged) show
327.000 13.000 moveto
(spheres) show
369.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.008 w
.02381 .19474 Mdot
.04762 .25086 Mdot
.07143 .30182 Mdot
.09524 .34793 Mdot
.11905 .38946 Mdot
.14286 .42666 Mdot
.16667 .45975 Mdot
.19048 .48895 Mdot
.21429 .51444 Mdot
.2381 .5364 Mdot
.2619 .55499 Mdot
.28571 .57035 Mdot
.30952 .58264 Mdot
.33333 .59196 Mdot
.35714 .59844 Mdot
.38095 .60219 Mdot
.40476 .60331 Mdot
.42857 .6019 Mdot
.45238 .59803 Mdot
.47619 .59179 Mdot
.5 .58326 Mdot
.52381 .57251 Mdot
.54762 .55961 Mdot
.57143 .54461 Mdot
.59524 .52758 Mdot
.61905 .50857 Mdot
.64286 .48763 Mdot
.66667 .46481 Mdot
.69048 .44015 Mdot
.71429 .41371 Mdot
.7381 .38551 Mdot
.7619 .35561 Mdot
.78571 .32402 Mdot
.80952 .29079 Mdot
.83333 .25596 Mdot
.85714 .21954 Mdot
.88095 .18157 Mdot
.90476 .14208 Mdot
.92857 .10109 Mdot
.95238 .05863 Mdot
.97619 .01472 Mdot
.5 Mabswid
.02381 .19474 m
.06244 .28318 L
.10458 .36476 L
.14415 .42856 L
.18221 .47924 L
.22272 .52261 L
.26171 .55485 L
.28158 .56791 L
.30316 .57965 L
.32216 .58794 L
.33296 .59184 L
.34309 .59495 L
.35344 .59762 L
.36292 .5996 L
.37305 .60125 L
.37864 .60195 L
.38395 .60248 L
.38898 .60286 L
.39135 .603 L
.39354 .60311 L
.39607 .6032 L
.3974 .60324 L
.3988 .60327 L
.40002 .6033 L
.40116 .60331 L
.40242 .60332 L
.40312 .60332 L
.40376 .60332 L
.4049 .60331 L
.40611 .6033 L
.40714 .60328 L
.40828 .60326 L
.41082 .60319 L
.4132 .6031 L
.4175 .60286 L
.42214 .60252 L
.43172 .60152 L
.44219 .59998 L
.45312 .59787 L
.46328 .59546 L
.50233 .58231 L
.52368 .57258 L
.54383 .5618 L
.58229 .53709 L
.62321 .50504 L
.66262 .46882 L
.7005 .42923 L
.74084 .38215 L
.77967 .3322 L
.82094 .27428 L
Mistroke
.8607 .21396 L
.89895 .15186 L
.93965 .08152 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{388.688, 240.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007U0001;2000`400?l00000o`00003ooooooooV
ooooo`00oooooooVooooo`00Loooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
0000?Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool0>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`0?Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`0AOooool5o`00027ooooo001eooooo`03o`000?oooooooooo00Cooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@0?oooool00ol0003oooooooooo`04ooooo`;o8B4Q1oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B40?oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q04Gooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`00MOooool00ol0003ooooo
ooooo`0;ooooo`03oiRHV?lQ8B7ok^k^043ooooo00?o0000ooooooooool02_ooool5o`0003oooooo
00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000003oooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000004Kooooo00?oV9RHob4Q8Oo^k^h08_ooool007Go
oooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP0oooooo`03o`000?oooooooooo00[o
oooo00CoA4A4omgMgOoooooo0000@?ooool00ol0003oooooooooo`0:ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B40?oooool00ol0003oooooooooo`0:ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80Aooo
ool00onHV9So8B4Qonk^kP0Qooooo`00MOooool00ol0003oooooooooo`0=ooooo`03ogMgMomVIVKo
oooo03kooooo00?o0000ooooooooool02_ooool01?oMgMgoEEEEooooool00010ooooo`03o`000?oo
oooooooo00[ooooo00Go0000oeEEEOl0003o410@olc<c00oooooo`03o`000?oooooooooo00[ooooo
00Goc<c<o`000?l0003o0000olc<c018ooooo`03ogMgMomVIVKooooo023ooooo001eooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0;ooooo`03ogMg
Moo<c<co0000043ooooo00?o0000ooooooooool02_ooool00omEEEGoQhN7ooooo`11ooooo`03o`00
0?oooooooooo00[ooooo00Go410@okZj^_oooooo^[Zjoa0@4019ooooo`03o`000?oooooooooo01oo
oooo001eooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400oooooo`03
o`000?oooooooooo00_ooooo00?ok^k^odA4A?l00000@?ooool00ol0003oooooooooo`0:ooooo`03
omgMgOl@413oV9RH047ooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o0000
04Gooooo00Go0000okZj^_ooooooV9RHoa0@400Qooooo`00Loooool00omEEEGoIVIVo`00000<oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`0?Oooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003o
oooo03gooooo00?oEEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@410mooooo`03oeEEEOmV
IVKo000000cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@15ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`08Oooool002cooooo00?o0000ooooooooool0oooooongooooo`00;?ooool00ol0003ooooooooo
o`3ooooookOooooo000/ooooo`03o`000?oooooooooo0?oooooo]oooool002cooooo00?o0000oooo
ooooool0oooooongooooo`00;?ooool00ol0003oooooooooo`3ooooooj_ooooo00?o410@o`000?l0
00000ol00006ooooo`00;?ooool00ol0003oooooooooo`3oooooojgooooo00?o0000ooooooooool0
1oooool002cooooo00?o0000ooooooooool0oooooonBooooo`?o00006?ooool00ol0003ooooooooo
o`07ooooo`008_ooooooo`000:co00003_ooool00ol0003oooooooooo`07ooooo`00;?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo0ol0000Hooooo`03o`000?lb<S;ogMgM
00Oooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0C_ooool2o`0001Oo
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B45ooooo`00;?ooool00ol0003oooooooooo`3ooooooi?o
oooo00?o0000ooooooooool08Oooool002cooooo00?o0000ooooooooool0oooooonBooooo`03o`00
0?oooooooooo02;ooooo000/ooooo`03o`000?oooooooooo0?ooooooTOooool00ol0003ooooooooo
o`0Sooooo`00;?ooool00ol0003oooooooooo`3ooooooi7ooooo00?o0000ooooooooool08oooool0
02cooooo0_l0003ooooooi7ooooo00?o0000ooooooooool09?ooool002cooooo00?o0000oooooooo
ool0oooooon@ooooo`03o`000?oooooooooo02Cooooo000/ooooo`03o`000?oooooooooo0?oooooo
Soooool00ol0003oooooooooo`0Uooooo`00;?ooool00ol0003oooooooooo`3oooooohoooooo00?o
0000ooooooooool09Oooool002cooooo00?o0000ooooooooool0oooooon>ooooo`03o`000?oooooo
oooo02Kooooo000/ooooo`03o`000?oooooooooo0?ooooooSOooool00ol0003oooooooooo`0Woooo
o`00;?ooool00ol0003oooooooooo`3oooooohgooooo00?o0000ooooooooool09oooool002cooooo
00?o0000ooooooooool0oooooon<ooooo`03o`000?oooooooooo02Sooooo000/ooooo`;o0000oooo
oon=ooooo`03o`000?oooooooooo02Sooooo000/ooooo`03o`000?oooooooooo0?ooooooRoooool0
0ol0003oooooooooo`0Yooooo`00;?ooool00ol0003oooooooooo`3ooooooh_ooooo00?o0000oooo
ooooool0:Oooool002cooooo00?o0000ooooooooool0oooooon8ooooo`?o0000;?ooool002cooooo
00?o0000ooooooooool0oooooon8ooooo`?o0000;?ooool002cooooo00?o0000ooooooooool0oooo
oon8ooooo`?o0000;?ooool002cooooo00?o0000ooooooooool0oooooon8ooooo`03o`000?oooooo
oooo02cooooo000/ooooo`03o`000?oooooooooo0?ooooooR?ooool00ol0003oooooooooo`0/oooo
o`00;?ooool2o`000?ooooooR?ooool00ol0003oooooooooo`0]ooooo`00;?ooool00ol0003ooooo
ooooo`3oooooohOooooo00?o0000ooooooooool0;Oooool002cooooo00?o0000ooooooooool0oooo
oon6ooooo`03o`000?oooooooooo02kooooo000/ooooo`03o`000?oooooooooo0?ooooooQOooool0
0ol0003oooooooooo`0_ooooo`00;?ooool00ol0003oooooooooo`3oooooohGooooo00?o0000oooo
ooooool0;oooool002cooooo00?o0000ooooooooool0oooooon4ooooo`03o`000?oooooooooo033o
oooo000/ooooo`03o`000?oooooooooo0?ooooooQ?ooool00ol0003oooooooooo`0`ooooo`00;?oo
ool2o`000?ooooooQ?ooool00ol0003oooooooooo`0aooooo`00;?ooool00ol0003oooooooooo`3o
oooooh?ooooo00?o0000ooooooooool0<Oooool002cooooo00?o0000ooooooooool0oooooon2oooo
o`03o`000?oooooooooo03;ooooo000/ooooo`03o`000?oooooooooo0?ooooooPOooool00ol0003o
ooooooooo`0cooooo`00;?ooool00ol0003oooooooooo`3ooooooh7ooooo00?o0000ooooooooool0
<oooool002cooooo00?o0000ooooooooool0oooooon0ooooo`03o`000?oooooooooo03Cooooo0007
ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`3oooooogko
oooo0ol0000fooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00WoMgMgoc8b<_oo
ooooooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool0oooooomnooooo`?o0000=_ooool000Sooooo00?oV9RHob4Q8Oo^k^h02Ooo
ool01?l0003oooooooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`06ooooo`?o0000oooooomnooooo`?o0000=_ooool000Wooooo00?oV9RHob4Q8Oo^k^h0
1oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooomnooooo`03o`000?oooooooooo
03Kooooo000:ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool0oooooommooooo`03o`000?oooooooooo03Oooooo000;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo0?ooooooOOooool00ol0003ooooo
ooooo`0gooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`03o`000?oooooooooo0?ooooooO?ooool00ol0003oooooooooo`0hooooo`001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0oooooomlooooo`03o`000?oo
oooooooo03Sooooo000/ooooo`03o`000?oooooooooo0?ooooooNoooool00ol0003oooooooooo`0i
ooooo`00;?ooool00ol0003oooooooooo`3oooooog_ooooo00?o0000ooooooooool0>Oooool002co
oooo0_l0003oooooog_ooooo00?o0000ooooooooool0>_ooool002cooooo00?o0000ooooooooool0
oooooomjooooo`03o`000?oooooooooo03[ooooo000/ooooo`03o`000?oooooooooo0?ooooooNOoo
ool00ol0003oooooooooo`0kooooo`00;?ooool00ol0003oooooooooo`3oooooogSooooo00?o0000
ooooooooool0??ooool002cooooo00?o0000ooooooooool0oooooomhooooo`03o`000?oooooooooo
03cooooo000/ooooo`03o`000?oooooooooo0?ooooooMoooool00ol0003oooooooooo`0mooooo`00
;?ooool00ol0003oooooooooo`3oooooogOooooo00?o0000ooooooooool0?Oooool002cooooo0_l0
003oooooogGooooo0ol00010ooooo`00;?ooool00ol0003oooooooooo`3oooooogCooooo0ol00010
ooooo`00;?ooool00ol0003oooooooooo`3oooooogCooooo0ol00010ooooo`00;?ooool00ol0003o
ooooooooo`3oooooogCooooo00?o0000ooooooooool0@?ooool002cooooo00?o0000ooooooooool0
oooooomdooooo`03o`000?oooooooooo043ooooo000/ooooo`03o`000?oooooooooo0?ooooooLooo
ool00ol0003oooooooooo`11ooooo`00;?ooool00ol0003oooooooooo`3oooooog?ooooo00?o0000
ooooooooool0@Oooool002cooooo00?o0000ooooooooool0oooooombooooo`03o`000?oooooooooo
04;ooooo000/ooooo`;o0000oooooombooooo`03o`000?oooooooooo04?ooooo000/ooooo`03o`00
0?oooooooooo0?ooooooLOooool00ol0003oooooooooo`13ooooo`00;?ooool00ol0003ooooooooo
o`3oooooog3ooooo00?o0000ooooooooool0A?ooool002cooooo00?o0000ooooooooool0oooooom`
ooooo`03o`000?oooooooooo04Cooooo000/ooooo`03o`000?oooooooooo0?ooooooKoooool00ol0
003oooooooooo`15ooooo`00;?ooool00ol0003oooooooooo`3oooooofkooooo00?o0000oooooooo
ool0A_ooool002cooooo00?o0000ooooooooool0oooooom^ooooo`03o`000?oooooooooo04Kooooo
000/ooooo`03o`000?oooooooooo0?ooooooKOooool00ol0003oooooooooo`17ooooo`00;?ooool2
o`000?ooooooKOooool00ol0003oooooooooo`18ooooo`00;?ooool00ol0003oooooooooo`3ooooo
of[ooooo0ol0001:ooooo`00;?ooool00ol0003oooooooooo`3oooooof[ooooo0ol0001:ooooo`00
;?ooool00ol0003oooooooooo`3oooooof[ooooo0ol0001:ooooo`00;?ooool00ol0003ooooooooo
o`3oooooof[ooooo00?o0000ooooooooool0B_ooool000Sooooo00GoA4A4o`000?l0003o<S8bomgM
g@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo0?ooooooJOooool00ol0
003oooooooooo`1;ooooo`002oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool0oooooomYooooo`03o`000?oooooooooo04_ooooo000<ooooo`04o`00
0?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`05ooooo`Co0000oooooomXooooo`03o`000?oooooo
oooo04cooooo000;ooooo`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo
0ol0003oooooofSooooo00?o0000ooooooooool0COooool000Sooooo00Go0000ob4Q8Ol0003o<S8b
olc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000007ooooo`?o0000oooooomXooooo`03o`000?oooooo
oooo04gooooo0008ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo
0_l0003oooooofOooooo00?o0000ooooooooool0C_ooool000Sooooo00?o0000ooooooooool01?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`000?ooooooI_ooool00ol0003oooooooooo`1?oooo
o`002?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooool00000oooo
oomUooooo`03o`000?oooooooooo04oooooo000/ooooo`03o`000?oooooo00000?ooooooI?ooool0
0ol0003oooooooooo`1@ooooo`00;?ooool01?l0003oooooooooool0003oooooof?ooooo00?o0000
ooooooooool0D?ooool002cooooo0_l000000ooooooo0000ooooo`3oooooof7ooooo00?o0000oooo
ooooool0DOooool002cooooo00Go0000ooooooooooooooooo`00003oooooof3ooooo00?o0000oooo
ooooool0D_ooool002cooooo00Go0000ooooooooooooooooo`00003ooooooekooooo0ol0001Doooo
o`00;?ooool01Ol0003ooooooooooooooooo00000?ooooooG_ooool3o`0005Cooooo000/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooomKooooo`?o0000E?ooool002cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooe_ooooo00?o0000ooooooooool0
E?ooool002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooeWooooo00?o
0000ooooooooool0EOooool002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
oooooeSooooo00?o0000ooooooooool0E_ooool002cooooo0_l00005ooooo`03o`000?oooooooooo
0?ooooooEoooool00ol0003oooooooooo`1Fooooo`00;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooE_ooool00ol0003oooooooooo`1Gooooo`00;?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?ooooooEOooool00ol0003oooooooooo`1Hooooo`00;?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooE?ooool00ol0003ooooooooo
o`1Hooooo`00;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooDoooool0
0ol0003oooooooooo`1Iooooo`00;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?ooooooDOooool00ol0003oooooooooo`1Jooooo`00;?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0?ooooooD?ooool00ol0003oooooooooo`1Kooooo`00;?ooool2o`0000Oooooo
00?o0000ooooooooool0oooooom@ooooo`03o`000?oooooooooo05_ooooo000/ooooo`03o`000?oo
oooooooo00Kooooo0ol0003oooooodoooooo00?o0000ooooooooool0G?ooool002cooooo00?o0000
ooooooooool01_ooool3o`000?ooooooC_ooool00ol0003oooooooooo`1Mooooo`00;?ooool00ol0
003oooooooooo`06ooooo`?o0000oooooom=ooooo`?o0000G_ooool002cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3ooooood_ooooo0ol0001Nooooo`00;?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo0?ooooooBOooool4o`0005kooooo000/ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0oooooom9ooooo`03o`000?oooooooooo05oooooo000/
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooom8ooooo`03o`000?oooooo
oooo063ooooo000/ooooo`;o00002oooool00ol0003oooooooooo`3oooooodKooooo00?o0000oooo
ooooool0HOooool002cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooodKo
oooo00?o0000ooooooooool0HOooool002cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`3oooooodCooooo00?o0000ooooooooool0H_ooool002cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`3ooooood?ooooo00?o0000ooooooooool0Hoooool002cooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`3ooooood;ooooo00?o0000ooooooooool0Hoooool0
00Wooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0?oooooo@Oooool00ol0003oooooooooo`1Tooooo`002Ooo
ool00omEEEGoZJVYooooo`07ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0oooooom0ooooo`03o`000?oooooooooo06Gooooo0009ooooo`03ojVYZOmEEEGooooo
00Sooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo?ooo
ool00ol0003oooooooooo`1Uooooo`002_ooool00olQ8B7oooooooooo`06ooooo`05ogMgMolb<S;o
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1_ooool3o`0000gooooo00?o0000ooooooooool0oooooolnooooo`03o`000?oooooooooo06Kooooo
000:ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`3ooooooccooooo00?o0000ooooooooool0Ioooool000[o
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`3ooooooc[ooooo0ol0001Yooooo`001oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
ooooooliooooo`?o0000JOooool000Oooooo1Ol00004ooooo`Co00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0ooooooliooooo`?o0000JOooool002cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`3oooooocSooooo00?o0000ooooooooool0JOooool002cooooo00?o
0000ooooooooool04?ooool3o`000?oooooo=oooool00ol0003oooooooooo`1Zooooo`00;?ooool2
o`00017ooooo0ol0003oooooocKooooo00?o0000ooooooooool0Joooool002cooooo00?o0000oooo
ooooool04?ooool3o`000?oooooo=Oooool00ol0003oooooooooo`1/ooooo`00;?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0?oooooo<oooool00ol0003oooooooooo`1/ooooo`00
;?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo<_ooool00ol0003ooooo
ooooo`1]ooooo`00;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo<?oo
ool00ol0003oooooooooo`1^ooooo`00;?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo0?oooooo<?ooool00ol0003oooooooooo`1^ooooo`00;?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0?oooooo;_ooool00ol0003oooooooooo`1_ooooo`00;?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo;Oooool00ol0003oooooooooo`1`ooooo`00
;?ooool2o`0001Kooooo00?o0000ooooooooool0ooooool/ooooo`03o`000?oooooooooo073ooooo
000/ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0oooooolYooooo`?o0000Looo
ool002cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3oooooobSooooo0ol0001c
ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo9oooool3o`00
07?ooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0oooooolWooooo`03
o`000?oooooooooo07?ooooo000/ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
oooooolUooooo`03o`000?oooooooooo07Cooooo000/ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0oooooolUooooo`03o`000?oooooooooo07Cooooo000/ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0oooooolSooooo`03o`000?oooooooooo07Gooooo000/oooo
o`;o00006_ooool00ol0003oooooooooo`3oooooob;ooooo00?o0000ooooooooool0M_ooool002co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3oooooob3ooooo00?o0000oooooooo
ool0Moooool002cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3ooooooaoooooo
00?o0000ooooooooool0N?ooool002cooooo00?o0000ooooooooool06_ooool3o`000?oooooo7ooo
ool00ol0003oooooooooo`1hooooo`00;?ooool00ol0003oooooooooo`0Jooooo`?o0000oooooolN
ooooo`03o`000?oooooooooo07Wooooo000/ooooo`03o`000?oooooooooo01[ooooo0ol0003ooooo
oagooooo00?o0000ooooooooool0N_ooool002cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`3ooooooaSooooo0ol0001mooooo`00;?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0?oooooo5oooool3o`0007gooooo000/ooooo`;o00007_ooool00ol0003ooooooooo
o`3ooooooaOooooo0ol0001mooooo`00;?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo0?oooooo5_ooool00ol0003oooooooooo`1mooooo`00;?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo0?oooooo5Oooool00ol0003oooooooooo`1nooooo`00;?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo4oooool00ol0003oooooooooo`1oooooo`00
;?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo4_ooool00ol0003ooooo
ooooo`20ooooo`001?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0?oooooo
4?ooool00ol0003oooooooooo`21ooooo`000_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo0?oooooo3oooool00ol0003oooooooooo`21ooooo`000_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41002?ooool3o`00027ooooo00?o0000ooooooooool0ooooool>ooooo`03o`000?oooooooooo08;o
oooo0002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0oooo
ool<ooooo`03o`000?oooooooooo08?ooooo0002ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0ooooool;ooooo`03o`000?oooooooooo08Cooooo0002ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4008ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0ooooool9ooooo`03o`00
0?oooooooooo08Gooooo0002ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0ooooool6ooooo`?o0000Qoooool00003oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0ooooool6ooooo`?o0000Qoooool002cooooo00?o0000ooooooooool0
9?ooool3o`000?oooooo1_ooool3o`0008Oooooo000/ooooo`03o`000?oooooooooo02Cooooo0ol0
003oooooo`Gooooo00?o0000ooooooooool0R?ooool002cooooo0_l0000Uooooo`?o0000ooooool4
ooooo`03o`000?oooooooooo08Wooooo000/ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0ooooool00ol0003oooooooooo`2:ooooo`00;?ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo0?gooooo00?o0000ooooooooool0Roooool002cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`3mooooo`03o`000?oooooooooo08_ooooo000/ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0noooool00ol0003oooooooooo`2<ooooo`00;?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo0?[ooooo00?o0000ooooooooool0SOooool0
02cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3hooooo`03o`000?oooooooooo
08kooooo000/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0m_ooool00ol0003o
ooooooooo`2?ooooo`00;?ooool2o`0002cooooo00?o0000ooooooooool0m?ooool3o`00097ooooo
000/ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0loooool3o`00097ooooo000/
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0l_ooool3o`00097ooooo000/oooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool0lOooool00ol0003oooooooooo`2Boooo
o`00;?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0>oooooo00?o0000oooooooo
ool0Toooool002cooooo00?o0000ooooooooool0;_ooool3o`000>kooooo00?o0000ooooooooool0
U?ooool002cooooo00?o0000ooooooooool0;_ooool3o`000>gooooo00?o0000ooooooooool0UOoo
ool002cooooo0_l0000_ooooo`?o0000k?ooool00ol0003oooooooooo`2Fooooo`00;?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo0>[ooooo00?o0000ooooooooool0U_ooool002co
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3Xooooo`03o`000?oooooooooo09Oo
oooo000/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0i_ooool00ol0003ooooo
ooooo`2Hooooo`00;?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0>;ooooo0ol0
002Kooooo`00;?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0>;ooooo0ol0002K
ooooo`00;?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0>7ooooo0ol0002Koooo
o`00;?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0=oooooo00?o0000oooooooo
ool0W?ooool002cooooo0_l0000fooooo`03o`000?oooooooooo0=kooooo00?o0000ooooooooool0
WOooool002cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`3Looooo`03o`000?oo
oooooooo09kooooo000/ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0f_ooool0
0ol0003oooooooooo`2Oooooo`00;?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
0=Sooooo00?o0000ooooooooool0X?ooool002cooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`3Gooooo`03o`000?oooooooooo0:7ooooo0004o`000003oa0@4?oooooooooo00Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0hooooo`?o0000e_ooool0
0ol0003oooooooooo`2Rooooo`000_ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0hooooo`?o0000eOooool00ol0
003oooooooooo`2Sooooo`000_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00Wo
oooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01_ooool00ol0003oooooooooo`0hooooo`Co0000d_ooool3o`000:Gooooo0002oooo
o`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo0ol0
000kooooo`03o`000?oooooooooo0=3ooooo0ol0002Uooooo`000_ooool00ol0003oooooooooo`05
ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`3=ooooo`Go0000YOooool000;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool0Z?ooool000;ooooo00?o0000oooooooo
ool00_ooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0b_ooool00ol0003oooooooooo`2Yooooo`0000?oEEEE
ofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo0:[ooooo000/ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`2[ooooo`00;?oo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo0<Cooooo00?o0000ooooooooool0[?oo
ool002cooooo0_l00012ooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0[Oooool0
02cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`2nooooo`?o0000/?ooool002co
oooo00?o0000ooooooooool0@oooool3o`000;gooooo0ol0002`ooooo`00;?ooool00ol0003ooooo
ooooo`13ooooo`?o0000_Oooool3o`000;3ooooo000/ooooo`03o`000?oooooooooo04?ooooo0ol0
002looooo`03o`000?oooooooooo0;7ooooo000/ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool0^?ooool00ol0003oooooooooo`2booooo`00;?ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo0;Kooooo00?o0000ooooooooool0/oooool002cooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo0;Cooooo000/ooooo`;o0000
B_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo0;Gooooo000/ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`2fooooo`00;?ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0:_ooooo1?l0002iooooo`00;?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo0:[ooooo0ol0002jooooo`00;?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo0:Wooooo0ol0002jooooo`00;?ooool00ol0003ooooo
ooooo`1=ooooo`?o0000Yoooool2o`000;gooooo000/ooooo`03o`000?oooooooooo04gooooo0ol0
002Vooooo`03o`000?oooooooooo0;gooooo000/ooooo`03o`000?oooooooooo04gooooo1?l0002T
ooooo`03o`000?oooooooooo0;kooooo000/ooooo`;o0000D_ooool00ol0003oooooooooo`2Ooooo
o`;o0000`Oooool002cooooo00?o0000ooooooooool0D_ooool2o`0009kooooo00?o0000oooooooo
ool0`Oooool002cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`2Hooooo`?o0000
a?ooool002cooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`2Gooooo`?o0000a?oo
ool002cooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`2Eooooo`Co0000a?ooool0
02cooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo
0<Kooooo000/ooooo`03o`000?oooooooooo05Oooooo0ol0002Booooo`03o`000?oooooooooo0<Oo
oooo000/ooooo`;o0000F?ooool3o`00093ooooo0_l0003:ooooo`00;?ooool00ol0003ooooooooo
o`1Gooooo`Go0000SOooool00ol0003oooooooooo`3:ooooo`00;?ooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo08Sooooo0_l0003=ooooo`00;?ooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo08Gooooo0ol0003>ooooo`00;?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo08?ooooo1?l0003>ooooo`001?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool0P?ooool2o`000004ooooool0003o0000o`000<kooooo0002ooooo`03
o`000?oooooooooo00Kooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`3Booooo`00
0_ooool00ol0003oooooooooo`07ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`06
ooooo`03o`000?oooooooooo067ooooo0ol0001kooooo`;o0000eOooool000;ooooo00?o0000oooo
ooooool01_ooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06ooooo`?o0000
HOooool3o`0007[ooooo00?o0000ooooooooool0eOooool000;ooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool0HOooool5o`0007Gooooo0ol0003Hooooo`000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
I_ooool2o`0007?ooooo0ol0003Hooooo`000_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0J?ooool00ol0
003oooooooooo`1^ooooo`Go0000f?ooool00003oeEEEOmVIVKo000000Gooooo1?l00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo06Wooooo0_l0001/ooooo`;o0000gOoo
ool002cooooo00?o0000ooooooooool0Joooool2o`0006Sooooo0_l0003Oooooo`00;?ooool00ol0
003oooooooooo`1[ooooo`Co0000I?ooool2o`000>7ooooo000/ooooo`03o`000?oooooooooo06_o
oooo0ol000000ooooooo0000o`00001Pooooo`?o0000h_ooool002cooooo0_l0001/ooooo`?o0000
0oooool00ol0003oooooooooo`1Kooooo`Go0000h_ooool002cooooo00?o0000ooooooooool0L_oo
ool2o`0005Wooooo0_l00002ooooo`?o0000h_ooool002cooooo00?o0000ooooooooool0M?ooool2
o`0005Kooooo00?o0000ooooooooool0ioooool002cooooo00?o0000ooooooooool0MOooool3o`00
04kooooo0ol000000ooooooo0000o`00003Zooooo`00;?ooool00ol0003oooooooooo`1eooooo`Go
0000C?ooool4o`000>cooooo000/ooooo`03o`000?oooooooooo07Gooooo0ol00002ooooo`;o0000
B?ooool5o`000>gooooo000/ooooo`03o`000?oooooooooo07cooooo0_l00012ooooo`Co0000l_oo
ool002cooooo0_l0001oooooo`Co0000>_ooool4o`000?Kooooo000/ooooo`03o`000?oooooooooo
07oooooo1Ol0000fooooo`Go0000moooool002cooooo00?o0000ooooooooool0Ooooool3o`0000;o
oooo1?l0000^ooooo`Co00000_ooool3o`000?Oooooo000/ooooo`03o`000?oooooooooo08Sooooo
1Ol0000Uooooo`Co0000ooooool1ooooo`00;?ooool00ol0003oooooooooo`2:ooooo`Oo00000ooo
ool3o`00017ooooo0ol00002ooooo`So0000ooooool2ooooo`00;?ooool00ol0003oooooooooo`2:
ooooo`?o00001?ooool:o`0000?ooooo0ol00002ooooo`[o00001Oooool3o`000?oooooo0_ooool0
02cooooo00?o0000ooooooooool0U?ooool3o`0000Cooooo2?l00005ooooo`?o0000ooooool<oooo
o`00;?ooool00ol0003oooooooooo`2Nooooo`?o0000oooooolFooooo`00;?ooool2o`000?oooooo
^?ooool002cooooo00?o0000ooooooooool0oooooongooooo`00;?ooool00ol0003oooooooooo`3o
oooookOooooo000/ooooo`03o`000?oooooooooo0?oooooo]oooool002cooooo00?o0000oooooooo
ool0oooooongooooo`00oooooooVooooo`00oooooooVooooo`00oooooooVooooo`00oooooooVoooo
o`00oooooooVooooo`00oooooooVooooo`00XOooool01?l@413o0000o`000?l00032ooooo`05ob4Q
8Ol0003o0000odA4A?oMgMd07_ooool01?l@413o0000o`000?l0001Gooooo`00X_ooool00ol0003o
ooooooooo`35ooooo`03ogMgMolb<S;ooooo01kooooo00?o0000ooooooooool0Eoooool00:;ooooo
00?o0000ooooooooool0a_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05Oooooo
000hooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool5o`0000?ooooo00Kok^k^oeEEEOl0
003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`00oooool01onHV9So0000o`00
0?m4A4Co^[Zjooooool@41001Ol00003ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`06
oiRHV?l0003o0000ogMgMol@413o00000oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo1Ol0
0003ooooo`05ofIVI_l0003o0000odA4A?o<c<`01?ooool02Ol0003oMgMgo`000?l0003oEEEEonk^
k_ooooook^k^oeEEE@02o`000003oeEEEOo^k^kooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj
^P02ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2o`00
0004oa0@4?oooooooooooiRHV0;o000000?oA4A4okZj^_ooool00_ooool5o`0000;ooooo00KoV9RH
o`000?l0003oMgMgoa0@4?l00002ooooo`Go00001_ooool00ol@413o0000ohN7Q`02o`000005ofIV
I_o^k^koooooonk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4
A?nj^[X00oooool01Ol0003oc<c<omgMgOl0003ok^k^00;ooooo00Kok^k^oeEEEOl0003o0000odA4
A?nj^[X2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`05o`000?o<
c<cogMgMo`000?o^k^h00_ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kPWooooo00GoIVIVo`00
0?l0003oA4A4olc<c002ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooonHV9P00_l0
00001OmgMgOo410@o`000?oooooo410@00Go00000oooool01_o^k^koEEEEo`000?l@413oc<c<o`00
00;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`07onk^k_mEEEGo0000o`000?nHV9So
0000oa0@4005ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0oooool02?l0003oMgMgo`000?l0
003oEEEEonk^k_oooooo410@0_l000001ooooooo0000o`000?l@413oooooonk^k_mEEED00_l00000
1?m4A4Co^[Zjooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`06
oa0@4?lb<S;o0000o`000?l@413oZJVY;Oooool003Sooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4104ooooo`03o`000?oooooooooo00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06
ofIVI_mgMgOooooooooooon7QhOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o
0000ooooooooool01?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@;ooooo00Ko0000ojVYZOoo
oooooooookZj^_l00003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01Ol0003oc<c<onk^
k_n7QhOo000000Cooooo00Go410@okZj^_o^k^koMgMgoa0@4005ooooo`03o`000?oooooooooo00;o
oooo00KoIVIVogMgMoooooooooooohN7Qol@4104ooooo`09o`000?mEEEGok^k^oooooomgMgOoEEEE
oooooomEEEGoMgMg00;ooooo00?oMgMgoeEEEOooool00_ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
c<c<onk^k_n7QhOo000000Gooooo00?o0000ooooooooool01oooool03Ol0003oEEEEonk^k_oooooo
MgMgofIVI_ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00;ooooo00KoZJVYo`000?n7QhOoV9RHo`000?nHV9P2ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000oooooooooooooooo
o`000007ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_nYZJWo0000ohN7QonHV9So0000
oiRHV0;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED8ooooo`06ofIVI_mgMgOooooooooooon7
QhOo410@0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000olc<c?o^k^koQhN7o`00
0004ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Kooooo
00Ko0000ojVYZOoooooooooookZj^_l00003ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE0_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103oooo
o`03o`000?oooooooooo00Cooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06o`000?nY
ZJWooooooooooonj^[[o0000;Oooool003Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01_l0003ooooo
oooooooooooo^[ZjohN7Q`;oIVIV00Go410@ooooooooooooooooo`000006ooooo`05oa0@4?n7QhOo
ooooonk^k_l000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo000000Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
QhN7ooooooo^k^ko000000Gooooo00?o0000ooooooooool01oooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7odA4A?mEEEGo
MgMgoeEEE@;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOoA4A4oeEEEOmg
MgOoEEEE0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go410@ohN7Qoooooook^k^o`00
0004ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooooooonk^k_l00002ooooo`03
o`000?oooooooooo00Gooooo00Ko0000ooooooooooooooooonk^k_l00007ooooo`05okZj^_n7QhOo
IVIVofIVI_l@41000oooool00ol0003ok^k^ooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00Go^[ZjohN7QomVIVKoIVIVoa0@400]ooooo`00>?ooool6o`0000Cooooo00?o0000oooooooo
ool00oooool6o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooolb<S;o8B4Q
00;oMgMg00?oQhN7onk^k_ooool00_ooool00ol0003oooooooooo`04ooooo`03okZj^_l@413o0000
00;o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo000000Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`Ko00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03okZj^_l@413o000000;o00001Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooool000001Ol0
0003ooooo`03o`000?oooooooooo00Cooooo00Ko0000omgMgOm4A4Co8B4Qonk^k_l00002ooooo`Ko
00000_ooool6o`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00Cooooo00Ko0000omgMgOm4A4Co8B4Qonk^k_l00002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
0_ooool00onj^[[o410@o`000002o`0000Cooooo00?o0000ooooooooool01?ooool01_l0003ooooo
ooooooooooook^k^o`0000;ooooo1_l00002ooooo`06o`000?ooooooooooooooooo^k^ko00001_oo
ool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP?ooooo00?o0000onk^k_ooool00_ooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00Ko00000oooool00ol0003oooooooooo`04oooo
o`Ko00000_ooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kRgooooo000hooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`03ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003o<S8bomgMg@04ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0_ooool01_l0003o
^[Zjooooooo^k^koMgMgo`0000?ooooo00?o0000ooooooooool01oooool00oo<c<co0000ooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_mVIVKoMgMgoooooooo
ooooQhN7o`0000Cooooo00Wo0000oeEEEOo^k^koooooogMgMomVIVKooooooeEEEOmgMgL00_ooool0
0omgMgOoEEEEooooo`02ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7
Qolb<S83ooooo`05o`000?n7QhOoooooojVYZOl000000oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo00?oc<c<o`000?ooool01?ooool00ol0003oooooooooo`07ooooo`0=
o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03
o`000?oooooooooo00?ooooo00ooZJVYob4Q8OooooooQhN7oeEEEOoooooo<S8bojVYZOooooooEEEE
ohN7Qoo^k^koooooohN7Qolb<S800_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go
0000ohN7QoooooooZJVYo`000007ooooo`03o`000?oooooooooo00?ooooo00_oZJVYob4Q8Ooooooo
QhN7oeEEEOoooooo<S8bojVYZOooooooEEEEogMgM`02ooooo`03ogMgMomEEEGooooo00Oooooo00Ko
IVIVogMgMoooooooooooohN7Qol00003ooooo`05o`000?mgMgOoooooojVYZOl000001Oooool00oo<
c<co0000ooooo`03ooooo`03o`000?lb<S;ogMgM00Cooooo00KoEEEEogMgMoooooook^k^oeEEEOl0
0002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooo^k^koEEEE
o`0000Kooooo00Ko0000okZj^_ooooook^k^ogMgMol00003ooooo`06o`000?mEEEGok^k^oooooomg
MgOoIVIV0_ooool01Ol0003oMgMgoooooonYZJWo000000;ooooo00KoEEEEohN7Qoo^k^koooooohN7
Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82oooo
o`06o`000?nj^[[oooooonk^k_mgMgOo0000;Oooool003Sooooo00Kok^k^oeEEEOl0003o0000odA4
A?o^k^h4ooooo`03o`000?oooooooooo00?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2oooo
o`08onk^k_mVIVKo0000o`000?m4A4Co0000ooooool@4105o`0000?ooooo0_l000001?nYZJWo8B4Q
o`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool02?nYZJWo8B4Qo`000?l0
003o<S8bo`000?oooooo410@1Ol00004ooooo`04oc8b<_l0003o0000oiRHV0;ooooo00?o410@o`00
0?l000000ol00004ooooo`03oa0@4?l0003o000000Cooooo00Kok^k^ofIVI_l0003o0000odA4A?l0
0003ooooo`03oa0@4?l0003oMgMg00;o000000GoIVIVonk^k_ooooook^k^oeEEE@02o`000004oeEE
EOo^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@
o`000?mgMgL00_l000000onHV9Sooooooa0@4005o`0000Cooooo00?o410@o`000?l000001Oooool0
1?lb<S;o0000o`000?nHV9P5ooooo`03o`000?oooooooooo00Oooooo00Wo0000olc<c?l@413o0000
oeEEEOo^k^koooooonk^k_mEEED00_l000001?m4A4Cok^k^ooooool@4105o`0000;ooooo0ol00002
ooooo`?o000000?oooooonk^k_mEEED00_l000001_m4A4Cok^k^ooooooooooook^k^oeEEE@;o0000
00OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o000000?oV9RHooooooooool00oooool00ol@
413o0000o`000003o`0000;ooooo0ol00002ooooo`?o000000?oooooonk^k_mEEED00_l000000omE
EEGok^k^ooooo`07ooooo`06onk^k_mVIVKo0000o`000?m4A4Co00000oooool01Ol0003oMgMgo`00
0?l0003oV9RH00?ooooo00Co<S8bo`000?l0003oV9RH0oooool2o`000004ojVYZOlQ8B7o0000ob4Q
8@;ooooo00[ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooooo^k^koEEEE0_l000002_m4A4Co
k^k^ooooooooooook^k^oeEEEOl0003o410@olc<c?l00006ooooo`06ojVYZOlQ8B7o0000o`000?lb
<S;o00000_ooool00ol@413o0000ogMgM`02o`000006ofIVI_o^k^koooooooooool0003oMgMg0_l0
00001OnHV9Soooooooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooooooo0_l000001?nYZJWo
8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0002gooooo0012ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04oooooo0012ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1?ooooo`00@?ooool0
0ol@413o0000o`00001@ooooo`03oa0@4?oooooooooo03kooooo00?o410@ooooooooool02_ooool0
0ol@413o0000o`000008ooooo`03oa0@4?l0003ooooo05oooooo00?o410@o`000?ooool0:Oooool2
o`0001Kooooo00?o410@o`000?ooool0D?ooool00?ooooooi_ooool00?ooooooi_ooool00?oooooo
i_ooool00?ooooooi_ooool00?ooooooi_ooool00?ooooooi_ooool00?ooooooi_ooool00001\
\>"],
  ImageRangeCache->{{{0, 484.812}, {299.312, 0}} -> {0, -1080, 0, 81}}]
}, Open  ]],

Cell["\<\
This numerical method matches the analytic solution to the \
boundary-value problem quite nicely. For one-dimensional  linear \
boundary-value problems, matrix inversion is an excellent numerical method of \
solution. \
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 2.4", "Subsubtitle",
  CellTags->"c:51"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  " Find the Green's function for the following potential problem in terms of \
homogeneous solutions:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]\^2\/\[DifferentialD]x\^2\) \[Phi]\
\  = \ \[Rho](x)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0) = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](b) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the Green's function to find a particular solution for the case where \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x) = x\^3\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " Use the method of Sec. ",
  ButtonBox["2.4.2",
    ButtonData:>"c:42",
    ButtonStyle->"Hyperlink"],
  " to solve the following ODEs for the Green's function, for the given \
homogeneous boundary or initial conditions: "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`G\^\[Prime]\  + \ 
          3\ t\ \(G(t, t\_o)\)\  = \ \[Delta](t - t\_o), \ 
      G = \(\(0\ for\ t\)\(<\)\(t\_o\)\(\ \)\)\)]],
  ". Plot ",
  Cell[BoxData[
      \(TraditionalForm\`G(t, 0)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          
          RowBox[{\(G\^\[DoublePrime]\  + 4 \( G(t, t\_o)\) = \[Delta](
                t - t\_o)\), ",", 
            FormBox[\(G = 0\ for\ t < t\_o\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". Plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["G",
            "TraditionalForm"], "(", 
          RowBox[{"t", "-", 
            FormBox[\(t\_o\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`G\^\[DoublePrime]\  + 2\ G\^\[Prime] + 
          G(t, t\_o) = \[Delta](t - t\_o)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`G = 0\ for\ t < t\_o\)]],
  ". Plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["G",
            "TraditionalForm"], "(", 
          RowBox[{"t", "-", 
            FormBox[\(t\_o\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`G\^\[DoublePrime]\  + \ 
          t\ \(G(t, t\_o)\)\  = \ \[Delta](t - t\_o)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`G = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < t\_o\)]],
  " (Hint: The solution will be in terms of Airy functions.) Plot ",
  Cell[BoxData[
      \(TraditionalForm\`G(t, 0)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(G\^\[DoublePrime]\)\^\[Prime] + 
          2  G\^\[DoublePrime] - G\^\[Prime] - 2  G = \[Delta](t - t\_o), \ 
      G = 0\ for\ t < t\_o\)]],
  ". Plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["G",
            "TraditionalForm"], "(", 
          RowBox[{"t", "-", 
            FormBox[\(t\_o\),
              "TraditionalForm"]}], ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(G\^\[DoublePrime]\  + \(\[Omega]\_o\^2\) \(G(x, 
                  x\_o)\) = \[Delta](x - x\_o)\), ",", 
          FormBox[
            RowBox[{"G", "=", 
              RowBox[{\(0\ for\ x\), "=", 
                RowBox[{"a", " ", "and", " ", Cell[TextData[Cell[BoxData[
                      \(TraditionalForm\`x = b\)]]]]}]}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ">0, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\  \[NotEqual] \ 
        n\ \[Pi]/\((b - a)\)\ for\ any\ integer\ n\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["(g)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(G\^\[DoublePrime]\  - \(\[Kappa]\_o\^2\) \(G(x, 
                  x\_o)\) = \[Delta](x - x\_o)\), ",", 
          FormBox[
            RowBox[{"G", "=", 
              RowBox[{\(0\ for\ x\), "=", 
                RowBox[{"a", " ", "and", " ", Cell[TextData[Cell[BoxData[
                      \(TraditionalForm\`x = b\)]]]]}]}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            FormBox[\(\[Kappa]\_o\),
              "TraditionalForm"], ">", "0"}], ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(h)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(G\^\[DoublePrime]\  + 
              n\ \(\(G\^\[Prime]\)(x, x\_o)\)/x = \[Delta](x - x\_o)\), ",", 
          FormBox[
            RowBox[{"G", "=", 
              RowBox[{\(0\ for\ x\), "=", 
                RowBox[{"a", ">", 
                  RowBox[{"0", " ", "and", " ", Cell[TextData[Cell[BoxData[
                        \(TraditionalForm\`x = b\)]]]]}]}]}]}],
            "TraditionalForm"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n \[NotEqual] \ 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(G\^\[DoublePrime]\)\^\[Prime] + 
          G\^\[DoublePrime] + G\^\[Prime] + G = \[Delta](x - x\_o), \ 
      G = \(G\^\[Prime] = \(0\ at\ x = 0\)\), G = \(0\ at\ x = 1\)\)]],
  ". Plot ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["G",
            "TraditionalForm"], "(", \(x - x\_o\), ")"}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Use the Green's functions found from Exercise (2) to help determine \
solutions to the following problems. Plot the solution in each case."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[Prime]\  + \ 3\ t\ \(x(t)\)\  = \ sin\ t, \ 
      x = \(0\ at\ t = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`x\^\[DoublePrime]\  + 4 \( x(t)\) = cos\ 2\ t, 
      x(0) = \(0 = \(x\^\[Prime]\)(0)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^\[DoublePrime]\  + 2\ x\^\[Prime] + x(t) = t\^2\),
            "TraditionalForm"], ",", " ", \(x(0) = 1\), 
          ",", \(\(x\^\[Prime]\)(0) = 0\)}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(x\^\[DoublePrime]\  + t\ \(x(t)\) = t\),
            "TraditionalForm"], ",", " ", \(x(0) = 1\), 
          ",", \(\(x\^\[Prime]\)(0) = 0\)}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[DoublePrime]\)\^\[Prime] + 
          2  x\^\[DoublePrime] - x\^\[Prime] - 
          2  x = \[ExponentialE]\^\(-t\), \ 
      x(0) = 1, \(x\^\[Prime]\)(0) = \(\(x\^\[DoublePrime]\)(0) = 0\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\^\[DoublePrime]\  + \[Phi](x) = x\^3\), ",", 
          FormBox[\(\[Phi](0) = 1\ , \ \[Phi](1) = 0\),
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(g)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\^\[DoublePrime]\  - \[Phi](x) = sin\ x\), ",", 
          FormBox[\(\(\[Phi]\^\[Prime]\)(0) = \(0\  = \[Phi](1)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(h)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\^\[DoublePrime]\  + 3\ \[Phi]\^\[Prime]/x = x\), ",",
           
          FormBox[\(\[Phi](1) = 0, \ \ \(\[Phi]\^\[Prime]\)(2) = 1\),
            "TraditionalForm"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(i)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\[DoublePrime]\)\^\[Prime] + \[Phi]\^\
\[DoublePrime] + \[Phi]\^\[Prime] + \[Phi] = 
        x\ \[ExponentialE]\^\(-x\), \ \ \ \[Phi] = \(\[Phi]\^\[Prime] = \(0\ \
at\ x = 0\)\), \ \ \ \[Phi] - 2  \[Phi]\^\[Prime] = \(1\ at\ x = 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Discretize the operator in Exercise (3)(a) using Euler's method, and \
solve the problem by matrix inversion for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 8\)]],
  ". Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], "=", "0.1"}], ","}], 
        TraditionalForm]]],
  " and compare with the exact solution by plotting both in the same plot."
}], "Text",
  CellTags->"i:91"],

Cell[TextData[{
  StyleBox["(5) (a)",
    FontWeight->"Bold"],
  " By writing the ODE in Exercise (3)(b) as a vector ODE in the unknown \
vector function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], 
          "=", \({x(t), \(x\^\[Prime]\)(t)}\)}], TraditionalForm]]],
  ", discretize the ODE using the vector Euler's method, and solve by matrix \
inversion for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 5\)]],
  ". Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", "0.05"}], TraditionalForm]]],
  ".  Plot the result along with the exact solution. (See. Sec. ",
  ButtonBox["1.4.5",
    ButtonData:>{"Chapter1.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text"],

Cell[TextData[{
  "     ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Repeat for Exercise (3)(c)"
}], "Text"],

Cell[TextData[{
  "     ",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat for Exercise (3)(d)"
}], "Text"],

Cell[TextData[{
  "     ",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Repeat for Exercise (3)(e), now taking the vector function as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", "t", ")"}], " ", "=", 
          " ", \({x(t), \(x\^\[Prime]\)(t), \(x\^\[DoublePrime]\)(t)}\)}], 
        TraditionalForm]]],
  ".\t\t"
}], "Text"],

Cell[TextData[{
  StyleBox["(6) (a)",
    FontWeight->"Bold"],
  " For the following general second-order ODE initial-value problem, find a \
way of including the initial conditions in the forcing function on the \
right-hand side, in analogy to Eq. ",
  ButtonBox["(2.4.24)",
    ButtonData:>"(2.4.24)",
    ButtonStyle->"Hyperlink"],
  ", and state the proper homogeneous initial condition for the new ODE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None], "+", " ", 
            RowBox[{\(\(u\_1\)(t)\), 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], "+", 
            " ", \(\(\(u\_o\)(t)\) \(x(t)\)\)}], "=", \(f(t)\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(t\_o) = x\_o, \ \(x\^\[Prime]\)(t\_o) = v\_o\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Using the result of part (a) along with Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ",write a general homogeneous solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  " to this problem in terms of the Green's function."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use the Green's function found in Exercise (2)(c) and the result from \
part (b) to solve the following problem: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[DifferentialD]\^2 x\), \(\[DifferentialD]t\^2\),
              MultilineFunction->None], "+", " ", 
            RowBox[{"2", 
              FractionBox[\(\[DifferentialD]x\), \(\[DifferentialD]t\),
                MultilineFunction->None]}], "+", " ", \(x(t)\)}], 
          "=", \(\[ExponentialE]\^\(-t\)\)}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`x(0) = 1, x' \((0)\) = 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " In this problem we will show that the centered difference scheme for \
taking a numerical derivative is more accurate than either forward- or \
backward-differencing. To do so, take a smooth function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Phi](x)\)\(\ \)\)\)]],
  "whose derivative we will determine numerically at a grid point ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_n\)]],
  ". Then the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_\(n + 1\)\)]],
  "can be determined by Taylor expansion:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi]\_\(n + 1\)\), "=", 
          RowBox[{
            RowBox[{\(\[Phi]\_n\), "+", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], 
                " ", \(\(\[Phi]\^\[Prime]\)\_n\)}], "+", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"], \(\(\[Phi]\^\[DoublePrime]\)\_n/2\)}], " ", "+", 
              RowBox[{
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "3"], \(\(\(\[Phi]\^\[DoublePrime]\)\^\[Prime]\)\_n/6\)}], 
              " ", "+"}], "..."}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "with a similar result for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(n - 1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Use these Taylor expansions in the forward- and backward-difference \
methods,  Eqs. ",
  ButtonBox["(2.4.42)",
    ButtonData:>"(2.4.42)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(2.4.43)",
    ButtonData:>"(2.4.43)",
    ButtonStyle->"Hyperlink"],
  ", to show that the error in these methods is of order \[CapitalDelta]",
  StyleBox["x",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use these Taylor expansions in the centered-difference derivative, Eq. ",
  ButtonBox["(2.4.41)",
    ButtonData:>"(2.4.41)",
    ButtonStyle->"Hyperlink"],
  ",  to show that the error in this method is of order ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Repeat for the centered-difference second derivative, Eq. ",
  ButtonBox["(2.4.44)",
    ButtonData:>"(2.4.44)",
    ButtonStyle->"Hyperlink"],
  ", to show that the error is also of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]x\^2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(8)(a)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(2.4.50)",
    ButtonData:>"(2.4.50)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "   ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(2.4.51)",
    ButtonData:>"(2.4.51)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "  ",
  StyleBox[" (c)",
    FontWeight->"Bold"],
  " Test Eq. ",
  ButtonBox["(2.4.51)",
    ButtonData:>"(2.4.51)",
    ButtonStyle->"Hyperlink"],
  " directly for the potential problem given in Exercise (1) of this section: \
by applying the Green's function found in Exercise (1)(a) to Eq. ",
  ButtonBox["(2.4.51)",
    ButtonData:>"(2.4.51)",
    ButtonStyle->"Hyperlink"],
  ", show that the correct homogeneous solution to this potential problem is \
recovered."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)(a)",
    FontWeight->"Bold"],
  " Find a way to include the boundary conditions in the forcing function for \
the following second-order boundary-value problem: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\^2\), \(\[DifferentialD]x\^2\),
                MultilineFunction->None], "\[Phi]"}], "+", 
            RowBox[{\(\(u\_1\)(x)\), 
              FractionBox["\[DifferentialD]", \(\[DifferentialD]x\),
                MultilineFunction->None], " ", "\[Phi]"}], 
            "+", \(\(\(u\_o\)(x)\) \[Phi]\)}], " ", "=", \(\[Rho](x)\)}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\[Prime]\)(a) = 
        V\_a, \(\(\(\[Phi]\^\[Prime]\)(b)\)\(=\)\(V\_b\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell["\<\
What homogeneous boundary conditions must be attached to the new \
ODE?\
\>", "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Using the result of part (a) along with Eq. ",
  ButtonBox["(2.4.3)",
    ButtonData:>"(2.4.3)",
    ButtonStyle->"Hyperlink"],
  ", write a general homogeneous solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\_h\)(t)\)]],
  " to this problem in terms of the Green's function. "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using the results of part (a) and (b), find the appropriate Green's \
function in terms of homogeneous solutions and solve the following \
boundary-value problem:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FractionBox[\(\[DifferentialD]\^2\), \(\[DifferentialD]x\^2\),
                MultilineFunction->None], "\[Phi]"}], "+", 
            RowBox[{"4", 
              FractionBox["\[DifferentialD]", \(\[DifferentialD]x\),
                MultilineFunction->None], " ", "\[Phi]"}], "+", "\[Phi]"}], 
          " ", "=", "x"}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\[Prime]\)(0) = 
        0, \ \(\[Phi]\^\[Prime]\)(1) = 1\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " Using the centered-difference discretization techniques discussed in Sec. \
",
  ButtonBox["2.4.5",
    ButtonData:>"c:48",
    ButtonStyle->"Hyperlink"],
  ", solve the following problems using matrix inversion, and compare each to \
the exact solution. In each case take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], 
          StyleBox[" ",
            FontSlant->"Italic"], "=", " ", "0.05"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Exercise (3)(f). "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Exercise (3)(g) (Hint: To learn about setting the derivative equal to \
zero at the boundary, see Sec. ",
  ButtonBox["6.2.1",
    ButtonData:>{"Chapter6.nb", "c:20"},
    ButtonStyle->"Hyperlink"],
  ", in the sub-subsection on von Neumann and mixed boundary conditions.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Exercise (3)(h) [see the hint for Exercise (10)(b)]."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Exercise (3)(i) [see the hint for Exercise (10) (b)]."
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Phi]\^\[DoublePrime]\)(x)\  = \ 1\), ",", " ", Cell[
          TextData[Cell[BoxData[
              \(TraditionalForm\`\(\[Phi]\^\[Prime]\)(0) = 
                2; \ \(\[Phi]\^\[Prime]\)(1) = 0\)]]]]}], TraditionalForm]]],
  ". [Hint: First solve this problem analytically by direct integration to \
show that a solution ",
  StyleBox["does not exist",
    FontSlant->"Italic"],
  ". Then solve the problem by finite differencing. Also, see the hint for \
Exercise (10(b).]"
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\^\[DoublePrime]\)(x)\  + \ \[Phi](x)\  = \ 
        0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](0) = \(0 = \[Phi](\[Pi])\)\)]],
  " [Hint: Recall that there are an infinite number of solutions; see Eq. ",
  ButtonBox["(1.5.9)",
    ButtonData:>{"Chapter1.nb", "(1.5.9)"},
    ButtonStyle->"Hyperlink"],
  ". Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", 
          " ", \(0.05\ \(\(\[Pi]\)\(.\)\)\)}], TraditionalForm]]],
  "]"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->"c:52"],

Cell[TextData[{
  "J. W. Bradbury and S. L. Vehrencamp, ",
  StyleBox["Principles of Animal Communication",
    FontSlant->"Italic"],
  " (Sinauer Associates, Sunderland, MA, 1998). An introductory reference on \
the auditory system."
}], "Text"],

Cell[TextData[{
  "W. F. Hartmann, ",
  StyleBox["How we localize sound",
    FontSlant->"Italic"],
  ", Phys. Today, November 1999, p. 24."
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->{},
WindowSize->{800, 556},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 2, Section 2.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 115, "IndexEntries" -> {{"i:100", \
"<<"}, {"i:101", {
  StyleBox[ "Fourier", FontWeight -> "Bold"], " and ", 
  StyleBox[ "Inverse Fourier", FontWeight -> "Bold"]}}, {"i:102", 
  StyleBox[ "Directory", FontWeight -> "Bold"]}, {"i:103", 
  StyleBox[ "SetDirectory", FontWeight -> "Bold"]}, {"i:104", {
  StyleBox[ "ListPlay ", FontWeight -> "Bold"], "(", 
  StyleBox[ "see also ", FontSlant -> "Italic"], 
  StyleBox[ 
  "Play", FontWeight -> 
    "Bold"], ")"}}, {"i:106", {"Uncertainty principle (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Bandwidth)"}}, {"i:107", "Heisenberg, Karl W."}, {"i:110", \
"Spectrum"}, {"i:111", "Aliasing"}, {"i:112", "Dirac, Paul"}, {"i:113", \
"Parseval's theorem"}, {"i:114", "Show"}, {"i:16", "Gibbs, Josiah"}, {"i:2", \
"Fourier, Jean"}, {"i:21", "Sine integral"}, {"i:24", "Sound"}, {"i:25", 
  StyleBox[ 
  "Play", FontWeight -> 
    "Bold"]}, {"i:29", "Periodic extension of a function"}, {"i:3", "Fourier \
series"}, {"i:32", {"Ear, inner (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Sound)"}}, {"i:38", "Fourier transforms"}, {"i:42", {
  StyleBox[ "FourierTransform", FontWeight -> "Bold"], " and ", 
  StyleBox[ 
  "InverseFourierTransform", FontWeight -> 
    "Bold"]}}, {"i:44", "Convolution theorem"}, {"i:5", "Fourier \
coefficients"}, {"i:51", "Heaviside step function"}, {"i:52", "FFTs"}, \
{"i:60", "Tuning fork"}, {"i:67", "Wronskian"}, {"i:68", "Wronskian"}, \
{"i:84", "Superposition principle"}, {"i:85", "Green, George"}, {"i:86", \
"Bandwidth"}, {"i:95", "Wavenumber"}, {"i:96", 
  StyleBox[ 
  "DiracDelta", FontWeight -> "Bold"]}, {"i:97", {"Fundamental period (", 
  StyleBox[ 
  "see", FontSlant -> Italic], " Frequency, fundamental)"}}, {"i:98", 
  StyleBox[ "Import", FontWeight -> "Bold"]}, {"i:99", 
  StyleBox[ "SampledSoundList", FontWeight -> "Bold"]}, {"i:99", 
  StyleBox[ "Shallow", FontWeight -> "Bold"]}, {"i:101", "FFTs", {"in ", 
  StyleBox[ "Mathematica", FontSlant -> "Italic"], " (", 
  StyleBox[ "see", FontSlant -> "Italic"], " ", 
  StyleBox[ "Fourier", FontWeight -> "Bold"], " and ", 
  StyleBox[ 
  "InverseFourier", FontWeight -> 
    "Bold"], ")"}}, {"i:105", "Function(s)", "error"}, {"i:108", "Green's \
function(s)", "as an inverse operator"}, {"i:109", "Green's function(s)", "as \
an inverse operator"}, {"i:11", "Convergence", "uniform"}, {"i:13", "Fourier \
series", "for even and odd functions"}, {"i:14", "Fourier series", "for \
periodic functions"}, {"i:15", "Fourier series", "for functions defined on an \
interval"}, {"i:2", "Forcing", "periodic"}, {"i:20", "Fourier coefficients", \
"exponential"}, {"i:22", "Forcing", "periodic"}, {"i:23", "Linear ODEs", \
"resonance"}, {"i:26", "Sound", "perception of phase vs. amplitude"}, \
{"i:27", "Sound", "perception of phase vs. amplitude"}, {"i:28", "Sound", \
"perception of phase vs. amplitude"}, {"i:30", "Periodic extension of a \
function", "even periodic extension"}, {"i:31", "Periodic extension of a \
function", "odd periodic extension"}, {"i:33", "Fourier series", "used in \
solving boundary value problems"}, {"i:34", "Linear ODEs", "exact \
resonance"}, {"i:35", "Linear ODEs", "particular solution"}, {"i:36", "Linear \
ODEs", "exact resonance"}, {"i:37", "Riemann", "Georg"}, {"i:40", "Fourier \
transforms", "conventions in time and space"}, {"i:41", "Fourier transforms", \
{"in ", 
  StyleBox[ 
  "Mathematica", FontSlant -> 
    "Italic"]}}, {"i:43", "Fourier transforms", "sine and cosine \
transforms"}, {"i:47", "Delta function", "periodic"}, {"i:49", "Fourier \
transforms", "connection to Fourier series"}, {"i:5", "Orthogonality", "for \
real functions, in Fourier series"}, {"i:52", "Fourier transforms", {"Fast \
Fourier transforms (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " FFTs)"}}, {"i:53", "Fourier transforms", "discrete"}, {"i:55", \
"Frequency", "Nyquist"}, {"i:56", "FFTs", "for real data"}, {"i:57", "FFTs", \
"used in frequency filtering"}, {"i:6", "Orthogonality", "for complex \
functions, in Fourier series"}, {"i:65", "Boundary value problems", "Green's \
function approach"}, {"i:69", "Boundary value problems", {"matrix inverse \
method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Green's functions)"}}, {"i:7", "Fourier coefficients", "for a \
triangle wave"}, {"i:73", "Derivatives", "centered difference forms"}, \
{"i:74", "Derivatives", "finite-differenced forms"}, {"i:76", "Forcing", \
"inclusion of boundary conditions in"}, {"i:77", "Boundary conditions", \
"contained in the forcing function"}, {"i:77", "Forcing", "inclusion of \
boundary conditions in"}, {"i:78", "Boundary value problems", {"matrix \
inverse method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Green's functions)"}}, {"i:81", "Boundary conditions", \
"periodic"}, {"i:82", "Boundary conditions", "homogeneous"}, {"i:87", \
"Bandwidth", "connection to bit rate"}, {"i:88", "Bandwidth", "and the \
uncertainty principle"}, {"i:89", "Derivatives", "of a \[Delta] function"}, \
{"i:9", "Fourier series", "for a square wave"}, {"i:94", "Linear ODEs", \
"resonance"}, {"i:97", "Frequency", "fundamental"}, {"i:1", "Function(s)", \
"periodic", ""}, {"i:100", {"Reading data from external files (", 
  StyleBox[ "see", FontSlant -> "Italic"], " ", 
  StyleBox[ 
  "Import", FontWeight -> 
    "Bold"], ", <<)"}, "", ""}, {"i:11", "Fourier series", {"uniform \
convergence (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Convergence)"}, ""}, {"i:12", "Convergence", {"nonuniform (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Gibbs phenomenon)"}, ""}, {"i:16", "Gibbs phenomenon", "", \
""}, {"i:17", "Gibbs phenomenon", "", ""}, {"i:18", "Fourier series", \
"exponential, for real functions", ""}, {"i:19", "Fourier series", \
"exponential, for general functions", ""}, {"i:33", "Boundary value \
problems", "particular solution via Fourier series", ""}, {"i:39", "Fourier \
transforms", "inverse", ""}, {"i:4", "Function(s)", "sectionally continuous", \
""}, {"i:45", {"Uncertainty principle (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Bandwidth)"}, "", ""}, {"i:46", "Delta function", "Dirac", \
""}, {"i:48", "Delta function", "periodic", ""}, {"i:50", "Fourier \
transforms", "generalized Fourier integrals", ""}, {"i:54", "Forcing", \
"general, possibly nonperiodic", ""}, {"i:59", "Green's function(s)", "for a \
damped harmonic oscillator", ""}, {"i:61", "Green's function(s)", "for an Nth \
order ODE with constant coefficients", ""}, {"i:62", "Green's function(s)", \
"", ""}, {"i:63", "Green's function(s)", "for initial value problems", ""}, \
{"i:64", "Green's function(s)", "from homogeneous solutions", ""}, {"i:65", \
"Green's function(s)", "for ODE boundary value problems", ""}, {"i:66", \
"Green's function(s)", "from homogeneous solutions", ""}, {"i:69", "Green's \
function(s)", "discretized", ""}, {"i:70", "Green's function(s)", \
"discretized", ""}, {"i:73", {"Centered difference (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Derivatives, finite-differenced forms)"}, "", ""}, {"i:75", \
{"Backward difference (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Derivatives, finite-differenced forms)"}, "", ""}, {"i:75", \
{"Forward difference(", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " derivatives, finite-differenced forms)"}, "", ""}, {"i:79", \
{"Initial value problems (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Differential equations)"}, "", ""}, {"i:83", "Forcing", \
{"delta function (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Green's functions)"}, ""}, {"i:90", {"Euler's method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:91", {"Euler's \
method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:92", {"Euler's \
method (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Numerical solution of ODEs)"}, "", ""}, {"i:98", {"Reading \
data from external files (", 
  StyleBox[ "see ", FontSlant -> "Italic"], 
  StyleBox[ "Import", FontWeight -> "Bold"], ", <<)"}, "", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", 
                BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(2.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(2.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(2.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(2.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(2.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(2.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1727, 52, 68, 1, 69, "Title",
      CellTags->"c:1"]},
  "Sec. 2.1"->{
    Cell[1839, 59, 109, 1, 39, "Subtitle",
      CellTags->{"Sec. 2.1", "i:14", "c:2"}]},
  "i:14"->{
    Cell[1839, 59, 109, 1, 39, "Subtitle",
      CellTags->{"Sec. 2.1", "i:14", "c:2"}]},
  "c:2"->{
    Cell[1839, 59, 109, 1, 39, "Subtitle",
      CellTags->{"Sec. 2.1", "i:14", "c:2"}]},
  "c:3"->{
    Cell[1992, 66, 60, 1, 41, "Subsubtitle",
      CellTags->"c:3"]},
  "i:1"->{
    Cell[2055, 69, 358, 15, 26, "Text",
      CellTags->"i:1"]},
  "(2.1.1)"->{
    Cell[2416, 86, 130, 5, 28, "NumberedEquation",
      CellTags->"(2.1.1)"]},
  "(2.1.2)"->{
    Cell[3541, 132, 232, 7, 26, "NumberedEquation",
      CellTags->"(2.1.2)"]},
  "i:97"->{
    Cell[3776, 141, 1195, 41, 77, "Text",
      CellTags->"i:97"]},
  "Fig. 2.1"->{
    Cell[36551, 1013, 159, 6, 15, "Caption",
      CellTags->"Fig. 2.1"]},
  "i:2"->{
    Cell[36713, 1021, 1325, 30, 128, "Text",
      CellTags->"i:2"]},
  "Cell 2.1"->{
    Cell[39843, 1111, 244, 6, 105, "Input",
      CellTags->"Cell 2.1"]},
  "Cell 2.2"->{
    Cell[117655, 2575, 194, 5, 85, "Input",
      CellTags->"Cell 2.2"]},
  "i:3"->{
    Cell[167821, 3574, 364, 11, 26, "Text",
      CellTags->"i:3"]},
  "i:4"->{
    Cell[171406, 3701, 880, 21, 95, "Text",
      CellTags->"i:4"]},
  "(2.1.3)"->{
    Cell[172289, 3724, 777, 25, 30, "NumberedEquation",
      CellTags->"(2.1.3)"]},
  "c:4"->{
    Cell[173103, 3754, 96, 1, 30, "Subsubtitle",
      CellTags->"c:4"]},
  "i:5"->{
    Cell[173202, 3757, 994, 34, 77, "Text",
      CellTags->"i:5"]},
  "(2.1.4)"->{
    Cell[174199, 3793, 187, 6, 33, "NumberedEquation",
      CellTags->"(2.1.4)"]},
  "(2.1.5)"->{
    Cell[175019, 3826, 614, 14, 80, "NumberedEquation",
      CellTags->"(2.1.5)"]},
  "(2.1.6)"->{
    Cell[176656, 3874, 358, 9, 37, "NumberedEquation",
      CellTags->"(2.1.6)"]},
  "(2.1.7)"->{
    Cell[177017, 3885, 220, 6, 37, "NumberedEquation",
      CellTags->"(2.1.7)"]},
  "Cell 2.3"->{
    Cell[178117, 3928, 393, 9, 142, "Input",
      CellTags->"Cell 2.3"]},
  "Cell 2.4"->{
    Cell[179049, 3960, 220, 6, 85, "Input",
      CellTags->"Cell 2.4"]},
  "(2.1.8)"->{
    Cell[181087, 4038, 626, 11, 73, "NumberedEquation",
      CellTags->"(2.1.8)"]},
  "(2.1.9)"->{
    Cell[182582, 4082, 412, 11, 85, "NumberedEquation",
      CellTags->"(2.1.9)"]},
  "(2.1.10)"->{
    Cell[183863, 4128, 286, 6, 40, "NumberedEquation",
      CellTags->"(2.1.10)"]},
  "c:5"->{
    Cell[184186, 4139, 61, 1, 30, "Subsubtitle",
      CellTags->"c:5"]},
  "Cell 2.5"->{
    Cell[185254, 4179, 279, 6, 105, "Input",
      CellTags->"Cell 2.5"]},
  "Cell 2.6"->{
    Cell[207601, 4671, 173, 4, 85, "Input",
      CellTags->"Cell 2.6"]},
  "Cell 2.7"->{
    Cell[207983, 4687, 115, 3, 66, "Input",
      CellTags->"Cell 2.7"]},
  "Cell 2.8"->{
    Cell[285595, 5975, 368, 9, 123, "Input",
      CellTags->"Cell 2.8"]},
  "Cell 2.9"->{
    Cell[286122, 5993, 260, 6, 105, "Input",
      CellTags->"Cell 2.9"]},
  "Cell 2.10"->{
    Cell[286593, 6014, 103, 3, 67, "Input",
      CellTags->"Cell 2.10"]},
  "i:7"->{
    Cell[286924, 6025, 122, 4, 27, "Text",
      CellTags->"i:7"]},
  "(2.1.11)"->{
    Cell[287049, 6031, 189, 3, 58, "NumberedEquation",
      CellTags->"(2.1.11)"]},
  "(2.1.12)"->{
    Cell[287799, 6055, 132, 5, 29, "NumberedEquation",
      CellTags->"(2.1.12)"]},
  "i:13"->{
    Cell[289023, 6098, 320, 9, 64, "Text",
      CellTags->"i:13"]},
  "Cell 2.11"->{
    Cell[289863, 6124, 152, 4, 69, "Input",
      CellTags->"Cell 2.11"]},
  "Cell 2.12"->{
    Cell[290434, 6147, 247, 6, 107, "Input",
      CellTags->"Cell 2.12"]},
  "c:6"->{
    Cell[426851, 9757, 59, 1, 30, "Subsubtitle",
      CellTags->"c:6"]},
  "Cell 2.13"->{
    Cell[427291, 9773, 255, 6, 105, "Input",
      CellTags->"Cell 2.13"]},
  "Cell 2.14"->{
    Cell[427884, 9795, 239, 5, 105, "Input",
      CellTags->"Cell 2.14"]},
  "(2.1.13)"->{
    Cell[482564, 10800, 141, 5, 29, "NumberedEquation",
      CellTags->"(2.1.13)"]},
  "Cell 2.15"->{
    Cell[483134, 10826, 340, 9, 124, "Input",
      CellTags->"Cell 2.15"]},
  "(2.1.14)"->{
    Cell[483628, 10843, 522, 15, 58, "NumberedEquation",
      CellTags->{"(2.1.14)", "i:9"}]},
  "i:9"->{
    Cell[483628, 10843, 522, 15, 58, "NumberedEquation",
      CellTags->{"(2.1.14)", "i:9"}]},
  "Cell 2.16"->{
    Cell[485375, 10897, 357, 9, 128, "Input",
      CellTags->"Cell 2.16"]},
  "c:7"->{
    Cell[715561, 17294, 82, 1, 30, "Subsubtitle",
      CellTags->"c:7"]},
  "Cell 2.17"->{
    Cell[716011, 17311, 429, 9, 145, "Input",
      CellTags->"Cell 2.17"]},
  "i:16"->{
    Cell[1214826, 44149, 1440, 42, 129, "Text",
      CellTags->"i:16"]},
  "i:11"->{
    Cell[1217926, 44244, 193, 6, 27, "Text",
      CellTags->"i:11"]},
  "(2.1.15)"->{
    Cell[1218122, 44252, 195, 3, 29, "NumberedEquation",
      CellTags->"(2.1.15)"]},
  "i:12"->{
    Cell[1218992, 44281, 707, 23, 61, "Text",
      CellTags->"i:12"]},
  "i:17"->{
    Cell[1220967, 44334, 94, 1, 30, "Subsubtitle",
      CellTags->{"i:17", "c:8"}]},
  "c:8"->{
    Cell[1220967, 44334, 94, 1, 30, "Subsubtitle",
      CellTags->{"i:17", "c:8"}]},
  "(2.1.16)"->{
    Cell[1222178, 44374, 523, 15, 58, "NumberedEquation",
      CellTags->"(2.1.16)"]},
  "(2.1.17)"->{
    Cell[1223099, 44406, 833, 24, 68, "NumberedEquation",
      CellTags->"(2.1.17)"]},
  "(2.1.18)"->{
    Cell[1224764, 44463, 1134, 27, 68, "NumberedEquation",
      CellTags->"(2.1.18)"]},
  "(2.1.19)"->{
    Cell[1226157, 44503, 425, 12, 41, "NumberedEquation",
      CellTags->"(2.1.19)"]},
  "i:21"->{
    Cell[1226585, 44517, 463, 17, 45, "Text",
      CellTags->"i:21"]},
  "Cell 2.18"->{
    Cell[1227073, 44538, 205, 5, 69, "Input",
      CellTags->"Cell 2.18"]},
  "Cell 2.19"->{
    Cell[1227667, 44560, 129, 3, 69, "Input",
      CellTags->"Cell 2.19"]},
  "Cell 2.20"->{
    Cell[1248943, 45257, 108, 3, 69, "Input",
      CellTags->"Cell 2.20"]},
  "Cell 2.21"->{
    Cell[1249610, 45284, 94, 3, 69, "Input",
      CellTags->"Cell 2.21"]},
  "Cell 2.22"->{
    Cell[1249810, 45295, 86, 3, 67, "Input",
      CellTags->"Cell 2.22"]},
  "Cell 2.23"->{
    Cell[1250286, 45317, 107, 3, 69, "Input",
      CellTags->"Cell 2.23"]},
  "Cell 2.24"->{
    Cell[1251115, 45352, 259, 7, 107, "Input",
      CellTags->"Cell 2.24"]},
  "c:9"->{
    Cell[1401362, 50796, 87, 1, 30, "Subsubtitle",
      CellTags->"c:9"]},
  "(2.1.20)"->{
    Cell[1402140, 50820, 360, 10, 30, "NumberedEquation",
      CellTags->"(2.1.20)"]},
  "(2.1.21)"->{
    Cell[1402965, 50849, 830, 26, 32, "NumberedEquation",
      CellTags->"(2.1.21)"]},
  "(2.1.22)"->{
    Cell[1404275, 50894, 419, 9, 38, "NumberedEquation",
      CellTags->"(2.1.22)"]},
  "(2.1.23)"->{
    Cell[1405239, 50926, 330, 10, 37, "NumberedEquation",
      CellTags->"(2.1.23)"]},
  "(2.1.24)"->{
    Cell[1405726, 50945, 213, 4, 45, "NumberedEquation",
      CellTags->"(2.1.24)"]},
  "(2.1.25)"->{
    Cell[1406123, 50960, 255, 7, 37, "NumberedEquation",
      CellTags->{"(2.1.25)", "i:18"}]},
  "i:18"->{
    Cell[1406123, 50960, 255, 7, 37, "NumberedEquation",
      CellTags->{"(2.1.25)", "i:18"}]},
  "(2.1.26)"->{
    Cell[1406926, 50988, 345, 7, 65, "NumberedEquation",
      CellTags->"(2.1.26)"]},
  "(2.1.27)"->{
    Cell[1408141, 51024, 268, 7, 37, "NumberedEquation",
      CellTags->{"(2.1.27)", "i:19"}]},
  "i:19"->{
    Cell[1408141, 51024, 268, 7, 37, "NumberedEquation",
      CellTags->{"(2.1.27)", "i:19"}]},
  "i:6"->{
    Cell[1410515, 51100, 627, 21, 61, "Text",
      CellTags->"i:6"]},
  "(2.1.28)"->{
    Cell[1411145, 51123, 195, 6, 34, "NumberedEquation",
      CellTags->"(2.1.28)"]},
  "(2.1.29)"->{
    Cell[1412744, 51173, 609, 18, 38, "NumberedEquation",
      CellTags->"(2.1.29)"]},
  "(2.1.30)"->{
    Cell[1413446, 51198, 1363, 29, 107, "NumberedEquation",
      CellTags->"(2.1.30)"]},
  "(2.1.31)"->{
    Cell[1414937, 51236, 862, 24, 38, "NumberedEquation",
      CellTags->"(2.1.31)"]},
  "(2.1.32)"->{
    Cell[1416447, 51284, 1021, 25, 40, "NumberedEquation",
      CellTags->"(2.1.32)"]},
  "(2.1.33)"->{
    Cell[1417928, 51329, 557, 15, 40, "NumberedEquation",
      CellTags->{"(2.1.33)", "i:20"}]},
  "i:20"->{
    Cell[1417928, 51329, 557, 15, 40, "NumberedEquation",
      CellTags->{"(2.1.33)", "i:20"}]},
  "(2.1.34)"->{
    Cell[1419393, 51381, 163, 3, 46, "NumberedEquation",
      CellTags->"(2.1.34)"]},
  "i:22"->{
    Cell[1421156, 51439, 112, 2, 30, "Subsubtitle",
      CellTags->{"i:22", "c:10"}]},
  "c:10"->{
    Cell[1421156, 51439, 112, 2, 30, "Subsubtitle",
      CellTags->{"i:22", "c:10"}]},
  "(2.1.35)"->{
    Cell[1421911, 51463, 298, 9, 38, "NumberedEquation",
      CellTags->"(2.1.35)"]},
  "(2.1.36)"->{
    Cell[1422930, 51499, 396, 9, 38, "NumberedEquation",
      CellTags->"(2.1.36)"]},
  "(2.1.37)"->{
    Cell[1423924, 51530, 347, 8, 33, "NumberedEquation",
      CellTags->"(2.1.37)"]},
  "i:23"->{
    Cell[1427205, 51629, 1542, 43, 115, "Text",
      CellTags->"i:23"]},
  "i:24"->{
    Cell[1428942, 51683, 95, 1, 30, "Subsubtitle",
      CellTags->{"i:24", "c:11"}]},
  "c:11"->{
    Cell[1428942, 51683, 95, 1, 30, "Subsubtitle",
      CellTags->{"i:24", "c:11"}]},
  "i:25"->{
    Cell[1429040, 51686, 706, 21, 64, "Text",
      CellTags->"i:25"]},
  "Cell 2.25"->{
    Cell[1429771, 51711, 115, 3, 67, "Input",
      CellTags->"Cell 2.25"]},
  "Cell 2.26"->{
    Cell[1575022, 53611, 369, 8, 128, "Input",
      CellTags->"Cell 2.26"]},
  "Cell 2.27"->{
    Cell[1721237, 55556, 379, 9, 147, "Input",
      CellTags->"Cell 2.27"]},
  "Cell 2.28"->{
    Cell[1767823, 56754, 169, 4, 69, "Input",
      CellTags->"Cell 2.28"]},
  "i:94"->{
    Cell[1887612, 58335, 1287, 23, 180, "Text",
      CellTags->"i:94"]},
  "i:26"->{
    Cell[1888902, 58360, 1048, 21, 146, "Text",
      CellTags->"i:26"]},
  "Fig. 2.2"->{
    Cell[1892184, 58438, 4169622, 57386, 216, 4010164, 55412, "GraphicsData", 
    "PostScript", "Picture",
      CellTags->{"Fig. 2.2", "i:32"}],
    Cell[6061809, 115826, 125, 4, 16, "Caption",
      CellTags->"Fig. 2.2"]},
  "i:32"->{
    Cell[1892184, 58438, 4169622, 57386, 216, 4010164, 55412, "GraphicsData", 
    "PostScript", "Picture",
      CellTags->{"Fig. 2.2", "i:32"}]},
  "c:12"->{
    Cell[6061971, 115835, 65, 1, 30, "Subsubtitle",
      CellTags->"c:12"]},
  "i:27"->{
    Cell[6074931, 116292, 1193, 32, 154, "Text",
      CellTags->"i:27"]},
  "Sec. 2.2"->{
    Cell[6077385, 116364, 140, 4, 74, "Subtitle",
      CellTags->{"Sec. 2.2", "i:15", "c:13"}]},
  "i:15"->{
    Cell[6077385, 116364, 140, 4, 74, "Subtitle",
      CellTags->{"Sec. 2.2", "i:15", "c:13"}]},
  "c:13"->{
    Cell[6077385, 116364, 140, 4, 74, "Subtitle",
      CellTags->{"Sec. 2.2", "i:15", "c:13"}]},
  "i:29"->{
    Cell[6077569, 116374, 91, 1, 40, "Subsubtitle",
      CellTags->{"i:29", "c:14"}]},
  "c:14"->{
    Cell[6077569, 116374, 91, 1, 40, "Subsubtitle",
      CellTags->{"i:29", "c:14"}]},
  "(2.2.1)"->{
    Cell[6079503, 116441, 221, 4, 54, "NE2",
      CellTags->"(2.2.1)"]},
  "Fig. 2.3"->{
    Cell[6121442, 117399, 405, 15, 16, "Caption",
      CellTags->"Fig. 2.3"]},
  "(2.2.2)"->{
    Cell[6122079, 117426, 279, 9, 38, "NE2",
      CellTags->"(2.2.2)"]},
  "(2.2.3)"->{
    Cell[6122693, 117451, 274, 7, 38, "NE2",
      CellTags->"(2.2.3)"]},
  "Cell 2.29"->{
    Cell[6123726, 117491, 189, 5, 67, "Input",
      CellTags->"Cell 2.29"]},
  "Cell 2.30"->{
    Cell[6124043, 117504, 116, 3, 67, "Input",
      CellTags->"Cell 2.30"]},
  "Cell 2.31"->{
    Cell[6124564, 117529, 470, 11, 176, "Input",
      CellTags->"Cell 2.31"]},
  "i:30"->{
    Cell[6170219, 118835, 83, 1, 29, "Subsubtitle",
      CellTags->{"i:30", "c:15"}]},
  "c:15"->{
    Cell[6170219, 118835, 83, 1, 29, "Subsubtitle",
      CellTags->{"i:30", "c:15"}]},
  "(2.2.4)"->{
    Cell[6170874, 118862, 698, 20, 102, "NE2",
      CellTags->"(2.2.4)"]},
  "Fig. 2.4"->{
    Cell[6215253, 119899, 257, 9, 16, "Caption",
      CellTags->"Fig. 2.4"]},
  "(2.2.5)"->{
    Cell[6215694, 119918, 231, 7, 33, "NE2",
      CellTags->"(2.2.5)"]},
  "(2.2.6)"->{
    Cell[6216630, 119953, 447, 8, 69, "NE2",
      CellTags->"(2.2.6)"]},
  "(2.2.7)"->{
    Cell[6217537, 119983, 803, 19, 81, "NE2",
      CellTags->"(2.2.7)"]},
  "(2.2.8)"->{
    Cell[6218759, 120020, 375, 6, 69, "NE2",
      CellTags->"(2.2.8)"]},
  "Cell 2.32"->{
    Cell[6219807, 120055, 218, 6, 105, "Input",
      CellTags->"Cell 2.32"]},
  "Cell 2.33"->{
    Cell[6220141, 120069, 121, 3, 67, "Input",
      CellTags->"Cell 2.33"]},
  "Cell 2.34"->{
    Cell[6220754, 120095, 468, 11, 176, "Input",
      CellTags->"Cell 2.34"]},
  "i:31"->{
    Cell[6253817, 120956, 82, 1, 29, "Subsubtitle",
      CellTags->{"i:31", "c:16"}]},
  "c:16"->{
    Cell[6253817, 120956, 82, 1, 29, "Subsubtitle",
      CellTags->{"i:31", "c:16"}]},
  "(2.2.9)"->{
    Cell[6254344, 120975, 686, 20, 81, "NE2",
      CellTags->"(2.2.9)"]},
  "Fig. 2.5"->{
    Cell[6322484, 123260, 250, 9, 16, "Caption",
      CellTags->"Fig. 2.5"]},
  "(2.2.10)"->{
    Cell[6323165, 123286, 232, 7, 33, "NE2",
      CellTags->"(2.2.10)"]},
  "(2.2.11)"->{
    Cell[6323687, 123307, 271, 7, 38, "NE2",
      CellTags->"(2.2.11)"]},
  "Cell 2.35"->{
    Cell[6324492, 123335, 240, 7, 124, "Input",
      CellTags->"Cell 2.35"]},
  "Cell 2.36"->{
    Cell[6325063, 123358, 240, 7, 124, "Input",
      CellTags->"Cell 2.36"]},
  "Cell 2.37"->{
    Cell[6325545, 123376, 234, 7, 105, "Input",
      CellTags->"Cell 2.37"]},
  "Cell 2.38"->{
    Cell[6326438, 123412, 730, 17, 233, "Input",
      CellTags->"Cell 2.38"]},
  "i:33"->{
    Cell[6373137, 124468, 125, 4, 29, "Subsubtitle",
      CellTags->{"i:33", "c:17"}]},
  "c:17"->{
    Cell[6373137, 124468, 125, 4, 29, "Subsubtitle",
      CellTags->{"i:33", "c:17"}]},
  "(2.2.12)"->{
    Cell[6373672, 124486, 128, 5, 33, "NE2",
      CellTags->"(2.2.12)"]},
  "(2.2.13)"->{
    Cell[6375520, 124557, 260, 7, 33, "NE2",
      CellTags->"(2.2.13)"]},
  "(2.2.14)"->{
    Cell[6376745, 124597, 133, 5, 30, "NE2",
      CellTags->"(2.2.14)"]},
  "(2.2.15)"->{
    Cell[6377135, 124615, 195, 6, 33, "NE2",
      CellTags->"(2.2.15)"]},
  "(2.2.16)"->{
    Cell[6377494, 124629, 301, 8, 33, "NE2",
      CellTags->"(2.2.16)"]},
  "i:35"->{
    Cell[6378452, 124661, 408, 9, 45, "Text",
      CellTags->"i:35"]},
  "(2.2.17)"->{
    Cell[6378863, 124672, 249, 7, 38, "NE2",
      CellTags->"(2.2.17)"]},
  "(2.2.18)"->{
    Cell[6380400, 124719, 376, 8, 40, "NE2",
      CellTags->"(2.2.18)"]},
  "(2.2.19)"->{
    Cell[6381256, 124747, 194, 6, 43, "NE2",
      CellTags->"(2.2.19)"]},
  "(2.2.20)"->{
    Cell[6381716, 124768, 303, 7, 38, "NE2",
      CellTags->"(2.2.20)"]},
  "(2.2.21)"->{
    Cell[6382897, 124806, 234, 6, 33, "NE2",
      CellTags->"(2.2.21)"]},
  "(2.2.22)"->{
    Cell[6383542, 124831, 176, 6, 33, "NE2",
      CellTags->"(2.2.22)"]},
  "i:34"->{
    Cell[6383721, 124839, 244, 8, 27, "Text",
      CellTags->"i:34"]},
  "(2.2.23)"->{
    Cell[6383968, 124849, 584, 15, 62, "NE2",
      CellTags->"(2.2.23)"]},
  "(2.2.24)"->{
    Cell[6385470, 124903, 540, 15, 35, "NE2",
      CellTags->"(2.2.24)"]},
  "Ex. 2.2"->{
    Cell[6386746, 124940, 78, 1, 29, "Subsubtitle",
      CellTags->{"Ex. 2.2", "c:18"}]},
  "c:18"->{
    Cell[6386746, 124940, 78, 1, 29, "Subsubtitle",
      CellTags->{"Ex. 2.2", "c:18"}]},
  "i:36"->{
    Cell[6391862, 125134, 351, 9, 58, "Text",
      CellTags->"i:36"]},
  "Sec. 2.3"->{
    Cell[6393219, 125177, 84, 1, 40, "Subtitle",
      CellTags->{"Sec. 2.3", "i:38", "c:19"}]},
  "i:38"->{
    Cell[6393219, 125177, 84, 1, 40, "Subtitle",
      CellTags->{"Sec. 2.3", "i:38", "c:19"}]},
  "c:19"->{
    Cell[6393219, 125177, 84, 1, 40, "Subtitle",
      CellTags->{"Sec. 2.3", "i:38", "c:19"}]},
  "c:20"->{
    Cell[6393347, 125184, 103, 2, 41, "Subsubtitle",
      CellTags->"c:20"]},
  "(2.3.1)"->{
    Cell[6395048, 125241, 422, 11, 38, "NE3",
      CellTags->"(2.3.1)"]},
  "i:37"->{
    Cell[6395473, 125254, 667, 19, 61, "Text",
      CellTags->"i:37"]},
  "(2.3.2)"->{
    Cell[6396143, 125275, 424, 10, 32, "NE3",
      CellTags->"(2.3.2)"]},
  "(2.3.3)"->{
    Cell[6396728, 125295, 305, 8, 34, "NE3",
      CellTags->"(2.3.3)"]},
  "(2.3.4)"->{
    Cell[6397778, 125330, 496, 11, 52, "NE3",
      CellTags->"(2.3.4)"]},
  "(2.3.5)"->{
    Cell[6398425, 125350, 376, 10, 38, "NE3",
      CellTags->"(2.3.5)"]},
  "i:39"->{
    Cell[6398804, 125362, 660, 26, 47, "Text",
      CellTags->"i:39"]},
  "i:110"->{
    Cell[6399467, 125390, 913, 30, 84, "Text",
      CellTags->"i:110"]},
  "i:95"->{
    Cell[6400983, 125442, 1112, 27, 129, "Text",
      CellTags->"i:95"]},
  "i:40"->{
    Cell[6402098, 125471, 2287, 50, 252, "Table",
      CellTags->{"i:40", "Table 2.1"}]},
  "Table 2.1"->{
    Cell[6402098, 125471, 2287, 50, 252, "Table",
      CellTags->{"i:40", "Table 2.1"}]},
  "(2.3.6)"->{
    Cell[6404745, 125535, 436, 15, 33, "NE3",
      CellTags->"(2.3.6)"]},
  "Cell 2.39"->{
    Cell[6405333, 125561, 184, 5, 67, "Input",
      CellTags->"Cell 2.39"]},
  "Cell 2.40"->{
    Cell[6407101, 125621, 413, 10, 105, "Input",
      CellTags->"Cell 2.40"]},
  "i:42"->{
    Cell[6407768, 125645, 1060, 32, 108, "Text",
      CellTags->"i:42"]},
  "Cell 2.41"->{
    Cell[6409038, 125691, 171, 5, 67, "Input",
      CellTags->"Cell 2.41"]},
  "Cell 2.42"->{
    Cell[6409873, 125727, 173, 4, 67, "Input",
      CellTags->"Cell 2.42"]},
  "i:41"->{
    Cell[6410557, 125749, 1568, 42, 182, "Table",
      CellTags->"i:41"]},
  "Cell 2.43"->{
    Cell[6412556, 125810, 259, 5, 105, "Input",
      CellTags->"Cell 2.43"]},
  "Cell 2.44"->{
    Cell[6432974, 126383, 150, 4, 73, "Input",
      CellTags->"Cell 2.44"]},
  "Cell 2.45"->{
    Cell[6433553, 126406, 425, 9, 146, "Input",
      CellTags->"Cell 2.45"]},
  "(2.3.7)"->{
    Cell[6521243, 129227, 159, 6, 30, "NE3",
      CellTags->"(2.3.7)"]},
  "i:86"->{
    Cell[6521679, 129243, 477, 10, 82, "Text",
      CellTags->"i:86"]},
  "Cell 2.46"->{
    Cell[6522159, 129255, 225, 6, 75, "Input",
      CellTags->"Cell 2.46"]},
  "Cell 2.47"->{
    Cell[6522641, 129274, 220, 5, 86, "Input",
      CellTags->"Cell 2.47"]},
  "Fig. 2.6"->{
    Cell[6683028, 133352, 397, 9, 29, "Caption",
      CellTags->"Fig. 2.6"]},
  "(2.3.8)"->{
    Cell[6685204, 133423, 190, 6, 29, "NE3",
      CellTags->{"(2.3.8)", "i:87"}]},
  "i:87"->{
    Cell[6685204, 133423, 190, 6, 29, "NE3",
      CellTags->{"(2.3.8)", "i:87"}]},
  "i:43"->{
    Cell[6686506, 133457, 93, 1, 30, "Subsubtitle",
      CellTags->{"i:43", "c:21"}]},
  "c:21"->{
    Cell[6686506, 133457, 93, 1, 30, "Subsubtitle",
      CellTags->{"i:43", "c:21"}]},
  "(2.3.9)"->{
    Cell[6687510, 133491, 348, 11, 34, "NE3",
      CellTags->"(2.3.9)"]},
  "Cell 2.48"->{
    Cell[6689048, 133549, 160, 4, 67, "Input",
      CellTags->"Cell 2.48"]},
  "(2.3.10)"->{
    Cell[6691109, 133617, 447, 12, 57, "NE3",
      CellTags->"(2.3.10)"]},
  "(2.3.11)"->{
    Cell[6691844, 133641, 447, 12, 57, "NE3",
      CellTags->"(2.3.11)"]},
  "Cell 2.49"->{
    Cell[6692907, 133681, 179, 4, 67, "Input",
      CellTags->"Cell 2.49"]},
  "Cell 2.50"->{
    Cell[6693237, 133695, 192, 5, 86, "Input",
      CellTags->"Cell 2.50"]},
  "Cell 2.51"->{
    Cell[6693830, 133718, 179, 4, 67, "Input",
      CellTags->"Cell 2.51"]},
  "Cell 2.52"->{
    Cell[6694201, 133735, 192, 5, 86, "Input",
      CellTags->"Cell 2.52"]},
  "c:22"->{
    Cell[6694515, 133749, 86, 1, 30, "Subsubtitle",
      CellTags->"c:22"]},
  "c:23"->{
    Cell[6694626, 133754, 86, 1, 42, "Section",
      CellTags->"c:23"]},
  "(2.3.12)"->{
    Cell[6695575, 133787, 252, 7, 57, "NE3",
      CellTags->"(2.3.12)"]},
  "(2.3.13)"->{
    Cell[6696121, 133809, 131, 5, 57, "NE3",
      CellTags->"(2.3.13)"]},
  "(2.3.14)"->{
    Cell[6697495, 133859, 295, 7, 57, "NE3",
      CellTags->"(2.3.14)"]},
  "(2.3.15)"->{
    Cell[6697966, 133876, 176, 6, 57, "NE3",
      CellTags->"(2.3.15)"]},
  "c:24"->{
    Cell[6698283, 133892, 86, 1, 31, "Section",
      CellTags->"c:24"]},
  "(2.3.16)"->{
    Cell[6698523, 133900, 309, 8, 57, "NE3",
      CellTags->"(2.3.16)"]},
  "(2.3.17)"->{
    Cell[6699079, 133917, 581, 9, 57, "NE3",
      CellTags->"(2.3.17)"]},
  "(2.3.18)"->{
    Cell[6700031, 133942, 228, 4, 57, "NE3",
      CellTags->"(2.3.18)"]},
  "(2.3.19)"->{
    Cell[6700784, 133967, 234, 7, 57, "NE3",
      CellTags->"(2.3.19)"]},
  "i:44"->{
    Cell[6701055, 133979, 68, 1, 31, "Section",
      CellTags->{"i:44", "c:25"}]},
  "c:25"->{
    Cell[6701055, 133979, 68, 1, 31, "Section",
      CellTags->{"i:44", "c:25"}]},
  "(2.3.20)"->{
    Cell[6701458, 133998, 367, 10, 57, "NE3",
      CellTags->"(2.3.20)"]},
  "(2.3.21)"->{
    Cell[6702613, 134040, 171, 6, 57, "NE3",
      CellTags->"(2.3.21)"]},
  "i:45"->{
    Cell[6705223, 134118, 94, 1, 31, "Section",
      CellTags->{"i:45", "c:26"}]},
  "c:26"->{
    Cell[6705223, 134118, 94, 1, 31, "Section",
      CellTags->{"i:45", "c:26"}]},
  "(2.3.22)"->{
    Cell[6709322, 134252, 307, 7, 34, "NE3",
      CellTags->"(2.3.22)"]},
  "(2.3.23)"->{
    Cell[6710493, 134292, 814, 23, 34, "NE3",
      CellTags->"(2.3.23)"]},
  "(2.3.24)"->{
    Cell[6711973, 134342, 154, 6, 29, "NE3",
      CellTags->"(2.3.24)"]},
  "i:107"->{
    Cell[6712847, 134373, 1035, 24, 112, "Text",
      CellTags->"i:107"]},
  "Cell 2.53"->{
    Cell[6714557, 134422, 169, 4, 67, "Input",
      CellTags->"Cell 2.53"]},
  "Fig. 2.7"->{
    Cell[6809482, 136562, 573, 17, 29, "Caption",
      CellTags->"Fig. 2.7"]},
  "Fig. 2.8"->{
    Cell[6880563, 138438, 148, 6, 16, "Caption",
      CellTags->"Fig. 2.8"]},
  "i:88"->{
    Cell[6880714, 138446, 1079, 27, 112, "Text",
      CellTags->"i:88"]},
  "i:46"->{
    Cell[6882168, 138491, 86, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:27"}]},
  "c:27"->{
    Cell[6882168, 138491, 86, 1, 30, "Subsubtitle",
      CellTags->{"i:46", "c:27"}]},
  "c:28"->{
    Cell[6882279, 138496, 51, 1, 42, "Section",
      CellTags->"c:28"]},
  "(2.3.25)"->{
    Cell[6884027, 138556, 450, 11, 34, "NE3",
      CellTags->"(2.3.25)"]},
  "i:112"->{
    Cell[6885752, 138611, 423, 16, 27, "Text",
      CellTags->"i:112"]},
  "(2.3.26)"->{
    Cell[6886178, 138629, 522, 15, 29, "NE3",
      CellTags->"(2.3.26)"]},
  "(2.3.27)"->{
    Cell[6886892, 138652, 495, 14, 45, "NE3",
      CellTags->"(2.3.27)"]},
  "(2.3.28)"->{
    Cell[6887846, 138682, 237, 7, 32, "NE3",
      CellTags->"(2.3.28)"]},
  "c:29"->{
    Cell[6888308, 138700, 70, 1, 31, "Section",
      CellTags->"c:29"]},
  "(2.3.29)"->{
    Cell[6888857, 138721, 504, 9, 34, "NE3",
      CellTags->"(2.3.29)"]},
  "c:30"->{
    Cell[6890035, 138756, 95, 3, 31, "Section",
      CellTags->"c:30"]},
  "(2.3.30)"->{
    Cell[6890253, 138766, 180, 6, 57, "NE3",
      CellTags->"(2.3.30)"]},
  "(2.3.31)"->{
    Cell[6892146, 138837, 300, 9, 57, "NE3",
      CellTags->"(2.3.31)"]},
  "(2.3.32)"->{
    Cell[6893234, 138876, 329, 8, 57, "NE3",
      CellTags->"(2.3.32)"]},
  "(2.3.33)"->{
    Cell[6897391, 139002, 270, 7, 57, "NE3",
      CellTags->"(2.3.33)"]},
  "i:50"->{
    Cell[6897698, 139014, 78, 1, 31, "Section",
      CellTags->{"i:50", "c:31"}]},
  "c:31"->{
    Cell[6897698, 139014, 78, 1, 31, "Section",
      CellTags->{"i:50", "c:31"}]},
  "(2.3.34)"->{
    Cell[6897986, 139025, 299, 5, 34, "NE3",
      CellTags->"(2.3.34)"]},
  "(2.3.35)"->{
    Cell[6899046, 139059, 279, 8, 34, "NE3",
      CellTags->"(2.3.35)"]},
  "(2.3.36)"->{
    Cell[6900011, 139088, 233, 4, 38, "NE3",
      CellTags->"(2.3.36)"]},
  "(2.3.37)"->{
    Cell[6901175, 139123, 291, 8, 38, "NE3",
      CellTags->"(2.3.37)"]},
  "(2.3.38)"->{
    Cell[6901660, 139140, 353, 5, 37, "NE3",
      CellTags->"(2.3.38)"]},
  "(2.3.39)"->{
    Cell[6902225, 139154, 217, 6, 36, "NE3",
      CellTags->"(2.3.39)"]},
  "(2.3.40)"->{
    Cell[6903153, 139189, 304, 5, 37, "NE3",
      CellTags->"(2.3.40)"]},
  "Cell 2.54"->{
    Cell[6905419, 139252, 254, 6, 86, "Input",
      CellTags->"Cell 2.54"]},
  "i:89"->{
    Cell[7244976, 148571, 83, 1, 31, "Section",
      CellTags->{"i:89", "c:32"}]},
  "c:32"->{
    Cell[7244976, 148571, 83, 1, 31, "Section",
      CellTags->{"i:89", "c:32"}]},
  "(2.3.41)"->{
    Cell[7245588, 148590, 539, 12, 34, "NE3",
      CellTags->"(2.3.41)"]},
  "Cell 2.55"->{
    Cell[7247156, 148635, 131, 3, 67, "Input",
      CellTags->"Cell 2.55"]},
  "i:96"->{
    Cell[7247352, 148644, 200, 7, 27, "Text",
      CellTags->"i:96"]},
  "Cell 2.56"->{
    Cell[7247577, 148655, 153, 4, 67, "Input",
      CellTags->"Cell 2.56"]},
  "(2.3.42)"->{
    Cell[7248717, 148692, 380, 7, 34, "NE3",
      CellTags->"(2.3.42)"]},
  "(2.3.43)"->{
    Cell[7249257, 148708, 335, 6, 50, "NE3",
      CellTags->"(2.3.43)"]},
  "(2.3.44)"->{
    Cell[7249882, 148727, 325, 5, 40, "NE3",
      CellTags->"(2.3.44)"]},
  "i:51"->{
    Cell[7252289, 148790, 72, 1, 31, "Section",
      CellTags->{"i:51", "c:33"}]},
  "c:33"->{
    Cell[7252289, 148790, 72, 1, 31, "Section",
      CellTags->{"i:51", "c:33"}]},
  "(2.3.45)"->{
    Cell[7252590, 148801, 208, 7, 33, "NE3",
      CellTags->"(2.3.45)"]},
  "(2.3.46)"->{
    Cell[7253787, 148846, 444, 14, 45, "NE3",
      CellTags->"(2.3.46)"]},
  "(2.3.47)"->{
    Cell[7257166, 148943, 1060, 26, 38, "NE3",
      CellTags->"(2.3.47)"]},
  "Cell 2.57"->{
    Cell[7258425, 148980, 149, 4, 67, "Input",
      CellTags->"Cell 2.57"]},
  "i:49"->{
    Cell[7258713, 148993, 100, 1, 31, "Section",
      CellTags->{"i:49", "c:34"}]},
  "c:34"->{
    Cell[7258713, 148993, 100, 1, 31, "Section",
      CellTags->{"i:49", "c:34"}]},
  "i:48"->{
    Cell[7259102, 149003, 408, 11, 45, "Text",
      CellTags->"i:48"]},
  "(2.3.48)"->{
    Cell[7259513, 149016, 218, 7, 30, "NE3",
      CellTags->"(2.3.48)"]},
  "(2.3.49)"->{
    Cell[7260741, 149060, 326, 8, 30, "NE3",
      CellTags->"(2.3.49)"]},
  "Cell 2.58"->{
    Cell[7263216, 149135, 135, 3, 67, "Input",
      CellTags->"Cell 2.58"]},
  "Cell 2.59"->{
    Cell[7263637, 149154, 130, 3, 67, "Input",
      CellTags->"Cell 2.59"]},
  "(2.3.50)"->{
    Cell[7335537, 150215, 376, 6, 37, "NE3",
      CellTags->"(2.3.50)"]},
  "(2.3.51)"->{
    Cell[7336378, 150240, 677, 11, 73, "NE3",
      CellTags->"(2.3.51)"]},
  "(2.3.52)"->{
    Cell[7337716, 150279, 255, 5, 37, "NE3",
      CellTags->"(2.3.52)"]},
  "c:35"->{
    Cell[7339148, 150326, 72, 1, 30, "Subsubtitle",
      CellTags->"c:35"]},
  "i:53"->{
    Cell[7339245, 150331, 76, 1, 42, "Section",
      CellTags->{"i:53", "c:36"}]},
  "c:36"->{
    Cell[7339245, 150331, 76, 1, 42, "Section",
      CellTags->{"i:53", "c:36"}]},
  "(2.3.53)"->{
    Cell[7341137, 150383, 873, 23, 33, "NE3",
      CellTags->"(2.3.53)"]},
  "(2.3.54)"->{
    Cell[7343090, 150448, 993, 31, 32, "NE3",
      CellTags->"(2.3.54)"]},
  "(2.3.55)"->{
    Cell[7345029, 150513, 1172, 35, 33, "NE3",
      CellTags->"(2.3.55)"]},
  "(2.3.56)"->{
    Cell[7346610, 150563, 525, 18, 32, "NE3",
      CellTags->"(2.3.56)"]},
  "Fig. 2.9"->{
    Cell[7384841, 151638, 116, 4, 16, "Caption",
      CellTags->"Fig. 2.9"]},
  "(2.3.57)"->{
    Cell[7385587, 151661, 264, 7, 38, "NE3",
      CellTags->"(2.3.57)"]},
  "(2.3.58)"->{
    Cell[7386759, 151697, 783, 22, 38, "NE3",
      CellTags->"(2.3.58)"]},
  "(2.3.59)"->{
    Cell[7387873, 151734, 1087, 27, 40, "NE3",
      CellTags->"(2.3.59)"]},
  "(2.3.60)"->{
    Cell[7389372, 151780, 617, 13, 40, "NE3",
      CellTags->"(2.3.60)"]},
  "(2.3.61)"->{
    Cell[7391293, 151836, 360, 7, 40, "NE3",
      CellTags->"(2.3.61)"]},
  "(2.3.62)"->{
    Cell[7392447, 151867, 876, 22, 33, "NE3",
      CellTags->"(2.3.62)"]},
  "(2.3.63)"->{
    Cell[7394231, 151927, 760, 20, 57, "NE3",
      CellTags->"(2.3.63)"]},
  "(2.3.64)"->{
    Cell[7398671, 152074, 777, 22, 57, "NE3",
      CellTags->"(2.3.64)"]},
  "Cell 2.60"->{
    Cell[7400846, 152143, 302, 9, 105, "Input",
      CellTags->"Cell 2.60"]},
  "Cell 2.61"->{
    Cell[7401494, 152165, 172, 5, 67, "Input",
      CellTags->"Cell 2.61"]},
  "Cell 2.62"->{
    Cell[7401951, 152184, 116, 3, 67, "Input",
      CellTags->"Cell 2.62"]},
  "Cell 2.63"->{
    Cell[7536788, 154131, 97, 3, 71, "Input",
      CellTags->"Cell 2.63"]},
  "Cell 2.64"->{
    Cell[7537410, 154157, 160, 4, 75, "Input",
      CellTags->"Cell 2.64"]},
  "Cell 2.65"->{
    Cell[7571591, 154853, 160, 4, 57, "Input",
      CellTags->"Cell 2.65"]},
  "(2.3.65)"->{
    Cell[7605648, 155579, 398, 12, 57, "NE3",
      CellTags->"(2.3.65)"]},
  "i:55"->{
    Cell[7606049, 155593, 1470, 43, 112, "Text",
      CellTags->"i:55"]},
  "i:111"->{
    Cell[7607522, 155638, 1303, 35, 129, "Text",
      CellTags->"i:111"]},
  "Fig. 2.10"->{
    Cell[7670114, 157092, 619, 17, 29, "Caption",
      CellTags->"Fig. 2.10"]},
  "(2.3.66)"->{
    Cell[7671963, 157148, 180, 6, 32, "NE3",
      CellTags->{"(2.3.66)", "i:56"}]},
  "i:56"->{
    Cell[7671963, 157148, 180, 6, 32, "NE3",
      CellTags->{"(2.3.66)", "i:56"}]},
  "(2.3.67)"->{
    Cell[7675167, 157248, 1132, 18, 135, "NE3",
      CellTags->"(2.3.67)"]},
  "i:101"->{
    Cell[7679677, 157377, 1817, 63, 105, "Text",
      CellTags->"i:101"]},
  "(2.3.68)"->{
    Cell[7682199, 157467, 1538, 58, 76, "NE3",
      CellTags->"(2.3.68)"]},
  "Cell 2.66"->{
    Cell[7684594, 157558, 317, 7, 128, "Input",
      CellTags->"Cell 2.66"]},
  "i:98"->{
    Cell[7749975, 158901, 655, 17, 78, "Text",
      CellTags->{"i:98", "i:102"}]},
  "i:102"->{
    Cell[7749975, 158901, 655, 17, 78, "Text",
      CellTags->{"i:98", "i:102"}]},
  "Cell 2.67"->{
    Cell[7750655, 158922, 91, 3, 67, "Input",
      CellTags->"Cell 2.67"]},
  "i:103"->{
    Cell[7750812, 158931, 403, 10, 61, "Text",
      CellTags->"i:103"]},
  "Cell 2.68"->{
    Cell[7751240, 158945, 121, 3, 67, "Input",
      CellTags->"Cell 2.68"]},
  "i:114"->{
    Cell[7751506, 158956, 261, 10, 27, "Text",
      CellTags->"i:114"]},
  "Cell 2.69"->{
    Cell[7751792, 158970, 89, 3, 67, "Input",
      CellTags->"Cell 2.69"]},
  "Cell 2.70"->{
    Cell[7889886, 160932, 103, 3, 67, "Input",
      CellTags->"Cell 2.70"]},
  "i:99"->{
    Cell[7890317, 160950, 1171, 39, 78, "Text",
      CellTags->"i:99"]},
  "Cell 2.71"->{
    Cell[7891513, 160993, 161, 4, 67, "Input",
      CellTags->"Cell 2.71"]},
  "Cell 2.72"->{
    Cell[7892016, 161013, 111, 3, 67, "Input",
      CellTags->"Cell 2.72"]},
  "Cell 2.73"->{
    Cell[7892260, 161024, 163, 4, 67, "Input",
      CellTags->"Cell 2.73"]},
  "Cell 2.74"->{
    Cell[7892498, 161034, 96, 3, 67, "Input",
      CellTags->"Cell 2.74"]},
  "Cell 2.75"->{
    Cell[7892777, 161050, 121, 3, 67, "Input",
      CellTags->"Cell 2.75"]},
  "Cell 2.76"->{
    Cell[7894351, 161082, 111, 3, 73, "Input",
      CellTags->"Cell 2.76"]},
  "Cell 2.77"->{
    Cell[7894749, 161098, 127, 3, 75, "Input",
      CellTags->"Cell 2.77"]},
  "Cell 2.78"->{
    Cell[8612155, 198550, 131, 3, 67, "Input",
      CellTags->"Cell 2.78"]},
  "Cell 2.79"->{
    Cell[8612932, 198578, 182, 5, 75, "Input",
      CellTags->"Cell 2.79"]},
  "Cell 2.80"->{
    Cell[8613341, 198595, 216, 5, 98, "Input",
      CellTags->"Cell 2.80"]},
  "i:57"->{
    Cell[8734245, 204273, 471, 8, 78, "Text",
      CellTags->"i:57"]},
  "Cell 2.81"->{
    Cell[8734719, 204283, 158, 4, 75, "Input",
      CellTags->"Cell 2.81"]},
  "Cell 2.82"->{
    Cell[8735352, 204300, 126, 3, 67, "Input",
      CellTags->"Cell 2.82"]},
  "Cell 2.83"->{
    Cell[8736195, 204327, 194, 4, 67, "Input",
      CellTags->"Cell 2.83"]},
  "Cell 2.84"->{
    Cell[8736482, 204338, 127, 3, 73, "Input",
      CellTags->"Cell 2.84"]},
  "Cell 2.85"->{
    Cell[8736992, 204355, 97, 3, 73, "Input",
      CellTags->"Cell 2.85"]},
  "i:104"->{
    Cell[8737146, 204364, 388, 13, 44, "Text",
      CellTags->"i:104"]},
  "Cell 2.86"->{
    Cell[8737559, 204381, 227, 5, 111, "Input",
      CellTags->"Cell 2.86"]},
  "i:54"->{
    Cell[8941633, 207166, 156, 4, 54, "Subsubtitle",
      CellTags->{"i:54", "c:38"}]},
  "c:38"->{
    Cell[8941633, 207166, 156, 4, 54, "Subsubtitle",
      CellTags->{"i:54", "c:38"}]},
  "(2.3.69)"->{
    Cell[8942831, 207205, 391, 12, 34, "NE3",
      CellTags->"(2.3.69)"]},
  "(2.3.70)"->{
    Cell[8943664, 207233, 237, 7, 33, "NE3",
      CellTags->"(2.3.70)"]},
  "(2.3.71)"->{
    Cell[8944266, 207256, 292, 8, 33, "NE3",
      CellTags->"(2.3.71)"]},
  "(2.3.72)"->{
    Cell[8945477, 207295, 390, 9, 49, "NE3",
      CellTags->"(2.3.72)"]},
  "(2.3.73)"->{
    Cell[8946885, 207336, 234, 7, 32, "NE3",
      CellTags->"(2.3.73)"]},
  "i:84"->{
    Cell[8951374, 207478, 887, 26, 79, "Text",
      CellTags->"i:84"]},
  "(2.3.74)"->{
    Cell[8953341, 207536, 333, 6, 47, "NE3",
      CellTags->"(2.3.74)"]},
  "(2.3.75)"->{
    Cell[8954643, 207575, 430, 11, 47, "NE3",
      CellTags->"(2.3.75)"]},
  "Cell 2.87"->{
    Cell[8955528, 207604, 227, 5, 105, "Input",
      CellTags->"Cell 2.87"]},
  "(2.3.76)"->{
    Cell[8956264, 207630, 311, 10, 43, "NE3",
      CellTags->"(2.3.76)"]},
  "(2.3.77)"->{
    Cell[8957334, 207670, 417, 8, 78, "NE3",
      CellTags->{"(2.3.77)", "i:59"}]},
  "i:59"->{
    Cell[8957334, 207670, 417, 8, 78, "NE3",
      CellTags->{"(2.3.77)", "i:59"}]},
  "Fig. 2.11"->{
    Cell[8988002, 208505, 306, 10, 16, "Caption",
      CellTags->"Fig. 2.11"]},
  "i:83"->{
    Cell[8988908, 208537, 169, 4, 27, "Text",
      CellTags->"i:83"]},
  "(2.3.78)"->{
    Cell[8989080, 208543, 184, 6, 32, "NE3",
      CellTags->"(2.3.78)"]},
  "(2.3.79)"->{
    Cell[8989671, 208567, 300, 7, 35, "NE3",
      CellTags->"(2.3.79)"]},
  "(2.3.80)"->{
    Cell[8990097, 208581, 317, 10, 35, "NE3",
      CellTags->"(2.3.80)"]},
  "(2.3.81)"->{
    Cell[8990831, 208608, 141, 6, 30, "NE3",
      CellTags->"(2.3.81)"]},
  "i:60"->{
    Cell[8991383, 208631, 450, 12, 61, "Text",
      CellTags->"i:60"]},
  "Cell 2.88"->{
    Cell[8991858, 208647, 192, 4, 67, "Input",
      CellTags->"Cell 2.88"]},
  "(2.3.82)"->{
    Cell[9158293, 210977, 331, 8, 57, "NE3",
      CellTags->"(2.3.82)"]},
  "(2.3.83)"->{
    Cell[9159307, 211008, 285, 8, 57, "NE3",
      CellTags->"(2.3.83)"]},
  "(2.3.84)"->{
    Cell[9160137, 211037, 381, 10, 57, "NE3",
      CellTags->"(2.3.84)"]},
  "(2.3.85)"->{
    Cell[9160906, 211064, 360, 10, 73, "NE3",
      CellTags->"(2.3.85)"]},
  "(2.3.86)"->{
    Cell[9163061, 211134, 243, 7, 32, "NE3",
      CellTags->"(2.3.86)"]},
  "(2.3.87)"->{
    Cell[9164547, 211177, 350, 8, 73, "NE3",
      CellTags->{"(2.3.87)", "i:61"}]},
  "i:61"->{
    Cell[9164547, 211177, 350, 8, 73, "NE3",
      CellTags->{"(2.3.87)", "i:61"}]},
  "Ex. 2.3"->{
    Cell[9165476, 211203, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 2.3", "c:39"}]},
  "c:39"->{
    Cell[9165476, 211203, 78, 1, 30, "Subsubtitle",
      CellTags->{"Ex. 2.3", "c:39"}]},
  "i:113"->{
    Cell[9176512, 211602, 343, 14, 30, "Text",
      CellTags->"i:113"]},
  "(2.3.88)"->{
    Cell[9176858, 211618, 335, 8, 34, "NE3",
      CellTags->"(2.3.88)"]},
  "i:106"->{
    Cell[9177196, 211628, 1820, 50, 116, "Text",
      CellTags->"i:106"]},
  "(2.3.89)"->{
    Cell[9180782, 211741, 398, 13, 29, "NE3",
      CellTags->"(2.3.89)"]},
  "Table 2.2"->{
    Cell[9185461, 211894, 76, 1, 27, "Text",
      CellTags->"Table 2.2"]},
  "Cell 2.89"->{
    Cell[9185540, 211897, 1643, 25, 467, "Input",
      Evaluatable->True,
      CellTags->"Cell 2.89"]},
  "i:100"->{
    Cell[9190590, 212039, 1208, 40, 95, "Text",
      CellTags->"i:100"]},
  "Fig. 2.12"->{
    Cell[9247551, 212827, 54, 1, 16, "Caption",
      CellTags->"Fig. 2.12"]},
  "i:81"->{
    Cell[9250698, 212931, 1115, 30, 96, "Text",
      CellTags->"i:81"]},
  "i:47"->{
    Cell[9254526, 213041, 190, 6, 27, "Text",
      CellTags->"i:47"]},
  "Cell 2.90"->{
    Cell[9254719, 213049, 194, 6, 67, "Input",
      CellTags->"Cell 2.90"]},
  "Sec. 2.4"->{
    Cell[9257758, 213146, 84, 1, 40, "Subtitle",
      CellTags->{"Sec. 2.4", "i:62", "c:40"}]},
  "i:62"->{
    Cell[9257758, 213146, 84, 1, 40, "Subtitle",
      CellTags->{"Sec. 2.4", "i:62", "c:40"}]},
  "c:40"->{
    Cell[9257758, 213146, 84, 1, 40, "Subtitle",
      CellTags->{"Sec. 2.4", "i:62", "c:40"}]},
  "c:41"->{
    Cell[9257886, 213153, 61, 1, 40, "Subsubtitle",
      CellTags->"c:41"]},
  "(2.4.1)"->{
    Cell[9258290, 213167, 126, 5, 33, "NE4",
      CellTags->"(2.4.1)"]},
  "i:85"->{
    Cell[9258419, 213174, 605, 19, 44, "Text",
      CellTags->"i:85"]},
  "(2.4.2)"->{
    Cell[9259027, 213195, 146, 5, 33, "NE4",
      CellTags->"(2.4.2)"]},
  "(2.4.3)"->{
    Cell[9259755, 213224, 236, 7, 32, "NE4",
      CellTags->"(2.4.3)"]},
  "i:63"->{
    Cell[9262114, 213308, 559, 15, 61, "Text",
      CellTags->"i:63"]},
  "i:64"->{
    Cell[9265999, 213432, 129, 4, 29, "Subsubtitle",
      CellTags->{"i:64", "c:42"}]},
  "c:42"->{
    Cell[9265999, 213432, 129, 4, 29, "Subsubtitle",
      CellTags->{"i:64", "c:42"}]},
  "c:43"->{
    Cell[9266153, 213440, 56, 1, 42, "Section",
      CellTags->"c:43"]},
  "(2.4.4)"->{
    Cell[9266687, 213458, 615, 13, 42, "NE4",
      CellTags->"(2.4.4)"]},
  "(2.4.5)"->{
    Cell[9268167, 213505, 424, 11, 27, "NE4",
      CellTags->"(2.4.5)"]},
  "(2.4.6)"->{
    Cell[9269158, 213537, 338, 8, 27, "NE4",
      CellTags->"(2.4.6)"]},
  "(2.4.7)"->{
    Cell[9273873, 213693, 273, 6, 29, "NE4",
      CellTags->"(2.4.7)"]},
  "(2.4.8)"->{
    Cell[9274530, 213719, 217, 4, 43, "NE4",
      CellTags->"(2.4.8)"]},
  "i:68"->{
    Cell[9274750, 213725, 406, 15, 28, "Text",
      CellTags->"i:68"]},
  "(2.4.9)"->{
    Cell[9276222, 213777, 139, 3, 27, "NE4",
      CellTags->"(2.4.9)"]},
  "(2.4.10)"->{
    Cell[9278201, 213845, 604, 11, 49, "NE4",
      CellTags->"(2.4.10)"]},
  "c:44"->{
    Cell[9279590, 213882, 46, 1, 31, "Section",
      CellTags->"c:44"]},
  "c:45"->{
    Cell[9282895, 214001, 53, 1, 31, "Section",
      CellTags->"c:45"]},
  "(2.4.11)"->{
    Cell[9283203, 214012, 852, 23, 42, "NE4",
      CellTags->"(2.4.11)"]},
  "(2.4.12)"->{
    Cell[9284573, 214057, 199, 4, 33, "NE4",
      CellTags->"(2.4.12)"]},
  "(2.4.13)"->{
    Cell[9285374, 214086, 450, 13, 45, "NE4",
      CellTags->"(2.4.13)"]},
  "(2.4.14)"->{
    Cell[9286111, 214111, 497, 13, 43, "NE4",
      CellTags->"(2.4.14)"]},
  "(2.4.15)"->{
    Cell[9286679, 214128, 107, 2, 27, "NE4",
      CellTags->"(2.4.15)"]},
  "i:70"->{
    Cell[9287842, 214169, 145, 4, 29, "Subsubtitle",
      CellTags->{"i:70", "c:46"}]},
  "c:46"->{
    Cell[9287842, 214169, 145, 4, 29, "Subsubtitle",
      CellTags->{"i:70", "c:46"}]},
  "i:108"->{
    Cell[9287990, 214175, 416, 16, 50, "Text",
      CellTags->"i:108"]},
  "(2.4.16)"->{
    Cell[9288409, 214193, 253, 7, 37, "NE4",
      CellTags->"(2.4.16)"]},
  "(2.4.17)"->{
    Cell[9289171, 214218, 126, 2, 36, "NE4",
      CellTags->"(2.4.17)"]},
  "(2.4.18)"->{
    Cell[9291448, 214294, 188, 6, 36, "NE4",
      CellTags->"(2.4.18)"]},
  "(2.4.19)"->{
    Cell[9293999, 214379, 428, 13, 38, "NE4",
      CellTags->"(2.4.19)"]},
  "i:90"->{
    Cell[9294430, 214394, 530, 17, 44, "Text",
      CellTags->"i:90"]},
  "(2.4.20)"->{
    Cell[9294963, 214413, 538, 13, 59, "NE4",
      CellTags->"(2.4.20)"]},
  "(2.4.21)"->{
    Cell[9295582, 214430, 449, 16, 29, "NE4",
      CellTags->"(2.4.21)"]},
  "(2.4.22)"->{
    Cell[9297656, 214504, 2212, 56, 108, "NE4",
      CellTags->"(2.4.22)"]},
  "(2.4.23)"->{
    Cell[9300870, 214598, 492, 17, 31, "NE4",
      CellTags->"(2.4.23)"]},
  "(2.4.24)"->{
    Cell[9303514, 214682, 227, 7, 29, "NE4",
      CellTags->"(2.4.24)"]},
  "Cell 2.91"->{
    Cell[9309467, 214882, 433, 10, 143, "Input",
      CellTags->"Cell 2.91"]},
  "Cell 2.92"->{
    Cell[9309974, 214896, 150, 4, 86, "Input",
      CellTags->"Cell 2.92"]},
  "Cell 2.93"->{
    Cell[9310236, 214909, 105, 3, 67, "Input",
      CellTags->"Cell 2.93"]},
  "Cell 2.94"->{
    Cell[9310728, 214931, 198, 5, 86, "Input",
      CellTags->"Cell 2.94"]},
  "i:105"->{
    Cell[9324523, 215340, 181, 5, 44, "Text",
      CellTags->"i:105"]},
  "Cell 2.95"->{
    Cell[9324729, 215349, 239, 6, 86, "Input",
      CellTags->"Cell 2.95"]},
  "Cell 2.96"->{
    Cell[9325299, 215372, 220, 5, 86, "Input",
      CellTags->"Cell 2.96"]},
  "i:65"->{
    Cell[9343642, 215900, 103, 1, 29, "Subsubtitle",
      CellTags->{"i:65", "c:47"}]},
  "c:47"->{
    Cell[9343642, 215900, 103, 1, 29, "Subsubtitle",
      CellTags->{"i:65", "c:47"}]},
  "(2.4.25)"->{
    Cell[9345316, 215949, 289, 11, 32, "NE4",
      CellTags->"(2.4.25)"]},
  "(2.4.26)"->{
    Cell[9347211, 216017, 141, 5, 28, "NE4",
      CellTags->"(2.4.26)"]},
  "(2.4.27)"->{
    Cell[9347918, 216043, 368, 10, 31, "NE4",
      CellTags->"(2.4.27)"]},
  "(2.4.28)"->{
    Cell[9348368, 216057, 409, 12, 33, "NE4",
      CellTags->"(2.4.28)"]},
  "i:82"->{
    Cell[9348780, 216071, 784, 26, 61, "Text",
      CellTags->"i:82"]},
  "(2.4.29)"->{
    Cell[9349884, 216112, 394, 13, 32, "NE4",
      CellTags->"(2.4.29)"]},
  "(2.4.30)"->{
    Cell[9350452, 216135, 222, 7, 57, "NE4",
      CellTags->"(2.4.30)"]},
  "(2.4.31)"->{
    Cell[9351898, 216182, 258, 8, 42, "NE4",
      CellTags->"(2.4.31)"]},
  "(2.4.32)"->{
    Cell[9352289, 216199, 258, 8, 42, "NE4",
      CellTags->"(2.4.32)"]},
  "(2.4.33)"->{
    Cell[9352777, 216219, 522, 14, 55, "NE4",
      CellTags->"(2.4.33)"]},
  "(2.4.34)"->{
    Cell[9354479, 216281, 185, 3, 30, "NE4",
      CellTags->"(2.4.34)"]},
  "(2.4.35)"->{
    Cell[9355922, 216331, 261, 7, 30, "NE4",
      CellTags->"(2.4.35)"]},
  "(2.4.36)"->{
    Cell[9356568, 216358, 1292, 32, 86, "NE4",
      CellTags->{"(2.4.36)", "i:66"}]},
  "i:66"->{
    Cell[9356568, 216358, 1292, 32, 86, "NE4",
      CellTags->{"(2.4.36)", "i:66"}]},
  "i:67"->{
    Cell[9357863, 216392, 1030, 33, 62, "Text",
      CellTags->"i:67"]},
  "i:69"->{
    Cell[9358930, 216430, 146, 4, 29, "Subsubtitle",
      CellTags->{"i:69", "c:48"}]},
  "c:48"->{
    Cell[9358930, 216430, 146, 4, 29, "Subsubtitle",
      CellTags->{"i:69", "c:48"}]},
  "c:49"->{
    Cell[9359101, 216438, 67, 1, 42, "Section",
      CellTags->"c:49"]},
  "i:109"->{
    Cell[9359171, 216441, 194, 7, 27, "Text",
      CellTags->"i:109"]},
  "(2.4.37)"->{
    Cell[9359368, 216450, 138, 5, 36, "NE4",
      CellTags->"(2.4.37)"]},
  "(2.4.38)"->{
    Cell[9359659, 216464, 262, 7, 37, "NE4",
      CellTags->"(2.4.38)"]},
  "(2.4.39)"->{
    Cell[9360357, 216484, 574, 13, 42, "NE4",
      CellTags->"(2.4.39)"]},
  "(2.4.40)"->{
    Cell[9360977, 216501, 146, 3, 27, "NE4",
      CellTags->"(2.4.40)"]},
  "(2.4.41)"->{
    Cell[9362294, 216544, 1401, 37, 41, "NE4",
      CellTags->"(2.4.41)"]},
  "i:92"->{
    Cell[9363698, 216583, 607, 19, 61, "Text",
      CellTags->"i:92"]},
  "(2.4.42)"->{
    Cell[9364308, 216604, 1148, 32, 41, "NE4",
      CellTags->"(2.4.42)"]},
  "(2.4.43)"->{
    Cell[9365532, 216640, 1145, 30, 40, "NE4",
      CellTags->"(2.4.43)"]},
  "(2.4.44)"->{
    Cell[9366862, 216678, 1254, 35, 48, "NE4",
      CellTags->"(2.4.44)"]},
  "i:75"->{
    Cell[9368119, 216715, 475, 13, 61, "Text",
      CellTags->"i:75"]},
  "i:74"->{
    Cell[9368597, 216730, 3662, 87, 158, "Table",
      CellTags->{"i:74", "Table 2.3"}]},
  "Table 2.3"->{
    Cell[9368597, 216730, 3662, 87, 158, "Table",
      CellTags->{"i:74", "Table 2.3"}]},
  "i:73"->{
    Cell[9372281, 216821, 10076, 196, 323, "Table",
      CellTags->{"i:73", "Table 2.4"}]},
  "Table 2.4"->{
    Cell[9372281, 216821, 10076, 196, 323, "Table",
      CellTags->{"i:73", "Table 2.4"}]},
  "(2.4.45)"->{
    Cell[9382684, 217031, 1114, 30, 40, "NE4",
      CellTags->"(2.4.45)"]},
  "(2.4.46)"->{
    Cell[9384073, 217074, 154, 3, 26, "NE4",
      CellTags->"(2.4.46)"]},
  "(2.4.47)"->{
    Cell[9385116, 217113, 393, 14, 28, "NE4",
      CellTags->"(2.4.47)"]},
  "(2.4.48)"->{
    Cell[9385537, 217131, 584, 19, 43, "NE4",
      CellTags->"(2.4.48)"]},
  "(2.4.49)"->{
    Cell[9386437, 217166, 967, 24, 32, "NE4",
      CellTags->"(2.4.49)"]},
  "Cell 2.97"->{
    Cell[9387519, 217199, 521, 13, 143, "Input",
      CellTags->"Cell 2.97"]},
  "Cell 2.98"->{
    Cell[9389151, 217242, 195, 4, 86, "Input",
      CellTags->"Cell 2.98"]},
  "Cell 2.99"->{
    Cell[9389419, 217252, 93, 3, 67, "Input",
      CellTags->"Cell 2.99"]},
  "i:76"->{
    Cell[9390673, 217292, 490, 15, 61, "Text",
      CellTags->"i:76"]},
  "(2.4.50)"->{
    Cell[9391166, 217309, 684, 18, 42, "NE4",
      CellTags->"(2.4.50)"]},
  "(2.4.51)"->{
    Cell[9393227, 217368, 568, 17, 41, "NE4",
      CellTags->"(2.4.51)"]},
  "i:77"->{
    Cell[9393798, 217387, 610, 11, 95, "Text",
      CellTags->"i:77"]},
  "(2.4.52)"->{
    Cell[9394786, 217414, 436, 15, 32, "NE4",
      CellTags->"(2.4.52)"]},
  "i:78"->{
    Cell[9395225, 217431, 807, 24, 78, "Text",
      CellTags->"i:78"]},
  "i:79"->{
    Cell[9398214, 217511, 2384, 67, 214, "Text",
      CellTags->"i:79"]},
  "c:50"->{
    Cell[9400635, 217583, 46, 1, 31, "Section",
      CellTags->"c:50"]},
  "Cell 2.100"->{
    Cell[9403313, 217679, 318, 7, 143, "Input",
      CellTags->"Cell 2.100"]},
  "Cell 2.101"->{
    Cell[9403788, 217696, 656, 14, 181, "Input",
      CellTags->"Cell 2.101"]},
  "Cell 2.102"->{
    Cell[9404562, 217719, 344, 7, 124, "Input",
      CellTags->"Cell 2.102"]},
  "Cell 2.103"->{
    Cell[9405009, 217733, 118, 3, 67, "Input",
      CellTags->"Cell 2.103"]},
  "Cell 2.104"->{
    Cell[9405759, 217758, 744, 14, 220, "Input",
      CellTags->"Cell 2.104"]},
  "c:51"->{
    Cell[9455968, 218738, 65, 1, 29, "Subsubtitle",
      CellTags->"c:51"]},
  "i:91"->{
    Cell[9464942, 219081, 609, 19, 44, "Text",
      CellTags->"i:91"]},
  "c:52"->{
    Cell[9478387, 219554, 50, 1, 40, "Subtitle",
      CellTags->"c:52"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 9521039, 220851},
  {"Sec. 2.1", 9521119, 220854},
  {"i:14", 9521221, 220857},
  {"c:2", 9521322, 220860},
  {"c:3", 9521423, 220863},
  {"i:1", 9521504, 220866},
  {"(2.1.1)", 9521584, 220869},
  {"(2.1.2)", 9521679, 220872},
  {"i:97", 9521772, 220875},
  {"Fig. 2.1", 9521856, 220878},
  {"i:2", 9521942, 220881},
  {"Cell 2.1", 9522028, 220884},
  {"Cell 2.2", 9522118, 220887},
  {"i:3", 9522203, 220890},
  {"i:4", 9522283, 220893},
  {"(2.1.3)", 9522367, 220896},
  {"c:4", 9522463, 220899},
  {"i:5", 9522548, 220902},
  {"(2.1.4)", 9522632, 220905},
  {"(2.1.5)", 9522731, 220908},
  {"(2.1.6)", 9522831, 220911},
  {"(2.1.7)", 9522930, 220914},
  {"Cell 2.3", 9523030, 220917},
  {"Cell 2.4", 9523121, 220920},
  {"(2.1.8)", 9523210, 220923},
  {"(2.1.9)", 9523310, 220926},
  {"(2.1.10)", 9523411, 220929},
  {"c:5", 9523507, 220932},
  {"Cell 2.5", 9523597, 220935},
  {"Cell 2.6", 9523688, 220938},
  {"Cell 2.7", 9523778, 220941},
  {"Cell 2.8", 9523868, 220944},
  {"Cell 2.9", 9523959, 220947},
  {"Cell 2.10", 9524051, 220950},
  {"i:7", 9524137, 220953},
  {"(2.1.11)", 9524221, 220956},
  {"(2.1.12)", 9524322, 220959},
  {"i:13", 9524419, 220962},
  {"Cell 2.11", 9524505, 220965},
  {"Cell 2.12", 9524597, 220968},
  {"c:6", 9524684, 220971},
  {"Cell 2.13", 9524775, 220974},
  {"Cell 2.14", 9524868, 220977},
  {"(2.1.13)", 9524960, 220980},
  {"Cell 2.15", 9525063, 220983},
  {"(2.1.14)", 9525156, 220986},
  {"i:9", 9525263, 220989},
  {"Cell 2.16", 9525376, 220992},
  {"c:7", 9525464, 220995},
  {"Cell 2.17", 9525556, 220998},
  {"i:16", 9525645, 221001},
  {"i:11", 9525731, 221004},
  {"(2.1.15)", 9525818, 221007},
  {"i:12", 9525917, 221010},
  {"i:17", 9526001, 221013},
  {"c:8", 9526098, 221016},
  {"(2.1.16)", 9526200, 221019},
  {"(2.1.17)", 9526304, 221022},
  {"(2.1.18)", 9526408, 221025},
  {"(2.1.19)", 9526513, 221028},
  {"i:21", 9526613, 221031},
  {"Cell 2.18", 9526702, 221034},
  {"Cell 2.19", 9526796, 221037},
  {"Cell 2.20", 9526890, 221040},
  {"Cell 2.21", 9526984, 221043},
  {"Cell 2.22", 9527077, 221046},
  {"Cell 2.23", 9527170, 221049},
  {"Cell 2.24", 9527264, 221052},
  {"c:9", 9527353, 221055},
  {"(2.1.20)", 9527445, 221058},
  {"(2.1.21)", 9527549, 221061},
  {"(2.1.22)", 9527653, 221064},
  {"(2.1.23)", 9527756, 221067},
  {"(2.1.24)", 9527860, 221070},
  {"(2.1.25)", 9527963, 221073},
  {"i:18", 9528072, 221076},
  {"(2.1.26)", 9528185, 221079},
  {"(2.1.27)", 9528288, 221082},
  {"i:19", 9528397, 221085},
  {"i:6", 9528505, 221088},
  {"(2.1.28)", 9528592, 221091},
  {"(2.1.29)", 9528695, 221094},
  {"(2.1.30)", 9528799, 221097},
  {"(2.1.31)", 9528905, 221100},
  {"(2.1.32)", 9529009, 221103},
  {"(2.1.33)", 9529114, 221106},
  {"i:20", 9529224, 221109},
  {"(2.1.34)", 9529338, 221112},
  {"i:22", 9529437, 221115},
  {"c:10", 9529537, 221118},
  {"(2.1.35)", 9529641, 221121},
  {"(2.1.36)", 9529744, 221124},
  {"(2.1.37)", 9529847, 221127},
  {"i:23", 9529946, 221130},
  {"i:24", 9530032, 221133},
  {"c:11", 9530131, 221136},
  {"i:25", 9530230, 221139},
  {"Cell 2.25", 9530319, 221142},
  {"Cell 2.26", 9530413, 221145},
  {"Cell 2.27", 9530508, 221148},
  {"Cell 2.28", 9530603, 221151},
  {"i:94", 9530692, 221154},
  {"i:26", 9530778, 221157},
  {"Fig. 2.2", 9530868, 221160},
  {"i:32", 9531106, 221166},
  {"c:12", 9531266, 221170},
  {"i:27", 9531356, 221173},
  {"Sec. 2.2", 9531447, 221176},
  {"i:15", 9531557, 221179},
  {"c:13", 9531667, 221182},
  {"i:29", 9531777, 221185},
  {"c:14", 9531877, 221188},
  {"(2.2.1)", 9531980, 221191},
  {"Fig. 2.3", 9532070, 221194},
  {"(2.2.2)", 9532165, 221197},
  {"(2.2.3)", 9532254, 221200},
  {"Cell 2.29", 9532345, 221203},
  {"Cell 2.30", 9532440, 221206},
  {"Cell 2.31", 9532535, 221209},
  {"i:30", 9532627, 221212},
  {"c:15", 9532727, 221215},
  {"(2.2.4)", 9532830, 221218},
  {"Fig. 2.4", 9532922, 221221},
  {"(2.2.5)", 9533016, 221224},
  {"(2.2.6)", 9533105, 221227},
  {"(2.2.7)", 9533194, 221230},
  {"(2.2.8)", 9533284, 221233},
  {"Cell 2.32", 9533375, 221236},
  {"Cell 2.33", 9533471, 221239},
  {"Cell 2.34", 9533566, 221242},
  {"i:31", 9533658, 221245},
  {"c:16", 9533758, 221248},
  {"(2.2.9)", 9533861, 221251},
  {"Fig. 2.5", 9533952, 221254},
  {"(2.2.10)", 9534047, 221257},
  {"(2.2.11)", 9534138, 221260},
  {"Cell 2.35", 9534230, 221263},
  {"Cell 2.36", 9534326, 221266},
  {"Cell 2.37", 9534422, 221269},
  {"Cell 2.38", 9534518, 221272},
  {"i:33", 9534610, 221275},
  {"c:17", 9534711, 221278},
  {"(2.2.12)", 9534816, 221281},
  {"(2.2.13)", 9534907, 221284},
  {"(2.2.14)", 9534998, 221287},
  {"(2.2.15)", 9535089, 221290},
  {"(2.2.16)", 9535180, 221293},
  {"i:35", 9535267, 221296},
  {"(2.2.17)", 9535355, 221299},
  {"(2.2.18)", 9535446, 221302},
  {"(2.2.19)", 9535537, 221305},
  {"(2.2.20)", 9535628, 221308},
  {"(2.2.21)", 9535719, 221311},
  {"(2.2.22)", 9535810, 221314},
  {"i:34", 9535897, 221317},
  {"(2.2.23)", 9535985, 221320},
  {"(2.2.24)", 9536077, 221323},
  {"Ex. 2.2", 9536168, 221326},
  {"c:18", 9536271, 221329},
  {"i:36", 9536374, 221332},
  {"Sec. 2.3", 9536462, 221335},
  {"i:38", 9536571, 221338},
  {"c:19", 9536680, 221341},
  {"c:20", 9536789, 221344},
  {"(2.3.1)", 9536883, 221347},
  {"i:37", 9536970, 221350},
  {"(2.3.2)", 9537058, 221353},
  {"(2.3.3)", 9537148, 221356},
  {"(2.3.4)", 9537237, 221359},
  {"(2.3.5)", 9537327, 221362},
  {"i:39", 9537414, 221365},
  {"i:110", 9537500, 221368},
  {"i:95", 9537586, 221371},
  {"i:40", 9537673, 221374},
  {"Table 2.1", 9537781, 221377},
  {"(2.3.6)", 9537887, 221380},
  {"Cell 2.39", 9537979, 221383},
  {"Cell 2.40", 9538074, 221386},
  {"i:42", 9538166, 221389},
  {"Cell 2.41", 9538258, 221392},
  {"Cell 2.42", 9538353, 221395},
  {"i:41", 9538443, 221398},
  {"Cell 2.43", 9538536, 221401},
  {"Cell 2.44", 9538632, 221404},
  {"Cell 2.45", 9538727, 221407},
  {"(2.3.7)", 9538821, 221410},
  {"i:86", 9538907, 221413},
  {"Cell 2.46", 9538997, 221416},
  {"Cell 2.47", 9539092, 221419},
  {"Fig. 2.6", 9539186, 221422},
  {"(2.3.8)", 9539280, 221425},
  {"i:87", 9539376, 221428},
  {"i:43", 9539472, 221431},
  {"c:21", 9539572, 221434},
  {"(2.3.9)", 9539675, 221437},
  {"Cell 2.48", 9539767, 221440},
  {"(2.3.10)", 9539861, 221443},
  {"(2.3.11)", 9539953, 221446},
  {"Cell 2.49", 9540046, 221449},
  {"Cell 2.50", 9540141, 221452},
  {"Cell 2.51", 9540236, 221455},
  {"Cell 2.52", 9540331, 221458},
  {"c:22", 9540421, 221461},
  {"c:23", 9540511, 221464},
  {"(2.3.12)", 9540601, 221467},
  {"(2.3.13)", 9540692, 221470},
  {"(2.3.14)", 9540783, 221473},
  {"(2.3.15)", 9540874, 221476},
  {"c:24", 9540961, 221479},
  {"(2.3.16)", 9541051, 221482},
  {"(2.3.17)", 9541142, 221485},
  {"(2.3.18)", 9541233, 221488},
  {"(2.3.19)", 9541324, 221491},
  {"i:44", 9541411, 221494},
  {"c:25", 9541507, 221497},
  {"(2.3.20)", 9541607, 221500},
  {"(2.3.21)", 9541699, 221503},
  {"i:45", 9541786, 221506},
  {"c:26", 9541882, 221509},
  {"(2.3.22)", 9541982, 221512},
  {"(2.3.23)", 9542073, 221515},
  {"(2.3.24)", 9542165, 221518},
  {"i:107", 9542253, 221521},
  {"Cell 2.53", 9542346, 221524},
  {"Fig. 2.7", 9542440, 221527},
  {"Fig. 2.8", 9542536, 221530},
  {"i:88", 9542627, 221533},
  {"i:46", 9542714, 221536},
  {"c:27", 9542814, 221539},
  {"c:28", 9542914, 221542},
  {"(2.3.25)", 9543004, 221545},
  {"i:112", 9543093, 221548},
  {"(2.3.26)", 9543183, 221551},
  {"(2.3.27)", 9543275, 221554},
  {"(2.3.28)", 9543367, 221557},
  {"c:29", 9543454, 221560},
  {"(2.3.29)", 9543544, 221563},
  {"c:30", 9543631, 221566},
  {"(2.3.30)", 9543721, 221569},
  {"(2.3.31)", 9543812, 221572},
  {"(2.3.32)", 9543903, 221575},
  {"(2.3.33)", 9543994, 221578},
  {"i:50", 9544081, 221581},
  {"c:31", 9544177, 221584},
  {"(2.3.34)", 9544277, 221587},
  {"(2.3.35)", 9544368, 221590},
  {"(2.3.36)", 9544459, 221593},
  {"(2.3.37)", 9544550, 221596},
  {"(2.3.38)", 9544641, 221599},
  {"(2.3.39)", 9544732, 221602},
  {"(2.3.40)", 9544823, 221605},
  {"Cell 2.54", 9544915, 221608},
  {"i:89", 9545005, 221611},
  {"c:32", 9545101, 221614},
  {"(2.3.41)", 9545201, 221617},
  {"Cell 2.55", 9545294, 221620},
  {"i:96", 9545384, 221623},
  {"Cell 2.56", 9545473, 221626},
  {"(2.3.42)", 9545567, 221629},
  {"(2.3.43)", 9545658, 221632},
  {"(2.3.44)", 9545749, 221635},
  {"i:51", 9545836, 221638},
  {"c:33", 9545932, 221641},
  {"(2.3.45)", 9546032, 221644},
  {"(2.3.46)", 9546123, 221647},
  {"(2.3.47)", 9546215, 221650},
  {"Cell 2.57", 9546309, 221653},
  {"i:49", 9546399, 221656},
  {"c:34", 9546496, 221659},
  {"i:48", 9546593, 221662},
  {"(2.3.48)", 9546682, 221665},
  {"(2.3.49)", 9546773, 221668},
  {"Cell 2.58", 9546865, 221671},
  {"Cell 2.59", 9546960, 221674},
  {"(2.3.50)", 9547054, 221677},
  {"(2.3.51)", 9547145, 221680},
  {"(2.3.52)", 9547237, 221683},
  {"c:35", 9547324, 221686},
  {"i:53", 9547414, 221689},
  {"c:36", 9547510, 221692},
  {"(2.3.53)", 9547610, 221695},
  {"(2.3.54)", 9547702, 221698},
  {"(2.3.55)", 9547794, 221701},
  {"(2.3.56)", 9547887, 221704},
  {"Fig. 2.9", 9547979, 221707},
  {"(2.3.57)", 9548074, 221710},
  {"(2.3.58)", 9548165, 221713},
  {"(2.3.59)", 9548257, 221716},
  {"(2.3.60)", 9548350, 221719},
  {"(2.3.61)", 9548442, 221722},
  {"(2.3.62)", 9548533, 221725},
  {"(2.3.63)", 9548625, 221728},
  {"(2.3.64)", 9548717, 221731},
  {"Cell 2.60", 9548810, 221734},
  {"Cell 2.61", 9548906, 221737},
  {"Cell 2.62", 9549001, 221740},
  {"Cell 2.63", 9549096, 221743},
  {"Cell 2.64", 9549190, 221746},
  {"Cell 2.65", 9549285, 221749},
  {"(2.3.65)", 9549379, 221752},
  {"i:55", 9549467, 221755},
  {"i:111", 9549555, 221758},
  {"Fig. 2.10", 9549648, 221761},
  {"(2.3.66)", 9549745, 221764},
  {"i:56", 9549842, 221767},
  {"(2.3.67)", 9549943, 221770},
  {"i:101", 9550034, 221773},
  {"(2.3.68)", 9550126, 221776},
  {"Cell 2.66", 9550220, 221779},
  {"i:98", 9550311, 221782},
  {"i:102", 9550408, 221785},
  {"Cell 2.67", 9550509, 221788},
  {"i:103", 9550599, 221791},
  {"Cell 2.68", 9550690, 221794},
  {"i:114", 9550781, 221797},
  {"Cell 2.69", 9550872, 221800},
  {"Cell 2.70", 9550966, 221803},
  {"i:99", 9551056, 221806},
  {"Cell 2.71", 9551147, 221809},
  {"Cell 2.72", 9551242, 221812},
  {"Cell 2.73", 9551337, 221815},
  {"Cell 2.74", 9551432, 221818},
  {"Cell 2.75", 9551526, 221821},
  {"Cell 2.76", 9551621, 221824},
  {"Cell 2.77", 9551716, 221827},
  {"Cell 2.78", 9551811, 221830},
  {"Cell 2.79", 9551906, 221833},
  {"Cell 2.80", 9552001, 221836},
  {"i:57", 9552091, 221839},
  {"Cell 2.81", 9552180, 221842},
  {"Cell 2.82", 9552275, 221845},
  {"Cell 2.83", 9552370, 221848},
  {"Cell 2.84", 9552465, 221851},
  {"Cell 2.85", 9552560, 221854},
  {"i:104", 9552650, 221857},
  {"Cell 2.86", 9552741, 221860},
  {"i:54", 9552832, 221863},
  {"c:38", 9552933, 221866},
  {"(2.3.69)", 9553038, 221869},
  {"(2.3.70)", 9553130, 221872},
  {"(2.3.71)", 9553221, 221875},
  {"(2.3.72)", 9553312, 221878},
  {"(2.3.73)", 9553403, 221881},
  {"i:84", 9553490, 221884},
  {"(2.3.74)", 9553579, 221887},
  {"(2.3.75)", 9553670, 221890},
  {"Cell 2.87", 9553763, 221893},
  {"(2.3.76)", 9553858, 221896},
  {"(2.3.77)", 9553950, 221899},
  {"i:59", 9554047, 221902},
  {"Fig. 2.11", 9554149, 221905},
  {"i:83", 9554242, 221908},
  {"(2.3.78)", 9554330, 221911},
  {"(2.3.79)", 9554421, 221914},
  {"(2.3.80)", 9554512, 221917},
  {"(2.3.81)", 9554604, 221920},
  {"i:60", 9554691, 221923},
  {"Cell 2.88", 9554781, 221926},
  {"(2.3.82)", 9554875, 221929},
  {"(2.3.83)", 9554966, 221932},
  {"(2.3.84)", 9555057, 221935},
  {"(2.3.85)", 9555149, 221938},
  {"(2.3.86)", 9555241, 221941},
  {"(2.3.87)", 9555332, 221944},
  {"i:61", 9555429, 221947},
  {"Ex. 2.3", 9555529, 221950},
  {"c:39", 9555632, 221953},
  {"i:113", 9555736, 221956},
  {"(2.3.88)", 9555826, 221959},
  {"i:106", 9555914, 221962},
  {"(2.3.89)", 9556006, 221965},
  {"Table 2.2", 9556099, 221968},
  {"Cell 2.89", 9556192, 221971},
  {"i:100", 9556311, 221975},
  {"Fig. 2.12", 9556403, 221978},
  {"i:81", 9556494, 221981},
  {"i:47", 9556580, 221984},
  {"Cell 2.90", 9556669, 221987},
  {"Sec. 2.4", 9556763, 221990},
  {"i:62", 9556872, 221993},
  {"c:40", 9556981, 221996},
  {"c:41", 9557090, 221999},
  {"(2.4.1)", 9557183, 222002},
  {"i:85", 9557269, 222005},
  {"(2.4.2)", 9557357, 222008},
  {"(2.4.3)", 9557446, 222011},
  {"i:63", 9557532, 222014},
  {"i:64", 9557617, 222017},
  {"c:42", 9557718, 222020},
  {"c:43", 9557819, 222023},
  {"(2.4.4)", 9557908, 222026},
  {"(2.4.5)", 9557998, 222029},
  {"(2.4.6)", 9558088, 222032},
  {"(2.4.7)", 9558177, 222035},
  {"(2.4.8)", 9558266, 222038},
  {"i:68", 9558352, 222041},
  {"(2.4.9)", 9558440, 222044},
  {"(2.4.10)", 9558530, 222047},
  {"c:44", 9558618, 222050},
  {"c:45", 9558704, 222053},
  {"(2.4.11)", 9558794, 222056},
  {"(2.4.12)", 9558886, 222059},
  {"(2.4.13)", 9558977, 222062},
  {"(2.4.14)", 9559069, 222065},
  {"(2.4.15)", 9559161, 222068},
  {"i:70", 9559248, 222071},
  {"c:46", 9559349, 222074},
  {"i:108", 9559451, 222077},
  {"(2.4.16)", 9559541, 222080},
  {"(2.4.17)", 9559632, 222083},
  {"(2.4.18)", 9559723, 222086},
  {"(2.4.19)", 9559814, 222089},
  {"i:90", 9559902, 222092},
  {"(2.4.20)", 9559991, 222095},
  {"(2.4.21)", 9560083, 222098},
  {"(2.4.22)", 9560175, 222101},
  {"(2.4.23)", 9560269, 222104},
  {"(2.4.24)", 9560361, 222107},
  {"Cell 2.91", 9560453, 222110},
  {"Cell 2.92", 9560550, 222113},
  {"Cell 2.93", 9560645, 222116},
  {"Cell 2.94", 9560740, 222119},
  {"i:105", 9560831, 222122},
  {"Cell 2.95", 9560921, 222125},
  {"Cell 2.96", 9561016, 222128},
  {"i:65", 9561106, 222131},
  {"c:47", 9561207, 222134},
  {"(2.4.25)", 9561312, 222137},
  {"(2.4.26)", 9561404, 222140},
  {"(2.4.27)", 9561495, 222143},
  {"(2.4.28)", 9561587, 222146},
  {"i:82", 9561675, 222149},
  {"(2.4.29)", 9561764, 222152},
  {"(2.4.30)", 9561856, 222155},
  {"(2.4.31)", 9561947, 222158},
  {"(2.4.32)", 9562038, 222161},
  {"(2.4.33)", 9562129, 222164},
  {"(2.4.34)", 9562221, 222167},
  {"(2.4.35)", 9562312, 222170},
  {"(2.4.36)", 9562403, 222173},
  {"i:66", 9562502, 222176},
  {"i:67", 9562601, 222179},
  {"i:69", 9562687, 222182},
  {"c:48", 9562788, 222185},
  {"c:49", 9562889, 222188},
  {"i:109", 9562976, 222191},
  {"(2.4.37)", 9563065, 222194},
  {"(2.4.38)", 9563156, 222197},
  {"(2.4.39)", 9563247, 222200},
  {"(2.4.40)", 9563339, 222203},
  {"(2.4.41)", 9563430, 222206},
  {"i:92", 9563519, 222209},
  {"(2.4.42)", 9563608, 222212},
  {"(2.4.43)", 9563701, 222215},
  {"(2.4.44)", 9563794, 222218},
  {"i:75", 9563883, 222221},
  {"i:74", 9563968, 222224},
  {"Table 2.3", 9564076, 222227},
  {"i:73", 9564179, 222230},
  {"Table 2.4", 9564289, 222233},
  {"(2.4.45)", 9564398, 222236},
  {"(2.4.46)", 9564491, 222239},
  {"(2.4.47)", 9564582, 222242},
  {"(2.4.48)", 9564674, 222245},
  {"(2.4.49)", 9564766, 222248},
  {"Cell 2.97", 9564859, 222251},
  {"Cell 2.98", 9564956, 222254},
  {"Cell 2.99", 9565051, 222257},
  {"i:76", 9565140, 222260},
  {"(2.4.50)", 9565229, 222263},
  {"(2.4.51)", 9565321, 222266},
  {"i:77", 9565409, 222269},
  {"(2.4.52)", 9565498, 222272},
  {"i:78", 9565586, 222275},
  {"i:79", 9565671, 222278},
  {"c:50", 9565758, 222281},
  {"Cell 2.100", 9565850, 222284},
  {"Cell 2.101", 9565948, 222287},
  {"Cell 2.102", 9566047, 222290},
  {"Cell 2.103", 9566145, 222293},
  {"Cell 2.104", 9566242, 222296},
  {"c:51", 9566335, 222299},
  {"i:91", 9566425, 222302},
  {"c:52", 9566510, 222305}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 68, 1, 69, "Title",
  CellTags->"c:1"],
Cell[1798, 55, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1839, 59, 109, 1, 39, "Subtitle",
  CellTags->{"Sec. 2.1", "i:14", "c:2"}],
Cell[1951, 62, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[1992, 66, 60, 1, 41, "Subsubtitle",
  CellTags->"c:3"],
Cell[2055, 69, 358, 15, 26, "Text",
  CellTags->"i:1"],
Cell[2416, 86, 130, 5, 28, "NumberedEquation",
  CellTags->"(2.1.1)"],
Cell[2549, 93, 620, 23, 43, "Text"],
Cell[3172, 118, 366, 12, 43, "Text"],
Cell[3541, 132, 232, 7, 26, "NumberedEquation",
  CellTags->"(2.1.2)"],
Cell[3776, 141, 1195, 41, 77, "Text",
  CellTags->"i:97"],
Cell[4974, 184, 31574, 827, 232, 8732, 541, "GraphicsData", "PostScript", \
"Picture"],
Cell[36551, 1013, 159, 6, 15, "Caption",
  CellTags->"Fig. 2.1"],
Cell[36713, 1021, 1325, 30, 128, "Text",
  CellTags->"i:2"],
Cell[38041, 1053, 305, 5, 60, "Text"],
Cell[38349, 1060, 1469, 47, 95, "Text"],

Cell[CellGroupData[{
Cell[39843, 1111, 244, 6, 105, "Input",
  CellTags->"Cell 2.1"],
Cell[40090, 1119, 77528, 1451, 232, 9116, 602, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117655, 2575, 194, 5, 85, "Input",
  CellTags->"Cell 2.2"],
Cell[117852, 2582, 49488, 972, 232, 6535, 438, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[167355, 3557, 463, 15, 43, "Text"],
Cell[167821, 3574, 364, 11, 26, "Text",
  CellTags->"i:3"],
Cell[168188, 3587, 608, 21, 27, "Text"],
Cell[168799, 3610, 502, 19, 43, "Text"],
Cell[169304, 3631, 1261, 38, 95, "Text"],
Cell[170568, 3671, 285, 8, 43, "Text"],
Cell[170856, 3681, 547, 18, 88, "Text"],
Cell[171406, 3701, 880, 21, 95, "Text",
  CellTags->"i:4"],
Cell[172289, 3724, 777, 25, 30, "NumberedEquation",
  CellTags->"(2.1.3)"]
}, Closed]],

Cell[CellGroupData[{
Cell[173103, 3754, 96, 1, 30, "Subsubtitle",
  CellTags->"c:4"],
Cell[173202, 3757, 994, 34, 77, "Text",
  CellTags->"i:5"],
Cell[174199, 3793, 187, 6, 33, "NumberedEquation",
  CellTags->"(2.1.4)"],
Cell[174389, 3801, 627, 23, 43, "Text"],
Cell[175019, 3826, 614, 14, 80, "NumberedEquation",
  CellTags->"(2.1.5)"],
Cell[175636, 3842, 1017, 30, 85, "Text"],
Cell[176656, 3874, 358, 9, 37, "NumberedEquation",
  CellTags->"(2.1.6)"],
Cell[177017, 3885, 220, 6, 37, "NumberedEquation",
  CellTags->"(2.1.7)"],
Cell[177240, 3893, 178, 5, 26, "Text"],
Cell[177421, 3900, 201, 5, 35, "Text"],
Cell[177625, 3907, 467, 17, 45, "Text"],

Cell[CellGroupData[{
Cell[178117, 3928, 393, 9, 142, "Input",
  CellTags->"Cell 2.3"],
Cell[178513, 3939, 47, 1, 45, "Output"]
}, Open  ]],
Cell[178575, 3943, 449, 13, 43, "Text"],

Cell[CellGroupData[{
Cell[179049, 3960, 220, 6, 85, "Input",
  CellTags->"Cell 2.4"],
Cell[179272, 3968, 46, 1, 63, "Output"]
}, Open  ]],
Cell[179333, 3972, 669, 23, 43, "Text"],
Cell[180005, 3997, 245, 8, 46, "Text"],
Cell[180253, 4007, 831, 29, 60, "Text"],
Cell[181087, 4038, 626, 11, 73, "NumberedEquation",
  CellTags->"(2.1.8)"],
Cell[181716, 4051, 863, 29, 60, "Text"],
Cell[182582, 4082, 412, 11, 85, "NumberedEquation",
  CellTags->"(2.1.9)"],
Cell[182997, 4095, 863, 31, 60, "Text"],
Cell[183863, 4128, 286, 6, 40, "NumberedEquation",
  CellTags->"(2.1.10)"]
}, Closed]],

Cell[CellGroupData[{
Cell[184186, 4139, 61, 1, 30, "Subsubtitle",
  CellTags->"c:5"],
Cell[184250, 4142, 979, 33, 78, "Text"],

Cell[CellGroupData[{
Cell[185254, 4179, 279, 6, 105, "Input",
  CellTags->"Cell 2.5"],
Cell[185536, 4187, 21603, 466, 233, 3461, 238, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[207154, 4656, 444, 13, 43, "Text"],
Cell[207601, 4671, 173, 4, 85, "Input",
  CellTags->"Cell 2.6"],
Cell[207777, 4677, 181, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[207983, 4687, 115, 3, 66, "Input",
  CellTags->"Cell 2.7"],
Cell[208101, 4692, 76518, 1247, 232, 5190, 362, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[284634, 5942, 936, 29, 77, "Text"],

Cell[CellGroupData[{
Cell[285595, 5975, 368, 9, 123, "Input",
  CellTags->"Cell 2.8"],
Cell[285966, 5986, 119, 2, 66, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286122, 5993, 260, 6, 105, "Input",
  CellTags->"Cell 2.9"],
Cell[286385, 6001, 38, 1, 63, "Output"]
}, Open  ]],
Cell[286438, 6005, 130, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[286593, 6014, 103, 3, 67, "Input",
  CellTags->"Cell 2.10"],
Cell[286699, 6019, 210, 3, 64, "Output"]
}, Open  ]],
Cell[286924, 6025, 122, 4, 27, "Text",
  CellTags->"i:7"],
Cell[287049, 6031, 189, 3, 58, "NumberedEquation",
  CellTags->"(2.1.11)"],
Cell[287241, 6036, 555, 17, 44, "Text"],
Cell[287799, 6055, 132, 5, 29, "NumberedEquation",
  CellTags->"(2.1.12)"],
Cell[287934, 6062, 1086, 34, 78, "Text"],
Cell[289023, 6098, 320, 9, 64, "Text",
  CellTags->"i:13"],
Cell[289346, 6109, 514, 13, 62, "Text"],
Cell[289863, 6124, 152, 4, 69, "Input",
  CellTags->"Cell 2.11"],
Cell[290018, 6130, 391, 13, 44, "Text"],

Cell[CellGroupData[{
Cell[290434, 6147, 247, 6, 107, "Input",
  CellTags->"Cell 2.12"],

Cell[CellGroupData[{
Cell[290706, 6157, 21811, 604, 233, 6507, 411, "GraphicsData", "PostScript", \
"Graphics"],
Cell[312520, 6763, 22451, 603, 57, 6337, 400, "GraphicsData", "PostScript", \
"Graphics"],
Cell[334974, 7368, 22451, 590, 57, 6077, 383, "GraphicsData", "PostScript", \
"Graphics"],
Cell[357428, 7960, 22363, 576, 57, 5823, 367, "GraphicsData", "PostScript", \
"Graphics"],
Cell[379794, 8538, 22372, 573, 57, 5767, 363, "GraphicsData", "PostScript", \
"Graphics"],
Cell[402169, 9113, 22481, 573, 57, 5747, 362, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]]
}, Open  ]],
Cell[424677, 9690, 730, 26, 65, "Text"],
Cell[425410, 9718, 578, 10, 95, "Text"],
Cell[425991, 9730, 328, 6, 64, "Text"],
Cell[426322, 9738, 492, 14, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[426851, 9757, 59, 1, 30, "Subsubtitle",
  CellTags->"c:6"],
Cell[426913, 9760, 375, 11, 44, "Text"],
Cell[427291, 9773, 255, 6, 105, "Input",
  CellTags->"Cell 2.13"],
Cell[427549, 9781, 310, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[427884, 9795, 239, 5, 105, "Input",
  CellTags->"Cell 2.14"],
Cell[428126, 9802, 54278, 988, 233, 5504, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[482419, 10793, 142, 5, 27, "Text"],
Cell[482564, 10800, 141, 5, 29, "NumberedEquation",
  CellTags->"(2.1.13)"],
Cell[482708, 10807, 401, 15, 44, "Text"],

Cell[CellGroupData[{
Cell[483134, 10826, 340, 9, 124, "Input",
  CellTags->"Cell 2.15"],
Cell[483477, 10837, 72, 1, 64, "Output"]
}, Open  ]],
Cell[483564, 10841, 61, 0, 27, "Text"],
Cell[483628, 10843, 522, 15, 58, "NumberedEquation",
  CellTags->{"(2.1.14)", "i:9"}],
Cell[484153, 10860, 1197, 33, 117, "Text"],

Cell[CellGroupData[{
Cell[485375, 10897, 357, 9, 128, "Input",
  CellTags->"Cell 2.16"],

Cell[CellGroupData[{
Cell[485757, 10910, 41202, 979, 233, 8907, 576, "GraphicsData", "PostScript", \
"Graphics"],
Cell[526962, 11891, 45802, 1194, 57, 11984, 772, "GraphicsData", \
"PostScript", "Graphics"],
Cell[572767, 13087, 47372, 1322, 57, 14097, 907, "GraphicsData", \
"PostScript", "Graphics"],
Cell[620142, 14411, 47079, 1395, 57, 15590, 1002, "GraphicsData", \
"PostScript", "Graphics"],
Cell[667224, 15808, 48054, 1473, 57, 16844, 1083, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[715305, 17285, 219, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[715561, 17294, 82, 1, 30, "Subsubtitle",
  CellTags->"c:7"],
Cell[715646, 17297, 340, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[716011, 17311, 429, 9, 145, "Input",
  CellTags->"Cell 2.17"],

Cell[CellGroupData[{
Cell[716465, 17324, 61647, 2293, 233, 29617, 1894, "GraphicsData", \
"PostScript", "Graphics"],
Cell[778115, 19619, 72345, 3711, 57, 54607, 3488, "GraphicsData", \
"PostScript", "Graphics"],
Cell[850463, 23332, 96539, 5326, 57, 79947, 5117, "GraphicsData", \
"PostScript", "Graphics"],
Cell[947005, 28660, 121499, 6943, 57, 105555, 6742, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1068507, 35605, 145521, 8514, 57, 130189, 8321, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1214055, 44123, 768, 24, 61, "Text"],
Cell[1214826, 44149, 1440, 42, 129, "Text",
  CellTags->"i:16"],
Cell[1216269, 44193, 1654, 49, 130, "Text"],
Cell[1217926, 44244, 193, 6, 27, "Text",
  CellTags->"i:11"],
Cell[1218122, 44252, 195, 3, 29, "NumberedEquation",
  CellTags->"(2.1.15)"],
Cell[1218320, 44257, 669, 22, 44, "Text"],
Cell[1218992, 44281, 707, 23, 61, "Text",
  CellTags->"i:12"],
Cell[1219702, 44306, 1228, 23, 163, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1220967, 44334, 94, 1, 30, "Subsubtitle",
  CellTags->{"i:17", "c:8"}],
Cell[1221064, 44337, 911, 27, 95, "Text"],
Cell[1221978, 44366, 197, 6, 27, "Text"],
Cell[1222178, 44374, 523, 15, 58, "NumberedEquation",
  CellTags->"(2.1.16)"],
Cell[1222704, 44391, 392, 13, 44, "Text"],
Cell[1223099, 44406, 833, 24, 68, "NumberedEquation",
  CellTags->"(2.1.17)"],
Cell[1223935, 44432, 826, 29, 61, "Text"],
Cell[1224764, 44463, 1134, 27, 68, "NumberedEquation",
  CellTags->"(2.1.18)"],
Cell[1225901, 44492, 253, 9, 28, "Text"],
Cell[1226157, 44503, 425, 12, 41, "NumberedEquation",
  CellTags->"(2.1.19)"],
Cell[1226585, 44517, 463, 17, 45, "Text",
  CellTags->"i:21"],

Cell[CellGroupData[{
Cell[1227073, 44538, 205, 5, 69, "Input",
  CellTags->"Cell 2.18"],
Cell[1227281, 44545, 77, 1, 65, "Output"]
}, Open  ]],
Cell[1227373, 44549, 269, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[1227667, 44560, 129, 3, 69, "Input",
  CellTags->"Cell 2.19"],
Cell[1227799, 44565, 20999, 682, 233, 7432, 511, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1248813, 45250, 105, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[1248943, 45257, 108, 3, 69, "Input",
  CellTags->"Cell 2.20"],
Cell[1249054, 45262, 81, 1, 65, "Output"]
}, Open  ]],
Cell[1249150, 45266, 435, 14, 46, "Text"],

Cell[CellGroupData[{
Cell[1249610, 45284, 94, 3, 69, "Input",
  CellTags->"Cell 2.21"],
Cell[1249707, 45289, 66, 1, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1249810, 45295, 86, 3, 67, "Input",
  CellTags->"Cell 2.22"],
Cell[1249899, 45300, 53, 1, 46, "Output"]
}, Open  ]],
Cell[1249967, 45304, 294, 9, 45, "Text"],

Cell[CellGroupData[{
Cell[1250286, 45317, 107, 3, 69, "Input",
  CellTags->"Cell 2.23"],
Cell[1250396, 45322, 54, 1, 46, "Output"]
}, Open  ]],
Cell[1250465, 45326, 625, 22, 45, "Text"],

Cell[CellGroupData[{
Cell[1251115, 45352, 259, 7, 107, "Input",
  CellTags->"Cell 2.24"],

Cell[CellGroupData[{
Cell[1251399, 45363, 26870, 830, 233, 9431, 610, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1278272, 46195, 29284, 1009, 57, 12376, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1307559, 47206, 29986, 1101, 57, 13989, 899, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1337548, 48309, 30938, 1189, 57, 15455, 993, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1368489, 49500, 31792, 1254, 57, 16483, 1060, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1400308, 50758, 1017, 33, 79, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1401362, 50796, 87, 1, 30, "Subsubtitle",
  CellTags->"c:9"],
Cell[1401452, 50799, 685, 19, 60, "Text"],
Cell[1402140, 50820, 360, 10, 30, "NumberedEquation",
  CellTags->"(2.1.20)"],
Cell[1402503, 50832, 341, 10, 43, "Text"],
Cell[1402847, 50844, 115, 3, 26, "Text"],
Cell[1402965, 50849, 830, 26, 32, "NumberedEquation",
  CellTags->"(2.1.21)"],
Cell[1403798, 50877, 474, 15, 46, "Text"],
Cell[1404275, 50894, 419, 9, 38, "NumberedEquation",
  CellTags->"(2.1.22)"],
Cell[1404697, 50905, 539, 19, 43, "Text"],
Cell[1405239, 50926, 330, 10, 37, "NumberedEquation",
  CellTags->"(2.1.23)"],
Cell[1405572, 50938, 151, 5, 26, "Text"],
Cell[1405726, 50945, 213, 4, 45, "NumberedEquation",
  CellTags->"(2.1.24)"],
Cell[1405942, 50951, 178, 7, 26, "Text"],
Cell[1406123, 50960, 255, 7, 37, "NumberedEquation",
  CellTags->{"(2.1.25)", "i:18"}],
Cell[1406381, 50969, 542, 17, 43, "Text"],
Cell[1406926, 50988, 345, 7, 65, "NumberedEquation",
  CellTags->"(2.1.26)"],
Cell[1407274, 50997, 864, 25, 65, "Text"],
Cell[1408141, 51024, 268, 7, 37, "NumberedEquation",
  CellTags->{"(2.1.27)", "i:19"}],
Cell[1408412, 51033, 1189, 38, 77, "Text"],
Cell[1409604, 51073, 908, 25, 78, "Text"],
Cell[1410515, 51100, 627, 21, 61, "Text",
  CellTags->"i:6"],
Cell[1411145, 51123, 195, 6, 34, "NumberedEquation",
  CellTags->"(2.1.28)"],
Cell[1411343, 51131, 830, 20, 88, "Text"],
Cell[1412176, 51153, 565, 18, 47, "Text"],
Cell[1412744, 51173, 609, 18, 38, "NumberedEquation",
  CellTags->"(2.1.29)"],
Cell[1413356, 51193, 87, 3, 27, "Text"],
Cell[1413446, 51198, 1363, 29, 107, "NumberedEquation",
  CellTags->"(2.1.30)"],
Cell[1414812, 51229, 122, 5, 27, "Text"],
Cell[1414937, 51236, 862, 24, 38, "NumberedEquation",
  CellTags->"(2.1.31)"],
Cell[1415802, 51262, 642, 20, 48, "Text"],
Cell[1416447, 51284, 1021, 25, 40, "NumberedEquation",
  CellTags->"(2.1.32)"],
Cell[1417471, 51311, 454, 16, 44, "Text"],
Cell[1417928, 51329, 557, 15, 40, "NumberedEquation",
  CellTags->{"(2.1.33)", "i:20"}],
Cell[1418488, 51346, 535, 18, 44, "Text"],
Cell[1419026, 51366, 364, 13, 27, "Text"],
Cell[1419393, 51381, 163, 3, 46, "NumberedEquation",
  CellTags->"(2.1.34)"],
Cell[1419559, 51386, 249, 10, 27, "Text"],
Cell[1419811, 51398, 1308, 36, 237, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1421156, 51439, 112, 2, 30, "Subsubtitle",
  CellTags->{"i:22", "c:10"}],
Cell[1421271, 51443, 307, 7, 44, "Text"],
Cell[1421581, 51452, 327, 9, 45, "Text"],
Cell[1421911, 51463, 298, 9, 38, "NumberedEquation",
  CellTags->"(2.1.35)"],
Cell[1422212, 51474, 715, 23, 62, "Text"],
Cell[1422930, 51499, 396, 9, 38, "NumberedEquation",
  CellTags->"(2.1.36)"],
Cell[1423329, 51510, 592, 18, 48, "Text"],
Cell[1423924, 51530, 347, 8, 33, "NumberedEquation",
  CellTags->"(2.1.37)"],
Cell[1424274, 51540, 309, 12, 27, "Text"],
Cell[1424586, 51554, 564, 16, 61, "Text"],
Cell[1425153, 51572, 405, 9, 61, "Text"],
Cell[1425561, 51583, 694, 18, 82, "Text"],
Cell[1426258, 51603, 944, 24, 89, "Text"],
Cell[1427205, 51629, 1542, 43, 115, "Text",
  CellTags->"i:23"],
Cell[1428750, 51674, 155, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1428942, 51683, 95, 1, 30, "Subsubtitle",
  CellTags->{"i:24", "c:11"}],
Cell[1429040, 51686, 706, 21, 64, "Text",
  CellTags->"i:25"],

Cell[CellGroupData[{
Cell[1429771, 51711, 115, 3, 67, "Input",
  CellTags->"Cell 2.25"],
Cell[1429889, 51716, 144446, 1868, 233, 17335, 259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1574338, 53586, 127, 3, 46, "Output"]
}, Open  ]],
Cell[1574480, 53592, 359, 10, 44, "Text"],
Cell[1574842, 53604, 155, 3, 44, "Text"],

Cell[CellGroupData[{
Cell[1575022, 53611, 369, 8, 128, "Input",
  CellTags->"Cell 2.26"],
Cell[1575394, 53621, 143458, 1856, 233, 17335, 259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1718855, 55479, 127, 3, 46, "Output"]
}, Open  ]],
Cell[1718997, 55485, 823, 23, 78, "Text"],
Cell[1719823, 55510, 200, 4, 44, "Text"],
Cell[1720026, 55516, 635, 15, 78, "Text"],
Cell[1720664, 55533, 234, 7, 27, "Text"],
Cell[1720901, 55542, 311, 10, 44, "Text"],

Cell[CellGroupData[{
Cell[1721237, 55556, 379, 9, 147, "Input",
  CellTags->"Cell 2.27"],
Cell[1721619, 55567, 45946, 1176, 233, 11009, 741, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1767580, 56746, 218, 4, 44, "Text"],

Cell[CellGroupData[{
Cell[1767823, 56754, 169, 4, 69, "Input",
  CellTags->"Cell 2.28"],
Cell[1767995, 56760, 119057, 1555, 233, 17335, 259, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1887055, 58317, 127, 3, 46, "Output"]
}, Open  ]],
Cell[1887197, 58323, 412, 10, 61, "Text"],
Cell[1887612, 58335, 1287, 23, 180, "Text",
  CellTags->"i:94"],
Cell[1888902, 58360, 1048, 21, 146, "Text",
  CellTags->"i:26"],
Cell[1889953, 58383, 916, 17, 129, "Text"],
Cell[1890872, 58402, 836, 15, 129, "Text"],
Cell[1891711, 58419, 470, 17, 64, "Text"],
Cell[1892184, 58438, 4169622, 57386, 216, 4010164, 55412, "GraphicsData", \
"PostScript", "Picture",
  CellTags->{"Fig. 2.2", "i:32"}],
Cell[6061809, 115826, 125, 4, 16, "Caption",
  CellTags->"Fig. 2.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[6061971, 115835, 65, 1, 30, "Subsubtitle",
  CellTags->"c:12"],
Cell[6062039, 115838, 517, 18, 32, "Text"],
Cell[6062559, 115858, 151, 4, 27, "Text"],
Cell[6062713, 115864, 190, 7, 30, "Text"],
Cell[6062906, 115873, 139, 5, 27, "Text"],
Cell[6063048, 115880, 264, 10, 27, "Text"],
Cell[6063315, 115892, 274, 10, 27, "Text"],
Cell[6063592, 115904, 353, 11, 44, "Text"],
Cell[6063948, 115917, 377, 11, 44, "Text"],
Cell[6064328, 115930, 698, 23, 62, "Text"],
Cell[6065029, 115955, 475, 10, 61, "Text"],
Cell[6065507, 115967, 273, 10, 30, "Text"],
Cell[6065783, 115979, 1055, 31, 86, "Text"],
Cell[6066841, 116012, 445, 15, 44, "Text"],
Cell[6067289, 116029, 140, 4, 27, "Text"],
Cell[6067432, 116035, 399, 11, 48, "Text"],
Cell[6067834, 116048, 225, 7, 28, "Text"],
Cell[6068062, 116057, 321, 8, 45, "Text"],
Cell[6068386, 116067, 405, 11, 45, "Text"],
Cell[6068794, 116080, 165, 5, 27, "Text"],
Cell[6068962, 116087, 362, 11, 45, "Text"],
Cell[6069327, 116100, 738, 27, 44, "Text"],
Cell[6070068, 116129, 1427, 49, 79, "Text"],
Cell[6071498, 116180, 524, 17, 44, "Text"],
Cell[6072025, 116199, 366, 11, 44, "Text"],
Cell[6072394, 116212, 1581, 47, 80, "Text"],
Cell[6073978, 116261, 176, 5, 27, "Text"],
Cell[6074157, 116268, 259, 6, 48, "Text"],
Cell[6074419, 116276, 509, 14, 65, "Text"],
Cell[6074931, 116292, 1193, 32, 154, "Text",
  CellTags->"i:27"],
Cell[6076127, 116326, 1209, 32, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6077385, 116364, 140, 4, 74, "Subtitle",
  CellTags->{"Sec. 2.2", "i:15", "c:13"}],
Cell[6077528, 116370, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6077569, 116374, 91, 1, 40, "Subsubtitle",
  CellTags->{"i:29", "c:14"}],
Cell[6077663, 116377, 622, 18, 61, "Text"],
Cell[6078288, 116397, 734, 23, 64, "Text"],
Cell[6079025, 116422, 475, 17, 47, "Text"],
Cell[6079503, 116441, 221, 4, 54, "NE2",
  CellTags->"(2.2.1)"],
Cell[6079727, 116447, 486, 18, 47, "Text"],
Cell[6080216, 116467, 41223, 930, 233, 9385, 533, "GraphicsData", \
"PostScript", "Picture"],
Cell[6121442, 117399, 405, 15, 16, "Caption",
  CellTags->"Fig. 2.3"],
Cell[6121850, 117416, 226, 8, 30, "Text"],
Cell[6122079, 117426, 279, 9, 38, "NE2",
  CellTags->"(2.2.2)"],
Cell[6122361, 117437, 329, 12, 27, "Text"],
Cell[6122693, 117451, 274, 7, 38, "NE2",
  CellTags->"(2.2.3)"],
Cell[6122970, 117460, 97, 3, 27, "Text"],
Cell[6123070, 117465, 307, 7, 31, "Text"],
Cell[6123380, 117474, 92, 3, 27, "Text"],
Cell[6123475, 117479, 226, 8, 30, "Text"],

Cell[CellGroupData[{
Cell[6123726, 117491, 189, 5, 67, "Input",
  CellTags->"Cell 2.29"],
Cell[6123918, 117498, 88, 1, 65, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6124043, 117504, 116, 3, 67, "Input",
  CellTags->"Cell 2.30"],
Cell[6124162, 117509, 38, 1, 64, "Output"]
}, Open  ]],
Cell[6124215, 117513, 324, 12, 27, "Text"],

Cell[CellGroupData[{
Cell[6124564, 117529, 470, 11, 176, "Input",
  CellTags->"Cell 2.31"],
Cell[6125037, 117542, 44446, 1265, 233, 15315, 901, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6169498, 118810, 684, 20, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6170219, 118835, 83, 1, 29, "Subsubtitle",
  CellTags->{"i:30", "c:15"}],
Cell[6170305, 118838, 566, 22, 47, "Text"],
Cell[6170874, 118862, 698, 20, 102, "NE2",
  CellTags->"(2.2.4)"],
Cell[6171575, 118884, 690, 20, 67, "Text"],
Cell[6172268, 118906, 42982, 991, 233, 10078, 581, "GraphicsData", \
"PostScript", "Picture"],
Cell[6215253, 119899, 257, 9, 16, "Caption",
  CellTags->"Fig. 2.4"],
Cell[6215513, 119910, 178, 6, 27, "Text"],
Cell[6215694, 119918, 231, 7, 33, "NE2",
  CellTags->"(2.2.5)"],
Cell[6215928, 119927, 297, 11, 27, "Text"],
Cell[6216228, 119940, 399, 11, 47, "Text"],
Cell[6216630, 119953, 447, 8, 69, "NE2",
  CellTags->"(2.2.6)"],
Cell[6217080, 119963, 454, 18, 27, "Text"],
Cell[6217537, 119983, 803, 19, 81, "NE2",
  CellTags->"(2.2.7)"],
Cell[6218343, 120004, 413, 14, 44, "Text"],
Cell[6218759, 120020, 375, 6, 69, "NE2",
  CellTags->"(2.2.8)"],
Cell[6219137, 120028, 645, 23, 47, "Text"],

Cell[CellGroupData[{
Cell[6219807, 120055, 218, 6, 105, "Input",
  CellTags->"Cell 2.32"],
Cell[6220028, 120063, 76, 1, 67, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6220141, 120069, 121, 3, 67, "Input",
  CellTags->"Cell 2.33"],
Cell[6220265, 120074, 38, 1, 64, "Output"]
}, Open  ]],
Cell[6220318, 120078, 411, 13, 48, "Text"],

Cell[CellGroupData[{
Cell[6220754, 120095, 468, 11, 176, "Input",
  CellTags->"Cell 2.34"],
Cell[6221225, 120108, 32254, 833, 233, 9830, 552, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6253494, 120944, 286, 7, 47, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6253817, 120956, 82, 1, 29, "Subsubtitle",
  CellTags->{"i:31", "c:16"}],
Cell[6253902, 120959, 439, 14, 47, "Text"],
Cell[6254344, 120975, 686, 20, 81, "NE2",
  CellTags->"(2.2.9)"],
Cell[6255033, 120997, 1033, 29, 95, "Text"],
Cell[6256069, 121028, 66412, 2230, 233, 28409, 1757, "GraphicsData", \
"PostScript", "Picture"],
Cell[6322484, 123260, 250, 9, 16, "Caption",
  CellTags->"Fig. 2.5"],
Cell[6322737, 123271, 425, 13, 44, "Text"],
Cell[6323165, 123286, 232, 7, 33, "NE2",
  CellTags->"(2.2.10)"],
Cell[6323400, 123295, 284, 10, 27, "Text"],
Cell[6323687, 123307, 271, 7, 38, "NE2",
  CellTags->"(2.2.11)"],
Cell[6323961, 123316, 448, 13, 65, "Text"],
Cell[6324412, 123331, 55, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6324492, 123335, 240, 7, 124, "Input",
  CellTags->"Cell 2.35"],
Cell[6324735, 123344, 86, 1, 67, "Output"]
}, Open  ]],
Cell[6324836, 123348, 202, 6, 31, "Text"],

Cell[CellGroupData[{
Cell[6325063, 123358, 240, 7, 124, "Input",
  CellTags->"Cell 2.36"],
Cell[6325306, 123367, 149, 2, 69, "Output"]
}, Open  ]],
Cell[6325470, 123372, 50, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6325545, 123376, 234, 7, 105, "Input",
  CellTags->"Cell 2.37"],
Cell[6325782, 123385, 120, 2, 65, "Output"]
}, Open  ]],
Cell[6325917, 123390, 198, 8, 31, "Text"],
Cell[6326118, 123400, 295, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[6326438, 123412, 730, 17, 233, "Input",
  CellTags->"Cell 2.38"],
Cell[6327171, 123431, 45917, 1031, 233, 11400, 600, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6373137, 124468, 125, 4, 29, "Subsubtitle",
  CellTags->{"i:33", "c:17"}],
Cell[6373265, 124474, 404, 10, 61, "Text"],
Cell[6373672, 124486, 128, 5, 33, "NE2",
  CellTags->"(2.2.12)"],
Cell[6373803, 124493, 539, 21, 48, "Text"],
Cell[6374345, 124516, 561, 21, 49, "Text"],
Cell[6374909, 124539, 608, 16, 61, "Text"],
Cell[6375520, 124557, 260, 7, 33, "NE2",
  CellTags->"(2.2.13)"],
Cell[6375783, 124566, 205, 8, 27, "Text"],
Cell[6375991, 124576, 461, 10, 61, "Text"],
Cell[6376455, 124588, 287, 7, 44, "Text"],
Cell[6376745, 124597, 133, 5, 30, "NE2",
  CellTags->"(2.2.14)"],
Cell[6376881, 124604, 251, 9, 28, "Text"],
Cell[6377135, 124615, 195, 6, 33, "NE2",
  CellTags->"(2.2.15)"],
Cell[6377333, 124623, 158, 4, 44, "Text"],
Cell[6377494, 124629, 301, 8, 33, "NE2",
  CellTags->"(2.2.16)"],
Cell[6377798, 124639, 651, 20, 61, "Text"],
Cell[6378452, 124661, 408, 9, 45, "Text",
  CellTags->"i:35"],
Cell[6378863, 124672, 249, 7, 38, "NE2",
  CellTags->"(2.2.17)"],
Cell[6379115, 124681, 131, 5, 27, "Text"],
Cell[6379249, 124688, 813, 17, 112, "Text"],
Cell[6380065, 124707, 332, 10, 44, "Text"],
Cell[6380400, 124719, 376, 8, 40, "NE2",
  CellTags->"(2.2.18)"],
Cell[6380779, 124729, 474, 16, 48, "Text"],
Cell[6381256, 124747, 194, 6, 43, "NE2",
  CellTags->"(2.2.19)"],
Cell[6381453, 124755, 260, 11, 27, "Text"],
Cell[6381716, 124768, 303, 7, 38, "NE2",
  CellTags->"(2.2.20)"],
Cell[6382022, 124777, 872, 27, 78, "Text"],
Cell[6382897, 124806, 234, 6, 33, "NE2",
  CellTags->"(2.2.21)"],
Cell[6383134, 124814, 405, 15, 27, "Text"],
Cell[6383542, 124831, 176, 6, 33, "NE2",
  CellTags->"(2.2.22)"],
Cell[6383721, 124839, 244, 8, 27, "Text",
  CellTags->"i:34"],
Cell[6383968, 124849, 584, 15, 62, "NE2",
  CellTags->"(2.2.23)"],
Cell[6384555, 124866, 387, 16, 28, "Text"],
Cell[6384945, 124884, 522, 17, 44, "Text"],
Cell[6385470, 124903, 540, 15, 35, "NE2",
  CellTags->"(2.2.24)"],
Cell[6386013, 124920, 696, 15, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6386746, 124940, 78, 1, 29, "Subsubtitle",
  CellTags->{"Ex. 2.2", "c:18"}],
Cell[6386827, 124943, 375, 12, 44, "Text"],
Cell[6387205, 124957, 316, 9, 44, "Text"],
Cell[6387524, 124968, 221, 8, 29, "Text"],
Cell[6387748, 124978, 198, 8, 30, "Text"],
Cell[6387949, 124988, 157, 6, 30, "Text"],
Cell[6388109, 124996, 351, 9, 44, "Text"],
Cell[6388463, 125007, 718, 25, 51, "Text"],
Cell[6389184, 125034, 515, 19, 44, "Text"],
Cell[6389702, 125055, 171, 5, 27, "Text"],
Cell[6389876, 125062, 607, 18, 65, "Text"],
Cell[6390486, 125082, 672, 21, 65, "Text"],
Cell[6391161, 125105, 171, 5, 27, "Text"],
Cell[6391335, 125112, 116, 5, 27, "Text"],
Cell[6391454, 125119, 200, 6, 44, "Text"],
Cell[6391657, 125127, 202, 5, 41, "Text"],
Cell[6391862, 125134, 351, 9, 58, "Text",
  CellTags->"i:36"],
Cell[6392216, 125145, 306, 7, 41, "Text"],
Cell[6392525, 125154, 263, 6, 41, "Text"],
Cell[6392791, 125162, 379, 9, 41, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6393219, 125177, 84, 1, 40, "Subtitle",
  CellTags->{"Sec. 2.3", "i:38", "c:19"}],
Cell[6393306, 125180, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6393347, 125184, 103, 2, 41, "Subsubtitle",
  CellTags->"c:20"],
Cell[6393453, 125188, 577, 17, 61, "Text"],
Cell[6394033, 125207, 648, 18, 63, "Text"],
Cell[6394684, 125227, 361, 12, 27, "Text"],
Cell[6395048, 125241, 422, 11, 38, "NE3",
  CellTags->"(2.3.1)"],
Cell[6395473, 125254, 667, 19, 61, "Text",
  CellTags->"i:37"],
Cell[6396143, 125275, 424, 10, 32, "NE3",
  CellTags->"(2.3.2)"],
Cell[6396570, 125287, 155, 6, 27, "Text"],
Cell[6396728, 125295, 305, 8, 34, "NE3",
  CellTags->"(2.3.3)"],
Cell[6397036, 125305, 739, 23, 47, "Text"],
Cell[6397778, 125330, 496, 11, 52, "NE3",
  CellTags->"(2.3.4)"],
Cell[6398277, 125343, 145, 5, 27, "Text"],
Cell[6398425, 125350, 376, 10, 38, "NE3",
  CellTags->"(2.3.5)"],
Cell[6398804, 125362, 660, 26, 47, "Text",
  CellTags->"i:39"],
Cell[6399467, 125390, 913, 30, 84, "Text",
  CellTags->"i:110"],
Cell[6400383, 125422, 597, 18, 61, "Text"],
Cell[6400983, 125442, 1112, 27, 129, "Text",
  CellTags->"i:95"],
Cell[6402098, 125471, 2287, 50, 252, "Table",
  CellTags->{"i:40", "Table 2.1"}],
Cell[6404388, 125523, 16, 0, 27, "Text"],
Cell[6404407, 125525, 335, 8, 44, "Text"],
Cell[6404745, 125535, 436, 15, 33, "NE3",
  CellTags->"(2.3.6)"],
Cell[6405184, 125552, 124, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[6405333, 125561, 184, 5, 67, "Input",
  CellTags->"Cell 2.39"],
Cell[6405520, 125568, 579, 12, 92, "Output"]
}, Open  ]],
Cell[6406114, 125583, 103, 3, 27, "Text"],
Cell[6406220, 125588, 192, 6, 31, "Text"],
Cell[6406415, 125596, 661, 21, 50, "Text"],

Cell[CellGroupData[{
Cell[6407101, 125621, 413, 10, 105, "Input",
  CellTags->"Cell 2.40"],
Cell[6407517, 125633, 55, 1, 64, "Output"]
}, Open  ]],
Cell[6407587, 125637, 178, 6, 27, "Text"],
Cell[6407768, 125645, 1060, 32, 108, "Text",
  CellTags->"i:42"],
Cell[6408831, 125679, 151, 6, 27, "Text"],
Cell[6408985, 125687, 28, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6409038, 125691, 171, 5, 67, "Input",
  CellTags->"Cell 2.41"],
Cell[6409212, 125698, 117, 2, 92, "Output"]
}, Open  ]],
Cell[6409344, 125703, 232, 8, 31, "Text"],
Cell[6409579, 125713, 160, 5, 27, "Text"],
Cell[6409742, 125720, 106, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[6409873, 125727, 173, 4, 67, "Input",
  CellTags->"Cell 2.42"],
Cell[6410049, 125733, 55, 1, 64, "Output"]
}, Open  ]],
Cell[6410119, 125737, 435, 10, 61, "Text"],
Cell[6410557, 125749, 1568, 42, 182, "Table",
  CellTags->"i:41"],
Cell[6412128, 125793, 119, 3, 27, "Text"],
Cell[6412250, 125798, 281, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[6412556, 125810, 259, 5, 105, "Input",
  CellTags->"Cell 2.43"],
Cell[6412818, 125817, 20052, 559, 233, 6584, 389, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6432885, 126379, 64, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6432974, 126383, 150, 4, 73, "Input",
  CellTags->"Cell 2.44"],
Cell[6433127, 126389, 190, 3, 70, "Output"]
}, Open  ]],
Cell[6433332, 126395, 196, 7, 27, "Text"],

Cell[CellGroupData[{
Cell[6433553, 126406, 425, 9, 146, "Input",
  CellTags->"Cell 2.45"],

Cell[CellGroupData[{
Cell[6434003, 126419, 45323, 1424, 231, 17321, 1074, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6479329, 127845, 41450, 1364, 231, 17335, 1062, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[6520806, 129213, 434, 12, 46, "Text"],
Cell[6521243, 129227, 159, 6, 30, "NE3",
  CellTags->"(2.3.7)"],
Cell[6521405, 129235, 271, 6, 45, "Text"],
Cell[6521679, 129243, 477, 10, 82, "Text",
  CellTags->"i:86"],
Cell[6522159, 129255, 225, 6, 75, "Input",
  CellTags->"Cell 2.46"],
Cell[6522387, 129263, 229, 7, 45, "Text"],

Cell[CellGroupData[{
Cell[6522641, 129274, 220, 5, 86, "Input",
  CellTags->"Cell 2.47"],
Cell[6522864, 129281, 28933, 847, 57, 9932, 608, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[6551812, 130131, 909, 27, 57, "Text"],
Cell[6552724, 130160, 130301, 3190, 687, 34991, 2009, "GraphicsData", \
"PostScript", "Picture"],
Cell[6683028, 133352, 397, 9, 29, "Caption",
  CellTags->"Fig. 2.6"],
Cell[6683428, 133363, 1773, 58, 78, "Text"],
Cell[6685204, 133423, 190, 6, 29, "NE3",
  CellTags->{"(2.3.8)", "i:87"}],
Cell[6685397, 133431, 1072, 21, 132, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6686506, 133457, 93, 1, 30, "Subsubtitle",
  CellTags->{"i:43", "c:21"}],
Cell[6686602, 133460, 683, 19, 61, "Text"],
Cell[6687288, 133481, 219, 8, 27, "Text"],
Cell[6687510, 133491, 348, 11, 34, "NE3",
  CellTags->"(2.3.9)"],
Cell[6687861, 133504, 65, 0, 27, "Text"],
Cell[6687929, 133506, 415, 13, 44, "Text"],
Cell[6688347, 133521, 403, 13, 32, "Text"],
Cell[6688753, 133536, 270, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[6689048, 133549, 160, 4, 67, "Input",
  CellTags->"Cell 2.48"],
Cell[6689211, 133555, 70, 1, 50, "Output"]
}, Open  ]],
Cell[6689296, 133559, 640, 22, 44, "Text"],
Cell[6689939, 133583, 360, 9, 44, "Text"],
Cell[6690302, 133594, 804, 21, 57, "Text"],
Cell[6691109, 133617, 447, 12, 57, "NE3",
  CellTags->"(2.3.10)"],
Cell[6691559, 133631, 282, 8, 57, "Text"],
Cell[6691844, 133641, 447, 12, 57, "NE3",
  CellTags->"(2.3.11)"],
Cell[6692294, 133655, 327, 12, 57, "Text"],
Cell[6692624, 133669, 258, 8, 57, "Text"],

Cell[CellGroupData[{
Cell[6692907, 133681, 179, 4, 67, "Input",
  CellTags->"Cell 2.49"],
Cell[6693089, 133687, 63, 1, 62, "Output"]
}, Open  ]],
Cell[6693167, 133691, 45, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[6693237, 133695, 192, 5, 86, "Input",
  CellTags->"Cell 2.50"],
Cell[6693432, 133702, 79, 1, 51, "Output"]
}, Open  ]],
Cell[6693526, 133706, 279, 8, 44, "Text"],

Cell[CellGroupData[{
Cell[6693830, 133718, 179, 4, 67, "Input",
  CellTags->"Cell 2.51"],
Cell[6694012, 133724, 56, 1, 64, "Output"]
}, Open  ]],
Cell[6694083, 133728, 93, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[6694201, 133735, 192, 5, 86, "Input",
  CellTags->"Cell 2.52"],
Cell[6694396, 133742, 70, 1, 51, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6694515, 133749, 86, 1, 30, "Subsubtitle",
  CellTags->"c:22"],

Cell[CellGroupData[{
Cell[6694626, 133754, 86, 1, 42, "Section",
  CellTags->"c:23"],
Cell[6694715, 133757, 857, 28, 57, "Text"],
Cell[6695575, 133787, 252, 7, 57, "NE3",
  CellTags->"(2.3.12)"],
Cell[6695830, 133796, 288, 11, 57, "Text"],
Cell[6696121, 133809, 131, 5, 57, "NE3",
  CellTags->"(2.3.13)"],
Cell[6696255, 133816, 731, 22, 57, "Text"],
Cell[6696989, 133840, 503, 17, 57, "Text"],
Cell[6697495, 133859, 295, 7, 57, "NE3",
  CellTags->"(2.3.14)"],
Cell[6697793, 133868, 170, 6, 57, "Text"],
Cell[6697966, 133876, 176, 6, 57, "NE3",
  CellTags->"(2.3.15)"],
Cell[6698145, 133884, 101, 3, 57, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6698283, 133892, 86, 1, 31, "Section",
  CellTags->"c:24"],
Cell[6698372, 133895, 148, 3, 57, "Text"],
Cell[6698523, 133900, 309, 8, 57, "NE3",
  CellTags->"(2.3.16)"],
Cell[6698835, 133910, 241, 5, 57, "Text"],
Cell[6699079, 133917, 581, 9, 57, "NE3",
  CellTags->"(2.3.17)"],
Cell[6699663, 133928, 365, 12, 57, "Text"],
Cell[6700031, 133942, 228, 4, 57, "NE3",
  CellTags->"(2.3.18)"],
Cell[6700262, 133948, 285, 8, 57, "Text"],
Cell[6700550, 133958, 231, 7, 57, "Text"],
Cell[6700784, 133967, 234, 7, 57, "NE3",
  CellTags->"(2.3.19)"]
}, Closed]],

Cell[CellGroupData[{
Cell[6701055, 133979, 68, 1, 31, "Section",
  CellTags->{"i:44", "c:25"}],
Cell[6701126, 133982, 329, 14, 57, "Text"],
Cell[6701458, 133998, 367, 10, 57, "NE3",
  CellTags->"(2.3.20)"],
Cell[6701828, 134010, 290, 9, 57, "Text"],
Cell[6702121, 134021, 489, 17, 57, "Text"],
Cell[6702613, 134040, 171, 6, 57, "NE3",
  CellTags->"(2.3.21)"],
Cell[6702787, 134048, 457, 11, 57, "Text"],
Cell[6703247, 134061, 216, 8, 57, "Text"],
Cell[6703466, 134071, 1681, 40, 57, "Text"],
Cell[6705150, 134113, 36, 0, 57, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6705223, 134118, 94, 1, 31, "Section",
  CellTags->{"i:45", "c:26"}],
Cell[6705320, 134121, 1441, 38, 104, "Text"],
Cell[6706764, 134161, 1539, 50, 61, "Text"],
Cell[6708306, 134213, 879, 30, 65, "Text"],
Cell[6709188, 134245, 131, 5, 27, "Text"],
Cell[6709322, 134252, 307, 7, 34, "NE3",
  CellTags->"(2.3.22)"],
Cell[6709632, 134261, 858, 29, 44, "Text"],
Cell[6710493, 134292, 814, 23, 34, "NE3",
  CellTags->"(2.3.23)"],
Cell[6711310, 134317, 660, 23, 30, "Text"],
Cell[6711973, 134342, 154, 6, 29, "NE3",
  CellTags->"(2.3.24)"],
Cell[6712130, 134350, 714, 21, 68, "Text"],
Cell[6712847, 134373, 1035, 24, 112, "Text",
  CellTags->"i:107"],
Cell[6713885, 134399, 647, 19, 48, "Text"],

Cell[CellGroupData[{
Cell[6714557, 134422, 169, 4, 67, "Input",
  CellTags->"Cell 2.53"],
Cell[6714729, 134428, 136, 2, 57, "Output"]
}, Open  ]],
Cell[6714880, 134433, 419, 13, 44, "Text"],
Cell[6715302, 134448, 94177, 2112, 233, 21273, 1207, "GraphicsData", \
"PostScript", "Picture"],
Cell[6809482, 136562, 573, 17, 29, "Caption",
  CellTags->"Fig. 2.7"],
Cell[6810058, 136581, 70502, 1855, 233, 22388, 1256, "GraphicsData", \
"PostScript", "Picture"],
Cell[6880563, 138438, 148, 6, 16, "Caption",
  CellTags->"Fig. 2.8"],
Cell[6880714, 138446, 1079, 27, 112, "Text",
  CellTags->"i:88"],
Cell[6881796, 138475, 323, 10, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[6882168, 138491, 86, 1, 30, "Subsubtitle",
  CellTags->{"i:46", "c:27"}],

Cell[CellGroupData[{
Cell[6882279, 138496, 51, 1, 42, "Section",
  CellTags->"c:28"],
Cell[6882333, 138499, 1691, 55, 103, "Text"],
Cell[6884027, 138556, 450, 11, 34, "NE3",
  CellTags->"(2.3.25)"],
Cell[6884480, 138569, 1269, 40, 86, "Text"],
Cell[6885752, 138611, 423, 16, 27, "Text",
  CellTags->"i:112"],
Cell[6886178, 138629, 522, 15, 29, "NE3",
  CellTags->"(2.3.26)"],
Cell[6886703, 138646, 186, 4, 44, "Text"],
Cell[6886892, 138652, 495, 14, 45, "NE3",
  CellTags->"(2.3.27)"],
Cell[6887390, 138668, 453, 12, 61, "Text"],
Cell[6887846, 138682, 237, 7, 32, "NE3",
  CellTags->"(2.3.28)"],
Cell[6888086, 138691, 185, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6888308, 138700, 70, 1, 31, "Section",
  CellTags->"c:29"],
Cell[6888381, 138703, 473, 16, 44, "Text"],
Cell[6888857, 138721, 504, 9, 34, "NE3",
  CellTags->"(2.3.29)"],
Cell[6889364, 138732, 634, 19, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6890035, 138756, 95, 3, 31, "Section",
  CellTags->"c:30"],
Cell[6890133, 138761, 117, 3, 57, "Text"],
Cell[6890253, 138766, 180, 6, 57, "NE3",
  CellTags->"(2.3.30)"],
Cell[6890436, 138774, 1045, 35, 57, "Text"],
Cell[6891484, 138811, 659, 24, 57, "Text"],
Cell[6892146, 138837, 300, 9, 57, "NE3",
  CellTags->"(2.3.31)"],
Cell[6892449, 138848, 782, 26, 57, "Text"],
Cell[6893234, 138876, 329, 8, 57, "NE3",
  CellTags->"(2.3.32)"],
Cell[6893566, 138886, 818, 26, 57, "Text"],
Cell[6894387, 138914, 1551, 43, 57, "Text"],
Cell[6895941, 138959, 1175, 29, 57, "Text"],
Cell[6897119, 138990, 269, 10, 57, "Text"],
Cell[6897391, 139002, 270, 7, 57, "NE3",
  CellTags->"(2.3.33)"]
}, Closed]],

Cell[CellGroupData[{
Cell[6897698, 139014, 78, 1, 31, "Section",
  CellTags->{"i:50", "c:31"}],
Cell[6897779, 139017, 204, 6, 27, "Text"],
Cell[6897986, 139025, 299, 5, 34, "NE3",
  CellTags->"(2.3.34)"],
Cell[6898288, 139032, 473, 13, 44, "Text"],
Cell[6898764, 139047, 279, 10, 44, "Text"],
Cell[6899046, 139059, 279, 8, 34, "NE3",
  CellTags->"(2.3.35)"],
Cell[6899328, 139069, 162, 4, 27, "Text"],
Cell[6899493, 139075, 436, 9, 54, "Text"],
Cell[6899932, 139086, 76, 0, 27, "Text"],
Cell[6900011, 139088, 233, 4, 38, "NE3",
  CellTags->"(2.3.36)"],
Cell[6900247, 139094, 633, 16, 61, "Text"],
Cell[6900883, 139112, 289, 9, 44, "Text"],
Cell[6901175, 139123, 291, 8, 38, "NE3",
  CellTags->"(2.3.37)"],
Cell[6901469, 139133, 188, 5, 27, "Text"],
Cell[6901660, 139140, 353, 5, 37, "NE3",
  CellTags->"(2.3.38)"],
Cell[6902016, 139147, 206, 5, 35, "Text"],
Cell[6902225, 139154, 217, 6, 36, "NE3",
  CellTags->"(2.3.39)"],
Cell[6902445, 139162, 548, 17, 45, "Text"],
Cell[6902996, 139181, 154, 6, 27, "Text"],
Cell[6903153, 139189, 304, 5, 37, "NE3",
  CellTags->"(2.3.40)"],
Cell[6903460, 139196, 1934, 52, 155, "Text"],

Cell[CellGroupData[{
Cell[6905419, 139252, 254, 6, 86, "Input",
  CellTags->"Cell 2.54"],

Cell[CellGroupData[{
Cell[6905698, 139262, 18392, 542, 233, 5494, 379, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6924093, 139806, 23135, 672, 57, 6904, 468, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6947231, 140480, 26279, 740, 57, 7460, 504, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6973513, 141222, 30011, 835, 57, 8409, 564, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7003527, 142059, 32802, 917, 57, 9317, 623, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7036332, 142978, 36078, 994, 57, 10050, 669, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7072413, 143974, 38749, 1043, 57, 10319, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7111165, 145019, 41376, 1105, 57, 10925, 725, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7152544, 146126, 44113, 1164, 57, 11398, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7196660, 147292, 45923, 1204, 57, 11718, 778, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[7242610, 148500, 734, 18, 61, "Text"],
Cell[7243347, 148520, 575, 14, 61, "Text"],
Cell[7243925, 148536, 454, 14, 44, "Text"],
Cell[7244382, 148552, 557, 14, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7244976, 148571, 83, 1, 31, "Section",
  CellTags->{"i:89", "c:32"}],
Cell[7245062, 148574, 523, 14, 45, "Text"],
Cell[7245588, 148590, 539, 12, 34, "NE3",
  CellTags->"(2.3.41)"],
Cell[7246130, 148604, 1001, 27, 96, "Text"],

Cell[CellGroupData[{
Cell[7247156, 148635, 131, 3, 67, "Input",
  CellTags->"Cell 2.55"],
Cell[7247290, 148640, 47, 1, 46, "Output"]
}, Open  ]],
Cell[7247352, 148644, 200, 7, 27, "Text",
  CellTags->"i:96"],

Cell[CellGroupData[{
Cell[7247577, 148655, 153, 4, 67, "Input",
  CellTags->"Cell 2.56"],
Cell[7247733, 148661, 135, 3, 47, "Output"]
}, Open  ]],
Cell[7247883, 148667, 462, 11, 62, "Text"],
Cell[7248348, 148680, 366, 10, 44, "Text"],
Cell[7248717, 148692, 380, 7, 34, "NE3",
  CellTags->"(2.3.42)"],
Cell[7249100, 148701, 154, 5, 27, "Text"],
Cell[7249257, 148708, 335, 6, 50, "NE3",
  CellTags->"(2.3.43)"],
Cell[7249595, 148716, 284, 9, 38, "Text"],
Cell[7249882, 148727, 325, 5, 40, "NE3",
  CellTags->"(2.3.44)"],
Cell[7250210, 148734, 365, 8, 79, "Text"],
Cell[7250578, 148744, 228, 4, 44, "Text"],
Cell[7250809, 148750, 695, 14, 45, "Text"],
Cell[7251507, 148766, 550, 13, 82, "Text"],
Cell[7252060, 148781, 192, 4, 44, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7252289, 148790, 72, 1, 31, "Section",
  CellTags->{"i:51", "c:33"}],
Cell[7252364, 148793, 223, 6, 44, "Text"],
Cell[7252590, 148801, 208, 7, 33, "NE3",
  CellTags->"(2.3.45)"],
Cell[7252801, 148810, 983, 34, 61, "Text"],
Cell[7253787, 148846, 444, 14, 45, "NE3",
  CellTags->"(2.3.46)"],
Cell[7254234, 148862, 496, 11, 54, "Text"],
Cell[7254733, 148875, 208, 4, 44, "Text"],
Cell[7254944, 148881, 285, 6, 30, "Text"],
Cell[7255232, 148889, 272, 7, 32, "Text"],
Cell[7255507, 148898, 1656, 43, 99, "Text"],
Cell[7257166, 148943, 1060, 26, 38, "NE3",
  CellTags->"(2.3.47)"],
Cell[7258229, 148971, 171, 5, 27, "Text"],

Cell[CellGroupData[{
Cell[7258425, 148980, 149, 4, 67, "Input",
  CellTags->"Cell 2.57"],
Cell[7258577, 148986, 87, 1, 65, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[7258713, 148993, 100, 1, 31, "Section",
  CellTags->{"i:49", "c:34"}],
Cell[7258816, 148996, 283, 5, 65, "Text"],
Cell[7259102, 149003, 408, 11, 45, "Text",
  CellTags->"i:48"],
Cell[7259513, 149016, 218, 7, 30, "NE3",
  CellTags->"(2.3.48)"],
Cell[7259734, 149025, 111, 3, 27, "Text"],
Cell[7259848, 149030, 253, 8, 28, "Text"],
Cell[7260104, 149040, 465, 11, 75, "Text"],
Cell[7260572, 149053, 166, 5, 27, "Text"],
Cell[7260741, 149060, 326, 8, 30, "NE3",
  CellTags->"(2.3.49)"],
Cell[7261070, 149070, 1451, 44, 120, "Text"],
Cell[7262524, 149116, 689, 17, 82, "Text"],
Cell[7263216, 149135, 135, 3, 67, "Input",
  CellTags->"Cell 2.58"],
Cell[7263354, 149140, 258, 10, 27, "Text"],

Cell[CellGroupData[{
Cell[7263637, 149154, 130, 3, 67, "Input",
  CellTags->"Cell 2.59"],
Cell[7263770, 149159, 69673, 990, 231, 33936, 475, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7333446, 150151, 127, 3, 57, "Output"]
}, Open  ]],
Cell[7333588, 150157, 449, 7, 82, "Text"],
Cell[7334040, 150166, 443, 13, 65, "Text"],
Cell[7334486, 150181, 408, 11, 56, "Text"],
Cell[7334897, 150194, 637, 19, 78, "Text"],
Cell[7335537, 150215, 376, 6, 37, "NE3",
  CellTags->"(2.3.50)"],
Cell[7335916, 150223, 459, 15, 28, "Text"],
Cell[7336378, 150240, 677, 11, 73, "NE3",
  CellTags->"(2.3.51)"],
Cell[7337058, 150253, 655, 24, 45, "Text"],
Cell[7337716, 150279, 255, 5, 37, "NE3",
  CellTags->"(2.3.52)"],
Cell[7337974, 150286, 497, 12, 65, "Text"],
Cell[7338474, 150300, 368, 10, 45, "Text"],
Cell[7338845, 150312, 254, 8, 28, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7339148, 150326, 72, 1, 30, "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{
Cell[7339245, 150331, 76, 1, 42, "Section",
  CellTags->{"i:53", "c:36"}],
Cell[7339324, 150334, 749, 21, 61, "Text"],
Cell[7340076, 150357, 232, 4, 44, "Text"],
Cell[7340311, 150363, 823, 18, 99, "Text"],
Cell[7341137, 150383, 873, 23, 33, "NE3",
  CellTags->"(2.3.53)"],
Cell[7342013, 150408, 1074, 38, 30, "Text"],
Cell[7343090, 150448, 993, 31, 32, "NE3",
  CellTags->"(2.3.54)"],
Cell[7344086, 150481, 743, 23, 69, "Text"],
Cell[7344832, 150506, 194, 5, 33, "Text"],
Cell[7345029, 150513, 1172, 35, 33, "NE3",
  CellTags->"(2.3.55)"],
Cell[7346204, 150550, 403, 11, 48, "Text"],
Cell[7346610, 150563, 525, 18, 32, "NE3",
  CellTags->"(2.3.56)"],
Cell[7347138, 150583, 1167, 39, 64, "Text"],
Cell[7348308, 150624, 1635, 40, 115, "Text"],
Cell[7349946, 150666, 917, 20, 95, "Text"],
Cell[7350866, 150688, 850, 22, 98, "Text"],
Cell[7351719, 150712, 1686, 51, 78, "Text"],
Cell[7353408, 150765, 31430, 871, 233, 12723, 636, "GraphicsData", \
"PostScript", "Picture"],
Cell[7384841, 151638, 116, 4, 16, "Caption",
  CellTags->"Fig. 2.9"],
Cell[7384960, 151644, 624, 15, 78, "Text"],
Cell[7385587, 151661, 264, 7, 38, "NE3",
  CellTags->"(2.3.57)"],
Cell[7385854, 151670, 749, 18, 84, "Text"],
Cell[7386606, 151690, 150, 5, 30, "Text"],
Cell[7386759, 151697, 783, 22, 38, "NE3",
  CellTags->"(2.3.58)"],
Cell[7387545, 151721, 325, 11, 44, "Text"],
Cell[7387873, 151734, 1087, 27, 40, "NE3",
  CellTags->"(2.3.59)"],
Cell[7388963, 151763, 160, 5, 27, "Text"],
Cell[7389126, 151770, 243, 8, 47, "Text"],
Cell[7389372, 151780, 617, 13, 40, "NE3",
  CellTags->"(2.3.60)"],
Cell[7389992, 151795, 438, 15, 47, "Text"],
Cell[7390433, 151812, 598, 11, 41, "Text"],
Cell[7391034, 151825, 256, 9, 27, "Text"],
Cell[7391293, 151836, 360, 7, 40, "NE3",
  CellTags->"(2.3.61)"],
Cell[7391656, 151845, 788, 20, 78, "Text"],
Cell[7392447, 151867, 876, 22, 33, "NE3",
  CellTags->"(2.3.62)"],
Cell[7393326, 151891, 421, 16, 30, "Text"],
Cell[7393750, 151909, 478, 16, 57, "Text"],
Cell[7394231, 151927, 760, 20, 57, "NE3",
  CellTags->"(2.3.63)"],
Cell[7394994, 151949, 1568, 48, 57, "Text"],
Cell[7396565, 151999, 705, 19, 57, "Text"],
Cell[7397273, 152020, 1395, 52, 57, "Text"],
Cell[7398671, 152074, 777, 22, 57, "NE3",
  CellTags->"(2.3.64)"],
Cell[7399451, 152098, 1058, 33, 57, "Text"],
Cell[7400512, 152133, 331, 8, 57, "Text"],
Cell[7400846, 152143, 302, 9, 105, "Input",
  CellTags->"Cell 2.60"],
Cell[7401151, 152154, 220, 4, 45, "Text"],
Cell[7401374, 152160, 117, 3, 27, "Text"],
Cell[7401494, 152165, 172, 5, 67, "Input",
  CellTags->"Cell 2.61"],
Cell[7401669, 152172, 257, 8, 27, "Text"],

Cell[CellGroupData[{
Cell[7401951, 152184, 116, 3, 67, "Input",
  CellTags->"Cell 2.62"],
Cell[7402070, 152189, 134532, 1931, 231, 4652, 324, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7536617, 154123, 168, 6, 30, "Text"],
Cell[7536788, 154131, 97, 3, 71, "Input",
  CellTags->"Cell 2.63"],
Cell[7536888, 154136, 497, 17, 46, "Text"],

Cell[CellGroupData[{
Cell[7537410, 154157, 160, 4, 75, "Input",
  CellTags->"Cell 2.64"],
Cell[7537573, 154163, 33981, 685, 57, 4607, 318, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7571591, 154853, 160, 4, 57, "Input",
  CellTags->"Cell 2.65"],
Cell[7571754, 154859, 30656, 628, 57, 4420, 300, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[7602425, 155490, 1156, 28, 57, "Text"],
Cell[7603584, 155520, 1374, 40, 57, "Text"],
Cell[7604961, 155562, 684, 15, 57, "Text"],
Cell[7605648, 155579, 398, 12, 57, "NE3",
  CellTags->"(2.3.65)"],
Cell[7606049, 155593, 1470, 43, 112, "Text",
  CellTags->"i:55"],
Cell[7607522, 155638, 1303, 35, 129, "Text",
  CellTags->"i:111"],
Cell[7608828, 155675, 61283, 1415, 233, 13148, 816, "GraphicsData", \
"PostScript", "Picture"],
Cell[7670114, 157092, 619, 17, 29, "Caption",
  CellTags->"Fig. 2.10"],
Cell[7670736, 157111, 1224, 35, 103, "Text"],
Cell[7671963, 157148, 180, 6, 32, "NE3",
  CellTags->{"(2.3.66)", "i:56"}]
}, Closed]],

Cell[CellGroupData[{
Cell[7672180, 157159, 42, 0, 31, "Section"],
Cell[7672225, 157161, 1136, 32, 118, "Text"],
Cell[7673364, 157195, 776, 20, 81, "Text"],
Cell[7674143, 157217, 439, 9, 78, "Text"],
Cell[7674585, 157228, 579, 18, 61, "Text"],
Cell[7675167, 157248, 1132, 18, 135, "NE3",
  CellTags->"(2.3.67)"],
Cell[7676302, 157268, 509, 17, 49, "Text"],
Cell[7676814, 157287, 954, 30, 86, "Text"],
Cell[7677771, 157319, 1068, 33, 104, "Text"],
Cell[7678842, 157354, 832, 21, 104, "Text"],
Cell[7679677, 157377, 1817, 63, 105, "Text",
  CellTags->"i:101"],
Cell[7681497, 157442, 699, 23, 61, "Text"],
Cell[7682199, 157467, 1538, 58, 76, "NE3",
  CellTags->"(2.3.68)"],
Cell[7683740, 157527, 303, 7, 44, "Text"],
Cell[7684046, 157536, 523, 18, 47, "Text"],

Cell[CellGroupData[{
Cell[7684594, 157558, 317, 7, 128, "Input",
  CellTags->"Cell 2.66"],

Cell[CellGroupData[{
Cell[7684936, 157569, 34005, 685, 233, 4607, 318, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7718944, 158256, 30656, 628, 233, 4420, 300, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[7749627, 158888, 345, 11, 44, "Text"],
Cell[7749975, 158901, 655, 17, 78, "Text",
  CellTags->{"i:98", "i:102"}],

Cell[CellGroupData[{
Cell[7750655, 158922, 91, 3, 67, "Input",
  CellTags->"Cell 2.67"],
Cell[7750749, 158927, 48, 1, 46, "Output"]
}, Open  ]],
Cell[7750812, 158931, 403, 10, 61, "Text",
  CellTags->"i:103"],

Cell[CellGroupData[{
Cell[7751240, 158945, 121, 3, 67, "Input",
  CellTags->"Cell 2.68"],
Cell[7751364, 158950, 127, 3, 46, "Output"]
}, Open  ]],
Cell[7751506, 158956, 261, 10, 27, "Text",
  CellTags->"i:114"],

Cell[CellGroupData[{
Cell[7751792, 158970, 89, 3, 67, "Input",
  CellTags->"Cell 2.69"],
Cell[7751884, 158975, 137637, 1939, 233, 75437, 1014, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7889524, 160916, 127, 3, 46, "Output"]
}, Open  ]],
Cell[7889666, 160922, 195, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[7889886, 160932, 103, 3, 67, "Input",
  CellTags->"Cell 2.70"],
Cell[7889992, 160937, 310, 10, 46, "Output"]
}, Open  ]],
Cell[7890317, 160950, 1171, 39, 78, "Text",
  CellTags->"i:99"],

Cell[CellGroupData[{
Cell[7891513, 160993, 161, 4, 67, "Input",
  CellTags->"Cell 2.71"],
Cell[7891677, 160999, 41, 1, 46, "Output"]
}, Open  ]],
Cell[7891733, 161003, 258, 6, 44, "Text"],

Cell[CellGroupData[{
Cell[7892016, 161013, 111, 3, 67, "Input",
  CellTags->"Cell 2.72"],
Cell[7892130, 161018, 58, 1, 46, "Output"]
}, Open  ]],
Cell[7892203, 161022, 54, 0, 27, "Text"],
Cell[7892260, 161024, 163, 4, 67, "Input",
  CellTags->"Cell 2.73"],
Cell[7892426, 161030, 47, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[7892498, 161034, 96, 3, 67, "Input",
  CellTags->"Cell 2.74"],
Cell[7892597, 161039, 39, 1, 46, "Output"]
}, Open  ]],
Cell[7892651, 161043, 101, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[7892777, 161050, 121, 3, 67, "Input",
  CellTags->"Cell 2.75"],
Cell[7892901, 161055, 500, 7, 141, "Output"]
}, Open  ]],
Cell[7893416, 161065, 932, 15, 157, "Text"],
Cell[7894351, 161082, 111, 3, 73, "Input",
  CellTags->"Cell 2.76"],
Cell[7894465, 161087, 259, 7, 44, "Text"],

Cell[CellGroupData[{
Cell[7894749, 161098, 127, 3, 75, "Input",
  CellTags->"Cell 2.77"],
Cell[7894879, 161103, 715944, 37402, 233, 696192, 37154, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8610838, 198508, 1292, 38, 64, "Text"],

Cell[CellGroupData[{
Cell[8612155, 198550, 131, 3, 67, "Input",
  CellTags->"Cell 2.78"],
Cell[8612289, 198555, 205, 3, 50, "Message"],
Cell[8612497, 198560, 48, 1, 46, "Output"]
}, Open  ]],
Cell[8612560, 198564, 369, 12, 30, "Text"],
Cell[8612932, 198578, 182, 5, 75, "Input",
  CellTags->"Cell 2.79"],
Cell[8613117, 198585, 199, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[8613341, 198595, 216, 5, 98, "Input",
  CellTags->"Cell 2.80"],
Cell[8613560, 198602, 120670, 5668, 233, 101001, 5421, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[8734245, 204273, 471, 8, 78, "Text",
  CellTags->"i:57"],
Cell[8734719, 204283, 158, 4, 75, "Input",
  CellTags->"Cell 2.81"],
Cell[8734880, 204289, 469, 9, 61, "Text"],
Cell[8735352, 204300, 126, 3, 67, "Input",
  CellTags->"Cell 2.82"],
Cell[8735481, 204305, 711, 20, 61, "Text"],
Cell[8736195, 204327, 194, 4, 67, "Input",
  CellTags->"Cell 2.83"],
Cell[8736392, 204333, 87, 3, 27, "Text"],
Cell[8736482, 204338, 127, 3, 73, "Input",
  CellTags->"Cell 2.84"],
Cell[8736612, 204343, 355, 8, 61, "Text"],

Cell[CellGroupData[{
Cell[8736992, 204355, 97, 3, 73, "Input",
  CellTags->"Cell 2.85"],
Cell[8737092, 204360, 39, 1, 46, "Output"]
}, Open  ]],
Cell[8737146, 204364, 388, 13, 44, "Text",
  CellTags->"i:104"],

Cell[CellGroupData[{
Cell[8737559, 204381, 227, 5, 111, "Input",
  CellTags->"Cell 2.86"],
Cell[8737789, 204388, 202876, 2745, 233, 75435, 1014, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8940668, 207135, 127, 3, 46, "Output"]
}, Open  ]],
Cell[8940810, 207141, 774, 19, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8941633, 207166, 156, 4, 54, "Subsubtitle",
  CellTags->{"i:54", "c:38"}],
Cell[8941792, 207172, 590, 15, 61, "Text"],
Cell[8942385, 207189, 443, 14, 49, "Text"],
Cell[8942831, 207205, 391, 12, 34, "NE3",
  CellTags->"(2.3.69)"],
Cell[8943225, 207219, 436, 12, 49, "Text"],
Cell[8943664, 207233, 237, 7, 33, "NE3",
  CellTags->"(2.3.70)"],
Cell[8943904, 207242, 359, 12, 45, "Text"],
Cell[8944266, 207256, 292, 8, 33, "NE3",
  CellTags->"(2.3.71)"],
Cell[8944561, 207266, 680, 18, 79, "Text"],
Cell[8945244, 207286, 230, 7, 44, "Text"],
Cell[8945477, 207295, 390, 9, 49, "NE3",
  CellTags->"(2.3.72)"],
Cell[8945870, 207306, 274, 8, 44, "Text"],
Cell[8946147, 207316, 735, 18, 68, "Text"],
Cell[8946885, 207336, 234, 7, 32, "NE3",
  CellTags->"(2.3.73)"],
Cell[8947122, 207345, 246, 9, 33, "Text"],
Cell[8947371, 207356, 1272, 39, 95, "Text"],
Cell[8948646, 207397, 347, 9, 44, "Text"],
Cell[8948996, 207408, 343, 10, 44, "Text"],
Cell[8949342, 207420, 441, 14, 44, "Text"],
Cell[8949786, 207436, 108, 5, 28, "Text"],
Cell[8949897, 207443, 925, 22, 98, "Text"],
Cell[8950825, 207467, 546, 9, 95, "Text"],
Cell[8951374, 207478, 887, 26, 79, "Text",
  CellTags->"i:84"],
Cell[8952264, 207506, 830, 19, 95, "Text"],
Cell[8953097, 207527, 241, 7, 44, "Text"],
Cell[8953341, 207536, 333, 6, 47, "NE3",
  CellTags->"(2.3.74)"],
Cell[8953677, 207544, 963, 29, 64, "Text"],
Cell[8954643, 207575, 430, 11, 47, "NE3",
  CellTags->"(2.3.75)"],
Cell[8955076, 207588, 427, 12, 61, "Text"],

Cell[CellGroupData[{
Cell[8955528, 207604, 227, 5, 105, "Input",
  CellTags->"Cell 2.87"],
Cell[8955758, 207611, 109, 2, 64, "Output"]
}, Open  ]],
Cell[8955882, 207616, 379, 12, 27, "Text"],
Cell[8956264, 207630, 311, 10, 43, "NE3",
  CellTags->"(2.3.76)"],
Cell[8956578, 207642, 753, 26, 44, "Text"],
Cell[8957334, 207670, 417, 8, 78, "NE3",
  CellTags->{"(2.3.77)", "i:59"}],
Cell[8957754, 207680, 1206, 33, 112, "Text"],
Cell[8958963, 207715, 29036, 788, 233, 8790, 534, "GraphicsData", \
"PostScript", "Picture"],
Cell[8988002, 208505, 306, 10, 16, "Caption",
  CellTags->"Fig. 2.11"],
Cell[8988311, 208517, 594, 18, 45, "Text"],
Cell[8988908, 208537, 169, 4, 27, "Text",
  CellTags->"i:83"],
Cell[8989080, 208543, 184, 6, 32, "NE3",
  CellTags->"(2.3.78)"],
Cell[8989267, 208551, 401, 14, 28, "Text"],
Cell[8989671, 208567, 300, 7, 35, "NE3",
  CellTags->"(2.3.79)"],
Cell[8989974, 208576, 120, 3, 27, "Text"],
Cell[8990097, 208581, 317, 10, 35, "NE3",
  CellTags->"(2.3.80)"],
Cell[8990417, 208593, 411, 13, 45, "Text"],
Cell[8990831, 208608, 141, 6, 30, "NE3",
  CellTags->"(2.3.81)"],
Cell[8990975, 208616, 405, 13, 45, "Text"],
Cell[8991383, 208631, 450, 12, 61, "Text",
  CellTags->"i:60"],

Cell[CellGroupData[{
Cell[8991858, 208647, 192, 4, 67, "Input",
  CellTags->"Cell 2.88"],
Cell[8992053, 208653, 165811, 2309, 233, 83734, 1121, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9157879, 210965, 411, 10, 57, "Text"],
Cell[9158293, 210977, 331, 8, 57, "NE3",
  CellTags->"(2.3.82)"],
Cell[9158627, 210987, 677, 19, 57, "Text"],
Cell[9159307, 211008, 285, 8, 57, "NE3",
  CellTags->"(2.3.83)"],
Cell[9159595, 211018, 539, 17, 57, "Text"],
Cell[9160137, 211037, 381, 10, 57, "NE3",
  CellTags->"(2.3.84)"],
Cell[9160521, 211049, 382, 13, 44, "Text"],
Cell[9160906, 211064, 360, 10, 73, "NE3",
  CellTags->"(2.3.85)"],
Cell[9161269, 211076, 194, 4, 44, "Text"],
Cell[9161466, 211082, 1071, 29, 97, "Text"],
Cell[9162540, 211113, 321, 11, 27, "Text"],
Cell[9162864, 211126, 194, 6, 27, "Text"],
Cell[9163061, 211134, 243, 7, 32, "NE3",
  CellTags->"(2.3.86)"],
Cell[9163307, 211143, 1237, 32, 135, "Text"],
Cell[9164547, 211177, 350, 8, 73, "NE3",
  CellTags->{"(2.3.87)", "i:61"}],
Cell[9164900, 211187, 539, 11, 63, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9165476, 211203, 78, 1, 30, "Subsubtitle",
  CellTags->{"Ex. 2.3", "c:39"}],
Cell[9165557, 211206, 498, 15, 61, "Text"],
Cell[9166058, 211223, 320, 11, 29, "Text"],
Cell[9166381, 211236, 194, 8, 27, "Text"],
Cell[9166578, 211246, 389, 14, 27, "Text"],
Cell[9166970, 211262, 279, 9, 31, "Text"],
Cell[9167252, 211273, 300, 11, 34, "Text"],
Cell[9167555, 211286, 502, 14, 47, "Text"],
Cell[9168060, 211302, 590, 19, 50, "Text"],
Cell[9168653, 211323, 353, 12, 27, "Text"],
Cell[9169009, 211337, 201, 7, 27, "Text"],
Cell[9169213, 211346, 288, 10, 27, "Text"],
Cell[9169504, 211358, 424, 17, 28, "Text"],
Cell[9169931, 211377, 433, 10, 49, "Text"],
Cell[9170367, 211389, 230, 6, 44, "Text"],
Cell[9170600, 211397, 1322, 37, 31, "Text"],
Cell[9171925, 211436, 1109, 31, 31, "Text"],
Cell[9173037, 211469, 330, 9, 31, "Text"],
Cell[9173370, 211480, 585, 15, 52, "Text"],
Cell[9173958, 211497, 118, 4, 27, "Text"],
Cell[9174079, 211503, 212, 7, 32, "Text"],
Cell[9174294, 211512, 215, 7, 32, "Text"],
Cell[9174512, 211521, 217, 8, 32, "Text"],
Cell[9174732, 211531, 160, 5, 27, "Text"],
Cell[9174895, 211538, 217, 8, 36, "Text"],
Cell[9175115, 211548, 411, 14, 35, "Text"],
Cell[9175529, 211564, 285, 8, 36, "Text"],
Cell[9175817, 211574, 378, 12, 32, "Text"],
Cell[9176198, 211588, 311, 12, 36, "Text"],
Cell[9176512, 211602, 343, 14, 30, "Text",
  CellTags->"i:113"],
Cell[9176858, 211618, 335, 8, 34, "NE3",
  CellTags->"(2.3.88)"],
Cell[9177196, 211628, 1820, 50, 116, "Text",
  CellTags->"i:106"],
Cell[9179019, 211680, 414, 14, 31, "Text"],
Cell[9179436, 211696, 1016, 29, 52, "Text"],
Cell[9180455, 211727, 324, 12, 31, "Text"],
Cell[9180782, 211741, 398, 13, 29, "NE3",
  CellTags->"(2.3.89)"],
Cell[9181183, 211756, 778, 23, 61, "Text"],
Cell[9181964, 211781, 1158, 38, 65, "Text"],
Cell[9183125, 211821, 229, 6, 44, "Text"],
Cell[9183357, 211829, 1011, 27, 85, "Text"],
Cell[9184371, 211858, 446, 13, 44, "Text"],
Cell[9184820, 211873, 234, 7, 27, "Text"],
Cell[9185057, 211882, 401, 10, 44, "Text"],
Cell[9185461, 211894, 76, 1, 27, "Text",
  CellTags->"Table 2.2"],
Cell[9185540, 211897, 1643, 25, 467, "Input",
  Evaluatable->True,
  CellTags->"Cell 2.89"],
Cell[9187186, 211924, 1264, 36, 85, "Text"],
Cell[9188453, 211962, 1070, 35, 57, "Text"],
Cell[9189526, 211999, 721, 24, 55, "Text"],
Cell[9190250, 212025, 337, 12, 47, "Text"],
Cell[9190590, 212039, 1208, 40, 95, "Text",
  CellTags->"i:100"],
Cell[9191801, 212081, 272, 5, 61, "Text"],
Cell[9192076, 212088, 170, 4, 44, "Text"],
Cell[9192249, 212094, 436, 13, 47, "Text"],
Cell[9192688, 212109, 147, 6, 28, "Text"],
Cell[9192838, 212117, 444, 15, 44, "Text"],
Cell[9193285, 212134, 386, 11, 44, "Text"],
Cell[9193674, 212147, 377, 12, 44, "Text"],
Cell[9194054, 212161, 53494, 664, 164, 53373, 660, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[9247551, 212827, 54, 1, 16, "Caption",
  CellTags->"Fig. 2.12"],
Cell[9247608, 212830, 128, 4, 27, "Text"],
Cell[9247739, 212836, 246, 7, 31, "Text"],
Cell[9247988, 212845, 559, 17, 49, "Text"],
Cell[9248550, 212864, 693, 19, 78, "Text"],
Cell[9249246, 212885, 188, 6, 29, "Text"],
Cell[9249437, 212893, 1258, 36, 80, "Text"],
Cell[9250698, 212931, 1115, 30, 96, "Text",
  CellTags->"i:81"],
Cell[9251816, 212963, 1136, 28, 132, "Text"],
Cell[9252955, 212993, 1088, 32, 81, "Text"],
Cell[9254046, 213027, 477, 12, 61, "Text"],
Cell[9254526, 213041, 190, 6, 27, "Text",
  CellTags->"i:47"],
Cell[9254719, 213049, 194, 6, 67, "Input",
  CellTags->"Cell 2.90"],
Cell[9254916, 213057, 321, 6, 61, "Text"],
Cell[9255240, 213065, 391, 8, 61, "Text"],
Cell[9255634, 213075, 398, 12, 47, "Text"],
Cell[9256035, 213089, 401, 11, 44, "Text"],
Cell[9256439, 213102, 207, 6, 28, "Text"],
Cell[9256649, 213110, 224, 6, 28, "Text"],
Cell[9256876, 213118, 833, 22, 87, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9257758, 213146, 84, 1, 40, "Subtitle",
  CellTags->{"Sec. 2.4", "i:62", "c:40"}],
Cell[9257845, 213149, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[9257886, 213153, 61, 1, 40, "Subsubtitle",
  CellTags->"c:41"],
Cell[9257950, 213156, 337, 9, 44, "Text"],
Cell[9258290, 213167, 126, 5, 33, "NE4",
  CellTags->"(2.4.1)"],
Cell[9258419, 213174, 605, 19, 44, "Text",
  CellTags->"i:85"],
Cell[9259027, 213195, 146, 5, 33, "NE4",
  CellTags->"(2.4.2)"],
Cell[9259176, 213202, 342, 11, 27, "Text"],
Cell[9259521, 213215, 231, 7, 44, "Text"],
Cell[9259755, 213224, 236, 7, 32, "NE4",
  CellTags->"(2.4.3)"],
Cell[9259994, 213233, 947, 29, 78, "Text"],
Cell[9260944, 213264, 437, 17, 31, "Text"],
Cell[9261384, 213283, 580, 15, 33, "Text"],
Cell[9261967, 213300, 144, 6, 27, "Text"],
Cell[9262114, 213308, 559, 15, 61, "Text",
  CellTags->"i:63"],
Cell[9262676, 213325, 237, 7, 44, "Text"],
Cell[9262916, 213334, 1312, 41, 96, "Text"],
Cell[9264231, 213377, 206, 7, 34, "Text"],
Cell[9264440, 213386, 397, 12, 44, "Text"],
Cell[9264840, 213400, 1122, 27, 129, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9265999, 213432, 129, 4, 29, "Subsubtitle",
  CellTags->{"i:64", "c:42"}],

Cell[CellGroupData[{
Cell[9266153, 213440, 56, 1, 42, "Section",
  CellTags->"c:43"],
Cell[9266212, 213443, 242, 5, 44, "Text"],
Cell[9266457, 213450, 227, 6, 27, "Text"],
Cell[9266687, 213458, 615, 13, 42, "NE4",
  CellTags->"(2.4.4)"],
Cell[9267305, 213473, 362, 12, 27, "Text"],
Cell[9267670, 213487, 494, 16, 48, "Text"],
Cell[9268167, 213505, 424, 11, 27, "NE4",
  CellTags->"(2.4.5)"],
Cell[9268594, 213518, 561, 17, 61, "Text"],
Cell[9269158, 213537, 338, 8, 27, "NE4",
  CellTags->"(2.4.6)"],
Cell[9269499, 213547, 547, 21, 45, "Text"],
Cell[9270049, 213570, 836, 19, 52, "Text"],
Cell[9270888, 213591, 606, 18, 61, "Text"],
Cell[9271497, 213611, 1213, 31, 43, "Text"],
Cell[9272713, 213644, 397, 14, 27, "Text"],
Cell[9273113, 213660, 401, 14, 39, "Text"],
Cell[9273517, 213676, 353, 15, 27, "Text"],
Cell[9273873, 213693, 273, 6, 29, "NE4",
  CellTags->"(2.4.7)"],
Cell[9274149, 213701, 378, 16, 27, "Text"],
Cell[9274530, 213719, 217, 4, 43, "NE4",
  CellTags->"(2.4.8)"],
Cell[9274750, 213725, 406, 15, 28, "Text",
  CellTags->"i:68"],
Cell[9275159, 213742, 986, 31, 78, "Text"],
Cell[9276148, 213775, 71, 0, 27, "Text"],
Cell[9276222, 213777, 139, 3, 27, "NE4",
  CellTags->"(2.4.9)"],
Cell[9276364, 213782, 1216, 35, 112, "Text"],
Cell[9277583, 213819, 615, 24, 44, "Text"],
Cell[9278201, 213845, 604, 11, 49, "NE4",
  CellTags->"(2.4.10)"],
Cell[9278808, 213858, 745, 19, 78, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9279590, 213882, 46, 1, 31, "Section",
  CellTags->"c:44"],
Cell[9279639, 213885, 194, 4, 44, "Text"],
Cell[9279836, 213891, 187, 6, 31, "Text"],
Cell[9280026, 213899, 117, 3, 27, "Text"],
Cell[9280146, 213904, 220, 7, 76, "Text"],
Cell[9280369, 213913, 403, 12, 53, "Text"],
Cell[9280775, 213927, 206, 7, 40, "Text"],
Cell[9280984, 213936, 521, 16, 48, "Text"],
Cell[9281508, 213954, 1018, 29, 107, "Text"],
Cell[9282529, 213985, 115, 3, 27, "Text"],
Cell[9282647, 213990, 211, 6, 42, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9282895, 214001, 53, 1, 31, "Section",
  CellTags->"c:45"],
Cell[9282951, 214004, 249, 6, 44, "Text"],
Cell[9283203, 214012, 852, 23, 42, "NE4",
  CellTags->"(2.4.11)"],
Cell[9284058, 214037, 512, 18, 44, "Text"],
Cell[9284573, 214057, 199, 4, 33, "NE4",
  CellTags->"(2.4.12)"],
Cell[9284775, 214063, 596, 21, 62, "Text"],
Cell[9285374, 214086, 450, 13, 45, "NE4",
  CellTags->"(2.4.13)"],
Cell[9285827, 214101, 281, 8, 44, "Text"],
Cell[9286111, 214111, 497, 13, 43, "NE4",
  CellTags->"(2.4.14)"],
Cell[9286611, 214126, 65, 0, 27, "Text"],
Cell[9286679, 214128, 107, 2, 27, "NE4",
  CellTags->"(2.4.15)"],
Cell[9286789, 214132, 1004, 31, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9287842, 214169, 145, 4, 29, "Subsubtitle",
  CellTags->{"i:70", "c:46"}],
Cell[9287990, 214175, 416, 16, 50, "Text",
  CellTags->"i:108"],
Cell[9288409, 214193, 253, 7, 37, "NE4",
  CellTags->"(2.4.16)"],
Cell[9288665, 214202, 503, 14, 67, "Text"],
Cell[9289171, 214218, 126, 2, 36, "NE4",
  CellTags->"(2.4.17)"],
Cell[9289300, 214222, 585, 22, 54, "Text"],
Cell[9289888, 214246, 672, 16, 77, "Text"],
Cell[9290563, 214264, 882, 28, 75, "Text"],
Cell[9291448, 214294, 188, 6, 36, "NE4",
  CellTags->"(2.4.18)"],
Cell[9291639, 214302, 277, 11, 34, "Text"],
Cell[9291919, 214315, 940, 26, 94, "Text"],
Cell[9292862, 214343, 776, 24, 71, "Text"],
Cell[9293641, 214369, 355, 8, 61, "Text"],
Cell[9293999, 214379, 428, 13, 38, "NE4",
  CellTags->"(2.4.19)"],
Cell[9294430, 214394, 530, 17, 44, "Text",
  CellTags->"i:90"],
Cell[9294963, 214413, 538, 13, 59, "NE4",
  CellTags->"(2.4.20)"],
Cell[9295504, 214428, 75, 0, 27, "Text"],
Cell[9295582, 214430, 449, 16, 29, "NE4",
  CellTags->"(2.4.21)"],
Cell[9296034, 214448, 1619, 54, 48, "Text"],
Cell[9297656, 214504, 2212, 56, 108, "NE4",
  CellTags->"(2.4.22)"],
Cell[9299871, 214562, 754, 23, 43, "Text"],
Cell[9300628, 214587, 239, 9, 26, "Text"],
Cell[9300870, 214598, 492, 17, 31, "NE4",
  CellTags->"(2.4.23)"],
Cell[9301365, 214617, 411, 13, 50, "Text"],
Cell[9301779, 214632, 1316, 36, 129, "Text"],
Cell[9303098, 214670, 413, 10, 61, "Text"],
Cell[9303514, 214682, 227, 7, 29, "NE4",
  CellTags->"(2.4.24)"],
Cell[9303744, 214691, 1436, 49, 86, "Text"],
Cell[9305183, 214742, 998, 37, 72, "Text"],
Cell[9306184, 214781, 693, 20, 65, "Text"],
Cell[9306880, 214803, 1238, 32, 118, "Text"],
Cell[9308121, 214837, 1343, 43, 95, "Text"],
Cell[9309467, 214882, 433, 10, 143, "Input",
  CellTags->"Cell 2.91"],
Cell[9309903, 214894, 68, 0, 27, "Text"],
Cell[9309974, 214896, 150, 4, 86, "Input",
  CellTags->"Cell 2.92"],
Cell[9310127, 214902, 106, 5, 27, "Text"],
Cell[9310236, 214909, 105, 3, 67, "Input",
  CellTags->"Cell 2.93"],
Cell[9310344, 214914, 359, 13, 27, "Text"],

Cell[CellGroupData[{
Cell[9310728, 214931, 198, 5, 86, "Input",
  CellTags->"Cell 2.94"],
Cell[9310929, 214938, 13579, 399, 233, 4189, 279, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9324523, 215340, 181, 5, 44, "Text",
  CellTags->"i:105"],

Cell[CellGroupData[{
Cell[9324729, 215349, 239, 6, 86, "Input",
  CellTags->"Cell 2.95"],
Cell[9324971, 215357, 106, 2, 77, "Output"]
}, Open  ]],
Cell[9325092, 215362, 182, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[9325299, 215372, 220, 5, 86, "Input",
  CellTags->"Cell 2.96"],
Cell[9325522, 215379, 17470, 495, 233, 5120, 339, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9343007, 215877, 167, 4, 44, "Text"],
Cell[9343177, 215883, 428, 12, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9343642, 215900, 103, 1, 29, "Subsubtitle",
  CellTags->{"i:65", "c:47"}],
Cell[9343748, 215903, 953, 26, 77, "Text"],
Cell[9344704, 215931, 609, 16, 60, "Text"],
Cell[9345316, 215949, 289, 11, 32, "NE4",
  CellTags->"(2.4.25)"],
Cell[9345608, 215962, 1149, 34, 60, "Text"],
Cell[9346760, 215998, 448, 17, 43, "Text"],
Cell[9347211, 216017, 141, 5, 28, "NE4",
  CellTags->"(2.4.26)"],
Cell[9347355, 216024, 560, 17, 45, "Text"],
Cell[9347918, 216043, 368, 10, 31, "NE4",
  CellTags->"(2.4.27)"],
Cell[9348289, 216055, 76, 0, 26, "Text"],
Cell[9348368, 216057, 409, 12, 33, "NE4",
  CellTags->"(2.4.28)"],
Cell[9348780, 216071, 784, 26, 61, "Text",
  CellTags->"i:82"],
Cell[9349567, 216099, 314, 11, 43, "Text"],
Cell[9349884, 216112, 394, 13, 32, "NE4",
  CellTags->"(2.4.29)"],
Cell[9350281, 216127, 168, 6, 26, "Text"],
Cell[9350452, 216135, 222, 7, 57, "NE4",
  CellTags->"(2.4.30)"],
Cell[9350677, 216144, 382, 12, 27, "Text"],
Cell[9351062, 216158, 312, 5, 60, "Text"],
Cell[9351377, 216165, 518, 15, 60, "Text"],
Cell[9351898, 216182, 258, 8, 42, "NE4",
  CellTags->"(2.4.31)"],
Cell[9352159, 216192, 127, 5, 26, "Text"],
Cell[9352289, 216199, 258, 8, 42, "NE4",
  CellTags->"(2.4.32)"],
Cell[9352550, 216209, 224, 8, 28, "Text"],
Cell[9352777, 216219, 522, 14, 55, "NE4",
  CellTags->"(2.4.33)"],
Cell[9353302, 216235, 793, 29, 47, "Text"],
Cell[9354098, 216266, 378, 13, 43, "Text"],
Cell[9354479, 216281, 185, 3, 30, "NE4",
  CellTags->"(2.4.34)"],
Cell[9354667, 216286, 442, 16, 45, "Text"],
Cell[9355112, 216304, 807, 25, 63, "Text"],
Cell[9355922, 216331, 261, 7, 30, "NE4",
  CellTags->"(2.4.35)"],
Cell[9356186, 216340, 379, 16, 26, "Text"],
Cell[9356568, 216358, 1292, 32, 86, "NE4",
  CellTags->{"(2.4.36)", "i:66"}],
Cell[9357863, 216392, 1030, 33, 62, "Text",
  CellTags->"i:67"]
}, Closed]],

Cell[CellGroupData[{
Cell[9358930, 216430, 146, 4, 29, "Subsubtitle",
  CellTags->{"i:69", "c:48"}],

Cell[CellGroupData[{
Cell[9359101, 216438, 67, 1, 42, "Section",
  CellTags->"c:49"],
Cell[9359171, 216441, 194, 7, 27, "Text",
  CellTags->"i:109"],
Cell[9359368, 216450, 138, 5, 36, "NE4",
  CellTags->"(2.4.37)"],
Cell[9359509, 216457, 147, 5, 33, "Text"],
Cell[9359659, 216464, 262, 7, 37, "NE4",
  CellTags->"(2.4.38)"],
Cell[9359924, 216473, 430, 9, 61, "Text"],
Cell[9360357, 216484, 574, 13, 42, "NE4",
  CellTags->"(2.4.39)"],
Cell[9360934, 216499, 40, 0, 27, "Text"],
Cell[9360977, 216501, 146, 3, 27, "NE4",
  CellTags->"(2.4.40)"],
Cell[9361126, 216506, 919, 28, 44, "Text"],
Cell[9362048, 216536, 243, 6, 44, "Text"],
Cell[9362294, 216544, 1401, 37, 41, "NE4",
  CellTags->"(2.4.41)"],
Cell[9363698, 216583, 607, 19, 61, "Text",
  CellTags->"i:92"],
Cell[9364308, 216604, 1148, 32, 41, "NE4",
  CellTags->"(2.4.42)"],
Cell[9365459, 216638, 70, 0, 27, "Text"],
Cell[9365532, 216640, 1145, 30, 40, "NE4",
  CellTags->"(2.4.43)"],
Cell[9366680, 216672, 179, 4, 44, "Text"],
Cell[9366862, 216678, 1254, 35, 48, "NE4",
  CellTags->"(2.4.44)"],
Cell[9368119, 216715, 475, 13, 61, "Text",
  CellTags->"i:75"],
Cell[9368597, 216730, 3662, 87, 158, "Table",
  CellTags->{"i:74", "Table 2.3"}],
Cell[9372262, 216819, 16, 0, 27, "Text"],
Cell[9372281, 216821, 10076, 196, 323, "Table",
  CellTags->{"i:73", "Table 2.4"}],
Cell[9382360, 217019, 321, 10, 43, "Text"],
Cell[9382684, 217031, 1114, 30, 40, "NE4",
  CellTags->"(2.4.45)"],
Cell[9383801, 217063, 269, 9, 43, "Text"],
Cell[9384073, 217074, 154, 3, 26, "NE4",
  CellTags->"(2.4.46)"],
Cell[9384230, 217079, 883, 32, 60, "Text"],
Cell[9385116, 217113, 393, 14, 28, "NE4",
  CellTags->"(2.4.47)"],
Cell[9385512, 217129, 22, 0, 26, "Text"],
Cell[9385537, 217131, 584, 19, 43, "NE4",
  CellTags->"(2.4.48)"],
Cell[9386124, 217152, 310, 12, 26, "Text"],
Cell[9386437, 217166, 967, 24, 32, "NE4",
  CellTags->"(2.4.49)"],
Cell[9387407, 217192, 87, 3, 26, "Text"],

Cell[CellGroupData[{
Cell[9387519, 217199, 521, 13, 143, "Input",
  CellTags->"Cell 2.97"],
Cell[9388043, 217214, 948, 20, 152, "Output"]
}, Open  ]],
Cell[9389006, 217237, 142, 3, 27, "Text"],
Cell[9389151, 217242, 195, 4, 86, "Input",
  CellTags->"Cell 2.98"],
Cell[9389349, 217248, 45, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[9389419, 217252, 93, 3, 67, "Input",
  CellTags->"Cell 2.99"],
Cell[9389515, 217257, 680, 15, 128, "Output"]
}, Open  ]],
Cell[9390210, 217275, 460, 15, 44, "Text"],
Cell[9390673, 217292, 490, 15, 61, "Text",
  CellTags->"i:76"],
Cell[9391166, 217309, 684, 18, 42, "NE4",
  CellTags->"(2.4.50)"],
Cell[9391853, 217329, 1371, 37, 114, "Text"],
Cell[9393227, 217368, 568, 17, 41, "NE4",
  CellTags->"(2.4.51)"],
Cell[9393798, 217387, 610, 11, 95, "Text",
  CellTags->"i:77"],
Cell[9394411, 217400, 372, 12, 44, "Text"],
Cell[9394786, 217414, 436, 15, 32, "NE4",
  CellTags->"(2.4.52)"],
Cell[9395225, 217431, 807, 24, 78, "Text",
  CellTags->"i:78"],
Cell[9396035, 217457, 478, 15, 44, "Text"],
Cell[9396516, 217474, 1695, 35, 201, "Text"],
Cell[9398214, 217511, 2384, 67, 214, "Text",
  CellTags->"i:79"]
}, Closed]],

Cell[CellGroupData[{
Cell[9400635, 217583, 46, 1, 31, "Section",
  CellTags->"c:50"],
Cell[9400684, 217586, 1372, 42, 82, "Text"],
Cell[9402059, 217630, 483, 14, 43, "Text"],
Cell[9402545, 217646, 289, 12, 36, "Text"],
Cell[9402837, 217660, 473, 17, 44, "Text"],
Cell[9403313, 217679, 318, 7, 143, "Input",
  CellTags->"Cell 2.100"],
Cell[9403634, 217688, 151, 6, 27, "Text"],
Cell[9403788, 217696, 656, 14, 181, "Input",
  CellTags->"Cell 2.101"],
Cell[9404447, 217712, 112, 5, 27, "Text"],
Cell[9404562, 217719, 344, 7, 124, "Input",
  CellTags->"Cell 2.102"],
Cell[9404909, 217728, 97, 3, 27, "Text"],
Cell[9405009, 217733, 118, 3, 67, "Input",
  CellTags->"Cell 2.103"],
Cell[9405130, 217738, 604, 16, 78, "Text"],

Cell[CellGroupData[{
Cell[9405759, 217758, 744, 14, 220, "Input",
  CellTags->"Cell 2.104"],
Cell[9406506, 217774, 49156, 950, 311, 7144, 428, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[9455677, 218727, 242, 5, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9455968, 218738, 65, 1, 29, "Subsubtitle",
  CellTags->"c:51"],
Cell[9456036, 218741, 177, 5, 27, "Text"],
Cell[9456216, 218748, 296, 12, 40, "Text"],
Cell[9456515, 218762, 222, 8, 30, "Text"],
Cell[9456740, 218772, 296, 9, 44, "Text"],
Cell[9457039, 218783, 322, 12, 28, "Text"],
Cell[9457364, 218797, 595, 21, 28, "Text"],
Cell[9457962, 218820, 530, 20, 28, "Text"],
Cell[9458495, 218842, 456, 17, 28, "Text"],
Cell[9458954, 218861, 512, 18, 28, "Text"],
Cell[9459469, 218881, 721, 22, 30, "Text"],
Cell[9460193, 218905, 707, 22, 30, "Text"],
Cell[9460903, 218929, 628, 19, 28, "Text"],
Cell[9461534, 218950, 464, 15, 28, "Text"],
Cell[9462001, 218967, 214, 5, 44, "Text"],
Cell[9462218, 218974, 206, 8, 28, "Text"],
Cell[9462427, 218984, 217, 8, 28, "Text"],
Cell[9462647, 218994, 327, 11, 30, "Text"],
Cell[9462977, 219007, 314, 11, 28, "Text"],
Cell[9463294, 219020, 327, 10, 29, "Text"],
Cell[9463624, 219032, 295, 10, 30, "Text"],
Cell[9463922, 219044, 310, 10, 28, "Text"],
Cell[9464235, 219056, 329, 11, 28, "Text"],
Cell[9464567, 219069, 372, 10, 28, "Text"],
Cell[9464942, 219081, 609, 19, 44, "Text",
  CellTags->"i:91"],
Cell[9465554, 219102, 1025, 32, 62, "Text"],
Cell[9466582, 219136, 113, 5, 27, "Text"],
Cell[9466698, 219143, 113, 5, 27, "Text"],
Cell[9466814, 219150, 454, 15, 28, "Text"],
Cell[9467271, 219167, 421, 10, 61, "Text"],
Cell[9467695, 219179, 594, 17, 40, "Text"],
Cell[9468292, 219198, 359, 11, 44, "Text"],
Cell[9468654, 219211, 189, 5, 27, "Text"],
Cell[9468846, 219218, 548, 16, 40, "Text"],
Cell[9469397, 219236, 669, 18, 78, "Text"],
Cell[9470069, 219256, 1057, 29, 30, "Text"],
Cell[9471129, 219287, 129, 5, 27, "Text"],
Cell[9471261, 219294, 462, 16, 44, "Text"],
Cell[9471726, 219312, 506, 16, 47, "Text"],
Cell[9472235, 219330, 338, 11, 30, "Text"],
Cell[9472576, 219343, 179, 8, 27, "Text"],
Cell[9472758, 219353, 185, 9, 27, "Text"],
Cell[9472946, 219364, 500, 15, 61, "Text"],
Cell[9473449, 219381, 206, 5, 44, "Text"],
Cell[9473658, 219388, 684, 19, 40, "Text"],
Cell[9474345, 219409, 95, 3, 27, "Text"],
Cell[9474443, 219414, 361, 11, 44, "Text"],
Cell[9474807, 219427, 238, 6, 44, "Text"],
Cell[9475048, 219435, 609, 18, 40, "Text"],
Cell[9475660, 219455, 633, 20, 44, "Text"],
Cell[9476296, 219477, 93, 4, 27, "Text"],
Cell[9476392, 219483, 348, 9, 44, "Text"],
Cell[9476743, 219494, 128, 4, 27, "Text"],
Cell[9476874, 219500, 129, 4, 27, "Text"],
Cell[9477006, 219506, 606, 16, 45, "Text"],
Cell[9477615, 219524, 723, 24, 45, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9478387, 219554, 50, 1, 40, "Subtitle",
  CellTags->"c:52"],
Cell[9478440, 219557, 246, 6, 44, "Text"],
Cell[9478689, 219565, 152, 5, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

